*========================PROGRAM: PDI_ALL_FORMATS.SAS =======================;
*
* DESCRIPTION: Creates Format library for AHRQ Pediatric Quality Indicators;
*
*  VERSION: AHRQ QI v7.0.1 BETA
*  RELEASE DATE: DECEMBER 2017
*
* ============================================================================;
*PATHNAME specifies the location of the PDI folder which includes the
 Programs, Macros, and SASdata subfolders;
%LET PATHNAME=C:\PATHNAME\PDI;                           *<===USER MUST modify; 
filename CONTROL "&PATHNAME.\Programs\PDI_ALL_CONTROL.SAS"; 
%INCLUDE CONTROL; 
 
*SAS option to print program text to log is disabled to avoid filling log window;
%let orgoptionValue = %sysfunc(getoption(source));
option nosource;

 proc format library=LIBRARY;

/* -------------------------------------------------------------- */
/* --- FORMATS FOR STRATIFIERS ---------------------------------- */
/* -------------------------------------------------------------- */
 
/* --- FORMAT FOR SEX CATEGORY ---------------------------------- */
value SEXCAT
1 = 'Male'
2 = 'Female'
;
 
/* --- FORMAT FOR AGE CATEGORY ---------------------------------- */
value PAGECAT
1 = "<1"
2 = "1 TO 2"
3 = "3 TO 5"
4 = "6 TO 12"
5 = "13 TO 17"
;
 
/* --- FORMAT FOR AGEDAY CATEGORY ------------------------------- */
value AGEDCAT
0 = "NA"
1 = "0 TO 28"
2 = "29 TO 60"
3 = "61 TO 90"
4 = "91+"
;
 
/* --- FORMAT FOR BIRTH WEIGHT CATEGORY ------------------------- */
value BWHTCAT
0 = "NA"
1 = "0 TO 499g"
2 = "500 TO 749g"
3 = "750 TO 999g"
4 = "1000 TO 1249g"
5 = "1250 TO 1499g"
6 = "1500 TO 1749g"
7 = "1750 TO 1999g"
8 = "2000 TO 2499g"
9 = "2500g or more"
;
 
/* --- FORMAT FOR RACE CATEGORY --------------------------------- */
value RACECAT
1 = 'White'
2 = 'Black'
3 = 'Hispanic'
4 = 'Asian and NH/PI'
5 = 'Amer Indian/AN'
6 = 'Other'
;
 
/* --- FORMAT FOR PAYER CATEGORY ---------------------------------- */
value PAYCAT
1 = 'Medicare'
2 = 'Medicaid'
3 = 'Private'
4 = 'Self Pay'
5 = 'No Charge'
6 = 'Other'
;
 
/* --- FORMAT FOR POPULATION CATEGORY ----------------------------- */
value POPCAT
1 = '0 to 4'
2 = '5 to 9'
3 = '10 to 14'
4 = '15 to 17'
;
 
* -------------------------------------------------------------- ;
* --- PDI DEFINING FORMATS ------------------------------------- ;
* -------------------------------------------------------------- ;
 
* -------------------------------------------------------------- ;
* --- FORMATS - PROVIDER AND AREA LEVEL INDICATORS ------------- ;
* -------------------------------------------------------------- ;
 
/* ---------------------------------------------------------------- */
/* MEDICAL DRGS - PEDIATRIC ONLY                                    */
/* ---------------------------------------------------------------- */
 
/* DIAGNOSTIC RELATED GROUPS (DRGS) */
 
value $MEDIC2R
'052' = '1' /* Spinal disorders & injuries w CC/MCC */
'053' = '1' /* Spinal disorders & injuries w/o CC/MCC */
'054' = '1' /* Nervous system neoplasms w MCC */
'055' = '1' /* Nervous system neoplasms w/o MCC */
'056' = '1' /* Degenerative nervous system disorders w MCC */
'057' = '1' /* Degenerative nervous system disorders w/o MCC */
'058' = '1' /* Multiple sclerosis & cerebellar ataxia w MCC */
'059' = '1' /* Multiple sclerosis & cerebellar ataxia w CC */
'060' = '1' /* Multiple sclerosis & cerebellar ataxia w/o CC/MCC */
'061' = '1' /* Acute ischemic stroke w use of thrombolytic agent w MCC */
'062' = '1' /* Acute ischemic stroke w use of thrombolytic agent w CC */
'063' = '1' /* Acute ischemic stroke w use of thrombolytic agent w/o CC/MCC */
'064' = '1' /* Intracranial hemorrhage or cerebral infarction w MCC */
'065' = '1' /* Intracranial hemorrhage or cerebral infarction w CC */
'066' = '1' /* Intracranial hemorrhage or cerebral infarction w/o CC/MCC */
'067' = '1' /* Nonspecific cva & precerebral occlusion w/o infarct w MCC */
'068' = '1' /* Nonspecific cva & precerebral occlusion w/o infarct w/o MCC */
'069' = '1' /* Transient ischemia */
'070' = '1' /* Nonspecific cerebrovascular disorders w MCC */
'071' = '1' /* Nonspecific cerebrovascular disorders w CC */
'072' = '1' /* Nonspecific cerebrovascular disorders w/o CC/MCC */
'073' = '1' /* Cranial & peripheral nerve disorders w MCC */
'074' = '1' /* Cranial & peripheral nerve disorders w/o MCC */
'075' = '1' /* Viral meningitis w CC/MCC */
'076' = '1' /* Viral meningitis w/o CC/MCC */
'077' = '1' /* Hypertensive encephalopathy w MCC */
'078' = '1' /* Hypertensive encephalopathy w CC */
'079' = '1' /* Hypertensive encephalopathy w/o CC/MCC */
'080' = '1' /* Nontraumatic stupor & coma w MCC */
'081' = '1' /* Nontraumatic stupor & coma w/o MCC */
'082' = '1' /* Traumatic stupor & coma, coma >1 hr w MCC */
'083' = '1' /* Traumatic stupor & coma, coma >1 hr w CC */
'084' = '1' /* Traumatic stupor & coma, coma >1 hr w/o CC/MCC */
'085' = '1' /* Traumatic stupor & coma, coma <1 hr w MCC */
'086' = '1' /* Traumatic stupor & coma, coma <1 hr w CC */
'087' = '1' /* Traumatic stupor & coma, coma <1 hr w/o CC/MCC */
'088' = '1' /* Concussion w MCC */
'089' = '1' /* Concussion w CC */
'090' = '1' /* Concussion w/o CC/MCC */
'091' = '1' /* Other disorders of nervous system w MCC */
'092' = '1' /* Other disorders of nervous system w CC */
'093' = '1' /* Other disorders of nervous system w/o CC/MCC */
'094' = '1' /* Bacterial & tuberculous infections of nervous system w MCC */
'095' = '1' /* Bacterial & tuberculous infections of nervous system w CC */
'096' = '1' /* Bacterial & tuberculous infections of nervous system w/o CC/MCC */
'097' = '1' /* Non-bacterial infect of nervous sys exc viral meningitis w MCC */
'098' = '1' /* Non-bacterial infect of nervous sys exc viral meningitis w CC */
'099' = '1' /* Non-bacterial infect of nervous sys exc viral meningitis w/o CC/MCC */
'100' = '1' /* Seizures w MCC */
'101' = '1' /* Seizures w/o MCC */
'102' = '1' /* Headaches w MCC */
'103' = '1' /* Headaches w/o MCC */
'121' = '1' /* Acute major eye infections w CC/MCC */
'122' = '1' /* Acute major eye infections w/o CC/MCC */
'123' = '1' /* Neurological eye disorders */
'124' = '1' /* Other disorders of the eye w MCC */
'125' = '1' /* Other disorders of the eye w/o MCC */
'146' = '1' /* Ear, nose, mouth & throat malignancy w MCC */
'147' = '1' /* Ear, nose, mouth & throat malignancy w CC */
'148' = '1' /* Ear, nose, mouth & throat malignancy w/o CC/MCC */
'149' = '1' /* Dysequilibrium */
'150' = '1' /* Epistaxis w MCC */
'151' = '1' /* Epistaxis w/o MCC */
'152' = '1' /* Otitis media & URI w MCC */
'153' = '1' /* Otitis media & URI w/o MCC */
'154' = '1' /* Nasal trauma & deformity w MCC */
'155' = '1' /* Nasal trauma & deformity w CC */
'156' = '1' /* Nasal trauma & deformity w/o CC/MCC */
'157' = '1' /* Dental & Oral Diseases w MCC */
'158' = '1' /* Dental & Oral Diseases w CC */
'159' = '1' /* Dental & Oral Diseases w/o CC/MCC */
'175' = '1' /* Pulmonary embolism w MCC */
'176' = '1' /* Pulmonary embolism w/o MCC */
'177' = '1' /* Respiratory infections & inflammations w MCC */
'178' = '1' /* Respiratory infections & inflammations w CC */
'179' = '1' /* Respiratory infections & inflammations w/o CC/MCC */
'180' = '1' /* Respiratory neoplasms w MCC */
'181' = '1' /* Respiratory neoplasms w CC */
'182' = '1' /* Respiratory neoplasms w/o CC/MCC */
'183' = '1' /* Major chest trauma w MCC */
'184' = '1' /* Major chest trauma w CC */
'185' = '1' /* Major chest trauma w/o CC/MCC */
'186' = '1' /* Pleural effusion w MCC */
'187' = '1' /* Pleural effusion w CC */
'188' = '1' /* Pleural effusion w/o CC/MCC */
'189' = '1' /* Pulmonary edema & respiratory failure */
'190' = '1' /* Chronic obstructive pulmonary disease w MCC */
'191' = '1' /* Chronic obstructive pulmonary disease w CC */
'192' = '1' /* Chronic obstructive pulmonary disease w/o CC/MCC */
'193' = '1' /* Simple pneumonia & pleurisy w MCC */
'194' = '1' /* Simple pneumonia & pleurisy w CC */
'195' = '1' /* Simple pneumonia & pleurisy w/o CC/MCC */
'196' = '1' /* Interstitial lung disease w MCC */
'197' = '1' /* Interstitial lung disease w CC */
'198' = '1' /* Interstitial lung disease w/o CC/MCC */
'199' = '1' /* Pneumothorax w MCC */
'200' = '1' /* Pneumothorax w CC */
'201' = '1' /* Pneumothorax w/o CC/MCC */
'202' = '1' /* Bronchitis & asthma w CC/MCC */
'203' = '1' /* Bronchitis & asthma w/o CC/MCC */
'204' = '1' /* Respiratory signs & symptoms */
'205' = '1' /* Other respiratory system diagnoses w MCC */
'206' = '1' /* Other respiratory system diagnoses w/o MCC */
'207' = '1' /* Respiratory system diagnosis w ventilator support 96+ hours */
'208' = '1' /* Respiratory system diagnosis w ventilator support <96 hours */
'280' = '1' /* Acute myocardial infarction, discharged alive w MCC */
'281' = '1' /* Acute myocardial infarction, discharged alive w CC */
'282' = '1' /* Acute myocardia infarction, discharged alive w/o CC/MCC */
'283' = '1' /* Acute myocardial infarction, expired w MCC */
'284' = '1' /* Acute myocardial infarction, expired w CC */
'285' = '1' /* Acute myocardial infarction, expired w/o CC/MCC */
'286' = '1' /* Circulatory disorders except AMI, w card cath w MCC */
'287' = '1' /* Circulatory disorders except AMI, w card cath w/o MCC */
'288' = '1' /* Acute & subacute endocarditis w MCC */
'289' = '1' /* Acute & subacute endocarditis w CC */
'290' = '1' /* Acute & subacute endocarditis w/o CC/MCC */
'291' = '1' /* Heart failure & shock w MCC */
'292' = '1' /* Heart failure & shock w CC */
'293' = '1' /* Heart failure & shock w/o CC/MCC */
'294' = '1' /* Deep vein thrombophlebitis w CC/MCC */
'295' = '1' /* Deep vein thrombophlebitis w/o CC/MCC */
'296' = '1' /* Cardiac arrest, unexplained w MCC */
'297' = '1' /* Cardiac arrest, unexplained w CC */
'298' = '1' /* Cardiac arrest, unexplained w/o CC/MCC */
'299' = '1' /* Peripheral vascular disorders w MCC */
'300' = '1' /* Peripheral vascular disorders w CC */
'301' = '1' /* Peripheral vascular disorders w/o CC/MCC */
'302' = '1' /* Atherosclerosis w MCC */
'303' = '1' /* Atherosclerosis w/o MCC */
'304' = '1' /* Hypertension w MCC */
'305' = '1' /* Hypertension w/o MCC */
'306' = '1' /* Cardiac congenital & valvular disorders w MCC */
'307' = '1' /* Cardiac congenital & valvular disorders w/o MCC */
'308' = '1' /* Cardiac arrhythmia & conduction disorders w MCC */
'309' = '1' /* Cardiac arrhythmia & conduction disorders w CC */
'310' = '1' /* Cardiac arrhythmia & conduction disorders w/o CC/MCC */
'311' = '1' /* Angina pectoris */
'312' = '1' /* Syncope & collapse */
'313' = '1' /* Chest pain */
'314' = '1' /* Other circulatory system diagnoses w MCC */
'315' = '1' /* Other circulatory system diagnoses w CC */
'316' = '1' /* Other circulatory system diagnoses w/o CC/MCC */
'368' = '1' /* Major esophageal disorders w MCC */
'369' = '1' /* Major esophageal disorders w CC */
'370' = '1' /* Major esophageal disorders w/o CC/MCC */
'371' = '1' /* Major gastrointestinal disorders & peritoneal infections w MCC */
'372' = '1' /* Major gastrointestinal disorders & peritoneal infections w CC */
'373' = '1' /* Major gastrointestinal disorders & peritoneal infections w/o CC/MCC */
'374' = '1' /* Digestive malignancy w MCC */
'375' = '1' /* Digestive malignancy w CC */
'376' = '1' /* Digestive malignancy w/o CC/MCC */
'377' = '1' /* G.I. hemorrhage w MCC */
'378' = '1' /* G.I. hemorrhage w CC */
'379' = '1' /* G.I. hemorrhage w/o CC/MCC */
'380' = '1' /* Complicated peptic ulcer w MCC */
'381' = '1' /* Complicated peptic ulcer w CC */
'382' = '1' /* Complicated peptic ulcer w/o CC/MCC */
'383' = '1' /* Uncomplicated peptic ulcer w MCC */
'384' = '1' /* Uncomplicated peptic ulcer w/o MCC */
'385' = '1' /* Inflammatory bowel disease w MCC */
'386' = '1' /* Inflammatory bowel disease w CC */
'387' = '1' /* Inflammatory bowel disease w/o CC/MCC */
'388' = '1' /* G.I. obstruction w MCC */
'389' = '1' /* G.I. obstruction w CC */
'390' = '1' /* G.I. obstruction w/o CC/MCC */
'391' = '1' /* Esophagitis, gastroent & misc digest disorders w MCC */
'392' = '1' /* Esophagitis, gastroent & misc digest disorders w/o MCC */
'393' = '1' /* Other digestive system diagnoses w MCC */
'394' = '1' /* Other digestive system diagnoses w CC */
'395' = '1' /* Other digestive system diagnoses w/o CC/MCC */
'432' = '1' /* Cirrhosis & alcoholic hepatitis w MCC */
'433' = '1' /* Cirrhosis & alcoholic hepatitis w CC */
'434' = '1' /* Cirrhosis & alcoholic hepatitis w/o CC/MCC */
'435' = '1' /* Malignancy of hepatobiliary system or pancreas w MCC */
'436' = '1' /* Malignancy of hepatobiliary system or pancreas w CC */
'437' = '1' /* Malignancy of hepatobiliary system or pancreas w/o CC/MCC */
'438' = '1' /* Disorders of pancreas except malignancy w MCC */
'439' = '1' /* Disorders of pancreas except malignancy w CC */
'440' = '1' /* Disorders of pancreas except malignancy w/o CC/MCC */
'441' = '1' /* Disorders of liver except malig,cirr,alc hepa w MCC */
'442' = '1' /* Disorders of liver except malig,cirr,alc hepa w CC */
'443' = '1' /* Disorders of liver except malig,cirr,alc hepa w/o CC/MCC */
'444' = '1' /* Disorders of the biliary tract w MCC */
'445' = '1' /* Disorders of the biliary tract w CC */
'446' = '1' /* Disorders of the biliary tract w/o CC/MCC */
'533' = '1' /* Fractures of femur w MCC */
'534' = '1' /* Fractures of femur w/o MCC */
'535' = '1' /* Fractures of hip & pelvis w MCC */
'536' = '1' /* Fractures of hip & pelvis w/o MCC */
'537' = '1' /* Sprains, strains, & dislocations of hip, pelvis & thigh w CC/MCC */
'538' = '1' /* Sprains, strains, & dislocations of hip, pelvis & thigh w/o CC/MCC */
'539' = '1' /* Osteomyelitis w MCC */
'540' = '1' /* Osteomyelitis w CC */
'541' = '1' /* Osteomyelitis w/o CC/MCC */
'542' = '1' /* Pathological fractures & musculoskelet & conn tiss malig w MCC */
'543' = '1' /* Pathological fractures & musculoskelet & conn tiss malig w CC */
'544' = '1' /* Pathological fractures & musculoskelet & conn tiss malig w/o CC/MCC */
'545' = '1' /* Connective tissue disorders w MCC */
'546' = '1' /* Connective tissue disorders w CC */
'547' = '1' /* Connective tissue disorders w/o CC/MCC */
'548' = '1' /* Septic arthritis w MCC */
'549' = '1' /* Septic arthritis w CC */
'550' = '1' /* Septic arthritis w/o CC/MCC */
'551' = '1' /* Medical back problems w MCC */
'552' = '1' /* Medical back problems w/o MCC */
'553' = '1' /* Bone diseases & arthropathies w MCC */
'554' = '1' /* Bone diseases & arthropathies w/o MCC */
'555' = '1' /* Signs & symptoms of musculoskeletal system & conn tissue w MCC */
'556' = '1' /* Signs & symptoms of musculoskeletal system & conn tissue w/o MCC */
'557' = '1' /* Tendonitis, myositis & bursitis w MCC */
'558' = '1' /* Tendonitis, myositis & bursitis w/o MCC */
'559' = '1' /* Aftercare, musculoskeletal system & connective tissue w MCC */
'560' = '1' /* Aftercare, musculoskeletal system & connective tissue w CC */
'561' = '1' /* Aftercare, musculoskeletal system & connective tissue w/o CC/MCC */
'562' = '1' /* Fx, sprn, strn & disl except femur, hip, pelvis & thigh w MCC */
'563' = '1' /* Fx, sprn, strn & disl except femur, hip, pelvis & thigh w/o MCC */
'564' = '1' /* Other musculoskeletal sys & connective tissue diagnoses w MCC */
'565' = '1' /* Other musculoskeletal sys & connective tissue diagnoses w CC */
'566' = '1' /* Other musculoskeletal sys & connective tissue diagnoses w/o CC/MCC */
'592' = '1' /* Skin ulcers w MCC */
'593' = '1' /* Skin ulcers w CC */
'594' = '1' /* Skin ulcers w/o CC/MCC */
'595' = '1' /* Major skin disorders w MCC */
'596' = '1' /* Major skin disorders w/o MCC */
'597' = '1' /* Malignant breast disorders w MCC */
'598' = '1' /* Malignant breast disorders w CC */
'599' = '1' /* Malignant breast disorders w/o CC/MCC */
'600' = '1' /* Non-malignant breast disorders w CC/MCC */
'601' = '1' /* Non-malignant breast disorders w/o CC/MCC */
'602' = '1' /* Cellulitis w MCC */
'603' = '1' /* Cellulitis w/o MCC */
'604' = '1' /* Trauma to the skin, subcut tiss & breast w MCC */
'605' = '1' /* Trauma to the skin, subcut tiss & breast w/o MCC */
'606' = '1' /* Minor skin disorders w MCC */
'607' = '1' /* Minor skin disorders w/o MCC */
'637' = '1' /* Diabetes w MCC */
'638' = '1' /* Diabetes w CC */
'639' = '1' /* Diabetes w/o CC/MCC */
'640' = '1' /* Nutritional & misc metabolic disorders w MCC */
'641' = '1' /* Nutritional & misc metabolic disorders w/o MCC */
'642' = '1' /* Inborn errors of metabolism */
'643' = '1' /* Endocrine disorders w MCC */
'644' = '1' /* Endocrine disorders w CC */
'645' = '1' /* Endocrine disorders w/o CC/MCC */
'682' = '1' /* Renal failure w MCC */
'683' = '1' /* Renal failure w CC */
'684' = '1' /* Renal failure w/o CC/MCC */
'685' = '1' /* Admit for renal dialysis */
'686' = '1' /* Kidney & urinary tract neoplasms w MCC */
'687' = '1' /* Kidney & urinary tract neoplasms w CC */
'688' = '1' /* Kidney & urinary tract neoplasms w/o CC/MCC */
'689' = '1' /* Kidney & urinary tract infections w MCC */
'690' = '1' /* Kidney & urinary tract infections w/o MCC */
'691' = '1' /* Urinary stones w esw lithotripsy w CC/MCC */
'692' = '1' /* Urinary stones w esw lithotripsy w/o CC/MCC */
'693' = '1' /* Urinary stones w/o esw lithotripsy w MCC */
'694' = '1' /* Urinary stones w/o esw lithotripsy w/o MCC */
'695' = '1' /* Kidney & urinary tract signs & symptoms w MCC */
'696' = '1' /* Kidney & urinary tract signs & symptoms w/o MCC */
'697' = '1' /* Urethral stricture */
'698' = '1' /* Other kidney & urinary tract diagnoses w MCC */
'699' = '1' /* Other kidney & urinary tract diagnoses w CC */
'700' = '1' /* Other kidney & urinary tract diagnoses w/o CC/MCC */
'722' = '1' /* Malignancy, male reproductive system w MCC */
'723' = '1' /* Malignancy, male reproductive system w CC */
'724' = '1' /* Malignancy, male reproductive system w/o CC/MCC */
'725' = '1' /* Benign prostatic hypertrophy w MCC */
'726' = '1' /* Benign prostatic hypertrophy w/o MCC */
'727' = '1' /* Inflammation of the male reproductive system w MCC */
'728' = '1' /* Inflammation of the male reproductive system w/o MCC */
'729' = '1' /* Other male reproductive system diagnoses w CC/MCC */
'730' = '1' /* Other male reproductive system diagnoses w/o CC/MCC */
'754' = '1' /* Malignancy, female reproductive system w MCC */
'755' = '1' /* Malignancy, female reproductive system w CC */
'756' = '1' /* Malignancy, female reproductive system w/o CC/MCC */
'757' = '1' /* Infections, female reproductive system w MCC */
'758' = '1' /* Infections, female reproductive system w CC */
'759' = '1' /* Infections, female reproductive system w/o CC/MCC */
'760' = '1' /* Menstrual & other female reproductive system disorders w CC/MCC */
'761' = '1' /* Menstrual & other female reproductive system disorders w/o CC/MCC */
'774' = '1' /* Vaginal delivery w complicating diagnoses */
'775' = '1' /* Vaginal delivery w/o complicating diagnoses */
'776' = '1' /* Postpartum & post abortion diagnoses w/o O.R. procedure */
'777' = '1' /* Ectopic pregnancy */
'778' = '1' /* Threatened abortion */
'779' = '1' /* Abortion w/o D&C */
'780' = '1' /* False labor */
'781' = '1' /* Other antepartum diagnoses w medical complications */
'782' = '1' /* Other antepartum diagnoses w/o medical complications */
'789' = '1' /* Neonates, died or transferred to another acute care facility */
'790' = '1' /* Extreme immaturity or respiratory distress syndrome, neonate */
'791' = '1' /* Prematurity w major problems */
'792' = '1' /* Prematurity w/o major problems */
'793' = '1' /* Full term neonate w major problems */
'794' = '1' /* Neonate w other significant problems */
'795' = '1' /* Normal newborn */
'808' = '1' /* Major hematol/immun diag exc sickle cell crisis & coagul w MCC */
'809' = '1' /* Major hematol/immun diag exc sickle cell crisis & coagul w CC */
'810' = '1' /* Major hematol/immun diag exc sickle cell crisis & coagul w/o CC/MCC */
'811' = '1' /* Red blood cell disorders w MCC */
'812' = '1' /* Red blood cell disorders w/o MCC */
'813' = '1' /* Coagulation disorders */
'814' = '1' /* Reticuloendothelial & immunity disorders w MCC */
'815' = '1' /* Reticuloendothelial & immunity disorders w CC */
'816' = '1' /* Reticuloendothelial & immunity disorders w/o CC/MCC */
'834' = '1' /* Acute leukemia w/o major O.R. procedure w MCC */
'835' = '1' /* Acute leukemia w/o major O.R. procedure w CC */
'836' = '1' /* Acute leukemia w/o major O.R. procedure w/o CC/MCC */
'837' = '1' /* Chemo w acute leukemia as sdx or w high dose chemo agent w MCC */
'838' = '1' /* Chemo w acute leukemia as sdx w CC or high dose chemo agent */
'839' = '1' /* Chemo w acute leukemia as sdx w/o CC/MCC */
'840' = '1' /* Lymphoma & non-acute leukemia w MCC */
'841' = '1' /* Lymphoma & non-acute leukemia w CC */
'842' = '1' /* Lymphoma & non-acute leukemia w/o CC/MCC */
'843' = '1' /* Other myeloprolif dis or poorly diff neopl diag w MCC */
'844' = '1' /* Other myeloprolif dis or poorly diff neopl diag w CC */
'845' = '1' /* Other myeloprolif dis or poorly diff neopl diag w/o CC/MCC */
'846' = '1' /* Chemotherapy w/o acute leukemia as secondary diagnosis w MCC */
'847' = '1' /* Chemotherapy w/o acute leukemia as secondary diagnosis w CC */
'848' = '1' /* Chemotherapy w/o acute leukemia as secondary diagnosis w/o CC/MCC */
'849' = '1' /* Radiotherapy */
'862' = '1' /* Postoperative & post-traumatic infections w MCC */
'863' = '1' /* Postoperative & post-traumatic infections w/o MCC */
'864' = '1' /* Fever of unknown origin */
'865' = '1' /* Viral illness w MCC */
'866' = '1' /* Viral illness w/o MCC */
'867' = '1' /* Other infectious & parasitic diseases diagnoses w MCC */
'868' = '1' /* Other infectious & parasitic diseases diagnoses w CC */
'869' = '1' /* Other infectious & parasitic diseases diagnoses w/o CC/MCC */
'870' = '1' /* Septicemia w MV 96+ hours */
'871' = '1' /* Septicemia w/o MV 96+ hours w MCC */
'872' = '1' /* Septicemia w/o MV 96+ hours w/o MCC */
'880' = '1' /* Acute adjustment reaction & psychosocial dysfunction */
'881' = '1' /* Depressive neuroses */
'882' = '1' /* Neuroses except depressive */
'883' = '1' /* Disorders of personality & impulse control */
'884' = '1' /* Organic disturbances & mental retardation */
'885' = '1' /* Psychoses */
'886' = '1' /* Behavioral & developmental disorders */
'887' = '1' /* Other mental disorder diagnoses */
'894' = '1' /* Alcohol/drug abuse or dependence, left ama */
'895' = '1' /* Alcohol/drug abuse or dependence w rehabilitation therapy */
'896' = '1' /* Alcohol/drug abuse or dependence w/o rehabilitation therapy w MCC */
'897' = '1' /* Alcohol/drug abuse or dependence w/o rehabilitation therapy w/o MCC */
'913' = '1' /* Traumatic injury w MCC */
'914' = '1' /* Traumatic injury w/o MCC */
'915' = '1' /* Allergic reactions w MCC */
'916' = '1' /* Allergic reactions w/o MCC */
'917' = '1' /* Poisoning & toxic effects of drugs w MCC */
'918' = '1' /* Poisoning & toxic effects of drugs w/o MCC */
'919' = '1' /* Complications of treatment w MCC */
'920' = '1' /* Complications of treatment w CC */
'921' = '1' /* Complications of treatment w/o CC/MCC */
'922' = '1' /* Other injury, poisoning & toxic effect diag w MCC */
'923' = '1' /* Other injury, poisoning & toxic effect diag w/o MCC */
'933' = '1' /* Extensive burns or full thickness burns w MV 96+ hrs w/o skin graft */
'934' = '1' /* Full thickness burn w/o skin grft or inhal inj */
'935' = '1' /* Non-extensive burns */
'945' = '1' /* Rehabilitation w CC/MCC */
'946' = '1' /* Rehabilitation w/o CC/MCC */
'947' = '1' /* Signs & symptoms w MCC */
'948' = '1' /* Signs & symptoms w/o MCC */
'949' = '1' /* Aftercare w CC/MCC */
'950' = '1' /* Aftercare w/o CC/MCC */
'951' = '1' /* Other factors influencing health status */
'963' = '1' /* Other multiple significant trauma w MCC */
'964' = '1' /* Other multiple significant trauma w CC */
'965' = '1' /* Other multiple significant trauma w/o CC/MCC */
'974' = '1' /* HIV w major related condition w MCC */
'975' = '1' /* HIV w major related condition w CC */
'976' = '1' /* HIV w major related condition w/o CC/MCC */
'977' = '1' /* HIV w or w/o other related condition */
OTHER = '0'
;
/* ---------------------------------------------------------------- */
/* SURGICAL DRGS  PEDIATRIC ONLY                                    */
/* ---------------------------------------------------------------- */
 
/* DIAGNOSTIC RELATED GROUPS (DRGS) */
 
value $SURGI2R
'001' = '1' /* Heart transplant or implant of heart assist system w MCC */
'002' = '1' /* Heart transplant or implant of heart assist system w/o MCC */
'003' = '1' /* ECMO or trach w MV 96+ hrs or PDX exc face, mouth & neck w maj O.R. */
'004' = '1' /* Trach w MV 96+ hrs or PDX exc face, mouth & neck w/o maj O.R. */
'005' = '1' /* Liver transplant w MCC or intestinal transplant */
'006' = '1' /* Liver transplant w/o MCC */
'007' = '1' /* Lung transplant */
'008' = '1' /* Simultaneous pancreas/kidney transplant */
'009' = '1' /* Bone marrow transplant */
'010' = '1' /* Pancreas transplant */
'011' = '1' /* Tracheostomy for face,mouth & neck diagnoses w MCC */
'012' = '1' /* Tracheostomy for face,mouth & neck diagnoses w CC */
'013' = '1' /* Tracheostomy for face,mouth & neck diagnoses w/o CC/MCC */
'014' = '1' /* ALLOGENEIC BONE MARROW TRANSPLANT */
'015' = '1' /* AUTOLOGOUS BONE MARROW TRANSPLANT */
'016' = '1' /* AUTOLOGOUS BONE MARROW TRANSPLANT W CC/MCC */
'017' = '1' /* AUTOLOGOUS BONE MARROW TRANSPLANT W/O CC/MCC */
'020' = '1' /* Intracranial vascular procedures w PDX hemorrhage w MCC */
'021' = '1' /* Intracranial vascular procedures w PDX hemorrhage w CC */
'022' = '1' /* Intracranial vascular procedures w PDX hemorrhage w/o CC/MCC */
'023' = '1' /* Cranio w major dev impl/acute complex CNS PDX w MCC or chemo implant */
'024' = '1' /* Cranio w major dev impl/acute complex CNS PDX w/o MCC */
'025' = '1' /* Craniotomy & endovascular intracranial procedures w MCC */
'026' = '1' /* Craniotomy & endovascular intracranial procedures w CC */
'027' = '1' /* Craniotomy & endovascular intracranial procedures w/o CC/MCC */
'028' = '1' /* Spinal procedures w MCC */
'029' = '1' /* Spinal procedures w CC or spinal neurostimulators */
'030' = '1' /* Spinal procedures w/o CC/MCC */
'031' = '1' /* Ventricular shunt procedures w MCC */
'032' = '1' /* Ventricular shunt procedures w CC */
'033' = '1' /* Ventricular shunt procedures w/o CC/MCC */
'034' = '1' /* Carotid artery stent procedure w MCC */
'035' = '1' /* Carotid artery stent procedure w CC */
'036' = '1' /* Carotid artery stent procedure w/o CC/MCC */
'037' = '1' /* Extracranial procedures w MCC */
'038' = '1' /* Extracranial procedures w CC */
'039' = '1' /* Extracranial procedures w/o CC/MCC */
'040' = '1' /* Periph/cranial nerve & other nerv syst proc w MCC */
'041' = '1' /* Periph/cranial nerve & other nerv syst proc w CC or periph neurostim */
'042' = '1' /* Periph/cranial nerve & other nerv syst proc w/o CC/MCC */
'113' = '1' /* Orbital procedures w CC/MCC */
'114' = '1' /* Orbital procedures w/o CC/MCC */
'115' = '1' /* Extraocular procedures except orbit */
'116' = '1' /* Intraocular procedures w CC/MCC */
'117' = '1' /* Intraocular procedures w/o CC/MCC */
'129' = '1' /* Major head & neck procedures w CC/MCC or major device */
'130' = '1' /* Major head & neck procedures w/o CC/MCC */
'131' = '1' /* Cranial/facial procedures w CC/MCC */
'132' = '1' /* Cranial/facial procedures w/o CC/MCC */
'133' = '1' /* Other ear, nose, mouth & throat O.R. procedures w CC/MCC */
'134' = '1' /* Other ear, nose, mouth & throat O.R. procedures w/o CC/MCC */
'135' = '1' /* Sinus & mastoid procedures w CC/MCC */
'136' = '1' /* Sinus & mastoid procedures w/o CC/MCC */
'137' = '1' /* Mouth procedures w CC/MCC */
'138' = '1' /* Mouth procedures w/o CC/MCC */
'139' = '1' /* Salivary gland procedures */
'163' = '1' /* Major chest procedures w MCC */
'164' = '1' /* Major chest procedures w CC */
'165' = '1' /* Major chest procedures w/o CC/MCC */
'166' = '1' /* Other resp system O.R. procedures w MCC */
'167' = '1' /* Other resp system O.R. procedures w CC */
'168' = '1' /* Other resp system O.R. procedures w/o CC/MCC */
'215' = '1' /* Other heart assist system implant */
'216' = '1' /* Cardiac valve & oth maj cardiothoracic proc w card cath w MCC */
'217' = '1' /* Cardiac valve & oth maj cardiothoracic proc w card cath w CC */
'218' = '1' /* Cardiac valve & oth maj cardiothoracic proc w card cath w/o CC/MCC */
'219' = '1' /* Cardiac valve & oth maj cardiothoracic proc w/o card cath w MCC */
'220' = '1' /* Cardiac valve & oth maj cardiothoracic proc w/o card cath w CC */
'221' = '1' /* Cardiac valve & oth maj cardiothoracic proc w/o card cath w/o CC/MCC */
'222' = '1' /* Cardiac defib implant w cardiac cath w AMI/HF/shock w MCC */
'223' = '1' /* Cardiac defib implant w cardiac cath w AMI/HF/shock w/o MCC */
'224' = '1' /* Cardiac defib implant w cardiac cath w/o AMI/HF/shock w MCC */
'225' = '1' /* Cardiac defib implant w cardiac cath w/o AMI/HF/shock w/o MCC */
'226' = '1' /* Cardiac defibrillator implant w/o cardiac cath w MCC */
'227' = '1' /* Cardiac defibrillator implant w/o cardiac cath w/o MCC */
'228' = '1' /* Other cardiothoracic procedures w MCC */
'229' = '1' /* Other cardiothoracic procedures w CC */
'230' = '1' /* Other cardiothoracic procedures w/o CC/MCC */
'231' = '1' /* Coronary bypass w PTCA w MCC */
'232' = '1' /* Coronary bypass w PTCA w/o MCC */
'233' = '1' /* Coronary bypass w cardiac cath w MCC */
'234' = '1' /* Coronary bypass w cardiac cath w/o MCC */
'235' = '1' /* Coronary bypass w/o cardiac cath w MCC */
'236' = '1' /* Coronary bypass w/o cardiac cath w/o MCC */
'239' = '1' /* Amputation for circ sys disorders exc upper limb & toe w MCC */
'240' = '1' /* Amputation for circ sys disorders exc upper limb & toe w CC */
'241' = '1' /* Amputation for circ sys disorders exc upper limb & toe w/o CC/MCC */
'242' = '1' /* Permanent cardiac pacemaker implant w MCC */
'243' = '1' /* Permanent cardiac pacemaker implant w CC */
'244' = '1' /* Permanent cardiac pacemaker implant w/o CC/MCC */
'245' = '1' /* AICD lead & generator procedures */
'246' = '1' /* Perc cardiovasc proc w drug-eluting stent w MCC or 4+ vessels/stents */
'247' = '1' /* Perc cardiovasc proc w drug-eluting stent w/o MCC */
'248' = '1' /* Perc cardiovasc proc w non-drug-eluting stent w MCC or 4+ ves/stents */
'249' = '1' /* Perc cardiovasc proc w non-drug-eluting stent w/o MCC */
'250' = '1' /* Perc cardiovasc proc w/o coronary artery stent or AMI w MCC */
'251' = '1' /* Perc cardiovasc proc w/o coronary artery stent or AMI w/o MCC */
'252' = '1' /* Other vascular procedures w MCC */
'253' = '1' /* Other vascular procedures w CC */
'254' = '1' /* Other vascular procedures w/o CC/MCC */
'255' = '1' /* Upper limb & toe amputation for circ system disorders w MCC */
'256' = '1' /* Upper limb & toe amputation for circ system disorders w CC */
'257' = '1' /* Upper limb & toe amputation for circ system disorders w/o CC/MCC */
'258' = '1' /* Cardiac pacemaker device replacement w MCC */
'259' = '1' /* Cardiac pacemaker device replacement w/o MCC */
'260' = '1' /* Cardiac pacemaker revision except device replacement w MCC */
'261' = '1' /* Cardiac pacemaker revision except device replacement w CC */
'262' = '1' /* Cardiac pacemaker revision except device replacement w/o CC/MCC */
'263' = '1' /* Vein ligation & stripping */
'264' = '1' /* Other circulatory system O.R. procedures */
'265' = '1' /* AICD LEAD PROCEDURES */
'266' = '1' /* Endovascular Cardiac Valve Replacement w MCC */
'267' = '1' /* Endovascular Cardiac Valve Replacement w/o MCC */
'268' = '1' /* Aortic and heart assist procedures except pulsation balloon w mcc */
'269' = '1' /* Aortic and heart assist procedures except pulsation balloon w/o mcc */
'270' = '1' /* Other major cardiovascular procedures w mcc */
'271' = '1' /* Other major cardiovascular procedures w cc */
'272' = '1' /* Other major cardiovascular procedures w/o cc/mcc */
'273' = '1' /* Percutaneous intracardiac procedures w mcc */
'274' = '1' /* Percutaneous intracardiac procedures w/o mcc */
'326' = '1' /* Stomach, esophageal & duodenal proc w MCC */
'327' = '1' /* Stomach, esophageal & duodenal proc w CC */
'328' = '1' /* Stomach, esophageal & duodenal proc w/o CC/MCC */
'329' = '1' /* Major small & large bowel procedures w MCC */
'330' = '1' /* Major small & large bowel procedures w CC */
'331' = '1' /* Major small & large bowel procedures w/o CC/MCC */
'332' = '1' /* Rectal resection w MCC */
'333' = '1' /* Rectal resection w CC */
'334' = '1' /* Rectal resection w/o CC/MCC */
'335' = '1' /* Peritoneal adhesiolysis w MCC */
'336' = '1' /* Peritoneal adhesiolysis w CC */
'337' = '1' /* Peritoneal adhesiolysis w/o CC/MCC */
'338' = '1' /* Appendectomy w complicated principal diag w MCC */
'339' = '1' /* Appendectomy w complicated principal diag w CC */
'340' = '1' /* Appendectomy w complicated principal diag w/o CC/MCC */
'341' = '1' /* Appendectomy w/o complicated principal diag w MCC */
'342' = '1' /* Appendectomy w/o complicated principal diag w CC */
'343' = '1' /* Appendectomy w/o complicated principal diag w/o CC/MCC */
'344' = '1' /* Minor small & large bowel procedures w MCC */
'345' = '1' /* Minor small & large bowel procedures w CC */
'346' = '1' /* Minor small & large bowel procedures w/o CC/MCC */
'347' = '1' /* Anal & stomal procedures w MCC */
'348' = '1' /* Anal & stomal procedures w CC */
'349' = '1' /* Anal & stomal procedures w/o CC/MCC */
'350' = '1' /* Inguinal & femoral hernia procedures w MCC */
'351' = '1' /* Inguinal & femoral hernia procedures w CC */
'352' = '1' /* Inguinal & femoral hernia procedures w/o CC/MCC */
'353' = '1' /* Hernia procedures except inguinal & femoral w MCC */
'354' = '1' /* Hernia procedures except inguinal & femoral w CC */
'355' = '1' /* Hernia procedures except inguinal & femoral w/o CC/MCC */
'356' = '1' /* Other digestive system O.R. procedures w MCC */
'357' = '1' /* Other digestive system O.R. procedures w CC */
'358' = '1' /* Other digestive system O.R. procedures w/o CC/MCC */
'405' = '1' /* Pancreas, liver & shunt procedures w MCC */
'406' = '1' /* Pancreas, liver & shunt procedures w CC */
'407' = '1' /* Pancreas, liver & shunt procedures w/o CC/MCC */
'408' = '1' /* Biliary tract proc except only cholecyst w or w/o c.d.e. w MCC */
'409' = '1' /* Biliary tract proc except only cholecyst w or w/o c.d.e. w CC */
'410' = '1' /* Biliary tract proc except only cholecyst w or w/o c.d.e. w/o CC/MCC */
'411' = '1' /* Cholecystectomy w c.d.e. w MCC */
'412' = '1' /* Cholecystectomy w c.d.e. w CC */
'413' = '1' /* Cholecystectomy w c.d.e. w/o CC/MCC */
'414' = '1' /* Cholecystectomy except by laparoscope w/o c.d.e. w MCC */
'415' = '1' /* Cholecystectomy except by laparoscope w/o c.d.e. w CC */
'416' = '1' /* Cholecystectomy except by laparoscope w/o c.d.e. w/o CC/MCC */
'417' = '1' /* Laparoscopic cholecystectomy w/o c.d.e. w MCC */
'418' = '1' /* Laparoscopic cholecystectomy w/o c.d.e. w CC */
'419' = '1' /* Laparoscopic cholecystectomy w/o c.d.e. w/o CC/MCC */
'420' = '1' /* Hepatobiliary diagnostic procedures w MCC */
'421' = '1' /* Hepatobiliary diagnostic procedures w CC */
'422' = '1' /* Hepatobiliary diagnostic procedures w/o CC/MCC */
'423' = '1' /* Other hepatobiliary or pancreas O.R. procedures w MCC */
'424' = '1' /* Other hepatobiliary or pancreas O.R. procedures w CC */
'425' = '1' /* Other hepatobiliary or pancreas O.R. procedures w/o CC/MCC */
'453' = '1' /* Combined anterior/posterior spinal fusion w MCC */
'454' = '1' /* Combined anterior/posterior spinal fusion w CC */
'455' = '1' /* Combined anterior/posterior spinal fusion w/o CC/MCC */
'456' = '1' /* Spinal Fusion Except Cervical with Spinal Curvature/Malignancy/Infection or Extensive Fusion with MCC */
'457' = '1' /* Spinal Fusion Except Cervical with Spinal Curvature/Malignancy/Infection or Extensive Fusion with CC */
'458' = '1' /* Spinal Fusion Except Cervical with Spinal Curvature/Malignancy/Infection or Extensive Fusion without CC/MCC */
'459' = '1' /* Spinal fusion except cervical w MCC */
'460' = '1' /* Spinal fusion except cervical w/o MCC */
'461' = '1' /* Bilateral or multiple major joint procs of lower extremity w MCC */
'462' = '1' /* Bilateral or multiple major joint procs of lower extremity w/o MCC */
'463' = '1' /* Wnd debrid & skn grft exc hand, for musculo-conn tiss dis w MCC */
'464' = '1' /* Wnd debrid & skn grft exc hand, for musculo-conn tiss dis w CC */
'465' = '1' /* Wnd debrid & skn grft exc hand, for musculo-conn tiss dis w/o CC/MCC */
'466' = '1' /* Revision of hip or knee replacement w MCC */
'467' = '1' /* Revision of hip or knee replacement w CC */
'468' = '1' /* Revision of hip or knee replacement w/o CC/MCC */
'469' = '1' /* Major joint replacement or reattachment of lower extremity w MCC */
'470' = '1' /* Major joint replacement or reattachment of lower extremity w/o MCC */
'471' = '1' /* Cervical spinal fusion w MCC */
'472' = '1' /* Cervical spinal fusion w CC */
'473' = '1' /* Cervical spinal fusion w/o CC/MCC */
'474' = '1' /* Amputation for musculoskeletal sys & conn tissue dis w MCC */
'475' = '1' /* Amputation for musculoskeletal sys & conn tissue dis w CC */
'476' = '1' /* Amputation for musculoskeletal sys & conn tissue dis w/o CC/MCC */
'477' = '1' /* Biopsies of musculoskeletal system & connective tissue w MCC */
'478' = '1' /* Biopsies of musculoskeletal system & connective tissue w CC */
'479' = '1' /* Biopsies of musculoskeletal system & connective tissue w/o CC/MCC */
'480' = '1' /* Hip & femur procedures except major joint w MCC */
'481' = '1' /* Hip & femur procedures except major joint w CC */
'482' = '1' /* Hip & femur procedures except major joint w/o CC/MCC */
'483' = '1' /* Major joint & limb reattachment proc of upper extremity w CC/MCC */
'484' = '1' /* Major joint & limb reattachment proc of upper extremity w/o CC/MCC */
'485' = '1' /* Knee procedures w pdx of infection w MCC */
'486' = '1' /* Knee procedures w pdx of infection w CC */
'487' = '1' /* Knee procedures w pdx of infection w/o CC/MCC */
'488' = '1' /* Knee procedures w/o pdx of infection w CC/MCC */
'489' = '1' /* Knee procedures w/o pdx of infection w/o CC/MCC */
'490' = '1' /* Back & neck proc exc spinal fusion w CC/MCC or disc device/neurostim */
'491' = '1' /* Back & neck proc exc spinal fusion w/o CC/MCC */
'492' = '1' /* Lower extrem & humer proc except hip,foot,femur w MCC */
'493' = '1' /* Lower extrem & humer proc except hip,foot,femur w CC */
'494' = '1' /* Lower extrem & humer proc except hip,foot,femur w/o CC/MCC */
'495' = '1' /* Local excision & removal int fix devices exc hip & femur w MCC */
'496' = '1' /* Local excision & removal int fix devices exc hip & femur w CC */
'497' = '1' /* Local excision & removal int fix devices exc hip & femur w/o CC/MCC */
'498' = '1' /* Local excision & removal int fix devices of hip & femur w CC/MCC */
'499' = '1' /* Local excision & removal int fix devices of hip & femur w/o CC/MCC */
'500' = '1' /* Soft tissue procedures w MCC */
'501' = '1' /* Soft tissue procedures w CC */
'502' = '1' /* Soft tissue procedures w/o CC/MCC */
'503' = '1' /* Foot procedures w MCC */
'504' = '1' /* Foot procedures w CC */
'505' = '1' /* Foot procedures w/o CC/MCC */
'506' = '1' /* Major thumb or joint procedures */
'507' = '1' /* Major shoulder or elbow joint procedures w CC/MCC */
'508' = '1' /* Major shoulder or elbow joint procedures w/o CC/MCC */
'509' = '1' /* Arthroscopy */
'510' = '1' /* Shoulder,elbow or forearm proc,exc major joint proc w MCC */
'511' = '1' /* Shoulder,elbow or forearm proc,exc major joint proc w CC */
'512' = '1' /* Shoulder,elbow or forearm proc,exc major joint proc w/o CC/MCC */
'513' = '1' /* Hand or wrist proc, except major thumb or joint proc w CC/MCC */
'514' = '1' /* Hand or wrist proc, except major thumb or joint proc w/o CC/MCC */
'515' = '1' /* Other musculoskelet sys & conn tiss O.R. proc w MCC */
'516' = '1' /* Other musculoskelet sys & conn tiss O.R. proc w CC */
'517' = '1' /* Other musculoskelet sys & conn tiss O.R. proc w/o CC/MCC */
'518' = '1' /* Back & Neck Procedure excluding spinal fusion w MCC or disc device/neurostimulator */
'519' = '1' /* Back & Neck Procedure excluding spinal fusion w CC */
'520' = '1' /* Back & Neck Procedure excluding spinal fusion w/o CC/MCC */
'570' = '1' /* SKIN DEBRIDEMENT W MCC */
'571' = '1' /* SKIN DEBRIDEMENT W CC */
'572' = '1' /* SKIN DEBRIDEMENT W/O CC/MCC */
'573' = '1' /* Skin graft for skn ulcer or cellulitis w MCC */
'574' = '1' /* Skin graft for skn ulcer or cellulitis w CC */
'575' = '1' /* Skin graft for skn ulcer or cellulitis w/o CC/MCC */
'576' = '1' /* Skin graft exc for skin ulcer or cellulitis w MCC */
'577' = '1' /* Skin graft exc for skin ulcer or cellulitis w CC */
'578' = '1' /* Skin graft exc for skin ulcer or cellulitis w/o CC/MCC */
'579' = '1' /* Other skin, subcut tiss & breast proc w MCC */
'580' = '1' /* Other skin, subcut tiss & breast proc w CC */
'581' = '1' /* Other skin, subcut tiss & breast proc w/o CC/MCC */
'582' = '1' /* Mastectomy for malignancy w CC/MCC */
'583' = '1' /* Mastectomy for malignancy w/o CC/MCC */
'584' = '1' /* Breast biopsy, local excision & other breast procedures w CC/MCC */
'585' = '1' /* Breast biopsy, local excision & other breast procedures w/o CC/MCC */
'614' = '1' /* Adrenal & pituitary procedures w CC/MCC */
'615' = '1' /* Adrenal & pituitary procedures w/o CC/MCC */
'616' = '1' /* Amputat of lower limb for endocrine,nutrit,& metabol dis w MCC */
'617' = '1' /* Amputat of lower limb for endocrine,nutrit,& metabol dis w CC */
'618' = '1' /* Amputat of lower limb for endocrine,nutrit,& metabol dis w/o CC/MCC */
'619' = '1' /* O.R. procedures for obesity w MCC */
'620' = '1' /* O.R. procedures for obesity w CC */
'621' = '1' /* O.R. procedures for obesity w/o CC/MCC */
'622' = '1' /* Skin grafts & wound debrid for endoc, nutrit & metab dis w MCC */
'623' = '1' /* Skin grafts & wound debrid for endoc, nutrit & metab dis w CC */
'624' = '1' /* Skin grafts & wound debrid for endoc, nutrit & metab dis w/o CC/MCC */
'625' = '1' /* Thyroid, parathyroid & thyroglossal procedures w MCC */
'626' = '1' /* Thyroid, parathyroid & thyroglossal procedures w CC */
'627' = '1' /* Thyroid, parathyroid & thyroglossal procedures w/o CC/MCC */
'628' = '1' /* Other endocrine, nutrit & metab O.R. proc w MCC */
'629' = '1' /* Other endocrine, nutrit & metab O.R. proc w CC */
'630' = '1' /* Other endocrine, nutrit & metab O.R. proc w/o CC/MCC */
'652' = '1' /* Kidney transplant */
'653' = '1' /* Major bladder procedures w MCC */
'654' = '1' /* Major bladder procedures w CC */
'655' = '1' /* Major bladder procedures w/o CC/MCC */
'656' = '1' /* Kidney & ureter procedures for neoplasm w MCC */
'657' = '1' /* Kidney & ureter procedures for neoplasm w CC */
'658' = '1' /* Kidney & ureter procedures for neoplasm w/o CC/MCC */
'659' = '1' /* Kidney & ureter procedures for non-neoplasm w MCC */
'660' = '1' /* Kidney & ureter procedures for non-neoplasm w CC */
'661' = '1' /* Kidney & ureter procedures for non-neoplasm w/o CC/MCC */
'662' = '1' /* Minor bladder procedures w MCC */
'663' = '1' /* Minor bladder procedures w CC */
'664' = '1' /* Minor bladder procedures w/o CC/MCC */
'665' = '1' /* Prostatectomy w MCC */
'666' = '1' /* Prostatectomy w CC */
'667' = '1' /* Prostatectomy w/o CC/MCC */
'668' = '1' /* Transurethral procedures w MCC */
'669' = '1' /* Transurethral procedures w CC */
'670' = '1' /* Transurethral procedures w/o CC/MCC */
'671' = '1' /* Urethral procedures w CC/MCC */
'672' = '1' /* Urethral procedures w/o CC/MCC */
'673' = '1' /* Other kidney & urinary tract procedures w MCC */
'674' = '1' /* Other kidney & urinary tract procedures w CC */
'675' = '1' /* Other kidney & urinary tract procedures w/o CC/MCC */
'707' = '1' /* Major male pelvic procedures w CC/MCC */
'708' = '1' /* Major male pelvic procedures w/o CC/MCC */
'709' = '1' /* Penis procedures w CC/MCC */
'710' = '1' /* Penis procedures w/o CC/MCC */
'711' = '1' /* Testes procedures w CC/MCC */
'712' = '1' /* Testes procedures w/o CC/MCC */
'713' = '1' /* Transurethral prostatectomy w CC/MCC */
'714' = '1' /* Transurethral prostatectomy w/o CC/MCC */
'715' = '1' /* Other male reproductive system O.R. proc for malignancy w CC/MCC */
'716' = '1' /* Other male reproductive system O.R. proc for malignancy w/o CC/MCC */
'717' = '1' /* Other male reproductive system O.R. proc exc malignancy w CC/MCC */
'718' = '1' /* Other male reproductive system O.R. proc exc malignancy w/o CC/MCC */
'734' = '1' /* Pelvic evisceration, rad hysterectomy & rad vulvectomy w CC/MCC */
'735' = '1' /* Pelvic evisceration, rad hysterectomy & rad vulvectomy w/o CC/MCC */
'736' = '1' /* Uterine & adnexa proc for ovarian or adnexal malignancy w MCC */
'737' = '1' /* Uterine & adnexa proc for ovarian or adnexal malignancy w CC */
'738' = '1' /* Uterine & adnexa proc for ovarian or adnexal malignancy w/o CC/MCC */
'739' = '1' /* Uterine,adnexa proc for non-ovarian/adnexal malig w MCC */
'740' = '1' /* Uterine,adnexa proc for non-ovarian/adnexal malig w CC */
'741' = '1' /* Uterine,adnexa proc for non-ovarian/adnexal malig w/o CC/MCC */
'742' = '1' /* Uterine & adnexa proc for non-malignancy w CC/MCC */
'743' = '1' /* Uterine & adnexa proc for non-malignancy w/o CC/MCC */
'744' = '1' /* D&C, conization, laparascopy & tubal interruption w CC/MCC */
'745' = '1' /* D&C, conization, laparascopy & tubal interruption w/o CC/MCC */
'746' = '1' /* Vagina, cervix & vulva procedures w CC/MCC */
'747' = '1' /* Vagina, cervix & vulva procedures w/o CC/MCC */
'748' = '1' /* Female reproductive system reconstructive procedures */
'749' = '1' /* Other female reproductive system O.R. procedures w CC/MCC */
'750' = '1' /* Other female reproductive system O.R. procedures w/o CC/MCC */
'765' = '1' /* Cesarean section w CC/MCC */
'766' = '1' /* Cesarean section w/o CC/MCC */
'767' = '1' /* Vaginal delivery w sterilization &/or D&C */
'768' = '1' /* Vaginal delivery w O.R. proc except steril &/or D&C */
'769' = '1' /* Postpartum & post abortion diagnoses w O.R. procedure */
'770' = '1' /* Abortion w D&C, aspiration curettage or hysterotomy */
'799' = '1' /* Splenectomy w MCC */
'800' = '1' /* Splenectomy w CC */
'801' = '1' /* Splenectomy w/o CC/MCC */
'802' = '1' /* Other O.R. proc of the blood & blood forming organs w MCC */
'803' = '1' /* Other O.R. proc of the blood & blood forming organs w CC */
'804' = '1' /* Other O.R. proc of the blood & blood forming organs w/o CC/MCC */
'820' = '1' /* Lymphoma & leukemia w major O.R. procedure w MCC */
'821' = '1' /* Lymphoma & leukemia w major O.R. procedure w CC */
'822' = '1' /* Lymphoma & leukemia w major O.R. procedure w/o CC/MCC */
'823' = '1' /* Lymphoma & non-acute leukemia w other O.R. proc w MCC */
'824' = '1' /* Lymphoma & non-acute leukemia w other O.R. proc w CC */
'825' = '1' /* Lymphoma & non-acute leukemia w other O.R. proc w/o CC/MCC */
'826' = '1' /* Myeloprolif disord or poorly diff neopl w maj O.R. proc w MCC */
'827' = '1' /* Myeloprolif disord or poorly diff neopl w maj O.R. proc w CC */
'828' = '1' /* Myeloprolif disord or poorly diff neopl w maj O.R. proc w/o CC/MCC */
'829' = '1' /* Myeloprolif disord or poorly diff neopl w other O.R. proc w CC/MCC */
'830' = '1' /* Myeloprolif disord or poorly diff neopl w other O.R. proc w/o CC/MCC */
'853' = '1' /* Infectious & parasitic diseases w O.R. procedure w MCC */
'854' = '1' /* Infectious & parasitic diseases w O.R. procedure w CC */
'855' = '1' /* Infectious & parasitic diseases w O.R. procedure w/o CC/MCC */
'856' = '1' /* Postoperative or post-traumatic infections w O.R. proc w MCC */
'857' = '1' /* Postoperative or post-traumatic infections w O.R. proc w CC */
'858' = '1' /* Postoperative or post-traumatic infections w O.R. proc w/o CC/MCC */
'876' = '1' /* O.R. procedure w principal diagnoses of mental illness */
'901' = '1' /* Wound debridements for injuries w MCC */
'902' = '1' /* Wound debridements for injuries w CC */
'903' = '1' /* Wound debridements for injuries w/o CC/MCC */
'904' = '1' /* Skin grafts for injuries w CC/MCC */
'905' = '1' /* Skin grafts for injuries w/o CC/MCC */
'906' = '1' /* Hand procedures for injuries */
'907' = '1' /* Other O.R. procedures for injuries w MCC */
'908' = '1' /* Other O.R. procedures for injuries w CC */
'909' = '1' /* Other O.R. procedures for injuries w/o CC/MCC */
'927' = '1' /* Extensive burns or full thickness burns w MV 96+ hrs w skin graft */
'928' = '1' /* Full thickness burn w skin graft or inhal inj w CC/MCC */
'929' = '1' /* Full thickness burn w skin graft or inhal inj w/o CC/MCC */
'939' = '1' /* O.R. proc w diagnoses of other contact w health services w MCC */
'940' = '1' /* O.R. proc w diagnoses of other contact w health services w CC */
'941' = '1' /* O.R. proc w diagnoses of other contact w health services w/o CC/MCC */
'955' = '1' /* Craniotomy for multiple significant trauma */
'956' = '1' /* Limb reattachment, hip & femur proc for multiple significant trauma */
'957' = '1' /* Other O.R. procedures for multiple significant trauma w MCC */
'958' = '1' /* Other O.R. procedures for multiple significant trauma w CC */
'959' = '1' /* Other O.R. procedures for multiple significant trauma w/o CC/MCC */
'969' = '1' /* HIV w extensive O.R. procedure w MCC */
'970' = '1' /* HIV w extensive O.R. procedure w/o MCC */
'981' = '1' /* Extensive O.R. procedure unrelated to principal diagnosis w MCC */
'982' = '1' /* Extensive O.R. procedure unrelated to principal diagnosis w CC */
'983' = '1' /* Extensive O.R. procedure unrelated to principal diagnosis w/o CC/MCC */
'984' = '1' /* Prostatic O.R. procedure unrelated to principal diagnosis w MCC */
'985' = '1' /* Prostatic O.R. procedure unrelated to principal diagnosis w CC */
'986' = '1' /* Prostatic O.R. procedure unrelated to principal diagnosis w/o CC/MCC */
'987' = '1' /* Non-extensive O.R. proc unrelated to principal diagnosis w MCC */
'988' = '1' /* Non-extensive O.R. proc unrelated to principal diagnosis w CC */
'989' = '1' /* Non-extensive O.R. proc unrelated to principal diagnosis w/o CC/MCC */
OTHER = '0'
;
 
 
value $BLANK
OTHER  = "0"
;
 
/* DRGS SURGICAL CLASS =1, TYPE OF DRGS = CLEAN */
 
value DRG1C
0101 = '1'
0102 = '1'
0103 = '1'
0104 = '1'
0105 = '1'
0106 = '1'
0107 = '1'
0108 = '1'
0201 = '1'
0202 = '1'
0203 = '1'
0301 = '1'
0302 = '1'
0303 = '1'
0304 = '1'
0305 = '1'
0501 = '1'
0502 = '1'
0503 = '1'
0504 = '1'
0505 = '1'
0506 = '1'
0507 = '1'
0509 = '1'
0510 = '1'
0511 = '1'
0513 = '1'
0514 = '1'
0515 = '1'
0516 = '1'
0517 = '1'
0518 = '1'
0519 = '1'
0540 = '1'
0599 = '1'
0609 = '1'
0801 = '1'
0802 = '1'
0803 = '1'
0804 = '1'
0805 = '1'
0806 = '1'
0807 = '1'
0808 = '1'
0809 = '1'
0810 = '1'
0811 = '1'
0812 = '1'
0813 = '1'
0814 = '1'
0815 = '1'
0816 = '1'
0817 = '1'
0818 = '1'
0819 = '1'
0820 = '1'
0821 = '1'
0822 = '1'
0823 = '1'
0824 = '1'
0825 = '1'
0826 = '1'
0899 = '1'
0904 = '1'
0905 = '1'
1001 = '1'
1002 = '1'
1004 = '1'
1005 = '1'
1006 = '1'
1203 = '1'
1601 = '1'
1602 = '1'
7701 = '1'
7705 = '1'
OTHER = '0'
;
 
/* DRGS SURGICAL CLASS =2, TYPE OF DRGS = CLEAN CONTAMINATED */
 
value DRG2C
0113 = '1'
0401 = '1'
0402 = '1'
0601 = '1'
0602 = '1'
0603 = '1'
0604 = '1'
0606 = '1'
0607 = '1'
0608 = '1'
0611 = '1'
0701 = '1'
0702 = '1'
0703 = '1'
0704 = '1'
0705 = '1'
0706 = '1'
0707 = '1'
0902 = '1'
0903 = '1'
1003 = '1'
1101 = '1'
1102 = '1'
1103 = '1'
1104 = '1'
1105 = '1'
1106 = '1'
1107 = '1'
1108 = '1'
1109 = '1'
1201 = '1'
1202 = '1'
1204 = '1'
1205 = '1'
1206 = '1'
1301 = '1'
1302 = '1'
1303 = '1'
1304 = '1'
1305 = '1'
1306 = '1'
1307 = '1'
1308 = '1'
1401 = '1'
1402 = '1'
1403 = '1'
1404 = '1'
1405 = '1'
7702 = '1'
7703 = '1'
7704 = '1'
7706 = '1'
7799 = '1'
8899 = '1'
OTHER = '0'
;
 
/* DRGS SURGICAL CLASS =3, TYPE OF DRGS = POTENTIALLY CONTAMINATED */
 
value DRG3C
0901 = '1'
2101 = '1'
2102 = '1'
2103 = '1'
2104 = '1'
2201 = '1'
2210 = '1'
2406 = '1'
2407 = '1'
2408 = '1'
OTHER = '0'
;
 
/* DRGS CLASS =4, TYPE OF DRGS = LIKELY INFECTED */
 
value DRG4C
0605 = '1'
1801 = '1'
1802 = '1'
1899 = '1'
OTHER = '0'
;
 
/* DRGS CLASS =9, TYPE OF DRGS = SURGICAL PROCEDURES NOT SPECIFIED  */
 
value DRG9C
1707 = '1'
1708 = '1'
1709 = '1'
1710 = '1'
1909 = '1'
2301 = '1'
2501 = '1'
OTHER = '0'
;
 
* ----------------------------------------------------- ;
* ---   AREA FORMATS     ------------------------------ ;
* ---   TRANSLATES FIPS STATE AND COUNTY CODE (SSCCC)   ;
* ---   TO MSA (METROPOLITAN STATISTICAL AREA)          ;
* ----------------------------------------------------- ;
 
/* MODIFIED FIPS */
 
value $M1AREA
'02013' = '02001'
'02016' = '02001'
'02020' = '02001'
'02050' = '02001'
'02060' = '02001'
'02068' = '02001'
'02070' = '02001'
'02090' = '02001'
'02100' = '02001'
'02110' = '02001'
'02122' = '02001'
'02130' = '02001'
'02150' = '02001'
'02164' = '02001'
'02170' = '02001'
'02180' = '02001'
'02185' = '02001'
'02188' = '02001'
'02201' = '02001'
'02220' = '02001'
'02232' = '02001'
'02240' = '02001'
'02261' = '02001'
'02270' = '02001'
'02280' = '02001'
'02282' = '02001'
'02290' = '02001'
'15005' = '15009'
'24510' = '24007'
'29510' = '29191'
'32510' = '32025'
'51515' = '51019'
'51520' = '51119'
'51530' = '51163'
'51540' = '51003'
'51560' = '51005'
'51570' = '51041'
'51580' = '51005'
'51590' = '51143'
'51595' = '51081'
'51600' = '51059'
'51610' = '51059'
'51620' = '51175'
'51630' = '51177'
'51640' = '51077'
'51660' = '51165'
'51670' = '51149'
'51678' = '51163'
'51680' = '51031'
'51683' = '51153'
'51685' = '51153'
'51690' = '51089'
'51710' = '51129'
'51720' = '51195'
'51730' = '51053'
'51735' = '51199'
'51740' = '51129'
'51750' = '51121'
'51760' = '51087'
'51770' = '51161'
'51775' = '51161'
'51780' = '51083'
'51790' = '51015'
'51800' = '51123'
'51820' = '51015'
'51830' = '51095'
'51840' = '51069'
;
 
/* OMB 1999 METRO AREA */
 
value $M2AREA
'01001' = '5240 '
'01003' = '5160 '
'01009' = '1000 '
'01015' = '0450 '
'01033' = '2650 '
'01045' = '2180 '
'01051' = '5240 '
'01055' = '2880 '
'01069' = '2180 '
'01073' = '1000 '
'01077' = '2650 '
'01079' = '2030 '
'01081' = '0580 '
'01083' = '3440 '
'01089' = '3440 '
'01097' = '5160 '
'01101' = '5240 '
'01103' = '2030 '
'01113' = '1800 '
'01115' = '1000 '
'01117' = '1000 '
'01125' = '8600 '
'02020' = '0380 '
'04005' = '2620 '
'04013' = '6200 '
'04015' = '4120 '
'04019' = '8520 '
'04021' = '6200 '
'04027' = '9360 '
'05007' = '2580 '
'05031' = '3700 '
'05033' = '2720 '
'05035' = '4920 '
'05045' = '4400 '
'05069' = '6240 '
'05085' = '4400 '
'05091' = '8360 '
'05119' = '4400 '
'05125' = '4400 '
'05131' = '2720 '
'05143' = '2580 '
'06001' = '5775 '
'06007' = '1620 '
'06013' = '5775 '
'06017' = '6920 '
'06019' = '2840 '
'06029' = '0680 '
'06037' = '4480 '
'06039' = '2840 '
'06041' = '7360 '
'06047' = '4940 '
'06053' = '7120 '
'06055' = '8720 '
'06059' = '5945 '
'06061' = '6920 '
'06065' = '6780 '
'06067' = '6920 '
'06071' = '6780 '
'06073' = '7320 '
'06075' = '7360 '
'06077' = '8120 '
'06079' = '7460 '
'06081' = '7360 '
'06083' = '7480 '
'06085' = '7400 '
'06087' = '7485 '
'06089' = '6690 '
'06095' = '8720 '
'06097' = '7500 '
'06099' = '5170 '
'06101' = '9340 '
'06107' = '8780 '
'06111' = '8735 '
'06113' = '9270 '
'06115' = '9340 '
'08001' = '2080 '
'08005' = '2080 '
'08013' = '1125 '
'08031' = '2080 '
'08035' = '2080 '
'08041' = '1720 '
'08059' = '2080 '
'08069' = '2670 '
'08077' = '2995 '
'08101' = '6560 '
'08123' = '3060 '
'09001' = '5483 '
'09003' = '3283 '
'09007' = '3283 '
'09009' = '5483 '
'09011' = '5523 '
'09013' = '3283 '
'10001' = '2190 '
'10003' = '9160 '
'11001' = '8840 '
'12001' = '2900 '
'12005' = '6015 '
'12009' = '4900 '
'12011' = '2680 '
'12015' = '6580 '
'12019' = '3600 '
'12021' = '5345 '
'12031' = '3600 '
'12033' = '6080 '
'12035' = '2020 '
'12039' = '8240 '
'12053' = '8280 '
'12057' = '8280 '
'12069' = '5960 '
'12071' = '2700 '
'12073' = '8240 '
'12081' = '7510 '
'12083' = '5790 '
'12085' = '2710 '
'12086' = '5000 '
'12089' = '3600 '
'12091' = '2750 '
'12095' = '5960 '
'12097' = '5960 '
'12099' = '8960 '
'12101' = '8280 '
'12103' = '8280 '
'12105' = '3980 '
'12109' = '3600 '
'12111' = '2710 '
'12113' = '6080 '
'12115' = '7510 '
'12117' = '5960 '
'12127' = '2020 '
'13013' = '0520 '
'13015' = '0520 '
'13021' = '4680 '
'13029' = '7520 '
'13045' = '0520 '
'13047' = '1560 '
'13051' = '7520 '
'13053' = '1800 '
'13057' = '0520 '
'13059' = '0500 '
'13063' = '0520 '
'13067' = '0520 '
'13073' = '0600 '
'13077' = '0520 '
'13083' = '1560 '
'13089' = '0520 '
'13095' = '0120 '
'13097' = '0520 '
'13103' = '7520 '
'13113' = '0520 '
'13117' = '0520 '
'13121' = '0520 '
'13135' = '0520 '
'13145' = '1800 '
'13151' = '0520 '
'13153' = '4680 '
'13169' = '4680 '
'13177' = '0120 '
'13189' = '0600 '
'13195' = '0500 '
'13215' = '1800 '
'13217' = '0520 '
'13219' = '0500 '
'13223' = '0520 '
'13225' = '4680 '
'13227' = '0520 '
'13245' = '0600 '
'13247' = '0520 '
'13255' = '0520 '
'13289' = '4680 '
'13295' = '1560 '
'13297' = '0520 '
'15003' = '3320 '
'16001' = '1080 '
'16005' = '6340 '
'16027' = '1080 '
'17007' = '6880 '
'17019' = '1400 '
'17027' = '7040 '
'17031' = '1600 '
'17037' = '1600 '
'17043' = '1600 '
'17063' = '1600 '
'17073' = '1960 '
'17083' = '7040 '
'17089' = '1600 '
'17091' = '3740 '
'17093' = '1600 '
'17097' = '1600 '
'17111' = '1600 '
'17113' = '1040 '
'17115' = '2040 '
'17119' = '7040 '
'17129' = '7880 '
'17133' = '7040 '
'17141' = '6880 '
'17143' = '6120 '
'17161' = '1960 '
'17163' = '7040 '
'17167' = '7880 '
'17179' = '6120 '
'17197' = '1600 '
'17201' = '6880 '
'17203' = '6120 '
'18001' = '2760 '
'18003' = '2760 '
'18011' = '3480 '
'18019' = '4520 '
'18021' = '8320 '
'18023' = '3920 '
'18029' = '1640 '
'18033' = '2760 '
'18035' = '5280 '
'18039' = '2330 '
'18043' = '4520 '
'18057' = '3480 '
'18059' = '3480 '
'18061' = '4520 '
'18063' = '3480 '
'18067' = '3850 '
'18069' = '2760 '
'18081' = '3480 '
'18089' = '2960 '
'18095' = '3480 '
'18097' = '3480 '
'18105' = '1020 '
'18109' = '3480 '
'18115' = '1640 '
'18127' = '2960 '
'18129' = '2440 '
'18141' = '7800 '
'18143' = '4520 '
'18145' = '3480 '
'18157' = '3920 '
'18159' = '3850 '
'18163' = '2440 '
'18165' = '8320 '
'18167' = '8320 '
'18173' = '2440 '
'18179' = '2760 '
'18183' = '2760 '
'19013' = '8920 '
'19049' = '2120 '
'19061' = '2200 '
'19103' = '3500 '
'19113' = '1360 '
'19153' = '2120 '
'19155' = '5920 '
'19163' = '1960 '
'19181' = '2120 '
'19193' = '7720 '
'20015' = '9040 '
'20045' = '4150 '
'20079' = '9040 '
'20091' = '3760 '
'20103' = '3760 '
'20121' = '3760 '
'20173' = '9040 '
'20177' = '8440 '
'20209' = '3760 '
'21015' = '1640 '
'21017' = '4280 '
'21019' = '3400 '
'21029' = '4520 '
'21037' = '1640 '
'21043' = '3400 '
'21047' = '1660 '
'21049' = '4280 '
'21059' = '5990 '
'21067' = '4280 '
'21077' = '1640 '
'21081' = '1640 '
'21089' = '3400 '
'21101' = '2440 '
'21111' = '4520 '
'21113' = '4280 '
'21117' = '1640 '
'21151' = '4280 '
'21185' = '4520 '
'21191' = '1640 '
'21209' = '4280 '
'21239' = '4280 '
'22001' = '3880 '
'22005' = '0760 '
'22015' = '7680 '
'22017' = '7680 '
'22019' = '3960 '
'22033' = '0760 '
'22051' = '5560 '
'22055' = '3880 '
'22057' = '3350 '
'22063' = '0760 '
'22071' = '5560 '
'22073' = '5200 '
'22075' = '5560 '
'22079' = '0220 '
'22087' = '5560 '
'22089' = '5560 '
'22093' = '5560 '
'22095' = '5560 '
'22097' = '3880 '
'22099' = '3880 '
'22103' = '5560 '
'22109' = '3350 '
'22119' = '7680 '
'22121' = '0760 '
'23001' = '4243 '
'23005' = '6403 '
'23019' = '0733 '
'24001' = '1900 '
'24003' = '0720 '
'24005' = '0720 '
'24009' = '8840 '
'24013' = '0720 '
'24015' = '9160 '
'24017' = '8840 '
'24021' = '8840 '
'24025' = '0720 '
'24027' = '0720 '
'24031' = '8840 '
'24033' = '8840 '
'24035' = '0720 '
'24043' = '3180 '
'24510' = '0720 '
'25001' = '0743 '
'25003' = '6323 '
'25005' = '1123 '
'25009' = '1123 '
'25013' = '8003 '
'25015' = '8003 '
'25017' = '1123 '
'25021' = '1123 '
'25023' = '1123 '
'25025' = '1123 '
'25027' = '1123 '
'26005' = '3000 '
'26017' = '6960 '
'26021' = '0870 '
'26025' = '3720 '
'26037' = '4040 '
'26045' = '4040 '
'26049' = '2640 '
'26065' = '4040 '
'26075' = '3520 '
'26077' = '3720 '
'26081' = '3000 '
'26087' = '2160 '
'26091' = '0440 '
'26093' = '0440 '
'26099' = '2160 '
'26111' = '6960 '
'26115' = '2160 '
'26121' = '3000 '
'26125' = '2160 '
'26139' = '3000 '
'26145' = '6960 '
'26147' = '2160 '
'26159' = '3720 '
'26161' = '0440 '
'26163' = '2160 '
'27003' = '5120 '
'27009' = '6980 '
'27019' = '5120 '
'27025' = '5120 '
'27027' = '2520 '
'27037' = '5120 '
'27053' = '5120 '
'27055' = '3870 '
'27059' = '5120 '
'27109' = '6820 '
'27119' = '2985 '
'27123' = '5120 '
'27137' = '2240 '
'27139' = '5120 '
'27141' = '5120 '
'27145' = '6980 '
'27163' = '5120 '
'27171' = '5120 '
'28033' = '4920 '
'28035' = '3285 '
'28045' = '0920 '
'28047' = '0920 '
'28049' = '3560 '
'28059' = '0920 '
'28073' = '3285 '
'28089' = '3560 '
'28121' = '3560 '
'29003' = '7000 '
'29019' = '1740 '
'29021' = '7000 '
'29037' = '3760 '
'29043' = '7920 '
'29047' = '3760 '
'29049' = '3760 '
'29071' = '7040 '
'29077' = '7920 '
'29095' = '3760 '
'29097' = '3710 '
'29099' = '7040 '
'29107' = '3760 '
'29113' = '7040 '
'29145' = '3710 '
'29165' = '3760 '
'29177' = '3760 '
'29183' = '7040 '
'29189' = '7040 '
'29219' = '7040 '
'29225' = '7920 '
'29510' = '7040 '
'30013' = '3040 '
'30063' = '5140 '
'30111' = '0880 '
'31025' = '5920 '
'31043' = '7720 '
'31055' = '5920 '
'31109' = '4360 '
'31153' = '5920 '
'31177' = '5920 '
'32003' = '4120 '
'32023' = '4120 '
'32031' = '6720 '
'33011' = '1123 '
'33015' = '1123 '
'33017' = '1123 '
'34001' = '0560 '
'34003' = '0875 '
'34005' = '6160 '
'34007' = '6160 '
'34009' = '0560 '
'34011' = '8760 '
'34013' = '5640 '
'34015' = '6160 '
'34017' = '3640 '
'34019' = '5015 '
'34021' = '8480 '
'34023' = '5015 '
'34025' = '5190 '
'34027' = '5640 '
'34029' = '5190 '
'34031' = '0875 '
'34033' = '6160 '
'34035' = '5015 '
'34037' = '5640 '
'34039' = '5640 '
'34041' = '5640 '
'35001' = '0200 '
'35013' = '4100 '
'35028' = '7490 '
'35043' = '0200 '
'35049' = '7490 '
'35061' = '0200 '
'36001' = '0160 '
'36005' = '5600 '
'36007' = '0960 '
'36011' = '8160 '
'36013' = '3610 '
'36015' = '2335 '
'36027' = '2281 '
'36029' = '1280 '
'36037' = '6840 '
'36043' = '8680 '
'36047' = '5600 '
'36051' = '6840 '
'36053' = '8160 '
'36055' = '6840 '
'36057' = '0160 '
'36059' = '5380 '
'36061' = '5600 '
'36063' = '1280 '
'36065' = '8680 '
'36067' = '8160 '
'36069' = '6840 '
'36071' = '5660 '
'36073' = '6840 '
'36075' = '8160 '
'36079' = '5600 '
'36081' = '5600 '
'36083' = '0160 '
'36085' = '5600 '
'36087' = '5600 '
'36091' = '0160 '
'36093' = '0160 '
'36095' = '0160 '
'36103' = '5380 '
'36107' = '0960 '
'36113' = '2975 '
'36115' = '2975 '
'36117' = '6840 '
'36119' = '5600 '
'37001' = '3120 '
'37003' = '3290 '
'37019' = '9200 '
'37021' = '0480 '
'37023' = '3290 '
'37025' = '1520 '
'37027' = '3290 '
'37035' = '3290 '
'37037' = '6640 '
'37051' = '2560 '
'37053' = '5720 '
'37057' = '3120 '
'37059' = '3120 '
'37063' = '6640 '
'37065' = '6895 '
'37067' = '3120 '
'37069' = '6640 '
'37071' = '1520 '
'37081' = '3120 '
'37101' = '6640 '
'37109' = '1520 '
'37115' = '0480 '
'37119' = '1520 '
'37127' = '6895 '
'37129' = '9200 '
'37133' = '3605 '
'37135' = '6640 '
'37147' = '3150 '
'37151' = '3120 '
'37159' = '1520 '
'37169' = '3120 '
'37179' = '1520 '
'37183' = '6640 '
'37191' = '2980 '
'37197' = '3120 '
'38015' = '1010 '
'38017' = '2520 '
'38035' = '2985 '
'38059' = '1010 '
'39003' = '4320 '
'39007' = '1680 '
'39011' = '4320 '
'39013' = '9000 '
'39015' = '1640 '
'39017' = '3200 '
'39019' = '1320 '
'39023' = '2000 '
'39025' = '1640 '
'39029' = '9320 '
'39033' = '4800 '
'39035' = '1680 '
'39041' = '1840 '
'39045' = '1840 '
'39049' = '1840 '
'39051' = '8400 '
'39055' = '1680 '
'39057' = '2000 '
'39061' = '1640 '
'39081' = '8080 '
'39085' = '1680 '
'39087' = '3400 '
'39089' = '1840 '
'39093' = '1680 '
'39095' = '8400 '
'39097' = '1840 '
'39099' = '9320 '
'39103' = '1680 '
'39109' = '2000 '
'39113' = '2000 '
'39129' = '1840 '
'39133' = '0080 '
'39139' = '4800 '
'39151' = '1320 '
'39153' = '0080 '
'39155' = '9320 '
'39165' = '1640 '
'39167' = '6020 '
'39173' = '8400 '
'40017' = '5880 '
'40027' = '5880 '
'40031' = '4200 '
'40037' = '8560 '
'40047' = '2340 '
'40083' = '5880 '
'40087' = '5880 '
'40109' = '5880 '
'40113' = '8560 '
'40125' = '5880 '
'40131' = '8560 '
'40135' = '2720 '
'40143' = '8560 '
'40145' = '8560 '
'41003' = '1890 '
'41005' = '6440 '
'41009' = '6440 '
'41029' = '4890 '
'41039' = '2400 '
'41047' = '7080 '
'41051' = '6440 '
'41053' = '7080 '
'41067' = '6440 '
'41071' = '6440 '
'42003' = '6280 '
'42007' = '6280 '
'42011' = '6680 '
'42013' = '0280 '
'42017' = '6160 '
'42019' = '6280 '
'42021' = '3680 '
'42025' = '0240 '
'42027' = '8050 '
'42029' = '6160 '
'42037' = '7560 '
'42041' = '3240 '
'42043' = '3240 '
'42045' = '6160 '
'42049' = '2360 '
'42051' = '6280 '
'42069' = '7560 '
'42071' = '4000 '
'42075' = '3240 '
'42077' = '0240 '
'42079' = '7560 '
'42081' = '9140 '
'42085' = '7610 '
'42091' = '6160 '
'42095' = '0240 '
'42099' = '3240 '
'42101' = '6160 '
'42103' = '5660 '
'42111' = '3680 '
'42125' = '6280 '
'42129' = '6280 '
'42131' = '7560 '
'42133' = '9280 '
'44001' = '6483 '
'44003' = '6483 '
'44007' = '6483 '
'44009' = '6483 '
'45003' = '0600 '
'45007' = '3160 '
'45015' = '1440 '
'45019' = '1440 '
'45021' = '3160 '
'45035' = '1440 '
'45037' = '0600 '
'45041' = '2655 '
'45045' = '3160 '
'45051' = '5330 '
'45063' = '1760 '
'45077' = '3160 '
'45079' = '1760 '
'45083' = '3160 '
'45085' = '8140 '
'45091' = '1520 '
'46083' = '7760 '
'46099' = '7760 '
'46103' = '6660 '
'47001' = '3840 '
'47009' = '3840 '
'47019' = '3660 '
'47021' = '5360 '
'47023' = '3580 '
'47037' = '5360 '
'47043' = '5360 '
'47047' = '4920 '
'47065' = '1560 '
'47073' = '3660 '
'47093' = '3840 '
'47105' = '3840 '
'47113' = '3580 '
'47115' = '1560 '
'47125' = '1660 '
'47147' = '5360 '
'47149' = '5360 '
'47155' = '3840 '
'47157' = '4920 '
'47163' = '3660 '
'47165' = '5360 '
'47167' = '4920 '
'47171' = '3660 '
'47173' = '3840 '
'47179' = '3660 '
'47187' = '5360 '
'47189' = '5360 '
'48009' = '9080 '
'48021' = '0640 '
'48027' = '3810 '
'48029' = '7240 '
'48037' = '8360 '
'48039' = '1145 '
'48041' = '1260 '
'48055' = '0640 '
'48061' = '1240 '
'48071' = '3360 '
'48085' = '1920 '
'48091' = '7240 '
'48099' = '3810 '
'48113' = '1920 '
'48121' = '1920 '
'48135' = '5800 '
'48139' = '1920 '
'48141' = '2320 '
'48157' = '3360 '
'48167' = '2920 '
'48181' = '7640 '
'48183' = '4420 '
'48187' = '7240 '
'48199' = '0840 '
'48201' = '3360 '
'48203' = '4420 '
'48209' = '0640 '
'48213' = '1920 '
'48215' = '4880 '
'48221' = '2800 '
'48231' = '1920 '
'48245' = '0840 '
'48251' = '2800 '
'48257' = '1920 '
'48291' = '3360 '
'48303' = '4600 '
'48309' = '8800 '
'48329' = '5800 '
'48339' = '3360 '
'48355' = '1880 '
'48361' = '0840 '
'48367' = '2800 '
'48375' = '0320 '
'48381' = '0320 '
'48397' = '1920 '
'48409' = '1880 '
'48423' = '8640 '
'48439' = '2800 '
'48441' = '0040 '
'48451' = '7200 '
'48453' = '0640 '
'48459' = '4420 '
'48469' = '8750 '
'48473' = '3360 '
'48479' = '4080 '
'48485' = '9080 '
'48491' = '0640 '
'48493' = '7240 '
'49011' = '7160 '
'49025' = '2620 '
'49035' = '7160 '
'49049' = '6520 '
'49057' = '7160 '
'50007' = '1303 '
'50011' = '1303 '
'50013' = '1303 '
'51003' = '1540 '
'51009' = '4640 '
'51013' = '8840 '
'51019' = '4640 '
'51023' = '6800 '
'51031' = '4640 '
'51036' = '6760 '
'51041' = '6760 '
'51043' = '8840 '
'51047' = '8840 '
'51053' = '6760 '
'51059' = '8840 '
'51061' = '8840 '
'51065' = '1540 '
'51073' = '5720 '
'51075' = '6760 '
'51079' = '1540 '
'51085' = '6760 '
'51087' = '6760 '
'51093' = '5720 '
'51095' = '5720 '
'51099' = '8840 '
'51107' = '8840 '
'51115' = '5720 '
'51127' = '6760 '
'51143' = '1950 '
'51145' = '6760 '
'51149' = '6760 '
'51153' = '8840 '
'51161' = '6800 '
'51169' = '3660 '
'51177' = '8840 '
'51179' = '8840 '
'51187' = '8840 '
'51191' = '3660 '
'51199' = '5720 '
'51510' = '8840 '
'51515' = '4640 '
'51520' = '3660 '
'51540' = '1540 '
'51550' = '5720 '
'51570' = '6760 '
'51590' = '1950 '
'51600' = '8840 '
'51610' = '8840 '
'51630' = '8840 '
'51650' = '5720 '
'51670' = '6760 '
'51680' = '4640 '
'51683' = '8840 '
'51685' = '8840 '
'51700' = '5720 '
'51710' = '5720 '
'51730' = '6760 '
'51735' = '5720 '
'51740' = '5720 '
'51760' = '6760 '
'51770' = '6800 '
'51775' = '6800 '
'51800' = '5720 '
'51810' = '5720 '
'51830' = '5720 '
'53005' = '6740 '
'53011' = '6440 '
'53021' = '6740 '
'53029' = '7600 '
'53033' = '7600 '
'53035' = '1150 '
'53053' = '8200 '
'53061' = '7600 '
'53063' = '7840 '
'53067' = '5910 '
'53073' = '0860 '
'53077' = '9260 '
'54003' = '8840 '
'54009' = '8080 '
'54011' = '3400 '
'54029' = '8080 '
'54037' = '8840 '
'54039' = '1480 '
'54051' = '9000 '
'54057' = '1900 '
'54069' = '9000 '
'54079' = '1480 '
'54099' = '3400 '
'54107' = '6020 '
'55009' = '3080 '
'55015' = '0460 '
'55017' = '2290 '
'55025' = '4720 '
'55031' = '2240 '
'55035' = '2290 '
'55059' = '3800 '
'55063' = '3870 '
'55073' = '8940 '
'55079' = '5080 '
'55087' = '0460 '
'55089' = '5080 '
'55093' = '5120 '
'55101' = '6600 '
'55105' = '3620 '
'55109' = '5120 '
'55117' = '7620 '
'55131' = '5080 '
'55133' = '5080 '
'55139' = '0460 '
'56021' = '1580 '
'56025' = '1350 '
;
 
/* OMB 2003 METRO AREA */
 
value $M3AREA
'01001' = '33860'
'01003' = '19300'
'01005' = '21640'
'01007' = '13820'
'01009' = '13820'
'01015' = '11500'
'01017' = '46740'
'01021' = '13820'
'01031' = '21460'
'01033' = '22520'
'01037' = '10760'
'01043' = '18980'
'01045' = '21460'
'01047' = '42820'
'01049' = '22840'
'01051' = '33860'
'01055' = '23460'
'01061' = '20020'
'01063' = '46220'
'01065' = '46220'
'01067' = '20020'
'01069' = '20020'
'01071' = '42460'
'01073' = '13820'
'01077' = '22520'
'01079' = '19460'
'01081' = '12220'
'01083' = '26620'
'01085' = '33860'
'01087' = '46260'
'01089' = '26620'
'01095' = '10700'
'01097' = '33660'
'01101' = '33860'
'01103' = '19460'
'01109' = '45980'
'01113' = '17980'
'01115' = '13820'
'01117' = '13820'
'01121' = '45180'
'01123' = '10760'
'01125' = '46220'
'01127' = '13820'
'02020' = '11260'
'02090' = '21820'
'02110' = '27940'
'02130' = '28540'
'02150' = '28980'
'02170' = '11260'
'04003' = '43420'
'04005' = '22380'
'04007' = '37740'
'04009' = '40940'
'04011' = '40940'
'04013' = '38060'
'04015' = '29420'
'04019' = '46060'
'04021' = '38060'
'04023' = '35700'
'04025' = '39140'
'04027' = '49740'
'05005' = '34260'
'05007' = '22220'
'05009' = '25460'
'05013' = '15780'
'05019' = '11660'
'05025' = '38220'
'05027' = '31620'
'05031' = '27860'
'05033' = '22900'
'05035' = '32820'
'05045' = '30780'
'05047' = '22900'
'05051' = '26300'
'05053' = '30780'
'05055' = '37500'
'05057' = '26260'
'05063' = '12900'
'05069' = '38220'
'05079' = '38220'
'05085' = '30780'
'05087' = '22220'
'05091' = '45500'
'05093' = '14180'
'05099' = '26260'
'05101' = '25460'
'05103' = '15780'
'05105' = '30780'
'05107' = '48340'
'05111' = '27860'
'05115' = '40780'
'05119' = '30780'
'05123' = '22620'
'05125' = '30780'
'05131' = '22900'
'05139' = '20980'
'05143' = '22220'
'05145' = '42620'
'05149' = '40780'
'06001' = '41860'
'06007' = '17020'
'06013' = '41860'
'06015' = '18860'
'06017' = '40900'
'06019' = '23420'
'06023' = '21700'
'06025' = '20940'
'06027' = '13860'
'06029' = '12540'
'06031' = '25260'
'06033' = '17340'
'06035' = '45000'
'06037' = '31100'
'06039' = '31460'
'06041' = '41860'
'06045' = '46380'
'06047' = '32900'
'06053' = '41500'
'06055' = '34900'
'06057' = '46020'
'06059' = '31100'
'06061' = '40900'
'06065' = '40140'
'06067' = '40900'
'06069' = '41940'
'06071' = '40140'
'06073' = '41740'
'06075' = '41860'
'06077' = '44700'
'06079' = '42020'
'06081' = '41860'
'06083' = '42060'
'06085' = '41940'
'06087' = '42100'
'06089' = '39820'
'06095' = '46700'
'06097' = '42220'
'06099' = '33700'
'06101' = '49700'
'06103' = '39780'
'06107' = '47300'
'06109' = '38020'
'06111' = '37100'
'06113' = '40900'
'06115' = '49700'
'08001' = '19740'
'08005' = '19740'
'08013' = '14500'
'08014' = '19740'
'08019' = '19740'
'08031' = '19740'
'08035' = '19740'
'08037' = '20780'
'08039' = '19740'
'08041' = '17820'
'08043' = '15860'
'08047' = '19740'
'08059' = '19740'
'08065' = '20780'
'08067' = '20420'
'08069' = '22660'
'08075' = '44540'
'08077' = '24300'
'08085' = '33940'
'08087' = '22820'
'08093' = '19740'
'08101' = '39380'
'08117' = '43540'
'08119' = '17820'
'08123' = '24540'
'09001' = '14860'
'09003' = '25540'
'09005' = '45860'
'09007' = '25540'
'09009' = '35300'
'09011' = '35980'
'09013' = '25540'
'09015' = '48740'
'10001' = '20100'
'10003' = '37980'
'10005' = '42580'
'11001' = '47900'
'12001' = '23540'
'12003' = '27260'
'12005' = '37460'
'12009' = '37340'
'12011' = '33100'
'12015' = '39460'
'12017' = '26140'
'12019' = '27260'
'12021' = '34940'
'12023' = '29380'
'12027' = '11580'
'12031' = '27260'
'12033' = '37860'
'12035' = '37380'
'12039' = '45220'
'12041' = '23540'
'12049' = '48100'
'12051' = '17500'
'12053' = '45300'
'12055' = '42700'
'12057' = '45300'
'12061' = '46940'
'12065' = '45220'
'12069' = '36740'
'12071' = '15980'
'12073' = '45220'
'12081' = '42260'
'12083' = '36100'
'12085' = '38940'
'12086' = '33100'
'12087' = '28580'
'12089' = '27260'
'12091' = '23020'
'12093' = '36380'
'12095' = '36740'
'12097' = '36740'
'12099' = '33100'
'12101' = '45300'
'12103' = '45300'
'12105' = '29460'
'12107' = '37260'
'12109' = '27260'
'12111' = '38940'
'12113' = '37860'
'12115' = '42260'
'12117' = '36740'
'12119' = '45540'
'12127' = '19660'
'12129' = '45220'
'13003' = '20060'
'13007' = '10500'
'13009' = '33300'
'13013' = '12060'
'13015' = '12060'
'13017' = '22340'
'13021' = '31420'
'13025' = '15260'
'13027' = '46660'
'13029' = '42340'
'13031' = '44340'
'13033' = '12260'
'13035' = '12060'
'13039' = '41220'
'13045' = '12060'
'13047' = '16860'
'13051' = '42340'
'13053' = '17980'
'13055' = '44900'
'13057' = '12060'
'13059' = '12020'
'13063' = '12060'
'13067' = '12060'
'13069' = '20060'
'13071' = '34220'
'13073' = '12260'
'13077' = '12060'
'13079' = '31420'
'13081' = '18380'
'13083' = '16860'
'13085' = '12060'
'13087' = '12460'
'13089' = '12060'
'13095' = '10500'
'13097' = '12060'
'13101' = '46660'
'13103' = '42340'
'13113' = '12060'
'13115' = '40660'
'13117' = '12060'
'13121' = '12060'
'13127' = '15260'
'13129' = '15660'
'13135' = '12060'
'13137' = '18460'
'13139' = '23580'
'13141' = '33300'
'13143' = '12060'
'13145' = '17980'
'13149' = '12060'
'13151' = '12060'
'13153' = '47580'
'13155' = '22340'
'13159' = '12060'
'13167' = '20140'
'13169' = '31420'
'13171' = '12060'
'13173' = '46660'
'13175' = '20140'
'13177' = '10500'
'13179' = '25980'
'13183' = '25980'
'13185' = '46660'
'13189' = '12260'
'13191' = '15260'
'13195' = '12020'
'13197' = '17980'
'13199' = '12060'
'13207' = '31420'
'13209' = '47080'
'13213' = '19140'
'13215' = '17980'
'13217' = '12060'
'13219' = '12020'
'13221' = '12020'
'13223' = '12060'
'13225' = '22980'
'13227' = '12060'
'13229' = '48180'
'13231' = '12060'
'13233' = '16340'
'13239' = '21640'
'13245' = '12260'
'13247' = '12060'
'13249' = '11140'
'13255' = '12060'
'13257' = '45740'
'13261' = '11140'
'13273' = '10500'
'13275' = '45620'
'13277' = '45700'
'13279' = '47080'
'13285' = '29300'
'13289' = '31420'
'13293' = '45580'
'13295' = '16860'
'13297' = '12060'
'13299' = '48180'
'13305' = '27700'
'13313' = '19140'
'13321' = '10500'
'15001' = '25900'
'15003' = '26180'
'15007' = '28180'
'15009' = '27980'
'16001' = '14260'
'16005' = '38540'
'16011' = '13940'
'16015' = '14260'
'16019' = '26820'
'16027' = '14260'
'16031' = '15420'
'16039' = '34300'
'16041' = '30860'
'16043' = '39940'
'16045' = '14260'
'16051' = '26820'
'16053' = '46300'
'16055' = '17660'
'16057' = '34140'
'16065' = '39940'
'16067' = '15420'
'16069' = '30300'
'16073' = '14260'
'16075' = '36620'
'16077' = '38540'
'16081' = '27220'
'16083' = '46300'
'17001' = '39500'
'17003' = '16020'
'17005' = '41180'
'17007' = '40420'
'17011' = '36860'
'17013' = '41180'
'17019' = '16580'
'17021' = '45380'
'17027' = '41180'
'17029' = '16660'
'17031' = '16980'
'17035' = '16660'
'17037' = '16980'
'17043' = '16980'
'17049' = '20820'
'17053' = '16580'
'17057' = '15900'
'17063' = '16980'
'17065' = '34500'
'17071' = '15460'
'17073' = '19340'
'17077' = '16060'
'17081' = '34500'
'17083' = '41180'
'17089' = '16980'
'17091' = '28100'
'17093' = '16980'
'17095' = '23660'
'17097' = '16980'
'17099' = '36860'
'17103' = '19940'
'17105' = '38700'
'17107' = '30660'
'17109' = '31380'
'17111' = '16980'
'17113' = '14060'
'17115' = '19500'
'17117' = '41180'
'17119' = '41180'
'17121' = '16460'
'17123' = '37900'
'17127' = '37140'
'17129' = '44100'
'17131' = '19340'
'17133' = '41180'
'17137' = '27300'
'17141' = '40300'
'17143' = '37900'
'17147' = '16580'
'17155' = '36860'
'17161' = '19340'
'17163' = '41180'
'17165' = '25380'
'17167' = '44100'
'17171' = '27300'
'17175' = '37900'
'17177' = '23300'
'17179' = '37900'
'17183' = '19180'
'17187' = '23660'
'17195' = '44580'
'17197' = '16980'
'17199' = '32060'
'17201' = '40420'
'17203' = '37900'
'18001' = '19540'
'18003' = '23060'
'18005' = '18020'
'18007' = '29140'
'18011' = '26900'
'18013' = '26900'
'18015' = '29140'
'18017' = '30900'
'18019' = '31140'
'18021' = '45460'
'18023' = '23140'
'18027' = '47780'
'18029' = '17140'
'18031' = '24700'
'18033' = '12140'
'18035' = '34620'
'18037' = '27540'
'18039' = '21140'
'18041' = '18220'
'18043' = '31140'
'18047' = '17140'
'18051' = '21780'
'18053' = '31980'
'18055' = '14020'
'18057' = '26900'
'18059' = '26900'
'18061' = '31140'
'18063' = '26900'
'18065' = '35220'
'18067' = '29020'
'18069' = '26540'
'18071' = '42980'
'18073' = '16980'
'18077' = '31500'
'18079' = '35860'
'18081' = '26900'
'18083' = '47180'
'18085' = '47700'
'18089' = '16980'
'18091' = '33140'
'18093' = '13260'
'18095' = '11300'
'18097' = '26900'
'18099' = '38500'
'18103' = '37940'
'18105' = '14020'
'18107' = '18820'
'18109' = '26900'
'18111' = '16980'
'18113' = '28340'
'18115' = '17140'
'18119' = '14020'
'18125' = '27540'
'18127' = '16980'
'18129' = '21780'
'18133' = '26900'
'18141' = '43780'
'18143' = '42500'
'18145' = '26900'
'18151' = '11420'
'18153' = '45460'
'18157' = '29140'
'18159' = '29020'
'18163' = '21780'
'18165' = '45460'
'18167' = '45460'
'18169' = '47340'
'18173' = '21780'
'18175' = '31140'
'18177' = '39980'
'18179' = '23060'
'18183' = '23060'
'19011' = '16300'
'19013' = '47940'
'19015' = '14340'
'19017' = '47940'
'19021' = '44740'
'19033' = '32380'
'19041' = '43980'
'19045' = '17540'
'19049' = '19780'
'19057' = '15460'
'19059' = '44020'
'19061' = '20220'
'19075' = '47940'
'19077' = '19780'
'19085' = '36540'
'19099' = '35500'
'19103' = '26980'
'19105' = '16300'
'19111' = '28460'
'19113' = '16300'
'19115' = '34700'
'19121' = '19780'
'19123' = '36820'
'19125' = '37800'
'19127' = '32260'
'19129' = '36540'
'19139' = '34700'
'19153' = '19780'
'19155' = '36540'
'19163' = '19340'
'19169' = '11180'
'19179' = '36900'
'19181' = '19780'
'19183' = '26980'
'19187' = '22700'
'19193' = '43580'
'19195' = '32380'
'20005' = '11860'
'20009' = '24460'
'20015' = '48620'
'20017' = '21380'
'20035' = '49060'
'20037' = '38260'
'20043' = '41140'
'20045' = '29940'
'20051' = '25700'
'20055' = '23780'
'20057' = '19980'
'20059' = '28140'
'20061' = '31740'
'20079' = '48620'
'20085' = '45820'
'20087' = '45820'
'20091' = '28140'
'20099' = '37660'
'20103' = '28140'
'20107' = '28140'
'20111' = '21380'
'20113' = '32700'
'20121' = '28140'
'20125' = '17700'
'20139' = '45820'
'20143' = '41460'
'20149' = '31740'
'20155' = '26740'
'20161' = '31740'
'20169' = '41460'
'20173' = '48620'
'20175' = '30580'
'20177' = '45820'
'20191' = '48620'
'20197' = '45820'
'20209' = '28140'
'21005' = '23180'
'21007' = '37140'
'21009' = '23980'
'21011' = '34460'
'21013' = '33180'
'21015' = '17140'
'21017' = '30460'
'21019' = '26580'
'21021' = '19220'
'21023' = '17140'
'21029' = '31140'
'21035' = '34660'
'21037' = '17140'
'21047' = '17300'
'21049' = '30460'
'21059' = '36980'
'21061' = '14540'
'21067' = '30460'
'21073' = '23180'
'21075' = '46460'
'21077' = '17140'
'21081' = '17140'
'21083' = '32460'
'21089' = '26580'
'21091' = '36980'
'21093' = '21060'
'21101' = '21780'
'21103' = '31140'
'21107' = '31580'
'21111' = '31140'
'21113' = '30460'
'21117' = '17140'
'21123' = '21060'
'21125' = '30940'
'21135' = '32500'
'21137' = '19220'
'21139' = '37140'
'21145' = '37140'
'21149' = '36980'
'21151' = '40080'
'21161' = '32500'
'21163' = '31140'
'21165' = '34460'
'21169' = '23980'
'21173' = '34460'
'21177' = '16420'
'21179' = '31140'
'21185' = '31140'
'21191' = '17140'
'21199' = '43700'
'21203' = '40080'
'21209' = '30460'
'21211' = '31140'
'21215' = '31140'
'21217' = '15820'
'21221' = '17300'
'21223' = '31140'
'21227' = '14540'
'21233' = '21780'
'21235' = '18340'
'21239' = '30460'
'22001' = '18940'
'22005' = '12940'
'22007' = '38200'
'22011' = '19760'
'22015' = '43340'
'22017' = '43340'
'22019' = '29340'
'22023' = '29340'
'22029' = '35020'
'22031' = '43340'
'22033' = '12940'
'22037' = '12940'
'22043' = '10780'
'22045' = '35340'
'22047' = '12940'
'22049' = '40820'
'22051' = '35380'
'22053' = '27660'
'22055' = '29180'
'22057' = '26380'
'22061' = '40820'
'22063' = '12940'
'22065' = '45260'
'22067' = '12820'
'22069' = '35060'
'22071' = '35380'
'22073' = '33740'
'22075' = '35380'
'22077' = '12940'
'22079' = '10780'
'22087' = '35380'
'22089' = '35380'
'22091' = '12940'
'22095' = '35380'
'22097' = '36660'
'22099' = '29180'
'22101' = '34020'
'22103' = '35380'
'22105' = '25220'
'22109' = '26380'
'22111' = '33740'
'22113' = '10020'
'22115' = '22860'
'22117' = '14220'
'22119' = '33380'
'22121' = '12940'
'22125' = '12940'
'23001' = '30340'
'23005' = '38860'
'23011' = '12300'
'23013' = '40500'
'23019' = '12620'
'23023' = '38860'
'23031' = '38860'
'24001' = '19060'
'24003' = '12580'
'24005' = '12580'
'24009' = '47900'
'24013' = '12580'
'24015' = '37980'
'24017' = '47900'
'24019' = '15700'
'24021' = '47900'
'24025' = '12580'
'24027' = '12580'
'24031' = '47900'
'24033' = '47900'
'24035' = '12580'
'24037' = '30500'
'24039' = '41540'
'24041' = '20660'
'24043' = '25180'
'24045' = '41540'
'24047' = '36180'
'24510' = '12580'
'25001' = '12700'
'25003' = '38340'
'25005' = '39300'
'25009' = '14460'
'25011' = '44140'
'25013' = '44140'
'25015' = '44140'
'25017' = '14460'
'25021' = '14460'
'25023' = '14460'
'25025' = '14460'
'25027' = '49340'
'26005' = '10880'
'26007' = '10980'
'26015' = '24340'
'26017' = '13020'
'26019' = '45900'
'26021' = '35660'
'26023' = '17740'
'26025' = '12980'
'26027' = '43780'
'26033' = '42300'
'26037' = '29620'
'26041' = '21540'
'26043' = '27020'
'26045' = '29620'
'26049' = '22420'
'26055' = '45900'
'26057' = '10940'
'26061' = '26340'
'26065' = '29620'
'26067' = '24340'
'26073' = '34380'
'26075' = '27100'
'26077' = '28020'
'26079' = '45900'
'26081' = '24340'
'26083' = '26340'
'26087' = '19820'
'26089' = '45900'
'26091' = '10300'
'26093' = '19820'
'26099' = '19820'
'26103' = '32100'
'26107' = '13660'
'26109' = '31940'
'26111' = '33220'
'26113' = '15620'
'26115' = '33780'
'26121' = '34740'
'26123' = '24340'
'26125' = '19820'
'26139' = '26100'
'26145' = '40980'
'26147' = '19820'
'26149' = '44780'
'26155' = '37020'
'26159' = '28020'
'26161' = '11460'
'26163' = '19820'
'26165' = '15620'
'27003' = '33460'
'27007' = '13420'
'27009' = '41060'
'27013' = '31860'
'27015' = '35580'
'27017' = '20260'
'27019' = '33460'
'27021' = '14660'
'27025' = '33460'
'27027' = '22020'
'27035' = '14660'
'27037' = '33460'
'27039' = '40340'
'27041' = '10820'
'27047' = '10660'
'27049' = '39860'
'27053' = '33460'
'27055' = '29100'
'27059' = '33460'
'27067' = '48820'
'27083' = '32140'
'27085' = '26780'
'27091' = '21860'
'27099' = '12380'
'27103' = '31860'
'27105' = '49380'
'27109' = '40340'
'27111' = '22260'
'27119' = '24220'
'27123' = '33460'
'27131' = '22060'
'27137' = '20260'
'27139' = '33460'
'27141' = '33460'
'27145' = '41060'
'27147' = '36940'
'27157' = '40340'
'27163' = '33460'
'27167' = '47420'
'27169' = '49100'
'27171' = '33460'
'28001' = '35020'
'28003' = '18420'
'28005' = '32620'
'28011' = '17380'
'28015' = '24900'
'28023' = '32940'
'28025' = '48500'
'28027' = '17260'
'28029' = '27140'
'28033' = '32820'
'28035' = '25620'
'28039' = '37700'
'28043' = '24980'
'28045' = '25060'
'28047' = '25060'
'28049' = '27140'
'28057' = '46180'
'28059' = '37700'
'28061' = '29860'
'28067' = '29860'
'28069' = '32940'
'28071' = '37060'
'28073' = '25620'
'28075' = '32940'
'28081' = '46180'
'28083' = '24900'
'28085' = '15020'
'28087' = '18060'
'28089' = '27140'
'28093' = '32820'
'28105' = '44260'
'28109' = '38100'
'28111' = '25620'
'28113' = '32620'
'28115' = '46180'
'28121' = '27140'
'28127' = '27140'
'28131' = '25060'
'28133' = '26940'
'28137' = '32820'
'28143' = '32820'
'28149' = '46980'
'28151' = '24740'
'28163' = '49540'
'29001' = '28860'
'29003' = '41140'
'29007' = '33020'
'29013' = '28140'
'29017' = '16020'
'29019' = '17860'
'29021' = '41140'
'29023' = '38740'
'29025' = '28140'
'29027' = '27620'
'29031' = '16020'
'29037' = '28140'
'29043' = '44180'
'29045' = '28460'
'29047' = '28140'
'29049' = '28140'
'29051' = '27620'
'29059' = '44180'
'29063' = '41140'
'29069' = '28380'
'29071' = '41180'
'29077' = '44180'
'29089' = '17860'
'29091' = '48460'
'29095' = '28140'
'29097' = '27900'
'29099' = '41180'
'29101' = '47660'
'29105' = '30060'
'29107' = '28140'
'29111' = '39500'
'29113' = '41180'
'29119' = '22220'
'29127' = '25300'
'29135' = '27620'
'29145' = '27900'
'29147' = '32340'
'29151' = '27620'
'29159' = '42740'
'29161' = '40620'
'29165' = '28140'
'29167' = '44180'
'29169' = '22780'
'29173' = '25300'
'29175' = '33620'
'29177' = '28140'
'29183' = '41180'
'29187' = '22100'
'29189' = '41180'
'29195' = '32180'
'29197' = '28860'
'29201' = '43460'
'29209' = '14700'
'29213' = '14700'
'29219' = '41180'
'29221' = '41180'
'29225' = '44180'
'29510' = '41180'
'30009' = '13740'
'30013' = '24500'
'30029' = '28060'
'30031' = '14580'
'30041' = '25660'
'30043' = '25740'
'30049' = '25740'
'30063' = '33540'
'30093' = '15580'
'30111' = '13740'
'31001' = '25580'
'31007' = '42420'
'31019' = '28260'
'31025' = '36540'
'31035' = '25580'
'31043' = '43580'
'31047' = '30420'
'31051' = '43580'
'31053' = '23340'
'31055' = '36540'
'31067' = '13100'
'31073' = '30420'
'31079' = '24260'
'31093' = '24260'
'31099' = '28260'
'31109' = '30700'
'31111' = '35820'
'31113' = '35820'
'31117' = '35820'
'31119' = '35740'
'31121' = '24260'
'31139' = '35740'
'31141' = '18100'
'31153' = '36540'
'31155' = '36540'
'31157' = '42420'
'31159' = '30700'
'31167' = '35740'
'31177' = '36540'
'32001' = '21980'
'32003' = '29820'
'32005' = '23820'
'32007' = '21220'
'32011' = '21220'
'32023' = '37220'
'32029' = '39900'
'32031' = '39900'
'32510' = '16180'
'33001' = '29060'
'33005' = '28300'
'33007' = '13620'
'33009' = '30100'
'33011' = '31700'
'33013' = '18180'
'33015' = '14460'
'33017' = '14460'
'33019' = '17200'
'34001' = '12100'
'34003' = '35620'
'34005' = '37980'
'34007' = '37980'
'34009' = '36140'
'34011' = '47220'
'34013' = '35620'
'34015' = '37980'
'34017' = '35620'
'34019' = '35620'
'34021' = '45940'
'34023' = '35620'
'34025' = '35620'
'34027' = '35620'
'34029' = '35620'
'34031' = '35620'
'34033' = '37980'
'34035' = '35620'
'34037' = '35620'
'34039' = '35620'
'34041' = '10900'
'35001' = '10740'
'35005' = '40740'
'35006' = '24380'
'35009' = '17580'
'35013' = '29740'
'35015' = '16100'
'35017' = '43500'
'35025' = '26020'
'35028' = '31060'
'35029' = '19700'
'35031' = '23700'
'35035' = '10460'
'35039' = '21580'
'35041' = '38780'
'35043' = '10740'
'35045' = '22140'
'35047' = '29780'
'35049' = '42140'
'35055' = '45340'
'35057' = '10740'
'35061' = '10740'
'36001' = '10580'
'36005' = '35620'
'36007' = '13780'
'36009' = '36460'
'36011' = '12180'
'36013' = '27460'
'36015' = '21300'
'36019' = '38460'
'36021' = '26460'
'36023' = '18660'
'36027' = '39100'
'36029' = '15380'
'36033' = '31660'
'36035' = '24100'
'36037' = '12860'
'36043' = '46540'
'36045' = '48060'
'36047' = '35620'
'36051' = '40380'
'36053' = '45060'
'36055' = '40380'
'36057' = '11220'
'36059' = '35620'
'36061' = '35620'
'36063' = '15380'
'36065' = '46540'
'36067' = '45060'
'36069' = '40380'
'36071' = '39100'
'36073' = '40380'
'36075' = '45060'
'36077' = '36580'
'36079' = '35620'
'36081' = '35620'
'36083' = '10580'
'36085' = '35620'
'36087' = '35620'
'36089' = '36300'
'36091' = '10580'
'36093' = '10580'
'36095' = '10580'
'36099' = '42900'
'36101' = '18500'
'36103' = '35620'
'36107' = '13780'
'36109' = '27060'
'36111' = '28740'
'36113' = '24020'
'36115' = '24020'
'36117' = '40380'
'36119' = '35620'
'37001' = '15500'
'37003' = '25860'
'37007' = '16740'
'37013' = '47820'
'37019' = '48900'
'37021' = '11700'
'37023' = '25860'
'37025' = '16740'
'37027' = '25860'
'37029' = '21020'
'37031' = '33980'
'37035' = '25860'
'37037' = '20500'
'37045' = '43140'
'37049' = '35100'
'37051' = '22180'
'37053' = '47260'
'37055' = '28620'
'37057' = '45640'
'37059' = '49180'
'37063' = '20500'
'37065' = '40580'
'37067' = '49180'
'37069' = '39580'
'37071' = '16740'
'37079' = '24780'
'37081' = '24660'
'37083' = '40260'
'37085' = '20380'
'37087' = '11700'
'37089' = '11700'
'37093' = '22180'
'37097' = '44380'
'37101' = '39580'
'37103' = '35100'
'37105' = '41820'
'37107' = '28820'
'37109' = '30740'
'37115' = '11700'
'37119' = '16740'
'37125' = '43860'
'37127' = '40580'
'37129' = '48900'
'37131' = '40260'
'37133' = '27340'
'37135' = '20500'
'37137' = '35100'
'37139' = '21020'
'37141' = '48900'
'37143' = '21020'
'37145' = '20500'
'37147' = '24780'
'37151' = '24660'
'37153' = '40460'
'37155' = '31300'
'37157' = '24660'
'37159' = '41580'
'37161' = '22580'
'37165' = '29900'
'37167' = '10620'
'37169' = '49180'
'37171' = '34340'
'37175' = '14820'
'37179' = '16740'
'37181' = '25780'
'37183' = '39580'
'37189' = '14380'
'37191' = '24140'
'37193' = '35900'
'37195' = '48980'
'37197' = '49180'
'38007' = '19860'
'38015' = '13900'
'38017' = '22020'
'38035' = '24220'
'38049' = '33500'
'38059' = '13900'
'38075' = '33500'
'38077' = '47420'
'38089' = '19860'
'38093' = '27420'
'38101' = '33500'
'38105' = '48780'
'39003' = '30620'
'39005' = '11740'
'39007' = '11780'
'39009' = '11900'
'39011' = '47540'
'39013' = '48540'
'39015' = '17140'
'39017' = '17140'
'39019' = '15940'
'39021' = '46500'
'39023' = '44220'
'39025' = '17140'
'39027' = '48940'
'39029' = '20620'
'39031' = '18740'
'39033' = '15340'
'39035' = '17460'
'39037' = '24820'
'39039' = '19580'
'39041' = '18140'
'39043' = '41780'
'39045' = '18140'
'39047' = '47860'
'39049' = '18140'
'39051' = '45780'
'39053' = '38580'
'39055' = '17460'
'39057' = '19380'
'39059' = '15740'
'39061' = '17140'
'39063' = '22300'
'39077' = '35940'
'39081' = '48260'
'39083' = '34540'
'39085' = '17460'
'39087' = '26580'
'39089' = '18140'
'39091' = '13340'
'39093' = '17460'
'39095' = '45780'
'39097' = '18140'
'39099' = '49660'
'39101' = '32020'
'39103' = '17460'
'39107' = '16380'
'39109' = '19380'
'39113' = '19380'
'39117' = '18140'
'39119' = '49780'
'39123' = '45780'
'39129' = '18140'
'39133' = '10420'
'39135' = '19380'
'39139' = '31900'
'39141' = '17060'
'39143' = '23380'
'39145' = '39020'
'39147' = '45660'
'39149' = '43380'
'39151' = '15940'
'39153' = '10420'
'39155' = '49660'
'39157' = '35420'
'39159' = '18140'
'39161' = '46780'
'39165' = '17140'
'39167' = '37620'
'39169' = '49300'
'39173' = '45780'
'40009' = '21120'
'40013' = '20460'
'40017' = '36420'
'40019' = '11620'
'40021' = '45140'
'40027' = '36420'
'40031' = '30020'
'40037' = '46140'
'40047' = '21420'
'40051' = '36420'
'40065' = '11060'
'40071' = '38620'
'40079' = '22900'
'40081' = '36420'
'40083' = '36420'
'40085' = '11620'
'40087' = '36420'
'40101' = '34780'
'40109' = '36420'
'40111' = '46140'
'40113' = '46140'
'40115' = '33060'
'40117' = '46140'
'40119' = '44660'
'40121' = '32540'
'40123' = '10220'
'40125' = '43060'
'40131' = '46140'
'40135' = '22900'
'40137' = '20340'
'40139' = '25100'
'40143' = '46140'
'40145' = '46140'
'40147' = '12780'
'40153' = '49260'
'41003' = '18700'
'41005' = '38900'
'41007' = '11820'
'41009' = '38900'
'41011' = '18300'
'41013' = '39260'
'41015' = '15060'
'41017' = '13460'
'41019' = '40700'
'41027' = '26220'
'41029' = '32780'
'41033' = '24420'
'41035' = '28900'
'41039' = '21660'
'41043' = '10540'
'41045' = '36620'
'41047' = '41420'
'41049' = '37820'
'41051' = '38900'
'41053' = '41420'
'41059' = '37820'
'41061' = '29260'
'41065' = '17180'
'41067' = '38900'
'41071' = '38900'
'42001' = '23900'
'42003' = '38300'
'42005' = '38300'
'42007' = '38300'
'42011' = '39740'
'42013' = '11020'
'42015' = '42380'
'42017' = '37980'
'42019' = '38300'
'42021' = '27780'
'42025' = '10900'
'42027' = '44300'
'42029' = '37980'
'42033' = '20180'
'42035' = '30820'
'42037' = '14100'
'42039' = '32740'
'42041' = '25420'
'42043' = '25420'
'42045' = '37980'
'42047' = '41260'
'42049' = '21500'
'42051' = '38300'
'42055' = '16540'
'42061' = '26500'
'42063' = '26860'
'42069' = '42540'
'42071' = '29540'
'42073' = '35260'
'42075' = '30140'
'42077' = '10900'
'42079' = '42540'
'42081' = '48700'
'42083' = '14620'
'42085' = '49660'
'42087' = '30380'
'42089' = '20700'
'42091' = '37980'
'42093' = '14100'
'42095' = '10900'
'42097' = '44980'
'42099' = '25420'
'42101' = '37980'
'42103' = '35620'
'42107' = '39060'
'42109' = '42780'
'42111' = '43740'
'42119' = '30260'
'42121' = '36340'
'42123' = '47620'
'42125' = '38300'
'42129' = '38300'
'42131' = '42540'
'42133' = '49620'
'44001' = '39300'
'44003' = '39300'
'44005' = '39300'
'44007' = '39300'
'44009' = '39300'
'45003' = '12260'
'45007' = '11340'
'45013' = '25940'
'45015' = '16700'
'45017' = '17900'
'45019' = '16700'
'45021' = '23500'
'45023' = '16900'
'45029' = '47500'
'45031' = '22500'
'45033' = '19900'
'45035' = '16700'
'45037' = '12260'
'45039' = '17900'
'45041' = '22500'
'45043' = '23860'
'45045' = '24860'
'45047' = '24940'
'45051' = '34820'
'45053' = '25940'
'45055' = '17900'
'45057' = '29580'
'45059' = '24860'
'45063' = '17900'
'45069' = '13500'
'45071' = '35140'
'45073' = '42860'
'45075' = '36700'
'45077' = '24860'
'45079' = '17900'
'45081' = '17900'
'45083' = '43900'
'45085' = '44940'
'45087' = '46420'
'45091' = '16740'
'46005' = '26700'
'46011' = '15100'
'46013' = '10100'
'46027' = '46820'
'46029' = '47980'
'46035' = '33580'
'46045' = '10100'
'46057' = '47980'
'46061' = '33580'
'46065' = '38180'
'46081' = '43940'
'46083' = '43620'
'46087' = '43620'
'46093' = '39660'
'46099' = '43620'
'46103' = '39660'
'46117' = '38180'
'46125' = '43620'
'46127' = '43580'
'46135' = '49460'
'47001' = '28940'
'47003' = '43180'
'47009' = '28940'
'47011' = '17420'
'47013' = '29220'
'47015' = '34980'
'47019' = '27740'
'47021' = '34980'
'47023' = '27180'
'47029' = '35460'
'47031' = '46100'
'47035' = '18900'
'47037' = '34980'
'47043' = '34980'
'47045' = '20540'
'47047' = '32820'
'47051' = '46100'
'47053' = '26480'
'47057' = '34100'
'47059' = '24620'
'47063' = '34100'
'47065' = '16860'
'47073' = '28700'
'47075' = '15140'
'47079' = '37540'
'47081' = '34980'
'47087' = '18260'
'47089' = '34100'
'47093' = '28940'
'47099' = '29980'
'47105' = '28940'
'47107' = '11940'
'47111' = '34980'
'47113' = '27180'
'47115' = '16860'
'47117' = '30280'
'47119' = '17940'
'47125' = '17300'
'47127' = '46100'
'47131' = '46460'
'47133' = '18260'
'47139' = '17420'
'47141' = '18260'
'47145' = '25340'
'47147' = '34980'
'47149' = '34980'
'47153' = '16860'
'47155' = '42940'
'47157' = '32820'
'47159' = '34980'
'47161' = '17300'
'47163' = '28700'
'47165' = '34980'
'47167' = '32820'
'47169' = '34980'
'47171' = '27740'
'47173' = '28940'
'47177' = '32660'
'47179' = '27740'
'47183' = '32280'
'47187' = '34980'
'47189' = '34980'
'48001' = '37300'
'48003' = '11380'
'48005' = '31260'
'48007' = '18580'
'48009' = '48660'
'48011' = '11100'
'48013' = '41700'
'48015' = '26420'
'48019' = '41700'
'48021' = '12420'
'48025' = '13300'
'48027' = '28660'
'48029' = '41700'
'48037' = '45500'
'48039' = '26420'
'48041' = '17780'
'48049' = '15220'
'48051' = '17780'
'48055' = '12420'
'48057' = '47020'
'48059' = '10180'
'48061' = '15180'
'48065' = '11100'
'48071' = '26420'
'48073' = '27380'
'48077' = '48660'
'48085' = '19100'
'48091' = '41700'
'48097' = '23620'
'48099' = '28660'
'48107' = '31180'
'48113' = '19100'
'48115' = '29500'
'48117' = '25820'
'48119' = '19100'
'48121' = '19100'
'48135' = '36220'
'48139' = '19100'
'48141' = '21340'
'48143' = '44500'
'48147' = '14300'
'48157' = '26420'
'48167' = '26420'
'48175' = '47020'
'48179' = '37420'
'48181' = '43300'
'48183' = '30980'
'48187' = '41700'
'48189' = '38380'
'48199' = '13140'
'48201' = '26420'
'48203' = '32220'
'48209' = '12420'
'48213' = '11980'
'48215' = '32580'
'48219' = '30220'
'48221' = '24180'
'48223' = '44860'
'48227' = '13700'
'48231' = '19100'
'48233' = '14420'
'48235' = '41660'
'48245' = '13140'
'48249' = '10860'
'48251' = '19100'
'48253' = '10180'
'48257' = '19100'
'48259' = '41700'
'48261' = '28780'
'48265' = '28500'
'48273' = '28780'
'48277' = '37580'
'48281' = '28660'
'48291' = '26420'
'48303' = '31180'
'48309' = '47380'
'48321' = '13060'
'48323' = '20580'
'48325' = '41700'
'48329' = '33260'
'48339' = '26420'
'48341' = '20300'
'48347' = '34860'
'48349' = '18620'
'48353' = '45020'
'48355' = '18580'
'48361' = '13140'
'48363' = '33420'
'48367' = '19100'
'48375' = '11100'
'48381' = '11100'
'48389' = '37780'
'48393' = '37420'
'48395' = '17780'
'48397' = '19100'
'48401' = '30980'
'48407' = '26420'
'48409' = '18580'
'48415' = '43660'
'48423' = '46340'
'48425' = '24180'
'48427' = '40100'
'48439' = '19100'
'48441' = '10180'
'48449' = '34420'
'48451' = '41660'
'48453' = '12420'
'48459' = '30980'
'48463' = '46620'
'48465' = '19620'
'48469' = '47020'
'48471' = '26660'
'48473' = '26420'
'48477' = '14780'
'48479' = '29700'
'48481' = '20900'
'48485' = '48660'
'48487' = '46900'
'48489' = '39700'
'48491' = '12420'
'48493' = '41700'
'48497' = '19100'
'49003' = '14940'
'49005' = '30860'
'49007' = '39220'
'49011' = '36260'
'49021' = '16260'
'49023' = '39340'
'49029' = '36260'
'49035' = '41620'
'49043' = '41620'
'49045' = '41620'
'49047' = '46860'
'49049' = '39340'
'49051' = '25720'
'49053' = '41100'
'49057' = '36260'
'50003' = '13540'
'50007' = '15540'
'50009' = '13620'
'50011' = '15540'
'50013' = '15540'
'50017' = '30100'
'50021' = '40860'
'50023' = '12740'
'50027' = '30100'
'51003' = '16820'
'51007' = '40060'
'51009' = '31340'
'51011' = '31340'
'51013' = '47900'
'51015' = '44420'
'51019' = '31340'
'51023' = '40220'
'51031' = '31340'
'51033' = '40060'
'51036' = '40060'
'51041' = '40060'
'51043' = '47900'
'51045' = '40220'
'51047' = '19020'
'51049' = '40060'
'51053' = '40060'
'51059' = '47900'
'51061' = '47900'
'51065' = '16820'
'51067' = '40220'
'51069' = '49020'
'51071' = '13980'
'51073' = '47260'
'51075' = '40060'
'51079' = '16820'
'51085' = '40060'
'51087' = '40060'
'51089' = '32300'
'51093' = '47260'
'51095' = '47260'
'51097' = '40060'
'51101' = '40060'
'51107' = '47900'
'51109' = '40060'
'51115' = '47260'
'51121' = '13980'
'51125' = '16820'
'51127' = '40060'
'51143' = '19260'
'51145' = '40060'
'51149' = '40060'
'51153' = '47900'
'51155' = '13980'
'51161' = '40220'
'51165' = '25500'
'51169' = '28700'
'51177' = '47900'
'51179' = '47900'
'51181' = '47260'
'51183' = '40060'
'51185' = '14140'
'51187' = '47900'
'51191' = '28700'
'51199' = '47260'
'51510' = '47900'
'51515' = '31340'
'51520' = '28700'
'51540' = '16820'
'51550' = '47260'
'51570' = '40060'
'51590' = '19260'
'51600' = '47900'
'51610' = '47900'
'51630' = '47900'
'51650' = '47260'
'51660' = '25500'
'51670' = '40060'
'51680' = '31340'
'51683' = '47900'
'51685' = '47900'
'51690' = '32300'
'51700' = '47260'
'51710' = '47260'
'51730' = '40060'
'51735' = '47260'
'51740' = '47260'
'51750' = '13980'
'51760' = '40060'
'51770' = '40220'
'51775' = '40220'
'51790' = '44420'
'51800' = '47260'
'51810' = '47260'
'51820' = '44420'
'51830' = '47260'
'51840' = '49020'
'53003' = '30300'
'53005' = '28420'
'53007' = '48300'
'53009' = '38820'
'53011' = '38900'
'53015' = '31020'
'53017' = '48300'
'53021' = '28420'
'53025' = '34180'
'53027' = '10140'
'53029' = '36020'
'53033' = '42660'
'53035' = '14740'
'53037' = '21260'
'53041' = '16500'
'53045' = '43220'
'53053' = '42660'
'53057' = '34580'
'53059' = '38900'
'53061' = '42660'
'53063' = '44060'
'53067' = '36500'
'53071' = '47460'
'53073' = '13380'
'53075' = '39420'
'53077' = '49420'
'54003' = '25180'
'54005' = '16620'
'54009' = '48260'
'54011' = '26580'
'54015' = '16620'
'54017' = '17220'
'54019' = '36060'
'54027' = '49020'
'54029' = '48260'
'54033' = '17220'
'54037' = '47900'
'54039' = '16620'
'54043' = '16620'
'54049' = '21900'
'54051' = '48540'
'54053' = '38580'
'54055' = '14140'
'54057' = '19060'
'54061' = '34060'
'54065' = '25180'
'54069' = '48540'
'54073' = '37620'
'54077' = '34060'
'54079' = '16620'
'54081' = '13220'
'54091' = '17220'
'54099' = '26580'
'54105' = '37620'
'54107' = '37620'
'55009' = '24580'
'55015' = '11540'
'55017' = '20740'
'55021' = '31540'
'55025' = '31540'
'55027' = '13180'
'55031' = '20260'
'55033' = '32860'
'55035' = '20740'
'55037' = '27020'
'55039' = '22540'
'55043' = '38420'
'55045' = '33820'
'55049' = '31540'
'55055' = '48020'
'55059' = '16980'
'55061' = '24580'
'55063' = '29100'
'55069' = '32980'
'55071' = '31820'
'55073' = '48140'
'55075' = '31940'
'55079' = '33340'
'55083' = '24580'
'55087' = '11540'
'55089' = '33340'
'55093' = '33460'
'55097' = '44620'
'55101' = '39540'
'55105' = '27500'
'55109' = '33460'
'55111' = '12660'
'55117' = '43100'
'55127' = '48580'
'55131' = '33340'
'55133' = '33340'
'55139' = '36780'
'55141' = '49220'
'56001' = '29660'
'56005' = '23940'
'56013' = '40180'
'56021' = '16940'
'56025' = '16220'
'56033' = '43260'
'56037' = '40540'
'56039' = '27220'
'56041' = '21740'
;
 
/* --------------------------------------------------------------- */
/* ---   FORMAT FOR AGE STRATIFIERS                            --- */
/* ---   PROGRAM 3. ASSIGNS ARRAY INDEX FOR AGE CATEGORIES     --- */
/* --------------------------------------------------------------- */
 
value AGEFMT
low - 4 = 1
5 -  9 = 2
10 - 14 = 3
15 - 17 = 4
18 - 24 = 5
25 - 29 = 6
30 - 34 = 7
35 - 39 = 8
40 - 44 = 9
45 - 49 = 10
50 - 54 = 11
55 - 59 = 12
60 - 64 = 13
65 - 69 = 14
70 - 74 = 15
75 - 79 = 16
80 - 84 = 17
85 - high = 18
;
 
/* -------------------------------------------------------------- */
/* ---   FORMATS FOR DRG STRATIFIERS                          --- */
/* ---   PROGRAM 3. ASSIGNS ARRAY INDEX FOR DRG CATEGORIES    --- */
/* -------------------------------------------------------------- */
 
/* MS-DRG TO MODIFIED DRG */
 
value $DRGF2T
001 = 7701
002 = 7701
003 = 7799
004 = 7799
005 = 7702
006 = 7702
007 = 7703
008 = 7704
009 = 7705
010 = 7706
011 = 7799
012 = 7799
013 = 7799
014 = 7705
015 = 7705
016 = 7705
017 = 7705
020 = 0101
021 = 0101
022 = 0101
023 = 0102
024 = 0102
025 = 0103
026 = 0103
027 = 0103
028 = 0104
029 = 0104
030 = 0104
031 = 0105
032 = 0105
033 = 0105
034 = 0106
035 = 0106
036 = 0106
037 = 0107
038 = 0107
039 = 0107
040 = 0108
041 = 0108
042 = 0108
052 = 0109
053 = 0109
054 = 0110
055 = 0110
056 = 0111
057 = 0111
058 = 0112
059 = 0112
060 = 0112
061 = 0113
062 = 0113
063 = 0113
064 = 0114
065 = 0114
066 = 0114
067 = 0115
068 = 0115
069 = 0116
070 = 0117
071 = 0117
072 = 0117
073 = 0118
074 = 0118
075 = 0119
076 = 0119
077 = 0120
078 = 0120
079 = 0120
080 = 0121
081 = 0121
082 = 0122
083 = 0122
084 = 0122
085 = 0123
086 = 0123
087 = 0123
088 = 0124
089 = 0124
090 = 0124
091 = 0125
092 = 0125
093 = 0125
094 = 0126
095 = 0126
096 = 0126
097 = 0127
098 = 0127
099 = 0127
100 = 0128
101 = 0128
102 = 0129
103 = 0129
113 = 0201
114 = 0201
115 = 0202
116 = 0203
117 = 0203
121 = 0204
122 = 0204
123 = 0205
124 = 0206
125 = 0206
129 = 0301
130 = 0301
131 = 0301
132 = 0301
133 = 0302
134 = 0302
135 = 0303
136 = 0303
137 = 0304
138 = 0304
139 = 0305
146 = 0306
147 = 0306
148 = 0306
149 = 0307
150 = 0308
151 = 0308
152 = 0309
153 = 0309
154 = 0310
155 = 0310
156 = 0310
157 = 0311
158 = 0311
159 = 0311
163 = 0401
164 = 0401
165 = 0401
166 = 0402
167 = 0402
168 = 0402
175 = 0403
176 = 0403
177 = 0404
178 = 0404
179 = 0404
180 = 0405
181 = 0405
182 = 0405
183 = 0406
184 = 0406
185 = 0406
186 = 0407
187 = 0407
188 = 0407
189 = 0408
190 = 0409
191 = 0409
192 = 0409
193 = 0410
194 = 0410
195 = 0410
196 = 0411
197 = 0411
198 = 0411
199 = 0412
200 = 0412
201 = 0412
202 = 0413
203 = 0413
204 = 0414
205 = 0415
206 = 0415
207 = 0416
208 = 0416
215 = 0501
216 = 0503
217 = 0503
218 = 0503
219 = 0503
220 = 0503
221 = 0503
222 = 0504
223 = 0504
224 = 0504
225 = 0504
226 = 0504
227 = 0504
228 = 0505
229 = 0505
230 = 0505
231 = 0506
232 = 0506
233 = 0507
234 = 0507
235 = 0507
236 = 0507
237 = 0508
238 = 0508
239 = 0509
240 = 0509
241 = 0509
242 = 0510
243 = 0510
244 = 0510
245 = 0510
246 = 0511
247 = 0511
248 = 0502
249 = 0502
250 = 0513
251 = 0513
252 = 0514
253 = 0514
254 = 0514
255 = 0515
256 = 0515
257 = 0515
258 = 0516
259 = 0516
260 = 0517
261 = 0517
262 = 0517
263 = 0518
264 = 0519
265 = 0510
266 = 0540
267 = 0540
268 = 0541
269 = 0541
270 = 0542
271 = 0542
272 = 0542
273 = 0543
274 = 0543
280 = 0520
281 = 0520
282 = 0520
283 = 0520
284 = 0520
285 = 0520
286 = 0522
287 = 0522
288 = 0523
289 = 0523
290 = 0523
291 = 0524
292 = 0524
293 = 0524
294 = 0525
295 = 0525
296 = 0526
297 = 0526
298 = 0526
299 = 0527
300 = 0527
301 = 0527
302 = 0528
303 = 0528
304 = 0529
305 = 0529
306 = 0530
307 = 0530
308 = 0531
309 = 0531
310 = 0531
311 = 0532
312 = 0533
313 = 0534
314 = 0535
315 = 0535
316 = 0535
326 = 0601
327 = 0601
328 = 0601
329 = 0602
330 = 0602
331 = 0602
332 = 0603
333 = 0603
334 = 0603
335 = 0604
336 = 0604
337 = 0604
338 = 0605
339 = 0605
340 = 0605
341 = 0606
342 = 0606
343 = 0606
344 = 0607
345 = 0607
346 = 0607
347 = 0608
348 = 0608
349 = 0608
350 = 0609
351 = 0609
352 = 0609
353 = 0610
354 = 0610
355 = 0610
356 = 0611
357 = 0611
358 = 0611
368 = 0612
369 = 0612
370 = 0612
371 = 0613
372 = 0613
373 = 0613
374 = 0614
375 = 0614
376 = 0614
377 = 0615
378 = 0615
379 = 0615
380 = 0616
381 = 0616
382 = 0616
383 = 0617
384 = 0617
385 = 0618
386 = 0618
387 = 0618
388 = 0619
389 = 0619
390 = 0619
391 = 0620
392 = 0620
393 = 0621
394 = 0621
395 = 0621
405 = 0701
406 = 0701
407 = 0701
408 = 0702
409 = 0702
410 = 0702
411 = 0703
412 = 0703
413 = 0703
414 = 0704
415 = 0704
416 = 0704
417 = 0705
418 = 0705
419 = 0705
420 = 0706
421 = 0706
422 = 0706
423 = 0707
424 = 0707
425 = 0707
432 = 0708
433 = 0708
434 = 0708
435 = 0709
436 = 0709
437 = 0709
438 = 0710
439 = 0710
440 = 0710
441 = 0711
442 = 0711
443 = 0711
444 = 0712
445 = 0712
446 = 0712
453 = 0801
454 = 0801
455 = 0801
456 = 0802
457 = 0802
458 = 0802
459 = 0803
460 = 0803
461 = 0804
462 = 0804
463 = 0805
464 = 0805
465 = 0805
466 = 0806
467 = 0806
468 = 0806
469 = 0807
470 = 0807
471 = 0808
472 = 0808
473 = 0808
474 = 0809
475 = 0809
476 = 0809
477 = 0810
478 = 0810
479 = 0810
480 = 0811
481 = 0811
482 = 0811
483 = 0812
484 = 0812
485 = 0813
486 = 0813
487 = 0813
488 = 0814
489 = 0814
490 = 0815
491 = 0815
492 = 0816
493 = 0816
494 = 0816
495 = 0817
496 = 0817
497 = 0817
498 = 0818
499 = 0818
500 = 0819
501 = 0819
502 = 0819
503 = 0820
504 = 0820
505 = 0820
506 = 0821
507 = 0822
508 = 0822
509 = 0823
510 = 0824
511 = 0824
512 = 0824
513 = 0825
514 = 0825
515 = 0826
516 = 0826
517 = 0826
518 = 0815
519 = 0815
520 = 0815
533 = 0827
534 = 0827
535 = 0828
536 = 0828
537 = 0829
538 = 0829
539 = 0830
540 = 0830
541 = 0830
542 = 0831
543 = 0831
544 = 0831
545 = 0832
546 = 0832
547 = 0832
548 = 0833
549 = 0833
550 = 0833
551 = 0834
552 = 0834
553 = 0835
554 = 0835
555 = 0836
556 = 0836
557 = 0837
558 = 0837
559 = 0838
560 = 0838
561 = 0838
562 = 0839
563 = 0839
564 = 0840
565 = 0840
566 = 0840
570 = 0901
571 = 0901
572 = 0901
573 = 0901
574 = 0901
575 = 0901
576 = 0902
577 = 0902
578 = 0902
579 = 0903
580 = 0903
581 = 0903
582 = 0904
583 = 0904
584 = 0905
585 = 0905
592 = 0906
593 = 0906
594 = 0906
595 = 0907
596 = 0907
597 = 0908
598 = 0908
599 = 0908
600 = 0909
601 = 0909
602 = 0910
603 = 0910
604 = 0911
605 = 0911
606 = 0912
607 = 0912
614 = 1001
615 = 1001
616 = 1002
617 = 1002
618 = 1002
619 = 1003
620 = 1003
621 = 1003
622 = 1004
623 = 1004
624 = 1004
625 = 1005
626 = 1005
627 = 1005
628 = 1006
629 = 1006
630 = 1006
637 = 1007
638 = 1007
639 = 1007
640 = 1008
641 = 1008
642 = 1009
643 = 1010
644 = 1010
645 = 1010
652 = 1101
653 = 1102
654 = 1102
655 = 1102
656 = 1103
657 = 1103
658 = 1103
659 = 1104
660 = 1104
661 = 1104
662 = 1105
663 = 1105
664 = 1105
665 = 1106
666 = 1106
667 = 1106
668 = 1107
669 = 1107
670 = 1107
671 = 1108
672 = 1108
673 = 1109
674 = 1109
675 = 1109
682 = 1110
683 = 1110
684 = 1110
685 = 1111
686 = 1112
687 = 1112
688 = 1112
689 = 1113
690 = 1113
691 = 1114
692 = 1114
693 = 1115
694 = 1115
695 = 1116
696 = 1116
697 = 1117
698 = 1118
699 = 1118
700 = 1118
707 = 1201
708 = 1201
709 = 1202
710 = 1202
711 = 1203
712 = 1203
713 = 1204
714 = 1204
715 = 1205
716 = 1205
717 = 1206
718 = 1206
722 = 1207
723 = 1207
724 = 1207
725 = 1208
726 = 1208
727 = 1209
728 = 1209
729 = 1210
730 = 1210
734 = 1301
735 = 1301
736 = 1302
737 = 1302
738 = 1302
739 = 1303
740 = 1303
741 = 1303
742 = 1304
743 = 1304
744 = 1305
745 = 1305
746 = 1306
747 = 1306
748 = 1307
749 = 1308
750 = 1308
754 = 1309
755 = 1309
756 = 1309
757 = 1310
758 = 1310
759 = 1310
760 = 1311
761 = 1311
765 = 1401
766 = 1401
767 = 1402
768 = 1402
769 = 1403
770 = 1404
774 = 1405
775 = 1405
776 = 1406
777 = 1407
778 = 1408
779 = 1409
780 = 1410
781 = 1411
782 = 1412
789 = 1501
790 = 1502
791 = 1503
792 = 1504
793 = 1505
794 = 1506
795 = 1507
799 = 1601
800 = 1601
801 = 1601
802 = 1602
803 = 1602
804 = 1602
808 = 1603
809 = 1603
810 = 1603
811 = 1604
812 = 1604
813 = 1605
814 = 1606
815 = 1606
816 = 1606
820 = 1707
821 = 1707
822 = 1707
823 = 1708
824 = 1708
825 = 1708
826 = 1709
827 = 1709
828 = 1709
829 = 1710
830 = 1710
834 = 1711
835 = 1711
836 = 1711
837 = 1712
838 = 1712
839 = 1712
840 = 1713
841 = 1713
842 = 1713
843 = 1714
844 = 1714
845 = 1714
846 = 1715
847 = 1715
848 = 1715
849 = 1716
853 = 1801
854 = 1801
855 = 1801
856 = 1802
857 = 1802
858 = 1802
862 = 1803
863 = 1803
864 = 1804
865 = 1805
866 = 1805
867 = 1806
868 = 1806
869 = 1806
870 = 1807
871 = 1808
872 = 1808
876 = 1909
880 = 1910
881 = 1911
882 = 1912
883 = 1913
884 = 1914
885 = 1915
886 = 1916
887 = 1917
894 = 2018
895 = 2019
896 = 2020
897 = 2020
901 = 2101
902 = 2101
903 = 2101
904 = 2102
905 = 2102
906 = 2103
907 = 2104
908 = 2104
909 = 2104
913 = 2105
914 = 2105
915 = 2106
916 = 2106
917 = 2107
918 = 2107
919 = 2108
920 = 2108
921 = 2108
922 = 2109
923 = 2109
927 = 2210
928 = 2201
929 = 2201
933 = 2212
934 = 2213
935 = 2214
939 = 2301
940 = 2301
941 = 2301
945 = 2302
946 = 2302
947 = 2303
948 = 2303
949 = 2304
950 = 2304
951 = 2305
955 = 2406
956 = 2407
957 = 2408
958 = 2408
959 = 2408
963 = 2409
964 = 2409
965 = 2409
969 = 2501
970 = 2501
974 = 2502
975 = 2502
976 = 2502
977 = 2503
981 = 8899
982 = 8899
983 = 8899
984 = 8899
985 = 8899
986 = 8899
987 = 8899
988 = 8899
989 = 8899
998 = 8898
999 = 8898
other = 9999
;
 
/* MS-DRG TO MDC */
 
value MDCF2T
001 = 77
002 = 77
003 = 77
004 = 77
005 = 77
006 = 77
007 = 77
008 = 77
009 = 77
010 = 77
011 = 77
012 = 77
013 = 77
014 = 77
015 = 77
016 = 77
017 = 77
020 = 01
021 = 01
022 = 01
023 = 01
024 = 01
025 = 01
026 = 01
027 = 01
028 = 01
029 = 01
030 = 01
031 = 01
032 = 01
033 = 01
034 = 01
035 = 01
036 = 01
037 = 01
038 = 01
039 = 01
040 = 01
041 = 01
042 = 01
052 = 01
053 = 01
054 = 01
055 = 01
056 = 01
057 = 01
058 = 01
059 = 01
060 = 01
061 = 01
062 = 01
063 = 01
064 = 01
065 = 01
066 = 01
067 = 01
068 = 01
069 = 01
070 = 01
071 = 01
072 = 01
073 = 01
074 = 01
075 = 01
076 = 01
077 = 01
078 = 01
079 = 01
080 = 01
081 = 01
082 = 01
083 = 01
084 = 01
085 = 01
086 = 01
087 = 01
088 = 01
089 = 01
090 = 01
091 = 01
092 = 01
093 = 01
094 = 01
095 = 01
096 = 01
097 = 01
098 = 01
099 = 01
100 = 01
101 = 01
102 = 01
103 = 01
113 = 02
114 = 02
115 = 02
116 = 02
117 = 02
121 = 02
122 = 02
123 = 02
124 = 02
125 = 02
129 = 03
130 = 03
131 = 03
132 = 03
133 = 03
134 = 03
135 = 03
136 = 03
137 = 03
138 = 03
139 = 03
146 = 03
147 = 03
148 = 03
149 = 03
150 = 03
151 = 03
152 = 03
153 = 03
154 = 03
155 = 03
156 = 03
157 = 03
158 = 03
159 = 03
163 = 04
164 = 04
165 = 04
166 = 04
167 = 04
168 = 04
175 = 04
176 = 04
177 = 04
178 = 04
179 = 04
180 = 04
181 = 04
182 = 04
183 = 04
184 = 04
185 = 04
186 = 04
187 = 04
188 = 04
189 = 04
190 = 04
191 = 04
192 = 04
193 = 04
194 = 04
195 = 04
196 = 04
197 = 04
198 = 04
199 = 04
200 = 04
201 = 04
202 = 04
203 = 04
204 = 04
205 = 04
206 = 04
207 = 04
208 = 04
215 = 05
216 = 05
217 = 05
218 = 05
219 = 05
220 = 05
221 = 05
222 = 05
223 = 05
224 = 05
225 = 05
226 = 05
227 = 05
228 = 05
229 = 05
230 = 05
231 = 05
232 = 05
233 = 05
234 = 05
235 = 05
236 = 05
237 = 05
238 = 05
239 = 05
240 = 05
241 = 05
242 = 05
243 = 05
244 = 05
245 = 05
246 = 05
247 = 05
248 = 05
249 = 05
250 = 05
251 = 05
252 = 05
253 = 05
254 = 05
255 = 05
256 = 05
257 = 05
258 = 05
259 = 05
260 = 05
261 = 05
262 = 05
263 = 05
264 = 05
265 = 05
266 = 05
267 = 05
268 = 05
269 = 05
270 = 05
271 = 05
272 = 05
273 = 05
274 = 05
280 = 05
281 = 05
282 = 05
283 = 05
284 = 05
285 = 05
286 = 05
287 = 05
288 = 05
289 = 05
290 = 05
291 = 05
292 = 05
293 = 05
294 = 05
295 = 05
296 = 05
297 = 05
298 = 05
299 = 05
300 = 05
301 = 05
302 = 05
303 = 05
304 = 05
305 = 05
306 = 05
307 = 05
308 = 05
309 = 05
310 = 05
311 = 05
312 = 05
313 = 05
314 = 05
315 = 05
316 = 05
326 = 06
327 = 06
328 = 06
329 = 06
330 = 06
331 = 06
332 = 06
333 = 06
334 = 06
335 = 06
336 = 06
337 = 06
338 = 06
339 = 06
340 = 06
341 = 06
342 = 06
343 = 06
344 = 06
345 = 06
346 = 06
347 = 06
348 = 06
349 = 06
350 = 06
351 = 06
352 = 06
353 = 06
354 = 06
355 = 06
356 = 06
357 = 06
358 = 06
368 = 06
369 = 06
370 = 06
371 = 06
372 = 06
373 = 06
374 = 06
375 = 06
376 = 06
377 = 06
378 = 06
379 = 06
380 = 06
381 = 06
382 = 06
383 = 06
384 = 06
385 = 06
386 = 06
387 = 06
388 = 06
389 = 06
390 = 06
391 = 06
392 = 06
393 = 06
394 = 06
395 = 06
405 = 07
406 = 07
407 = 07
408 = 07
409 = 07
410 = 07
411 = 07
412 = 07
413 = 07
414 = 07
415 = 07
416 = 07
417 = 07
418 = 07
419 = 07
420 = 07
421 = 07
422 = 07
423 = 07
424 = 07
425 = 07
432 = 07
433 = 07
434 = 07
435 = 07
436 = 07
437 = 07
438 = 07
439 = 07
440 = 07
441 = 07
442 = 07
443 = 07
444 = 07
445 = 07
446 = 07
453 = 08
454 = 08
455 = 08
456 = 08
457 = 08
458 = 08
459 = 08
460 = 08
461 = 08
462 = 08
463 = 08
464 = 08
465 = 08
466 = 08
467 = 08
468 = 08
469 = 08
470 = 08
471 = 08
472 = 08
473 = 08
474 = 08
475 = 08
476 = 08
477 = 08
478 = 08
479 = 08
480 = 08
481 = 08
482 = 08
483 = 08
484 = 08
485 = 08
486 = 08
487 = 08
488 = 08
489 = 08
490 = 08
491 = 08
492 = 08
493 = 08
494 = 08
495 = 08
496 = 08
497 = 08
498 = 08
499 = 08
500 = 08
501 = 08
502 = 08
503 = 08
504 = 08
505 = 08
506 = 08
507 = 08
508 = 08
509 = 08
510 = 08
511 = 08
512 = 08
513 = 08
514 = 08
515 = 08
516 = 08
517 = 08
518 = 08
519 = 08
520 = 08
533 = 08
534 = 08
535 = 08
536 = 08
537 = 08
538 = 08
539 = 08
540 = 08
541 = 08
542 = 08
543 = 08
544 = 08
545 = 08
546 = 08
547 = 08
548 = 08
549 = 08
550 = 08
551 = 08
552 = 08
553 = 08
554 = 08
555 = 08
556 = 08
557 = 08
558 = 08
559 = 08
560 = 08
561 = 08
562 = 08
563 = 08
564 = 08
565 = 08
566 = 08
570 = 09
571 = 09
572 = 09
573 = 09
574 = 09
575 = 09
576 = 09
577 = 09
578 = 09
579 = 09
580 = 09
581 = 09
582 = 09
583 = 09
584 = 09
585 = 09
592 = 09
593 = 09
594 = 09
595 = 09
596 = 09
597 = 09
598 = 09
599 = 09
600 = 09
601 = 09
602 = 09
603 = 09
604 = 09
605 = 09
606 = 09
607 = 09
614 = 10
615 = 10
616 = 10
617 = 10
618 = 10
619 = 10
620 = 10
621 = 10
622 = 10
623 = 10
624 = 10
625 = 10
626 = 10
627 = 10
628 = 10
629 = 10
630 = 10
637 = 10
638 = 10
639 = 10
640 = 10
641 = 10
642 = 10
643 = 10
644 = 10
645 = 10
652 = 11
653 = 11
654 = 11
655 = 11
656 = 11
657 = 11
658 = 11
659 = 11
660 = 11
661 = 11
662 = 11
663 = 11
664 = 11
665 = 11
666 = 11
667 = 11
668 = 11
669 = 11
670 = 11
671 = 11
672 = 11
673 = 11
674 = 11
675 = 11
682 = 11
683 = 11
684 = 11
685 = 11
686 = 11
687 = 11
688 = 11
689 = 11
690 = 11
691 = 11
692 = 11
693 = 11
694 = 11
695 = 11
696 = 11
697 = 11
698 = 11
699 = 11
700 = 11
707 = 12
708 = 12
709 = 12
710 = 12
711 = 12
712 = 12
713 = 12
714 = 12
715 = 12
716 = 12
717 = 12
718 = 12
722 = 12
723 = 12
724 = 12
725 = 12
726 = 12
727 = 12
728 = 12
729 = 12
730 = 12
734 = 13
735 = 13
736 = 13
737 = 13
738 = 13
739 = 13
740 = 13
741 = 13
742 = 13
743 = 13
744 = 13
745 = 13
746 = 13
747 = 13
748 = 13
749 = 13
750 = 13
754 = 13
755 = 13
756 = 13
757 = 13
758 = 13
759 = 13
760 = 13
761 = 13
765 = 14
766 = 14
767 = 14
768 = 14
769 = 14
770 = 14
774 = 14
775 = 14
776 = 14
777 = 14
778 = 14
779 = 14
780 = 14
781 = 14
782 = 14
789 = 15
790 = 15
791 = 15
792 = 15
793 = 15
794 = 15
795 = 15
799 = 16
800 = 16
801 = 16
802 = 16
803 = 16
804 = 16
808 = 16
809 = 16
810 = 16
811 = 16
812 = 16
813 = 16
814 = 16
815 = 16
816 = 16
820 = 17
821 = 17
822 = 17
823 = 17
824 = 17
825 = 17
826 = 17
827 = 17
828 = 17
829 = 17
830 = 17
834 = 17
835 = 17
836 = 17
837 = 17
838 = 17
839 = 17
840 = 17
841 = 17
842 = 17
843 = 17
844 = 17
845 = 17
846 = 17
847 = 17
848 = 17
849 = 17
853 = 18
854 = 18
855 = 18
856 = 18
857 = 18
858 = 18
862 = 18
863 = 18
864 = 18
865 = 18
866 = 18
867 = 18
868 = 18
869 = 18
870 = 18
871 = 18
872 = 18
876 = 19
880 = 19
881 = 19
882 = 19
883 = 19
884 = 19
885 = 19
886 = 19
887 = 19
894 = 20
895 = 20
896 = 20
897 = 20
901 = 21
902 = 21
903 = 21
904 = 21
905 = 21
906 = 21
907 = 21
908 = 21
909 = 21
913 = 21
914 = 21
915 = 21
916 = 21
917 = 21
918 = 21
919 = 21
920 = 21
921 = 21
922 = 21
923 = 21
927 = 22
928 = 22
929 = 22
933 = 22
934 = 22
935 = 22
939 = 23
940 = 23
941 = 23
945 = 23
946 = 23
947 = 23
948 = 23
949 = 23
950 = 23
951 = 23
955 = 24
956 = 24
957 = 24
958 = 24
959 = 24
963 = 24
964 = 24
965 = 24
969 = 25
970 = 25
974 = 25
975 = 25
976 = 25
977 = 25
981 = 88
982 = 88
983 = 88
984 = 88
985 = 88
986 = 88
987 = 88
988 = 88
989 = 88
998 = 88
999 = 88
OTHER  = 99
;

/*Present On Admission Exempt ICD-10-CM Diagnosis Codes 2016*/
value $poaxmpt_v33fmt
'B900'
,'B901'
,'B902'
,'B908'
,'B909'
,'B91'
,'B92'
,'B940'
,'B941'
,'B942'
,'B948'
,'B949'
,'E640'
,'E641'
,'E642'
,'E643'
,'E648'
,'E649'
,'I252'
,'I6900'
,'I6901'
,'I69020'
,'I69021'
,'I69022'
,'I69023'
,'I69028'
,'I69031'
,'I69032'
,'I69033'
,'I69034'
,'I69039'
,'I69041'
,'I69042'
,'I69043'
,'I69044'
,'I69049'
,'I69051'
,'I69052'
,'I69053'
,'I69054'
,'I69059'
,'I69061'
,'I69062'
,'I69063'
,'I69064'
,'I69065'
,'I69069'
,'I69090'
,'I69091'
,'I69092'
,'I69093'
,'I69098'
,'I6910'
,'I6911'
,'I69120'
,'I69121'
,'I69122'
,'I69123'
,'I69128'
,'I69131'
,'I69132'
,'I69133'
,'I69134'
,'I69139'
,'I69141'
,'I69142'
,'I69143'
,'I69144'
,'I69149'
,'I69151'
,'I69152'
,'I69153'
,'I69154'
,'I69159'
,'I69161'
,'I69162'
,'I69163'
,'I69164'
,'I69165'
,'I69169'
,'I69190'
,'I69191'
,'I69192'
,'I69193'
,'I69198'
,'I6920'
,'I6921'
,'I69220'
,'I69221'
,'I69222'
,'I69223'
,'I69228'
,'I69231'
,'I69232'
,'I69233'
,'I69234'
,'I69239'
,'I69241'
,'I69242'
,'I69243'
,'I69244'
,'I69249'
,'I69251'
,'I69252'
,'I69253'
,'I69254'
,'I69259'
,'I69261'
,'I69262'
,'I69263'
,'I69264'
,'I69265'
,'I69269'
,'I69290'
,'I69291'
,'I69292'
,'I69293'
,'I69298'
,'I6930'
,'I6931'
,'I69320'
,'I69321'
,'I69322'
,'I69323'
,'I69328'
,'I69331'
,'I69332'
,'I69333'
,'I69334'
,'I69339'
,'I69341'
,'I69342'
,'I69343'
,'I69344'
,'I69349'
,'I69351'
,'I69352'
,'I69353'
,'I69354'
,'I69359'
,'I69361'
,'I69362'
,'I69363'
,'I69364'
,'I69365'
,'I69369'
,'I69390'
,'I69391'
,'I69392'
,'I69393'
,'I69398'
,'I6980'
,'I6981'
,'I69820'
,'I69821'
,'I69822'
,'I69823'
,'I69828'
,'I69831'
,'I69832'
,'I69833'
,'I69834'
,'I69839'
,'I69841'
,'I69842'
,'I69843'
,'I69844'
,'I69849'
,'I69851'
,'I69852'
,'I69853'
,'I69854'
,'I69859'
,'I69861'
,'I69862'
,'I69863'
,'I69864'
,'I69865'
,'I69869'
,'I69890'
,'I69891'
,'I69892'
,'I69893'
,'I69898'
,'I6990'
,'I6991'
,'I69920'
,'I69921'
,'I69922'
,'I69923'
,'I69928'
,'I69931'
,'I69932'
,'I69933'
,'I69934'
,'I69939'
,'I69941'
,'I69942'
,'I69943'
,'I69944'
,'I69949'
,'I69951'
,'I69952'
,'I69953'
,'I69954'
,'I69959'
,'I69961'
,'I69962'
,'I69963'
,'I69964'
,'I69965'
,'I69969'
,'I69990'
,'I69991'
,'I69992'
,'I69993'
,'I69998'
,'O0900'
,'O0901'
,'O0902'
,'O0903'
,'O0910'
,'O0911'
,'O0912'
,'O0913'
,'O09211'
,'O09212'
,'O09213'
,'O09219'
,'O09291'
,'O09292'
,'O09293'
,'O09299'
,'O0930'
,'O0931'
,'O0932'
,'O0933'
,'O0940'
,'O0941'
,'O0942'
,'O0943'
,'O09511'
,'O09512'
,'O09513'
,'O09519'
,'O09521'
,'O09522'
,'O09523'
,'O09529'
,'O09611'
,'O09612'
,'O09613'
,'O09619'
,'O09621'
,'O09622'
,'O09623'
,'O09629'
,'O0970'
,'O0971'
,'O0972'
,'O0973'
,'O09811'
,'O09812'
,'O09813'
,'O09819'
,'O09821'
,'O09822'
,'O09823'
,'O09829'
,'O09891'
,'O09892'
,'O09893'
,'O09899'
,'O0990'
,'O0991'
,'O0992'
,'O0993'
,'O665'
,'O80'
,'O94'
,'P000'
,'P001'
,'P002'
,'P003'
,'P004'
,'P005'
,'P006'
,'P007'
,'P0081'
,'P0089'
,'P009'
,'Q000'
,'Q001'
,'Q002'
,'Q010'
,'Q011'
,'Q012'
,'Q018'
,'Q019'
,'Q02'
,'Q030'
,'Q031'
,'Q038'
,'Q039'
,'Q040'
,'Q041'
,'Q042'
,'Q043'
,'Q044'
,'Q045'
,'Q046'
,'Q048'
,'Q049'
,'Q050'
,'Q051'
,'Q052'
,'Q053'
,'Q054'
,'Q055'
,'Q056'
,'Q057'
,'Q058'
,'Q059'
,'Q060'
,'Q061'
,'Q062'
,'Q063'
,'Q064'
,'Q068'
,'Q069'
,'Q0700'
,'Q0701'
,'Q0702'
,'Q0703'
,'Q078'
,'Q079'
,'Q100'
,'Q101'
,'Q102'
,'Q103'
,'Q104'
,'Q105'
,'Q106'
,'Q107'
,'Q110'
,'Q111'
,'Q112'
,'Q113'
,'Q120'
,'Q121'
,'Q122'
,'Q123'
,'Q124'
,'Q128'
,'Q129'
,'Q130'
,'Q131'
,'Q132'
,'Q133'
,'Q134'
,'Q135'
,'Q1381'
,'Q1389'
,'Q139'
,'Q140'
,'Q141'
,'Q142'
,'Q143'
,'Q148'
,'Q149'
,'Q150'
,'Q158'
,'Q159'
,'Q160'
,'Q161'
,'Q162'
,'Q163'
,'Q164'
,'Q165'
,'Q169'
,'Q170'
,'Q171'
,'Q172'
,'Q173'
,'Q174'
,'Q175'
,'Q178'
,'Q179'
,'Q180'
,'Q181'
,'Q182'
,'Q183'
,'Q184'
,'Q185'
,'Q186'
,'Q187'
,'Q188'
,'Q189'
,'Q200'
,'Q201'
,'Q202'
,'Q203'
,'Q204'
,'Q205'
,'Q206'
,'Q208'
,'Q209'
,'Q210'
,'Q211'
,'Q212'
,'Q213'
,'Q214'
,'Q218'
,'Q219'
,'Q220'
,'Q221'
,'Q222'
,'Q223'
,'Q224'
,'Q225'
,'Q226'
,'Q228'
,'Q229'
,'Q230'
,'Q231'
,'Q232'
,'Q233'
,'Q234'
,'Q238'
,'Q239'
,'Q240'
,'Q241'
,'Q242'
,'Q243'
,'Q244'
,'Q245'
,'Q246'
,'Q248'
,'Q249'
,'Q250'
,'Q251'
,'Q252'
,'Q253'
,'Q254'
,'Q255'
,'Q256'
,'Q2571'
,'Q2572'
,'Q2579'
,'Q258'
,'Q259'
,'Q260'
,'Q261'
,'Q262'
,'Q263'
,'Q264'
,'Q265'
,'Q266'
,'Q268'
,'Q269'
,'Q270'
,'Q271'
,'Q272'
,'Q2730'
,'Q2731'
,'Q2732'
,'Q2733'
,'Q2734'
,'Q2739'
,'Q274'
,'Q278'
,'Q279'
,'Q280'
,'Q281'
,'Q282'
,'Q283'
,'Q288'
,'Q289'
,'Q300'
,'Q301'
,'Q302'
,'Q303'
,'Q308'
,'Q309'
,'Q310'
,'Q311'
,'Q312'
,'Q313'
,'Q315'
,'Q318'
,'Q319'
,'Q320'
,'Q321'
,'Q322'
,'Q323'
,'Q324'
,'Q330'
,'Q331'
,'Q332'
,'Q333'
,'Q334'
,'Q335'
,'Q336'
,'Q338'
,'Q339'
,'Q340'
,'Q341'
,'Q348'
,'Q349'
,'Q351'
,'Q353'
,'Q355'
,'Q357'
,'Q359'
,'Q360'
,'Q361'
,'Q369'
,'Q370'
,'Q371'
,'Q372'
,'Q373'
,'Q374'
,'Q375'
,'Q378'
,'Q379'
,'Q380'
,'Q381'
,'Q382'
,'Q383'
,'Q384'
,'Q385'
,'Q386'
,'Q387'
,'Q388'
,'Q390'
,'Q391'
,'Q392'
,'Q393'
,'Q394'
,'Q395'
,'Q396'
,'Q398'
,'Q399'
,'Q400'
,'Q401'
,'Q402'
,'Q403'
,'Q408'
,'Q409'
,'Q410'
,'Q411'
,'Q412'
,'Q418'
,'Q419'
,'Q420'
,'Q421'
,'Q422'
,'Q423'
,'Q428'
,'Q429'
,'Q430'
,'Q431'
,'Q432'
,'Q433'
,'Q434'
,'Q435'
,'Q436'
,'Q437'
,'Q438'
,'Q439'
,'Q440'
,'Q441'
,'Q442'
,'Q443'
,'Q444'
,'Q445'
,'Q446'
,'Q447'
,'Q450'
,'Q451'
,'Q452'
,'Q453'
,'Q458'
,'Q459'
,'Q5001'
,'Q5002'
,'Q501'
,'Q502'
,'Q5031'
,'Q5032'
,'Q5039'
,'Q504'
,'Q505'
,'Q506'
,'Q510'
,'Q5110'
,'Q5111'
,'Q512'
,'Q513'
,'Q514'
,'Q515'
,'Q516'
,'Q517'
,'Q51810'
,'Q51811'
,'Q51818'
,'Q51820'
,'Q51821'
,'Q51828'
,'Q519'
,'Q520'
,'Q5210'
,'Q5211'
,'Q5212'
,'Q522'
,'Q523'
,'Q524'
,'Q525'
,'Q526'
,'Q5270'
,'Q5271'
,'Q5279'
,'Q528'
,'Q529'
,'Q5300'
,'Q5301'
,'Q5302'
,'Q5310'
,'Q5311'
,'Q5312'
,'Q5320'
,'Q5321'
,'Q5322'
,'Q539'
,'Q540'
,'Q541'
,'Q542'
,'Q543'
,'Q544'
,'Q548'
,'Q549'
,'Q550'
,'Q551'
,'Q5520'
,'Q5521'
,'Q5522'
,'Q5523'
,'Q5529'
,'Q553'
,'Q554'
,'Q555'
,'Q5561'
,'Q5562'
,'Q5563'
,'Q5564'
,'Q5569'
,'Q557'
,'Q558'
,'Q559'
,'Q560'
,'Q561'
,'Q562'
,'Q563'
,'Q564'
,'Q600'
,'Q601'
,'Q602'
,'Q603'
,'Q604'
,'Q605'
,'Q606'
,'Q6100'
,'Q6101'
,'Q6102'
,'Q6111'
,'Q6119'
,'Q612'
,'Q613'
,'Q614'
,'Q615'
,'Q618'
,'Q619'
,'Q620'
,'Q6210'
,'Q6211'
,'Q6212'
,'Q622'
,'Q6231'
,'Q6232'
,'Q6239'
,'Q624'
,'Q625'
,'Q6260'
,'Q6261'
,'Q6262'
,'Q6263'
,'Q6269'
,'Q627'
,'Q628'
,'Q630'
,'Q631'
,'Q632'
,'Q633'
,'Q638'
,'Q639'
,'Q640'
,'Q6410'
,'Q6411'
,'Q6412'
,'Q6419'
,'Q642'
,'Q6431'
,'Q6432'
,'Q6433'
,'Q6439'
,'Q644'
,'Q645'
,'Q646'
,'Q6470'
,'Q6471'
,'Q6472'
,'Q6473'
,'Q6474'
,'Q6475'
,'Q6479'
,'Q648'
,'Q649'
,'Q6500'
,'Q6501'
,'Q6502'
,'Q651'
,'Q652'
,'Q6530'
,'Q6531'
,'Q6532'
,'Q654'
,'Q655'
,'Q656'
,'Q6581'
,'Q6582'
,'Q6589'
,'Q659'
,'Q660'
,'Q661'
,'Q662'
,'Q663'
,'Q664'
,'Q6650'
,'Q6651'
,'Q6652'
,'Q666'
,'Q667'
,'Q6680'
,'Q6681'
,'Q6682'
,'Q6689'
,'Q669'
,'Q670'
,'Q671'
,'Q672'
,'Q673'
,'Q674'
,'Q675'
,'Q676'
,'Q677'
,'Q678'
,'Q680'
,'Q681'
,'Q682'
,'Q683'
,'Q684'
,'Q685'
,'Q686'
,'Q688'
,'Q690'
,'Q691'
,'Q692'
,'Q699'
,'Q7000'
,'Q7001'
,'Q7002'
,'Q7003'
,'Q7010'
,'Q7011'
,'Q7012'
,'Q7013'
,'Q7020'
,'Q7021'
,'Q7022'
,'Q7023'
,'Q7030'
,'Q7031'
,'Q7032'
,'Q7033'
,'Q704'
,'Q709'
,'Q7100'
,'Q7101'
,'Q7102'
,'Q7103'
,'Q7110'
,'Q7111'
,'Q7112'
,'Q7113'
,'Q7120'
,'Q7121'
,'Q7122'
,'Q7123'
,'Q7130'
,'Q7131'
,'Q7132'
,'Q7133'
,'Q7140'
,'Q7141'
,'Q7142'
,'Q7143'
,'Q7150'
,'Q7151'
,'Q7152'
,'Q7153'
,'Q7160'
,'Q7161'
,'Q7162'
,'Q7163'
,'Q71811'
,'Q71812'
,'Q71813'
,'Q71819'
,'Q71891'
,'Q71892'
,'Q71893'
,'Q71899'
,'Q7190'
,'Q7191'
,'Q7192'
,'Q7193'
,'Q7200'
,'Q7201'
,'Q7202'
,'Q7203'
,'Q7210'
,'Q7211'
,'Q7212'
,'Q7213'
,'Q7220'
,'Q7221'
,'Q7222'
,'Q7223'
,'Q7230'
,'Q7231'
,'Q7232'
,'Q7233'
,'Q7240'
,'Q7241'
,'Q7242'
,'Q7243'
,'Q7250'
,'Q7251'
,'Q7252'
,'Q7253'
,'Q7260'
,'Q7261'
,'Q7262'
,'Q7263'
,'Q7270'
,'Q7271'
,'Q7272'
,'Q7273'
,'Q72811'
,'Q72812'
,'Q72813'
,'Q72819'
,'Q72891'
,'Q72892'
,'Q72893'
,'Q72899'
,'Q7290'
,'Q7291'
,'Q7292'
,'Q7293'
,'Q730'
,'Q731'
,'Q738'
,'Q740'
,'Q741'
,'Q742'
,'Q743'
,'Q748'
,'Q749'
,'Q750'
,'Q751'
,'Q752'
,'Q753'
,'Q754'
,'Q755'
,'Q758'
,'Q759'
,'Q760'
,'Q761'
,'Q762'
,'Q763'
,'Q76411'
,'Q76412'
,'Q76413'
,'Q76414'
,'Q76415'
,'Q76419'
,'Q76425'
,'Q76426'
,'Q76427'
,'Q76428'
,'Q76429'
,'Q7649'
,'Q765'
,'Q766'
,'Q767'
,'Q768'
,'Q769'
,'Q770'
,'Q771'
,'Q772'
,'Q773'
,'Q774'
,'Q775'
,'Q776'
,'Q777'
,'Q778'
,'Q779'
,'Q780'
,'Q781'
,'Q782'
,'Q783'
,'Q784'
,'Q785'
,'Q786'
,'Q788'
,'Q789'
,'Q790'
,'Q791'
,'Q792'
,'Q793'
,'Q794'
,'Q7951'
,'Q7959'
,'Q796'
,'Q798'
,'Q799'
,'Q800'
,'Q801'
,'Q802'
,'Q803'
,'Q804'
,'Q808'
,'Q809'
,'Q810'
,'Q811'
,'Q812'
,'Q818'
,'Q819'
,'Q820'
,'Q821'
,'Q822'
,'Q823'
,'Q824'
,'Q825'
,'Q828'
,'Q829'
,'Q830'
,'Q831'
,'Q832'
,'Q833'
,'Q838'
,'Q839'
,'Q840'
,'Q841'
,'Q842'
,'Q843'
,'Q844'
,'Q845'
,'Q846'
,'Q848'
,'Q849'
,'Q8500'
,'Q8501'
,'Q8502'
,'Q8503'
,'Q8509'
,'Q851'
,'Q858'
,'Q859'
,'Q860'
,'Q861'
,'Q862'
,'Q868'
,'Q870'
,'Q871'
,'Q872'
,'Q873'
,'Q8740'
,'Q87410'
,'Q87418'
,'Q8742'
,'Q8743'
,'Q875'
,'Q8781'
,'Q8789'
,'Q8901'
,'Q8909'
,'Q891'
,'Q892'
,'Q893'
,'Q894'
,'Q897'
,'Q898'
,'Q899'
,'Q900'
,'Q901'
,'Q902'
,'Q909'
,'Q910'
,'Q911'
,'Q912'
,'Q913'
,'Q914'
,'Q915'
,'Q916'
,'Q917'
,'Q920'
,'Q921'
,'Q922'
,'Q925'
,'Q9261'
,'Q9262'
,'Q927'
,'Q928'
,'Q929'
,'Q930'
,'Q931'
,'Q932'
,'Q933'
,'Q934'
,'Q935'
,'Q937'
,'Q9381'
,'Q9388'
,'Q9389'
,'Q939'
,'Q950'
,'Q951'
,'Q952'
,'Q953'
,'Q955'
,'Q958'
,'Q959'
,'Q960'
,'Q961'
,'Q962'
,'Q963'
,'Q964'
,'Q968'
,'Q969'
,'Q970'
,'Q971'
,'Q972'
,'Q973'
,'Q978'
,'Q979'
,'Q980'
,'Q981'
,'Q983'
,'Q984'
,'Q985'
,'Q986'
,'Q987'
,'Q988'
,'Q989'
,'Q990'
,'Q991'
,'Q992'
,'Q998'
,'Q999'
,'S0000XD'
,'S0000XS'
,'S0001XD'
,'S0001XS'
,'S0002XD'
,'S0002XS'
,'S0003XD'
,'S0003XS'
,'S0004XD'
,'S0004XS'
,'S0005XD'
,'S0005XS'
,'S0006XD'
,'S0006XS'
,'S0007XD'
,'S0007XS'
,'S0010XD'
,'S0010XS'
,'S0011XD'
,'S0011XS'
,'S0012XD'
,'S0012XS'
,'S00201D'
,'S00201S'
,'S00202D'
,'S00202S'
,'S00209D'
,'S00209S'
,'S00211D'
,'S00211S'
,'S00212D'
,'S00212S'
,'S00219D'
,'S00219S'
,'S00221D'
,'S00221S'
,'S00222D'
,'S00222S'
,'S00229D'
,'S00229S'
,'S00241D'
,'S00241S'
,'S00242D'
,'S00242S'
,'S00249D'
,'S00249S'
,'S00251D'
,'S00251S'
,'S00252D'
,'S00252S'
,'S00259D'
,'S00259S'
,'S00261D'
,'S00261S'
,'S00262D'
,'S00262S'
,'S00269D'
,'S00269S'
,'S00271D'
,'S00271S'
,'S00272D'
,'S00272S'
,'S00279D'
,'S00279S'
,'S0030XD'
,'S0030XS'
,'S0031XD'
,'S0031XS'
,'S0032XD'
,'S0032XS'
,'S0033XD'
,'S0033XS'
,'S0034XD'
,'S0034XS'
,'S0035XD'
,'S0035XS'
,'S0036XD'
,'S0036XS'
,'S0037XD'
,'S0037XS'
,'S00401D'
,'S00401S'
,'S00402D'
,'S00402S'
,'S00409D'
,'S00409S'
,'S00411D'
,'S00411S'
,'S00412D'
,'S00412S'
,'S00419D'
,'S00419S'
,'S00421D'
,'S00421S'
,'S00422D'
,'S00422S'
,'S00429D'
,'S00429S'
,'S00431D'
,'S00431S'
,'S00432D'
,'S00432S'
,'S00439D'
,'S00439S'
,'S00441D'
,'S00441S'
,'S00442D'
,'S00442S'
,'S00449D'
,'S00449S'
,'S00451D'
,'S00451S'
,'S00452D'
,'S00452S'
,'S00459D'
,'S00459S'
,'S00461D'
,'S00461S'
,'S00462D'
,'S00462S'
,'S00469D'
,'S00469S'
,'S00471D'
,'S00471S'
,'S00472D'
,'S00472S'
,'S00479D'
,'S00479S'
,'S00501D'
,'S00501S'
,'S00502D'
,'S00502S'
,'S00511D'
,'S00511S'
,'S00512D'
,'S00512S'
,'S00521D'
,'S00521S'
,'S00522D'
,'S00522S'
,'S00531D'
,'S00531S'
,'S00532D'
,'S00532S'
,'S00541D'
,'S00541S'
,'S00542D'
,'S00542S'
,'S00551D'
,'S00551S'
,'S00552D'
,'S00552S'
,'S00561D'
,'S00561S'
,'S00562D'
,'S00562S'
,'S00571D'
,'S00571S'
,'S00572D'
,'S00572S'
,'S0080XD'
,'S0080XS'
,'S0081XD'
,'S0081XS'
,'S0082XD'
,'S0082XS'
,'S0083XD'
,'S0083XS'
,'S0084XD'
,'S0084XS'
,'S0085XD'
,'S0085XS'
,'S0086XD'
,'S0086XS'
,'S0087XD'
,'S0087XS'
,'S0090XD'
,'S0090XS'
,'S0091XD'
,'S0091XS'
,'S0092XD'
,'S0092XS'
,'S0093XD'
,'S0093XS'
,'S0094XD'
,'S0094XS'
,'S0095XD'
,'S0095XS'
,'S0096XD'
,'S0096XS'
,'S0097XD'
,'S0097XS'
,'S0100XD'
,'S0100XS'
,'S0101XD'
,'S0101XS'
,'S0102XD'
,'S0102XS'
,'S0103XD'
,'S0103XS'
,'S0104XD'
,'S0104XS'
,'S0105XD'
,'S0105XS'
,'S01101D'
,'S01101S'
,'S01102D'
,'S01102S'
,'S01109D'
,'S01109S'
,'S01111D'
,'S01111S'
,'S01112D'
,'S01112S'
,'S01119D'
,'S01119S'
,'S01121D'
,'S01121S'
,'S01122D'
,'S01122S'
,'S01129D'
,'S01129S'
,'S01131D'
,'S01131S'
,'S01132D'
,'S01132S'
,'S01139D'
,'S01139S'
,'S01141D'
,'S01141S'
,'S01142D'
,'S01142S'
,'S01149D'
,'S01149S'
,'S01151D'
,'S01151S'
,'S01152D'
,'S01152S'
,'S01159D'
,'S01159S'
,'S0120XD'
,'S0120XS'
,'S0121XD'
,'S0121XS'
,'S0122XD'
,'S0122XS'
,'S0123XD'
,'S0123XS'
,'S0124XD'
,'S0124XS'
,'S0125XD'
,'S0125XS'
,'S01301D'
,'S01301S'
,'S01302D'
,'S01302S'
,'S01309D'
,'S01309S'
,'S01311D'
,'S01311S'
,'S01312D'
,'S01312S'
,'S01319D'
,'S01319S'
,'S01321D'
,'S01321S'
,'S01322D'
,'S01322S'
,'S01329D'
,'S01329S'
,'S01331D'
,'S01331S'
,'S01332D'
,'S01332S'
,'S01339D'
,'S01339S'
,'S01341D'
,'S01341S'
,'S01342D'
,'S01342S'
,'S01349D'
,'S01349S'
,'S01351D'
,'S01351S'
,'S01352D'
,'S01352S'
,'S01359D'
,'S01359S'
,'S01401D'
,'S01401S'
,'S01402D'
,'S01402S'
,'S01409D'
,'S01409S'
,'S01411D'
,'S01411S'
,'S01412D'
,'S01412S'
,'S01419D'
,'S01419S'
,'S01421D'
,'S01421S'
,'S01422D'
,'S01422S'
,'S01429D'
,'S01429S'
,'S01431D'
,'S01431S'
,'S01432D'
,'S01432S'
,'S01439D'
,'S01439S'
,'S01441D'
,'S01441S'
,'S01442D'
,'S01442S'
,'S01449D'
,'S01449S'
,'S01451D'
,'S01451S'
,'S01452D'
,'S01452S'
,'S01459D'
,'S01459S'
,'S01501D'
,'S01501S'
,'S01502D'
,'S01502S'
,'S01511D'
,'S01511S'
,'S01512D'
,'S01512S'
,'S01521D'
,'S01521S'
,'S01522D'
,'S01522S'
,'S01531D'
,'S01531S'
,'S01532D'
,'S01532S'
,'S01541D'
,'S01541S'
,'S01542D'
,'S01542S'
,'S01551D'
,'S01551S'
,'S01552D'
,'S01552S'
,'S0180XD'
,'S0180XS'
,'S0181XD'
,'S0181XS'
,'S0182XD'
,'S0182XS'
,'S0183XD'
,'S0183XS'
,'S0184XD'
,'S0184XS'
,'S0185XD'
,'S0185XS'
,'S0190XD'
,'S0190XS'
,'S0191XD'
,'S0191XS'
,'S0192XD'
,'S0192XS'
,'S0193XD'
,'S0193XS'
,'S0194XD'
,'S0194XS'
,'S0195XD'
,'S0195XS'
,'S020XXD'
,'S020XXG'
,'S020XXK'
,'S020XXS'
,'S0210XD'
,'S0210XG'
,'S0210XK'
,'S0210XS'
,'S02110D'
,'S02110G'
,'S02110K'
,'S02110S'
,'S02111D'
,'S02111G'
,'S02111K'
,'S02111S'
,'S02112D'
,'S02112G'
,'S02112K'
,'S02112S'
,'S02113D'
,'S02113G'
,'S02113K'
,'S02113S'
,'S02118D'
,'S02118G'
,'S02118K'
,'S02118S'
,'S02119D'
,'S02119G'
,'S02119K'
,'S02119S'
,'S0219XD'
,'S0219XG'
,'S0219XK'
,'S0219XS'
,'S022XXD'
,'S022XXG'
,'S022XXK'
,'S022XXS'
,'S023XXD'
,'S023XXG'
,'S023XXK'
,'S023XXS'
,'S02400D'
,'S02400G'
,'S02400K'
,'S02400S'
,'S02401D'
,'S02401G'
,'S02401K'
,'S02401S'
,'S02402D'
,'S02402G'
,'S02402K'
,'S02402S'
,'S02411D'
,'S02411G'
,'S02411K'
,'S02411S'
,'S02412D'
,'S02412G'
,'S02412K'
,'S02412S'
,'S02413D'
,'S02413G'
,'S02413K'
,'S02413S'
,'S0242XD'
,'S0242XG'
,'S0242XK'
,'S0242XS'
,'S025XXD'
,'S025XXG'
,'S025XXK'
,'S025XXS'
,'S02600D'
,'S02600G'
,'S02600K'
,'S02600S'
,'S02609D'
,'S02609G'
,'S02609K'
,'S02609S'
,'S0261XD'
,'S0261XG'
,'S0261XK'
,'S0261XS'
,'S0262XD'
,'S0262XG'
,'S0262XK'
,'S0262XS'
,'S0263XD'
,'S0263XG'
,'S0263XK'
,'S0263XS'
,'S0264XD'
,'S0264XG'
,'S0264XK'
,'S0264XS'
,'S0265XD'
,'S0265XG'
,'S0265XK'
,'S0265XS'
,'S0266XD'
,'S0266XG'
,'S0266XK'
,'S0266XS'
,'S0267XD'
,'S0267XG'
,'S0267XK'
,'S0267XS'
,'S0269XD'
,'S0269XG'
,'S0269XK'
,'S0269XS'
,'S028XXD'
,'S028XXG'
,'S028XXK'
,'S028XXS'
,'S0291XD'
,'S0291XG'
,'S0291XK'
,'S0291XS'
,'S0292XD'
,'S0292XG'
,'S0292XK'
,'S0292XS'
,'S030XXD'
,'S030XXS'
,'S031XXD'
,'S031XXS'
,'S032XXD'
,'S032XXS'
,'S034XXD'
,'S034XXS'
,'S038XXD'
,'S038XXS'
,'S039XXD'
,'S039XXS'
,'S04011D'
,'S04011S'
,'S04012D'
,'S04012S'
,'S04019D'
,'S04019S'
,'S0402XD'
,'S0402XS'
,'S04031D'
,'S04031S'
,'S04032D'
,'S04032S'
,'S04039D'
,'S04039S'
,'S04041D'
,'S04041S'
,'S04042D'
,'S04042S'
,'S04049D'
,'S04049S'
,'S0410XD'
,'S0410XS'
,'S0411XD'
,'S0411XS'
,'S0412XD'
,'S0412XS'
,'S0420XD'
,'S0420XS'
,'S0421XD'
,'S0421XS'
,'S0422XD'
,'S0422XS'
,'S0430XD'
,'S0430XS'
,'S0431XD'
,'S0431XS'
,'S0432XD'
,'S0432XS'
,'S0440XD'
,'S0440XS'
,'S0441XD'
,'S0441XS'
,'S0442XD'
,'S0442XS'
,'S0450XD'
,'S0450XS'
,'S0451XD'
,'S0451XS'
,'S0452XD'
,'S0452XS'
,'S0460XD'
,'S0460XS'
,'S0461XD'
,'S0461XS'
,'S0462XD'
,'S0462XS'
,'S0470XD'
,'S0470XS'
,'S0471XD'
,'S0471XS'
,'S0472XD'
,'S0472XS'
,'S04811D'
,'S04811S'
,'S04812D'
,'S04812S'
,'S04819D'
,'S04819S'
,'S04891D'
,'S04891S'
,'S04892D'
,'S04892S'
,'S04899D'
,'S04899S'
,'S049XXD'
,'S049XXS'
,'S0500XD'
,'S0500XS'
,'S0501XD'
,'S0501XS'
,'S0502XD'
,'S0502XS'
,'S0510XD'
,'S0510XS'
,'S0511XD'
,'S0511XS'
,'S0512XD'
,'S0512XS'
,'S0520XD'
,'S0520XS'
,'S0521XD'
,'S0521XS'
,'S0522XD'
,'S0522XS'
,'S0530XD'
,'S0530XS'
,'S0531XD'
,'S0531XS'
,'S0532XD'
,'S0532XS'
,'S0540XD'
,'S0540XS'
,'S0541XD'
,'S0541XS'
,'S0542XD'
,'S0542XS'
,'S0550XD'
,'S0550XS'
,'S0551XD'
,'S0551XS'
,'S0552XD'
,'S0552XS'
,'S0560XD'
,'S0560XS'
,'S0561XD'
,'S0561XS'
,'S0562XD'
,'S0562XS'
,'S0570XD'
,'S0570XS'
,'S0571XD'
,'S0571XS'
,'S0572XD'
,'S0572XS'
,'S058X1D'
,'S058X1S'
,'S058X2D'
,'S058X2S'
,'S058X9D'
,'S058X9S'
,'S0590XD'
,'S0590XS'
,'S0591XD'
,'S0591XS'
,'S0592XD'
,'S0592XS'
,'S060X0D'
,'S060X0S'
,'S060X1D'
,'S060X1S'
,'S060X2D'
,'S060X2S'
,'S060X3D'
,'S060X3S'
,'S060X4D'
,'S060X4S'
,'S060X5D'
,'S060X5S'
,'S060X6D'
,'S060X6S'
,'S060X7D'
,'S060X7S'
,'S060X8D'
,'S060X8S'
,'S060X9D'
,'S060X9S'
,'S061X0D'
,'S061X0S'
,'S061X1D'
,'S061X1S'
,'S061X2D'
,'S061X2S'
,'S061X3D'
,'S061X3S'
,'S061X4D'
,'S061X4S'
,'S061X5D'
,'S061X5S'
,'S061X6D'
,'S061X6S'
,'S061X7D'
,'S061X7S'
,'S061X8D'
,'S061X8S'
,'S061X9D'
,'S061X9S'
,'S062X0D'
,'S062X0S'
,'S062X1D'
,'S062X1S'
,'S062X2D'
,'S062X2S'
,'S062X3D'
,'S062X3S'
,'S062X4D'
,'S062X4S'
,'S062X5D'
,'S062X5S'
,'S062X6D'
,'S062X6S'
,'S062X7D'
,'S062X7S'
,'S062X8D'
,'S062X8S'
,'S062X9D'
,'S062X9S'
,'S06300D'
,'S06300S'
,'S06301D'
,'S06301S'
,'S06302D'
,'S06302S'
,'S06303D'
,'S06303S'
,'S06304D'
,'S06304S'
,'S06305D'
,'S06305S'
,'S06306D'
,'S06306S'
,'S06307D'
,'S06307S'
,'S06308D'
,'S06308S'
,'S06309D'
,'S06309S'
,'S06310D'
,'S06310S'
,'S06311D'
,'S06311S'
,'S06312D'
,'S06312S'
,'S06313D'
,'S06313S'
,'S06314D'
,'S06314S'
,'S06315D'
,'S06315S'
,'S06316D'
,'S06316S'
,'S06317D'
,'S06317S'
,'S06318D'
,'S06318S'
,'S06319D'
,'S06319S'
,'S06320D'
,'S06320S'
,'S06321D'
,'S06321S'
,'S06322D'
,'S06322S'
,'S06323D'
,'S06323S'
,'S06324D'
,'S06324S'
,'S06325D'
,'S06325S'
,'S06326D'
,'S06326S'
,'S06327D'
,'S06327S'
,'S06328D'
,'S06328S'
,'S06329D'
,'S06329S'
,'S06330D'
,'S06330S'
,'S06331D'
,'S06331S'
,'S06332D'
,'S06332S'
,'S06333D'
,'S06333S'
,'S06334D'
,'S06334S'
,'S06335D'
,'S06335S'
,'S06336D'
,'S06336S'
,'S06337D'
,'S06337S'
,'S06338D'
,'S06338S'
,'S06339D'
,'S06339S'
,'S06340D'
,'S06340S'
,'S06341D'
,'S06341S'
,'S06342D'
,'S06342S'
,'S06343D'
,'S06343S'
,'S06344D'
,'S06344S'
,'S06345D'
,'S06345S'
,'S06346D'
,'S06346S'
,'S06347D'
,'S06347S'
,'S06348D'
,'S06348S'
,'S06349D'
,'S06349S'
,'S06350D'
,'S06350S'
,'S06351D'
,'S06351S'
,'S06352D'
,'S06352S'
,'S06353D'
,'S06353S'
,'S06354D'
,'S06354S'
,'S06355D'
,'S06355S'
,'S06356D'
,'S06356S'
,'S06357D'
,'S06357S'
,'S06358D'
,'S06358S'
,'S06359D'
,'S06359S'
,'S06360D'
,'S06360S'
,'S06361D'
,'S06361S'
,'S06362D'
,'S06362S'
,'S06363D'
,'S06363S'
,'S06364D'
,'S06364S'
,'S06365D'
,'S06365S'
,'S06366D'
,'S06366S'
,'S06367D'
,'S06367S'
,'S06368D'
,'S06368S'
,'S06369D'
,'S06369S'
,'S06370D'
,'S06370S'
,'S06371D'
,'S06371S'
,'S06372D'
,'S06372S'
,'S06373D'
,'S06373S'
,'S06374D'
,'S06374S'
,'S06375D'
,'S06375S'
,'S06376D'
,'S06376S'
,'S06377D'
,'S06377S'
,'S06378D'
,'S06378S'
,'S06379D'
,'S06379S'
,'S06380D'
,'S06380S'
,'S06381D'
,'S06381S'
,'S06382D'
,'S06382S'
,'S06383D'
,'S06383S'
,'S06384D'
,'S06384S'
,'S06385D'
,'S06385S'
,'S06386D'
,'S06386S'
,'S06387D'
,'S06387S'
,'S06388D'
,'S06388S'
,'S06389D'
,'S06389S'
,'S064X0D'
,'S064X0S'
,'S064X1D'
,'S064X1S'
,'S064X2D'
,'S064X2S'
,'S064X3D'
,'S064X3S'
,'S064X4D'
,'S064X4S'
,'S064X5D'
,'S064X5S'
,'S064X6D'
,'S064X6S'
,'S064X7D'
,'S064X7S'
,'S064X8D'
,'S064X8S'
,'S064X9D'
,'S064X9S'
,'S065X0D'
,'S065X0S'
,'S065X1D'
,'S065X1S'
,'S065X2D'
,'S065X2S'
,'S065X3D'
,'S065X3S'
,'S065X4D'
,'S065X4S'
,'S065X5D'
,'S065X5S'
,'S065X6D'
,'S065X6S'
,'S065X7D'
,'S065X7S'
,'S065X8D'
,'S065X8S'
,'S065X9D'
,'S065X9S'
,'S066X0D'
,'S066X0S'
,'S066X1D'
,'S066X1S'
,'S066X2D'
,'S066X2S'
,'S066X3D'
,'S066X3S'
,'S066X4D'
,'S066X4S'
,'S066X5D'
,'S066X5S'
,'S066X6D'
,'S066X6S'
,'S066X7D'
,'S066X7S'
,'S066X8D'
,'S066X8S'
,'S066X9D'
,'S066X9S'
,'S06810D'
,'S06810S'
,'S06811D'
,'S06811S'
,'S06812D'
,'S06812S'
,'S06813D'
,'S06813S'
,'S06814D'
,'S06814S'
,'S06815D'
,'S06815S'
,'S06816D'
,'S06816S'
,'S06817D'
,'S06817S'
,'S06818D'
,'S06818S'
,'S06819D'
,'S06819S'
,'S06820D'
,'S06820S'
,'S06821D'
,'S06821S'
,'S06822D'
,'S06822S'
,'S06823D'
,'S06823S'
,'S06824D'
,'S06824S'
,'S06825D'
,'S06825S'
,'S06826D'
,'S06826S'
,'S06827D'
,'S06827S'
,'S06828D'
,'S06828S'
,'S06829D'
,'S06829S'
,'S06890D'
,'S06890S'
,'S06891D'
,'S06891S'
,'S06892D'
,'S06892S'
,'S06893D'
,'S06893S'
,'S06894D'
,'S06894S'
,'S06895D'
,'S06895S'
,'S06896D'
,'S06896S'
,'S06897D'
,'S06897S'
,'S06898D'
,'S06898S'
,'S06899D'
,'S06899S'
,'S069X0D'
,'S069X0S'
,'S069X1D'
,'S069X1S'
,'S069X2D'
,'S069X2S'
,'S069X3D'
,'S069X3S'
,'S069X4D'
,'S069X4S'
,'S069X5D'
,'S069X5S'
,'S069X6D'
,'S069X6S'
,'S069X7D'
,'S069X7S'
,'S069X8D'
,'S069X8S'
,'S069X9D'
,'S069X9S'
,'S070XXD'
,'S070XXS'
,'S071XXD'
,'S071XXS'
,'S078XXD'
,'S078XXS'
,'S079XXD'
,'S079XXS'
,'S080XXD'
,'S080XXS'
,'S08111D'
,'S08111S'
,'S08112D'
,'S08112S'
,'S08119D'
,'S08119S'
,'S08121D'
,'S08121S'
,'S08122D'
,'S08122S'
,'S08129D'
,'S08129S'
,'S08811D'
,'S08811S'
,'S08812D'
,'S08812S'
,'S0889XD'
,'S0889XS'
,'S090XXD'
,'S090XXS'
,'S0910XD'
,'S0910XS'
,'S0911XD'
,'S0911XS'
,'S0912XD'
,'S0912XS'
,'S0919XD'
,'S0919XS'
,'S0920XD'
,'S0920XS'
,'S0921XD'
,'S0921XS'
,'S0922XD'
,'S0922XS'
,'S09301D'
,'S09301S'
,'S09302D'
,'S09302S'
,'S09309D'
,'S09309S'
,'S09311D'
,'S09311S'
,'S09312D'
,'S09312S'
,'S09313D'
,'S09313S'
,'S09319D'
,'S09319S'
,'S09391D'
,'S09391S'
,'S09392D'
,'S09392S'
,'S09399D'
,'S09399S'
,'S098XXD'
,'S098XXS'
,'S0990XD'
,'S0990XS'
,'S0991XD'
,'S0991XS'
,'S0992XD'
,'S0992XS'
,'S0993XD'
,'S0993XS'
,'S100XXD'
,'S100XXS'
,'S1010XD'
,'S1010XS'
,'S1011XD'
,'S1011XS'
,'S1012XD'
,'S1012XS'
,'S1014XD'
,'S1014XS'
,'S1015XD'
,'S1015XS'
,'S1016XD'
,'S1016XS'
,'S1017XD'
,'S1017XS'
,'S1080XD'
,'S1080XS'
,'S1081XD'
,'S1081XS'
,'S1082XD'
,'S1082XS'
,'S1083XD'
,'S1083XS'
,'S1084XD'
,'S1084XS'
,'S1085XD'
,'S1085XS'
,'S1086XD'
,'S1086XS'
,'S1087XD'
,'S1087XS'
,'S1090XD'
,'S1090XS'
,'S1091XD'
,'S1091XS'
,'S1092XD'
,'S1092XS'
,'S1093XD'
,'S1093XS'
,'S1094XD'
,'S1094XS'
,'S1095XD'
,'S1095XS'
,'S1096XD'
,'S1096XS'
,'S1097XD'
,'S1097XS'
,'S11011D'
,'S11011S'
,'S11012D'
,'S11012S'
,'S11013D'
,'S11013S'
,'S11014D'
,'S11014S'
,'S11015D'
,'S11015S'
,'S11019D'
,'S11019S'
,'S11021D'
,'S11021S'
,'S11022D'
,'S11022S'
,'S11023D'
,'S11023S'
,'S11024D'
,'S11024S'
,'S11025D'
,'S11025S'
,'S11029D'
,'S11029S'
,'S11031D'
,'S11031S'
,'S11032D'
,'S11032S'
,'S11033D'
,'S11033S'
,'S11034D'
,'S11034S'
,'S11035D'
,'S11035S'
,'S11039D'
,'S11039S'
,'S1110XD'
,'S1110XS'
,'S1111XD'
,'S1111XS'
,'S1112XD'
,'S1112XS'
,'S1113XD'
,'S1113XS'
,'S1114XD'
,'S1114XS'
,'S1115XD'
,'S1115XS'
,'S1120XD'
,'S1120XS'
,'S1121XD'
,'S1121XS'
,'S1122XD'
,'S1122XS'
,'S1123XD'
,'S1123XS'
,'S1124XD'
,'S1124XS'
,'S1125XD'
,'S1125XS'
,'S1180XD'
,'S1180XS'
,'S1181XD'
,'S1181XS'
,'S1182XD'
,'S1182XS'
,'S1183XD'
,'S1183XS'
,'S1184XD'
,'S1184XS'
,'S1185XD'
,'S1185XS'
,'S1189XD'
,'S1189XS'
,'S1190XD'
,'S1190XS'
,'S1191XD'
,'S1191XS'
,'S1192XD'
,'S1192XS'
,'S1193XD'
,'S1193XS'
,'S1194XD'
,'S1194XS'
,'S1195XD'
,'S1195XS'
,'S12000D'
,'S12000G'
,'S12000K'
,'S12000S'
,'S12001D'
,'S12001G'
,'S12001K'
,'S12001S'
,'S1201XD'
,'S1201XG'
,'S1201XK'
,'S1201XS'
,'S1202XD'
,'S1202XG'
,'S1202XK'
,'S1202XS'
,'S12030D'
,'S12030G'
,'S12030K'
,'S12030S'
,'S12031D'
,'S12031G'
,'S12031K'
,'S12031S'
,'S12040D'
,'S12040G'
,'S12040K'
,'S12040S'
,'S12041D'
,'S12041G'
,'S12041K'
,'S12041S'
,'S12090D'
,'S12090G'
,'S12090K'
,'S12090S'
,'S12091D'
,'S12091G'
,'S12091K'
,'S12091S'
,'S12100D'
,'S12100G'
,'S12100K'
,'S12100S'
,'S12101D'
,'S12101G'
,'S12101K'
,'S12101S'
,'S12110D'
,'S12110G'
,'S12110K'
,'S12110S'
,'S12111D'
,'S12111G'
,'S12111K'
,'S12111S'
,'S12112D'
,'S12112G'
,'S12112K'
,'S12112S'
,'S12120D'
,'S12120G'
,'S12120K'
,'S12120S'
,'S12121D'
,'S12121G'
,'S12121K'
,'S12121S'
,'S12130D'
,'S12130G'
,'S12130K'
,'S12130S'
,'S12131D'
,'S12131G'
,'S12131K'
,'S12131S'
,'S1214XD'
,'S1214XG'
,'S1214XK'
,'S1214XS'
,'S12150D'
,'S12150G'
,'S12150K'
,'S12150S'
,'S12151D'
,'S12151G'
,'S12151K'
,'S12151S'
,'S12190D'
,'S12190G'
,'S12190K'
,'S12190S'
,'S12191D'
,'S12191G'
,'S12191K'
,'S12191S'
,'S12200D'
,'S12200G'
,'S12200K'
,'S12200S'
,'S12201D'
,'S12201G'
,'S12201K'
,'S12201S'
,'S12230D'
,'S12230G'
,'S12230K'
,'S12230S'
,'S12231D'
,'S12231G'
,'S12231K'
,'S12231S'
,'S1224XD'
,'S1224XG'
,'S1224XK'
,'S1224XS'
,'S12250D'
,'S12250G'
,'S12250K'
,'S12250S'
,'S12251D'
,'S12251G'
,'S12251K'
,'S12251S'
,'S12290D'
,'S12290G'
,'S12290K'
,'S12290S'
,'S12291D'
,'S12291G'
,'S12291K'
,'S12291S'
,'S12300D'
,'S12300G'
,'S12300K'
,'S12300S'
,'S12301D'
,'S12301G'
,'S12301K'
,'S12301S'
,'S12330D'
,'S12330G'
,'S12330K'
,'S12330S'
,'S12331D'
,'S12331G'
,'S12331K'
,'S12331S'
,'S1234XD'
,'S1234XG'
,'S1234XK'
,'S1234XS'
,'S12350D'
,'S12350G'
,'S12350K'
,'S12350S'
,'S12351D'
,'S12351G'
,'S12351K'
,'S12351S'
,'S12390D'
,'S12390G'
,'S12390K'
,'S12390S'
,'S12391D'
,'S12391G'
,'S12391K'
,'S12391S'
,'S12400D'
,'S12400G'
,'S12400K'
,'S12400S'
,'S12401D'
,'S12401G'
,'S12401K'
,'S12401S'
,'S12430D'
,'S12430G'
,'S12430K'
,'S12430S'
,'S12431D'
,'S12431G'
,'S12431K'
,'S12431S'
,'S1244XD'
,'S1244XG'
,'S1244XK'
,'S1244XS'
,'S12450D'
,'S12450G'
,'S12450K'
,'S12450S'
,'S12451D'
,'S12451G'
,'S12451K'
,'S12451S'
,'S12490D'
,'S12490G'
,'S12490K'
,'S12490S'
,'S12491D'
,'S12491G'
,'S12491K'
,'S12491S'
,'S12500D'
,'S12500G'
,'S12500K'
,'S12500S'
,'S12501D'
,'S12501G'
,'S12501K'
,'S12501S'
,'S12530D'
,'S12530G'
,'S12530K'
,'S12530S'
,'S12531D'
,'S12531G'
,'S12531K'
,'S12531S'
,'S1254XD'
,'S1254XG'
,'S1254XK'
,'S1254XS'
,'S12550D'
,'S12550G'
,'S12550K'
,'S12550S'
,'S12551D'
,'S12551G'
,'S12551K'
,'S12551S'
,'S12590D'
,'S12590G'
,'S12590K'
,'S12590S'
,'S12591D'
,'S12591G'
,'S12591K'
,'S12591S'
,'S12600D'
,'S12600G'
,'S12600K'
,'S12600S'
,'S12601D'
,'S12601G'
,'S12601K'
,'S12601S'
,'S12630D'
,'S12630G'
,'S12630K'
,'S12630S'
,'S12631D'
,'S12631G'
,'S12631K'
,'S12631S'
,'S1264XD'
,'S1264XG'
,'S1264XK'
,'S1264XS'
,'S12650D'
,'S12650G'
,'S12650K'
,'S12650S'
,'S12651D'
,'S12651G'
,'S12651K'
,'S12651S'
,'S12690D'
,'S12690G'
,'S12690K'
,'S12690S'
,'S12691D'
,'S12691G'
,'S12691K'
,'S12691S'
,'S128XXD'
,'S128XXS'
,'S129XXD'
,'S129XXS'
,'S130XXD'
,'S130XXS'
,'S13100D'
,'S13100S'
,'S13101D'
,'S13101S'
,'S13110D'
,'S13110S'
,'S13111D'
,'S13111S'
,'S13120D'
,'S13120S'
,'S13121D'
,'S13121S'
,'S13130D'
,'S13130S'
,'S13131D'
,'S13131S'
,'S13140D'
,'S13140S'
,'S13141D'
,'S13141S'
,'S13150D'
,'S13150S'
,'S13151D'
,'S13151S'
,'S13160D'
,'S13160S'
,'S13161D'
,'S13161S'
,'S13170D'
,'S13170S'
,'S13171D'
,'S13171S'
,'S13180D'
,'S13180S'
,'S13181D'
,'S13181S'
,'S1320XD'
,'S1320XS'
,'S1329XD'
,'S1329XS'
,'S134XXD'
,'S134XXS'
,'S135XXD'
,'S135XXS'
,'S138XXD'
,'S138XXS'
,'S139XXD'
,'S139XXS'
,'S140XXD'
,'S140XXS'
,'S14101D'
,'S14101S'
,'S14102D'
,'S14102S'
,'S14103D'
,'S14103S'
,'S14104D'
,'S14104S'
,'S14105D'
,'S14105S'
,'S14106D'
,'S14106S'
,'S14107D'
,'S14107S'
,'S14108D'
,'S14108S'
,'S14109D'
,'S14109S'
,'S14111D'
,'S14111S'
,'S14112D'
,'S14112S'
,'S14113D'
,'S14113S'
,'S14114D'
,'S14114S'
,'S14115D'
,'S14115S'
,'S14116D'
,'S14116S'
,'S14117D'
,'S14117S'
,'S14118D'
,'S14118S'
,'S14119D'
,'S14119S'
,'S14121D'
,'S14121S'
,'S14122D'
,'S14122S'
,'S14123D'
,'S14123S'
,'S14124D'
,'S14124S'
,'S14125D'
,'S14125S'
,'S14126D'
,'S14126S'
,'S14127D'
,'S14127S'
,'S14128D'
,'S14128S'
,'S14129D'
,'S14129S'
,'S14131D'
,'S14131S'
,'S14132D'
,'S14132S'
,'S14133D'
,'S14133S'
,'S14134D'
,'S14134S'
,'S14135D'
,'S14135S'
,'S14136D'
,'S14136S'
,'S14137D'
,'S14137S'
,'S14138D'
,'S14138S'
,'S14139D'
,'S14139S'
,'S14141D'
,'S14141S'
,'S14142D'
,'S14142S'
,'S14143D'
,'S14143S'
,'S14144D'
,'S14144S'
,'S14145D'
,'S14145S'
,'S14146D'
,'S14146S'
,'S14147D'
,'S14147S'
,'S14148D'
,'S14148S'
,'S14149D'
,'S14149S'
,'S14151D'
,'S14151S'
,'S14152D'
,'S14152S'
,'S14153D'
,'S14153S'
,'S14154D'
,'S14154S'
,'S14155D'
,'S14155S'
,'S14156D'
,'S14156S'
,'S14157D'
,'S14157S'
,'S14158D'
,'S14158S'
,'S14159D'
,'S14159S'
,'S142XXD'
,'S142XXS'
,'S143XXD'
,'S143XXS'
,'S144XXD'
,'S144XXS'
,'S145XXD'
,'S145XXS'
,'S148XXD'
,'S148XXS'
,'S149XXD'
,'S149XXS'
,'S15001D'
,'S15001S'
,'S15002D'
,'S15002S'
,'S15009D'
,'S15009S'
,'S15011D'
,'S15011S'
,'S15012D'
,'S15012S'
,'S15019D'
,'S15019S'
,'S15021D'
,'S15021S'
,'S15022D'
,'S15022S'
,'S15029D'
,'S15029S'
,'S15091D'
,'S15091S'
,'S15092D'
,'S15092S'
,'S15099D'
,'S15099S'
,'S15101D'
,'S15101S'
,'S15102D'
,'S15102S'
,'S15109D'
,'S15109S'
,'S15111D'
,'S15111S'
,'S15112D'
,'S15112S'
,'S15119D'
,'S15119S'
,'S15121D'
,'S15121S'
,'S15122D'
,'S15122S'
,'S15129D'
,'S15129S'
,'S15191D'
,'S15191S'
,'S15192D'
,'S15192S'
,'S15199D'
,'S15199S'
,'S15201D'
,'S15201S'
,'S15202D'
,'S15202S'
,'S15209D'
,'S15209S'
,'S15211D'
,'S15211S'
,'S15212D'
,'S15212S'
,'S15219D'
,'S15219S'
,'S15221D'
,'S15221S'
,'S15222D'
,'S15222S'
,'S15229D'
,'S15229S'
,'S15291D'
,'S15291S'
,'S15292D'
,'S15292S'
,'S15299D'
,'S15299S'
,'S15301D'
,'S15301S'
,'S15302D'
,'S15302S'
,'S15309D'
,'S15309S'
,'S15311D'
,'S15311S'
,'S15312D'
,'S15312S'
,'S15319D'
,'S15319S'
,'S15321D'
,'S15321S'
,'S15322D'
,'S15322S'
,'S15329D'
,'S15329S'
,'S15391D'
,'S15391S'
,'S15392D'
,'S15392S'
,'S15399D'
,'S15399S'
,'S158XXD'
,'S158XXS'
,'S159XXD'
,'S159XXS'
,'S161XXD'
,'S161XXS'
,'S162XXD'
,'S162XXS'
,'S168XXD'
,'S168XXS'
,'S169XXD'
,'S169XXS'
,'S170XXD'
,'S170XXS'
,'S178XXD'
,'S178XXS'
,'S179XXD'
,'S179XXS'
,'S1980XD'
,'S1980XS'
,'S1981XD'
,'S1981XS'
,'S1982XD'
,'S1982XS'
,'S1983XD'
,'S1983XS'
,'S1984XD'
,'S1984XS'
,'S1985XD'
,'S1985XS'
,'S1989XD'
,'S1989XS'
,'S199XXD'
,'S199XXS'
,'S2000XD'
,'S2000XS'
,'S2001XD'
,'S2001XS'
,'S2002XD'
,'S2002XS'
,'S20101D'
,'S20101S'
,'S20102D'
,'S20102S'
,'S20109D'
,'S20109S'
,'S20111D'
,'S20111S'
,'S20112D'
,'S20112S'
,'S20119D'
,'S20119S'
,'S20121D'
,'S20121S'
,'S20122D'
,'S20122S'
,'S20129D'
,'S20129S'
,'S20141D'
,'S20141S'
,'S20142D'
,'S20142S'
,'S20149D'
,'S20149S'
,'S20151D'
,'S20151S'
,'S20152D'
,'S20152S'
,'S20159D'
,'S20159S'
,'S20161D'
,'S20161S'
,'S20162D'
,'S20162S'
,'S20169D'
,'S20169S'
,'S20171D'
,'S20171S'
,'S20172D'
,'S20172S'
,'S20179D'
,'S20179S'
,'S2020XD'
,'S2020XS'
,'S20211D'
,'S20211S'
,'S20212D'
,'S20212S'
,'S20219D'
,'S20219S'
,'S20221D'
,'S20221S'
,'S20222D'
,'S20222S'
,'S20229D'
,'S20229S'
,'S20301D'
,'S20301S'
,'S20302D'
,'S20302S'
,'S20309D'
,'S20309S'
,'S20311D'
,'S20311S'
,'S20312D'
,'S20312S'
,'S20319D'
,'S20319S'
,'S20321D'
,'S20321S'
,'S20322D'
,'S20322S'
,'S20329D'
,'S20329S'
,'S20341D'
,'S20341S'
,'S20342D'
,'S20342S'
,'S20349D'
,'S20349S'
,'S20351D'
,'S20351S'
,'S20352D'
,'S20352S'
,'S20359D'
,'S20359S'
,'S20361D'
,'S20361S'
,'S20362D'
,'S20362S'
,'S20369D'
,'S20369S'
,'S20371D'
,'S20371S'
,'S20372D'
,'S20372S'
,'S20379D'
,'S20379S'
,'S20401D'
,'S20401S'
,'S20402D'
,'S20402S'
,'S20409D'
,'S20409S'
,'S20411D'
,'S20411S'
,'S20412D'
,'S20412S'
,'S20419D'
,'S20419S'
,'S20421D'
,'S20421S'
,'S20422D'
,'S20422S'
,'S20429D'
,'S20429S'
,'S20441D'
,'S20441S'
,'S20442D'
,'S20442S'
,'S20449D'
,'S20449S'
,'S20451D'
,'S20451S'
,'S20452D'
,'S20452S'
,'S20459D'
,'S20459S'
,'S20461D'
,'S20461S'
,'S20462D'
,'S20462S'
,'S20469D'
,'S20469S'
,'S20471D'
,'S20471S'
,'S20472D'
,'S20472S'
,'S20479D'
,'S20479S'
,'S2090XD'
,'S2090XS'
,'S2091XD'
,'S2091XS'
,'S2092XD'
,'S2092XS'
,'S2094XD'
,'S2094XS'
,'S2095XD'
,'S2095XS'
,'S2096XD'
,'S2096XS'
,'S2097XD'
,'S2097XS'
,'S21001D'
,'S21001S'
,'S21002D'
,'S21002S'
,'S21009D'
,'S21009S'
,'S21011D'
,'S21011S'
,'S21012D'
,'S21012S'
,'S21019D'
,'S21019S'
,'S21021D'
,'S21021S'
,'S21022D'
,'S21022S'
,'S21029D'
,'S21029S'
,'S21031D'
,'S21031S'
,'S21032D'
,'S21032S'
,'S21039D'
,'S21039S'
,'S21041D'
,'S21041S'
,'S21042D'
,'S21042S'
,'S21049D'
,'S21049S'
,'S21051D'
,'S21051S'
,'S21052D'
,'S21052S'
,'S21059D'
,'S21059S'
,'S21101D'
,'S21101S'
,'S21102D'
,'S21102S'
,'S21109D'
,'S21109S'
,'S21111D'
,'S21111S'
,'S21112D'
,'S21112S'
,'S21119D'
,'S21119S'
,'S21121D'
,'S21121S'
,'S21122D'
,'S21122S'
,'S21129D'
,'S21129S'
,'S21131D'
,'S21131S'
,'S21132D'
,'S21132S'
,'S21139D'
,'S21139S'
,'S21141D'
,'S21141S'
,'S21142D'
,'S21142S'
,'S21149D'
,'S21149S'
,'S21151D'
,'S21151S'
,'S21152D'
,'S21152S'
,'S21159D'
,'S21159S'
,'S21201D'
,'S21201S'
,'S21202D'
,'S21202S'
,'S21209D'
,'S21209S'
,'S21211D'
,'S21211S'
,'S21212D'
,'S21212S'
,'S21219D'
,'S21219S'
,'S21221D'
,'S21221S'
,'S21222D'
,'S21222S'
,'S21229D'
,'S21229S'
,'S21231D'
,'S21231S'
,'S21232D'
,'S21232S'
,'S21239D'
,'S21239S'
,'S21241D'
,'S21241S'
,'S21242D'
,'S21242S'
,'S21249D'
,'S21249S'
,'S21251D'
,'S21251S'
,'S21252D'
,'S21252S'
,'S21259D'
,'S21259S'
,'S21301D'
,'S21301S'
,'S21302D'
,'S21302S'
,'S21309D'
,'S21309S'
,'S21311D'
,'S21311S'
,'S21312D'
,'S21312S'
,'S21319D'
,'S21319S'
,'S21321D'
,'S21321S'
,'S21322D'
,'S21322S'
,'S21329D'
,'S21329S'
,'S21331D'
,'S21331S'
,'S21332D'
,'S21332S'
,'S21339D'
,'S21339S'
,'S21341D'
,'S21341S'
,'S21342D'
,'S21342S'
,'S21349D'
,'S21349S'
,'S21351D'
,'S21351S'
,'S21352D'
,'S21352S'
,'S21359D'
,'S21359S'
,'S21401D'
,'S21401S'
,'S21402D'
,'S21402S'
,'S21409D'
,'S21409S'
,'S21411D'
,'S21411S'
,'S21412D'
,'S21412S'
,'S21419D'
,'S21419S'
,'S21421D'
,'S21421S'
,'S21422D'
,'S21422S'
,'S21429D'
,'S21429S'
,'S21431D'
,'S21431S'
,'S21432D'
,'S21432S'
,'S21439D'
,'S21439S'
,'S21441D'
,'S21441S'
,'S21442D'
,'S21442S'
,'S21449D'
,'S21449S'
,'S21451D'
,'S21451S'
,'S21452D'
,'S21452S'
,'S21459D'
,'S21459S'
,'S2190XD'
,'S2190XS'
,'S2191XD'
,'S2191XS'
,'S2192XD'
,'S2192XS'
,'S2193XD'
,'S2193XS'
,'S2194XD'
,'S2194XS'
,'S2195XD'
,'S2195XS'
,'S22000D'
,'S22000G'
,'S22000K'
,'S22000S'
,'S22001D'
,'S22001G'
,'S22001K'
,'S22001S'
,'S22002D'
,'S22002G'
,'S22002K'
,'S22002S'
,'S22008D'
,'S22008G'
,'S22008K'
,'S22008S'
,'S22009D'
,'S22009G'
,'S22009K'
,'S22009S'
,'S22010D'
,'S22010G'
,'S22010K'
,'S22010S'
,'S22011D'
,'S22011G'
,'S22011K'
,'S22011S'
,'S22012D'
,'S22012G'
,'S22012K'
,'S22012S'
,'S22018D'
,'S22018G'
,'S22018K'
,'S22018S'
,'S22019D'
,'S22019G'
,'S22019K'
,'S22019S'
,'S22020D'
,'S22020G'
,'S22020K'
,'S22020S'
,'S22021D'
,'S22021G'
,'S22021K'
,'S22021S'
,'S22022D'
,'S22022G'
,'S22022K'
,'S22022S'
,'S22028D'
,'S22028G'
,'S22028K'
,'S22028S'
,'S22029D'
,'S22029G'
,'S22029K'
,'S22029S'
,'S22030D'
,'S22030G'
,'S22030K'
,'S22030S'
,'S22031D'
,'S22031G'
,'S22031K'
,'S22031S'
,'S22032D'
,'S22032G'
,'S22032K'
,'S22032S'
,'S22038D'
,'S22038G'
,'S22038K'
,'S22038S'
,'S22039D'
,'S22039G'
,'S22039K'
,'S22039S'
,'S22040D'
,'S22040G'
,'S22040K'
,'S22040S'
,'S22041D'
,'S22041G'
,'S22041K'
,'S22041S'
,'S22042D'
,'S22042G'
,'S22042K'
,'S22042S'
,'S22048D'
,'S22048G'
,'S22048K'
,'S22048S'
,'S22049D'
,'S22049G'
,'S22049K'
,'S22049S'
,'S22050D'
,'S22050G'
,'S22050K'
,'S22050S'
,'S22051D'
,'S22051G'
,'S22051K'
,'S22051S'
,'S22052D'
,'S22052G'
,'S22052K'
,'S22052S'
,'S22058D'
,'S22058G'
,'S22058K'
,'S22058S'
,'S22059D'
,'S22059G'
,'S22059K'
,'S22059S'
,'S22060D'
,'S22060G'
,'S22060K'
,'S22060S'
,'S22061D'
,'S22061G'
,'S22061K'
,'S22061S'
,'S22062D'
,'S22062G'
,'S22062K'
,'S22062S'
,'S22068D'
,'S22068G'
,'S22068K'
,'S22068S'
,'S22069D'
,'S22069G'
,'S22069K'
,'S22069S'
,'S22070D'
,'S22070G'
,'S22070K'
,'S22070S'
,'S22071D'
,'S22071G'
,'S22071K'
,'S22071S'
,'S22072D'
,'S22072G'
,'S22072K'
,'S22072S'
,'S22078D'
,'S22078G'
,'S22078K'
,'S22078S'
,'S22079D'
,'S22079G'
,'S22079K'
,'S22079S'
,'S22080D'
,'S22080G'
,'S22080K'
,'S22080S'
,'S22081D'
,'S22081G'
,'S22081K'
,'S22081S'
,'S22082D'
,'S22082G'
,'S22082K'
,'S22082S'
,'S22088D'
,'S22088G'
,'S22088K'
,'S22088S'
,'S22089D'
,'S22089G'
,'S22089K'
,'S22089S'
,'S2220XD'
,'S2220XG'
,'S2220XK'
,'S2220XS'
,'S2221XD'
,'S2221XG'
,'S2221XK'
,'S2221XS'
,'S2222XD'
,'S2222XG'
,'S2222XK'
,'S2222XS'
,'S2223XD'
,'S2223XG'
,'S2223XK'
,'S2223XS'
,'S2224XD'
,'S2224XG'
,'S2224XK'
,'S2224XS'
,'S2231XD'
,'S2231XG'
,'S2231XK'
,'S2231XS'
,'S2232XD'
,'S2232XG'
,'S2232XK'
,'S2232XS'
,'S2239XD'
,'S2239XG'
,'S2239XK'
,'S2239XS'
,'S2241XD'
,'S2241XG'
,'S2241XK'
,'S2241XS'
,'S2242XD'
,'S2242XG'
,'S2242XK'
,'S2242XS'
,'S2243XD'
,'S2243XG'
,'S2243XK'
,'S2243XS'
,'S2249XD'
,'S2249XG'
,'S2249XK'
,'S2249XS'
,'S225XXD'
,'S225XXG'
,'S225XXK'
,'S225XXS'
,'S229XXD'
,'S229XXG'
,'S229XXK'
,'S229XXS'
,'S230XXD'
,'S230XXS'
,'S23100D'
,'S23100S'
,'S23101D'
,'S23101S'
,'S23110D'
,'S23110S'
,'S23111D'
,'S23111S'
,'S23120D'
,'S23120S'
,'S23121D'
,'S23121S'
,'S23122D'
,'S23122S'
,'S23123D'
,'S23123S'
,'S23130D'
,'S23130S'
,'S23131D'
,'S23131S'
,'S23132D'
,'S23132S'
,'S23133D'
,'S23133S'
,'S23140D'
,'S23140S'
,'S23141D'
,'S23141S'
,'S23142D'
,'S23142S'
,'S23143D'
,'S23143S'
,'S23150D'
,'S23150S'
,'S23151D'
,'S23151S'
,'S23152D'
,'S23152S'
,'S23153D'
,'S23153S'
,'S23160D'
,'S23160S'
,'S23161D'
,'S23161S'
,'S23162D'
,'S23162S'
,'S23163D'
,'S23163S'
,'S23170D'
,'S23170S'
,'S23171D'
,'S23171S'
,'S2320XD'
,'S2320XS'
,'S2329XD'
,'S2329XS'
,'S233XXD'
,'S233XXS'
,'S2341XD'
,'S2341XS'
,'S23420D'
,'S23420S'
,'S23421D'
,'S23421S'
,'S23428D'
,'S23428S'
,'S23429D'
,'S23429S'
,'S238XXD'
,'S238XXS'
,'S239XXD'
,'S239XXS'
,'S240XXD'
,'S240XXS'
,'S24101D'
,'S24101S'
,'S24102D'
,'S24102S'
,'S24103D'
,'S24103S'
,'S24104D'
,'S24104S'
,'S24109D'
,'S24109S'
,'S24111D'
,'S24111S'
,'S24112D'
,'S24112S'
,'S24113D'
,'S24113S'
,'S24114D'
,'S24114S'
,'S24119D'
,'S24119S'
,'S24131D'
,'S24131S'
,'S24132D'
,'S24132S'
,'S24133D'
,'S24133S'
,'S24134D'
,'S24134S'
,'S24139D'
,'S24139S'
,'S24141D'
,'S24141S'
,'S24142D'
,'S24142S'
,'S24143D'
,'S24143S'
,'S24144D'
,'S24144S'
,'S24149D'
,'S24149S'
,'S24151D'
,'S24151S'
,'S24152D'
,'S24152S'
,'S24153D'
,'S24153S'
,'S24154D'
,'S24154S'
,'S24159D'
,'S24159S'
,'S242XXD'
,'S242XXS'
,'S243XXD'
,'S243XXS'
,'S244XXD'
,'S244XXS'
,'S248XXD'
,'S248XXS'
,'S249XXD'
,'S249XXS'
,'S2500XD'
,'S2500XS'
,'S2501XD'
,'S2501XS'
,'S2502XD'
,'S2502XS'
,'S2509XD'
,'S2509XS'
,'S25101D'
,'S25101S'
,'S25102D'
,'S25102S'
,'S25109D'
,'S25109S'
,'S25111D'
,'S25111S'
,'S25112D'
,'S25112S'
,'S25119D'
,'S25119S'
,'S25121D'
,'S25121S'
,'S25122D'
,'S25122S'
,'S25129D'
,'S25129S'
,'S25191D'
,'S25191S'
,'S25192D'
,'S25192S'
,'S25199D'
,'S25199S'
,'S2520XD'
,'S2520XS'
,'S2521XD'
,'S2521XS'
,'S2522XD'
,'S2522XS'
,'S2529XD'
,'S2529XS'
,'S25301D'
,'S25301S'
,'S25302D'
,'S25302S'
,'S25309D'
,'S25309S'
,'S25311D'
,'S25311S'
,'S25312D'
,'S25312S'
,'S25319D'
,'S25319S'
,'S25321D'
,'S25321S'
,'S25322D'
,'S25322S'
,'S25329D'
,'S25329S'
,'S25391D'
,'S25391S'
,'S25392D'
,'S25392S'
,'S25399D'
,'S25399S'
,'S25401D'
,'S25401S'
,'S25402D'
,'S25402S'
,'S25409D'
,'S25409S'
,'S25411D'
,'S25411S'
,'S25412D'
,'S25412S'
,'S25419D'
,'S25419S'
,'S25421D'
,'S25421S'
,'S25422D'
,'S25422S'
,'S25429D'
,'S25429S'
,'S25491D'
,'S25491S'
,'S25492D'
,'S25492S'
,'S25499D'
,'S25499S'
,'S25501D'
,'S25501S'
,'S25502D'
,'S25502S'
,'S25509D'
,'S25509S'
,'S25511D'
,'S25511S'
,'S25512D'
,'S25512S'
,'S25519D'
,'S25519S'
,'S25591D'
,'S25591S'
,'S25592D'
,'S25592S'
,'S25599D'
,'S25599S'
,'S25801D'
,'S25801S'
,'S25802D'
,'S25802S'
,'S25809D'
,'S25809S'
,'S25811D'
,'S25811S'
,'S25812D'
,'S25812S'
,'S25819D'
,'S25819S'
,'S25891D'
,'S25891S'
,'S25892D'
,'S25892S'
,'S25899D'
,'S25899S'
,'S2590XD'
,'S2590XS'
,'S2591XD'
,'S2591XS'
,'S2599XD'
,'S2599XS'
,'S2600XD'
,'S2600XS'
,'S2601XD'
,'S2601XS'
,'S26020D'
,'S26020S'
,'S26021D'
,'S26021S'
,'S26022D'
,'S26022S'
,'S2609XD'
,'S2609XS'
,'S2610XD'
,'S2610XS'
,'S2611XD'
,'S2611XS'
,'S2612XD'
,'S2612XS'
,'S2619XD'
,'S2619XS'
,'S2690XD'
,'S2690XS'
,'S2691XD'
,'S2691XS'
,'S2692XD'
,'S2692XS'
,'S2699XD'
,'S2699XS'
,'S270XXD'
,'S270XXS'
,'S271XXD'
,'S271XXS'
,'S272XXD'
,'S272XXS'
,'S27301D'
,'S27301S'
,'S27302D'
,'S27302S'
,'S27309D'
,'S27309S'
,'S27311D'
,'S27311S'
,'S27312D'
,'S27312S'
,'S27319D'
,'S27319S'
,'S27321D'
,'S27321S'
,'S27322D'
,'S27322S'
,'S27329D'
,'S27329S'
,'S27331D'
,'S27331S'
,'S27332D'
,'S27332S'
,'S27339D'
,'S27339S'
,'S27391D'
,'S27391S'
,'S27392D'
,'S27392S'
,'S27399D'
,'S27399S'
,'S27401D'
,'S27401S'
,'S27402D'
,'S27402S'
,'S27409D'
,'S27409S'
,'S27411D'
,'S27411S'
,'S27412D'
,'S27412S'
,'S27419D'
,'S27419S'
,'S27421D'
,'S27421S'
,'S27422D'
,'S27422S'
,'S27429D'
,'S27429S'
,'S27431D'
,'S27431S'
,'S27432D'
,'S27432S'
,'S27439D'
,'S27439S'
,'S27491D'
,'S27491S'
,'S27492D'
,'S27492S'
,'S27499D'
,'S27499S'
,'S2750XD'
,'S2750XS'
,'S2751XD'
,'S2751XS'
,'S2752XD'
,'S2752XS'
,'S2753XD'
,'S2753XS'
,'S2759XD'
,'S2759XS'
,'S2760XD'
,'S2760XS'
,'S2763XD'
,'S2763XS'
,'S2769XD'
,'S2769XS'
,'S27802D'
,'S27802S'
,'S27803D'
,'S27803S'
,'S27808D'
,'S27808S'
,'S27809D'
,'S27809S'
,'S27812D'
,'S27812S'
,'S27813D'
,'S27813S'
,'S27818D'
,'S27818S'
,'S27819D'
,'S27819S'
,'S27892D'
,'S27892S'
,'S27893D'
,'S27893S'
,'S27898D'
,'S27898S'
,'S27899D'
,'S27899S'
,'S279XXD'
,'S279XXS'
,'S280XXD'
,'S280XXS'
,'S281XXD'
,'S281XXS'
,'S28211D'
,'S28211S'
,'S28212D'
,'S28212S'
,'S28219D'
,'S28219S'
,'S28221D'
,'S28221S'
,'S28222D'
,'S28222S'
,'S28229D'
,'S28229S'
,'S29001D'
,'S29001S'
,'S29002D'
,'S29002S'
,'S29009D'
,'S29009S'
,'S29011D'
,'S29011S'
,'S29012D'
,'S29012S'
,'S29019D'
,'S29019S'
,'S29021D'
,'S29021S'
,'S29022D'
,'S29022S'
,'S29029D'
,'S29029S'
,'S29091D'
,'S29091S'
,'S29092D'
,'S29092S'
,'S29099D'
,'S29099S'
,'S298XXD'
,'S298XXS'
,'S299XXD'
,'S299XXS'
,'S300XXD'
,'S300XXS'
,'S301XXD'
,'S301XXS'
,'S30201D'
,'S30201S'
,'S30202D'
,'S30202S'
,'S3021XD'
,'S3021XS'
,'S3022XD'
,'S3022XS'
,'S3023XD'
,'S3023XS'
,'S303XXD'
,'S303XXS'
,'S30810D'
,'S30810S'
,'S30811D'
,'S30811S'
,'S30812D'
,'S30812S'
,'S30813D'
,'S30813S'
,'S30814D'
,'S30814S'
,'S30815D'
,'S30815S'
,'S30816D'
,'S30816S'
,'S30817D'
,'S30817S'
,'S30820D'
,'S30820S'
,'S30821D'
,'S30821S'
,'S30822D'
,'S30822S'
,'S30823D'
,'S30823S'
,'S30824D'
,'S30824S'
,'S30825D'
,'S30825S'
,'S30826D'
,'S30826S'
,'S30827D'
,'S30827S'
,'S30840D'
,'S30840S'
,'S30841D'
,'S30841S'
,'S30842D'
,'S30842S'
,'S30843D'
,'S30843S'
,'S30844D'
,'S30844S'
,'S30845D'
,'S30845S'
,'S30846D'
,'S30846S'
,'S30850D'
,'S30850S'
,'S30851D'
,'S30851S'
,'S30852D'
,'S30852S'
,'S30853D'
,'S30853S'
,'S30854D'
,'S30854S'
,'S30855D'
,'S30855S'
,'S30856D'
,'S30856S'
,'S30857D'
,'S30857S'
,'S30860D'
,'S30860S'
,'S30861D'
,'S30861S'
,'S30862D'
,'S30862S'
,'S30863D'
,'S30863S'
,'S30864D'
,'S30864S'
,'S30865D'
,'S30865S'
,'S30866D'
,'S30866S'
,'S30867D'
,'S30867S'
,'S30870D'
,'S30870S'
,'S30871D'
,'S30871S'
,'S30872D'
,'S30872S'
,'S30873D'
,'S30873S'
,'S30874D'
,'S30874S'
,'S30875D'
,'S30875S'
,'S30876D'
,'S30876S'
,'S30877D'
,'S30877S'
,'S3091XD'
,'S3091XS'
,'S3092XD'
,'S3092XS'
,'S3093XD'
,'S3093XS'
,'S3094XD'
,'S3094XS'
,'S3095XD'
,'S3095XS'
,'S3096XD'
,'S3096XS'
,'S3097XD'
,'S3097XS'
,'S3098XD'
,'S3098XS'
,'S31000D'
,'S31000S'
,'S31001D'
,'S31001S'
,'S31010D'
,'S31010S'
,'S31011D'
,'S31011S'
,'S31020D'
,'S31020S'
,'S31021D'
,'S31021S'
,'S31030D'
,'S31030S'
,'S31031D'
,'S31031S'
,'S31040D'
,'S31040S'
,'S31041D'
,'S31041S'
,'S31050D'
,'S31050S'
,'S31051D'
,'S31051S'
,'S31100D'
,'S31100S'
,'S31101D'
,'S31101S'
,'S31102D'
,'S31102S'
,'S31103D'
,'S31103S'
,'S31104D'
,'S31104S'
,'S31105D'
,'S31105S'
,'S31109D'
,'S31109S'
,'S31110D'
,'S31110S'
,'S31111D'
,'S31111S'
,'S31112D'
,'S31112S'
,'S31113D'
,'S31113S'
,'S31114D'
,'S31114S'
,'S31115D'
,'S31115S'
,'S31119D'
,'S31119S'
,'S31120D'
,'S31120S'
,'S31121D'
,'S31121S'
,'S31122D'
,'S31122S'
,'S31123D'
,'S31123S'
,'S31124D'
,'S31124S'
,'S31125D'
,'S31125S'
,'S31129D'
,'S31129S'
,'S31130D'
,'S31130S'
,'S31131D'
,'S31131S'
,'S31132D'
,'S31132S'
,'S31133D'
,'S31133S'
,'S31134D'
,'S31134S'
,'S31135D'
,'S31135S'
,'S31139D'
,'S31139S'
,'S31140D'
,'S31140S'
,'S31141D'
,'S31141S'
,'S31142D'
,'S31142S'
,'S31143D'
,'S31143S'
,'S31144D'
,'S31144S'
,'S31145D'
,'S31145S'
,'S31149D'
,'S31149S'
,'S31150D'
,'S31150S'
,'S31151D'
,'S31151S'
,'S31152D'
,'S31152S'
,'S31153D'
,'S31153S'
,'S31154D'
,'S31154S'
,'S31155D'
,'S31155S'
,'S31159D'
,'S31159S'
,'S3120XD'
,'S3120XS'
,'S3121XD'
,'S3121XS'
,'S3122XD'
,'S3122XS'
,'S3123XD'
,'S3123XS'
,'S3124XD'
,'S3124XS'
,'S3125XD'
,'S3125XS'
,'S3130XD'
,'S3130XS'
,'S3131XD'
,'S3131XS'
,'S3132XD'
,'S3132XS'
,'S3133XD'
,'S3133XS'
,'S3134XD'
,'S3134XS'
,'S3135XD'
,'S3135XS'
,'S3140XD'
,'S3140XS'
,'S3141XD'
,'S3141XS'
,'S3142XD'
,'S3142XS'
,'S3143XD'
,'S3143XS'
,'S3144XD'
,'S3144XS'
,'S3145XD'
,'S3145XS'
,'S31501D'
,'S31501S'
,'S31502D'
,'S31502S'
,'S31511D'
,'S31511S'
,'S31512D'
,'S31512S'
,'S31521D'
,'S31521S'
,'S31522D'
,'S31522S'
,'S31531D'
,'S31531S'
,'S31532D'
,'S31532S'
,'S31541D'
,'S31541S'
,'S31542D'
,'S31542S'
,'S31551D'
,'S31551S'
,'S31552D'
,'S31552S'
,'S31600D'
,'S31600S'
,'S31601D'
,'S31601S'
,'S31602D'
,'S31602S'
,'S31603D'
,'S31603S'
,'S31604D'
,'S31604S'
,'S31605D'
,'S31605S'
,'S31609D'
,'S31609S'
,'S31610D'
,'S31610S'
,'S31611D'
,'S31611S'
,'S31612D'
,'S31612S'
,'S31613D'
,'S31613S'
,'S31614D'
,'S31614S'
,'S31615D'
,'S31615S'
,'S31619D'
,'S31619S'
,'S31620D'
,'S31620S'
,'S31621D'
,'S31621S'
,'S31622D'
,'S31622S'
,'S31623D'
,'S31623S'
,'S31624D'
,'S31624S'
,'S31625D'
,'S31625S'
,'S31629D'
,'S31629S'
,'S31630D'
,'S31630S'
,'S31631D'
,'S31631S'
,'S31632D'
,'S31632S'
,'S31633D'
,'S31633S'
,'S31634D'
,'S31634S'
,'S31635D'
,'S31635S'
,'S31639D'
,'S31639S'
,'S31640D'
,'S31640S'
,'S31641D'
,'S31641S'
,'S31642D'
,'S31642S'
,'S31643D'
,'S31643S'
,'S31644D'
,'S31644S'
,'S31645D'
,'S31645S'
,'S31649D'
,'S31649S'
,'S31650D'
,'S31650S'
,'S31651D'
,'S31651S'
,'S31652D'
,'S31652S'
,'S31653D'
,'S31653S'
,'S31654D'
,'S31654S'
,'S31655D'
,'S31655S'
,'S31659D'
,'S31659S'
,'S31801D'
,'S31801S'
,'S31802D'
,'S31802S'
,'S31803D'
,'S31803S'
,'S31804D'
,'S31804S'
,'S31805D'
,'S31805S'
,'S31809D'
,'S31809S'
,'S31811D'
,'S31811S'
,'S31812D'
,'S31812S'
,'S31813D'
,'S31813S'
,'S31814D'
,'S31814S'
,'S31815D'
,'S31815S'
,'S31819D'
,'S31819S'
,'S31821D'
,'S31821S'
,'S31822D'
,'S31822S'
,'S31823D'
,'S31823S'
,'S31824D'
,'S31824S'
,'S31825D'
,'S31825S'
,'S31829D'
,'S31829S'
,'S31831D'
,'S31831S'
,'S31832D'
,'S31832S'
,'S31833D'
,'S31833S'
,'S31834D'
,'S31834S'
,'S31835D'
,'S31835S'
,'S31839D'
,'S31839S'
,'S32000D'
,'S32000G'
,'S32000K'
,'S32000S'
,'S32001D'
,'S32001G'
,'S32001K'
,'S32001S'
,'S32002D'
,'S32002G'
,'S32002K'
,'S32002S'
,'S32008D'
,'S32008G'
,'S32008K'
,'S32008S'
,'S32009D'
,'S32009G'
,'S32009K'
,'S32009S'
,'S32010D'
,'S32010G'
,'S32010K'
,'S32010S'
,'S32011D'
,'S32011G'
,'S32011K'
,'S32011S'
,'S32012D'
,'S32012G'
,'S32012K'
,'S32012S'
,'S32018D'
,'S32018G'
,'S32018K'
,'S32018S'
,'S32019D'
,'S32019G'
,'S32019K'
,'S32019S'
,'S32020D'
,'S32020G'
,'S32020K'
,'S32020S'
,'S32021D'
,'S32021G'
,'S32021K'
,'S32021S'
,'S32022D'
,'S32022G'
,'S32022K'
,'S32022S'
,'S32028D'
,'S32028G'
,'S32028K'
,'S32028S'
,'S32029D'
,'S32029G'
,'S32029K'
,'S32029S'
,'S32030D'
,'S32030G'
,'S32030K'
,'S32030S'
,'S32031D'
,'S32031G'
,'S32031K'
,'S32031S'
,'S32032D'
,'S32032G'
,'S32032K'
,'S32032S'
,'S32038D'
,'S32038G'
,'S32038K'
,'S32038S'
,'S32039D'
,'S32039G'
,'S32039K'
,'S32039S'
,'S32040D'
,'S32040G'
,'S32040K'
,'S32040S'
,'S32041D'
,'S32041G'
,'S32041K'
,'S32041S'
,'S32042D'
,'S32042G'
,'S32042K'
,'S32042S'
,'S32048D'
,'S32048G'
,'S32048K'
,'S32048S'
,'S32049D'
,'S32049G'
,'S32049K'
,'S32049S'
,'S32050D'
,'S32050G'
,'S32050K'
,'S32050S'
,'S32051D'
,'S32051G'
,'S32051K'
,'S32051S'
,'S32052D'
,'S32052G'
,'S32052K'
,'S32052S'
,'S32058D'
,'S32058G'
,'S32058K'
,'S32058S'
,'S32059D'
,'S32059G'
,'S32059K'
,'S32059S'
,'S3210XD'
,'S3210XG'
,'S3210XK'
,'S3210XS'
,'S32110D'
,'S32110G'
,'S32110K'
,'S32110S'
,'S32111D'
,'S32111G'
,'S32111K'
,'S32111S'
,'S32112D'
,'S32112G'
,'S32112K'
,'S32112S'
,'S32119D'
,'S32119G'
,'S32119K'
,'S32119S'
,'S32120D'
,'S32120G'
,'S32120K'
,'S32120S'
,'S32121D'
,'S32121G'
,'S32121K'
,'S32121S'
,'S32122D'
,'S32122G'
,'S32122K'
,'S32122S'
,'S32129D'
,'S32129G'
,'S32129K'
,'S32129S'
,'S32130D'
,'S32130G'
,'S32130K'
,'S32130S'
,'S32131D'
,'S32131G'
,'S32131K'
,'S32131S'
,'S32132D'
,'S32132G'
,'S32132K'
,'S32132S'
,'S32139D'
,'S32139G'
,'S32139K'
,'S32139S'
,'S3214XD'
,'S3214XG'
,'S3214XK'
,'S3214XS'
,'S3215XD'
,'S3215XG'
,'S3215XK'
,'S3215XS'
,'S3216XD'
,'S3216XG'
,'S3216XK'
,'S3216XS'
,'S3217XD'
,'S3217XG'
,'S3217XK'
,'S3217XS'
,'S3219XD'
,'S3219XG'
,'S3219XK'
,'S3219XS'
,'S322XXD'
,'S322XXG'
,'S322XXK'
,'S322XXS'
,'S32301D'
,'S32301G'
,'S32301K'
,'S32301S'
,'S32302D'
,'S32302G'
,'S32302K'
,'S32302S'
,'S32309D'
,'S32309G'
,'S32309K'
,'S32309S'
,'S32311D'
,'S32311G'
,'S32311K'
,'S32311S'
,'S32312D'
,'S32312G'
,'S32312K'
,'S32312S'
,'S32313D'
,'S32313G'
,'S32313K'
,'S32313S'
,'S32314D'
,'S32314G'
,'S32314K'
,'S32314S'
,'S32315D'
,'S32315G'
,'S32315K'
,'S32315S'
,'S32316D'
,'S32316G'
,'S32316K'
,'S32316S'
,'S32391D'
,'S32391G'
,'S32391K'
,'S32391S'
,'S32392D'
,'S32392G'
,'S32392K'
,'S32392S'
,'S32399D'
,'S32399G'
,'S32399K'
,'S32399S'
,'S32401D'
,'S32401G'
,'S32401K'
,'S32401S'
,'S32402D'
,'S32402G'
,'S32402K'
,'S32402S'
,'S32409D'
,'S32409G'
,'S32409K'
,'S32409S'
,'S32411D'
,'S32411G'
,'S32411K'
,'S32411S'
,'S32412D'
,'S32412G'
,'S32412K'
,'S32412S'
,'S32413D'
,'S32413G'
,'S32413K'
,'S32413S'
,'S32414D'
,'S32414G'
,'S32414K'
,'S32414S'
,'S32415D'
,'S32415G'
,'S32415K'
,'S32415S'
,'S32416D'
,'S32416G'
,'S32416K'
,'S32416S'
,'S32421D'
,'S32421G'
,'S32421K'
,'S32421S'
,'S32422D'
,'S32422G'
,'S32422K'
,'S32422S'
,'S32423D'
,'S32423G'
,'S32423K'
,'S32423S'
,'S32424D'
,'S32424G'
,'S32424K'
,'S32424S'
,'S32425D'
,'S32425G'
,'S32425K'
,'S32425S'
,'S32426D'
,'S32426G'
,'S32426K'
,'S32426S'
,'S32431D'
,'S32431G'
,'S32431K'
,'S32431S'
,'S32432D'
,'S32432G'
,'S32432K'
,'S32432S'
,'S32433D'
,'S32433G'
,'S32433K'
,'S32433S'
,'S32434D'
,'S32434G'
,'S32434K'
,'S32434S'
,'S32435D'
,'S32435G'
,'S32435K'
,'S32435S'
,'S32436D'
,'S32436G'
,'S32436K'
,'S32436S'
,'S32441D'
,'S32441G'
,'S32441K'
,'S32441S'
,'S32442D'
,'S32442G'
,'S32442K'
,'S32442S'
,'S32443D'
,'S32443G'
,'S32443K'
,'S32443S'
,'S32444D'
,'S32444G'
,'S32444K'
,'S32444S'
,'S32445D'
,'S32445G'
,'S32445K'
,'S32445S'
,'S32446D'
,'S32446G'
,'S32446K'
,'S32446S'
,'S32451D'
,'S32451G'
,'S32451K'
,'S32451S'
,'S32452D'
,'S32452G'
,'S32452K'
,'S32452S'
,'S32453D'
,'S32453G'
,'S32453K'
,'S32453S'
,'S32454D'
,'S32454G'
,'S32454K'
,'S32454S'
,'S32455D'
,'S32455G'
,'S32455K'
,'S32455S'
,'S32456D'
,'S32456G'
,'S32456K'
,'S32456S'
,'S32461D'
,'S32461G'
,'S32461K'
,'S32461S'
,'S32462D'
,'S32462G'
,'S32462K'
,'S32462S'
,'S32463D'
,'S32463G'
,'S32463K'
,'S32463S'
,'S32464D'
,'S32464G'
,'S32464K'
,'S32464S'
,'S32465D'
,'S32465G'
,'S32465K'
,'S32465S'
,'S32466D'
,'S32466G'
,'S32466K'
,'S32466S'
,'S32471D'
,'S32471G'
,'S32471K'
,'S32471S'
,'S32472D'
,'S32472G'
,'S32472K'
,'S32472S'
,'S32473D'
,'S32473G'
,'S32473K'
,'S32473S'
,'S32474D'
,'S32474G'
,'S32474K'
,'S32474S'
,'S32475D'
,'S32475G'
,'S32475K'
,'S32475S'
,'S32476D'
,'S32476G'
,'S32476K'
,'S32476S'
,'S32481D'
,'S32481G'
,'S32481K'
,'S32481S'
,'S32482D'
,'S32482G'
,'S32482K'
,'S32482S'
,'S32483D'
,'S32483G'
,'S32483K'
,'S32483S'
,'S32484D'
,'S32484G'
,'S32484K'
,'S32484S'
,'S32485D'
,'S32485G'
,'S32485K'
,'S32485S'
,'S32486D'
,'S32486G'
,'S32486K'
,'S32486S'
,'S32491D'
,'S32491G'
,'S32491K'
,'S32491S'
,'S32492D'
,'S32492G'
,'S32492K'
,'S32492S'
,'S32499D'
,'S32499G'
,'S32499K'
,'S32499S'
,'S32501D'
,'S32501G'
,'S32501K'
,'S32501S'
,'S32502D'
,'S32502G'
,'S32502K'
,'S32502S'
,'S32509D'
,'S32509G'
,'S32509K'
,'S32509S'
,'S32511D'
,'S32511G'
,'S32511K'
,'S32511S'
,'S32512D'
,'S32512G'
,'S32512K'
,'S32512S'
,'S32519D'
,'S32519G'
,'S32519K'
,'S32519S'
,'S32591D'
,'S32591G'
,'S32591K'
,'S32591S'
,'S32592D'
,'S32592G'
,'S32592K'
,'S32592S'
,'S32599D'
,'S32599G'
,'S32599K'
,'S32599S'
,'S32601D'
,'S32601G'
,'S32601K'
,'S32601S'
,'S32602D'
,'S32602G'
,'S32602K'
,'S32602S'
,'S32609D'
,'S32609G'
,'S32609K'
,'S32609S'
,'S32611D'
,'S32611G'
,'S32611K'
,'S32611S'
,'S32612D'
,'S32612G'
,'S32612K'
,'S32612S'
,'S32613D'
,'S32613G'
,'S32613K'
,'S32613S'
,'S32614D'
,'S32614G'
,'S32614K'
,'S32614S'
,'S32615D'
,'S32615G'
,'S32615K'
,'S32615S'
,'S32616D'
,'S32616G'
,'S32616K'
,'S32616S'
,'S32691D'
,'S32691G'
,'S32691K'
,'S32691S'
,'S32692D'
,'S32692G'
,'S32692K'
,'S32692S'
,'S32699D'
,'S32699G'
,'S32699K'
,'S32699S'
,'S32810D'
,'S32810G'
,'S32810K'
,'S32810S'
,'S32811D'
,'S32811G'
,'S32811K'
,'S32811S'
,'S3282XD'
,'S3282XG'
,'S3282XK'
,'S3282XS'
,'S3289XD'
,'S3289XG'
,'S3289XK'
,'S3289XS'
,'S329XXD'
,'S329XXG'
,'S329XXK'
,'S329XXS'
,'S330XXD'
,'S330XXS'
,'S33100D'
,'S33100S'
,'S33101D'
,'S33101S'
,'S33110D'
,'S33110S'
,'S33111D'
,'S33111S'
,'S33120D'
,'S33120S'
,'S33121D'
,'S33121S'
,'S33130D'
,'S33130S'
,'S33131D'
,'S33131S'
,'S33140D'
,'S33140S'
,'S33141D'
,'S33141S'
,'S332XXD'
,'S332XXS'
,'S3330XD'
,'S3330XS'
,'S3339XD'
,'S3339XS'
,'S334XXD'
,'S334XXS'
,'S335XXD'
,'S335XXS'
,'S336XXD'
,'S336XXS'
,'S338XXD'
,'S338XXS'
,'S339XXD'
,'S339XXS'
,'S3401XD'
,'S3401XS'
,'S3402XD'
,'S3402XS'
,'S34101D'
,'S34101S'
,'S34102D'
,'S34102S'
,'S34103D'
,'S34103S'
,'S34104D'
,'S34104S'
,'S34105D'
,'S34105S'
,'S34109D'
,'S34109S'
,'S34111D'
,'S34111S'
,'S34112D'
,'S34112S'
,'S34113D'
,'S34113S'
,'S34114D'
,'S34114S'
,'S34115D'
,'S34115S'
,'S34119D'
,'S34119S'
,'S34121D'
,'S34121S'
,'S34122D'
,'S34122S'
,'S34123D'
,'S34123S'
,'S34124D'
,'S34124S'
,'S34125D'
,'S34125S'
,'S34129D'
,'S34129S'
,'S34131D'
,'S34131S'
,'S34132D'
,'S34132S'
,'S34139D'
,'S34139S'
,'S3421XD'
,'S3421XS'
,'S3422XD'
,'S3422XS'
,'S343XXD'
,'S343XXS'
,'S344XXD'
,'S344XXS'
,'S345XXD'
,'S345XXS'
,'S346XXD'
,'S346XXS'
,'S348XXD'
,'S348XXS'
,'S349XXD'
,'S349XXS'
,'S3500XD'
,'S3500XS'
,'S3501XD'
,'S3501XS'
,'S3502XD'
,'S3502XS'
,'S3509XD'
,'S3509XS'
,'S3510XD'
,'S3510XS'
,'S3511XD'
,'S3511XS'
,'S3512XD'
,'S3512XS'
,'S3519XD'
,'S3519XS'
,'S35211D'
,'S35211S'
,'S35212D'
,'S35212S'
,'S35218D'
,'S35218S'
,'S35219D'
,'S35219S'
,'S35221D'
,'S35221S'
,'S35222D'
,'S35222S'
,'S35228D'
,'S35228S'
,'S35229D'
,'S35229S'
,'S35231D'
,'S35231S'
,'S35232D'
,'S35232S'
,'S35238D'
,'S35238S'
,'S35239D'
,'S35239S'
,'S35291D'
,'S35291S'
,'S35292D'
,'S35292S'
,'S35298D'
,'S35298S'
,'S35299D'
,'S35299S'
,'S35311D'
,'S35311S'
,'S35318D'
,'S35318S'
,'S35319D'
,'S35319S'
,'S35321D'
,'S35321S'
,'S35328D'
,'S35328S'
,'S35329D'
,'S35329S'
,'S35331D'
,'S35331S'
,'S35338D'
,'S35338S'
,'S35339D'
,'S35339S'
,'S35341D'
,'S35341S'
,'S35348D'
,'S35348S'
,'S35349D'
,'S35349S'
,'S35401D'
,'S35401S'
,'S35402D'
,'S35402S'
,'S35403D'
,'S35403S'
,'S35404D'
,'S35404S'
,'S35405D'
,'S35405S'
,'S35406D'
,'S35406S'
,'S35411D'
,'S35411S'
,'S35412D'
,'S35412S'
,'S35413D'
,'S35413S'
,'S35414D'
,'S35414S'
,'S35415D'
,'S35415S'
,'S35416D'
,'S35416S'
,'S35491D'
,'S35491S'
,'S35492D'
,'S35492S'
,'S35493D'
,'S35493S'
,'S35494D'
,'S35494S'
,'S35495D'
,'S35495S'
,'S35496D'
,'S35496S'
,'S3550XD'
,'S3550XS'
,'S35511D'
,'S35511S'
,'S35512D'
,'S35512S'
,'S35513D'
,'S35513S'
,'S35514D'
,'S35514S'
,'S35515D'
,'S35515S'
,'S35516D'
,'S35516S'
,'S35531D'
,'S35531S'
,'S35532D'
,'S35532S'
,'S35533D'
,'S35533S'
,'S35534D'
,'S35534S'
,'S35535D'
,'S35535S'
,'S35536D'
,'S35536S'
,'S3559XD'
,'S3559XS'
,'S358X1D'
,'S358X1S'
,'S358X8D'
,'S358X8S'
,'S358X9D'
,'S358X9S'
,'S3590XD'
,'S3590XS'
,'S3591XD'
,'S3591XS'
,'S3599XD'
,'S3599XS'
,'S3600XD'
,'S3600XS'
,'S36020D'
,'S36020S'
,'S36021D'
,'S36021S'
,'S36029D'
,'S36029S'
,'S36030D'
,'S36030S'
,'S36031D'
,'S36031S'
,'S36032D'
,'S36032S'
,'S36039D'
,'S36039S'
,'S3609XD'
,'S3609XS'
,'S36112D'
,'S36112S'
,'S36113D'
,'S36113S'
,'S36114D'
,'S36114S'
,'S36115D'
,'S36115S'
,'S36116D'
,'S36116S'
,'S36118D'
,'S36118S'
,'S36119D'
,'S36119S'
,'S36122D'
,'S36122S'
,'S36123D'
,'S36123S'
,'S36128D'
,'S36128S'
,'S36129D'
,'S36129S'
,'S3613XD'
,'S3613XS'
,'S36200D'
,'S36200S'
,'S36201D'
,'S36201S'
,'S36202D'
,'S36202S'
,'S36209D'
,'S36209S'
,'S36220D'
,'S36220S'
,'S36221D'
,'S36221S'
,'S36222D'
,'S36222S'
,'S36229D'
,'S36229S'
,'S36230D'
,'S36230S'
,'S36231D'
,'S36231S'
,'S36232D'
,'S36232S'
,'S36239D'
,'S36239S'
,'S36240D'
,'S36240S'
,'S36241D'
,'S36241S'
,'S36242D'
,'S36242S'
,'S36249D'
,'S36249S'
,'S36250D'
,'S36250S'
,'S36251D'
,'S36251S'
,'S36252D'
,'S36252S'
,'S36259D'
,'S36259S'
,'S36260D'
,'S36260S'
,'S36261D'
,'S36261S'
,'S36262D'
,'S36262S'
,'S36269D'
,'S36269S'
,'S36290D'
,'S36290S'
,'S36291D'
,'S36291S'
,'S36292D'
,'S36292S'
,'S36299D'
,'S36299S'
,'S3630XD'
,'S3630XS'
,'S3632XD'
,'S3632XS'
,'S3633XD'
,'S3633XS'
,'S3639XD'
,'S3639XS'
,'S36400D'
,'S36400S'
,'S36408D'
,'S36408S'
,'S36409D'
,'S36409S'
,'S36410D'
,'S36410S'
,'S36418D'
,'S36418S'
,'S36419D'
,'S36419S'
,'S36420D'
,'S36420S'
,'S36428D'
,'S36428S'
,'S36429D'
,'S36429S'
,'S36430D'
,'S36430S'
,'S36438D'
,'S36438S'
,'S36439D'
,'S36439S'
,'S36490D'
,'S36490S'
,'S36498D'
,'S36498S'
,'S36499D'
,'S36499S'
,'S36500D'
,'S36500S'
,'S36501D'
,'S36501S'
,'S36502D'
,'S36502S'
,'S36503D'
,'S36503S'
,'S36508D'
,'S36508S'
,'S36509D'
,'S36509S'
,'S36510D'
,'S36510S'
,'S36511D'
,'S36511S'
,'S36512D'
,'S36512S'
,'S36513D'
,'S36513S'
,'S36518D'
,'S36518S'
,'S36519D'
,'S36519S'
,'S36520D'
,'S36520S'
,'S36521D'
,'S36521S'
,'S36522D'
,'S36522S'
,'S36523D'
,'S36523S'
,'S36528D'
,'S36528S'
,'S36529D'
,'S36529S'
,'S36530D'
,'S36530S'
,'S36531D'
,'S36531S'
,'S36532D'
,'S36532S'
,'S36533D'
,'S36533S'
,'S36538D'
,'S36538S'
,'S36539D'
,'S36539S'
,'S36590D'
,'S36590S'
,'S36591D'
,'S36591S'
,'S36592D'
,'S36592S'
,'S36593D'
,'S36593S'
,'S36598D'
,'S36598S'
,'S36599D'
,'S36599S'
,'S3660XD'
,'S3660XS'
,'S3661XD'
,'S3661XS'
,'S3662XD'
,'S3662XS'
,'S3663XD'
,'S3663XS'
,'S3669XD'
,'S3669XS'
,'S3681XD'
,'S3681XS'
,'S36892D'
,'S36892S'
,'S36893D'
,'S36893S'
,'S36898D'
,'S36898S'
,'S36899D'
,'S36899S'
,'S3690XD'
,'S3690XS'
,'S3692XD'
,'S3692XS'
,'S3693XD'
,'S3693XS'
,'S3699XD'
,'S3699XS'
,'S37001D'
,'S37001S'
,'S37002D'
,'S37002S'
,'S37009D'
,'S37009S'
,'S37011D'
,'S37011S'
,'S37012D'
,'S37012S'
,'S37019D'
,'S37019S'
,'S37021D'
,'S37021S'
,'S37022D'
,'S37022S'
,'S37029D'
,'S37029S'
,'S37031D'
,'S37031S'
,'S37032D'
,'S37032S'
,'S37039D'
,'S37039S'
,'S37041D'
,'S37041S'
,'S37042D'
,'S37042S'
,'S37049D'
,'S37049S'
,'S37051D'
,'S37051S'
,'S37052D'
,'S37052S'
,'S37059D'
,'S37059S'
,'S37061D'
,'S37061S'
,'S37062D'
,'S37062S'
,'S37069D'
,'S37069S'
,'S37091D'
,'S37091S'
,'S37092D'
,'S37092S'
,'S37099D'
,'S37099S'
,'S3710XD'
,'S3710XS'
,'S3712XD'
,'S3712XS'
,'S3713XD'
,'S3713XS'
,'S3719XD'
,'S3719XS'
,'S3720XD'
,'S3720XS'
,'S3722XD'
,'S3722XS'
,'S3723XD'
,'S3723XS'
,'S3729XD'
,'S3729XS'
,'S3730XD'
,'S3730XS'
,'S3732XD'
,'S3732XS'
,'S3733XD'
,'S3733XS'
,'S3739XD'
,'S3739XS'
,'S37401D'
,'S37401S'
,'S37402D'
,'S37402S'
,'S37409D'
,'S37409S'
,'S37421D'
,'S37421S'
,'S37422D'
,'S37422S'
,'S37429D'
,'S37429S'
,'S37431D'
,'S37431S'
,'S37432D'
,'S37432S'
,'S37439D'
,'S37439S'
,'S37491D'
,'S37491S'
,'S37492D'
,'S37492S'
,'S37499D'
,'S37499S'
,'S37501D'
,'S37501S'
,'S37502D'
,'S37502S'
,'S37509D'
,'S37509S'
,'S37511D'
,'S37511S'
,'S37512D'
,'S37512S'
,'S37519D'
,'S37519S'
,'S37521D'
,'S37521S'
,'S37522D'
,'S37522S'
,'S37529D'
,'S37529S'
,'S37531D'
,'S37531S'
,'S37532D'
,'S37532S'
,'S37539D'
,'S37539S'
,'S37591D'
,'S37591S'
,'S37592D'
,'S37592S'
,'S37599D'
,'S37599S'
,'S3760XD'
,'S3760XS'
,'S3762XD'
,'S3762XS'
,'S3763XD'
,'S3763XS'
,'S3769XD'
,'S3769XS'
,'S37812D'
,'S37812S'
,'S37813D'
,'S37813S'
,'S37818D'
,'S37818S'
,'S37819D'
,'S37819S'
,'S37822D'
,'S37822S'
,'S37823D'
,'S37823S'
,'S37828D'
,'S37828S'
,'S37829D'
,'S37829S'
,'S37892D'
,'S37892S'
,'S37893D'
,'S37893S'
,'S37898D'
,'S37898S'
,'S37899D'
,'S37899S'
,'S3790XD'
,'S3790XS'
,'S3792XD'
,'S3792XS'
,'S3793XD'
,'S3793XS'
,'S3799XD'
,'S3799XS'
,'S38001D'
,'S38001S'
,'S38002D'
,'S38002S'
,'S3801XD'
,'S3801XS'
,'S3802XD'
,'S3802XS'
,'S3803XD'
,'S3803XS'
,'S381XXD'
,'S381XXS'
,'S38211D'
,'S38211S'
,'S38212D'
,'S38212S'
,'S38221D'
,'S38221S'
,'S38222D'
,'S38222S'
,'S38231D'
,'S38231S'
,'S38232D'
,'S38232S'
,'S383XXD'
,'S383XXS'
,'S39001D'
,'S39001S'
,'S39002D'
,'S39002S'
,'S39003D'
,'S39003S'
,'S39011D'
,'S39011S'
,'S39012D'
,'S39012S'
,'S39013D'
,'S39013S'
,'S39021D'
,'S39021S'
,'S39022D'
,'S39022S'
,'S39023D'
,'S39023S'
,'S39091D'
,'S39091S'
,'S39092D'
,'S39092S'
,'S39093D'
,'S39093S'
,'S3981XD'
,'S3981XS'
,'S3982XD'
,'S3982XS'
,'S3983XD'
,'S3983XS'
,'S39840D'
,'S39840S'
,'S39848D'
,'S39848S'
,'S3991XD'
,'S3991XS'
,'S3992XD'
,'S3992XS'
,'S3993XD'
,'S3993XS'
,'S3994XD'
,'S3994XS'
,'S40011D'
,'S40011S'
,'S40012D'
,'S40012S'
,'S40019D'
,'S40019S'
,'S40021D'
,'S40021S'
,'S40022D'
,'S40022S'
,'S40029D'
,'S40029S'
,'S40211D'
,'S40211S'
,'S40212D'
,'S40212S'
,'S40219D'
,'S40219S'
,'S40221D'
,'S40221S'
,'S40222D'
,'S40222S'
,'S40229D'
,'S40229S'
,'S40241D'
,'S40241S'
,'S40242D'
,'S40242S'
,'S40249D'
,'S40249S'
,'S40251D'
,'S40251S'
,'S40252D'
,'S40252S'
,'S40259D'
,'S40259S'
,'S40261D'
,'S40261S'
,'S40262D'
,'S40262S'
,'S40269D'
,'S40269S'
,'S40271D'
,'S40271S'
,'S40272D'
,'S40272S'
,'S40279D'
,'S40279S'
,'S40811D'
,'S40811S'
,'S40812D'
,'S40812S'
,'S40819D'
,'S40819S'
,'S40821D'
,'S40821S'
,'S40822D'
,'S40822S'
,'S40829D'
,'S40829S'
,'S40841D'
,'S40841S'
,'S40842D'
,'S40842S'
,'S40849D'
,'S40849S'
,'S40851D'
,'S40851S'
,'S40852D'
,'S40852S'
,'S40859D'
,'S40859S'
,'S40861D'
,'S40861S'
,'S40862D'
,'S40862S'
,'S40869D'
,'S40869S'
,'S40871D'
,'S40871S'
,'S40872D'
,'S40872S'
,'S40879D'
,'S40879S'
,'S40911D'
,'S40911S'
,'S40912D'
,'S40912S'
,'S40919D'
,'S40919S'
,'S40921D'
,'S40921S'
,'S40922D'
,'S40922S'
,'S40929D'
,'S40929S'
,'S41001D'
,'S41001S'
,'S41002D'
,'S41002S'
,'S41009D'
,'S41009S'
,'S41011D'
,'S41011S'
,'S41012D'
,'S41012S'
,'S41019D'
,'S41019S'
,'S41021D'
,'S41021S'
,'S41022D'
,'S41022S'
,'S41029D'
,'S41029S'
,'S41031D'
,'S41031S'
,'S41032D'
,'S41032S'
,'S41039D'
,'S41039S'
,'S41041D'
,'S41041S'
,'S41042D'
,'S41042S'
,'S41049D'
,'S41049S'
,'S41051D'
,'S41051S'
,'S41052D'
,'S41052S'
,'S41059D'
,'S41059S'
,'S41101D'
,'S41101S'
,'S41102D'
,'S41102S'
,'S41109D'
,'S41109S'
,'S41111D'
,'S41111S'
,'S41112D'
,'S41112S'
,'S41119D'
,'S41119S'
,'S41121D'
,'S41121S'
,'S41122D'
,'S41122S'
,'S41129D'
,'S41129S'
,'S41131D'
,'S41131S'
,'S41132D'
,'S41132S'
,'S41139D'
,'S41139S'
,'S41141D'
,'S41141S'
,'S41142D'
,'S41142S'
,'S41149D'
,'S41149S'
,'S41151D'
,'S41151S'
,'S41152D'
,'S41152S'
,'S41159D'
,'S41159S'
,'S42001D'
,'S42001G'
,'S42001K'
,'S42001P'
,'S42001S'
,'S42002D'
,'S42002G'
,'S42002K'
,'S42002P'
,'S42002S'
,'S42009D'
,'S42009G'
,'S42009K'
,'S42009P'
,'S42009S'
,'S42011D'
,'S42011G'
,'S42011K'
,'S42011P'
,'S42011S'
,'S42012D'
,'S42012G'
,'S42012K'
,'S42012P'
,'S42012S'
,'S42013D'
,'S42013G'
,'S42013K'
,'S42013P'
,'S42013S'
,'S42014D'
,'S42014G'
,'S42014K'
,'S42014P'
,'S42014S'
,'S42015D'
,'S42015G'
,'S42015K'
,'S42015P'
,'S42015S'
,'S42016D'
,'S42016G'
,'S42016K'
,'S42016P'
,'S42016S'
,'S42017D'
,'S42017G'
,'S42017K'
,'S42017P'
,'S42017S'
,'S42018D'
,'S42018G'
,'S42018K'
,'S42018P'
,'S42018S'
,'S42019D'
,'S42019G'
,'S42019K'
,'S42019P'
,'S42019S'
,'S42021D'
,'S42021G'
,'S42021K'
,'S42021P'
,'S42021S'
,'S42022D'
,'S42022G'
,'S42022K'
,'S42022P'
,'S42022S'
,'S42023D'
,'S42023G'
,'S42023K'
,'S42023P'
,'S42023S'
,'S42024D'
,'S42024G'
,'S42024K'
,'S42024P'
,'S42024S'
,'S42025D'
,'S42025G'
,'S42025K'
,'S42025P'
,'S42025S'
,'S42026D'
,'S42026G'
,'S42026K'
,'S42026P'
,'S42026S'
,'S42031D'
,'S42031G'
,'S42031K'
,'S42031P'
,'S42031S'
,'S42032D'
,'S42032G'
,'S42032K'
,'S42032P'
,'S42032S'
,'S42033D'
,'S42033G'
,'S42033K'
,'S42033P'
,'S42033S'
,'S42034D'
,'S42034G'
,'S42034K'
,'S42034P'
,'S42034S'
,'S42035D'
,'S42035G'
,'S42035K'
,'S42035P'
,'S42035S'
,'S42036D'
,'S42036G'
,'S42036K'
,'S42036P'
,'S42036S'
,'S42101D'
,'S42101G'
,'S42101K'
,'S42101P'
,'S42101S'
,'S42102D'
,'S42102G'
,'S42102K'
,'S42102P'
,'S42102S'
,'S42109D'
,'S42109G'
,'S42109K'
,'S42109P'
,'S42109S'
,'S42111D'
,'S42111G'
,'S42111K'
,'S42111P'
,'S42111S'
,'S42112D'
,'S42112G'
,'S42112K'
,'S42112P'
,'S42112S'
,'S42113D'
,'S42113G'
,'S42113K'
,'S42113P'
,'S42113S'
,'S42114D'
,'S42114G'
,'S42114K'
,'S42114P'
,'S42114S'
,'S42115D'
,'S42115G'
,'S42115K'
,'S42115P'
,'S42115S'
,'S42116D'
,'S42116G'
,'S42116K'
,'S42116P'
,'S42116S'
,'S42121D'
,'S42121G'
,'S42121K'
,'S42121P'
,'S42121S'
,'S42122D'
,'S42122G'
,'S42122K'
,'S42122P'
,'S42122S'
,'S42123D'
,'S42123G'
,'S42123K'
,'S42123P'
,'S42123S'
,'S42124D'
,'S42124G'
,'S42124K'
,'S42124P'
,'S42124S'
,'S42125D'
,'S42125G'
,'S42125K'
,'S42125P'
,'S42125S'
,'S42126D'
,'S42126G'
,'S42126K'
,'S42126P'
,'S42126S'
,'S42131D'
,'S42131G'
,'S42131K'
,'S42131P'
,'S42131S'
,'S42132D'
,'S42132G'
,'S42132K'
,'S42132P'
,'S42132S'
,'S42133D'
,'S42133G'
,'S42133K'
,'S42133P'
,'S42133S'
,'S42134D'
,'S42134G'
,'S42134K'
,'S42134P'
,'S42134S'
,'S42135D'
,'S42135G'
,'S42135K'
,'S42135P'
,'S42135S'
,'S42136D'
,'S42136G'
,'S42136K'
,'S42136P'
,'S42136S'
,'S42141D'
,'S42141G'
,'S42141K'
,'S42141P'
,'S42141S'
,'S42142D'
,'S42142G'
,'S42142K'
,'S42142P'
,'S42142S'
,'S42143D'
,'S42143G'
,'S42143K'
,'S42143P'
,'S42143S'
,'S42144D'
,'S42144G'
,'S42144K'
,'S42144P'
,'S42144S'
,'S42145D'
,'S42145G'
,'S42145K'
,'S42145P'
,'S42145S'
,'S42146D'
,'S42146G'
,'S42146K'
,'S42146P'
,'S42146S'
,'S42151D'
,'S42151G'
,'S42151K'
,'S42151P'
,'S42151S'
,'S42152D'
,'S42152G'
,'S42152K'
,'S42152P'
,'S42152S'
,'S42153D'
,'S42153G'
,'S42153K'
,'S42153P'
,'S42153S'
,'S42154D'
,'S42154G'
,'S42154K'
,'S42154P'
,'S42154S'
,'S42155D'
,'S42155G'
,'S42155K'
,'S42155P'
,'S42155S'
,'S42156D'
,'S42156G'
,'S42156K'
,'S42156P'
,'S42156S'
,'S42191D'
,'S42191G'
,'S42191K'
,'S42191P'
,'S42191S'
,'S42192D'
,'S42192G'
,'S42192K'
,'S42192P'
,'S42192S'
,'S42199D'
,'S42199G'
,'S42199K'
,'S42199P'
,'S42199S'
,'S42201D'
,'S42201G'
,'S42201K'
,'S42201P'
,'S42201S'
,'S42202D'
,'S42202G'
,'S42202K'
,'S42202P'
,'S42202S'
,'S42209D'
,'S42209G'
,'S42209K'
,'S42209P'
,'S42209S'
,'S42211D'
,'S42211G'
,'S42211K'
,'S42211P'
,'S42211S'
,'S42212D'
,'S42212G'
,'S42212K'
,'S42212P'
,'S42212S'
,'S42213D'
,'S42213G'
,'S42213K'
,'S42213P'
,'S42213S'
,'S42214D'
,'S42214G'
,'S42214K'
,'S42214P'
,'S42214S'
,'S42215D'
,'S42215G'
,'S42215K'
,'S42215P'
,'S42215S'
,'S42216D'
,'S42216G'
,'S42216K'
,'S42216P'
,'S42216S'
,'S42221D'
,'S42221G'
,'S42221K'
,'S42221P'
,'S42221S'
,'S42222D'
,'S42222G'
,'S42222K'
,'S42222P'
,'S42222S'
,'S42223D'
,'S42223G'
,'S42223K'
,'S42223P'
,'S42223S'
,'S42224D'
,'S42224G'
,'S42224K'
,'S42224P'
,'S42224S'
,'S42225D'
,'S42225G'
,'S42225K'
,'S42225P'
,'S42225S'
,'S42226D'
,'S42226G'
,'S42226K'
,'S42226P'
,'S42226S'
,'S42231D'
,'S42231G'
,'S42231K'
,'S42231P'
,'S42231S'
,'S42232D'
,'S42232G'
,'S42232K'
,'S42232P'
,'S42232S'
,'S42239D'
,'S42239G'
,'S42239K'
,'S42239P'
,'S42239S'
,'S42241D'
,'S42241G'
,'S42241K'
,'S42241P'
,'S42241S'
,'S42242D'
,'S42242G'
,'S42242K'
,'S42242P'
,'S42242S'
,'S42249D'
,'S42249G'
,'S42249K'
,'S42249P'
,'S42249S'
,'S42251D'
,'S42251G'
,'S42251K'
,'S42251P'
,'S42251S'
,'S42252D'
,'S42252G'
,'S42252K'
,'S42252P'
,'S42252S'
,'S42253D'
,'S42253G'
,'S42253K'
,'S42253P'
,'S42253S'
,'S42254D'
,'S42254G'
,'S42254K'
,'S42254P'
,'S42254S'
,'S42255D'
,'S42255G'
,'S42255K'
,'S42255P'
,'S42255S'
,'S42256D'
,'S42256G'
,'S42256K'
,'S42256P'
,'S42256S'
,'S42261D'
,'S42261G'
,'S42261K'
,'S42261P'
,'S42261S'
,'S42262D'
,'S42262G'
,'S42262K'
,'S42262P'
,'S42262S'
,'S42263D'
,'S42263G'
,'S42263K'
,'S42263P'
,'S42263S'
,'S42264D'
,'S42264G'
,'S42264K'
,'S42264P'
,'S42264S'
,'S42265D'
,'S42265G'
,'S42265K'
,'S42265P'
,'S42265S'
,'S42266D'
,'S42266G'
,'S42266K'
,'S42266P'
,'S42266S'
,'S42271D'
,'S42271G'
,'S42271K'
,'S42271P'
,'S42271S'
,'S42272D'
,'S42272G'
,'S42272K'
,'S42272P'
,'S42272S'
,'S42279D'
,'S42279G'
,'S42279K'
,'S42279P'
,'S42279S'
,'S42291D'
,'S42291G'
,'S42291K'
,'S42291P'
,'S42291S'
,'S42292D'
,'S42292G'
,'S42292K'
,'S42292P'
,'S42292S'
,'S42293D'
,'S42293G'
,'S42293K'
,'S42293P'
,'S42293S'
,'S42294D'
,'S42294G'
,'S42294K'
,'S42294P'
,'S42294S'
,'S42295D'
,'S42295G'
,'S42295K'
,'S42295P'
,'S42295S'
,'S42296D'
,'S42296G'
,'S42296K'
,'S42296P'
,'S42296S'
,'S42301D'
,'S42301G'
,'S42301K'
,'S42301P'
,'S42301S'
,'S42302D'
,'S42302G'
,'S42302K'
,'S42302P'
,'S42302S'
,'S42309D'
,'S42309G'
,'S42309K'
,'S42309P'
,'S42309S'
,'S42311D'
,'S42311G'
,'S42311K'
,'S42311P'
,'S42311S'
,'S42312D'
,'S42312G'
,'S42312K'
,'S42312P'
,'S42312S'
,'S42319D'
,'S42319G'
,'S42319K'
,'S42319P'
,'S42319S'
,'S42321D'
,'S42321G'
,'S42321K'
,'S42321P'
,'S42321S'
,'S42322D'
,'S42322G'
,'S42322K'
,'S42322P'
,'S42322S'
,'S42323D'
,'S42323G'
,'S42323K'
,'S42323P'
,'S42323S'
,'S42324D'
,'S42324G'
,'S42324K'
,'S42324P'
,'S42324S'
,'S42325D'
,'S42325G'
,'S42325K'
,'S42325P'
,'S42325S'
,'S42326D'
,'S42326G'
,'S42326K'
,'S42326P'
,'S42326S'
,'S42331D'
,'S42331G'
,'S42331K'
,'S42331P'
,'S42331S'
,'S42332D'
,'S42332G'
,'S42332K'
,'S42332P'
,'S42332S'
,'S42333D'
,'S42333G'
,'S42333K'
,'S42333P'
,'S42333S'
,'S42334D'
,'S42334G'
,'S42334K'
,'S42334P'
,'S42334S'
,'S42335D'
,'S42335G'
,'S42335K'
,'S42335P'
,'S42335S'
,'S42336D'
,'S42336G'
,'S42336K'
,'S42336P'
,'S42336S'
,'S42341D'
,'S42341G'
,'S42341K'
,'S42341P'
,'S42341S'
,'S42342D'
,'S42342G'
,'S42342K'
,'S42342P'
,'S42342S'
,'S42343D'
,'S42343G'
,'S42343K'
,'S42343P'
,'S42343S'
,'S42344D'
,'S42344G'
,'S42344K'
,'S42344P'
,'S42344S'
,'S42345D'
,'S42345G'
,'S42345K'
,'S42345P'
,'S42345S'
,'S42346D'
,'S42346G'
,'S42346K'
,'S42346P'
,'S42346S'
,'S42351D'
,'S42351G'
,'S42351K'
,'S42351P'
,'S42351S'
,'S42352D'
,'S42352G'
,'S42352K'
,'S42352P'
,'S42352S'
,'S42353D'
,'S42353G'
,'S42353K'
,'S42353P'
,'S42353S'
,'S42354D'
,'S42354G'
,'S42354K'
,'S42354P'
,'S42354S'
,'S42355D'
,'S42355G'
,'S42355K'
,'S42355P'
,'S42355S'
,'S42356D'
,'S42356G'
,'S42356K'
,'S42356P'
,'S42356S'
,'S42361D'
,'S42361G'
,'S42361K'
,'S42361P'
,'S42361S'
,'S42362D'
,'S42362G'
,'S42362K'
,'S42362P'
,'S42362S'
,'S42363D'
,'S42363G'
,'S42363K'
,'S42363P'
,'S42363S'
,'S42364D'
,'S42364G'
,'S42364K'
,'S42364P'
,'S42364S'
,'S42365D'
,'S42365G'
,'S42365K'
,'S42365P'
,'S42365S'
,'S42366D'
,'S42366G'
,'S42366K'
,'S42366P'
,'S42366S'
,'S42391D'
,'S42391G'
,'S42391K'
,'S42391P'
,'S42391S'
,'S42392D'
,'S42392G'
,'S42392K'
,'S42392P'
,'S42392S'
,'S42399D'
,'S42399G'
,'S42399K'
,'S42399P'
,'S42399S'
,'S42401D'
,'S42401G'
,'S42401K'
,'S42401P'
,'S42401S'
,'S42402D'
,'S42402G'
,'S42402K'
,'S42402P'
,'S42402S'
,'S42409D'
,'S42409G'
,'S42409K'
,'S42409P'
,'S42409S'
,'S42411D'
,'S42411G'
,'S42411K'
,'S42411P'
,'S42411S'
,'S42412D'
,'S42412G'
,'S42412K'
,'S42412P'
,'S42412S'
,'S42413D'
,'S42413G'
,'S42413K'
,'S42413P'
,'S42413S'
,'S42414D'
,'S42414G'
,'S42414K'
,'S42414P'
,'S42414S'
,'S42415D'
,'S42415G'
,'S42415K'
,'S42415P'
,'S42415S'
,'S42416D'
,'S42416G'
,'S42416K'
,'S42416P'
,'S42416S'
,'S42421D'
,'S42421G'
,'S42421K'
,'S42421P'
,'S42421S'
,'S42422D'
,'S42422G'
,'S42422K'
,'S42422P'
,'S42422S'
,'S42423D'
,'S42423G'
,'S42423K'
,'S42423P'
,'S42423S'
,'S42424D'
,'S42424G'
,'S42424K'
,'S42424P'
,'S42424S'
,'S42425D'
,'S42425G'
,'S42425K'
,'S42425P'
,'S42425S'
,'S42426D'
,'S42426G'
,'S42426K'
,'S42426P'
,'S42426S'
,'S42431D'
,'S42431G'
,'S42431K'
,'S42431P'
,'S42431S'
,'S42432D'
,'S42432G'
,'S42432K'
,'S42432P'
,'S42432S'
,'S42433D'
,'S42433G'
,'S42433K'
,'S42433P'
,'S42433S'
,'S42434D'
,'S42434G'
,'S42434K'
,'S42434P'
,'S42434S'
,'S42435D'
,'S42435G'
,'S42435K'
,'S42435P'
,'S42435S'
,'S42436D'
,'S42436G'
,'S42436K'
,'S42436P'
,'S42436S'
,'S42441D'
,'S42441G'
,'S42441K'
,'S42441P'
,'S42441S'
,'S42442D'
,'S42442G'
,'S42442K'
,'S42442P'
,'S42442S'
,'S42443D'
,'S42443G'
,'S42443K'
,'S42443P'
,'S42443S'
,'S42444D'
,'S42444G'
,'S42444K'
,'S42444P'
,'S42444S'
,'S42445D'
,'S42445G'
,'S42445K'
,'S42445P'
,'S42445S'
,'S42446D'
,'S42446G'
,'S42446K'
,'S42446P'
,'S42446S'
,'S42447D'
,'S42447G'
,'S42447K'
,'S42447P'
,'S42447S'
,'S42448D'
,'S42448G'
,'S42448K'
,'S42448P'
,'S42448S'
,'S42449D'
,'S42449G'
,'S42449K'
,'S42449P'
,'S42449S'
,'S42451D'
,'S42451G'
,'S42451K'
,'S42451P'
,'S42451S'
,'S42452D'
,'S42452G'
,'S42452K'
,'S42452P'
,'S42452S'
,'S42453D'
,'S42453G'
,'S42453K'
,'S42453P'
,'S42453S'
,'S42454D'
,'S42454G'
,'S42454K'
,'S42454P'
,'S42454S'
,'S42455D'
,'S42455G'
,'S42455K'
,'S42455P'
,'S42455S'
,'S42456D'
,'S42456G'
,'S42456K'
,'S42456P'
,'S42456S'
,'S42461D'
,'S42461G'
,'S42461K'
,'S42461P'
,'S42461S'
,'S42462D'
,'S42462G'
,'S42462K'
,'S42462P'
,'S42462S'
,'S42463D'
,'S42463G'
,'S42463K'
,'S42463P'
,'S42463S'
,'S42464D'
,'S42464G'
,'S42464K'
,'S42464P'
,'S42464S'
,'S42465D'
,'S42465G'
,'S42465K'
,'S42465P'
,'S42465S'
,'S42466D'
,'S42466G'
,'S42466K'
,'S42466P'
,'S42466S'
,'S42471D'
,'S42471G'
,'S42471K'
,'S42471P'
,'S42471S'
,'S42472D'
,'S42472G'
,'S42472K'
,'S42472P'
,'S42472S'
,'S42473D'
,'S42473G'
,'S42473K'
,'S42473P'
,'S42473S'
,'S42474D'
,'S42474G'
,'S42474K'
,'S42474P'
,'S42474S'
,'S42475D'
,'S42475G'
,'S42475K'
,'S42475P'
,'S42475S'
,'S42476D'
,'S42476G'
,'S42476K'
,'S42476P'
,'S42476S'
,'S42481D'
,'S42481G'
,'S42481K'
,'S42481P'
,'S42481S'
,'S42482D'
,'S42482G'
,'S42482K'
,'S42482P'
,'S42482S'
,'S42489D'
,'S42489G'
,'S42489K'
,'S42489P'
,'S42489S'
,'S42491D'
,'S42491G'
,'S42491K'
,'S42491P'
,'S42491S'
,'S42492D'
,'S42492G'
,'S42492K'
,'S42492P'
,'S42492S'
,'S42493D'
,'S42493G'
,'S42493K'
,'S42493P'
,'S42493S'
,'S42494D'
,'S42494G'
,'S42494K'
,'S42494P'
,'S42494S'
,'S42495D'
,'S42495G'
,'S42495K'
,'S42495P'
,'S42495S'
,'S42496D'
,'S42496G'
,'S42496K'
,'S42496P'
,'S42496S'
,'S4290XD'
,'S4290XG'
,'S4290XK'
,'S4290XP'
,'S4290XS'
,'S4291XD'
,'S4291XG'
,'S4291XK'
,'S4291XP'
,'S4291XS'
,'S4292XD'
,'S4292XG'
,'S4292XK'
,'S4292XP'
,'S4292XS'
,'S43001D'
,'S43001S'
,'S43002D'
,'S43002S'
,'S43003D'
,'S43003S'
,'S43004D'
,'S43004S'
,'S43005D'
,'S43005S'
,'S43006D'
,'S43006S'
,'S43011D'
,'S43011S'
,'S43012D'
,'S43012S'
,'S43013D'
,'S43013S'
,'S43014D'
,'S43014S'
,'S43015D'
,'S43015S'
,'S43016D'
,'S43016S'
,'S43021D'
,'S43021S'
,'S43022D'
,'S43022S'
,'S43023D'
,'S43023S'
,'S43024D'
,'S43024S'
,'S43025D'
,'S43025S'
,'S43026D'
,'S43026S'
,'S43031D'
,'S43031S'
,'S43032D'
,'S43032S'
,'S43033D'
,'S43033S'
,'S43034D'
,'S43034S'
,'S43035D'
,'S43035S'
,'S43036D'
,'S43036S'
,'S43081D'
,'S43081S'
,'S43082D'
,'S43082S'
,'S43083D'
,'S43083S'
,'S43084D'
,'S43084S'
,'S43085D'
,'S43085S'
,'S43086D'
,'S43086S'
,'S43101D'
,'S43101S'
,'S43102D'
,'S43102S'
,'S43109D'
,'S43109S'
,'S43111D'
,'S43111S'
,'S43112D'
,'S43112S'
,'S43119D'
,'S43119S'
,'S43121D'
,'S43121S'
,'S43122D'
,'S43122S'
,'S43129D'
,'S43129S'
,'S43131D'
,'S43131S'
,'S43132D'
,'S43132S'
,'S43139D'
,'S43139S'
,'S43141D'
,'S43141S'
,'S43142D'
,'S43142S'
,'S43149D'
,'S43149S'
,'S43151D'
,'S43151S'
,'S43152D'
,'S43152S'
,'S43159D'
,'S43159S'
,'S43201D'
,'S43201S'
,'S43202D'
,'S43202S'
,'S43203D'
,'S43203S'
,'S43204D'
,'S43204S'
,'S43205D'
,'S43205S'
,'S43206D'
,'S43206S'
,'S43211D'
,'S43211S'
,'S43212D'
,'S43212S'
,'S43213D'
,'S43213S'
,'S43214D'
,'S43214S'
,'S43215D'
,'S43215S'
,'S43216D'
,'S43216S'
,'S43221D'
,'S43221S'
,'S43222D'
,'S43222S'
,'S43223D'
,'S43223S'
,'S43224D'
,'S43224S'
,'S43225D'
,'S43225S'
,'S43226D'
,'S43226S'
,'S43301D'
,'S43301S'
,'S43302D'
,'S43302S'
,'S43303D'
,'S43303S'
,'S43304D'
,'S43304S'
,'S43305D'
,'S43305S'
,'S43306D'
,'S43306S'
,'S43311D'
,'S43311S'
,'S43312D'
,'S43312S'
,'S43313D'
,'S43313S'
,'S43314D'
,'S43314S'
,'S43315D'
,'S43315S'
,'S43316D'
,'S43316S'
,'S43391D'
,'S43391S'
,'S43392D'
,'S43392S'
,'S43393D'
,'S43393S'
,'S43394D'
,'S43394S'
,'S43395D'
,'S43395S'
,'S43396D'
,'S43396S'
,'S43401D'
,'S43401S'
,'S43402D'
,'S43402S'
,'S43409D'
,'S43409S'
,'S43411D'
,'S43411S'
,'S43412D'
,'S43412S'
,'S43419D'
,'S43419S'
,'S43421D'
,'S43421S'
,'S43422D'
,'S43422S'
,'S43429D'
,'S43429S'
,'S43431D'
,'S43431S'
,'S43432D'
,'S43432S'
,'S43439D'
,'S43439S'
,'S43491D'
,'S43491S'
,'S43492D'
,'S43492S'
,'S43499D'
,'S43499S'
,'S4350XD'
,'S4350XS'
,'S4351XD'
,'S4351XS'
,'S4352XD'
,'S4352XS'
,'S4360XD'
,'S4360XS'
,'S4361XD'
,'S4361XS'
,'S4362XD'
,'S4362XS'
,'S4380XD'
,'S4380XS'
,'S4381XD'
,'S4381XS'
,'S4382XD'
,'S4382XS'
,'S4390XD'
,'S4390XS'
,'S4391XD'
,'S4391XS'
,'S4392XD'
,'S4392XS'
,'S4400XD'
,'S4400XS'
,'S4401XD'
,'S4401XS'
,'S4402XD'
,'S4402XS'
,'S4410XD'
,'S4410XS'
,'S4411XD'
,'S4411XS'
,'S4412XD'
,'S4412XS'
,'S4420XD'
,'S4420XS'
,'S4421XD'
,'S4421XS'
,'S4422XD'
,'S4422XS'
,'S4430XD'
,'S4430XS'
,'S4431XD'
,'S4431XS'
,'S4432XD'
,'S4432XS'
,'S4440XD'
,'S4440XS'
,'S4441XD'
,'S4441XS'
,'S4442XD'
,'S4442XS'
,'S4450XD'
,'S4450XS'
,'S4451XD'
,'S4451XS'
,'S4452XD'
,'S4452XS'
,'S448X1D'
,'S448X1S'
,'S448X2D'
,'S448X2S'
,'S448X9D'
,'S448X9S'
,'S4490XD'
,'S4490XS'
,'S4491XD'
,'S4491XS'
,'S4492XD'
,'S4492XS'
,'S45001D'
,'S45001S'
,'S45002D'
,'S45002S'
,'S45009D'
,'S45009S'
,'S45011D'
,'S45011S'
,'S45012D'
,'S45012S'
,'S45019D'
,'S45019S'
,'S45091D'
,'S45091S'
,'S45092D'
,'S45092S'
,'S45099D'
,'S45099S'
,'S45101D'
,'S45101S'
,'S45102D'
,'S45102S'
,'S45109D'
,'S45109S'
,'S45111D'
,'S45111S'
,'S45112D'
,'S45112S'
,'S45119D'
,'S45119S'
,'S45191D'
,'S45191S'
,'S45192D'
,'S45192S'
,'S45199D'
,'S45199S'
,'S45201D'
,'S45201S'
,'S45202D'
,'S45202S'
,'S45209D'
,'S45209S'
,'S45211D'
,'S45211S'
,'S45212D'
,'S45212S'
,'S45219D'
,'S45219S'
,'S45291D'
,'S45291S'
,'S45292D'
,'S45292S'
,'S45299D'
,'S45299S'
,'S45301D'
,'S45301S'
,'S45302D'
,'S45302S'
,'S45309D'
,'S45309S'
,'S45311D'
,'S45311S'
,'S45312D'
,'S45312S'
,'S45319D'
,'S45319S'
,'S45391D'
,'S45391S'
,'S45392D'
,'S45392S'
,'S45399D'
,'S45399S'
,'S45801D'
,'S45801S'
,'S45802D'
,'S45802S'
,'S45809D'
,'S45809S'
,'S45811D'
,'S45811S'
,'S45812D'
,'S45812S'
,'S45819D'
,'S45819S'
,'S45891D'
,'S45891S'
,'S45892D'
,'S45892S'
,'S45899D'
,'S45899S'
,'S45901D'
,'S45901S'
,'S45902D'
,'S45902S'
,'S45909D'
,'S45909S'
,'S45911D'
,'S45911S'
,'S45912D'
,'S45912S'
,'S45919D'
,'S45919S'
,'S45991D'
,'S45991S'
,'S45992D'
,'S45992S'
,'S45999D'
,'S45999S'
,'S46001D'
,'S46001S'
,'S46002D'
,'S46002S'
,'S46009D'
,'S46009S'
,'S46011D'
,'S46011S'
,'S46012D'
,'S46012S'
,'S46019D'
,'S46019S'
,'S46021D'
,'S46021S'
,'S46022D'
,'S46022S'
,'S46029D'
,'S46029S'
,'S46091D'
,'S46091S'
,'S46092D'
,'S46092S'
,'S46099D'
,'S46099S'
,'S46101D'
,'S46101S'
,'S46102D'
,'S46102S'
,'S46109D'
,'S46109S'
,'S46111D'
,'S46111S'
,'S46112D'
,'S46112S'
,'S46119D'
,'S46119S'
,'S46121D'
,'S46121S'
,'S46122D'
,'S46122S'
,'S46129D'
,'S46129S'
,'S46191D'
,'S46191S'
,'S46192D'
,'S46192S'
,'S46199D'
,'S46199S'
,'S46201D'
,'S46201S'
,'S46202D'
,'S46202S'
,'S46209D'
,'S46209S'
,'S46211D'
,'S46211S'
,'S46212D'
,'S46212S'
,'S46219D'
,'S46219S'
,'S46221D'
,'S46221S'
,'S46222D'
,'S46222S'
,'S46229D'
,'S46229S'
,'S46291D'
,'S46291S'
,'S46292D'
,'S46292S'
,'S46299D'
,'S46299S'
,'S46301D'
,'S46301S'
,'S46302D'
,'S46302S'
,'S46309D'
,'S46309S'
,'S46311D'
,'S46311S'
,'S46312D'
,'S46312S'
,'S46319D'
,'S46319S'
,'S46321D'
,'S46321S'
,'S46322D'
,'S46322S'
,'S46329D'
,'S46329S'
,'S46391D'
,'S46391S'
,'S46392D'
,'S46392S'
,'S46399D'
,'S46399S'
,'S46801D'
,'S46801S'
,'S46802D'
,'S46802S'
,'S46809D'
,'S46809S'
,'S46811D'
,'S46811S'
,'S46812D'
,'S46812S'
,'S46819D'
,'S46819S'
,'S46821D'
,'S46821S'
,'S46822D'
,'S46822S'
,'S46829D'
,'S46829S'
,'S46891D'
,'S46891S'
,'S46892D'
,'S46892S'
,'S46899D'
,'S46899S'
,'S46901D'
,'S46901S'
,'S46902D'
,'S46902S'
,'S46909D'
,'S46909S'
,'S46911D'
,'S46911S'
,'S46912D'
,'S46912S'
,'S46919D'
,'S46919S'
,'S46921D'
,'S46921S'
,'S46922D'
,'S46922S'
,'S46929D'
,'S46929S'
,'S46991D'
,'S46991S'
,'S46992D'
,'S46992S'
,'S46999D'
,'S46999S'
,'S471XXD'
,'S471XXS'
,'S472XXD'
,'S472XXS'
,'S479XXD'
,'S479XXS'
,'S48011D'
,'S48011S'
,'S48012D'
,'S48012S'
,'S48019D'
,'S48019S'
,'S48021D'
,'S48021S'
,'S48022D'
,'S48022S'
,'S48029D'
,'S48029S'
,'S48111D'
,'S48111S'
,'S48112D'
,'S48112S'
,'S48119D'
,'S48119S'
,'S48121D'
,'S48121S'
,'S48122D'
,'S48122S'
,'S48129D'
,'S48129S'
,'S48911D'
,'S48911S'
,'S48912D'
,'S48912S'
,'S48919D'
,'S48919S'
,'S48921D'
,'S48921S'
,'S48922D'
,'S48922S'
,'S48929D'
,'S48929S'
,'S49001D'
,'S49001G'
,'S49001K'
,'S49001P'
,'S49001S'
,'S49002D'
,'S49002G'
,'S49002K'
,'S49002P'
,'S49002S'
,'S49009D'
,'S49009G'
,'S49009K'
,'S49009P'
,'S49009S'
,'S49011D'
,'S49011G'
,'S49011K'
,'S49011P'
,'S49011S'
,'S49012D'
,'S49012G'
,'S49012K'
,'S49012P'
,'S49012S'
,'S49019D'
,'S49019G'
,'S49019K'
,'S49019P'
,'S49019S'
,'S49021D'
,'S49021G'
,'S49021K'
,'S49021P'
,'S49021S'
,'S49022D'
,'S49022G'
,'S49022K'
,'S49022P'
,'S49022S'
,'S49029D'
,'S49029G'
,'S49029K'
,'S49029P'
,'S49029S'
,'S49031D'
,'S49031G'
,'S49031K'
,'S49031P'
,'S49031S'
,'S49032D'
,'S49032G'
,'S49032K'
,'S49032P'
,'S49032S'
,'S49039D'
,'S49039G'
,'S49039K'
,'S49039P'
,'S49039S'
,'S49041D'
,'S49041G'
,'S49041K'
,'S49041P'
,'S49041S'
,'S49042D'
,'S49042G'
,'S49042K'
,'S49042P'
,'S49042S'
,'S49049D'
,'S49049G'
,'S49049K'
,'S49049P'
,'S49049S'
,'S49091D'
,'S49091G'
,'S49091K'
,'S49091P'
,'S49091S'
,'S49092D'
,'S49092G'
,'S49092K'
,'S49092P'
,'S49092S'
,'S49099D'
,'S49099G'
,'S49099K'
,'S49099P'
,'S49099S'
,'S49101D'
,'S49101G'
,'S49101K'
,'S49101P'
,'S49101S'
,'S49102D'
,'S49102G'
,'S49102K'
,'S49102P'
,'S49102S'
,'S49109D'
,'S49109G'
,'S49109K'
,'S49109P'
,'S49109S'
,'S49111D'
,'S49111G'
,'S49111K'
,'S49111P'
,'S49111S'
,'S49112D'
,'S49112G'
,'S49112K'
,'S49112P'
,'S49112S'
,'S49119D'
,'S49119G'
,'S49119K'
,'S49119P'
,'S49119S'
,'S49121D'
,'S49121G'
,'S49121K'
,'S49121P'
,'S49121S'
,'S49122D'
,'S49122G'
,'S49122K'
,'S49122P'
,'S49122S'
,'S49129D'
,'S49129G'
,'S49129K'
,'S49129P'
,'S49129S'
,'S49131D'
,'S49131G'
,'S49131K'
,'S49131P'
,'S49131S'
,'S49132D'
,'S49132G'
,'S49132K'
,'S49132P'
,'S49132S'
,'S49139D'
,'S49139G'
,'S49139K'
,'S49139P'
,'S49139S'
,'S49141D'
,'S49141G'
,'S49141K'
,'S49141P'
,'S49141S'
,'S49142D'
,'S49142G'
,'S49142K'
,'S49142P'
,'S49142S'
,'S49149D'
,'S49149G'
,'S49149K'
,'S49149P'
,'S49149S'
,'S49191D'
,'S49191G'
,'S49191K'
,'S49191P'
,'S49191S'
,'S49192D'
,'S49192G'
,'S49192K'
,'S49192P'
,'S49192S'
,'S49199D'
,'S49199G'
,'S49199K'
,'S49199P'
,'S49199S'
,'S4980XD'
,'S4980XS'
,'S4981XD'
,'S4981XS'
,'S4982XD'
,'S4982XS'
,'S4990XD'
,'S4990XS'
,'S4991XD'
,'S4991XS'
,'S4992XD'
,'S4992XS'
,'S5000XD'
,'S5000XS'
,'S5001XD'
,'S5001XS'
,'S5002XD'
,'S5002XS'
,'S5010XD'
,'S5010XS'
,'S5011XD'
,'S5011XS'
,'S5012XD'
,'S5012XS'
,'S50311D'
,'S50311S'
,'S50312D'
,'S50312S'
,'S50319D'
,'S50319S'
,'S50321D'
,'S50321S'
,'S50322D'
,'S50322S'
,'S50329D'
,'S50329S'
,'S50341D'
,'S50341S'
,'S50342D'
,'S50342S'
,'S50349D'
,'S50349S'
,'S50351D'
,'S50351S'
,'S50352D'
,'S50352S'
,'S50359D'
,'S50359S'
,'S50361D'
,'S50361S'
,'S50362D'
,'S50362S'
,'S50369D'
,'S50369S'
,'S50371D'
,'S50371S'
,'S50372D'
,'S50372S'
,'S50379D'
,'S50379S'
,'S50811D'
,'S50811S'
,'S50812D'
,'S50812S'
,'S50819D'
,'S50819S'
,'S50821D'
,'S50821S'
,'S50822D'
,'S50822S'
,'S50829D'
,'S50829S'
,'S50841D'
,'S50841S'
,'S50842D'
,'S50842S'
,'S50849D'
,'S50849S'
,'S50851D'
,'S50851S'
,'S50852D'
,'S50852S'
,'S50859D'
,'S50859S'
,'S50861D'
,'S50861S'
,'S50862D'
,'S50862S'
,'S50869D'
,'S50869S'
,'S50871D'
,'S50871S'
,'S50872D'
,'S50872S'
,'S50879D'
,'S50879S'
,'S50901D'
,'S50901S'
,'S50902D'
,'S50902S'
,'S50909D'
,'S50909S'
,'S50911D'
,'S50911S'
,'S50912D'
,'S50912S'
,'S50919D'
,'S50919S'
,'S51001D'
,'S51001S'
,'S51002D'
,'S51002S'
,'S51009D'
,'S51009S'
,'S51011D'
,'S51011S'
,'S51012D'
,'S51012S'
,'S51019D'
,'S51019S'
,'S51021D'
,'S51021S'
,'S51022D'
,'S51022S'
,'S51029D'
,'S51029S'
,'S51031D'
,'S51031S'
,'S51032D'
,'S51032S'
,'S51039D'
,'S51039S'
,'S51041D'
,'S51041S'
,'S51042D'
,'S51042S'
,'S51049D'
,'S51049S'
,'S51051D'
,'S51051S'
,'S51052D'
,'S51052S'
,'S51059D'
,'S51059S'
,'S51801D'
,'S51801S'
,'S51802D'
,'S51802S'
,'S51809D'
,'S51809S'
,'S51811D'
,'S51811S'
,'S51812D'
,'S51812S'
,'S51819D'
,'S51819S'
,'S51821D'
,'S51821S'
,'S51822D'
,'S51822S'
,'S51829D'
,'S51829S'
,'S51831D'
,'S51831S'
,'S51832D'
,'S51832S'
,'S51839D'
,'S51839S'
,'S51841D'
,'S51841S'
,'S51842D'
,'S51842S'
,'S51849D'
,'S51849S'
,'S51851D'
,'S51851S'
,'S51852D'
,'S51852S'
,'S51859D'
,'S51859S'
,'S52001C'
,'S52001D'
,'S52001E'
,'S52001F'
,'S52001G'
,'S52001H'
,'S52001J'
,'S52001K'
,'S52001M'
,'S52001N'
,'S52001P'
,'S52001Q'
,'S52001R'
,'S52001S'
,'S52002C'
,'S52002D'
,'S52002E'
,'S52002F'
,'S52002G'
,'S52002H'
,'S52002J'
,'S52002K'
,'S52002M'
,'S52002N'
,'S52002P'
,'S52002Q'
,'S52002R'
,'S52002S'
,'S52009C'
,'S52009D'
,'S52009E'
,'S52009F'
,'S52009G'
,'S52009H'
,'S52009J'
,'S52009K'
,'S52009M'
,'S52009N'
,'S52009P'
,'S52009Q'
,'S52009R'
,'S52009S'
,'S52011D'
,'S52011G'
,'S52011K'
,'S52011P'
,'S52011S'
,'S52012D'
,'S52012G'
,'S52012K'
,'S52012P'
,'S52012S'
,'S52019D'
,'S52019G'
,'S52019K'
,'S52019P'
,'S52019S'
,'S52021C'
,'S52021D'
,'S52021E'
,'S52021F'
,'S52021G'
,'S52021H'
,'S52021J'
,'S52021K'
,'S52021M'
,'S52021N'
,'S52021P'
,'S52021Q'
,'S52021R'
,'S52021S'
,'S52022C'
,'S52022D'
,'S52022E'
,'S52022F'
,'S52022G'
,'S52022H'
,'S52022J'
,'S52022K'
,'S52022M'
,'S52022N'
,'S52022P'
,'S52022Q'
,'S52022R'
,'S52022S'
,'S52023C'
,'S52023D'
,'S52023E'
,'S52023F'
,'S52023G'
,'S52023H'
,'S52023J'
,'S52023K'
,'S52023M'
,'S52023N'
,'S52023P'
,'S52023Q'
,'S52023R'
,'S52023S'
,'S52024C'
,'S52024D'
,'S52024E'
,'S52024F'
,'S52024G'
,'S52024H'
,'S52024J'
,'S52024K'
,'S52024M'
,'S52024N'
,'S52024P'
,'S52024Q'
,'S52024R'
,'S52024S'
,'S52025C'
,'S52025D'
,'S52025E'
,'S52025F'
,'S52025G'
,'S52025H'
,'S52025J'
,'S52025K'
,'S52025M'
,'S52025N'
,'S52025P'
,'S52025Q'
,'S52025R'
,'S52025S'
,'S52026C'
,'S52026D'
,'S52026E'
,'S52026F'
,'S52026G'
,'S52026H'
,'S52026J'
,'S52026K'
,'S52026M'
,'S52026N'
,'S52026P'
,'S52026Q'
,'S52026R'
,'S52026S'
,'S52031C'
,'S52031D'
,'S52031E'
,'S52031F'
,'S52031G'
,'S52031H'
,'S52031J'
,'S52031K'
,'S52031M'
,'S52031N'
,'S52031P'
,'S52031Q'
,'S52031R'
,'S52031S'
,'S52032C'
,'S52032D'
,'S52032E'
,'S52032F'
,'S52032G'
,'S52032H'
,'S52032J'
,'S52032K'
,'S52032M'
,'S52032N'
,'S52032P'
,'S52032Q'
,'S52032R'
,'S52032S'
,'S52033C'
,'S52033D'
,'S52033E'
,'S52033F'
,'S52033G'
,'S52033H'
,'S52033J'
,'S52033K'
,'S52033M'
,'S52033N'
,'S52033P'
,'S52033Q'
,'S52033R'
,'S52033S'
,'S52034C'
,'S52034D'
,'S52034E'
,'S52034F'
,'S52034G'
,'S52034H'
,'S52034J'
,'S52034K'
,'S52034M'
,'S52034N'
,'S52034P'
,'S52034Q'
,'S52034R'
,'S52034S'
,'S52035C'
,'S52035D'
,'S52035E'
,'S52035F'
,'S52035G'
,'S52035H'
,'S52035J'
,'S52035K'
,'S52035M'
,'S52035N'
,'S52035P'
,'S52035Q'
,'S52035R'
,'S52035S'
,'S52036C'
,'S52036D'
,'S52036E'
,'S52036F'
,'S52036G'
,'S52036H'
,'S52036J'
,'S52036K'
,'S52036M'
,'S52036N'
,'S52036P'
,'S52036Q'
,'S52036R'
,'S52036S'
,'S52041C'
,'S52041D'
,'S52041E'
,'S52041F'
,'S52041G'
,'S52041H'
,'S52041J'
,'S52041K'
,'S52041M'
,'S52041N'
,'S52041P'
,'S52041Q'
,'S52041R'
,'S52041S'
,'S52042C'
,'S52042D'
,'S52042E'
,'S52042F'
,'S52042G'
,'S52042H'
,'S52042J'
,'S52042K'
,'S52042M'
,'S52042N'
,'S52042P'
,'S52042Q'
,'S52042R'
,'S52042S'
,'S52043C'
,'S52043D'
,'S52043E'
,'S52043F'
,'S52043G'
,'S52043H'
,'S52043J'
,'S52043K'
,'S52043M'
,'S52043N'
,'S52043P'
,'S52043Q'
,'S52043R'
,'S52043S'
,'S52044C'
,'S52044D'
,'S52044E'
,'S52044F'
,'S52044G'
,'S52044H'
,'S52044J'
,'S52044K'
,'S52044M'
,'S52044N'
,'S52044P'
,'S52044Q'
,'S52044R'
,'S52044S'
,'S52045C'
,'S52045D'
,'S52045E'
,'S52045F'
,'S52045G'
,'S52045H'
,'S52045J'
,'S52045K'
,'S52045M'
,'S52045N'
,'S52045P'
,'S52045Q'
,'S52045R'
,'S52045S'
,'S52046C'
,'S52046D'
,'S52046E'
,'S52046F'
,'S52046G'
,'S52046H'
,'S52046J'
,'S52046K'
,'S52046M'
,'S52046N'
,'S52046P'
,'S52046Q'
,'S52046R'
,'S52046S'
,'S52091C'
,'S52091D'
,'S52091E'
,'S52091F'
,'S52091G'
,'S52091H'
,'S52091J'
,'S52091K'
,'S52091M'
,'S52091N'
,'S52091P'
,'S52091Q'
,'S52091R'
,'S52091S'
,'S52092C'
,'S52092D'
,'S52092E'
,'S52092F'
,'S52092G'
,'S52092H'
,'S52092J'
,'S52092K'
,'S52092M'
,'S52092N'
,'S52092P'
,'S52092Q'
,'S52092R'
,'S52092S'
,'S52099C'
,'S52099D'
,'S52099E'
,'S52099F'
,'S52099G'
,'S52099H'
,'S52099J'
,'S52099K'
,'S52099M'
,'S52099N'
,'S52099P'
,'S52099Q'
,'S52099R'
,'S52099S'
,'S52101C'
,'S52101D'
,'S52101E'
,'S52101F'
,'S52101G'
,'S52101H'
,'S52101J'
,'S52101K'
,'S52101M'
,'S52101N'
,'S52101P'
,'S52101Q'
,'S52101R'
,'S52101S'
,'S52102C'
,'S52102D'
,'S52102E'
,'S52102F'
,'S52102G'
,'S52102H'
,'S52102J'
,'S52102K'
,'S52102M'
,'S52102N'
,'S52102P'
,'S52102Q'
,'S52102R'
,'S52102S'
,'S52109C'
,'S52109D'
,'S52109E'
,'S52109F'
,'S52109G'
,'S52109H'
,'S52109J'
,'S52109K'
,'S52109M'
,'S52109N'
,'S52109P'
,'S52109Q'
,'S52109R'
,'S52109S'
,'S52111D'
,'S52111G'
,'S52111K'
,'S52111P'
,'S52111S'
,'S52112D'
,'S52112G'
,'S52112K'
,'S52112P'
,'S52112S'
,'S52119D'
,'S52119G'
,'S52119K'
,'S52119P'
,'S52119S'
,'S52121C'
,'S52121D'
,'S52121E'
,'S52121F'
,'S52121G'
,'S52121H'
,'S52121J'
,'S52121K'
,'S52121M'
,'S52121N'
,'S52121P'
,'S52121Q'
,'S52121R'
,'S52121S'
,'S52122C'
,'S52122D'
,'S52122E'
,'S52122F'
,'S52122G'
,'S52122H'
,'S52122J'
,'S52122K'
,'S52122M'
,'S52122N'
,'S52122P'
,'S52122Q'
,'S52122R'
,'S52122S'
,'S52123C'
,'S52123D'
,'S52123E'
,'S52123F'
,'S52123G'
,'S52123H'
,'S52123J'
,'S52123K'
,'S52123M'
,'S52123N'
,'S52123P'
,'S52123Q'
,'S52123R'
,'S52123S'
,'S52124C'
,'S52124D'
,'S52124E'
,'S52124F'
,'S52124G'
,'S52124H'
,'S52124J'
,'S52124K'
,'S52124M'
,'S52124N'
,'S52124P'
,'S52124Q'
,'S52124R'
,'S52124S'
,'S52125C'
,'S52125D'
,'S52125E'
,'S52125F'
,'S52125G'
,'S52125H'
,'S52125J'
,'S52125K'
,'S52125M'
,'S52125N'
,'S52125P'
,'S52125Q'
,'S52125R'
,'S52125S'
,'S52126C'
,'S52126D'
,'S52126E'
,'S52126F'
,'S52126G'
,'S52126H'
,'S52126J'
,'S52126K'
,'S52126M'
,'S52126N'
,'S52126P'
,'S52126Q'
,'S52126R'
,'S52126S'
,'S52131C'
,'S52131D'
,'S52131E'
,'S52131F'
,'S52131G'
,'S52131H'
,'S52131J'
,'S52131K'
,'S52131M'
,'S52131N'
,'S52131P'
,'S52131Q'
,'S52131R'
,'S52131S'
,'S52132C'
,'S52132D'
,'S52132E'
,'S52132F'
,'S52132G'
,'S52132H'
,'S52132J'
,'S52132K'
,'S52132M'
,'S52132N'
,'S52132P'
,'S52132Q'
,'S52132R'
,'S52132S'
,'S52133C'
,'S52133D'
,'S52133E'
,'S52133F'
,'S52133G'
,'S52133H'
,'S52133J'
,'S52133K'
,'S52133M'
,'S52133N'
,'S52133P'
,'S52133Q'
,'S52133R'
,'S52133S'
,'S52134C'
,'S52134D'
,'S52134E'
,'S52134F'
,'S52134G'
,'S52134H'
,'S52134J'
,'S52134K'
,'S52134M'
,'S52134N'
,'S52134P'
,'S52134Q'
,'S52134R'
,'S52134S'
,'S52135C'
,'S52135D'
,'S52135E'
,'S52135F'
,'S52135G'
,'S52135H'
,'S52135J'
,'S52135K'
,'S52135M'
,'S52135N'
,'S52135P'
,'S52135Q'
,'S52135R'
,'S52135S'
,'S52136C'
,'S52136D'
,'S52136E'
,'S52136F'
,'S52136G'
,'S52136H'
,'S52136J'
,'S52136K'
,'S52136M'
,'S52136N'
,'S52136P'
,'S52136Q'
,'S52136R'
,'S52136S'
,'S52181C'
,'S52181D'
,'S52181E'
,'S52181F'
,'S52181G'
,'S52181H'
,'S52181J'
,'S52181K'
,'S52181M'
,'S52181N'
,'S52181P'
,'S52181Q'
,'S52181R'
,'S52181S'
,'S52182C'
,'S52182D'
,'S52182E'
,'S52182F'
,'S52182G'
,'S52182H'
,'S52182J'
,'S52182K'
,'S52182M'
,'S52182N'
,'S52182P'
,'S52182Q'
,'S52182R'
,'S52182S'
,'S52189C'
,'S52189D'
,'S52189E'
,'S52189F'
,'S52189G'
,'S52189H'
,'S52189J'
,'S52189K'
,'S52189M'
,'S52189N'
,'S52189P'
,'S52189Q'
,'S52189R'
,'S52189S'
,'S52201C'
,'S52201D'
,'S52201E'
,'S52201F'
,'S52201G'
,'S52201H'
,'S52201J'
,'S52201K'
,'S52201M'
,'S52201N'
,'S52201P'
,'S52201Q'
,'S52201R'
,'S52201S'
,'S52202C'
,'S52202D'
,'S52202E'
,'S52202F'
,'S52202G'
,'S52202H'
,'S52202J'
,'S52202K'
,'S52202M'
,'S52202N'
,'S52202P'
,'S52202Q'
,'S52202R'
,'S52202S'
,'S52209C'
,'S52209D'
,'S52209E'
,'S52209F'
,'S52209G'
,'S52209H'
,'S52209J'
,'S52209K'
,'S52209M'
,'S52209N'
,'S52209P'
,'S52209Q'
,'S52209R'
,'S52209S'
,'S52211D'
,'S52211G'
,'S52211K'
,'S52211P'
,'S52211S'
,'S52212D'
,'S52212G'
,'S52212K'
,'S52212P'
,'S52212S'
,'S52219D'
,'S52219G'
,'S52219K'
,'S52219P'
,'S52219S'
,'S52221C'
,'S52221D'
,'S52221E'
,'S52221F'
,'S52221G'
,'S52221H'
,'S52221J'
,'S52221K'
,'S52221M'
,'S52221N'
,'S52221P'
,'S52221Q'
,'S52221R'
,'S52221S'
,'S52222C'
,'S52222D'
,'S52222E'
,'S52222F'
,'S52222G'
,'S52222H'
,'S52222J'
,'S52222K'
,'S52222M'
,'S52222N'
,'S52222P'
,'S52222Q'
,'S52222R'
,'S52222S'
,'S52223C'
,'S52223D'
,'S52223E'
,'S52223F'
,'S52223G'
,'S52223H'
,'S52223J'
,'S52223K'
,'S52223M'
,'S52223N'
,'S52223P'
,'S52223Q'
,'S52223R'
,'S52223S'
,'S52224C'
,'S52224D'
,'S52224E'
,'S52224F'
,'S52224G'
,'S52224H'
,'S52224J'
,'S52224K'
,'S52224M'
,'S52224N'
,'S52224P'
,'S52224Q'
,'S52224R'
,'S52224S'
,'S52225C'
,'S52225D'
,'S52225E'
,'S52225F'
,'S52225G'
,'S52225H'
,'S52225J'
,'S52225K'
,'S52225M'
,'S52225N'
,'S52225P'
,'S52225Q'
,'S52225R'
,'S52225S'
,'S52226C'
,'S52226D'
,'S52226E'
,'S52226F'
,'S52226G'
,'S52226H'
,'S52226J'
,'S52226K'
,'S52226M'
,'S52226N'
,'S52226P'
,'S52226Q'
,'S52226R'
,'S52226S'
,'S52231C'
,'S52231D'
,'S52231E'
,'S52231F'
,'S52231G'
,'S52231H'
,'S52231J'
,'S52231K'
,'S52231M'
,'S52231N'
,'S52231P'
,'S52231Q'
,'S52231R'
,'S52231S'
,'S52232C'
,'S52232D'
,'S52232E'
,'S52232F'
,'S52232G'
,'S52232H'
,'S52232J'
,'S52232K'
,'S52232M'
,'S52232N'
,'S52232P'
,'S52232Q'
,'S52232R'
,'S52232S'
,'S52233C'
,'S52233D'
,'S52233E'
,'S52233F'
,'S52233G'
,'S52233H'
,'S52233J'
,'S52233K'
,'S52233M'
,'S52233N'
,'S52233P'
,'S52233Q'
,'S52233R'
,'S52233S'
,'S52234C'
,'S52234D'
,'S52234E'
,'S52234F'
,'S52234G'
,'S52234H'
,'S52234J'
,'S52234K'
,'S52234M'
,'S52234N'
,'S52234P'
,'S52234Q'
,'S52234R'
,'S52234S'
,'S52235C'
,'S52235D'
,'S52235E'
,'S52235F'
,'S52235G'
,'S52235H'
,'S52235J'
,'S52235K'
,'S52235M'
,'S52235N'
,'S52235P'
,'S52235Q'
,'S52235R'
,'S52235S'
,'S52236C'
,'S52236D'
,'S52236E'
,'S52236F'
,'S52236G'
,'S52236H'
,'S52236J'
,'S52236K'
,'S52236M'
,'S52236N'
,'S52236P'
,'S52236Q'
,'S52236R'
,'S52236S'
,'S52241C'
,'S52241D'
,'S52241E'
,'S52241F'
,'S52241G'
,'S52241H'
,'S52241J'
,'S52241K'
,'S52241M'
,'S52241N'
,'S52241P'
,'S52241Q'
,'S52241R'
,'S52241S'
,'S52242C'
,'S52242D'
,'S52242E'
,'S52242F'
,'S52242G'
,'S52242H'
,'S52242J'
,'S52242K'
,'S52242M'
,'S52242N'
,'S52242P'
,'S52242Q'
,'S52242R'
,'S52242S'
,'S52243C'
,'S52243D'
,'S52243E'
,'S52243F'
,'S52243G'
,'S52243H'
,'S52243J'
,'S52243K'
,'S52243M'
,'S52243N'
,'S52243P'
,'S52243Q'
,'S52243R'
,'S52243S'
,'S52244C'
,'S52244D'
,'S52244E'
,'S52244F'
,'S52244G'
,'S52244H'
,'S52244J'
,'S52244K'
,'S52244M'
,'S52244N'
,'S52244P'
,'S52244Q'
,'S52244R'
,'S52244S'
,'S52245C'
,'S52245D'
,'S52245E'
,'S52245F'
,'S52245G'
,'S52245H'
,'S52245J'
,'S52245K'
,'S52245M'
,'S52245N'
,'S52245P'
,'S52245Q'
,'S52245R'
,'S52245S'
,'S52246C'
,'S52246D'
,'S52246E'
,'S52246F'
,'S52246G'
,'S52246H'
,'S52246J'
,'S52246K'
,'S52246M'
,'S52246N'
,'S52246P'
,'S52246Q'
,'S52246R'
,'S52246S'
,'S52251C'
,'S52251D'
,'S52251E'
,'S52251F'
,'S52251G'
,'S52251H'
,'S52251J'
,'S52251K'
,'S52251M'
,'S52251N'
,'S52251P'
,'S52251Q'
,'S52251R'
,'S52251S'
,'S52252C'
,'S52252D'
,'S52252E'
,'S52252F'
,'S52252G'
,'S52252H'
,'S52252J'
,'S52252K'
,'S52252M'
,'S52252N'
,'S52252P'
,'S52252Q'
,'S52252R'
,'S52252S'
,'S52253C'
,'S52253D'
,'S52253E'
,'S52253F'
,'S52253G'
,'S52253H'
,'S52253J'
,'S52253K'
,'S52253M'
,'S52253N'
,'S52253P'
,'S52253Q'
,'S52253R'
,'S52253S'
,'S52254C'
,'S52254D'
,'S52254E'
,'S52254F'
,'S52254G'
,'S52254H'
,'S52254J'
,'S52254K'
,'S52254M'
,'S52254N'
,'S52254P'
,'S52254Q'
,'S52254R'
,'S52254S'
,'S52255C'
,'S52255D'
,'S52255E'
,'S52255F'
,'S52255G'
,'S52255H'
,'S52255J'
,'S52255K'
,'S52255M'
,'S52255N'
,'S52255P'
,'S52255Q'
,'S52255R'
,'S52255S'
,'S52256C'
,'S52256D'
,'S52256E'
,'S52256F'
,'S52256G'
,'S52256H'
,'S52256J'
,'S52256K'
,'S52256M'
,'S52256N'
,'S52256P'
,'S52256Q'
,'S52256R'
,'S52256S'
,'S52261C'
,'S52261D'
,'S52261E'
,'S52261F'
,'S52261G'
,'S52261H'
,'S52261J'
,'S52261K'
,'S52261M'
,'S52261N'
,'S52261P'
,'S52261Q'
,'S52261R'
,'S52261S'
,'S52262C'
,'S52262D'
,'S52262E'
,'S52262F'
,'S52262G'
,'S52262H'
,'S52262J'
,'S52262K'
,'S52262M'
,'S52262N'
,'S52262P'
,'S52262Q'
,'S52262R'
,'S52262S'
,'S52263C'
,'S52263D'
,'S52263E'
,'S52263F'
,'S52263G'
,'S52263H'
,'S52263J'
,'S52263K'
,'S52263M'
,'S52263N'
,'S52263P'
,'S52263Q'
,'S52263R'
,'S52263S'
,'S52264C'
,'S52264D'
,'S52264E'
,'S52264F'
,'S52264G'
,'S52264H'
,'S52264J'
,'S52264K'
,'S52264M'
,'S52264N'
,'S52264P'
,'S52264Q'
,'S52264R'
,'S52264S'
,'S52265C'
,'S52265D'
,'S52265E'
,'S52265F'
,'S52265G'
,'S52265H'
,'S52265J'
,'S52265K'
,'S52265M'
,'S52265N'
,'S52265P'
,'S52265Q'
,'S52265R'
,'S52265S'
,'S52266C'
,'S52266D'
,'S52266E'
,'S52266F'
,'S52266G'
,'S52266H'
,'S52266J'
,'S52266K'
,'S52266M'
,'S52266N'
,'S52266P'
,'S52266Q'
,'S52266R'
,'S52266S'
,'S52271C'
,'S52271D'
,'S52271E'
,'S52271F'
,'S52271G'
,'S52271H'
,'S52271J'
,'S52271K'
,'S52271M'
,'S52271N'
,'S52271P'
,'S52271Q'
,'S52271R'
,'S52271S'
,'S52272C'
,'S52272D'
,'S52272E'
,'S52272F'
,'S52272G'
,'S52272H'
,'S52272J'
,'S52272K'
,'S52272M'
,'S52272N'
,'S52272P'
,'S52272Q'
,'S52272R'
,'S52272S'
,'S52279C'
,'S52279D'
,'S52279E'
,'S52279F'
,'S52279G'
,'S52279H'
,'S52279J'
,'S52279K'
,'S52279M'
,'S52279N'
,'S52279P'
,'S52279Q'
,'S52279R'
,'S52279S'
,'S52281C'
,'S52281D'
,'S52281E'
,'S52281F'
,'S52281G'
,'S52281H'
,'S52281J'
,'S52281K'
,'S52281M'
,'S52281N'
,'S52281P'
,'S52281Q'
,'S52281R'
,'S52281S'
,'S52282C'
,'S52282D'
,'S52282E'
,'S52282F'
,'S52282G'
,'S52282H'
,'S52282J'
,'S52282K'
,'S52282M'
,'S52282N'
,'S52282P'
,'S52282Q'
,'S52282R'
,'S52282S'
,'S52283C'
,'S52283D'
,'S52283E'
,'S52283F'
,'S52283G'
,'S52283H'
,'S52283J'
,'S52283K'
,'S52283M'
,'S52283N'
,'S52283P'
,'S52283Q'
,'S52283R'
,'S52283S'
,'S52291C'
,'S52291D'
,'S52291E'
,'S52291F'
,'S52291G'
,'S52291H'
,'S52291J'
,'S52291K'
,'S52291M'
,'S52291N'
,'S52291P'
,'S52291Q'
,'S52291R'
,'S52291S'
,'S52292C'
,'S52292D'
,'S52292E'
,'S52292F'
,'S52292G'
,'S52292H'
,'S52292J'
,'S52292K'
,'S52292M'
,'S52292N'
,'S52292P'
,'S52292Q'
,'S52292R'
,'S52292S'
,'S52299C'
,'S52299D'
,'S52299E'
,'S52299F'
,'S52299G'
,'S52299H'
,'S52299J'
,'S52299K'
,'S52299M'
,'S52299N'
,'S52299P'
,'S52299Q'
,'S52299R'
,'S52299S'
,'S52301C'
,'S52301D'
,'S52301E'
,'S52301F'
,'S52301G'
,'S52301H'
,'S52301J'
,'S52301K'
,'S52301M'
,'S52301N'
,'S52301P'
,'S52301Q'
,'S52301R'
,'S52301S'
,'S52302C'
,'S52302D'
,'S52302E'
,'S52302F'
,'S52302G'
,'S52302H'
,'S52302J'
,'S52302K'
,'S52302M'
,'S52302N'
,'S52302P'
,'S52302Q'
,'S52302R'
,'S52302S'
,'S52309C'
,'S52309D'
,'S52309E'
,'S52309F'
,'S52309G'
,'S52309H'
,'S52309J'
,'S52309K'
,'S52309M'
,'S52309N'
,'S52309P'
,'S52309Q'
,'S52309R'
,'S52309S'
,'S52311D'
,'S52311G'
,'S52311K'
,'S52311P'
,'S52311S'
,'S52312D'
,'S52312G'
,'S52312K'
,'S52312P'
,'S52312S'
,'S52319D'
,'S52319G'
,'S52319K'
,'S52319P'
,'S52319S'
,'S52321C'
,'S52321D'
,'S52321E'
,'S52321F'
,'S52321G'
,'S52321H'
,'S52321J'
,'S52321K'
,'S52321M'
,'S52321N'
,'S52321P'
,'S52321Q'
,'S52321R'
,'S52321S'
,'S52322C'
,'S52322D'
,'S52322E'
,'S52322F'
,'S52322G'
,'S52322H'
,'S52322J'
,'S52322K'
,'S52322M'
,'S52322N'
,'S52322P'
,'S52322Q'
,'S52322R'
,'S52322S'
,'S52323C'
,'S52323D'
,'S52323E'
,'S52323F'
,'S52323G'
,'S52323H'
,'S52323J'
,'S52323K'
,'S52323M'
,'S52323N'
,'S52323P'
,'S52323Q'
,'S52323R'
,'S52323S'
,'S52324C'
,'S52324D'
,'S52324E'
,'S52324F'
,'S52324G'
,'S52324H'
,'S52324J'
,'S52324K'
,'S52324M'
,'S52324N'
,'S52324P'
,'S52324Q'
,'S52324R'
,'S52324S'
,'S52325C'
,'S52325D'
,'S52325E'
,'S52325F'
,'S52325G'
,'S52325H'
,'S52325J'
,'S52325K'
,'S52325M'
,'S52325N'
,'S52325P'
,'S52325Q'
,'S52325R'
,'S52325S'
,'S52326C'
,'S52326D'
,'S52326E'
,'S52326F'
,'S52326G'
,'S52326H'
,'S52326J'
,'S52326K'
,'S52326M'
,'S52326N'
,'S52326P'
,'S52326Q'
,'S52326R'
,'S52326S'
,'S52331C'
,'S52331D'
,'S52331E'
,'S52331F'
,'S52331G'
,'S52331H'
,'S52331J'
,'S52331K'
,'S52331M'
,'S52331N'
,'S52331P'
,'S52331Q'
,'S52331R'
,'S52331S'
,'S52332C'
,'S52332D'
,'S52332E'
,'S52332F'
,'S52332G'
,'S52332H'
,'S52332J'
,'S52332K'
,'S52332M'
,'S52332N'
,'S52332P'
,'S52332Q'
,'S52332R'
,'S52332S'
,'S52333C'
,'S52333D'
,'S52333E'
,'S52333F'
,'S52333G'
,'S52333H'
,'S52333J'
,'S52333K'
,'S52333M'
,'S52333N'
,'S52333P'
,'S52333Q'
,'S52333R'
,'S52333S'
,'S52334C'
,'S52334D'
,'S52334E'
,'S52334F'
,'S52334G'
,'S52334H'
,'S52334J'
,'S52334K'
,'S52334M'
,'S52334N'
,'S52334P'
,'S52334Q'
,'S52334R'
,'S52334S'
,'S52335C'
,'S52335D'
,'S52335E'
,'S52335F'
,'S52335G'
,'S52335H'
,'S52335J'
,'S52335K'
,'S52335M'
,'S52335N'
,'S52335P'
,'S52335Q'
,'S52335R'
,'S52335S'
,'S52336C'
,'S52336D'
,'S52336E'
,'S52336F'
,'S52336G'
,'S52336H'
,'S52336J'
,'S52336K'
,'S52336M'
,'S52336N'
,'S52336P'
,'S52336Q'
,'S52336R'
,'S52336S'
,'S52341C'
,'S52341D'
,'S52341E'
,'S52341F'
,'S52341G'
,'S52341H'
,'S52341J'
,'S52341K'
,'S52341M'
,'S52341N'
,'S52341P'
,'S52341Q'
,'S52341R'
,'S52341S'
,'S52342C'
,'S52342D'
,'S52342E'
,'S52342F'
,'S52342G'
,'S52342H'
,'S52342J'
,'S52342K'
,'S52342M'
,'S52342N'
,'S52342P'
,'S52342Q'
,'S52342R'
,'S52342S'
,'S52343C'
,'S52343D'
,'S52343E'
,'S52343F'
,'S52343G'
,'S52343H'
,'S52343J'
,'S52343K'
,'S52343M'
,'S52343N'
,'S52343P'
,'S52343Q'
,'S52343R'
,'S52343S'
,'S52344C'
,'S52344D'
,'S52344E'
,'S52344F'
,'S52344G'
,'S52344H'
,'S52344J'
,'S52344K'
,'S52344M'
,'S52344N'
,'S52344P'
,'S52344Q'
,'S52344R'
,'S52344S'
,'S52345C'
,'S52345D'
,'S52345E'
,'S52345F'
,'S52345G'
,'S52345H'
,'S52345J'
,'S52345K'
,'S52345M'
,'S52345N'
,'S52345P'
,'S52345Q'
,'S52345R'
,'S52345S'
,'S52346C'
,'S52346D'
,'S52346E'
,'S52346F'
,'S52346G'
,'S52346H'
,'S52346J'
,'S52346K'
,'S52346M'
,'S52346N'
,'S52346P'
,'S52346Q'
,'S52346R'
,'S52346S'
,'S52351C'
,'S52351D'
,'S52351E'
,'S52351F'
,'S52351G'
,'S52351H'
,'S52351J'
,'S52351K'
,'S52351M'
,'S52351N'
,'S52351P'
,'S52351Q'
,'S52351R'
,'S52351S'
,'S52352C'
,'S52352D'
,'S52352E'
,'S52352F'
,'S52352G'
,'S52352H'
,'S52352J'
,'S52352K'
,'S52352M'
,'S52352N'
,'S52352P'
,'S52352Q'
,'S52352R'
,'S52352S'
,'S52353C'
,'S52353D'
,'S52353E'
,'S52353F'
,'S52353G'
,'S52353H'
,'S52353J'
,'S52353K'
,'S52353M'
,'S52353N'
,'S52353P'
,'S52353Q'
,'S52353R'
,'S52353S'
,'S52354C'
,'S52354D'
,'S52354E'
,'S52354F'
,'S52354G'
,'S52354H'
,'S52354J'
,'S52354K'
,'S52354M'
,'S52354N'
,'S52354P'
,'S52354Q'
,'S52354R'
,'S52354S'
,'S52355C'
,'S52355D'
,'S52355E'
,'S52355F'
,'S52355G'
,'S52355H'
,'S52355J'
,'S52355K'
,'S52355M'
,'S52355N'
,'S52355P'
,'S52355Q'
,'S52355R'
,'S52355S'
,'S52356C'
,'S52356D'
,'S52356E'
,'S52356F'
,'S52356G'
,'S52356H'
,'S52356J'
,'S52356K'
,'S52356M'
,'S52356N'
,'S52356P'
,'S52356Q'
,'S52356R'
,'S52356S'
,'S52361C'
,'S52361D'
,'S52361E'
,'S52361F'
,'S52361G'
,'S52361H'
,'S52361J'
,'S52361K'
,'S52361M'
,'S52361N'
,'S52361P'
,'S52361Q'
,'S52361R'
,'S52361S'
,'S52362C'
,'S52362D'
,'S52362E'
,'S52362F'
,'S52362G'
,'S52362H'
,'S52362J'
,'S52362K'
,'S52362M'
,'S52362N'
,'S52362P'
,'S52362Q'
,'S52362R'
,'S52362S'
,'S52363C'
,'S52363D'
,'S52363E'
,'S52363F'
,'S52363G'
,'S52363H'
,'S52363J'
,'S52363K'
,'S52363M'
,'S52363N'
,'S52363P'
,'S52363Q'
,'S52363R'
,'S52363S'
,'S52364C'
,'S52364D'
,'S52364E'
,'S52364F'
,'S52364G'
,'S52364H'
,'S52364J'
,'S52364K'
,'S52364M'
,'S52364N'
,'S52364P'
,'S52364Q'
,'S52364R'
,'S52364S'
,'S52365C'
,'S52365D'
,'S52365E'
,'S52365F'
,'S52365G'
,'S52365H'
,'S52365J'
,'S52365K'
,'S52365M'
,'S52365N'
,'S52365P'
,'S52365Q'
,'S52365R'
,'S52365S'
,'S52366C'
,'S52366D'
,'S52366E'
,'S52366F'
,'S52366G'
,'S52366H'
,'S52366J'
,'S52366K'
,'S52366M'
,'S52366N'
,'S52366P'
,'S52366Q'
,'S52366R'
,'S52366S'
,'S52371C'
,'S52371D'
,'S52371E'
,'S52371F'
,'S52371G'
,'S52371H'
,'S52371J'
,'S52371K'
,'S52371M'
,'S52371N'
,'S52371P'
,'S52371Q'
,'S52371R'
,'S52371S'
,'S52372C'
,'S52372D'
,'S52372E'
,'S52372F'
,'S52372G'
,'S52372H'
,'S52372J'
,'S52372K'
,'S52372M'
,'S52372N'
,'S52372P'
,'S52372Q'
,'S52372R'
,'S52372S'
,'S52379C'
,'S52379D'
,'S52379E'
,'S52379F'
,'S52379G'
,'S52379H'
,'S52379J'
,'S52379K'
,'S52379M'
,'S52379N'
,'S52379P'
,'S52379Q'
,'S52379R'
,'S52379S'
,'S52381C'
,'S52381D'
,'S52381E'
,'S52381F'
,'S52381G'
,'S52381H'
,'S52381J'
,'S52381K'
,'S52381M'
,'S52381N'
,'S52381P'
,'S52381Q'
,'S52381R'
,'S52381S'
,'S52382C'
,'S52382D'
,'S52382E'
,'S52382F'
,'S52382G'
,'S52382H'
,'S52382J'
,'S52382K'
,'S52382M'
,'S52382N'
,'S52382P'
,'S52382Q'
,'S52382R'
,'S52382S'
,'S52389C'
,'S52389D'
,'S52389E'
,'S52389F'
,'S52389G'
,'S52389H'
,'S52389J'
,'S52389K'
,'S52389M'
,'S52389N'
,'S52389P'
,'S52389Q'
,'S52389R'
,'S52389S'
,'S52391C'
,'S52391D'
,'S52391E'
,'S52391F'
,'S52391G'
,'S52391H'
,'S52391J'
,'S52391K'
,'S52391M'
,'S52391N'
,'S52391P'
,'S52391Q'
,'S52391R'
,'S52391S'
,'S52392C'
,'S52392D'
,'S52392E'
,'S52392F'
,'S52392G'
,'S52392H'
,'S52392J'
,'S52392K'
,'S52392M'
,'S52392N'
,'S52392P'
,'S52392Q'
,'S52392R'
,'S52392S'
,'S52399C'
,'S52399D'
,'S52399E'
,'S52399F'
,'S52399G'
,'S52399H'
,'S52399J'
,'S52399K'
,'S52399M'
,'S52399N'
,'S52399P'
,'S52399Q'
,'S52399R'
,'S52399S'
,'S52501C'
,'S52501D'
,'S52501E'
,'S52501F'
,'S52501G'
,'S52501H'
,'S52501J'
,'S52501K'
,'S52501M'
,'S52501N'
,'S52501P'
,'S52501Q'
,'S52501R'
,'S52501S'
,'S52502C'
,'S52502D'
,'S52502E'
,'S52502F'
,'S52502G'
,'S52502H'
,'S52502J'
,'S52502K'
,'S52502M'
,'S52502N'
,'S52502P'
,'S52502Q'
,'S52502R'
,'S52502S'
,'S52509C'
,'S52509D'
,'S52509E'
,'S52509F'
,'S52509G'
,'S52509H'
,'S52509J'
,'S52509K'
,'S52509M'
,'S52509N'
,'S52509P'
,'S52509Q'
,'S52509R'
,'S52509S'
,'S52511C'
,'S52511D'
,'S52511E'
,'S52511F'
,'S52511G'
,'S52511H'
,'S52511J'
,'S52511K'
,'S52511M'
,'S52511N'
,'S52511P'
,'S52511Q'
,'S52511R'
,'S52511S'
,'S52512C'
,'S52512D'
,'S52512E'
,'S52512F'
,'S52512G'
,'S52512H'
,'S52512J'
,'S52512K'
,'S52512M'
,'S52512N'
,'S52512P'
,'S52512Q'
,'S52512R'
,'S52512S'
,'S52513C'
,'S52513D'
,'S52513E'
,'S52513F'
,'S52513G'
,'S52513H'
,'S52513J'
,'S52513K'
,'S52513M'
,'S52513N'
,'S52513P'
,'S52513Q'
,'S52513R'
,'S52513S'
,'S52514C'
,'S52514D'
,'S52514E'
,'S52514F'
,'S52514G'
,'S52514H'
,'S52514J'
,'S52514K'
,'S52514M'
,'S52514N'
,'S52514P'
,'S52514Q'
,'S52514R'
,'S52514S'
,'S52515C'
,'S52515D'
,'S52515E'
,'S52515F'
,'S52515G'
,'S52515H'
,'S52515J'
,'S52515K'
,'S52515M'
,'S52515N'
,'S52515P'
,'S52515Q'
,'S52515R'
,'S52515S'
,'S52516C'
,'S52516D'
,'S52516E'
,'S52516F'
,'S52516G'
,'S52516H'
,'S52516J'
,'S52516K'
,'S52516M'
,'S52516N'
,'S52516P'
,'S52516Q'
,'S52516R'
,'S52516S'
,'S52521D'
,'S52521G'
,'S52521K'
,'S52521P'
,'S52521S'
,'S52522D'
,'S52522G'
,'S52522K'
,'S52522P'
,'S52522S'
,'S52529D'
,'S52529G'
,'S52529K'
,'S52529P'
,'S52529S'
,'S52531C'
,'S52531D'
,'S52531E'
,'S52531F'
,'S52531G'
,'S52531H'
,'S52531J'
,'S52531K'
,'S52531M'
,'S52531N'
,'S52531P'
,'S52531Q'
,'S52531R'
,'S52531S'
,'S52532C'
,'S52532D'
,'S52532E'
,'S52532F'
,'S52532G'
,'S52532H'
,'S52532J'
,'S52532K'
,'S52532M'
,'S52532N'
,'S52532P'
,'S52532Q'
,'S52532R'
,'S52532S'
,'S52539C'
,'S52539D'
,'S52539E'
,'S52539F'
,'S52539G'
,'S52539H'
,'S52539J'
,'S52539K'
,'S52539M'
,'S52539N'
,'S52539P'
,'S52539Q'
,'S52539R'
,'S52539S'
,'S52541C'
,'S52541D'
,'S52541E'
,'S52541F'
,'S52541G'
,'S52541H'
,'S52541J'
,'S52541K'
,'S52541M'
,'S52541N'
,'S52541P'
,'S52541Q'
,'S52541R'
,'S52541S'
,'S52542C'
,'S52542D'
,'S52542E'
,'S52542F'
,'S52542G'
,'S52542H'
,'S52542J'
,'S52542K'
,'S52542M'
,'S52542N'
,'S52542P'
,'S52542Q'
,'S52542R'
,'S52542S'
,'S52549C'
,'S52549D'
,'S52549E'
,'S52549F'
,'S52549G'
,'S52549H'
,'S52549J'
,'S52549K'
,'S52549M'
,'S52549N'
,'S52549P'
,'S52549Q'
,'S52549R'
,'S52549S'
,'S52551C'
,'S52551D'
,'S52551E'
,'S52551F'
,'S52551G'
,'S52551H'
,'S52551J'
,'S52551K'
,'S52551M'
,'S52551N'
,'S52551P'
,'S52551Q'
,'S52551R'
,'S52551S'
,'S52552C'
,'S52552D'
,'S52552E'
,'S52552F'
,'S52552G'
,'S52552H'
,'S52552J'
,'S52552K'
,'S52552M'
,'S52552N'
,'S52552P'
,'S52552Q'
,'S52552R'
,'S52552S'
,'S52559C'
,'S52559D'
,'S52559E'
,'S52559F'
,'S52559G'
,'S52559H'
,'S52559J'
,'S52559K'
,'S52559M'
,'S52559N'
,'S52559P'
,'S52559Q'
,'S52559R'
,'S52559S'
,'S52561C'
,'S52561D'
,'S52561E'
,'S52561F'
,'S52561G'
,'S52561H'
,'S52561J'
,'S52561K'
,'S52561M'
,'S52561N'
,'S52561P'
,'S52561Q'
,'S52561R'
,'S52561S'
,'S52562C'
,'S52562D'
,'S52562E'
,'S52562F'
,'S52562G'
,'S52562H'
,'S52562J'
,'S52562K'
,'S52562M'
,'S52562N'
,'S52562P'
,'S52562Q'
,'S52562R'
,'S52562S'
,'S52569C'
,'S52569D'
,'S52569E'
,'S52569F'
,'S52569G'
,'S52569H'
,'S52569J'
,'S52569K'
,'S52569M'
,'S52569N'
,'S52569P'
,'S52569Q'
,'S52569R'
,'S52569S'
,'S52571C'
,'S52571D'
,'S52571E'
,'S52571F'
,'S52571G'
,'S52571H'
,'S52571J'
,'S52571K'
,'S52571M'
,'S52571N'
,'S52571P'
,'S52571Q'
,'S52571R'
,'S52571S'
,'S52572C'
,'S52572D'
,'S52572E'
,'S52572F'
,'S52572G'
,'S52572H'
,'S52572J'
,'S52572K'
,'S52572M'
,'S52572N'
,'S52572P'
,'S52572Q'
,'S52572R'
,'S52572S'
,'S52579C'
,'S52579D'
,'S52579E'
,'S52579F'
,'S52579G'
,'S52579H'
,'S52579J'
,'S52579K'
,'S52579M'
,'S52579N'
,'S52579P'
,'S52579Q'
,'S52579R'
,'S52579S'
,'S52591C'
,'S52591D'
,'S52591E'
,'S52591F'
,'S52591G'
,'S52591H'
,'S52591J'
,'S52591K'
,'S52591M'
,'S52591N'
,'S52591P'
,'S52591Q'
,'S52591R'
,'S52591S'
,'S52592C'
,'S52592D'
,'S52592E'
,'S52592F'
,'S52592G'
,'S52592H'
,'S52592J'
,'S52592K'
,'S52592M'
,'S52592N'
,'S52592P'
,'S52592Q'
,'S52592R'
,'S52592S'
,'S52599C'
,'S52599D'
,'S52599E'
,'S52599F'
,'S52599G'
,'S52599H'
,'S52599J'
,'S52599K'
,'S52599M'
,'S52599N'
,'S52599P'
,'S52599Q'
,'S52599R'
,'S52599S'
,'S52601C'
,'S52601D'
,'S52601E'
,'S52601F'
,'S52601G'
,'S52601H'
,'S52601J'
,'S52601K'
,'S52601M'
,'S52601N'
,'S52601P'
,'S52601Q'
,'S52601R'
,'S52601S'
,'S52602C'
,'S52602D'
,'S52602E'
,'S52602F'
,'S52602G'
,'S52602H'
,'S52602J'
,'S52602K'
,'S52602M'
,'S52602N'
,'S52602P'
,'S52602Q'
,'S52602R'
,'S52602S'
,'S52609C'
,'S52609D'
,'S52609E'
,'S52609F'
,'S52609G'
,'S52609H'
,'S52609J'
,'S52609K'
,'S52609M'
,'S52609N'
,'S52609P'
,'S52609Q'
,'S52609R'
,'S52609S'
,'S52611C'
,'S52611D'
,'S52611E'
,'S52611F'
,'S52611G'
,'S52611H'
,'S52611J'
,'S52611K'
,'S52611M'
,'S52611N'
,'S52611P'
,'S52611Q'
,'S52611R'
,'S52611S'
,'S52612C'
,'S52612D'
,'S52612E'
,'S52612F'
,'S52612G'
,'S52612H'
,'S52612J'
,'S52612K'
,'S52612M'
,'S52612N'
,'S52612P'
,'S52612Q'
,'S52612R'
,'S52612S'
,'S52613C'
,'S52613D'
,'S52613E'
,'S52613F'
,'S52613G'
,'S52613H'
,'S52613J'
,'S52613K'
,'S52613M'
,'S52613N'
,'S52613P'
,'S52613Q'
,'S52613R'
,'S52613S'
,'S52614C'
,'S52614D'
,'S52614E'
,'S52614F'
,'S52614G'
,'S52614H'
,'S52614J'
,'S52614K'
,'S52614M'
,'S52614N'
,'S52614P'
,'S52614Q'
,'S52614R'
,'S52614S'
,'S52615C'
,'S52615D'
,'S52615E'
,'S52615F'
,'S52615G'
,'S52615H'
,'S52615J'
,'S52615K'
,'S52615M'
,'S52615N'
,'S52615P'
,'S52615Q'
,'S52615R'
,'S52615S'
,'S52616C'
,'S52616D'
,'S52616E'
,'S52616F'
,'S52616G'
,'S52616H'
,'S52616J'
,'S52616K'
,'S52616M'
,'S52616N'
,'S52616P'
,'S52616Q'
,'S52616R'
,'S52616S'
,'S52621D'
,'S52621G'
,'S52621K'
,'S52621P'
,'S52621S'
,'S52622D'
,'S52622G'
,'S52622K'
,'S52622P'
,'S52622S'
,'S52629D'
,'S52629G'
,'S52629K'
,'S52629P'
,'S52629S'
,'S52691C'
,'S52691D'
,'S52691E'
,'S52691F'
,'S52691G'
,'S52691H'
,'S52691J'
,'S52691K'
,'S52691M'
,'S52691N'
,'S52691P'
,'S52691Q'
,'S52691R'
,'S52691S'
,'S52692C'
,'S52692D'
,'S52692E'
,'S52692F'
,'S52692G'
,'S52692H'
,'S52692J'
,'S52692K'
,'S52692M'
,'S52692N'
,'S52692P'
,'S52692Q'
,'S52692R'
,'S52692S'
,'S52699C'
,'S52699D'
,'S52699E'
,'S52699F'
,'S52699G'
,'S52699H'
,'S52699J'
,'S52699K'
,'S52699M'
,'S52699N'
,'S52699P'
,'S52699Q'
,'S52699R'
,'S52699S'
,'S5290XC'
,'S5290XD'
,'S5290XE'
,'S5290XF'
,'S5290XG'
,'S5290XH'
,'S5290XJ'
,'S5290XK'
,'S5290XM'
,'S5290XN'
,'S5290XP'
,'S5290XQ'
,'S5290XR'
,'S5290XS'
,'S5291XC'
,'S5291XD'
,'S5291XE'
,'S5291XF'
,'S5291XG'
,'S5291XH'
,'S5291XJ'
,'S5291XK'
,'S5291XM'
,'S5291XN'
,'S5291XP'
,'S5291XQ'
,'S5291XR'
,'S5291XS'
,'S5292XC'
,'S5292XD'
,'S5292XE'
,'S5292XF'
,'S5292XG'
,'S5292XH'
,'S5292XJ'
,'S5292XK'
,'S5292XM'
,'S5292XN'
,'S5292XP'
,'S5292XQ'
,'S5292XR'
,'S5292XS'
,'S53001D'
,'S53001S'
,'S53002D'
,'S53002S'
,'S53003D'
,'S53003S'
,'S53004D'
,'S53004S'
,'S53005D'
,'S53005S'
,'S53006D'
,'S53006S'
,'S53011D'
,'S53011S'
,'S53012D'
,'S53012S'
,'S53013D'
,'S53013S'
,'S53014D'
,'S53014S'
,'S53015D'
,'S53015S'
,'S53016D'
,'S53016S'
,'S53021D'
,'S53021S'
,'S53022D'
,'S53022S'
,'S53023D'
,'S53023S'
,'S53024D'
,'S53024S'
,'S53025D'
,'S53025S'
,'S53026D'
,'S53026S'
,'S53031D'
,'S53031S'
,'S53032D'
,'S53032S'
,'S53033D'
,'S53033S'
,'S53091D'
,'S53091S'
,'S53092D'
,'S53092S'
,'S53093D'
,'S53093S'
,'S53094D'
,'S53094S'
,'S53095D'
,'S53095S'
,'S53096D'
,'S53096S'
,'S53101D'
,'S53101S'
,'S53102D'
,'S53102S'
,'S53103D'
,'S53103S'
,'S53104D'
,'S53104S'
,'S53105D'
,'S53105S'
,'S53106D'
,'S53106S'
,'S53111D'
,'S53111S'
,'S53112D'
,'S53112S'
,'S53113D'
,'S53113S'
,'S53114D'
,'S53114S'
,'S53115D'
,'S53115S'
,'S53116D'
,'S53116S'
,'S53121D'
,'S53121S'
,'S53122D'
,'S53122S'
,'S53123D'
,'S53123S'
,'S53124D'
,'S53124S'
,'S53125D'
,'S53125S'
,'S53126D'
,'S53126S'
,'S53131D'
,'S53131S'
,'S53132D'
,'S53132S'
,'S53133D'
,'S53133S'
,'S53134D'
,'S53134S'
,'S53135D'
,'S53135S'
,'S53136D'
,'S53136S'
,'S53141D'
,'S53141S'
,'S53142D'
,'S53142S'
,'S53143D'
,'S53143S'
,'S53144D'
,'S53144S'
,'S53145D'
,'S53145S'
,'S53146D'
,'S53146S'
,'S53191D'
,'S53191S'
,'S53192D'
,'S53192S'
,'S53193D'
,'S53193S'
,'S53194D'
,'S53194S'
,'S53195D'
,'S53195S'
,'S53196D'
,'S53196S'
,'S5320XD'
,'S5320XS'
,'S5321XD'
,'S5321XS'
,'S5322XD'
,'S5322XS'
,'S5330XD'
,'S5330XS'
,'S5331XD'
,'S5331XS'
,'S5332XD'
,'S5332XS'
,'S53401D'
,'S53401S'
,'S53402D'
,'S53402S'
,'S53409D'
,'S53409S'
,'S53411D'
,'S53411S'
,'S53412D'
,'S53412S'
,'S53419D'
,'S53419S'
,'S53421D'
,'S53421S'
,'S53422D'
,'S53422S'
,'S53429D'
,'S53429S'
,'S53431D'
,'S53431S'
,'S53432D'
,'S53432S'
,'S53439D'
,'S53439S'
,'S53441D'
,'S53441S'
,'S53442D'
,'S53442S'
,'S53449D'
,'S53449S'
,'S53491D'
,'S53491S'
,'S53492D'
,'S53492S'
,'S53499D'
,'S53499S'
,'S5400XD'
,'S5400XS'
,'S5401XD'
,'S5401XS'
,'S5402XD'
,'S5402XS'
,'S5410XD'
,'S5410XS'
,'S5411XD'
,'S5411XS'
,'S5412XD'
,'S5412XS'
,'S5420XD'
,'S5420XS'
,'S5421XD'
,'S5421XS'
,'S5422XD'
,'S5422XS'
,'S5430XD'
,'S5430XS'
,'S5431XD'
,'S5431XS'
,'S5432XD'
,'S5432XS'
,'S548X1D'
,'S548X1S'
,'S548X2D'
,'S548X2S'
,'S548X9D'
,'S548X9S'
,'S5490XD'
,'S5490XS'
,'S5491XD'
,'S5491XS'
,'S5492XD'
,'S5492XS'
,'S55001D'
,'S55001S'
,'S55002D'
,'S55002S'
,'S55009D'
,'S55009S'
,'S55011D'
,'S55011S'
,'S55012D'
,'S55012S'
,'S55019D'
,'S55019S'
,'S55091D'
,'S55091S'
,'S55092D'
,'S55092S'
,'S55099D'
,'S55099S'
,'S55101D'
,'S55101S'
,'S55102D'
,'S55102S'
,'S55109D'
,'S55109S'
,'S55111D'
,'S55111S'
,'S55112D'
,'S55112S'
,'S55119D'
,'S55119S'
,'S55191D'
,'S55191S'
,'S55192D'
,'S55192S'
,'S55199D'
,'S55199S'
,'S55201D'
,'S55201S'
,'S55202D'
,'S55202S'
,'S55209D'
,'S55209S'
,'S55211D'
,'S55211S'
,'S55212D'
,'S55212S'
,'S55219D'
,'S55219S'
,'S55291D'
,'S55291S'
,'S55292D'
,'S55292S'
,'S55299D'
,'S55299S'
,'S55801D'
,'S55801S'
,'S55802D'
,'S55802S'
,'S55809D'
,'S55809S'
,'S55811D'
,'S55811S'
,'S55812D'
,'S55812S'
,'S55819D'
,'S55819S'
,'S55891D'
,'S55891S'
,'S55892D'
,'S55892S'
,'S55899D'
,'S55899S'
,'S55901D'
,'S55901S'
,'S55902D'
,'S55902S'
,'S55909D'
,'S55909S'
,'S55911D'
,'S55911S'
,'S55912D'
,'S55912S'
,'S55919D'
,'S55919S'
,'S55991D'
,'S55991S'
,'S55992D'
,'S55992S'
,'S55999D'
,'S55999S'
,'S56001D'
,'S56001S'
,'S56002D'
,'S56002S'
,'S56009D'
,'S56009S'
,'S56011D'
,'S56011S'
,'S56012D'
,'S56012S'
,'S56019D'
,'S56019S'
,'S56021D'
,'S56021S'
,'S56022D'
,'S56022S'
,'S56029D'
,'S56029S'
,'S56091D'
,'S56091S'
,'S56092D'
,'S56092S'
,'S56099D'
,'S56099S'
,'S56101D'
,'S56101S'
,'S56102D'
,'S56102S'
,'S56103D'
,'S56103S'
,'S56104D'
,'S56104S'
,'S56105D'
,'S56105S'
,'S56106D'
,'S56106S'
,'S56107D'
,'S56107S'
,'S56108D'
,'S56108S'
,'S56109D'
,'S56109S'
,'S56111D'
,'S56111S'
,'S56112D'
,'S56112S'
,'S56113D'
,'S56113S'
,'S56114D'
,'S56114S'
,'S56115D'
,'S56115S'
,'S56116D'
,'S56116S'
,'S56117D'
,'S56117S'
,'S56118D'
,'S56118S'
,'S56119D'
,'S56119S'
,'S56121D'
,'S56121S'
,'S56122D'
,'S56122S'
,'S56123D'
,'S56123S'
,'S56124D'
,'S56124S'
,'S56125D'
,'S56125S'
,'S56126D'
,'S56126S'
,'S56127D'
,'S56127S'
,'S56128D'
,'S56128S'
,'S56129D'
,'S56129S'
,'S56191D'
,'S56191S'
,'S56192D'
,'S56192S'
,'S56193D'
,'S56193S'
,'S56194D'
,'S56194S'
,'S56195D'
,'S56195S'
,'S56196D'
,'S56196S'
,'S56197D'
,'S56197S'
,'S56198D'
,'S56198S'
,'S56199D'
,'S56199S'
,'S56201D'
,'S56201S'
,'S56202D'
,'S56202S'
,'S56209D'
,'S56209S'
,'S56211D'
,'S56211S'
,'S56212D'
,'S56212S'
,'S56219D'
,'S56219S'
,'S56221D'
,'S56221S'
,'S56222D'
,'S56222S'
,'S56229D'
,'S56229S'
,'S56291D'
,'S56291S'
,'S56292D'
,'S56292S'
,'S56299D'
,'S56299S'
,'S56301D'
,'S56301S'
,'S56302D'
,'S56302S'
,'S56309D'
,'S56309S'
,'S56311D'
,'S56311S'
,'S56312D'
,'S56312S'
,'S56319D'
,'S56319S'
,'S56321D'
,'S56321S'
,'S56322D'
,'S56322S'
,'S56329D'
,'S56329S'
,'S56391D'
,'S56391S'
,'S56392D'
,'S56392S'
,'S56399D'
,'S56399S'
,'S56401D'
,'S56401S'
,'S56402D'
,'S56402S'
,'S56403D'
,'S56403S'
,'S56404D'
,'S56404S'
,'S56405D'
,'S56405S'
,'S56406D'
,'S56406S'
,'S56407D'
,'S56407S'
,'S56408D'
,'S56408S'
,'S56409D'
,'S56409S'
,'S56411D'
,'S56411S'
,'S56412D'
,'S56412S'
,'S56413D'
,'S56413S'
,'S56414D'
,'S56414S'
,'S56415D'
,'S56415S'
,'S56416D'
,'S56416S'
,'S56417D'
,'S56417S'
,'S56418D'
,'S56418S'
,'S56419D'
,'S56419S'
,'S56421D'
,'S56421S'
,'S56422D'
,'S56422S'
,'S56423D'
,'S56423S'
,'S56424D'
,'S56424S'
,'S56425D'
,'S56425S'
,'S56426D'
,'S56426S'
,'S56427D'
,'S56427S'
,'S56428D'
,'S56428S'
,'S56429D'
,'S56429S'
,'S56491D'
,'S56491S'
,'S56492D'
,'S56492S'
,'S56493D'
,'S56493S'
,'S56494D'
,'S56494S'
,'S56495D'
,'S56495S'
,'S56496D'
,'S56496S'
,'S56497D'
,'S56497S'
,'S56498D'
,'S56498S'
,'S56499D'
,'S56499S'
,'S56501D'
,'S56501S'
,'S56502D'
,'S56502S'
,'S56509D'
,'S56509S'
,'S56511D'
,'S56511S'
,'S56512D'
,'S56512S'
,'S56519D'
,'S56519S'
,'S56521D'
,'S56521S'
,'S56522D'
,'S56522S'
,'S56529D'
,'S56529S'
,'S56591D'
,'S56591S'
,'S56592D'
,'S56592S'
,'S56599D'
,'S56599S'
,'S56801D'
,'S56801S'
,'S56802D'
,'S56802S'
,'S56809D'
,'S56809S'
,'S56811D'
,'S56811S'
,'S56812D'
,'S56812S'
,'S56819D'
,'S56819S'
,'S56821D'
,'S56821S'
,'S56822D'
,'S56822S'
,'S56829D'
,'S56829S'
,'S56891D'
,'S56891S'
,'S56892D'
,'S56892S'
,'S56899D'
,'S56899S'
,'S56901D'
,'S56901S'
,'S56902D'
,'S56902S'
,'S56909D'
,'S56909S'
,'S56911D'
,'S56911S'
,'S56912D'
,'S56912S'
,'S56919D'
,'S56919S'
,'S56921D'
,'S56921S'
,'S56922D'
,'S56922S'
,'S56929D'
,'S56929S'
,'S56991D'
,'S56991S'
,'S56992D'
,'S56992S'
,'S56999D'
,'S56999S'
,'S5700XD'
,'S5700XS'
,'S5701XD'
,'S5701XS'
,'S5702XD'
,'S5702XS'
,'S5780XD'
,'S5780XS'
,'S5781XD'
,'S5781XS'
,'S5782XD'
,'S5782XS'
,'S58011D'
,'S58011S'
,'S58012D'
,'S58012S'
,'S58019D'
,'S58019S'
,'S58021D'
,'S58021S'
,'S58022D'
,'S58022S'
,'S58029D'
,'S58029S'
,'S58111D'
,'S58111S'
,'S58112D'
,'S58112S'
,'S58119D'
,'S58119S'
,'S58121D'
,'S58121S'
,'S58122D'
,'S58122S'
,'S58129D'
,'S58129S'
,'S58911D'
,'S58911S'
,'S58912D'
,'S58912S'
,'S58919D'
,'S58919S'
,'S58921D'
,'S58921S'
,'S58922D'
,'S58922S'
,'S58929D'
,'S58929S'
,'S59001D'
,'S59001G'
,'S59001K'
,'S59001P'
,'S59001S'
,'S59002D'
,'S59002G'
,'S59002K'
,'S59002P'
,'S59002S'
,'S59009D'
,'S59009G'
,'S59009K'
,'S59009P'
,'S59009S'
,'S59011D'
,'S59011G'
,'S59011K'
,'S59011P'
,'S59011S'
,'S59012D'
,'S59012G'
,'S59012K'
,'S59012P'
,'S59012S'
,'S59019D'
,'S59019G'
,'S59019K'
,'S59019P'
,'S59019S'
,'S59021D'
,'S59021G'
,'S59021K'
,'S59021P'
,'S59021S'
,'S59022D'
,'S59022G'
,'S59022K'
,'S59022P'
,'S59022S'
,'S59029D'
,'S59029G'
,'S59029K'
,'S59029P'
,'S59029S'
,'S59031D'
,'S59031G'
,'S59031K'
,'S59031P'
,'S59031S'
,'S59032D'
,'S59032G'
,'S59032K'
,'S59032P'
,'S59032S'
,'S59039D'
,'S59039G'
,'S59039K'
,'S59039P'
,'S59039S'
,'S59041D'
,'S59041G'
,'S59041K'
,'S59041P'
,'S59041S'
,'S59042D'
,'S59042G'
,'S59042K'
,'S59042P'
,'S59042S'
,'S59049D'
,'S59049G'
,'S59049K'
,'S59049P'
,'S59049S'
,'S59091D'
,'S59091G'
,'S59091K'
,'S59091P'
,'S59091S'
,'S59092D'
,'S59092G'
,'S59092K'
,'S59092P'
,'S59092S'
,'S59099D'
,'S59099G'
,'S59099K'
,'S59099P'
,'S59099S'
,'S59101D'
,'S59101G'
,'S59101K'
,'S59101P'
,'S59101S'
,'S59102D'
,'S59102G'
,'S59102K'
,'S59102P'
,'S59102S'
,'S59109D'
,'S59109G'
,'S59109K'
,'S59109P'
,'S59109S'
,'S59111D'
,'S59111G'
,'S59111K'
,'S59111P'
,'S59111S'
,'S59112D'
,'S59112G'
,'S59112K'
,'S59112P'
,'S59112S'
,'S59119D'
,'S59119G'
,'S59119K'
,'S59119P'
,'S59119S'
,'S59121D'
,'S59121G'
,'S59121K'
,'S59121P'
,'S59121S'
,'S59122D'
,'S59122G'
,'S59122K'
,'S59122P'
,'S59122S'
,'S59129D'
,'S59129G'
,'S59129K'
,'S59129P'
,'S59129S'
,'S59131D'
,'S59131G'
,'S59131K'
,'S59131P'
,'S59131S'
,'S59132D'
,'S59132G'
,'S59132K'
,'S59132P'
,'S59132S'
,'S59139D'
,'S59139G'
,'S59139K'
,'S59139P'
,'S59139S'
,'S59141D'
,'S59141G'
,'S59141K'
,'S59141P'
,'S59141S'
,'S59142D'
,'S59142G'
,'S59142K'
,'S59142P'
,'S59142S'
,'S59149D'
,'S59149G'
,'S59149K'
,'S59149P'
,'S59149S'
,'S59191D'
,'S59191G'
,'S59191K'
,'S59191P'
,'S59191S'
,'S59192D'
,'S59192G'
,'S59192K'
,'S59192P'
,'S59192S'
,'S59199D'
,'S59199G'
,'S59199K'
,'S59199P'
,'S59199S'
,'S59201D'
,'S59201G'
,'S59201K'
,'S59201P'
,'S59201S'
,'S59202D'
,'S59202G'
,'S59202K'
,'S59202P'
,'S59202S'
,'S59209D'
,'S59209G'
,'S59209K'
,'S59209P'
,'S59209S'
,'S59211D'
,'S59211G'
,'S59211K'
,'S59211P'
,'S59211S'
,'S59212D'
,'S59212G'
,'S59212K'
,'S59212P'
,'S59212S'
,'S59219D'
,'S59219G'
,'S59219K'
,'S59219P'
,'S59219S'
,'S59221D'
,'S59221G'
,'S59221K'
,'S59221P'
,'S59221S'
,'S59222D'
,'S59222G'
,'S59222K'
,'S59222P'
,'S59222S'
,'S59229D'
,'S59229G'
,'S59229K'
,'S59229P'
,'S59229S'
,'S59231D'
,'S59231G'
,'S59231K'
,'S59231P'
,'S59231S'
,'S59232D'
,'S59232G'
,'S59232K'
,'S59232P'
,'S59232S'
,'S59239D'
,'S59239G'
,'S59239K'
,'S59239P'
,'S59239S'
,'S59241D'
,'S59241G'
,'S59241K'
,'S59241P'
,'S59241S'
,'S59242D'
,'S59242G'
,'S59242K'
,'S59242P'
,'S59242S'
,'S59249D'
,'S59249G'
,'S59249K'
,'S59249P'
,'S59249S'
,'S59291D'
,'S59291G'
,'S59291K'
,'S59291P'
,'S59291S'
,'S59292D'
,'S59292G'
,'S59292K'
,'S59292P'
,'S59292S'
,'S59299D'
,'S59299G'
,'S59299K'
,'S59299P'
,'S59299S'
,'S59801D'
,'S59801S'
,'S59802D'
,'S59802S'
,'S59809D'
,'S59809S'
,'S59811D'
,'S59811S'
,'S59812D'
,'S59812S'
,'S59819D'
,'S59819S'
,'S59901D'
,'S59901S'
,'S59902D'
,'S59902S'
,'S59909D'
,'S59909S'
,'S59911D'
,'S59911S'
,'S59912D'
,'S59912S'
,'S59919D'
,'S59919S'
,'S6000XD'
,'S6000XS'
,'S60011D'
,'S60011S'
,'S60012D'
,'S60012S'
,'S60019D'
,'S60019S'
,'S60021D'
,'S60021S'
,'S60022D'
,'S60022S'
,'S60029D'
,'S60029S'
,'S60031D'
,'S60031S'
,'S60032D'
,'S60032S'
,'S60039D'
,'S60039S'
,'S60041D'
,'S60041S'
,'S60042D'
,'S60042S'
,'S60049D'
,'S60049S'
,'S60051D'
,'S60051S'
,'S60052D'
,'S60052S'
,'S60059D'
,'S60059S'
,'S6010XD'
,'S6010XS'
,'S60111D'
,'S60111S'
,'S60112D'
,'S60112S'
,'S60119D'
,'S60119S'
,'S60121D'
,'S60121S'
,'S60122D'
,'S60122S'
,'S60129D'
,'S60129S'
,'S60131D'
,'S60131S'
,'S60132D'
,'S60132S'
,'S60139D'
,'S60139S'
,'S60141D'
,'S60141S'
,'S60142D'
,'S60142S'
,'S60149D'
,'S60149S'
,'S60151D'
,'S60151S'
,'S60152D'
,'S60152S'
,'S60159D'
,'S60159S'
,'S60211D'
,'S60211S'
,'S60212D'
,'S60212S'
,'S60219D'
,'S60219S'
,'S60221D'
,'S60221S'
,'S60222D'
,'S60222S'
,'S60229D'
,'S60229S'
,'S60311D'
,'S60311S'
,'S60312D'
,'S60312S'
,'S60319D'
,'S60319S'
,'S60321D'
,'S60321S'
,'S60322D'
,'S60322S'
,'S60329D'
,'S60329S'
,'S60341D'
,'S60341S'
,'S60342D'
,'S60342S'
,'S60349D'
,'S60349S'
,'S60351D'
,'S60351S'
,'S60352D'
,'S60352S'
,'S60359D'
,'S60359S'
,'S60361D'
,'S60361S'
,'S60362D'
,'S60362S'
,'S60369D'
,'S60369S'
,'S60371D'
,'S60371S'
,'S60372D'
,'S60372S'
,'S60379D'
,'S60379S'
,'S60391D'
,'S60391S'
,'S60392D'
,'S60392S'
,'S60399D'
,'S60399S'
,'S60410D'
,'S60410S'
,'S60411D'
,'S60411S'
,'S60412D'
,'S60412S'
,'S60413D'
,'S60413S'
,'S60414D'
,'S60414S'
,'S60415D'
,'S60415S'
,'S60416D'
,'S60416S'
,'S60417D'
,'S60417S'
,'S60418D'
,'S60418S'
,'S60419D'
,'S60419S'
,'S60420D'
,'S60420S'
,'S60421D'
,'S60421S'
,'S60422D'
,'S60422S'
,'S60423D'
,'S60423S'
,'S60424D'
,'S60424S'
,'S60425D'
,'S60425S'
,'S60426D'
,'S60426S'
,'S60427D'
,'S60427S'
,'S60428D'
,'S60428S'
,'S60429D'
,'S60429S'
,'S60440D'
,'S60440S'
,'S60441D'
,'S60441S'
,'S60442D'
,'S60442S'
,'S60443D'
,'S60443S'
,'S60444D'
,'S60444S'
,'S60445D'
,'S60445S'
,'S60446D'
,'S60446S'
,'S60447D'
,'S60447S'
,'S60448D'
,'S60448S'
,'S60449D'
,'S60449S'
,'S60450D'
,'S60450S'
,'S60451D'
,'S60451S'
,'S60452D'
,'S60452S'
,'S60453D'
,'S60453S'
,'S60454D'
,'S60454S'
,'S60455D'
,'S60455S'
,'S60456D'
,'S60456S'
,'S60457D'
,'S60457S'
,'S60458D'
,'S60458S'
,'S60459D'
,'S60459S'
,'S60460D'
,'S60460S'
,'S60461D'
,'S60461S'
,'S60462D'
,'S60462S'
,'S60463D'
,'S60463S'
,'S60464D'
,'S60464S'
,'S60465D'
,'S60465S'
,'S60466D'
,'S60466S'
,'S60467D'
,'S60467S'
,'S60468D'
,'S60468S'
,'S60469D'
,'S60469S'
,'S60470D'
,'S60470S'
,'S60471D'
,'S60471S'
,'S60472D'
,'S60472S'
,'S60473D'
,'S60473S'
,'S60474D'
,'S60474S'
,'S60475D'
,'S60475S'
,'S60476D'
,'S60476S'
,'S60477D'
,'S60477S'
,'S60478D'
,'S60478S'
,'S60479D'
,'S60479S'
,'S60511D'
,'S60511S'
,'S60512D'
,'S60512S'
,'S60519D'
,'S60519S'
,'S60521D'
,'S60521S'
,'S60522D'
,'S60522S'
,'S60529D'
,'S60529S'
,'S60541D'
,'S60541S'
,'S60542D'
,'S60542S'
,'S60549D'
,'S60549S'
,'S60551D'
,'S60551S'
,'S60552D'
,'S60552S'
,'S60559D'
,'S60559S'
,'S60561D'
,'S60561S'
,'S60562D'
,'S60562S'
,'S60569D'
,'S60569S'
,'S60571D'
,'S60571S'
,'S60572D'
,'S60572S'
,'S60579D'
,'S60579S'
,'S60811D'
,'S60811S'
,'S60812D'
,'S60812S'
,'S60819D'
,'S60819S'
,'S60821D'
,'S60821S'
,'S60822D'
,'S60822S'
,'S60829D'
,'S60829S'
,'S60841D'
,'S60841S'
,'S60842D'
,'S60842S'
,'S60849D'
,'S60849S'
,'S60851D'
,'S60851S'
,'S60852D'
,'S60852S'
,'S60859D'
,'S60859S'
,'S60861D'
,'S60861S'
,'S60862D'
,'S60862S'
,'S60869D'
,'S60869S'
,'S60871D'
,'S60871S'
,'S60872D'
,'S60872S'
,'S60879D'
,'S60879S'
,'S60911D'
,'S60911S'
,'S60912D'
,'S60912S'
,'S60919D'
,'S60919S'
,'S60921D'
,'S60921S'
,'S60922D'
,'S60922S'
,'S60929D'
,'S60929S'
,'S60931D'
,'S60931S'
,'S60932D'
,'S60932S'
,'S60939D'
,'S60939S'
,'S60940D'
,'S60940S'
,'S60941D'
,'S60941S'
,'S60942D'
,'S60942S'
,'S60943D'
,'S60943S'
,'S60944D'
,'S60944S'
,'S60945D'
,'S60945S'
,'S60946D'
,'S60946S'
,'S60947D'
,'S60947S'
,'S60948D'
,'S60948S'
,'S60949D'
,'S60949S'
,'S61001D'
,'S61001S'
,'S61002D'
,'S61002S'
,'S61009D'
,'S61009S'
,'S61011D'
,'S61011S'
,'S61012D'
,'S61012S'
,'S61019D'
,'S61019S'
,'S61021D'
,'S61021S'
,'S61022D'
,'S61022S'
,'S61029D'
,'S61029S'
,'S61031D'
,'S61031S'
,'S61032D'
,'S61032S'
,'S61039D'
,'S61039S'
,'S61041D'
,'S61041S'
,'S61042D'
,'S61042S'
,'S61049D'
,'S61049S'
,'S61051D'
,'S61051S'
,'S61052D'
,'S61052S'
,'S61059D'
,'S61059S'
,'S61101D'
,'S61101S'
,'S61102D'
,'S61102S'
,'S61109D'
,'S61109S'
,'S61111D'
,'S61111S'
,'S61112D'
,'S61112S'
,'S61119D'
,'S61119S'
,'S61121D'
,'S61121S'
,'S61122D'
,'S61122S'
,'S61129D'
,'S61129S'
,'S61131D'
,'S61131S'
,'S61132D'
,'S61132S'
,'S61139D'
,'S61139S'
,'S61141D'
,'S61141S'
,'S61142D'
,'S61142S'
,'S61149D'
,'S61149S'
,'S61151D'
,'S61151S'
,'S61152D'
,'S61152S'
,'S61159D'
,'S61159S'
,'S61200D'
,'S61200S'
,'S61201D'
,'S61201S'
,'S61202D'
,'S61202S'
,'S61203D'
,'S61203S'
,'S61204D'
,'S61204S'
,'S61205D'
,'S61205S'
,'S61206D'
,'S61206S'
,'S61207D'
,'S61207S'
,'S61208D'
,'S61208S'
,'S61209D'
,'S61209S'
,'S61210D'
,'S61210S'
,'S61211D'
,'S61211S'
,'S61212D'
,'S61212S'
,'S61213D'
,'S61213S'
,'S61214D'
,'S61214S'
,'S61215D'
,'S61215S'
,'S61216D'
,'S61216S'
,'S61217D'
,'S61217S'
,'S61218D'
,'S61218S'
,'S61219D'
,'S61219S'
,'S61220D'
,'S61220S'
,'S61221D'
,'S61221S'
,'S61222D'
,'S61222S'
,'S61223D'
,'S61223S'
,'S61224D'
,'S61224S'
,'S61225D'
,'S61225S'
,'S61226D'
,'S61226S'
,'S61227D'
,'S61227S'
,'S61228D'
,'S61228S'
,'S61229D'
,'S61229S'
,'S61230D'
,'S61230S'
,'S61231D'
,'S61231S'
,'S61232D'
,'S61232S'
,'S61233D'
,'S61233S'
,'S61234D'
,'S61234S'
,'S61235D'
,'S61235S'
,'S61236D'
,'S61236S'
,'S61237D'
,'S61237S'
,'S61238D'
,'S61238S'
,'S61239D'
,'S61239S'
,'S61240D'
,'S61240S'
,'S61241D'
,'S61241S'
,'S61242D'
,'S61242S'
,'S61243D'
,'S61243S'
,'S61244D'
,'S61244S'
,'S61245D'
,'S61245S'
,'S61246D'
,'S61246S'
,'S61247D'
,'S61247S'
,'S61248D'
,'S61248S'
,'S61249D'
,'S61249S'
,'S61250D'
,'S61250S'
,'S61251D'
,'S61251S'
,'S61252D'
,'S61252S'
,'S61253D'
,'S61253S'
,'S61254D'
,'S61254S'
,'S61255D'
,'S61255S'
,'S61256D'
,'S61256S'
,'S61257D'
,'S61257S'
,'S61258D'
,'S61258S'
,'S61259D'
,'S61259S'
,'S61300D'
,'S61300S'
,'S61301D'
,'S61301S'
,'S61302D'
,'S61302S'
,'S61303D'
,'S61303S'
,'S61304D'
,'S61304S'
,'S61305D'
,'S61305S'
,'S61306D'
,'S61306S'
,'S61307D'
,'S61307S'
,'S61308D'
,'S61308S'
,'S61309D'
,'S61309S'
,'S61310D'
,'S61310S'
,'S61311D'
,'S61311S'
,'S61312D'
,'S61312S'
,'S61313D'
,'S61313S'
,'S61314D'
,'S61314S'
,'S61315D'
,'S61315S'
,'S61316D'
,'S61316S'
,'S61317D'
,'S61317S'
,'S61318D'
,'S61318S'
,'S61319D'
,'S61319S'
,'S61320D'
,'S61320S'
,'S61321D'
,'S61321S'
,'S61322D'
,'S61322S'
,'S61323D'
,'S61323S'
,'S61324D'
,'S61324S'
,'S61325D'
,'S61325S'
,'S61326D'
,'S61326S'
,'S61327D'
,'S61327S'
,'S61328D'
,'S61328S'
,'S61329D'
,'S61329S'
,'S61330D'
,'S61330S'
,'S61331D'
,'S61331S'
,'S61332D'
,'S61332S'
,'S61333D'
,'S61333S'
,'S61334D'
,'S61334S'
,'S61335D'
,'S61335S'
,'S61336D'
,'S61336S'
,'S61337D'
,'S61337S'
,'S61338D'
,'S61338S'
,'S61339D'
,'S61339S'
,'S61340D'
,'S61340S'
,'S61341D'
,'S61341S'
,'S61342D'
,'S61342S'
,'S61343D'
,'S61343S'
,'S61344D'
,'S61344S'
,'S61345D'
,'S61345S'
,'S61346D'
,'S61346S'
,'S61347D'
,'S61347S'
,'S61348D'
,'S61348S'
,'S61349D'
,'S61349S'
,'S61350D'
,'S61350S'
,'S61351D'
,'S61351S'
,'S61352D'
,'S61352S'
,'S61353D'
,'S61353S'
,'S61354D'
,'S61354S'
,'S61355D'
,'S61355S'
,'S61356D'
,'S61356S'
,'S61357D'
,'S61357S'
,'S61358D'
,'S61358S'
,'S61359D'
,'S61359S'
,'S61401D'
,'S61401S'
,'S61402D'
,'S61402S'
,'S61409D'
,'S61409S'
,'S61411D'
,'S61411S'
,'S61412D'
,'S61412S'
,'S61419D'
,'S61419S'
,'S61421D'
,'S61421S'
,'S61422D'
,'S61422S'
,'S61429D'
,'S61429S'
,'S61431D'
,'S61431S'
,'S61432D'
,'S61432S'
,'S61439D'
,'S61439S'
,'S61441D'
,'S61441S'
,'S61442D'
,'S61442S'
,'S61449D'
,'S61449S'
,'S61451D'
,'S61451S'
,'S61452D'
,'S61452S'
,'S61459D'
,'S61459S'
,'S61501D'
,'S61501S'
,'S61502D'
,'S61502S'
,'S61509D'
,'S61509S'
,'S61511D'
,'S61511S'
,'S61512D'
,'S61512S'
,'S61519D'
,'S61519S'
,'S61521D'
,'S61521S'
,'S61522D'
,'S61522S'
,'S61529D'
,'S61529S'
,'S61531D'
,'S61531S'
,'S61532D'
,'S61532S'
,'S61539D'
,'S61539S'
,'S61541D'
,'S61541S'
,'S61542D'
,'S61542S'
,'S61549D'
,'S61549S'
,'S61551D'
,'S61551S'
,'S61552D'
,'S61552S'
,'S61559D'
,'S61559S'
,'S62001D'
,'S62001G'
,'S62001K'
,'S62001P'
,'S62001S'
,'S62002D'
,'S62002G'
,'S62002K'
,'S62002P'
,'S62002S'
,'S62009D'
,'S62009G'
,'S62009K'
,'S62009P'
,'S62009S'
,'S62011D'
,'S62011G'
,'S62011K'
,'S62011P'
,'S62011S'
,'S62012D'
,'S62012G'
,'S62012K'
,'S62012P'
,'S62012S'
,'S62013D'
,'S62013G'
,'S62013K'
,'S62013P'
,'S62013S'
,'S62014D'
,'S62014G'
,'S62014K'
,'S62014P'
,'S62014S'
,'S62015D'
,'S62015G'
,'S62015K'
,'S62015P'
,'S62015S'
,'S62016D'
,'S62016G'
,'S62016K'
,'S62016P'
,'S62016S'
,'S62021D'
,'S62021G'
,'S62021K'
,'S62021P'
,'S62021S'
,'S62022D'
,'S62022G'
,'S62022K'
,'S62022P'
,'S62022S'
,'S62023D'
,'S62023G'
,'S62023K'
,'S62023P'
,'S62023S'
,'S62024D'
,'S62024G'
,'S62024K'
,'S62024P'
,'S62024S'
,'S62025D'
,'S62025G'
,'S62025K'
,'S62025P'
,'S62025S'
,'S62026D'
,'S62026G'
,'S62026K'
,'S62026P'
,'S62026S'
,'S62031D'
,'S62031G'
,'S62031K'
,'S62031P'
,'S62031S'
,'S62032D'
,'S62032G'
,'S62032K'
,'S62032P'
,'S62032S'
,'S62033D'
,'S62033G'
,'S62033K'
,'S62033P'
,'S62033S'
,'S62034D'
,'S62034G'
,'S62034K'
,'S62034P'
,'S62034S'
,'S62035D'
,'S62035G'
,'S62035K'
,'S62035P'
,'S62035S'
,'S62036D'
,'S62036G'
,'S62036K'
,'S62036P'
,'S62036S'
,'S62101D'
,'S62101G'
,'S62101K'
,'S62101P'
,'S62101S'
,'S62102D'
,'S62102G'
,'S62102K'
,'S62102P'
,'S62102S'
,'S62109D'
,'S62109G'
,'S62109K'
,'S62109P'
,'S62109S'
,'S62111D'
,'S62111G'
,'S62111K'
,'S62111P'
,'S62111S'
,'S62112D'
,'S62112G'
,'S62112K'
,'S62112P'
,'S62112S'
,'S62113D'
,'S62113G'
,'S62113K'
,'S62113P'
,'S62113S'
,'S62114D'
,'S62114G'
,'S62114K'
,'S62114P'
,'S62114S'
,'S62115D'
,'S62115G'
,'S62115K'
,'S62115P'
,'S62115S'
,'S62116D'
,'S62116G'
,'S62116K'
,'S62116P'
,'S62116S'
,'S62121D'
,'S62121G'
,'S62121K'
,'S62121P'
,'S62121S'
,'S62122D'
,'S62122G'
,'S62122K'
,'S62122P'
,'S62122S'
,'S62123D'
,'S62123G'
,'S62123K'
,'S62123P'
,'S62123S'
,'S62124D'
,'S62124G'
,'S62124K'
,'S62124P'
,'S62124S'
,'S62125D'
,'S62125G'
,'S62125K'
,'S62125P'
,'S62125S'
,'S62126D'
,'S62126G'
,'S62126K'
,'S62126P'
,'S62126S'
,'S62131D'
,'S62131G'
,'S62131K'
,'S62131P'
,'S62131S'
,'S62132D'
,'S62132G'
,'S62132K'
,'S62132P'
,'S62132S'
,'S62133D'
,'S62133G'
,'S62133K'
,'S62133P'
,'S62133S'
,'S62134D'
,'S62134G'
,'S62134K'
,'S62134P'
,'S62134S'
,'S62135D'
,'S62135G'
,'S62135K'
,'S62135P'
,'S62135S'
,'S62136D'
,'S62136G'
,'S62136K'
,'S62136P'
,'S62136S'
,'S62141D'
,'S62141G'
,'S62141K'
,'S62141P'
,'S62141S'
,'S62142D'
,'S62142G'
,'S62142K'
,'S62142P'
,'S62142S'
,'S62143D'
,'S62143G'
,'S62143K'
,'S62143P'
,'S62143S'
,'S62144D'
,'S62144G'
,'S62144K'
,'S62144P'
,'S62144S'
,'S62145D'
,'S62145G'
,'S62145K'
,'S62145P'
,'S62145S'
,'S62146D'
,'S62146G'
,'S62146K'
,'S62146P'
,'S62146S'
,'S62151D'
,'S62151G'
,'S62151K'
,'S62151P'
,'S62151S'
,'S62152D'
,'S62152G'
,'S62152K'
,'S62152P'
,'S62152S'
,'S62153D'
,'S62153G'
,'S62153K'
,'S62153P'
,'S62153S'
,'S62154D'
,'S62154G'
,'S62154K'
,'S62154P'
,'S62154S'
,'S62155D'
,'S62155G'
,'S62155K'
,'S62155P'
,'S62155S'
,'S62156D'
,'S62156G'
,'S62156K'
,'S62156P'
,'S62156S'
,'S62161D'
,'S62161G'
,'S62161K'
,'S62161P'
,'S62161S'
,'S62162D'
,'S62162G'
,'S62162K'
,'S62162P'
,'S62162S'
,'S62163D'
,'S62163G'
,'S62163K'
,'S62163P'
,'S62163S'
,'S62164D'
,'S62164G'
,'S62164K'
,'S62164P'
,'S62164S'
,'S62165D'
,'S62165G'
,'S62165K'
,'S62165P'
,'S62165S'
,'S62166D'
,'S62166G'
,'S62166K'
,'S62166P'
,'S62166S'
,'S62171D'
,'S62171G'
,'S62171K'
,'S62171P'
,'S62171S'
,'S62172D'
,'S62172G'
,'S62172K'
,'S62172P'
,'S62172S'
,'S62173D'
,'S62173G'
,'S62173K'
,'S62173P'
,'S62173S'
,'S62174D'
,'S62174G'
,'S62174K'
,'S62174P'
,'S62174S'
,'S62175D'
,'S62175G'
,'S62175K'
,'S62175P'
,'S62175S'
,'S62176D'
,'S62176G'
,'S62176K'
,'S62176P'
,'S62176S'
,'S62181D'
,'S62181G'
,'S62181K'
,'S62181P'
,'S62181S'
,'S62182D'
,'S62182G'
,'S62182K'
,'S62182P'
,'S62182S'
,'S62183D'
,'S62183G'
,'S62183K'
,'S62183P'
,'S62183S'
,'S62184D'
,'S62184G'
,'S62184K'
,'S62184P'
,'S62184S'
,'S62185D'
,'S62185G'
,'S62185K'
,'S62185P'
,'S62185S'
,'S62186D'
,'S62186G'
,'S62186K'
,'S62186P'
,'S62186S'
,'S62201D'
,'S62201G'
,'S62201K'
,'S62201P'
,'S62201S'
,'S62202D'
,'S62202G'
,'S62202K'
,'S62202P'
,'S62202S'
,'S62209D'
,'S62209G'
,'S62209K'
,'S62209P'
,'S62209S'
,'S62211D'
,'S62211G'
,'S62211K'
,'S62211P'
,'S62211S'
,'S62212D'
,'S62212G'
,'S62212K'
,'S62212P'
,'S62212S'
,'S62213D'
,'S62213G'
,'S62213K'
,'S62213P'
,'S62213S'
,'S62221D'
,'S62221G'
,'S62221K'
,'S62221P'
,'S62221S'
,'S62222D'
,'S62222G'
,'S62222K'
,'S62222P'
,'S62222S'
,'S62223D'
,'S62223G'
,'S62223K'
,'S62223P'
,'S62223S'
,'S62224D'
,'S62224G'
,'S62224K'
,'S62224P'
,'S62224S'
,'S62225D'
,'S62225G'
,'S62225K'
,'S62225P'
,'S62225S'
,'S62226D'
,'S62226G'
,'S62226K'
,'S62226P'
,'S62226S'
,'S62231D'
,'S62231G'
,'S62231K'
,'S62231P'
,'S62231S'
,'S62232D'
,'S62232G'
,'S62232K'
,'S62232P'
,'S62232S'
,'S62233D'
,'S62233G'
,'S62233K'
,'S62233P'
,'S62233S'
,'S62234D'
,'S62234G'
,'S62234K'
,'S62234P'
,'S62234S'
,'S62235D'
,'S62235G'
,'S62235K'
,'S62235P'
,'S62235S'
,'S62236D'
,'S62236G'
,'S62236K'
,'S62236P'
,'S62236S'
,'S62241D'
,'S62241G'
,'S62241K'
,'S62241P'
,'S62241S'
,'S62242D'
,'S62242G'
,'S62242K'
,'S62242P'
,'S62242S'
,'S62243D'
,'S62243G'
,'S62243K'
,'S62243P'
,'S62243S'
,'S62244D'
,'S62244G'
,'S62244K'
,'S62244P'
,'S62244S'
,'S62245D'
,'S62245G'
,'S62245K'
,'S62245P'
,'S62245S'
,'S62246D'
,'S62246G'
,'S62246K'
,'S62246P'
,'S62246S'
,'S62251D'
,'S62251G'
,'S62251K'
,'S62251P'
,'S62251S'
,'S62252D'
,'S62252G'
,'S62252K'
,'S62252P'
,'S62252S'
,'S62253D'
,'S62253G'
,'S62253K'
,'S62253P'
,'S62253S'
,'S62254D'
,'S62254G'
,'S62254K'
,'S62254P'
,'S62254S'
,'S62255D'
,'S62255G'
,'S62255K'
,'S62255P'
,'S62255S'
,'S62256D'
,'S62256G'
,'S62256K'
,'S62256P'
,'S62256S'
,'S62291D'
,'S62291G'
,'S62291K'
,'S62291P'
,'S62291S'
,'S62292D'
,'S62292G'
,'S62292K'
,'S62292P'
,'S62292S'
,'S62299D'
,'S62299G'
,'S62299K'
,'S62299P'
,'S62299S'
,'S62300D'
,'S62300G'
,'S62300K'
,'S62300P'
,'S62300S'
,'S62301D'
,'S62301G'
,'S62301K'
,'S62301P'
,'S62301S'
,'S62302D'
,'S62302G'
,'S62302K'
,'S62302P'
,'S62302S'
,'S62303D'
,'S62303G'
,'S62303K'
,'S62303P'
,'S62303S'
,'S62304D'
,'S62304G'
,'S62304K'
,'S62304P'
,'S62304S'
,'S62305D'
,'S62305G'
,'S62305K'
,'S62305P'
,'S62305S'
,'S62306D'
,'S62306G'
,'S62306K'
,'S62306P'
,'S62306S'
,'S62307D'
,'S62307G'
,'S62307K'
,'S62307P'
,'S62307S'
,'S62308D'
,'S62308G'
,'S62308K'
,'S62308P'
,'S62308S'
,'S62309D'
,'S62309G'
,'S62309K'
,'S62309P'
,'S62309S'
,'S62310D'
,'S62310G'
,'S62310K'
,'S62310P'
,'S62310S'
,'S62311D'
,'S62311G'
,'S62311K'
,'S62311P'
,'S62311S'
,'S62312D'
,'S62312G'
,'S62312K'
,'S62312P'
,'S62312S'
,'S62313D'
,'S62313G'
,'S62313K'
,'S62313P'
,'S62313S'
,'S62314D'
,'S62314G'
,'S62314K'
,'S62314P'
,'S62314S'
,'S62315D'
,'S62315G'
,'S62315K'
,'S62315P'
,'S62315S'
,'S62316D'
,'S62316G'
,'S62316K'
,'S62316P'
,'S62316S'
,'S62317D'
,'S62317G'
,'S62317K'
,'S62317P'
,'S62317S'
,'S62318D'
,'S62318G'
,'S62318K'
,'S62318P'
,'S62318S'
,'S62319D'
,'S62319G'
,'S62319K'
,'S62319P'
,'S62319S'
,'S62320D'
,'S62320G'
,'S62320K'
,'S62320P'
,'S62320S'
,'S62321D'
,'S62321G'
,'S62321K'
,'S62321P'
,'S62321S'
,'S62322D'
,'S62322G'
,'S62322K'
,'S62322P'
,'S62322S'
,'S62323D'
,'S62323G'
,'S62323K'
,'S62323P'
,'S62323S'
,'S62324D'
,'S62324G'
,'S62324K'
,'S62324P'
,'S62324S'
,'S62325D'
,'S62325G'
,'S62325K'
,'S62325P'
,'S62325S'
,'S62326D'
,'S62326G'
,'S62326K'
,'S62326P'
,'S62326S'
,'S62327D'
,'S62327G'
,'S62327K'
,'S62327P'
,'S62327S'
,'S62328D'
,'S62328G'
,'S62328K'
,'S62328P'
,'S62328S'
,'S62329D'
,'S62329G'
,'S62329K'
,'S62329P'
,'S62329S'
,'S62330D'
,'S62330G'
,'S62330K'
,'S62330P'
,'S62330S'
,'S62331D'
,'S62331G'
,'S62331K'
,'S62331P'
,'S62331S'
,'S62332D'
,'S62332G'
,'S62332K'
,'S62332P'
,'S62332S'
,'S62333D'
,'S62333G'
,'S62333K'
,'S62333P'
,'S62333S'
,'S62334D'
,'S62334G'
,'S62334K'
,'S62334P'
,'S62334S'
,'S62335D'
,'S62335G'
,'S62335K'
,'S62335P'
,'S62335S'
,'S62336D'
,'S62336G'
,'S62336K'
,'S62336P'
,'S62336S'
,'S62337D'
,'S62337G'
,'S62337K'
,'S62337P'
,'S62337S'
,'S62338D'
,'S62338G'
,'S62338K'
,'S62338P'
,'S62338S'
,'S62339D'
,'S62339G'
,'S62339K'
,'S62339P'
,'S62339S'
,'S62340D'
,'S62340G'
,'S62340K'
,'S62340P'
,'S62340S'
,'S62341D'
,'S62341G'
,'S62341K'
,'S62341P'
,'S62341S'
,'S62342D'
,'S62342G'
,'S62342K'
,'S62342P'
,'S62342S'
,'S62343D'
,'S62343G'
,'S62343K'
,'S62343P'
,'S62343S'
,'S62344D'
,'S62344G'
,'S62344K'
,'S62344P'
,'S62344S'
,'S62345D'
,'S62345G'
,'S62345K'
,'S62345P'
,'S62345S'
,'S62346D'
,'S62346G'
,'S62346K'
,'S62346P'
,'S62346S'
,'S62347D'
,'S62347G'
,'S62347K'
,'S62347P'
,'S62347S'
,'S62348D'
,'S62348G'
,'S62348K'
,'S62348P'
,'S62348S'
,'S62349D'
,'S62349G'
,'S62349K'
,'S62349P'
,'S62349S'
,'S62350D'
,'S62350G'
,'S62350K'
,'S62350P'
,'S62350S'
,'S62351D'
,'S62351G'
,'S62351K'
,'S62351P'
,'S62351S'
,'S62352D'
,'S62352G'
,'S62352K'
,'S62352P'
,'S62352S'
,'S62353D'
,'S62353G'
,'S62353K'
,'S62353P'
,'S62353S'
,'S62354D'
,'S62354G'
,'S62354K'
,'S62354P'
,'S62354S'
,'S62355D'
,'S62355G'
,'S62355K'
,'S62355P'
,'S62355S'
,'S62356D'
,'S62356G'
,'S62356K'
,'S62356P'
,'S62356S'
,'S62357D'
,'S62357G'
,'S62357K'
,'S62357P'
,'S62357S'
,'S62358D'
,'S62358G'
,'S62358K'
,'S62358P'
,'S62358S'
,'S62359D'
,'S62359G'
,'S62359K'
,'S62359P'
,'S62359S'
,'S62360D'
,'S62360G'
,'S62360K'
,'S62360P'
,'S62360S'
,'S62361D'
,'S62361G'
,'S62361K'
,'S62361P'
,'S62361S'
,'S62362D'
,'S62362G'
,'S62362K'
,'S62362P'
,'S62362S'
,'S62363D'
,'S62363G'
,'S62363K'
,'S62363P'
,'S62363S'
,'S62364D'
,'S62364G'
,'S62364K'
,'S62364P'
,'S62364S'
,'S62365D'
,'S62365G'
,'S62365K'
,'S62365P'
,'S62365S'
,'S62366D'
,'S62366G'
,'S62366K'
,'S62366P'
,'S62366S'
,'S62367D'
,'S62367G'
,'S62367K'
,'S62367P'
,'S62367S'
,'S62368D'
,'S62368G'
,'S62368K'
,'S62368P'
,'S62368S'
,'S62369D'
,'S62369G'
,'S62369K'
,'S62369P'
,'S62369S'
,'S62390D'
,'S62390G'
,'S62390K'
,'S62390P'
,'S62390S'
,'S62391D'
,'S62391G'
,'S62391K'
,'S62391P'
,'S62391S'
,'S62392D'
,'S62392G'
,'S62392K'
,'S62392P'
,'S62392S'
,'S62393D'
,'S62393G'
,'S62393K'
,'S62393P'
,'S62393S'
,'S62394D'
,'S62394G'
,'S62394K'
,'S62394P'
,'S62394S'
,'S62395D'
,'S62395G'
,'S62395K'
,'S62395P'
,'S62395S'
,'S62396D'
,'S62396G'
,'S62396K'
,'S62396P'
,'S62396S'
,'S62397D'
,'S62397G'
,'S62397K'
,'S62397P'
,'S62397S'
,'S62398D'
,'S62398G'
,'S62398K'
,'S62398P'
,'S62398S'
,'S62399D'
,'S62399G'
,'S62399K'
,'S62399P'
,'S62399S'
,'S62501D'
,'S62501G'
,'S62501K'
,'S62501P'
,'S62501S'
,'S62502D'
,'S62502G'
,'S62502K'
,'S62502P'
,'S62502S'
,'S62509D'
,'S62509G'
,'S62509K'
,'S62509P'
,'S62509S'
,'S62511D'
,'S62511G'
,'S62511K'
,'S62511P'
,'S62511S'
,'S62512D'
,'S62512G'
,'S62512K'
,'S62512P'
,'S62512S'
,'S62513D'
,'S62513G'
,'S62513K'
,'S62513P'
,'S62513S'
,'S62514D'
,'S62514G'
,'S62514K'
,'S62514P'
,'S62514S'
,'S62515D'
,'S62515G'
,'S62515K'
,'S62515P'
,'S62515S'
,'S62516D'
,'S62516G'
,'S62516K'
,'S62516P'
,'S62516S'
,'S62521D'
,'S62521G'
,'S62521K'
,'S62521P'
,'S62521S'
,'S62522D'
,'S62522G'
,'S62522K'
,'S62522P'
,'S62522S'
,'S62523D'
,'S62523G'
,'S62523K'
,'S62523P'
,'S62523S'
,'S62524D'
,'S62524G'
,'S62524K'
,'S62524P'
,'S62524S'
,'S62525D'
,'S62525G'
,'S62525K'
,'S62525P'
,'S62525S'
,'S62526D'
,'S62526G'
,'S62526K'
,'S62526P'
,'S62526S'
,'S62600D'
,'S62600G'
,'S62600K'
,'S62600P'
,'S62600S'
,'S62601D'
,'S62601G'
,'S62601K'
,'S62601P'
,'S62601S'
,'S62602D'
,'S62602G'
,'S62602K'
,'S62602P'
,'S62602S'
,'S62603D'
,'S62603G'
,'S62603K'
,'S62603P'
,'S62603S'
,'S62604D'
,'S62604G'
,'S62604K'
,'S62604P'
,'S62604S'
,'S62605D'
,'S62605G'
,'S62605K'
,'S62605P'
,'S62605S'
,'S62606D'
,'S62606G'
,'S62606K'
,'S62606P'
,'S62606S'
,'S62607D'
,'S62607G'
,'S62607K'
,'S62607P'
,'S62607S'
,'S62608D'
,'S62608G'
,'S62608K'
,'S62608P'
,'S62608S'
,'S62609D'
,'S62609G'
,'S62609K'
,'S62609P'
,'S62609S'
,'S62610D'
,'S62610G'
,'S62610K'
,'S62610P'
,'S62610S'
,'S62611D'
,'S62611G'
,'S62611K'
,'S62611P'
,'S62611S'
,'S62612D'
,'S62612G'
,'S62612K'
,'S62612P'
,'S62612S'
,'S62613D'
,'S62613G'
,'S62613K'
,'S62613P'
,'S62613S'
,'S62614D'
,'S62614G'
,'S62614K'
,'S62614P'
,'S62614S'
,'S62615D'
,'S62615G'
,'S62615K'
,'S62615P'
,'S62615S'
,'S62616D'
,'S62616G'
,'S62616K'
,'S62616P'
,'S62616S'
,'S62617D'
,'S62617G'
,'S62617K'
,'S62617P'
,'S62617S'
,'S62618D'
,'S62618G'
,'S62618K'
,'S62618P'
,'S62618S'
,'S62619D'
,'S62619G'
,'S62619K'
,'S62619P'
,'S62619S'
,'S62620D'
,'S62620G'
,'S62620K'
,'S62620P'
,'S62620S'
,'S62621D'
,'S62621G'
,'S62621K'
,'S62621P'
,'S62621S'
,'S62622D'
,'S62622G'
,'S62622K'
,'S62622P'
,'S62622S'
,'S62623D'
,'S62623G'
,'S62623K'
,'S62623P'
,'S62623S'
,'S62624D'
,'S62624G'
,'S62624K'
,'S62624P'
,'S62624S'
,'S62625D'
,'S62625G'
,'S62625K'
,'S62625P'
,'S62625S'
,'S62626D'
,'S62626G'
,'S62626K'
,'S62626P'
,'S62626S'
,'S62627D'
,'S62627G'
,'S62627K'
,'S62627P'
,'S62627S'
,'S62628D'
,'S62628G'
,'S62628K'
,'S62628P'
,'S62628S'
,'S62629D'
,'S62629G'
,'S62629K'
,'S62629P'
,'S62629S'
,'S62630D'
,'S62630G'
,'S62630K'
,'S62630P'
,'S62630S'
,'S62631D'
,'S62631G'
,'S62631K'
,'S62631P'
,'S62631S'
,'S62632D'
,'S62632G'
,'S62632K'
,'S62632P'
,'S62632S'
,'S62633D'
,'S62633G'
,'S62633K'
,'S62633P'
,'S62633S'
,'S62634D'
,'S62634G'
,'S62634K'
,'S62634P'
,'S62634S'
,'S62635D'
,'S62635G'
,'S62635K'
,'S62635P'
,'S62635S'
,'S62636D'
,'S62636G'
,'S62636K'
,'S62636P'
,'S62636S'
,'S62637D'
,'S62637G'
,'S62637K'
,'S62637P'
,'S62637S'
,'S62638D'
,'S62638G'
,'S62638K'
,'S62638P'
,'S62638S'
,'S62639D'
,'S62639G'
,'S62639K'
,'S62639P'
,'S62639S'
,'S62640D'
,'S62640G'
,'S62640K'
,'S62640P'
,'S62640S'
,'S62641D'
,'S62641G'
,'S62641K'
,'S62641P'
,'S62641S'
,'S62642D'
,'S62642G'
,'S62642K'
,'S62642P'
,'S62642S'
,'S62643D'
,'S62643G'
,'S62643K'
,'S62643P'
,'S62643S'
,'S62644D'
,'S62644G'
,'S62644K'
,'S62644P'
,'S62644S'
,'S62645D'
,'S62645G'
,'S62645K'
,'S62645P'
,'S62645S'
,'S62646D'
,'S62646G'
,'S62646K'
,'S62646P'
,'S62646S'
,'S62647D'
,'S62647G'
,'S62647K'
,'S62647P'
,'S62647S'
,'S62648D'
,'S62648G'
,'S62648K'
,'S62648P'
,'S62648S'
,'S62649D'
,'S62649G'
,'S62649K'
,'S62649P'
,'S62649S'
,'S62650D'
,'S62650G'
,'S62650K'
,'S62650P'
,'S62650S'
,'S62651D'
,'S62651G'
,'S62651K'
,'S62651P'
,'S62651S'
,'S62652D'
,'S62652G'
,'S62652K'
,'S62652P'
,'S62652S'
,'S62653D'
,'S62653G'
,'S62653K'
,'S62653P'
,'S62653S'
,'S62654D'
,'S62654G'
,'S62654K'
,'S62654P'
,'S62654S'
,'S62655D'
,'S62655G'
,'S62655K'
,'S62655P'
,'S62655S'
,'S62656D'
,'S62656G'
,'S62656K'
,'S62656P'
,'S62656S'
,'S62657D'
,'S62657G'
,'S62657K'
,'S62657P'
,'S62657S'
,'S62658D'
,'S62658G'
,'S62658K'
,'S62658P'
,'S62658S'
,'S62659D'
,'S62659G'
,'S62659K'
,'S62659P'
,'S62659S'
,'S62660D'
,'S62660G'
,'S62660K'
,'S62660P'
,'S62660S'
,'S62661D'
,'S62661G'
,'S62661K'
,'S62661P'
,'S62661S'
,'S62662D'
,'S62662G'
,'S62662K'
,'S62662P'
,'S62662S'
,'S62663D'
,'S62663G'
,'S62663K'
,'S62663P'
,'S62663S'
,'S62664D'
,'S62664G'
,'S62664K'
,'S62664P'
,'S62664S'
,'S62665D'
,'S62665G'
,'S62665K'
,'S62665P'
,'S62665S'
,'S62666D'
,'S62666G'
,'S62666K'
,'S62666P'
,'S62666S'
,'S62667D'
,'S62667G'
,'S62667K'
,'S62667P'
,'S62667S'
,'S62668D'
,'S62668G'
,'S62668K'
,'S62668P'
,'S62668S'
,'S62669D'
,'S62669G'
,'S62669K'
,'S62669P'
,'S62669S'
,'S6290XD'
,'S6290XG'
,'S6290XK'
,'S6290XP'
,'S6290XS'
,'S6291XD'
,'S6291XG'
,'S6291XK'
,'S6291XP'
,'S6291XS'
,'S6292XD'
,'S6292XG'
,'S6292XK'
,'S6292XP'
,'S6292XS'
,'S63001D'
,'S63001S'
,'S63002D'
,'S63002S'
,'S63003D'
,'S63003S'
,'S63004D'
,'S63004S'
,'S63005D'
,'S63005S'
,'S63006D'
,'S63006S'
,'S63011D'
,'S63011S'
,'S63012D'
,'S63012S'
,'S63013D'
,'S63013S'
,'S63014D'
,'S63014S'
,'S63015D'
,'S63015S'
,'S63016D'
,'S63016S'
,'S63021D'
,'S63021S'
,'S63022D'
,'S63022S'
,'S63023D'
,'S63023S'
,'S63024D'
,'S63024S'
,'S63025D'
,'S63025S'
,'S63026D'
,'S63026S'
,'S63031D'
,'S63031S'
,'S63032D'
,'S63032S'
,'S63033D'
,'S63033S'
,'S63034D'
,'S63034S'
,'S63035D'
,'S63035S'
,'S63036D'
,'S63036S'
,'S63041D'
,'S63041S'
,'S63042D'
,'S63042S'
,'S63043D'
,'S63043S'
,'S63044D'
,'S63044S'
,'S63045D'
,'S63045S'
,'S63046D'
,'S63046S'
,'S63051D'
,'S63051S'
,'S63052D'
,'S63052S'
,'S63053D'
,'S63053S'
,'S63054D'
,'S63054S'
,'S63055D'
,'S63055S'
,'S63056D'
,'S63056S'
,'S63061D'
,'S63061S'
,'S63062D'
,'S63062S'
,'S63063D'
,'S63063S'
,'S63064D'
,'S63064S'
,'S63065D'
,'S63065S'
,'S63066D'
,'S63066S'
,'S63071D'
,'S63071S'
,'S63072D'
,'S63072S'
,'S63073D'
,'S63073S'
,'S63074D'
,'S63074S'
,'S63075D'
,'S63075S'
,'S63076D'
,'S63076S'
,'S63091D'
,'S63091S'
,'S63092D'
,'S63092S'
,'S63093D'
,'S63093S'
,'S63094D'
,'S63094S'
,'S63095D'
,'S63095S'
,'S63096D'
,'S63096S'
,'S63101D'
,'S63101S'
,'S63102D'
,'S63102S'
,'S63103D'
,'S63103S'
,'S63104D'
,'S63104S'
,'S63105D'
,'S63105S'
,'S63106D'
,'S63106S'
,'S63111D'
,'S63111S'
,'S63112D'
,'S63112S'
,'S63113D'
,'S63113S'
,'S63114D'
,'S63114S'
,'S63115D'
,'S63115S'
,'S63116D'
,'S63116S'
,'S63121D'
,'S63121S'
,'S63122D'
,'S63122S'
,'S63123D'
,'S63123S'
,'S63124D'
,'S63124S'
,'S63125D'
,'S63125S'
,'S63126D'
,'S63126S'
,'S63131D'
,'S63131S'
,'S63132D'
,'S63132S'
,'S63133D'
,'S63133S'
,'S63134D'
,'S63134S'
,'S63135D'
,'S63135S'
,'S63136D'
,'S63136S'
,'S63141D'
,'S63141S'
,'S63142D'
,'S63142S'
,'S63143D'
,'S63143S'
,'S63144D'
,'S63144S'
,'S63145D'
,'S63145S'
,'S63146D'
,'S63146S'
,'S63200D'
,'S63200S'
,'S63201D'
,'S63201S'
,'S63202D'
,'S63202S'
,'S63203D'
,'S63203S'
,'S63204D'
,'S63204S'
,'S63205D'
,'S63205S'
,'S63206D'
,'S63206S'
,'S63207D'
,'S63207S'
,'S63208D'
,'S63208S'
,'S63209D'
,'S63209S'
,'S63210D'
,'S63210S'
,'S63211D'
,'S63211S'
,'S63212D'
,'S63212S'
,'S63213D'
,'S63213S'
,'S63214D'
,'S63214S'
,'S63215D'
,'S63215S'
,'S63216D'
,'S63216S'
,'S63217D'
,'S63217S'
,'S63218D'
,'S63218S'
,'S63219D'
,'S63219S'
,'S63220D'
,'S63220S'
,'S63221D'
,'S63221S'
,'S63222D'
,'S63222S'
,'S63223D'
,'S63223S'
,'S63224D'
,'S63224S'
,'S63225D'
,'S63225S'
,'S63226D'
,'S63226S'
,'S63227D'
,'S63227S'
,'S63228D'
,'S63228S'
,'S63229D'
,'S63229S'
,'S63230D'
,'S63230S'
,'S63231D'
,'S63231S'
,'S63232D'
,'S63232S'
,'S63233D'
,'S63233S'
,'S63234D'
,'S63234S'
,'S63235D'
,'S63235S'
,'S63236D'
,'S63236S'
,'S63237D'
,'S63237S'
,'S63238D'
,'S63238S'
,'S63239D'
,'S63239S'
,'S63240D'
,'S63240S'
,'S63241D'
,'S63241S'
,'S63242D'
,'S63242S'
,'S63243D'
,'S63243S'
,'S63244D'
,'S63244S'
,'S63245D'
,'S63245S'
,'S63246D'
,'S63246S'
,'S63247D'
,'S63247S'
,'S63248D'
,'S63248S'
,'S63249D'
,'S63249S'
,'S63250D'
,'S63250S'
,'S63251D'
,'S63251S'
,'S63252D'
,'S63252S'
,'S63253D'
,'S63253S'
,'S63254D'
,'S63254S'
,'S63255D'
,'S63255S'
,'S63256D'
,'S63256S'
,'S63257D'
,'S63257S'
,'S63258D'
,'S63258S'
,'S63259D'
,'S63259S'
,'S63260D'
,'S63260S'
,'S63261D'
,'S63261S'
,'S63262D'
,'S63262S'
,'S63263D'
,'S63263S'
,'S63264D'
,'S63264S'
,'S63265D'
,'S63265S'
,'S63266D'
,'S63266S'
,'S63267D'
,'S63267S'
,'S63268D'
,'S63268S'
,'S63269D'
,'S63269S'
,'S63270D'
,'S63270S'
,'S63271D'
,'S63271S'
,'S63272D'
,'S63272S'
,'S63273D'
,'S63273S'
,'S63274D'
,'S63274S'
,'S63275D'
,'S63275S'
,'S63276D'
,'S63276S'
,'S63277D'
,'S63277S'
,'S63278D'
,'S63278S'
,'S63279D'
,'S63279S'
,'S63280D'
,'S63280S'
,'S63281D'
,'S63281S'
,'S63282D'
,'S63282S'
,'S63283D'
,'S63283S'
,'S63284D'
,'S63284S'
,'S63285D'
,'S63285S'
,'S63286D'
,'S63286S'
,'S63287D'
,'S63287S'
,'S63288D'
,'S63288S'
,'S63289D'
,'S63289S'
,'S63290D'
,'S63290S'
,'S63291D'
,'S63291S'
,'S63292D'
,'S63292S'
,'S63293D'
,'S63293S'
,'S63294D'
,'S63294S'
,'S63295D'
,'S63295S'
,'S63296D'
,'S63296S'
,'S63297D'
,'S63297S'
,'S63298D'
,'S63298S'
,'S63299D'
,'S63299S'
,'S63301D'
,'S63301S'
,'S63302D'
,'S63302S'
,'S63309D'
,'S63309S'
,'S63311D'
,'S63311S'
,'S63312D'
,'S63312S'
,'S63319D'
,'S63319S'
,'S63321D'
,'S63321S'
,'S63322D'
,'S63322S'
,'S63329D'
,'S63329S'
,'S63331D'
,'S63331S'
,'S63332D'
,'S63332S'
,'S63339D'
,'S63339S'
,'S63391D'
,'S63391S'
,'S63392D'
,'S63392S'
,'S63399D'
,'S63399S'
,'S63400D'
,'S63400S'
,'S63401D'
,'S63401S'
,'S63402D'
,'S63402S'
,'S63403D'
,'S63403S'
,'S63404D'
,'S63404S'
,'S63405D'
,'S63405S'
,'S63406D'
,'S63406S'
,'S63407D'
,'S63407S'
,'S63408D'
,'S63408S'
,'S63409D'
,'S63409S'
,'S63410D'
,'S63410S'
,'S63411D'
,'S63411S'
,'S63412D'
,'S63412S'
,'S63413D'
,'S63413S'
,'S63414D'
,'S63414S'
,'S63415D'
,'S63415S'
,'S63416D'
,'S63416S'
,'S63417D'
,'S63417S'
,'S63418D'
,'S63418S'
,'S63419D'
,'S63419S'
,'S63420D'
,'S63420S'
,'S63421D'
,'S63421S'
,'S63422D'
,'S63422S'
,'S63423D'
,'S63423S'
,'S63424D'
,'S63424S'
,'S63425D'
,'S63425S'
,'S63426D'
,'S63426S'
,'S63427D'
,'S63427S'
,'S63428D'
,'S63428S'
,'S63429D'
,'S63429S'
,'S63430D'
,'S63430S'
,'S63431D'
,'S63431S'
,'S63432D'
,'S63432S'
,'S63433D'
,'S63433S'
,'S63434D'
,'S63434S'
,'S63435D'
,'S63435S'
,'S63436D'
,'S63436S'
,'S63437D'
,'S63437S'
,'S63438D'
,'S63438S'
,'S63439D'
,'S63439S'
,'S63490D'
,'S63490S'
,'S63491D'
,'S63491S'
,'S63492D'
,'S63492S'
,'S63493D'
,'S63493S'
,'S63494D'
,'S63494S'
,'S63495D'
,'S63495S'
,'S63496D'
,'S63496S'
,'S63497D'
,'S63497S'
,'S63498D'
,'S63498S'
,'S63499D'
,'S63499S'
,'S63501D'
,'S63501S'
,'S63502D'
,'S63502S'
,'S63509D'
,'S63509S'
,'S63511D'
,'S63511S'
,'S63512D'
,'S63512S'
,'S63519D'
,'S63519S'
,'S63521D'
,'S63521S'
,'S63522D'
,'S63522S'
,'S63529D'
,'S63529S'
,'S63591D'
,'S63591S'
,'S63592D'
,'S63592S'
,'S63599D'
,'S63599S'
,'S63601D'
,'S63601S'
,'S63602D'
,'S63602S'
,'S63609D'
,'S63609S'
,'S63610D'
,'S63610S'
,'S63611D'
,'S63611S'
,'S63612D'
,'S63612S'
,'S63613D'
,'S63613S'
,'S63614D'
,'S63614S'
,'S63615D'
,'S63615S'
,'S63616D'
,'S63616S'
,'S63617D'
,'S63617S'
,'S63618D'
,'S63618S'
,'S63619D'
,'S63619S'
,'S63621D'
,'S63621S'
,'S63622D'
,'S63622S'
,'S63629D'
,'S63629S'
,'S63630D'
,'S63630S'
,'S63631D'
,'S63631S'
,'S63632D'
,'S63632S'
,'S63633D'
,'S63633S'
,'S63634D'
,'S63634S'
,'S63635D'
,'S63635S'
,'S63636D'
,'S63636S'
,'S63637D'
,'S63637S'
,'S63638D'
,'S63638S'
,'S63639D'
,'S63639S'
,'S63641D'
,'S63641S'
,'S63642D'
,'S63642S'
,'S63649D'
,'S63649S'
,'S63650D'
,'S63650S'
,'S63651D'
,'S63651S'
,'S63652D'
,'S63652S'
,'S63653D'
,'S63653S'
,'S63654D'
,'S63654S'
,'S63655D'
,'S63655S'
,'S63656D'
,'S63656S'
,'S63657D'
,'S63657S'
,'S63658D'
,'S63658S'
,'S63659D'
,'S63659S'
,'S63681D'
,'S63681S'
,'S63682D'
,'S63682S'
,'S63689D'
,'S63689S'
,'S63690D'
,'S63690S'
,'S63691D'
,'S63691S'
,'S63692D'
,'S63692S'
,'S63693D'
,'S63693S'
,'S63694D'
,'S63694S'
,'S63695D'
,'S63695S'
,'S63696D'
,'S63696S'
,'S63697D'
,'S63697S'
,'S63698D'
,'S63698S'
,'S63699D'
,'S63699S'
,'S638X1D'
,'S638X1S'
,'S638X2D'
,'S638X2S'
,'S638X9D'
,'S638X9S'
,'S6390XD'
,'S6390XS'
,'S6391XD'
,'S6391XS'
,'S6392XD'
,'S6392XS'
,'S6400XD'
,'S6400XS'
,'S6401XD'
,'S6401XS'
,'S6402XD'
,'S6402XS'
,'S6410XD'
,'S6410XS'
,'S6411XD'
,'S6411XS'
,'S6412XD'
,'S6412XS'
,'S6420XD'
,'S6420XS'
,'S6421XD'
,'S6421XS'
,'S6422XD'
,'S6422XS'
,'S6430XD'
,'S6430XS'
,'S6431XD'
,'S6431XS'
,'S6432XD'
,'S6432XS'
,'S6440XD'
,'S6440XS'
,'S64490D'
,'S64490S'
,'S64491D'
,'S64491S'
,'S64492D'
,'S64492S'
,'S64493D'
,'S64493S'
,'S64494D'
,'S64494S'
,'S64495D'
,'S64495S'
,'S64496D'
,'S64496S'
,'S64497D'
,'S64497S'
,'S64498D'
,'S64498S'
,'S648X1D'
,'S648X1S'
,'S648X2D'
,'S648X2S'
,'S648X9D'
,'S648X9S'
,'S6490XD'
,'S6490XS'
,'S6491XD'
,'S6491XS'
,'S6492XD'
,'S6492XS'
,'S65001D'
,'S65001S'
,'S65002D'
,'S65002S'
,'S65009D'
,'S65009S'
,'S65011D'
,'S65011S'
,'S65012D'
,'S65012S'
,'S65019D'
,'S65019S'
,'S65091D'
,'S65091S'
,'S65092D'
,'S65092S'
,'S65099D'
,'S65099S'
,'S65101D'
,'S65101S'
,'S65102D'
,'S65102S'
,'S65109D'
,'S65109S'
,'S65111D'
,'S65111S'
,'S65112D'
,'S65112S'
,'S65119D'
,'S65119S'
,'S65191D'
,'S65191S'
,'S65192D'
,'S65192S'
,'S65199D'
,'S65199S'
,'S65201D'
,'S65201S'
,'S65202D'
,'S65202S'
,'S65209D'
,'S65209S'
,'S65211D'
,'S65211S'
,'S65212D'
,'S65212S'
,'S65219D'
,'S65219S'
,'S65291D'
,'S65291S'
,'S65292D'
,'S65292S'
,'S65299D'
,'S65299S'
,'S65301D'
,'S65301S'
,'S65302D'
,'S65302S'
,'S65309D'
,'S65309S'
,'S65311D'
,'S65311S'
,'S65312D'
,'S65312S'
,'S65319D'
,'S65319S'
,'S65391D'
,'S65391S'
,'S65392D'
,'S65392S'
,'S65399D'
,'S65399S'
,'S65401D'
,'S65401S'
,'S65402D'
,'S65402S'
,'S65409D'
,'S65409S'
,'S65411D'
,'S65411S'
,'S65412D'
,'S65412S'
,'S65419D'
,'S65419S'
,'S65491D'
,'S65491S'
,'S65492D'
,'S65492S'
,'S65499D'
,'S65499S'
,'S65500D'
,'S65500S'
,'S65501D'
,'S65501S'
,'S65502D'
,'S65502S'
,'S65503D'
,'S65503S'
,'S65504D'
,'S65504S'
,'S65505D'
,'S65505S'
,'S65506D'
,'S65506S'
,'S65507D'
,'S65507S'
,'S65508D'
,'S65508S'
,'S65509D'
,'S65509S'
,'S65510D'
,'S65510S'
,'S65511D'
,'S65511S'
,'S65512D'
,'S65512S'
,'S65513D'
,'S65513S'
,'S65514D'
,'S65514S'
,'S65515D'
,'S65515S'
,'S65516D'
,'S65516S'
,'S65517D'
,'S65517S'
,'S65518D'
,'S65518S'
,'S65519D'
,'S65519S'
,'S65590D'
,'S65590S'
,'S65591D'
,'S65591S'
,'S65592D'
,'S65592S'
,'S65593D'
,'S65593S'
,'S65594D'
,'S65594S'
,'S65595D'
,'S65595S'
,'S65596D'
,'S65596S'
,'S65597D'
,'S65597S'
,'S65598D'
,'S65598S'
,'S65599D'
,'S65599S'
,'S65801D'
,'S65801S'
,'S65802D'
,'S65802S'
,'S65809D'
,'S65809S'
,'S65811D'
,'S65811S'
,'S65812D'
,'S65812S'
,'S65819D'
,'S65819S'
,'S65891D'
,'S65891S'
,'S65892D'
,'S65892S'
,'S65899D'
,'S65899S'
,'S65901D'
,'S65901S'
,'S65902D'
,'S65902S'
,'S65909D'
,'S65909S'
,'S65911D'
,'S65911S'
,'S65912D'
,'S65912S'
,'S65919D'
,'S65919S'
,'S65991D'
,'S65991S'
,'S65992D'
,'S65992S'
,'S65999D'
,'S65999S'
,'S66001D'
,'S66001S'
,'S66002D'
,'S66002S'
,'S66009D'
,'S66009S'
,'S66011D'
,'S66011S'
,'S66012D'
,'S66012S'
,'S66019D'
,'S66019S'
,'S66021D'
,'S66021S'
,'S66022D'
,'S66022S'
,'S66029D'
,'S66029S'
,'S66091D'
,'S66091S'
,'S66092D'
,'S66092S'
,'S66099D'
,'S66099S'
,'S66100D'
,'S66100S'
,'S66101D'
,'S66101S'
,'S66102D'
,'S66102S'
,'S66103D'
,'S66103S'
,'S66104D'
,'S66104S'
,'S66105D'
,'S66105S'
,'S66106D'
,'S66106S'
,'S66107D'
,'S66107S'
,'S66108D'
,'S66108S'
,'S66109D'
,'S66109S'
,'S66110D'
,'S66110S'
,'S66111D'
,'S66111S'
,'S66112D'
,'S66112S'
,'S66113D'
,'S66113S'
,'S66114D'
,'S66114S'
,'S66115D'
,'S66115S'
,'S66116D'
,'S66116S'
,'S66117D'
,'S66117S'
,'S66118D'
,'S66118S'
,'S66119D'
,'S66119S'
,'S66120D'
,'S66120S'
,'S66121D'
,'S66121S'
,'S66122D'
,'S66122S'
,'S66123D'
,'S66123S'
,'S66124D'
,'S66124S'
,'S66125D'
,'S66125S'
,'S66126D'
,'S66126S'
,'S66127D'
,'S66127S'
,'S66128D'
,'S66128S'
,'S66129D'
,'S66129S'
,'S66190D'
,'S66190S'
,'S66191D'
,'S66191S'
,'S66192D'
,'S66192S'
,'S66193D'
,'S66193S'
,'S66194D'
,'S66194S'
,'S66195D'
,'S66195S'
,'S66196D'
,'S66196S'
,'S66197D'
,'S66197S'
,'S66198D'
,'S66198S'
,'S66199D'
,'S66199S'
,'S66201D'
,'S66201S'
,'S66202D'
,'S66202S'
,'S66209D'
,'S66209S'
,'S66211D'
,'S66211S'
,'S66212D'
,'S66212S'
,'S66219D'
,'S66219S'
,'S66221D'
,'S66221S'
,'S66222D'
,'S66222S'
,'S66229D'
,'S66229S'
,'S66291D'
,'S66291S'
,'S66292D'
,'S66292S'
,'S66299D'
,'S66299S'
,'S66300D'
,'S66300S'
,'S66301D'
,'S66301S'
,'S66302D'
,'S66302S'
,'S66303D'
,'S66303S'
,'S66304D'
,'S66304S'
,'S66305D'
,'S66305S'
,'S66306D'
,'S66306S'
,'S66307D'
,'S66307S'
,'S66308D'
,'S66308S'
,'S66309D'
,'S66309S'
,'S66310D'
,'S66310S'
,'S66311D'
,'S66311S'
,'S66312D'
,'S66312S'
,'S66313D'
,'S66313S'
,'S66314D'
,'S66314S'
,'S66315D'
,'S66315S'
,'S66316D'
,'S66316S'
,'S66317D'
,'S66317S'
,'S66318D'
,'S66318S'
,'S66319D'
,'S66319S'
,'S66320D'
,'S66320S'
,'S66321D'
,'S66321S'
,'S66322D'
,'S66322S'
,'S66323D'
,'S66323S'
,'S66324D'
,'S66324S'
,'S66325D'
,'S66325S'
,'S66326D'
,'S66326S'
,'S66327D'
,'S66327S'
,'S66328D'
,'S66328S'
,'S66329D'
,'S66329S'
,'S66390D'
,'S66390S'
,'S66391D'
,'S66391S'
,'S66392D'
,'S66392S'
,'S66393D'
,'S66393S'
,'S66394D'
,'S66394S'
,'S66395D'
,'S66395S'
,'S66396D'
,'S66396S'
,'S66397D'
,'S66397S'
,'S66398D'
,'S66398S'
,'S66399D'
,'S66399S'
,'S66401D'
,'S66401S'
,'S66402D'
,'S66402S'
,'S66409D'
,'S66409S'
,'S66411D'
,'S66411S'
,'S66412D'
,'S66412S'
,'S66419D'
,'S66419S'
,'S66421D'
,'S66421S'
,'S66422D'
,'S66422S'
,'S66429D'
,'S66429S'
,'S66491D'
,'S66491S'
,'S66492D'
,'S66492S'
,'S66499D'
,'S66499S'
,'S66500D'
,'S66500S'
,'S66501D'
,'S66501S'
,'S66502D'
,'S66502S'
,'S66503D'
,'S66503S'
,'S66504D'
,'S66504S'
,'S66505D'
,'S66505S'
,'S66506D'
,'S66506S'
,'S66507D'
,'S66507S'
,'S66508D'
,'S66508S'
,'S66509D'
,'S66509S'
,'S66510D'
,'S66510S'
,'S66511D'
,'S66511S'
,'S66512D'
,'S66512S'
,'S66513D'
,'S66513S'
,'S66514D'
,'S66514S'
,'S66515D'
,'S66515S'
,'S66516D'
,'S66516S'
,'S66517D'
,'S66517S'
,'S66518D'
,'S66518S'
,'S66519D'
,'S66519S'
,'S66520D'
,'S66520S'
,'S66521D'
,'S66521S'
,'S66522D'
,'S66522S'
,'S66523D'
,'S66523S'
,'S66524D'
,'S66524S'
,'S66525D'
,'S66525S'
,'S66526D'
,'S66526S'
,'S66527D'
,'S66527S'
,'S66528D'
,'S66528S'
,'S66529D'
,'S66529S'
,'S66590D'
,'S66590S'
,'S66591D'
,'S66591S'
,'S66592D'
,'S66592S'
,'S66593D'
,'S66593S'
,'S66594D'
,'S66594S'
,'S66595D'
,'S66595S'
,'S66596D'
,'S66596S'
,'S66597D'
,'S66597S'
,'S66598D'
,'S66598S'
,'S66599D'
,'S66599S'
,'S66801D'
,'S66801S'
,'S66802D'
,'S66802S'
,'S66809D'
,'S66809S'
,'S66811D'
,'S66811S'
,'S66812D'
,'S66812S'
,'S66819D'
,'S66819S'
,'S66821D'
,'S66821S'
,'S66822D'
,'S66822S'
,'S66829D'
,'S66829S'
,'S66891D'
,'S66891S'
,'S66892D'
,'S66892S'
,'S66899D'
,'S66899S'
,'S66901D'
,'S66901S'
,'S66902D'
,'S66902S'
,'S66909D'
,'S66909S'
,'S66911D'
,'S66911S'
,'S66912D'
,'S66912S'
,'S66919D'
,'S66919S'
,'S66921D'
,'S66921S'
,'S66922D'
,'S66922S'
,'S66929D'
,'S66929S'
,'S66991D'
,'S66991S'
,'S66992D'
,'S66992S'
,'S66999D'
,'S66999S'
,'S6700XD'
,'S6700XS'
,'S6701XD'
,'S6701XS'
,'S6702XD'
,'S6702XS'
,'S6710XD'
,'S6710XS'
,'S67190D'
,'S67190S'
,'S67191D'
,'S67191S'
,'S67192D'
,'S67192S'
,'S67193D'
,'S67193S'
,'S67194D'
,'S67194S'
,'S67195D'
,'S67195S'
,'S67196D'
,'S67196S'
,'S67197D'
,'S67197S'
,'S67198D'
,'S67198S'
,'S6720XD'
,'S6720XS'
,'S6721XD'
,'S6721XS'
,'S6722XD'
,'S6722XS'
,'S6730XD'
,'S6730XS'
,'S6731XD'
,'S6731XS'
,'S6732XD'
,'S6732XS'
,'S6740XD'
,'S6740XS'
,'S6741XD'
,'S6741XS'
,'S6742XD'
,'S6742XS'
,'S6790XD'
,'S6790XS'
,'S6791XD'
,'S6791XS'
,'S6792XD'
,'S6792XS'
,'S68011D'
,'S68011S'
,'S68012D'
,'S68012S'
,'S68019D'
,'S68019S'
,'S68021D'
,'S68021S'
,'S68022D'
,'S68022S'
,'S68029D'
,'S68029S'
,'S68110D'
,'S68110S'
,'S68111D'
,'S68111S'
,'S68112D'
,'S68112S'
,'S68113D'
,'S68113S'
,'S68114D'
,'S68114S'
,'S68115D'
,'S68115S'
,'S68116D'
,'S68116S'
,'S68117D'
,'S68117S'
,'S68118D'
,'S68118S'
,'S68119D'
,'S68119S'
,'S68120D'
,'S68120S'
,'S68121D'
,'S68121S'
,'S68122D'
,'S68122S'
,'S68123D'
,'S68123S'
,'S68124D'
,'S68124S'
,'S68125D'
,'S68125S'
,'S68126D'
,'S68126S'
,'S68127D'
,'S68127S'
,'S68128D'
,'S68128S'
,'S68129D'
,'S68129S'
,'S68411D'
,'S68411S'
,'S68412D'
,'S68412S'
,'S68419D'
,'S68419S'
,'S68421D'
,'S68421S'
,'S68422D'
,'S68422S'
,'S68429D'
,'S68429S'
,'S68511D'
,'S68511S'
,'S68512D'
,'S68512S'
,'S68519D'
,'S68519S'
,'S68521D'
,'S68521S'
,'S68522D'
,'S68522S'
,'S68529D'
,'S68529S'
,'S68610D'
,'S68610S'
,'S68611D'
,'S68611S'
,'S68612D'
,'S68612S'
,'S68613D'
,'S68613S'
,'S68614D'
,'S68614S'
,'S68615D'
,'S68615S'
,'S68616D'
,'S68616S'
,'S68617D'
,'S68617S'
,'S68618D'
,'S68618S'
,'S68619D'
,'S68619S'
,'S68620D'
,'S68620S'
,'S68621D'
,'S68621S'
,'S68622D'
,'S68622S'
,'S68623D'
,'S68623S'
,'S68624D'
,'S68624S'
,'S68625D'
,'S68625S'
,'S68626D'
,'S68626S'
,'S68627D'
,'S68627S'
,'S68628D'
,'S68628S'
,'S68629D'
,'S68629S'
,'S68711D'
,'S68711S'
,'S68712D'
,'S68712S'
,'S68719D'
,'S68719S'
,'S68721D'
,'S68721S'
,'S68722D'
,'S68722S'
,'S68729D'
,'S68729S'
,'S6980XD'
,'S6980XS'
,'S6981XD'
,'S6981XS'
,'S6982XD'
,'S6982XS'
,'S6990XD'
,'S6990XS'
,'S6991XD'
,'S6991XS'
,'S6992XD'
,'S6992XS'
,'S7000XD'
,'S7000XS'
,'S7001XD'
,'S7001XS'
,'S7002XD'
,'S7002XS'
,'S7010XD'
,'S7010XS'
,'S7011XD'
,'S7011XS'
,'S7012XD'
,'S7012XS'
,'S70211D'
,'S70211S'
,'S70212D'
,'S70212S'
,'S70219D'
,'S70219S'
,'S70221D'
,'S70221S'
,'S70222D'
,'S70222S'
,'S70229D'
,'S70229S'
,'S70241D'
,'S70241S'
,'S70242D'
,'S70242S'
,'S70249D'
,'S70249S'
,'S70251D'
,'S70251S'
,'S70252D'
,'S70252S'
,'S70259D'
,'S70259S'
,'S70261D'
,'S70261S'
,'S70262D'
,'S70262S'
,'S70269D'
,'S70269S'
,'S70271D'
,'S70271S'
,'S70272D'
,'S70272S'
,'S70279D'
,'S70279S'
,'S70311D'
,'S70311S'
,'S70312D'
,'S70312S'
,'S70319D'
,'S70319S'
,'S70321D'
,'S70321S'
,'S70322D'
,'S70322S'
,'S70329D'
,'S70329S'
,'S70341D'
,'S70341S'
,'S70342D'
,'S70342S'
,'S70349D'
,'S70349S'
,'S70351D'
,'S70351S'
,'S70352D'
,'S70352S'
,'S70359D'
,'S70359S'
,'S70361D'
,'S70361S'
,'S70362D'
,'S70362S'
,'S70369D'
,'S70369S'
,'S70371D'
,'S70371S'
,'S70372D'
,'S70372S'
,'S70379D'
,'S70379S'
,'S70911D'
,'S70911S'
,'S70912D'
,'S70912S'
,'S70919D'
,'S70919S'
,'S70921D'
,'S70921S'
,'S70922D'
,'S70922S'
,'S70929D'
,'S70929S'
,'S71001D'
,'S71001S'
,'S71002D'
,'S71002S'
,'S71009D'
,'S71009S'
,'S71011D'
,'S71011S'
,'S71012D'
,'S71012S'
,'S71019D'
,'S71019S'
,'S71021D'
,'S71021S'
,'S71022D'
,'S71022S'
,'S71029D'
,'S71029S'
,'S71031D'
,'S71031S'
,'S71032D'
,'S71032S'
,'S71039D'
,'S71039S'
,'S71041D'
,'S71041S'
,'S71042D'
,'S71042S'
,'S71049D'
,'S71049S'
,'S71051D'
,'S71051S'
,'S71052D'
,'S71052S'
,'S71059D'
,'S71059S'
,'S71101D'
,'S71101S'
,'S71102D'
,'S71102S'
,'S71109D'
,'S71109S'
,'S71111D'
,'S71111S'
,'S71112D'
,'S71112S'
,'S71119D'
,'S71119S'
,'S71121D'
,'S71121S'
,'S71122D'
,'S71122S'
,'S71129D'
,'S71129S'
,'S71131D'
,'S71131S'
,'S71132D'
,'S71132S'
,'S71139D'
,'S71139S'
,'S71141D'
,'S71141S'
,'S71142D'
,'S71142S'
,'S71149D'
,'S71149S'
,'S71151D'
,'S71151S'
,'S71152D'
,'S71152S'
,'S71159D'
,'S71159S'
,'S72001C'
,'S72001D'
,'S72001E'
,'S72001F'
,'S72001G'
,'S72001H'
,'S72001J'
,'S72001K'
,'S72001M'
,'S72001N'
,'S72001P'
,'S72001Q'
,'S72001R'
,'S72001S'
,'S72002C'
,'S72002D'
,'S72002E'
,'S72002F'
,'S72002G'
,'S72002H'
,'S72002J'
,'S72002K'
,'S72002M'
,'S72002N'
,'S72002P'
,'S72002Q'
,'S72002R'
,'S72002S'
,'S72009C'
,'S72009D'
,'S72009E'
,'S72009F'
,'S72009G'
,'S72009H'
,'S72009J'
,'S72009K'
,'S72009M'
,'S72009N'
,'S72009P'
,'S72009Q'
,'S72009R'
,'S72009S'
,'S72011C'
,'S72011D'
,'S72011E'
,'S72011F'
,'S72011G'
,'S72011H'
,'S72011J'
,'S72011K'
,'S72011M'
,'S72011N'
,'S72011P'
,'S72011Q'
,'S72011R'
,'S72011S'
,'S72012C'
,'S72012D'
,'S72012E'
,'S72012F'
,'S72012G'
,'S72012H'
,'S72012J'
,'S72012K'
,'S72012M'
,'S72012N'
,'S72012P'
,'S72012Q'
,'S72012R'
,'S72012S'
,'S72019C'
,'S72019D'
,'S72019E'
,'S72019F'
,'S72019G'
,'S72019H'
,'S72019J'
,'S72019K'
,'S72019M'
,'S72019N'
,'S72019P'
,'S72019Q'
,'S72019R'
,'S72019S'
,'S72021C'
,'S72021D'
,'S72021E'
,'S72021F'
,'S72021G'
,'S72021H'
,'S72021J'
,'S72021K'
,'S72021M'
,'S72021N'
,'S72021P'
,'S72021Q'
,'S72021R'
,'S72021S'
,'S72022C'
,'S72022D'
,'S72022E'
,'S72022F'
,'S72022G'
,'S72022H'
,'S72022J'
,'S72022K'
,'S72022M'
,'S72022N'
,'S72022P'
,'S72022Q'
,'S72022R'
,'S72022S'
,'S72023C'
,'S72023D'
,'S72023E'
,'S72023F'
,'S72023G'
,'S72023H'
,'S72023J'
,'S72023K'
,'S72023M'
,'S72023N'
,'S72023P'
,'S72023Q'
,'S72023R'
,'S72023S'
,'S72024C'
,'S72024D'
,'S72024E'
,'S72024F'
,'S72024G'
,'S72024H'
,'S72024J'
,'S72024K'
,'S72024M'
,'S72024N'
,'S72024P'
,'S72024Q'
,'S72024R'
,'S72024S'
,'S72025C'
,'S72025D'
,'S72025E'
,'S72025F'
,'S72025G'
,'S72025H'
,'S72025J'
,'S72025K'
,'S72025M'
,'S72025N'
,'S72025P'
,'S72025Q'
,'S72025R'
,'S72025S'
,'S72026C'
,'S72026D'
,'S72026E'
,'S72026F'
,'S72026G'
,'S72026H'
,'S72026J'
,'S72026K'
,'S72026M'
,'S72026N'
,'S72026P'
,'S72026Q'
,'S72026R'
,'S72026S'
,'S72031C'
,'S72031D'
,'S72031E'
,'S72031F'
,'S72031G'
,'S72031H'
,'S72031J'
,'S72031K'
,'S72031M'
,'S72031N'
,'S72031P'
,'S72031Q'
,'S72031R'
,'S72031S'
,'S72032C'
,'S72032D'
,'S72032E'
,'S72032F'
,'S72032G'
,'S72032H'
,'S72032J'
,'S72032K'
,'S72032M'
,'S72032N'
,'S72032P'
,'S72032Q'
,'S72032R'
,'S72032S'
,'S72033C'
,'S72033D'
,'S72033E'
,'S72033F'
,'S72033G'
,'S72033H'
,'S72033J'
,'S72033K'
,'S72033M'
,'S72033N'
,'S72033P'
,'S72033Q'
,'S72033R'
,'S72033S'
,'S72034C'
,'S72034D'
,'S72034E'
,'S72034F'
,'S72034G'
,'S72034H'
,'S72034J'
,'S72034K'
,'S72034M'
,'S72034N'
,'S72034P'
,'S72034Q'
,'S72034R'
,'S72034S'
,'S72035C'
,'S72035D'
,'S72035E'
,'S72035F'
,'S72035G'
,'S72035H'
,'S72035J'
,'S72035K'
,'S72035M'
,'S72035N'
,'S72035P'
,'S72035Q'
,'S72035R'
,'S72035S'
,'S72036C'
,'S72036D'
,'S72036E'
,'S72036F'
,'S72036G'
,'S72036H'
,'S72036J'
,'S72036K'
,'S72036M'
,'S72036N'
,'S72036P'
,'S72036Q'
,'S72036R'
,'S72036S'
,'S72041C'
,'S72041D'
,'S72041E'
,'S72041F'
,'S72041G'
,'S72041H'
,'S72041J'
,'S72041K'
,'S72041M'
,'S72041N'
,'S72041P'
,'S72041Q'
,'S72041R'
,'S72041S'
,'S72042C'
,'S72042D'
,'S72042E'
,'S72042F'
,'S72042G'
,'S72042H'
,'S72042J'
,'S72042K'
,'S72042M'
,'S72042N'
,'S72042P'
,'S72042Q'
,'S72042R'
,'S72042S'
,'S72043C'
,'S72043D'
,'S72043E'
,'S72043F'
,'S72043G'
,'S72043H'
,'S72043J'
,'S72043K'
,'S72043M'
,'S72043N'
,'S72043P'
,'S72043Q'
,'S72043R'
,'S72043S'
,'S72044C'
,'S72044D'
,'S72044E'
,'S72044F'
,'S72044G'
,'S72044H'
,'S72044J'
,'S72044K'
,'S72044M'
,'S72044N'
,'S72044P'
,'S72044Q'
,'S72044R'
,'S72044S'
,'S72045C'
,'S72045D'
,'S72045E'
,'S72045F'
,'S72045G'
,'S72045H'
,'S72045J'
,'S72045K'
,'S72045M'
,'S72045N'
,'S72045P'
,'S72045Q'
,'S72045R'
,'S72045S'
,'S72046C'
,'S72046D'
,'S72046E'
,'S72046F'
,'S72046G'
,'S72046H'
,'S72046J'
,'S72046K'
,'S72046M'
,'S72046N'
,'S72046P'
,'S72046Q'
,'S72046R'
,'S72046S'
,'S72051C'
,'S72051D'
,'S72051E'
,'S72051F'
,'S72051G'
,'S72051H'
,'S72051J'
,'S72051K'
,'S72051M'
,'S72051N'
,'S72051P'
,'S72051Q'
,'S72051R'
,'S72051S'
,'S72052C'
,'S72052D'
,'S72052E'
,'S72052F'
,'S72052G'
,'S72052H'
,'S72052J'
,'S72052K'
,'S72052M'
,'S72052N'
,'S72052P'
,'S72052Q'
,'S72052R'
,'S72052S'
,'S72059C'
,'S72059D'
,'S72059E'
,'S72059F'
,'S72059G'
,'S72059H'
,'S72059J'
,'S72059K'
,'S72059M'
,'S72059N'
,'S72059P'
,'S72059Q'
,'S72059R'
,'S72059S'
,'S72061C'
,'S72061D'
,'S72061E'
,'S72061F'
,'S72061G'
,'S72061H'
,'S72061J'
,'S72061K'
,'S72061M'
,'S72061N'
,'S72061P'
,'S72061Q'
,'S72061R'
,'S72061S'
,'S72062C'
,'S72062D'
,'S72062E'
,'S72062F'
,'S72062G'
,'S72062H'
,'S72062J'
,'S72062K'
,'S72062M'
,'S72062N'
,'S72062P'
,'S72062Q'
,'S72062R'
,'S72062S'
,'S72063C'
,'S72063D'
,'S72063E'
,'S72063F'
,'S72063G'
,'S72063H'
,'S72063J'
,'S72063K'
,'S72063M'
,'S72063N'
,'S72063P'
,'S72063Q'
,'S72063R'
,'S72063S'
,'S72064C'
,'S72064D'
,'S72064E'
,'S72064F'
,'S72064G'
,'S72064H'
,'S72064J'
,'S72064K'
,'S72064M'
,'S72064N'
,'S72064P'
,'S72064Q'
,'S72064R'
,'S72064S'
,'S72065C'
,'S72065D'
,'S72065E'
,'S72065F'
,'S72065G'
,'S72065H'
,'S72065J'
,'S72065K'
,'S72065M'
,'S72065N'
,'S72065P'
,'S72065Q'
,'S72065R'
,'S72065S'
,'S72066C'
,'S72066D'
,'S72066E'
,'S72066F'
,'S72066G'
,'S72066H'
,'S72066J'
,'S72066K'
,'S72066M'
,'S72066N'
,'S72066P'
,'S72066Q'
,'S72066R'
,'S72066S'
,'S72091C'
,'S72091D'
,'S72091E'
,'S72091F'
,'S72091G'
,'S72091H'
,'S72091J'
,'S72091K'
,'S72091M'
,'S72091N'
,'S72091P'
,'S72091Q'
,'S72091R'
,'S72091S'
,'S72092C'
,'S72092D'
,'S72092E'
,'S72092F'
,'S72092G'
,'S72092H'
,'S72092J'
,'S72092K'
,'S72092M'
,'S72092N'
,'S72092P'
,'S72092Q'
,'S72092R'
,'S72092S'
,'S72099C'
,'S72099D'
,'S72099E'
,'S72099F'
,'S72099G'
,'S72099H'
,'S72099J'
,'S72099K'
,'S72099M'
,'S72099N'
,'S72099P'
,'S72099Q'
,'S72099R'
,'S72099S'
,'S72101C'
,'S72101D'
,'S72101E'
,'S72101F'
,'S72101G'
,'S72101H'
,'S72101J'
,'S72101K'
,'S72101M'
,'S72101N'
,'S72101P'
,'S72101Q'
,'S72101R'
,'S72101S'
,'S72102C'
,'S72102D'
,'S72102E'
,'S72102F'
,'S72102G'
,'S72102H'
,'S72102J'
,'S72102K'
,'S72102M'
,'S72102N'
,'S72102P'
,'S72102Q'
,'S72102R'
,'S72102S'
,'S72109C'
,'S72109D'
,'S72109E'
,'S72109F'
,'S72109G'
,'S72109H'
,'S72109J'
,'S72109K'
,'S72109M'
,'S72109N'
,'S72109P'
,'S72109Q'
,'S72109R'
,'S72109S'
,'S72111C'
,'S72111D'
,'S72111E'
,'S72111F'
,'S72111G'
,'S72111H'
,'S72111J'
,'S72111K'
,'S72111M'
,'S72111N'
,'S72111P'
,'S72111Q'
,'S72111R'
,'S72111S'
,'S72112C'
,'S72112D'
,'S72112E'
,'S72112F'
,'S72112G'
,'S72112H'
,'S72112J'
,'S72112K'
,'S72112M'
,'S72112N'
,'S72112P'
,'S72112Q'
,'S72112R'
,'S72112S'
,'S72113C'
,'S72113D'
,'S72113E'
,'S72113F'
,'S72113G'
,'S72113H'
,'S72113J'
,'S72113K'
,'S72113M'
,'S72113N'
,'S72113P'
,'S72113Q'
,'S72113R'
,'S72113S'
,'S72114C'
,'S72114D'
,'S72114E'
,'S72114F'
,'S72114G'
,'S72114H'
,'S72114J'
,'S72114K'
,'S72114M'
,'S72114N'
,'S72114P'
,'S72114Q'
,'S72114R'
,'S72114S'
,'S72115C'
,'S72115D'
,'S72115E'
,'S72115F'
,'S72115G'
,'S72115H'
,'S72115J'
,'S72115K'
,'S72115M'
,'S72115N'
,'S72115P'
,'S72115Q'
,'S72115R'
,'S72115S'
,'S72116C'
,'S72116D'
,'S72116E'
,'S72116F'
,'S72116G'
,'S72116H'
,'S72116J'
,'S72116K'
,'S72116M'
,'S72116N'
,'S72116P'
,'S72116Q'
,'S72116R'
,'S72116S'
,'S72121C'
,'S72121D'
,'S72121E'
,'S72121F'
,'S72121G'
,'S72121H'
,'S72121J'
,'S72121K'
,'S72121M'
,'S72121N'
,'S72121P'
,'S72121Q'
,'S72121R'
,'S72121S'
,'S72122C'
,'S72122D'
,'S72122E'
,'S72122F'
,'S72122G'
,'S72122H'
,'S72122J'
,'S72122K'
,'S72122M'
,'S72122N'
,'S72122P'
,'S72122Q'
,'S72122R'
,'S72122S'
,'S72123C'
,'S72123D'
,'S72123E'
,'S72123F'
,'S72123G'
,'S72123H'
,'S72123J'
,'S72123K'
,'S72123M'
,'S72123N'
,'S72123P'
,'S72123Q'
,'S72123R'
,'S72123S'
,'S72124C'
,'S72124D'
,'S72124E'
,'S72124F'
,'S72124G'
,'S72124H'
,'S72124J'
,'S72124K'
,'S72124M'
,'S72124N'
,'S72124P'
,'S72124Q'
,'S72124R'
,'S72124S'
,'S72125C'
,'S72125D'
,'S72125E'
,'S72125F'
,'S72125G'
,'S72125H'
,'S72125J'
,'S72125K'
,'S72125M'
,'S72125N'
,'S72125P'
,'S72125Q'
,'S72125R'
,'S72125S'
,'S72126C'
,'S72126D'
,'S72126E'
,'S72126F'
,'S72126G'
,'S72126H'
,'S72126J'
,'S72126K'
,'S72126M'
,'S72126N'
,'S72126P'
,'S72126Q'
,'S72126R'
,'S72126S'
,'S72131C'
,'S72131D'
,'S72131E'
,'S72131F'
,'S72131G'
,'S72131H'
,'S72131J'
,'S72131K'
,'S72131M'
,'S72131N'
,'S72131P'
,'S72131Q'
,'S72131R'
,'S72131S'
,'S72132C'
,'S72132D'
,'S72132E'
,'S72132F'
,'S72132G'
,'S72132H'
,'S72132J'
,'S72132K'
,'S72132M'
,'S72132N'
,'S72132P'
,'S72132Q'
,'S72132R'
,'S72132S'
,'S72133C'
,'S72133D'
,'S72133E'
,'S72133F'
,'S72133G'
,'S72133H'
,'S72133J'
,'S72133K'
,'S72133M'
,'S72133N'
,'S72133P'
,'S72133Q'
,'S72133R'
,'S72133S'
,'S72134C'
,'S72134D'
,'S72134E'
,'S72134F'
,'S72134G'
,'S72134H'
,'S72134J'
,'S72134K'
,'S72134M'
,'S72134N'
,'S72134P'
,'S72134Q'
,'S72134R'
,'S72134S'
,'S72135C'
,'S72135D'
,'S72135E'
,'S72135F'
,'S72135G'
,'S72135H'
,'S72135J'
,'S72135K'
,'S72135M'
,'S72135N'
,'S72135P'
,'S72135Q'
,'S72135R'
,'S72135S'
,'S72136C'
,'S72136D'
,'S72136E'
,'S72136F'
,'S72136G'
,'S72136H'
,'S72136J'
,'S72136K'
,'S72136M'
,'S72136N'
,'S72136P'
,'S72136Q'
,'S72136R'
,'S72136S'
,'S72141C'
,'S72141D'
,'S72141E'
,'S72141F'
,'S72141G'
,'S72141H'
,'S72141J'
,'S72141K'
,'S72141M'
,'S72141N'
,'S72141P'
,'S72141Q'
,'S72141R'
,'S72141S'
,'S72142C'
,'S72142D'
,'S72142E'
,'S72142F'
,'S72142G'
,'S72142H'
,'S72142J'
,'S72142K'
,'S72142M'
,'S72142N'
,'S72142P'
,'S72142Q'
,'S72142R'
,'S72142S'
,'S72143C'
,'S72143D'
,'S72143E'
,'S72143F'
,'S72143G'
,'S72143H'
,'S72143J'
,'S72143K'
,'S72143M'
,'S72143N'
,'S72143P'
,'S72143Q'
,'S72143R'
,'S72143S'
,'S72144C'
,'S72144D'
,'S72144E'
,'S72144F'
,'S72144G'
,'S72144H'
,'S72144J'
,'S72144K'
,'S72144M'
,'S72144N'
,'S72144P'
,'S72144Q'
,'S72144R'
,'S72144S'
,'S72145C'
,'S72145D'
,'S72145E'
,'S72145F'
,'S72145G'
,'S72145H'
,'S72145J'
,'S72145K'
,'S72145M'
,'S72145N'
,'S72145P'
,'S72145Q'
,'S72145R'
,'S72145S'
,'S72146C'
,'S72146D'
,'S72146E'
,'S72146F'
,'S72146G'
,'S72146H'
,'S72146J'
,'S72146K'
,'S72146M'
,'S72146N'
,'S72146P'
,'S72146Q'
,'S72146R'
,'S72146S'
,'S7221XC'
,'S7221XD'
,'S7221XE'
,'S7221XF'
,'S7221XG'
,'S7221XH'
,'S7221XJ'
,'S7221XK'
,'S7221XM'
,'S7221XN'
,'S7221XP'
,'S7221XQ'
,'S7221XR'
,'S7221XS'
,'S7222XC'
,'S7222XD'
,'S7222XE'
,'S7222XF'
,'S7222XG'
,'S7222XH'
,'S7222XJ'
,'S7222XK'
,'S7222XM'
,'S7222XN'
,'S7222XP'
,'S7222XQ'
,'S7222XR'
,'S7222XS'
,'S7223XC'
,'S7223XD'
,'S7223XE'
,'S7223XF'
,'S7223XG'
,'S7223XH'
,'S7223XJ'
,'S7223XK'
,'S7223XM'
,'S7223XN'
,'S7223XP'
,'S7223XQ'
,'S7223XR'
,'S7223XS'
,'S7224XC'
,'S7224XD'
,'S7224XE'
,'S7224XF'
,'S7224XG'
,'S7224XH'
,'S7224XJ'
,'S7224XK'
,'S7224XM'
,'S7224XN'
,'S7224XP'
,'S7224XQ'
,'S7224XR'
,'S7224XS'
,'S7225XC'
,'S7225XD'
,'S7225XE'
,'S7225XF'
,'S7225XG'
,'S7225XH'
,'S7225XJ'
,'S7225XK'
,'S7225XM'
,'S7225XN'
,'S7225XP'
,'S7225XQ'
,'S7225XR'
,'S7225XS'
,'S7226XC'
,'S7226XD'
,'S7226XE'
,'S7226XF'
,'S7226XG'
,'S7226XH'
,'S7226XJ'
,'S7226XK'
,'S7226XM'
,'S7226XN'
,'S7226XP'
,'S7226XQ'
,'S7226XR'
,'S7226XS'
,'S72301C'
,'S72301D'
,'S72301E'
,'S72301F'
,'S72301G'
,'S72301H'
,'S72301J'
,'S72301K'
,'S72301M'
,'S72301N'
,'S72301P'
,'S72301Q'
,'S72301R'
,'S72301S'
,'S72302C'
,'S72302D'
,'S72302E'
,'S72302F'
,'S72302G'
,'S72302H'
,'S72302J'
,'S72302K'
,'S72302M'
,'S72302N'
,'S72302P'
,'S72302Q'
,'S72302R'
,'S72302S'
,'S72309C'
,'S72309D'
,'S72309E'
,'S72309F'
,'S72309G'
,'S72309H'
,'S72309J'
,'S72309K'
,'S72309M'
,'S72309N'
,'S72309P'
,'S72309Q'
,'S72309R'
,'S72309S'
,'S72321C'
,'S72321D'
,'S72321E'
,'S72321F'
,'S72321G'
,'S72321H'
,'S72321J'
,'S72321K'
,'S72321M'
,'S72321N'
,'S72321P'
,'S72321Q'
,'S72321R'
,'S72321S'
,'S72322C'
,'S72322D'
,'S72322E'
,'S72322F'
,'S72322G'
,'S72322H'
,'S72322J'
,'S72322K'
,'S72322M'
,'S72322N'
,'S72322P'
,'S72322Q'
,'S72322R'
,'S72322S'
,'S72323C'
,'S72323D'
,'S72323E'
,'S72323F'
,'S72323G'
,'S72323H'
,'S72323J'
,'S72323K'
,'S72323M'
,'S72323N'
,'S72323P'
,'S72323Q'
,'S72323R'
,'S72323S'
,'S72324C'
,'S72324D'
,'S72324E'
,'S72324F'
,'S72324G'
,'S72324H'
,'S72324J'
,'S72324K'
,'S72324M'
,'S72324N'
,'S72324P'
,'S72324Q'
,'S72324R'
,'S72324S'
,'S72325C'
,'S72325D'
,'S72325E'
,'S72325F'
,'S72325G'
,'S72325H'
,'S72325J'
,'S72325K'
,'S72325M'
,'S72325N'
,'S72325P'
,'S72325Q'
,'S72325R'
,'S72325S'
,'S72326C'
,'S72326D'
,'S72326E'
,'S72326F'
,'S72326G'
,'S72326H'
,'S72326J'
,'S72326K'
,'S72326M'
,'S72326N'
,'S72326P'
,'S72326Q'
,'S72326R'
,'S72326S'
,'S72331C'
,'S72331D'
,'S72331E'
,'S72331F'
,'S72331G'
,'S72331H'
,'S72331J'
,'S72331K'
,'S72331M'
,'S72331N'
,'S72331P'
,'S72331Q'
,'S72331R'
,'S72331S'
,'S72332C'
,'S72332D'
,'S72332E'
,'S72332F'
,'S72332G'
,'S72332H'
,'S72332J'
,'S72332K'
,'S72332M'
,'S72332N'
,'S72332P'
,'S72332Q'
,'S72332R'
,'S72332S'
,'S72333C'
,'S72333D'
,'S72333E'
,'S72333F'
,'S72333G'
,'S72333H'
,'S72333J'
,'S72333K'
,'S72333M'
,'S72333N'
,'S72333P'
,'S72333Q'
,'S72333R'
,'S72333S'
,'S72334C'
,'S72334D'
,'S72334E'
,'S72334F'
,'S72334G'
,'S72334H'
,'S72334J'
,'S72334K'
,'S72334M'
,'S72334N'
,'S72334P'
,'S72334Q'
,'S72334R'
,'S72334S'
,'S72335C'
,'S72335D'
,'S72335E'
,'S72335F'
,'S72335G'
,'S72335H'
,'S72335J'
,'S72335K'
,'S72335M'
,'S72335N'
,'S72335P'
,'S72335Q'
,'S72335R'
,'S72335S'
,'S72336C'
,'S72336D'
,'S72336E'
,'S72336F'
,'S72336G'
,'S72336H'
,'S72336J'
,'S72336K'
,'S72336M'
,'S72336N'
,'S72336P'
,'S72336Q'
,'S72336R'
,'S72336S'
,'S72341C'
,'S72341D'
,'S72341E'
,'S72341F'
,'S72341G'
,'S72341H'
,'S72341J'
,'S72341K'
,'S72341M'
,'S72341N'
,'S72341P'
,'S72341Q'
,'S72341R'
,'S72341S'
,'S72342C'
,'S72342D'
,'S72342E'
,'S72342F'
,'S72342G'
,'S72342H'
,'S72342J'
,'S72342K'
,'S72342M'
,'S72342N'
,'S72342P'
,'S72342Q'
,'S72342R'
,'S72342S'
,'S72343C'
,'S72343D'
,'S72343E'
,'S72343F'
,'S72343G'
,'S72343H'
,'S72343J'
,'S72343K'
,'S72343M'
,'S72343N'
,'S72343P'
,'S72343Q'
,'S72343R'
,'S72343S'
,'S72344C'
,'S72344D'
,'S72344E'
,'S72344F'
,'S72344G'
,'S72344H'
,'S72344J'
,'S72344K'
,'S72344M'
,'S72344N'
,'S72344P'
,'S72344Q'
,'S72344R'
,'S72344S'
,'S72345C'
,'S72345D'
,'S72345E'
,'S72345F'
,'S72345G'
,'S72345H'
,'S72345J'
,'S72345K'
,'S72345M'
,'S72345N'
,'S72345P'
,'S72345Q'
,'S72345R'
,'S72345S'
,'S72346C'
,'S72346D'
,'S72346E'
,'S72346F'
,'S72346G'
,'S72346H'
,'S72346J'
,'S72346K'
,'S72346M'
,'S72346N'
,'S72346P'
,'S72346Q'
,'S72346R'
,'S72346S'
,'S72351C'
,'S72351D'
,'S72351E'
,'S72351F'
,'S72351G'
,'S72351H'
,'S72351J'
,'S72351K'
,'S72351M'
,'S72351N'
,'S72351P'
,'S72351Q'
,'S72351R'
,'S72351S'
,'S72352C'
,'S72352D'
,'S72352E'
,'S72352F'
,'S72352G'
,'S72352H'
,'S72352J'
,'S72352K'
,'S72352M'
,'S72352N'
,'S72352P'
,'S72352Q'
,'S72352R'
,'S72352S'
,'S72353C'
,'S72353D'
,'S72353E'
,'S72353F'
,'S72353G'
,'S72353H'
,'S72353J'
,'S72353K'
,'S72353M'
,'S72353N'
,'S72353P'
,'S72353Q'
,'S72353R'
,'S72353S'
,'S72354C'
,'S72354D'
,'S72354E'
,'S72354F'
,'S72354G'
,'S72354H'
,'S72354J'
,'S72354K'
,'S72354M'
,'S72354N'
,'S72354P'
,'S72354Q'
,'S72354R'
,'S72354S'
,'S72355C'
,'S72355D'
,'S72355E'
,'S72355F'
,'S72355G'
,'S72355H'
,'S72355J'
,'S72355K'
,'S72355M'
,'S72355N'
,'S72355P'
,'S72355Q'
,'S72355R'
,'S72355S'
,'S72356C'
,'S72356D'
,'S72356E'
,'S72356F'
,'S72356G'
,'S72356H'
,'S72356J'
,'S72356K'
,'S72356M'
,'S72356N'
,'S72356P'
,'S72356Q'
,'S72356R'
,'S72356S'
,'S72361C'
,'S72361D'
,'S72361E'
,'S72361F'
,'S72361G'
,'S72361H'
,'S72361J'
,'S72361K'
,'S72361M'
,'S72361N'
,'S72361P'
,'S72361Q'
,'S72361R'
,'S72361S'
,'S72362C'
,'S72362D'
,'S72362E'
,'S72362F'
,'S72362G'
,'S72362H'
,'S72362J'
,'S72362K'
,'S72362M'
,'S72362N'
,'S72362P'
,'S72362Q'
,'S72362R'
,'S72362S'
,'S72363C'
,'S72363D'
,'S72363E'
,'S72363F'
,'S72363G'
,'S72363H'
,'S72363J'
,'S72363K'
,'S72363M'
,'S72363N'
,'S72363P'
,'S72363Q'
,'S72363R'
,'S72363S'
,'S72364C'
,'S72364D'
,'S72364E'
,'S72364F'
,'S72364G'
,'S72364H'
,'S72364J'
,'S72364K'
,'S72364M'
,'S72364N'
,'S72364P'
,'S72364Q'
,'S72364R'
,'S72364S'
,'S72365C'
,'S72365D'
,'S72365E'
,'S72365F'
,'S72365G'
,'S72365H'
,'S72365J'
,'S72365K'
,'S72365M'
,'S72365N'
,'S72365P'
,'S72365Q'
,'S72365R'
,'S72365S'
,'S72366C'
,'S72366D'
,'S72366E'
,'S72366F'
,'S72366G'
,'S72366H'
,'S72366J'
,'S72366K'
,'S72366M'
,'S72366N'
,'S72366P'
,'S72366Q'
,'S72366R'
,'S72366S'
,'S72391C'
,'S72391D'
,'S72391E'
,'S72391F'
,'S72391G'
,'S72391H'
,'S72391J'
,'S72391K'
,'S72391M'
,'S72391N'
,'S72391P'
,'S72391Q'
,'S72391R'
,'S72391S'
,'S72392C'
,'S72392D'
,'S72392E'
,'S72392F'
,'S72392G'
,'S72392H'
,'S72392J'
,'S72392K'
,'S72392M'
,'S72392N'
,'S72392P'
,'S72392Q'
,'S72392R'
,'S72392S'
,'S72399C'
,'S72399D'
,'S72399E'
,'S72399F'
,'S72399G'
,'S72399H'
,'S72399J'
,'S72399K'
,'S72399M'
,'S72399N'
,'S72399P'
,'S72399Q'
,'S72399R'
,'S72399S'
,'S72401C'
,'S72401D'
,'S72401E'
,'S72401F'
,'S72401G'
,'S72401H'
,'S72401J'
,'S72401K'
,'S72401M'
,'S72401N'
,'S72401P'
,'S72401Q'
,'S72401R'
,'S72401S'
,'S72402C'
,'S72402D'
,'S72402E'
,'S72402F'
,'S72402G'
,'S72402H'
,'S72402J'
,'S72402K'
,'S72402M'
,'S72402N'
,'S72402P'
,'S72402Q'
,'S72402R'
,'S72402S'
,'S72409C'
,'S72409D'
,'S72409E'
,'S72409F'
,'S72409G'
,'S72409H'
,'S72409J'
,'S72409K'
,'S72409M'
,'S72409N'
,'S72409P'
,'S72409Q'
,'S72409R'
,'S72409S'
,'S72411C'
,'S72411D'
,'S72411E'
,'S72411F'
,'S72411G'
,'S72411H'
,'S72411J'
,'S72411K'
,'S72411M'
,'S72411N'
,'S72411P'
,'S72411Q'
,'S72411R'
,'S72411S'
,'S72412C'
,'S72412D'
,'S72412E'
,'S72412F'
,'S72412G'
,'S72412H'
,'S72412J'
,'S72412K'
,'S72412M'
,'S72412N'
,'S72412P'
,'S72412Q'
,'S72412R'
,'S72412S'
,'S72413C'
,'S72413D'
,'S72413E'
,'S72413F'
,'S72413G'
,'S72413H'
,'S72413J'
,'S72413K'
,'S72413M'
,'S72413N'
,'S72413P'
,'S72413Q'
,'S72413R'
,'S72413S'
,'S72414C'
,'S72414D'
,'S72414E'
,'S72414F'
,'S72414G'
,'S72414H'
,'S72414J'
,'S72414K'
,'S72414M'
,'S72414N'
,'S72414P'
,'S72414Q'
,'S72414R'
,'S72414S'
,'S72415C'
,'S72415D'
,'S72415E'
,'S72415F'
,'S72415G'
,'S72415H'
,'S72415J'
,'S72415K'
,'S72415M'
,'S72415N'
,'S72415P'
,'S72415Q'
,'S72415R'
,'S72415S'
,'S72416C'
,'S72416D'
,'S72416E'
,'S72416F'
,'S72416G'
,'S72416H'
,'S72416J'
,'S72416K'
,'S72416M'
,'S72416N'
,'S72416P'
,'S72416Q'
,'S72416R'
,'S72416S'
,'S72421C'
,'S72421D'
,'S72421E'
,'S72421F'
,'S72421G'
,'S72421H'
,'S72421J'
,'S72421K'
,'S72421M'
,'S72421N'
,'S72421P'
,'S72421Q'
,'S72421R'
,'S72421S'
,'S72422C'
,'S72422D'
,'S72422E'
,'S72422F'
,'S72422G'
,'S72422H'
,'S72422J'
,'S72422K'
,'S72422M'
,'S72422N'
,'S72422P'
,'S72422Q'
,'S72422R'
,'S72422S'
,'S72423C'
,'S72423D'
,'S72423E'
,'S72423F'
,'S72423G'
,'S72423H'
,'S72423J'
,'S72423K'
,'S72423M'
,'S72423N'
,'S72423P'
,'S72423Q'
,'S72423R'
,'S72423S'
,'S72424C'
,'S72424D'
,'S72424E'
,'S72424F'
,'S72424G'
,'S72424H'
,'S72424J'
,'S72424K'
,'S72424M'
,'S72424N'
,'S72424P'
,'S72424Q'
,'S72424R'
,'S72424S'
,'S72425C'
,'S72425D'
,'S72425E'
,'S72425F'
,'S72425G'
,'S72425H'
,'S72425J'
,'S72425K'
,'S72425M'
,'S72425N'
,'S72425P'
,'S72425Q'
,'S72425R'
,'S72425S'
,'S72426C'
,'S72426D'
,'S72426E'
,'S72426F'
,'S72426G'
,'S72426H'
,'S72426J'
,'S72426K'
,'S72426M'
,'S72426N'
,'S72426P'
,'S72426Q'
,'S72426R'
,'S72426S'
,'S72431C'
,'S72431D'
,'S72431E'
,'S72431F'
,'S72431G'
,'S72431H'
,'S72431J'
,'S72431K'
,'S72431M'
,'S72431N'
,'S72431P'
,'S72431Q'
,'S72431R'
,'S72431S'
,'S72432C'
,'S72432D'
,'S72432E'
,'S72432F'
,'S72432G'
,'S72432H'
,'S72432J'
,'S72432K'
,'S72432M'
,'S72432N'
,'S72432P'
,'S72432Q'
,'S72432R'
,'S72432S'
,'S72433C'
,'S72433D'
,'S72433E'
,'S72433F'
,'S72433G'
,'S72433H'
,'S72433J'
,'S72433K'
,'S72433M'
,'S72433N'
,'S72433P'
,'S72433Q'
,'S72433R'
,'S72433S'
,'S72434C'
,'S72434D'
,'S72434E'
,'S72434F'
,'S72434G'
,'S72434H'
,'S72434J'
,'S72434K'
,'S72434M'
,'S72434N'
,'S72434P'
,'S72434Q'
,'S72434R'
,'S72434S'
,'S72435C'
,'S72435D'
,'S72435E'
,'S72435F'
,'S72435G'
,'S72435H'
,'S72435J'
,'S72435K'
,'S72435M'
,'S72435N'
,'S72435P'
,'S72435Q'
,'S72435R'
,'S72435S'
,'S72436C'
,'S72436D'
,'S72436E'
,'S72436F'
,'S72436G'
,'S72436H'
,'S72436J'
,'S72436K'
,'S72436M'
,'S72436N'
,'S72436P'
,'S72436Q'
,'S72436R'
,'S72436S'
,'S72441C'
,'S72441D'
,'S72441E'
,'S72441F'
,'S72441G'
,'S72441H'
,'S72441J'
,'S72441K'
,'S72441M'
,'S72441N'
,'S72441P'
,'S72441Q'
,'S72441R'
,'S72441S'
,'S72442C'
,'S72442D'
,'S72442E'
,'S72442F'
,'S72442G'
,'S72442H'
,'S72442J'
,'S72442K'
,'S72442M'
,'S72442N'
,'S72442P'
,'S72442Q'
,'S72442R'
,'S72442S'
,'S72443C'
,'S72443D'
,'S72443E'
,'S72443F'
,'S72443G'
,'S72443H'
,'S72443J'
,'S72443K'
,'S72443M'
,'S72443N'
,'S72443P'
,'S72443Q'
,'S72443R'
,'S72443S'
,'S72444C'
,'S72444D'
,'S72444E'
,'S72444F'
,'S72444G'
,'S72444H'
,'S72444J'
,'S72444K'
,'S72444M'
,'S72444N'
,'S72444P'
,'S72444Q'
,'S72444R'
,'S72444S'
,'S72445C'
,'S72445D'
,'S72445E'
,'S72445F'
,'S72445G'
,'S72445H'
,'S72445J'
,'S72445K'
,'S72445M'
,'S72445N'
,'S72445P'
,'S72445Q'
,'S72445R'
,'S72445S'
,'S72446C'
,'S72446D'
,'S72446E'
,'S72446F'
,'S72446G'
,'S72446H'
,'S72446J'
,'S72446K'
,'S72446M'
,'S72446N'
,'S72446P'
,'S72446Q'
,'S72446R'
,'S72446S'
,'S72451C'
,'S72451D'
,'S72451E'
,'S72451F'
,'S72451G'
,'S72451H'
,'S72451J'
,'S72451K'
,'S72451M'
,'S72451N'
,'S72451P'
,'S72451Q'
,'S72451R'
,'S72451S'
,'S72452C'
,'S72452D'
,'S72452E'
,'S72452F'
,'S72452G'
,'S72452H'
,'S72452J'
,'S72452K'
,'S72452M'
,'S72452N'
,'S72452P'
,'S72452Q'
,'S72452R'
,'S72452S'
,'S72453C'
,'S72453D'
,'S72453E'
,'S72453F'
,'S72453G'
,'S72453H'
,'S72453J'
,'S72453K'
,'S72453M'
,'S72453N'
,'S72453P'
,'S72453Q'
,'S72453R'
,'S72453S'
,'S72454C'
,'S72454D'
,'S72454E'
,'S72454F'
,'S72454G'
,'S72454H'
,'S72454J'
,'S72454K'
,'S72454M'
,'S72454N'
,'S72454P'
,'S72454Q'
,'S72454R'
,'S72454S'
,'S72455C'
,'S72455D'
,'S72455E'
,'S72455F'
,'S72455G'
,'S72455H'
,'S72455J'
,'S72455K'
,'S72455M'
,'S72455N'
,'S72455P'
,'S72455Q'
,'S72455R'
,'S72455S'
,'S72456C'
,'S72456D'
,'S72456E'
,'S72456F'
,'S72456G'
,'S72456H'
,'S72456J'
,'S72456K'
,'S72456M'
,'S72456N'
,'S72456P'
,'S72456Q'
,'S72456R'
,'S72456S'
,'S72461C'
,'S72461D'
,'S72461E'
,'S72461F'
,'S72461G'
,'S72461H'
,'S72461J'
,'S72461K'
,'S72461M'
,'S72461N'
,'S72461P'
,'S72461Q'
,'S72461R'
,'S72461S'
,'S72462C'
,'S72462D'
,'S72462E'
,'S72462F'
,'S72462G'
,'S72462H'
,'S72462J'
,'S72462K'
,'S72462M'
,'S72462N'
,'S72462P'
,'S72462Q'
,'S72462R'
,'S72462S'
,'S72463C'
,'S72463D'
,'S72463E'
,'S72463F'
,'S72463G'
,'S72463H'
,'S72463J'
,'S72463K'
,'S72463M'
,'S72463N'
,'S72463P'
,'S72463Q'
,'S72463R'
,'S72463S'
,'S72464C'
,'S72464D'
,'S72464E'
,'S72464F'
,'S72464G'
,'S72464H'
,'S72464J'
,'S72464K'
,'S72464M'
,'S72464N'
,'S72464P'
,'S72464Q'
,'S72464R'
,'S72464S'
,'S72465C'
,'S72465D'
,'S72465E'
,'S72465F'
,'S72465G'
,'S72465H'
,'S72465J'
,'S72465K'
,'S72465M'
,'S72465N'
,'S72465P'
,'S72465Q'
,'S72465R'
,'S72465S'
,'S72466C'
,'S72466D'
,'S72466E'
,'S72466F'
,'S72466G'
,'S72466H'
,'S72466J'
,'S72466K'
,'S72466M'
,'S72466N'
,'S72466P'
,'S72466Q'
,'S72466R'
,'S72466S'
,'S72471D'
,'S72471G'
,'S72471K'
,'S72471P'
,'S72471S'
,'S72472D'
,'S72472G'
,'S72472K'
,'S72472P'
,'S72472S'
,'S72479D'
,'S72479G'
,'S72479K'
,'S72479P'
,'S72479S'
,'S72491C'
,'S72491D'
,'S72491E'
,'S72491F'
,'S72491G'
,'S72491H'
,'S72491J'
,'S72491K'
,'S72491M'
,'S72491N'
,'S72491P'
,'S72491Q'
,'S72491R'
,'S72491S'
,'S72492C'
,'S72492D'
,'S72492E'
,'S72492F'
,'S72492G'
,'S72492H'
,'S72492J'
,'S72492K'
,'S72492M'
,'S72492N'
,'S72492P'
,'S72492Q'
,'S72492R'
,'S72492S'
,'S72499C'
,'S72499D'
,'S72499E'
,'S72499F'
,'S72499G'
,'S72499H'
,'S72499J'
,'S72499K'
,'S72499M'
,'S72499N'
,'S72499P'
,'S72499Q'
,'S72499R'
,'S72499S'
,'S728X1C'
,'S728X1D'
,'S728X1E'
,'S728X1F'
,'S728X1G'
,'S728X1H'
,'S728X1J'
,'S728X1K'
,'S728X1M'
,'S728X1N'
,'S728X1P'
,'S728X1Q'
,'S728X1R'
,'S728X1S'
,'S728X2C'
,'S728X2D'
,'S728X2E'
,'S728X2F'
,'S728X2G'
,'S728X2H'
,'S728X2J'
,'S728X2K'
,'S728X2M'
,'S728X2N'
,'S728X2P'
,'S728X2Q'
,'S728X2R'
,'S728X2S'
,'S728X9C'
,'S728X9D'
,'S728X9E'
,'S728X9F'
,'S728X9G'
,'S728X9H'
,'S728X9J'
,'S728X9K'
,'S728X9M'
,'S728X9N'
,'S728X9P'
,'S728X9Q'
,'S728X9R'
,'S728X9S'
,'S7290XC'
,'S7290XD'
,'S7290XE'
,'S7290XF'
,'S7290XG'
,'S7290XH'
,'S7290XJ'
,'S7290XK'
,'S7290XM'
,'S7290XN'
,'S7290XP'
,'S7290XQ'
,'S7290XR'
,'S7290XS'
,'S7291XC'
,'S7291XD'
,'S7291XE'
,'S7291XF'
,'S7291XG'
,'S7291XH'
,'S7291XJ'
,'S7291XK'
,'S7291XM'
,'S7291XN'
,'S7291XP'
,'S7291XQ'
,'S7291XR'
,'S7291XS'
,'S7292XC'
,'S7292XD'
,'S7292XE'
,'S7292XF'
,'S7292XG'
,'S7292XH'
,'S7292XJ'
,'S7292XK'
,'S7292XM'
,'S7292XN'
,'S7292XP'
,'S7292XQ'
,'S7292XR'
,'S7292XS'
,'S73001D'
,'S73001S'
,'S73002D'
,'S73002S'
,'S73003D'
,'S73003S'
,'S73004D'
,'S73004S'
,'S73005D'
,'S73005S'
,'S73006D'
,'S73006S'
,'S73011D'
,'S73011S'
,'S73012D'
,'S73012S'
,'S73013D'
,'S73013S'
,'S73014D'
,'S73014S'
,'S73015D'
,'S73015S'
,'S73016D'
,'S73016S'
,'S73021D'
,'S73021S'
,'S73022D'
,'S73022S'
,'S73023D'
,'S73023S'
,'S73024D'
,'S73024S'
,'S73025D'
,'S73025S'
,'S73026D'
,'S73026S'
,'S73031D'
,'S73031S'
,'S73032D'
,'S73032S'
,'S73033D'
,'S73033S'
,'S73034D'
,'S73034S'
,'S73035D'
,'S73035S'
,'S73036D'
,'S73036S'
,'S73041D'
,'S73041S'
,'S73042D'
,'S73042S'
,'S73043D'
,'S73043S'
,'S73044D'
,'S73044S'
,'S73045D'
,'S73045S'
,'S73046D'
,'S73046S'
,'S73101D'
,'S73101S'
,'S73102D'
,'S73102S'
,'S73109D'
,'S73109S'
,'S73111D'
,'S73111S'
,'S73112D'
,'S73112S'
,'S73119D'
,'S73119S'
,'S73121D'
,'S73121S'
,'S73122D'
,'S73122S'
,'S73129D'
,'S73129S'
,'S73191D'
,'S73191S'
,'S73192D'
,'S73192S'
,'S73199D'
,'S73199S'
,'S7400XD'
,'S7400XS'
,'S7401XD'
,'S7401XS'
,'S7402XD'
,'S7402XS'
,'S7410XD'
,'S7410XS'
,'S7411XD'
,'S7411XS'
,'S7412XD'
,'S7412XS'
,'S7420XD'
,'S7420XS'
,'S7421XD'
,'S7421XS'
,'S7422XD'
,'S7422XS'
,'S748X1D'
,'S748X1S'
,'S748X2D'
,'S748X2S'
,'S748X9D'
,'S748X9S'
,'S7490XD'
,'S7490XS'
,'S7491XD'
,'S7491XS'
,'S7492XD'
,'S7492XS'
,'S75001D'
,'S75001S'
,'S75002D'
,'S75002S'
,'S75009D'
,'S75009S'
,'S75011D'
,'S75011S'
,'S75012D'
,'S75012S'
,'S75019D'
,'S75019S'
,'S75021D'
,'S75021S'
,'S75022D'
,'S75022S'
,'S75029D'
,'S75029S'
,'S75091D'
,'S75091S'
,'S75092D'
,'S75092S'
,'S75099D'
,'S75099S'
,'S75101D'
,'S75101S'
,'S75102D'
,'S75102S'
,'S75109D'
,'S75109S'
,'S75111D'
,'S75111S'
,'S75112D'
,'S75112S'
,'S75119D'
,'S75119S'
,'S75121D'
,'S75121S'
,'S75122D'
,'S75122S'
,'S75129D'
,'S75129S'
,'S75191D'
,'S75191S'
,'S75192D'
,'S75192S'
,'S75199D'
,'S75199S'
,'S75201D'
,'S75201S'
,'S75202D'
,'S75202S'
,'S75209D'
,'S75209S'
,'S75211D'
,'S75211S'
,'S75212D'
,'S75212S'
,'S75219D'
,'S75219S'
,'S75221D'
,'S75221S'
,'S75222D'
,'S75222S'
,'S75229D'
,'S75229S'
,'S75291D'
,'S75291S'
,'S75292D'
,'S75292S'
,'S75299D'
,'S75299S'
,'S75801D'
,'S75801S'
,'S75802D'
,'S75802S'
,'S75809D'
,'S75809S'
,'S75811D'
,'S75811S'
,'S75812D'
,'S75812S'
,'S75819D'
,'S75819S'
,'S75891D'
,'S75891S'
,'S75892D'
,'S75892S'
,'S75899D'
,'S75899S'
,'S75901D'
,'S75901S'
,'S75902D'
,'S75902S'
,'S75909D'
,'S75909S'
,'S75911D'
,'S75911S'
,'S75912D'
,'S75912S'
,'S75919D'
,'S75919S'
,'S75991D'
,'S75991S'
,'S75992D'
,'S75992S'
,'S75999D'
,'S75999S'
,'S76001D'
,'S76001S'
,'S76002D'
,'S76002S'
,'S76009D'
,'S76009S'
,'S76011D'
,'S76011S'
,'S76012D'
,'S76012S'
,'S76019D'
,'S76019S'
,'S76021D'
,'S76021S'
,'S76022D'
,'S76022S'
,'S76029D'
,'S76029S'
,'S76091D'
,'S76091S'
,'S76092D'
,'S76092S'
,'S76099D'
,'S76099S'
,'S76101D'
,'S76101S'
,'S76102D'
,'S76102S'
,'S76109D'
,'S76109S'
,'S76111D'
,'S76111S'
,'S76112D'
,'S76112S'
,'S76119D'
,'S76119S'
,'S76121D'
,'S76121S'
,'S76122D'
,'S76122S'
,'S76129D'
,'S76129S'
,'S76191D'
,'S76191S'
,'S76192D'
,'S76192S'
,'S76199D'
,'S76199S'
,'S76201D'
,'S76201S'
,'S76202D'
,'S76202S'
,'S76209D'
,'S76209S'
,'S76211D'
,'S76211S'
,'S76212D'
,'S76212S'
,'S76219D'
,'S76219S'
,'S76221D'
,'S76221S'
,'S76222D'
,'S76222S'
,'S76229D'
,'S76229S'
,'S76291D'
,'S76291S'
,'S76292D'
,'S76292S'
,'S76299D'
,'S76299S'
,'S76301D'
,'S76301S'
,'S76302D'
,'S76302S'
,'S76309D'
,'S76309S'
,'S76311D'
,'S76311S'
,'S76312D'
,'S76312S'
,'S76319D'
,'S76319S'
,'S76321D'
,'S76321S'
,'S76322D'
,'S76322S'
,'S76329D'
,'S76329S'
,'S76391D'
,'S76391S'
,'S76392D'
,'S76392S'
,'S76399D'
,'S76399S'
,'S76801D'
,'S76801S'
,'S76802D'
,'S76802S'
,'S76809D'
,'S76809S'
,'S76811D'
,'S76811S'
,'S76812D'
,'S76812S'
,'S76819D'
,'S76819S'
,'S76821D'
,'S76821S'
,'S76822D'
,'S76822S'
,'S76829D'
,'S76829S'
,'S76891D'
,'S76891S'
,'S76892D'
,'S76892S'
,'S76899D'
,'S76899S'
,'S76901D'
,'S76901S'
,'S76902D'
,'S76902S'
,'S76909D'
,'S76909S'
,'S76911D'
,'S76911S'
,'S76912D'
,'S76912S'
,'S76919D'
,'S76919S'
,'S76921D'
,'S76921S'
,'S76922D'
,'S76922S'
,'S76929D'
,'S76929S'
,'S76991D'
,'S76991S'
,'S76992D'
,'S76992S'
,'S76999D'
,'S76999S'
,'S7700XD'
,'S7700XS'
,'S7701XD'
,'S7701XS'
,'S7702XD'
,'S7702XS'
,'S7710XD'
,'S7710XS'
,'S7711XD'
,'S7711XS'
,'S7712XD'
,'S7712XS'
,'S7720XD'
,'S7720XS'
,'S7721XD'
,'S7721XS'
,'S7722XD'
,'S7722XS'
,'S78011D'
,'S78011S'
,'S78012D'
,'S78012S'
,'S78019D'
,'S78019S'
,'S78021D'
,'S78021S'
,'S78022D'
,'S78022S'
,'S78029D'
,'S78029S'
,'S78111D'
,'S78111S'
,'S78112D'
,'S78112S'
,'S78119D'
,'S78119S'
,'S78121D'
,'S78121S'
,'S78122D'
,'S78122S'
,'S78129D'
,'S78129S'
,'S78911D'
,'S78911S'
,'S78912D'
,'S78912S'
,'S78919D'
,'S78919S'
,'S78921D'
,'S78921S'
,'S78922D'
,'S78922S'
,'S78929D'
,'S78929S'
,'S79001D'
,'S79001G'
,'S79001K'
,'S79001P'
,'S79001S'
,'S79002D'
,'S79002G'
,'S79002K'
,'S79002P'
,'S79002S'
,'S79009D'
,'S79009G'
,'S79009K'
,'S79009P'
,'S79009S'
,'S79011D'
,'S79011G'
,'S79011K'
,'S79011P'
,'S79011S'
,'S79012D'
,'S79012G'
,'S79012K'
,'S79012P'
,'S79012S'
,'S79019D'
,'S79019G'
,'S79019K'
,'S79019P'
,'S79019S'
,'S79091D'
,'S79091G'
,'S79091K'
,'S79091P'
,'S79091S'
,'S79092D'
,'S79092G'
,'S79092K'
,'S79092P'
,'S79092S'
,'S79099D'
,'S79099G'
,'S79099K'
,'S79099P'
,'S79099S'
,'S79101D'
,'S79101G'
,'S79101K'
,'S79101P'
,'S79101S'
,'S79102D'
,'S79102G'
,'S79102K'
,'S79102P'
,'S79102S'
,'S79109D'
,'S79109G'
,'S79109K'
,'S79109P'
,'S79109S'
,'S79111D'
,'S79111G'
,'S79111K'
,'S79111P'
,'S79111S'
,'S79112D'
,'S79112G'
,'S79112K'
,'S79112P'
,'S79112S'
,'S79119D'
,'S79119G'
,'S79119K'
,'S79119P'
,'S79119S'
,'S79121D'
,'S79121G'
,'S79121K'
,'S79121P'
,'S79121S'
,'S79122D'
,'S79122G'
,'S79122K'
,'S79122P'
,'S79122S'
,'S79129D'
,'S79129G'
,'S79129K'
,'S79129P'
,'S79129S'
,'S79131D'
,'S79131G'
,'S79131K'
,'S79131P'
,'S79131S'
,'S79132D'
,'S79132G'
,'S79132K'
,'S79132P'
,'S79132S'
,'S79139D'
,'S79139G'
,'S79139K'
,'S79139P'
,'S79139S'
,'S79141D'
,'S79141G'
,'S79141K'
,'S79141P'
,'S79141S'
,'S79142D'
,'S79142G'
,'S79142K'
,'S79142P'
,'S79142S'
,'S79149D'
,'S79149G'
,'S79149K'
,'S79149P'
,'S79149S'
,'S79191D'
,'S79191G'
,'S79191K'
,'S79191P'
,'S79191S'
,'S79192D'
,'S79192G'
,'S79192K'
,'S79192P'
,'S79192S'
,'S79199D'
,'S79199G'
,'S79199K'
,'S79199P'
,'S79199S'
,'S79811D'
,'S79811S'
,'S79812D'
,'S79812S'
,'S79819D'
,'S79819S'
,'S79821D'
,'S79821S'
,'S79822D'
,'S79822S'
,'S79829D'
,'S79829S'
,'S79911D'
,'S79911S'
,'S79912D'
,'S79912S'
,'S79919D'
,'S79919S'
,'S79921D'
,'S79921S'
,'S79922D'
,'S79922S'
,'S79929D'
,'S79929S'
,'S8000XD'
,'S8000XS'
,'S8001XD'
,'S8001XS'
,'S8002XD'
,'S8002XS'
,'S8010XD'
,'S8010XS'
,'S8011XD'
,'S8011XS'
,'S8012XD'
,'S8012XS'
,'S80211D'
,'S80211S'
,'S80212D'
,'S80212S'
,'S80219D'
,'S80219S'
,'S80221D'
,'S80221S'
,'S80222D'
,'S80222S'
,'S80229D'
,'S80229S'
,'S80241D'
,'S80241S'
,'S80242D'
,'S80242S'
,'S80249D'
,'S80249S'
,'S80251D'
,'S80251S'
,'S80252D'
,'S80252S'
,'S80259D'
,'S80259S'
,'S80261D'
,'S80261S'
,'S80262D'
,'S80262S'
,'S80269D'
,'S80269S'
,'S80271D'
,'S80271S'
,'S80272D'
,'S80272S'
,'S80279D'
,'S80279S'
,'S80811D'
,'S80811S'
,'S80812D'
,'S80812S'
,'S80819D'
,'S80819S'
,'S80821D'
,'S80821S'
,'S80822D'
,'S80822S'
,'S80829D'
,'S80829S'
,'S80841D'
,'S80841S'
,'S80842D'
,'S80842S'
,'S80849D'
,'S80849S'
,'S80851D'
,'S80851S'
,'S80852D'
,'S80852S'
,'S80859D'
,'S80859S'
,'S80861D'
,'S80861S'
,'S80862D'
,'S80862S'
,'S80869D'
,'S80869S'
,'S80871D'
,'S80871S'
,'S80872D'
,'S80872S'
,'S80879D'
,'S80879S'
,'S80911D'
,'S80911S'
,'S80912D'
,'S80912S'
,'S80919D'
,'S80919S'
,'S80921D'
,'S80921S'
,'S80922D'
,'S80922S'
,'S80929D'
,'S80929S'
,'S81001D'
,'S81001S'
,'S81002D'
,'S81002S'
,'S81009D'
,'S81009S'
,'S81011D'
,'S81011S'
,'S81012D'
,'S81012S'
,'S81019D'
,'S81019S'
,'S81021D'
,'S81021S'
,'S81022D'
,'S81022S'
,'S81029D'
,'S81029S'
,'S81031D'
,'S81031S'
,'S81032D'
,'S81032S'
,'S81039D'
,'S81039S'
,'S81041D'
,'S81041S'
,'S81042D'
,'S81042S'
,'S81049D'
,'S81049S'
,'S81051D'
,'S81051S'
,'S81052D'
,'S81052S'
,'S81059D'
,'S81059S'
,'S81801D'
,'S81801S'
,'S81802D'
,'S81802S'
,'S81809D'
,'S81809S'
,'S81811D'
,'S81811S'
,'S81812D'
,'S81812S'
,'S81819D'
,'S81819S'
,'S81821D'
,'S81821S'
,'S81822D'
,'S81822S'
,'S81829D'
,'S81829S'
,'S81831D'
,'S81831S'
,'S81832D'
,'S81832S'
,'S81839D'
,'S81839S'
,'S81841D'
,'S81841S'
,'S81842D'
,'S81842S'
,'S81849D'
,'S81849S'
,'S81851D'
,'S81851S'
,'S81852D'
,'S81852S'
,'S81859D'
,'S81859S'
,'S82001C'
,'S82001D'
,'S82001E'
,'S82001F'
,'S82001G'
,'S82001H'
,'S82001J'
,'S82001K'
,'S82001M'
,'S82001N'
,'S82001P'
,'S82001Q'
,'S82001R'
,'S82001S'
,'S82002C'
,'S82002D'
,'S82002E'
,'S82002F'
,'S82002G'
,'S82002H'
,'S82002J'
,'S82002K'
,'S82002M'
,'S82002N'
,'S82002P'
,'S82002Q'
,'S82002R'
,'S82002S'
,'S82009C'
,'S82009D'
,'S82009E'
,'S82009F'
,'S82009G'
,'S82009H'
,'S82009J'
,'S82009K'
,'S82009M'
,'S82009N'
,'S82009P'
,'S82009Q'
,'S82009R'
,'S82009S'
,'S82011C'
,'S82011D'
,'S82011E'
,'S82011F'
,'S82011G'
,'S82011H'
,'S82011J'
,'S82011K'
,'S82011M'
,'S82011N'
,'S82011P'
,'S82011Q'
,'S82011R'
,'S82011S'
,'S82012C'
,'S82012D'
,'S82012E'
,'S82012F'
,'S82012G'
,'S82012H'
,'S82012J'
,'S82012K'
,'S82012M'
,'S82012N'
,'S82012P'
,'S82012Q'
,'S82012R'
,'S82012S'
,'S82013C'
,'S82013D'
,'S82013E'
,'S82013F'
,'S82013G'
,'S82013H'
,'S82013J'
,'S82013K'
,'S82013M'
,'S82013N'
,'S82013P'
,'S82013Q'
,'S82013R'
,'S82013S'
,'S82014C'
,'S82014D'
,'S82014E'
,'S82014F'
,'S82014G'
,'S82014H'
,'S82014J'
,'S82014K'
,'S82014M'
,'S82014N'
,'S82014P'
,'S82014Q'
,'S82014R'
,'S82014S'
,'S82015C'
,'S82015D'
,'S82015E'
,'S82015F'
,'S82015G'
,'S82015H'
,'S82015J'
,'S82015K'
,'S82015M'
,'S82015N'
,'S82015P'
,'S82015Q'
,'S82015R'
,'S82015S'
,'S82016C'
,'S82016D'
,'S82016E'
,'S82016F'
,'S82016G'
,'S82016H'
,'S82016J'
,'S82016K'
,'S82016M'
,'S82016N'
,'S82016P'
,'S82016Q'
,'S82016R'
,'S82016S'
,'S82021C'
,'S82021D'
,'S82021E'
,'S82021F'
,'S82021G'
,'S82021H'
,'S82021J'
,'S82021K'
,'S82021M'
,'S82021N'
,'S82021P'
,'S82021Q'
,'S82021R'
,'S82021S'
,'S82022C'
,'S82022D'
,'S82022E'
,'S82022F'
,'S82022G'
,'S82022H'
,'S82022J'
,'S82022K'
,'S82022M'
,'S82022N'
,'S82022P'
,'S82022Q'
,'S82022R'
,'S82022S'
,'S82023C'
,'S82023D'
,'S82023E'
,'S82023F'
,'S82023G'
,'S82023H'
,'S82023J'
,'S82023K'
,'S82023M'
,'S82023N'
,'S82023P'
,'S82023Q'
,'S82023R'
,'S82023S'
,'S82024C'
,'S82024D'
,'S82024E'
,'S82024F'
,'S82024G'
,'S82024H'
,'S82024J'
,'S82024K'
,'S82024M'
,'S82024N'
,'S82024P'
,'S82024Q'
,'S82024R'
,'S82024S'
,'S82025C'
,'S82025D'
,'S82025E'
,'S82025F'
,'S82025G'
,'S82025H'
,'S82025J'
,'S82025K'
,'S82025M'
,'S82025N'
,'S82025P'
,'S82025Q'
,'S82025R'
,'S82025S'
,'S82026C'
,'S82026D'
,'S82026E'
,'S82026F'
,'S82026G'
,'S82026H'
,'S82026J'
,'S82026K'
,'S82026M'
,'S82026N'
,'S82026P'
,'S82026Q'
,'S82026R'
,'S82026S'
,'S82031C'
,'S82031D'
,'S82031E'
,'S82031F'
,'S82031G'
,'S82031H'
,'S82031J'
,'S82031K'
,'S82031M'
,'S82031N'
,'S82031P'
,'S82031Q'
,'S82031R'
,'S82031S'
,'S82032C'
,'S82032D'
,'S82032E'
,'S82032F'
,'S82032G'
,'S82032H'
,'S82032J'
,'S82032K'
,'S82032M'
,'S82032N'
,'S82032P'
,'S82032Q'
,'S82032R'
,'S82032S'
,'S82033C'
,'S82033D'
,'S82033E'
,'S82033F'
,'S82033G'
,'S82033H'
,'S82033J'
,'S82033K'
,'S82033M'
,'S82033N'
,'S82033P'
,'S82033Q'
,'S82033R'
,'S82033S'
,'S82034C'
,'S82034D'
,'S82034E'
,'S82034F'
,'S82034G'
,'S82034H'
,'S82034J'
,'S82034K'
,'S82034M'
,'S82034N'
,'S82034P'
,'S82034Q'
,'S82034R'
,'S82034S'
,'S82035C'
,'S82035D'
,'S82035E'
,'S82035F'
,'S82035G'
,'S82035H'
,'S82035J'
,'S82035K'
,'S82035M'
,'S82035N'
,'S82035P'
,'S82035Q'
,'S82035R'
,'S82035S'
,'S82036C'
,'S82036D'
,'S82036E'
,'S82036F'
,'S82036G'
,'S82036H'
,'S82036J'
,'S82036K'
,'S82036M'
,'S82036N'
,'S82036P'
,'S82036Q'
,'S82036R'
,'S82036S'
,'S82041C'
,'S82041D'
,'S82041E'
,'S82041F'
,'S82041G'
,'S82041H'
,'S82041J'
,'S82041K'
,'S82041M'
,'S82041N'
,'S82041P'
,'S82041Q'
,'S82041R'
,'S82041S'
,'S82042C'
,'S82042D'
,'S82042E'
,'S82042F'
,'S82042G'
,'S82042H'
,'S82042J'
,'S82042K'
,'S82042M'
,'S82042N'
,'S82042P'
,'S82042Q'
,'S82042R'
,'S82042S'
,'S82043C'
,'S82043D'
,'S82043E'
,'S82043F'
,'S82043G'
,'S82043H'
,'S82043J'
,'S82043K'
,'S82043M'
,'S82043N'
,'S82043P'
,'S82043Q'
,'S82043R'
,'S82043S'
,'S82044C'
,'S82044D'
,'S82044E'
,'S82044F'
,'S82044G'
,'S82044H'
,'S82044J'
,'S82044K'
,'S82044M'
,'S82044N'
,'S82044P'
,'S82044Q'
,'S82044R'
,'S82044S'
,'S82045C'
,'S82045D'
,'S82045E'
,'S82045F'
,'S82045G'
,'S82045H'
,'S82045J'
,'S82045K'
,'S82045M'
,'S82045N'
,'S82045P'
,'S82045Q'
,'S82045R'
,'S82045S'
,'S82046C'
,'S82046D'
,'S82046E'
,'S82046F'
,'S82046G'
,'S82046H'
,'S82046J'
,'S82046K'
,'S82046M'
,'S82046N'
,'S82046P'
,'S82046Q'
,'S82046R'
,'S82046S'
,'S82091C'
,'S82091D'
,'S82091E'
,'S82091F'
,'S82091G'
,'S82091H'
,'S82091J'
,'S82091K'
,'S82091M'
,'S82091N'
,'S82091P'
,'S82091Q'
,'S82091R'
,'S82091S'
,'S82092C'
,'S82092D'
,'S82092E'
,'S82092F'
,'S82092G'
,'S82092H'
,'S82092J'
,'S82092K'
,'S82092M'
,'S82092N'
,'S82092P'
,'S82092Q'
,'S82092R'
,'S82092S'
,'S82099C'
,'S82099D'
,'S82099E'
,'S82099F'
,'S82099G'
,'S82099H'
,'S82099J'
,'S82099K'
,'S82099M'
,'S82099N'
,'S82099P'
,'S82099Q'
,'S82099R'
,'S82099S'
,'S82101C'
,'S82101D'
,'S82101E'
,'S82101F'
,'S82101G'
,'S82101H'
,'S82101J'
,'S82101K'
,'S82101M'
,'S82101N'
,'S82101P'
,'S82101Q'
,'S82101R'
,'S82101S'
,'S82102C'
,'S82102D'
,'S82102E'
,'S82102F'
,'S82102G'
,'S82102H'
,'S82102J'
,'S82102K'
,'S82102M'
,'S82102N'
,'S82102P'
,'S82102Q'
,'S82102R'
,'S82102S'
,'S82109C'
,'S82109D'
,'S82109E'
,'S82109F'
,'S82109G'
,'S82109H'
,'S82109J'
,'S82109K'
,'S82109M'
,'S82109N'
,'S82109P'
,'S82109Q'
,'S82109R'
,'S82109S'
,'S82111C'
,'S82111D'
,'S82111E'
,'S82111F'
,'S82111G'
,'S82111H'
,'S82111J'
,'S82111K'
,'S82111M'
,'S82111N'
,'S82111P'
,'S82111Q'
,'S82111R'
,'S82111S'
,'S82112C'
,'S82112D'
,'S82112E'
,'S82112F'
,'S82112G'
,'S82112H'
,'S82112J'
,'S82112K'
,'S82112M'
,'S82112N'
,'S82112P'
,'S82112Q'
,'S82112R'
,'S82112S'
,'S82113C'
,'S82113D'
,'S82113E'
,'S82113F'
,'S82113G'
,'S82113H'
,'S82113J'
,'S82113K'
,'S82113M'
,'S82113N'
,'S82113P'
,'S82113Q'
,'S82113R'
,'S82113S'
,'S82114C'
,'S82114D'
,'S82114E'
,'S82114F'
,'S82114G'
,'S82114H'
,'S82114J'
,'S82114K'
,'S82114M'
,'S82114N'
,'S82114P'
,'S82114Q'
,'S82114R'
,'S82114S'
,'S82115C'
,'S82115D'
,'S82115E'
,'S82115F'
,'S82115G'
,'S82115H'
,'S82115J'
,'S82115K'
,'S82115M'
,'S82115N'
,'S82115P'
,'S82115Q'
,'S82115R'
,'S82115S'
,'S82116C'
,'S82116D'
,'S82116E'
,'S82116F'
,'S82116G'
,'S82116H'
,'S82116J'
,'S82116K'
,'S82116M'
,'S82116N'
,'S82116P'
,'S82116Q'
,'S82116R'
,'S82116S'
,'S82121C'
,'S82121D'
,'S82121E'
,'S82121F'
,'S82121G'
,'S82121H'
,'S82121J'
,'S82121K'
,'S82121M'
,'S82121N'
,'S82121P'
,'S82121Q'
,'S82121R'
,'S82121S'
,'S82122C'
,'S82122D'
,'S82122E'
,'S82122F'
,'S82122G'
,'S82122H'
,'S82122J'
,'S82122K'
,'S82122M'
,'S82122N'
,'S82122P'
,'S82122Q'
,'S82122R'
,'S82122S'
,'S82123C'
,'S82123D'
,'S82123E'
,'S82123F'
,'S82123G'
,'S82123H'
,'S82123J'
,'S82123K'
,'S82123M'
,'S82123N'
,'S82123P'
,'S82123Q'
,'S82123R'
,'S82123S'
,'S82124C'
,'S82124D'
,'S82124E'
,'S82124F'
,'S82124G'
,'S82124H'
,'S82124J'
,'S82124K'
,'S82124M'
,'S82124N'
,'S82124P'
,'S82124Q'
,'S82124R'
,'S82124S'
,'S82125C'
,'S82125D'
,'S82125E'
,'S82125F'
,'S82125G'
,'S82125H'
,'S82125J'
,'S82125K'
,'S82125M'
,'S82125N'
,'S82125P'
,'S82125Q'
,'S82125R'
,'S82125S'
,'S82126C'
,'S82126D'
,'S82126E'
,'S82126F'
,'S82126G'
,'S82126H'
,'S82126J'
,'S82126K'
,'S82126M'
,'S82126N'
,'S82126P'
,'S82126Q'
,'S82126R'
,'S82126S'
,'S82131C'
,'S82131D'
,'S82131E'
,'S82131F'
,'S82131G'
,'S82131H'
,'S82131J'
,'S82131K'
,'S82131M'
,'S82131N'
,'S82131P'
,'S82131Q'
,'S82131R'
,'S82131S'
,'S82132C'
,'S82132D'
,'S82132E'
,'S82132F'
,'S82132G'
,'S82132H'
,'S82132J'
,'S82132K'
,'S82132M'
,'S82132N'
,'S82132P'
,'S82132Q'
,'S82132R'
,'S82132S'
,'S82133C'
,'S82133D'
,'S82133E'
,'S82133F'
,'S82133G'
,'S82133H'
,'S82133J'
,'S82133K'
,'S82133M'
,'S82133N'
,'S82133P'
,'S82133Q'
,'S82133R'
,'S82133S'
,'S82134C'
,'S82134D'
,'S82134E'
,'S82134F'
,'S82134G'
,'S82134H'
,'S82134J'
,'S82134K'
,'S82134M'
,'S82134N'
,'S82134P'
,'S82134Q'
,'S82134R'
,'S82134S'
,'S82135C'
,'S82135D'
,'S82135E'
,'S82135F'
,'S82135G'
,'S82135H'
,'S82135J'
,'S82135K'
,'S82135M'
,'S82135N'
,'S82135P'
,'S82135Q'
,'S82135R'
,'S82135S'
,'S82136C'
,'S82136D'
,'S82136E'
,'S82136F'
,'S82136G'
,'S82136H'
,'S82136J'
,'S82136K'
,'S82136M'
,'S82136N'
,'S82136P'
,'S82136Q'
,'S82136R'
,'S82136S'
,'S82141C'
,'S82141D'
,'S82141E'
,'S82141F'
,'S82141G'
,'S82141H'
,'S82141J'
,'S82141K'
,'S82141M'
,'S82141N'
,'S82141P'
,'S82141Q'
,'S82141R'
,'S82141S'
,'S82142C'
,'S82142D'
,'S82142E'
,'S82142F'
,'S82142G'
,'S82142H'
,'S82142J'
,'S82142K'
,'S82142M'
,'S82142N'
,'S82142P'
,'S82142Q'
,'S82142R'
,'S82142S'
,'S82143C'
,'S82143D'
,'S82143E'
,'S82143F'
,'S82143G'
,'S82143H'
,'S82143J'
,'S82143K'
,'S82143M'
,'S82143N'
,'S82143P'
,'S82143Q'
,'S82143R'
,'S82143S'
,'S82144C'
,'S82144D'
,'S82144E'
,'S82144F'
,'S82144G'
,'S82144H'
,'S82144J'
,'S82144K'
,'S82144M'
,'S82144N'
,'S82144P'
,'S82144Q'
,'S82144R'
,'S82144S'
,'S82145C'
,'S82145D'
,'S82145E'
,'S82145F'
,'S82145G'
,'S82145H'
,'S82145J'
,'S82145K'
,'S82145M'
,'S82145N'
,'S82145P'
,'S82145Q'
,'S82145R'
,'S82145S'
,'S82146C'
,'S82146D'
,'S82146E'
,'S82146F'
,'S82146G'
,'S82146H'
,'S82146J'
,'S82146K'
,'S82146M'
,'S82146N'
,'S82146P'
,'S82146Q'
,'S82146R'
,'S82146S'
,'S82151C'
,'S82151D'
,'S82151E'
,'S82151F'
,'S82151G'
,'S82151H'
,'S82151J'
,'S82151K'
,'S82151M'
,'S82151N'
,'S82151P'
,'S82151Q'
,'S82151R'
,'S82151S'
,'S82152C'
,'S82152D'
,'S82152E'
,'S82152F'
,'S82152G'
,'S82152H'
,'S82152J'
,'S82152K'
,'S82152M'
,'S82152N'
,'S82152P'
,'S82152Q'
,'S82152R'
,'S82152S'
,'S82153C'
,'S82153D'
,'S82153E'
,'S82153F'
,'S82153G'
,'S82153H'
,'S82153J'
,'S82153K'
,'S82153M'
,'S82153N'
,'S82153P'
,'S82153Q'
,'S82153R'
,'S82153S'
,'S82154C'
,'S82154D'
,'S82154E'
,'S82154F'
,'S82154G'
,'S82154H'
,'S82154J'
,'S82154K'
,'S82154M'
,'S82154N'
,'S82154P'
,'S82154Q'
,'S82154R'
,'S82154S'
,'S82155C'
,'S82155D'
,'S82155E'
,'S82155F'
,'S82155G'
,'S82155H'
,'S82155J'
,'S82155K'
,'S82155M'
,'S82155N'
,'S82155P'
,'S82155Q'
,'S82155R'
,'S82155S'
,'S82156C'
,'S82156D'
,'S82156E'
,'S82156F'
,'S82156G'
,'S82156H'
,'S82156J'
,'S82156K'
,'S82156M'
,'S82156N'
,'S82156P'
,'S82156Q'
,'S82156R'
,'S82156S'
,'S82161D'
,'S82161G'
,'S82161K'
,'S82161P'
,'S82161S'
,'S82162D'
,'S82162G'
,'S82162K'
,'S82162P'
,'S82162S'
,'S82169D'
,'S82169G'
,'S82169K'
,'S82169P'
,'S82169S'
,'S82191C'
,'S82191D'
,'S82191E'
,'S82191F'
,'S82191G'
,'S82191H'
,'S82191J'
,'S82191K'
,'S82191M'
,'S82191N'
,'S82191P'
,'S82191Q'
,'S82191R'
,'S82191S'
,'S82192C'
,'S82192D'
,'S82192E'
,'S82192F'
,'S82192G'
,'S82192H'
,'S82192J'
,'S82192K'
,'S82192M'
,'S82192N'
,'S82192P'
,'S82192Q'
,'S82192R'
,'S82192S'
,'S82199C'
,'S82199D'
,'S82199E'
,'S82199F'
,'S82199G'
,'S82199H'
,'S82199J'
,'S82199K'
,'S82199M'
,'S82199N'
,'S82199P'
,'S82199Q'
,'S82199R'
,'S82199S'
,'S82201C'
,'S82201D'
,'S82201E'
,'S82201F'
,'S82201G'
,'S82201H'
,'S82201J'
,'S82201K'
,'S82201M'
,'S82201N'
,'S82201P'
,'S82201Q'
,'S82201R'
,'S82201S'
,'S82202C'
,'S82202D'
,'S82202E'
,'S82202F'
,'S82202G'
,'S82202H'
,'S82202J'
,'S82202K'
,'S82202M'
,'S82202N'
,'S82202P'
,'S82202Q'
,'S82202R'
,'S82202S'
,'S82209C'
,'S82209D'
,'S82209E'
,'S82209F'
,'S82209G'
,'S82209H'
,'S82209J'
,'S82209K'
,'S82209M'
,'S82209N'
,'S82209P'
,'S82209Q'
,'S82209R'
,'S82209S'
,'S82221C'
,'S82221D'
,'S82221E'
,'S82221F'
,'S82221G'
,'S82221H'
,'S82221J'
,'S82221K'
,'S82221M'
,'S82221N'
,'S82221P'
,'S82221Q'
,'S82221R'
,'S82221S'
,'S82222C'
,'S82222D'
,'S82222E'
,'S82222F'
,'S82222G'
,'S82222H'
,'S82222J'
,'S82222K'
,'S82222M'
,'S82222N'
,'S82222P'
,'S82222Q'
,'S82222R'
,'S82222S'
,'S82223C'
,'S82223D'
,'S82223E'
,'S82223F'
,'S82223G'
,'S82223H'
,'S82223J'
,'S82223K'
,'S82223M'
,'S82223N'
,'S82223P'
,'S82223Q'
,'S82223R'
,'S82223S'
,'S82224C'
,'S82224D'
,'S82224E'
,'S82224F'
,'S82224G'
,'S82224H'
,'S82224J'
,'S82224K'
,'S82224M'
,'S82224N'
,'S82224P'
,'S82224Q'
,'S82224R'
,'S82224S'
,'S82225C'
,'S82225D'
,'S82225E'
,'S82225F'
,'S82225G'
,'S82225H'
,'S82225J'
,'S82225K'
,'S82225M'
,'S82225N'
,'S82225P'
,'S82225Q'
,'S82225R'
,'S82225S'
,'S82226C'
,'S82226D'
,'S82226E'
,'S82226F'
,'S82226G'
,'S82226H'
,'S82226J'
,'S82226K'
,'S82226M'
,'S82226N'
,'S82226P'
,'S82226Q'
,'S82226R'
,'S82226S'
,'S82231C'
,'S82231D'
,'S82231E'
,'S82231F'
,'S82231G'
,'S82231H'
,'S82231J'
,'S82231K'
,'S82231M'
,'S82231N'
,'S82231P'
,'S82231Q'
,'S82231R'
,'S82231S'
,'S82232C'
,'S82232D'
,'S82232E'
,'S82232F'
,'S82232G'
,'S82232H'
,'S82232J'
,'S82232K'
,'S82232M'
,'S82232N'
,'S82232P'
,'S82232Q'
,'S82232R'
,'S82232S'
,'S82233C'
,'S82233D'
,'S82233E'
,'S82233F'
,'S82233G'
,'S82233H'
,'S82233J'
,'S82233K'
,'S82233M'
,'S82233N'
,'S82233P'
,'S82233Q'
,'S82233R'
,'S82233S'
,'S82234C'
,'S82234D'
,'S82234E'
,'S82234F'
,'S82234G'
,'S82234H'
,'S82234J'
,'S82234K'
,'S82234M'
,'S82234N'
,'S82234P'
,'S82234Q'
,'S82234R'
,'S82234S'
,'S82235C'
,'S82235D'
,'S82235E'
,'S82235F'
,'S82235G'
,'S82235H'
,'S82235J'
,'S82235K'
,'S82235M'
,'S82235N'
,'S82235P'
,'S82235Q'
,'S82235R'
,'S82235S'
,'S82236C'
,'S82236D'
,'S82236E'
,'S82236F'
,'S82236G'
,'S82236H'
,'S82236J'
,'S82236K'
,'S82236M'
,'S82236N'
,'S82236P'
,'S82236Q'
,'S82236R'
,'S82236S'
,'S82241C'
,'S82241D'
,'S82241E'
,'S82241F'
,'S82241G'
,'S82241H'
,'S82241J'
,'S82241K'
,'S82241M'
,'S82241N'
,'S82241P'
,'S82241Q'
,'S82241R'
,'S82241S'
,'S82242C'
,'S82242D'
,'S82242E'
,'S82242F'
,'S82242G'
,'S82242H'
,'S82242J'
,'S82242K'
,'S82242M'
,'S82242N'
,'S82242P'
,'S82242Q'
,'S82242R'
,'S82242S'
,'S82243C'
,'S82243D'
,'S82243E'
,'S82243F'
,'S82243G'
,'S82243H'
,'S82243J'
,'S82243K'
,'S82243M'
,'S82243N'
,'S82243P'
,'S82243Q'
,'S82243R'
,'S82243S'
,'S82244C'
,'S82244D'
,'S82244E'
,'S82244F'
,'S82244G'
,'S82244H'
,'S82244J'
,'S82244K'
,'S82244M'
,'S82244N'
,'S82244P'
,'S82244Q'
,'S82244R'
,'S82244S'
,'S82245C'
,'S82245D'
,'S82245E'
,'S82245F'
,'S82245G'
,'S82245H'
,'S82245J'
,'S82245K'
,'S82245M'
,'S82245N'
,'S82245P'
,'S82245Q'
,'S82245R'
,'S82245S'
,'S82246C'
,'S82246D'
,'S82246E'
,'S82246F'
,'S82246G'
,'S82246H'
,'S82246J'
,'S82246K'
,'S82246M'
,'S82246N'
,'S82246P'
,'S82246Q'
,'S82246R'
,'S82246S'
,'S82251C'
,'S82251D'
,'S82251E'
,'S82251F'
,'S82251G'
,'S82251H'
,'S82251J'
,'S82251K'
,'S82251M'
,'S82251N'
,'S82251P'
,'S82251Q'
,'S82251R'
,'S82251S'
,'S82252C'
,'S82252D'
,'S82252E'
,'S82252F'
,'S82252G'
,'S82252H'
,'S82252J'
,'S82252K'
,'S82252M'
,'S82252N'
,'S82252P'
,'S82252Q'
,'S82252R'
,'S82252S'
,'S82253C'
,'S82253D'
,'S82253E'
,'S82253F'
,'S82253G'
,'S82253H'
,'S82253J'
,'S82253K'
,'S82253M'
,'S82253N'
,'S82253P'
,'S82253Q'
,'S82253R'
,'S82253S'
,'S82254C'
,'S82254D'
,'S82254E'
,'S82254F'
,'S82254G'
,'S82254H'
,'S82254J'
,'S82254K'
,'S82254M'
,'S82254N'
,'S82254P'
,'S82254Q'
,'S82254R'
,'S82254S'
,'S82255C'
,'S82255D'
,'S82255E'
,'S82255F'
,'S82255G'
,'S82255H'
,'S82255J'
,'S82255K'
,'S82255M'
,'S82255N'
,'S82255P'
,'S82255Q'
,'S82255R'
,'S82255S'
,'S82256C'
,'S82256D'
,'S82256E'
,'S82256F'
,'S82256G'
,'S82256H'
,'S82256J'
,'S82256K'
,'S82256M'
,'S82256N'
,'S82256P'
,'S82256Q'
,'S82256R'
,'S82256S'
,'S82261C'
,'S82261D'
,'S82261E'
,'S82261F'
,'S82261G'
,'S82261H'
,'S82261J'
,'S82261K'
,'S82261M'
,'S82261N'
,'S82261P'
,'S82261Q'
,'S82261R'
,'S82261S'
,'S82262C'
,'S82262D'
,'S82262E'
,'S82262F'
,'S82262G'
,'S82262H'
,'S82262J'
,'S82262K'
,'S82262M'
,'S82262N'
,'S82262P'
,'S82262Q'
,'S82262R'
,'S82262S'
,'S82263C'
,'S82263D'
,'S82263E'
,'S82263F'
,'S82263G'
,'S82263H'
,'S82263J'
,'S82263K'
,'S82263M'
,'S82263N'
,'S82263P'
,'S82263Q'
,'S82263R'
,'S82263S'
,'S82264C'
,'S82264D'
,'S82264E'
,'S82264F'
,'S82264G'
,'S82264H'
,'S82264J'
,'S82264K'
,'S82264M'
,'S82264N'
,'S82264P'
,'S82264Q'
,'S82264R'
,'S82264S'
,'S82265C'
,'S82265D'
,'S82265E'
,'S82265F'
,'S82265G'
,'S82265H'
,'S82265J'
,'S82265K'
,'S82265M'
,'S82265N'
,'S82265P'
,'S82265Q'
,'S82265R'
,'S82265S'
,'S82266C'
,'S82266D'
,'S82266E'
,'S82266F'
,'S82266G'
,'S82266H'
,'S82266J'
,'S82266K'
,'S82266M'
,'S82266N'
,'S82266P'
,'S82266Q'
,'S82266R'
,'S82266S'
,'S82291C'
,'S82291D'
,'S82291E'
,'S82291F'
,'S82291G'
,'S82291H'
,'S82291J'
,'S82291K'
,'S82291M'
,'S82291N'
,'S82291P'
,'S82291Q'
,'S82291R'
,'S82291S'
,'S82292C'
,'S82292D'
,'S82292E'
,'S82292F'
,'S82292G'
,'S82292H'
,'S82292J'
,'S82292K'
,'S82292M'
,'S82292N'
,'S82292P'
,'S82292Q'
,'S82292R'
,'S82292S'
,'S82299C'
,'S82299D'
,'S82299E'
,'S82299F'
,'S82299G'
,'S82299H'
,'S82299J'
,'S82299K'
,'S82299M'
,'S82299N'
,'S82299P'
,'S82299Q'
,'S82299R'
,'S82299S'
,'S82301C'
,'S82301D'
,'S82301E'
,'S82301F'
,'S82301G'
,'S82301H'
,'S82301J'
,'S82301K'
,'S82301M'
,'S82301N'
,'S82301P'
,'S82301Q'
,'S82301R'
,'S82301S'
,'S82302C'
,'S82302D'
,'S82302E'
,'S82302F'
,'S82302G'
,'S82302H'
,'S82302J'
,'S82302K'
,'S82302M'
,'S82302N'
,'S82302P'
,'S82302Q'
,'S82302R'
,'S82302S'
,'S82309C'
,'S82309D'
,'S82309E'
,'S82309F'
,'S82309G'
,'S82309H'
,'S82309J'
,'S82309K'
,'S82309M'
,'S82309N'
,'S82309P'
,'S82309Q'
,'S82309R'
,'S82309S'
,'S82311D'
,'S82311G'
,'S82311K'
,'S82311P'
,'S82311S'
,'S82312D'
,'S82312G'
,'S82312K'
,'S82312P'
,'S82312S'
,'S82319D'
,'S82319G'
,'S82319K'
,'S82319P'
,'S82319S'
,'S82391C'
,'S82391D'
,'S82391E'
,'S82391F'
,'S82391G'
,'S82391H'
,'S82391J'
,'S82391K'
,'S82391M'
,'S82391N'
,'S82391P'
,'S82391Q'
,'S82391R'
,'S82391S'
,'S82392C'
,'S82392D'
,'S82392E'
,'S82392F'
,'S82392G'
,'S82392H'
,'S82392J'
,'S82392K'
,'S82392M'
,'S82392N'
,'S82392P'
,'S82392Q'
,'S82392R'
,'S82392S'
,'S82399C'
,'S82399D'
,'S82399E'
,'S82399F'
,'S82399G'
,'S82399H'
,'S82399J'
,'S82399K'
,'S82399M'
,'S82399N'
,'S82399P'
,'S82399Q'
,'S82399R'
,'S82399S'
,'S82401C'
,'S82401D'
,'S82401E'
,'S82401F'
,'S82401G'
,'S82401H'
,'S82401J'
,'S82401K'
,'S82401M'
,'S82401N'
,'S82401P'
,'S82401Q'
,'S82401R'
,'S82401S'
,'S82402C'
,'S82402D'
,'S82402E'
,'S82402F'
,'S82402G'
,'S82402H'
,'S82402J'
,'S82402K'
,'S82402M'
,'S82402N'
,'S82402P'
,'S82402Q'
,'S82402R'
,'S82402S'
,'S82409C'
,'S82409D'
,'S82409E'
,'S82409F'
,'S82409G'
,'S82409H'
,'S82409J'
,'S82409K'
,'S82409M'
,'S82409N'
,'S82409P'
,'S82409Q'
,'S82409R'
,'S82409S'
,'S82421C'
,'S82421D'
,'S82421E'
,'S82421F'
,'S82421G'
,'S82421H'
,'S82421J'
,'S82421K'
,'S82421M'
,'S82421N'
,'S82421P'
,'S82421Q'
,'S82421R'
,'S82421S'
,'S82422C'
,'S82422D'
,'S82422E'
,'S82422F'
,'S82422G'
,'S82422H'
,'S82422J'
,'S82422K'
,'S82422M'
,'S82422N'
,'S82422P'
,'S82422Q'
,'S82422R'
,'S82422S'
,'S82423C'
,'S82423D'
,'S82423E'
,'S82423F'
,'S82423G'
,'S82423H'
,'S82423J'
,'S82423K'
,'S82423M'
,'S82423N'
,'S82423P'
,'S82423Q'
,'S82423R'
,'S82423S'
,'S82424C'
,'S82424D'
,'S82424E'
,'S82424F'
,'S82424G'
,'S82424H'
,'S82424J'
,'S82424K'
,'S82424M'
,'S82424N'
,'S82424P'
,'S82424Q'
,'S82424R'
,'S82424S'
,'S82425C'
,'S82425D'
,'S82425E'
,'S82425F'
,'S82425G'
,'S82425H'
,'S82425J'
,'S82425K'
,'S82425M'
,'S82425N'
,'S82425P'
,'S82425Q'
,'S82425R'
,'S82425S'
,'S82426C'
,'S82426D'
,'S82426E'
,'S82426F'
,'S82426G'
,'S82426H'
,'S82426J'
,'S82426K'
,'S82426M'
,'S82426N'
,'S82426P'
,'S82426Q'
,'S82426R'
,'S82426S'
,'S82431C'
,'S82431D'
,'S82431E'
,'S82431F'
,'S82431G'
,'S82431H'
,'S82431J'
,'S82431K'
,'S82431M'
,'S82431N'
,'S82431P'
,'S82431Q'
,'S82431R'
,'S82431S'
,'S82432C'
,'S82432D'
,'S82432E'
,'S82432F'
,'S82432G'
,'S82432H'
,'S82432J'
,'S82432K'
,'S82432M'
,'S82432N'
,'S82432P'
,'S82432Q'
,'S82432R'
,'S82432S'
,'S82433C'
,'S82433D'
,'S82433E'
,'S82433F'
,'S82433G'
,'S82433H'
,'S82433J'
,'S82433K'
,'S82433M'
,'S82433N'
,'S82433P'
,'S82433Q'
,'S82433R'
,'S82433S'
,'S82434C'
,'S82434D'
,'S82434E'
,'S82434F'
,'S82434G'
,'S82434H'
,'S82434J'
,'S82434K'
,'S82434M'
,'S82434N'
,'S82434P'
,'S82434Q'
,'S82434R'
,'S82434S'
,'S82435C'
,'S82435D'
,'S82435E'
,'S82435F'
,'S82435G'
,'S82435H'
,'S82435J'
,'S82435K'
,'S82435M'
,'S82435N'
,'S82435P'
,'S82435Q'
,'S82435R'
,'S82435S'
,'S82436C'
,'S82436D'
,'S82436E'
,'S82436F'
,'S82436G'
,'S82436H'
,'S82436J'
,'S82436K'
,'S82436M'
,'S82436N'
,'S82436P'
,'S82436Q'
,'S82436R'
,'S82436S'
,'S82441C'
,'S82441D'
,'S82441E'
,'S82441F'
,'S82441G'
,'S82441H'
,'S82441J'
,'S82441K'
,'S82441M'
,'S82441N'
,'S82441P'
,'S82441Q'
,'S82441R'
,'S82441S'
,'S82442C'
,'S82442D'
,'S82442E'
,'S82442F'
,'S82442G'
,'S82442H'
,'S82442J'
,'S82442K'
,'S82442M'
,'S82442N'
,'S82442P'
,'S82442Q'
,'S82442R'
,'S82442S'
,'S82443C'
,'S82443D'
,'S82443E'
,'S82443F'
,'S82443G'
,'S82443H'
,'S82443J'
,'S82443K'
,'S82443M'
,'S82443N'
,'S82443P'
,'S82443Q'
,'S82443R'
,'S82443S'
,'S82444C'
,'S82444D'
,'S82444E'
,'S82444F'
,'S82444G'
,'S82444H'
,'S82444J'
,'S82444K'
,'S82444M'
,'S82444N'
,'S82444P'
,'S82444Q'
,'S82444R'
,'S82444S'
,'S82445C'
,'S82445D'
,'S82445E'
,'S82445F'
,'S82445G'
,'S82445H'
,'S82445J'
,'S82445K'
,'S82445M'
,'S82445N'
,'S82445P'
,'S82445Q'
,'S82445R'
,'S82445S'
,'S82446C'
,'S82446D'
,'S82446E'
,'S82446F'
,'S82446G'
,'S82446H'
,'S82446J'
,'S82446K'
,'S82446M'
,'S82446N'
,'S82446P'
,'S82446Q'
,'S82446R'
,'S82446S'
,'S82451C'
,'S82451D'
,'S82451E'
,'S82451F'
,'S82451G'
,'S82451H'
,'S82451J'
,'S82451K'
,'S82451M'
,'S82451N'
,'S82451P'
,'S82451Q'
,'S82451R'
,'S82451S'
,'S82452C'
,'S82452D'
,'S82452E'
,'S82452F'
,'S82452G'
,'S82452H'
,'S82452J'
,'S82452K'
,'S82452M'
,'S82452N'
,'S82452P'
,'S82452Q'
,'S82452R'
,'S82452S'
,'S82453C'
,'S82453D'
,'S82453E'
,'S82453F'
,'S82453G'
,'S82453H'
,'S82453J'
,'S82453K'
,'S82453M'
,'S82453N'
,'S82453P'
,'S82453Q'
,'S82453R'
,'S82453S'
,'S82454C'
,'S82454D'
,'S82454E'
,'S82454F'
,'S82454G'
,'S82454H'
,'S82454J'
,'S82454K'
,'S82454M'
,'S82454N'
,'S82454P'
,'S82454Q'
,'S82454R'
,'S82454S'
,'S82455C'
,'S82455D'
,'S82455E'
,'S82455F'
,'S82455G'
,'S82455H'
,'S82455J'
,'S82455K'
,'S82455M'
,'S82455N'
,'S82455P'
,'S82455Q'
,'S82455R'
,'S82455S'
,'S82456C'
,'S82456D'
,'S82456E'
,'S82456F'
,'S82456G'
,'S82456H'
,'S82456J'
,'S82456K'
,'S82456M'
,'S82456N'
,'S82456P'
,'S82456Q'
,'S82456R'
,'S82456S'
,'S82461C'
,'S82461D'
,'S82461E'
,'S82461F'
,'S82461G'
,'S82461H'
,'S82461J'
,'S82461K'
,'S82461M'
,'S82461N'
,'S82461P'
,'S82461Q'
,'S82461R'
,'S82461S'
,'S82462C'
,'S82462D'
,'S82462E'
,'S82462F'
,'S82462G'
,'S82462H'
,'S82462J'
,'S82462K'
,'S82462M'
,'S82462N'
,'S82462P'
,'S82462Q'
,'S82462R'
,'S82462S'
,'S82463C'
,'S82463D'
,'S82463E'
,'S82463F'
,'S82463G'
,'S82463H'
,'S82463J'
,'S82463K'
,'S82463M'
,'S82463N'
,'S82463P'
,'S82463Q'
,'S82463R'
,'S82463S'
,'S82464C'
,'S82464D'
,'S82464E'
,'S82464F'
,'S82464G'
,'S82464H'
,'S82464J'
,'S82464K'
,'S82464M'
,'S82464N'
,'S82464P'
,'S82464Q'
,'S82464R'
,'S82464S'
,'S82465C'
,'S82465D'
,'S82465E'
,'S82465F'
,'S82465G'
,'S82465H'
,'S82465J'
,'S82465K'
,'S82465M'
,'S82465N'
,'S82465P'
,'S82465Q'
,'S82465R'
,'S82465S'
,'S82466C'
,'S82466D'
,'S82466E'
,'S82466F'
,'S82466G'
,'S82466H'
,'S82466J'
,'S82466K'
,'S82466M'
,'S82466N'
,'S82466P'
,'S82466Q'
,'S82466R'
,'S82466S'
,'S82491C'
,'S82491D'
,'S82491E'
,'S82491F'
,'S82491G'
,'S82491H'
,'S82491J'
,'S82491K'
,'S82491M'
,'S82491N'
,'S82491P'
,'S82491Q'
,'S82491R'
,'S82491S'
,'S82492C'
,'S82492D'
,'S82492E'
,'S82492F'
,'S82492G'
,'S82492H'
,'S82492J'
,'S82492K'
,'S82492M'
,'S82492N'
,'S82492P'
,'S82492Q'
,'S82492R'
,'S82492S'
,'S82499C'
,'S82499D'
,'S82499E'
,'S82499F'
,'S82499G'
,'S82499H'
,'S82499J'
,'S82499K'
,'S82499M'
,'S82499N'
,'S82499P'
,'S82499Q'
,'S82499R'
,'S82499S'
,'S8251XC'
,'S8251XD'
,'S8251XE'
,'S8251XF'
,'S8251XG'
,'S8251XH'
,'S8251XJ'
,'S8251XK'
,'S8251XM'
,'S8251XN'
,'S8251XP'
,'S8251XQ'
,'S8251XR'
,'S8251XS'
,'S8252XC'
,'S8252XD'
,'S8252XE'
,'S8252XF'
,'S8252XG'
,'S8252XH'
,'S8252XJ'
,'S8252XK'
,'S8252XM'
,'S8252XN'
,'S8252XP'
,'S8252XQ'
,'S8252XR'
,'S8252XS'
,'S8253XC'
,'S8253XD'
,'S8253XE'
,'S8253XF'
,'S8253XG'
,'S8253XH'
,'S8253XJ'
,'S8253XK'
,'S8253XM'
,'S8253XN'
,'S8253XP'
,'S8253XQ'
,'S8253XR'
,'S8253XS'
,'S8254XC'
,'S8254XD'
,'S8254XE'
,'S8254XF'
,'S8254XG'
,'S8254XH'
,'S8254XJ'
,'S8254XK'
,'S8254XM'
,'S8254XN'
,'S8254XP'
,'S8254XQ'
,'S8254XR'
,'S8254XS'
,'S8255XC'
,'S8255XD'
,'S8255XE'
,'S8255XF'
,'S8255XG'
,'S8255XH'
,'S8255XJ'
,'S8255XK'
,'S8255XM'
,'S8255XN'
,'S8255XP'
,'S8255XQ'
,'S8255XR'
,'S8255XS'
,'S8256XC'
,'S8256XD'
,'S8256XE'
,'S8256XF'
,'S8256XG'
,'S8256XH'
,'S8256XJ'
,'S8256XK'
,'S8256XM'
,'S8256XN'
,'S8256XP'
,'S8256XQ'
,'S8256XR'
,'S8256XS'
,'S8261XC'
,'S8261XD'
,'S8261XE'
,'S8261XF'
,'S8261XG'
,'S8261XH'
,'S8261XJ'
,'S8261XK'
,'S8261XM'
,'S8261XN'
,'S8261XP'
,'S8261XQ'
,'S8261XR'
,'S8261XS'
,'S8262XC'
,'S8262XD'
,'S8262XE'
,'S8262XF'
,'S8262XG'
,'S8262XH'
,'S8262XJ'
,'S8262XK'
,'S8262XM'
,'S8262XN'
,'S8262XP'
,'S8262XQ'
,'S8262XR'
,'S8262XS'
,'S8263XC'
,'S8263XD'
,'S8263XE'
,'S8263XF'
,'S8263XG'
,'S8263XH'
,'S8263XJ'
,'S8263XK'
,'S8263XM'
,'S8263XN'
,'S8263XP'
,'S8263XQ'
,'S8263XR'
,'S8263XS'
,'S8264XC'
,'S8264XD'
,'S8264XE'
,'S8264XF'
,'S8264XG'
,'S8264XH'
,'S8264XJ'
,'S8264XK'
,'S8264XM'
,'S8264XN'
,'S8264XP'
,'S8264XQ'
,'S8264XR'
,'S8264XS'
,'S8265XC'
,'S8265XD'
,'S8265XE'
,'S8265XF'
,'S8265XG'
,'S8265XH'
,'S8265XJ'
,'S8265XK'
,'S8265XM'
,'S8265XN'
,'S8265XP'
,'S8265XQ'
,'S8265XR'
,'S8265XS'
,'S8266XC'
,'S8266XD'
,'S8266XE'
,'S8266XF'
,'S8266XG'
,'S8266XH'
,'S8266XJ'
,'S8266XK'
,'S8266XM'
,'S8266XN'
,'S8266XP'
,'S8266XQ'
,'S8266XR'
,'S8266XS'
,'S82811D'
,'S82811G'
,'S82811K'
,'S82811P'
,'S82811S'
,'S82812D'
,'S82812G'
,'S82812K'
,'S82812P'
,'S82812S'
,'S82819D'
,'S82819G'
,'S82819K'
,'S82819P'
,'S82819S'
,'S82821D'
,'S82821G'
,'S82821K'
,'S82821P'
,'S82821S'
,'S82822D'
,'S82822G'
,'S82822K'
,'S82822P'
,'S82822S'
,'S82829D'
,'S82829G'
,'S82829K'
,'S82829P'
,'S82829S'
,'S82831C'
,'S82831D'
,'S82831E'
,'S82831F'
,'S82831G'
,'S82831H'
,'S82831J'
,'S82831K'
,'S82831M'
,'S82831N'
,'S82831P'
,'S82831Q'
,'S82831R'
,'S82831S'
,'S82832C'
,'S82832D'
,'S82832E'
,'S82832F'
,'S82832G'
,'S82832H'
,'S82832J'
,'S82832K'
,'S82832M'
,'S82832N'
,'S82832P'
,'S82832Q'
,'S82832R'
,'S82832S'
,'S82839C'
,'S82839D'
,'S82839E'
,'S82839F'
,'S82839G'
,'S82839H'
,'S82839J'
,'S82839K'
,'S82839M'
,'S82839N'
,'S82839P'
,'S82839Q'
,'S82839R'
,'S82839S'
,'S82841C'
,'S82841D'
,'S82841E'
,'S82841F'
,'S82841G'
,'S82841H'
,'S82841J'
,'S82841K'
,'S82841M'
,'S82841N'
,'S82841P'
,'S82841Q'
,'S82841R'
,'S82841S'
,'S82842C'
,'S82842D'
,'S82842E'
,'S82842F'
,'S82842G'
,'S82842H'
,'S82842J'
,'S82842K'
,'S82842M'
,'S82842N'
,'S82842P'
,'S82842Q'
,'S82842R'
,'S82842S'
,'S82843C'
,'S82843D'
,'S82843E'
,'S82843F'
,'S82843G'
,'S82843H'
,'S82843J'
,'S82843K'
,'S82843M'
,'S82843N'
,'S82843P'
,'S82843Q'
,'S82843R'
,'S82843S'
,'S82844C'
,'S82844D'
,'S82844E'
,'S82844F'
,'S82844G'
,'S82844H'
,'S82844J'
,'S82844K'
,'S82844M'
,'S82844N'
,'S82844P'
,'S82844Q'
,'S82844R'
,'S82844S'
,'S82845C'
,'S82845D'
,'S82845E'
,'S82845F'
,'S82845G'
,'S82845H'
,'S82845J'
,'S82845K'
,'S82845M'
,'S82845N'
,'S82845P'
,'S82845Q'
,'S82845R'
,'S82845S'
,'S82846C'
,'S82846D'
,'S82846E'
,'S82846F'
,'S82846G'
,'S82846H'
,'S82846J'
,'S82846K'
,'S82846M'
,'S82846N'
,'S82846P'
,'S82846Q'
,'S82846R'
,'S82846S'
,'S82851C'
,'S82851D'
,'S82851E'
,'S82851F'
,'S82851G'
,'S82851H'
,'S82851J'
,'S82851K'
,'S82851M'
,'S82851N'
,'S82851P'
,'S82851Q'
,'S82851R'
,'S82851S'
,'S82852C'
,'S82852D'
,'S82852E'
,'S82852F'
,'S82852G'
,'S82852H'
,'S82852J'
,'S82852K'
,'S82852M'
,'S82852N'
,'S82852P'
,'S82852Q'
,'S82852R'
,'S82852S'
,'S82853C'
,'S82853D'
,'S82853E'
,'S82853F'
,'S82853G'
,'S82853H'
,'S82853J'
,'S82853K'
,'S82853M'
,'S82853N'
,'S82853P'
,'S82853Q'
,'S82853R'
,'S82853S'
,'S82854C'
,'S82854D'
,'S82854E'
,'S82854F'
,'S82854G'
,'S82854H'
,'S82854J'
,'S82854K'
,'S82854M'
,'S82854N'
,'S82854P'
,'S82854Q'
,'S82854R'
,'S82854S'
,'S82855C'
,'S82855D'
,'S82855E'
,'S82855F'
,'S82855G'
,'S82855H'
,'S82855J'
,'S82855K'
,'S82855M'
,'S82855N'
,'S82855P'
,'S82855Q'
,'S82855R'
,'S82855S'
,'S82856C'
,'S82856D'
,'S82856E'
,'S82856F'
,'S82856G'
,'S82856H'
,'S82856J'
,'S82856K'
,'S82856M'
,'S82856N'
,'S82856P'
,'S82856Q'
,'S82856R'
,'S82856S'
,'S82861C'
,'S82861D'
,'S82861E'
,'S82861F'
,'S82861G'
,'S82861H'
,'S82861J'
,'S82861K'
,'S82861M'
,'S82861N'
,'S82861P'
,'S82861Q'
,'S82861R'
,'S82861S'
,'S82862C'
,'S82862D'
,'S82862E'
,'S82862F'
,'S82862G'
,'S82862H'
,'S82862J'
,'S82862K'
,'S82862M'
,'S82862N'
,'S82862P'
,'S82862Q'
,'S82862R'
,'S82862S'
,'S82863C'
,'S82863D'
,'S82863E'
,'S82863F'
,'S82863G'
,'S82863H'
,'S82863J'
,'S82863K'
,'S82863M'
,'S82863N'
,'S82863P'
,'S82863Q'
,'S82863R'
,'S82863S'
,'S82864C'
,'S82864D'
,'S82864E'
,'S82864F'
,'S82864G'
,'S82864H'
,'S82864J'
,'S82864K'
,'S82864M'
,'S82864N'
,'S82864P'
,'S82864Q'
,'S82864R'
,'S82864S'
,'S82865C'
,'S82865D'
,'S82865E'
,'S82865F'
,'S82865G'
,'S82865H'
,'S82865J'
,'S82865K'
,'S82865M'
,'S82865N'
,'S82865P'
,'S82865Q'
,'S82865R'
,'S82865S'
,'S82866C'
,'S82866D'
,'S82866E'
,'S82866F'
,'S82866G'
,'S82866H'
,'S82866J'
,'S82866K'
,'S82866M'
,'S82866N'
,'S82866P'
,'S82866Q'
,'S82866R'
,'S82866S'
,'S82871C'
,'S82871D'
,'S82871E'
,'S82871F'
,'S82871G'
,'S82871H'
,'S82871J'
,'S82871K'
,'S82871M'
,'S82871N'
,'S82871P'
,'S82871Q'
,'S82871R'
,'S82871S'
,'S82872C'
,'S82872D'
,'S82872E'
,'S82872F'
,'S82872G'
,'S82872H'
,'S82872J'
,'S82872K'
,'S82872M'
,'S82872N'
,'S82872P'
,'S82872Q'
,'S82872R'
,'S82872S'
,'S82873C'
,'S82873D'
,'S82873E'
,'S82873F'
,'S82873G'
,'S82873H'
,'S82873J'
,'S82873K'
,'S82873M'
,'S82873N'
,'S82873P'
,'S82873Q'
,'S82873R'
,'S82873S'
,'S82874C'
,'S82874D'
,'S82874E'
,'S82874F'
,'S82874G'
,'S82874H'
,'S82874J'
,'S82874K'
,'S82874M'
,'S82874N'
,'S82874P'
,'S82874Q'
,'S82874R'
,'S82874S'
,'S82875C'
,'S82875D'
,'S82875E'
,'S82875F'
,'S82875G'
,'S82875H'
,'S82875J'
,'S82875K'
,'S82875M'
,'S82875N'
,'S82875P'
,'S82875Q'
,'S82875R'
,'S82875S'
,'S82876C'
,'S82876D'
,'S82876E'
,'S82876F'
,'S82876G'
,'S82876H'
,'S82876J'
,'S82876K'
,'S82876M'
,'S82876N'
,'S82876P'
,'S82876Q'
,'S82876R'
,'S82876S'
,'S82891C'
,'S82891D'
,'S82891E'
,'S82891F'
,'S82891G'
,'S82891H'
,'S82891J'
,'S82891K'
,'S82891M'
,'S82891N'
,'S82891P'
,'S82891Q'
,'S82891R'
,'S82891S'
,'S82892C'
,'S82892D'
,'S82892E'
,'S82892F'
,'S82892G'
,'S82892H'
,'S82892J'
,'S82892K'
,'S82892M'
,'S82892N'
,'S82892P'
,'S82892Q'
,'S82892R'
,'S82892S'
,'S82899C'
,'S82899D'
,'S82899E'
,'S82899F'
,'S82899G'
,'S82899H'
,'S82899J'
,'S82899K'
,'S82899M'
,'S82899N'
,'S82899P'
,'S82899Q'
,'S82899R'
,'S82899S'
,'S8290XC'
,'S8290XD'
,'S8290XE'
,'S8290XF'
,'S8290XG'
,'S8290XH'
,'S8290XJ'
,'S8290XK'
,'S8290XM'
,'S8290XN'
,'S8290XP'
,'S8290XQ'
,'S8290XR'
,'S8290XS'
,'S8291XC'
,'S8291XD'
,'S8291XE'
,'S8291XF'
,'S8291XG'
,'S8291XH'
,'S8291XJ'
,'S8291XK'
,'S8291XM'
,'S8291XN'
,'S8291XP'
,'S8291XQ'
,'S8291XR'
,'S8291XS'
,'S8292XC'
,'S8292XD'
,'S8292XE'
,'S8292XF'
,'S8292XG'
,'S8292XH'
,'S8292XJ'
,'S8292XK'
,'S8292XM'
,'S8292XN'
,'S8292XP'
,'S8292XQ'
,'S8292XR'
,'S8292XS'
,'S83001D'
,'S83001S'
,'S83002D'
,'S83002S'
,'S83003D'
,'S83003S'
,'S83004D'
,'S83004S'
,'S83005D'
,'S83005S'
,'S83006D'
,'S83006S'
,'S83011D'
,'S83011S'
,'S83012D'
,'S83012S'
,'S83013D'
,'S83013S'
,'S83014D'
,'S83014S'
,'S83015D'
,'S83015S'
,'S83016D'
,'S83016S'
,'S83091D'
,'S83091S'
,'S83092D'
,'S83092S'
,'S83093D'
,'S83093S'
,'S83094D'
,'S83094S'
,'S83095D'
,'S83095S'
,'S83096D'
,'S83096S'
,'S83101D'
,'S83101S'
,'S83102D'
,'S83102S'
,'S83103D'
,'S83103S'
,'S83104D'
,'S83104S'
,'S83105D'
,'S83105S'
,'S83106D'
,'S83106S'
,'S83111D'
,'S83111S'
,'S83112D'
,'S83112S'
,'S83113D'
,'S83113S'
,'S83114D'
,'S83114S'
,'S83115D'
,'S83115S'
,'S83116D'
,'S83116S'
,'S83121D'
,'S83121S'
,'S83122D'
,'S83122S'
,'S83123D'
,'S83123S'
,'S83124D'
,'S83124S'
,'S83125D'
,'S83125S'
,'S83126D'
,'S83126S'
,'S83131D'
,'S83131S'
,'S83132D'
,'S83132S'
,'S83133D'
,'S83133S'
,'S83134D'
,'S83134S'
,'S83135D'
,'S83135S'
,'S83136D'
,'S83136S'
,'S83141D'
,'S83141S'
,'S83142D'
,'S83142S'
,'S83143D'
,'S83143S'
,'S83144D'
,'S83144S'
,'S83145D'
,'S83145S'
,'S83146D'
,'S83146S'
,'S83191D'
,'S83191S'
,'S83192D'
,'S83192S'
,'S83193D'
,'S83193S'
,'S83194D'
,'S83194S'
,'S83195D'
,'S83195S'
,'S83196D'
,'S83196S'
,'S83200D'
,'S83200S'
,'S83201D'
,'S83201S'
,'S83202D'
,'S83202S'
,'S83203D'
,'S83203S'
,'S83204D'
,'S83204S'
,'S83205D'
,'S83205S'
,'S83206D'
,'S83206S'
,'S83207D'
,'S83207S'
,'S83209D'
,'S83209S'
,'S83211D'
,'S83211S'
,'S83212D'
,'S83212S'
,'S83219D'
,'S83219S'
,'S83221D'
,'S83221S'
,'S83222D'
,'S83222S'
,'S83229D'
,'S83229S'
,'S83231D'
,'S83231S'
,'S83232D'
,'S83232S'
,'S83239D'
,'S83239S'
,'S83241D'
,'S83241S'
,'S83242D'
,'S83242S'
,'S83249D'
,'S83249S'
,'S83251D'
,'S83251S'
,'S83252D'
,'S83252S'
,'S83259D'
,'S83259S'
,'S83261D'
,'S83261S'
,'S83262D'
,'S83262S'
,'S83269D'
,'S83269S'
,'S83271D'
,'S83271S'
,'S83272D'
,'S83272S'
,'S83279D'
,'S83279S'
,'S83281D'
,'S83281S'
,'S83282D'
,'S83282S'
,'S83289D'
,'S83289S'
,'S8330XD'
,'S8330XS'
,'S8331XD'
,'S8331XS'
,'S8332XD'
,'S8332XS'
,'S83401D'
,'S83401S'
,'S83402D'
,'S83402S'
,'S83409D'
,'S83409S'
,'S83411D'
,'S83411S'
,'S83412D'
,'S83412S'
,'S83419D'
,'S83419S'
,'S83421D'
,'S83421S'
,'S83422D'
,'S83422S'
,'S83429D'
,'S83429S'
,'S83501D'
,'S83501S'
,'S83502D'
,'S83502S'
,'S83509D'
,'S83509S'
,'S83511D'
,'S83511S'
,'S83512D'
,'S83512S'
,'S83519D'
,'S83519S'
,'S83521D'
,'S83521S'
,'S83522D'
,'S83522S'
,'S83529D'
,'S83529S'
,'S8360XD'
,'S8360XS'
,'S8361XD'
,'S8361XS'
,'S8362XD'
,'S8362XS'
,'S838X1D'
,'S838X1S'
,'S838X2D'
,'S838X2S'
,'S838X9D'
,'S838X9S'
,'S8390XD'
,'S8390XS'
,'S8391XD'
,'S8391XS'
,'S8392XD'
,'S8392XS'
,'S8400XD'
,'S8400XS'
,'S8401XD'
,'S8401XS'
,'S8402XD'
,'S8402XS'
,'S8410XD'
,'S8410XS'
,'S8411XD'
,'S8411XS'
,'S8412XD'
,'S8412XS'
,'S8420XD'
,'S8420XS'
,'S8421XD'
,'S8421XS'
,'S8422XD'
,'S8422XS'
,'S84801D'
,'S84801S'
,'S84802D'
,'S84802S'
,'S84809D'
,'S84809S'
,'S8490XD'
,'S8490XS'
,'S8491XD'
,'S8491XS'
,'S8492XD'
,'S8492XS'
,'S85001D'
,'S85001S'
,'S85002D'
,'S85002S'
,'S85009D'
,'S85009S'
,'S85011D'
,'S85011S'
,'S85012D'
,'S85012S'
,'S85019D'
,'S85019S'
,'S85091D'
,'S85091S'
,'S85092D'
,'S85092S'
,'S85099D'
,'S85099S'
,'S85101D'
,'S85101S'
,'S85102D'
,'S85102S'
,'S85109D'
,'S85109S'
,'S85111D'
,'S85111S'
,'S85112D'
,'S85112S'
,'S85119D'
,'S85119S'
,'S85121D'
,'S85121S'
,'S85122D'
,'S85122S'
,'S85129D'
,'S85129S'
,'S85131D'
,'S85131S'
,'S85132D'
,'S85132S'
,'S85139D'
,'S85139S'
,'S85141D'
,'S85141S'
,'S85142D'
,'S85142S'
,'S85149D'
,'S85149S'
,'S85151D'
,'S85151S'
,'S85152D'
,'S85152S'
,'S85159D'
,'S85159S'
,'S85161D'
,'S85161S'
,'S85162D'
,'S85162S'
,'S85169D'
,'S85169S'
,'S85171D'
,'S85171S'
,'S85172D'
,'S85172S'
,'S85179D'
,'S85179S'
,'S85181D'
,'S85181S'
,'S85182D'
,'S85182S'
,'S85189D'
,'S85189S'
,'S85201D'
,'S85201S'
,'S85202D'
,'S85202S'
,'S85209D'
,'S85209S'
,'S85211D'
,'S85211S'
,'S85212D'
,'S85212S'
,'S85219D'
,'S85219S'
,'S85291D'
,'S85291S'
,'S85292D'
,'S85292S'
,'S85299D'
,'S85299S'
,'S85301D'
,'S85301S'
,'S85302D'
,'S85302S'
,'S85309D'
,'S85309S'
,'S85311D'
,'S85311S'
,'S85312D'
,'S85312S'
,'S85319D'
,'S85319S'
,'S85391D'
,'S85391S'
,'S85392D'
,'S85392S'
,'S85399D'
,'S85399S'
,'S85401D'
,'S85401S'
,'S85402D'
,'S85402S'
,'S85409D'
,'S85409S'
,'S85411D'
,'S85411S'
,'S85412D'
,'S85412S'
,'S85419D'
,'S85419S'
,'S85491D'
,'S85491S'
,'S85492D'
,'S85492S'
,'S85499D'
,'S85499S'
,'S85501D'
,'S85501S'
,'S85502D'
,'S85502S'
,'S85509D'
,'S85509S'
,'S85511D'
,'S85511S'
,'S85512D'
,'S85512S'
,'S85519D'
,'S85519S'
,'S85591D'
,'S85591S'
,'S85592D'
,'S85592S'
,'S85599D'
,'S85599S'
,'S85801D'
,'S85801S'
,'S85802D'
,'S85802S'
,'S85809D'
,'S85809S'
,'S85811D'
,'S85811S'
,'S85812D'
,'S85812S'
,'S85819D'
,'S85819S'
,'S85891D'
,'S85891S'
,'S85892D'
,'S85892S'
,'S85899D'
,'S85899S'
,'S85901D'
,'S85901S'
,'S85902D'
,'S85902S'
,'S85909D'
,'S85909S'
,'S85911D'
,'S85911S'
,'S85912D'
,'S85912S'
,'S85919D'
,'S85919S'
,'S85991D'
,'S85991S'
,'S85992D'
,'S85992S'
,'S85999D'
,'S85999S'
,'S86001D'
,'S86001S'
,'S86002D'
,'S86002S'
,'S86009D'
,'S86009S'
,'S86011D'
,'S86011S'
,'S86012D'
,'S86012S'
,'S86019D'
,'S86019S'
,'S86021D'
,'S86021S'
,'S86022D'
,'S86022S'
,'S86029D'
,'S86029S'
,'S86091D'
,'S86091S'
,'S86092D'
,'S86092S'
,'S86099D'
,'S86099S'
,'S86101D'
,'S86101S'
,'S86102D'
,'S86102S'
,'S86109D'
,'S86109S'
,'S86111D'
,'S86111S'
,'S86112D'
,'S86112S'
,'S86119D'
,'S86119S'
,'S86121D'
,'S86121S'
,'S86122D'
,'S86122S'
,'S86129D'
,'S86129S'
,'S86191D'
,'S86191S'
,'S86192D'
,'S86192S'
,'S86199D'
,'S86199S'
,'S86201D'
,'S86201S'
,'S86202D'
,'S86202S'
,'S86209D'
,'S86209S'
,'S86211D'
,'S86211S'
,'S86212D'
,'S86212S'
,'S86219D'
,'S86219S'
,'S86221D'
,'S86221S'
,'S86222D'
,'S86222S'
,'S86229D'
,'S86229S'
,'S86291D'
,'S86291S'
,'S86292D'
,'S86292S'
,'S86299D'
,'S86299S'
,'S86301D'
,'S86301S'
,'S86302D'
,'S86302S'
,'S86309D'
,'S86309S'
,'S86311D'
,'S86311S'
,'S86312D'
,'S86312S'
,'S86319D'
,'S86319S'
,'S86321D'
,'S86321S'
,'S86322D'
,'S86322S'
,'S86329D'
,'S86329S'
,'S86391D'
,'S86391S'
,'S86392D'
,'S86392S'
,'S86399D'
,'S86399S'
,'S86801D'
,'S86801S'
,'S86802D'
,'S86802S'
,'S86809D'
,'S86809S'
,'S86811D'
,'S86811S'
,'S86812D'
,'S86812S'
,'S86819D'
,'S86819S'
,'S86821D'
,'S86821S'
,'S86822D'
,'S86822S'
,'S86829D'
,'S86829S'
,'S86891D'
,'S86891S'
,'S86892D'
,'S86892S'
,'S86899D'
,'S86899S'
,'S86901D'
,'S86901S'
,'S86902D'
,'S86902S'
,'S86909D'
,'S86909S'
,'S86911D'
,'S86911S'
,'S86912D'
,'S86912S'
,'S86919D'
,'S86919S'
,'S86921D'
,'S86921S'
,'S86922D'
,'S86922S'
,'S86929D'
,'S86929S'
,'S86991D'
,'S86991S'
,'S86992D'
,'S86992S'
,'S86999D'
,'S86999S'
,'S8700XD'
,'S8700XS'
,'S8701XD'
,'S8701XS'
,'S8702XD'
,'S8702XS'
,'S8780XD'
,'S8780XS'
,'S8781XD'
,'S8781XS'
,'S8782XD'
,'S8782XS'
,'S88011D'
,'S88011S'
,'S88012D'
,'S88012S'
,'S88019D'
,'S88019S'
,'S88021D'
,'S88021S'
,'S88022D'
,'S88022S'
,'S88029D'
,'S88029S'
,'S88111D'
,'S88111S'
,'S88112D'
,'S88112S'
,'S88119D'
,'S88119S'
,'S88121D'
,'S88121S'
,'S88122D'
,'S88122S'
,'S88129D'
,'S88129S'
,'S88911D'
,'S88911S'
,'S88912D'
,'S88912S'
,'S88919D'
,'S88919S'
,'S88921D'
,'S88921S'
,'S88922D'
,'S88922S'
,'S88929D'
,'S88929S'
,'S89001D'
,'S89001G'
,'S89001K'
,'S89001P'
,'S89001S'
,'S89002D'
,'S89002G'
,'S89002K'
,'S89002P'
,'S89002S'
,'S89009D'
,'S89009G'
,'S89009K'
,'S89009P'
,'S89009S'
,'S89011D'
,'S89011G'
,'S89011K'
,'S89011P'
,'S89011S'
,'S89012D'
,'S89012G'
,'S89012K'
,'S89012P'
,'S89012S'
,'S89019D'
,'S89019G'
,'S89019K'
,'S89019P'
,'S89019S'
,'S89021D'
,'S89021G'
,'S89021K'
,'S89021P'
,'S89021S'
,'S89022D'
,'S89022G'
,'S89022K'
,'S89022P'
,'S89022S'
,'S89029D'
,'S89029G'
,'S89029K'
,'S89029P'
,'S89029S'
,'S89031D'
,'S89031G'
,'S89031K'
,'S89031P'
,'S89031S'
,'S89032D'
,'S89032G'
,'S89032K'
,'S89032P'
,'S89032S'
,'S89039D'
,'S89039G'
,'S89039K'
,'S89039P'
,'S89039S'
,'S89041D'
,'S89041G'
,'S89041K'
,'S89041P'
,'S89041S'
,'S89042D'
,'S89042G'
,'S89042K'
,'S89042P'
,'S89042S'
,'S89049D'
,'S89049G'
,'S89049K'
,'S89049P'
,'S89049S'
,'S89091D'
,'S89091G'
,'S89091K'
,'S89091P'
,'S89091S'
,'S89092D'
,'S89092G'
,'S89092K'
,'S89092P'
,'S89092S'
,'S89099D'
,'S89099G'
,'S89099K'
,'S89099P'
,'S89099S'
,'S89101D'
,'S89101G'
,'S89101K'
,'S89101P'
,'S89101S'
,'S89102D'
,'S89102G'
,'S89102K'
,'S89102P'
,'S89102S'
,'S89109D'
,'S89109G'
,'S89109K'
,'S89109P'
,'S89109S'
,'S89111D'
,'S89111G'
,'S89111K'
,'S89111P'
,'S89111S'
,'S89112D'
,'S89112G'
,'S89112K'
,'S89112P'
,'S89112S'
,'S89119D'
,'S89119G'
,'S89119K'
,'S89119P'
,'S89119S'
,'S89121D'
,'S89121G'
,'S89121K'
,'S89121P'
,'S89121S'
,'S89122D'
,'S89122G'
,'S89122K'
,'S89122P'
,'S89122S'
,'S89129D'
,'S89129G'
,'S89129K'
,'S89129P'
,'S89129S'
,'S89131D'
,'S89131G'
,'S89131K'
,'S89131P'
,'S89131S'
,'S89132D'
,'S89132G'
,'S89132K'
,'S89132P'
,'S89132S'
,'S89139D'
,'S89139G'
,'S89139K'
,'S89139P'
,'S89139S'
,'S89141D'
,'S89141G'
,'S89141K'
,'S89141P'
,'S89141S'
,'S89142D'
,'S89142G'
,'S89142K'
,'S89142P'
,'S89142S'
,'S89149D'
,'S89149G'
,'S89149K'
,'S89149P'
,'S89149S'
,'S89191D'
,'S89191G'
,'S89191K'
,'S89191P'
,'S89191S'
,'S89192D'
,'S89192G'
,'S89192K'
,'S89192P'
,'S89192S'
,'S89199D'
,'S89199G'
,'S89199K'
,'S89199P'
,'S89199S'
,'S89201D'
,'S89201G'
,'S89201K'
,'S89201P'
,'S89201S'
,'S89202D'
,'S89202G'
,'S89202K'
,'S89202P'
,'S89202S'
,'S89209D'
,'S89209G'
,'S89209K'
,'S89209P'
,'S89209S'
,'S89211D'
,'S89211G'
,'S89211K'
,'S89211P'
,'S89211S'
,'S89212D'
,'S89212G'
,'S89212K'
,'S89212P'
,'S89212S'
,'S89219D'
,'S89219G'
,'S89219K'
,'S89219P'
,'S89219S'
,'S89221D'
,'S89221G'
,'S89221K'
,'S89221P'
,'S89221S'
,'S89222D'
,'S89222G'
,'S89222K'
,'S89222P'
,'S89222S'
,'S89229D'
,'S89229G'
,'S89229K'
,'S89229P'
,'S89229S'
,'S89291D'
,'S89291G'
,'S89291K'
,'S89291P'
,'S89291S'
,'S89292D'
,'S89292G'
,'S89292K'
,'S89292P'
,'S89292S'
,'S89299D'
,'S89299G'
,'S89299K'
,'S89299P'
,'S89299S'
,'S89301D'
,'S89301G'
,'S89301K'
,'S89301P'
,'S89301S'
,'S89302D'
,'S89302G'
,'S89302K'
,'S89302P'
,'S89302S'
,'S89309D'
,'S89309G'
,'S89309K'
,'S89309P'
,'S89309S'
,'S89311D'
,'S89311G'
,'S89311K'
,'S89311P'
,'S89311S'
,'S89312D'
,'S89312G'
,'S89312K'
,'S89312P'
,'S89312S'
,'S89319D'
,'S89319G'
,'S89319K'
,'S89319P'
,'S89319S'
,'S89321D'
,'S89321G'
,'S89321K'
,'S89321P'
,'S89321S'
,'S89322D'
,'S89322G'
,'S89322K'
,'S89322P'
,'S89322S'
,'S89329D'
,'S89329G'
,'S89329K'
,'S89329P'
,'S89329S'
,'S89391D'
,'S89391G'
,'S89391K'
,'S89391P'
,'S89391S'
,'S89392D'
,'S89392G'
,'S89392K'
,'S89392P'
,'S89392S'
,'S89399D'
,'S89399G'
,'S89399K'
,'S89399P'
,'S89399S'
,'S8980XD'
,'S8980XS'
,'S8981XD'
,'S8981XS'
,'S8982XD'
,'S8982XS'
,'S8990XD'
,'S8990XS'
,'S8991XD'
,'S8991XS'
,'S8992XD'
,'S8992XS'
,'S9000XD'
,'S9000XS'
,'S9001XD'
,'S9001XS'
,'S9002XD'
,'S9002XS'
,'S90111D'
,'S90111S'
,'S90112D'
,'S90112S'
,'S90119D'
,'S90119S'
,'S90121D'
,'S90121S'
,'S90122D'
,'S90122S'
,'S90129D'
,'S90129S'
,'S90211D'
,'S90211S'
,'S90212D'
,'S90212S'
,'S90219D'
,'S90219S'
,'S90221D'
,'S90221S'
,'S90222D'
,'S90222S'
,'S90229D'
,'S90229S'
,'S9030XD'
,'S9030XS'
,'S9031XD'
,'S9031XS'
,'S9032XD'
,'S9032XS'
,'S90411D'
,'S90411S'
,'S90412D'
,'S90412S'
,'S90413D'
,'S90413S'
,'S90414D'
,'S90414S'
,'S90415D'
,'S90415S'
,'S90416D'
,'S90416S'
,'S90421D'
,'S90421S'
,'S90422D'
,'S90422S'
,'S90423D'
,'S90423S'
,'S90424D'
,'S90424S'
,'S90425D'
,'S90425S'
,'S90426D'
,'S90426S'
,'S90441D'
,'S90441S'
,'S90442D'
,'S90442S'
,'S90443D'
,'S90443S'
,'S90444D'
,'S90444S'
,'S90445D'
,'S90445S'
,'S90446D'
,'S90446S'
,'S90451D'
,'S90451S'
,'S90452D'
,'S90452S'
,'S90453D'
,'S90453S'
,'S90454D'
,'S90454S'
,'S90455D'
,'S90455S'
,'S90456D'
,'S90456S'
,'S90461D'
,'S90461S'
,'S90462D'
,'S90462S'
,'S90463D'
,'S90463S'
,'S90464D'
,'S90464S'
,'S90465D'
,'S90465S'
,'S90466D'
,'S90466S'
,'S90471D'
,'S90471S'
,'S90472D'
,'S90472S'
,'S90473D'
,'S90473S'
,'S90474D'
,'S90474S'
,'S90475D'
,'S90475S'
,'S90476D'
,'S90476S'
,'S90511D'
,'S90511S'
,'S90512D'
,'S90512S'
,'S90519D'
,'S90519S'
,'S90521D'
,'S90521S'
,'S90522D'
,'S90522S'
,'S90529D'
,'S90529S'
,'S90541D'
,'S90541S'
,'S90542D'
,'S90542S'
,'S90549D'
,'S90549S'
,'S90551D'
,'S90551S'
,'S90552D'
,'S90552S'
,'S90559D'
,'S90559S'
,'S90561D'
,'S90561S'
,'S90562D'
,'S90562S'
,'S90569D'
,'S90569S'
,'S90571D'
,'S90571S'
,'S90572D'
,'S90572S'
,'S90579D'
,'S90579S'
,'S90811D'
,'S90811S'
,'S90812D'
,'S90812S'
,'S90819D'
,'S90819S'
,'S90821D'
,'S90821S'
,'S90822D'
,'S90822S'
,'S90829D'
,'S90829S'
,'S90841D'
,'S90841S'
,'S90842D'
,'S90842S'
,'S90849D'
,'S90849S'
,'S90851D'
,'S90851S'
,'S90852D'
,'S90852S'
,'S90859D'
,'S90859S'
,'S90861D'
,'S90861S'
,'S90862D'
,'S90862S'
,'S90869D'
,'S90869S'
,'S90871D'
,'S90871S'
,'S90872D'
,'S90872S'
,'S90879D'
,'S90879S'
,'S90911D'
,'S90911S'
,'S90912D'
,'S90912S'
,'S90919D'
,'S90919S'
,'S90921D'
,'S90921S'
,'S90922D'
,'S90922S'
,'S90929D'
,'S90929S'
,'S90931D'
,'S90931S'
,'S90932D'
,'S90932S'
,'S90933D'
,'S90933S'
,'S90934D'
,'S90934S'
,'S90935D'
,'S90935S'
,'S90936D'
,'S90936S'
,'S91001D'
,'S91001S'
,'S91002D'
,'S91002S'
,'S91009D'
,'S91009S'
,'S91011D'
,'S91011S'
,'S91012D'
,'S91012S'
,'S91019D'
,'S91019S'
,'S91021D'
,'S91021S'
,'S91022D'
,'S91022S'
,'S91029D'
,'S91029S'
,'S91031D'
,'S91031S'
,'S91032D'
,'S91032S'
,'S91039D'
,'S91039S'
,'S91041D'
,'S91041S'
,'S91042D'
,'S91042S'
,'S91049D'
,'S91049S'
,'S91051D'
,'S91051S'
,'S91052D'
,'S91052S'
,'S91059D'
,'S91059S'
,'S91101D'
,'S91101S'
,'S91102D'
,'S91102S'
,'S91103D'
,'S91103S'
,'S91104D'
,'S91104S'
,'S91105D'
,'S91105S'
,'S91106D'
,'S91106S'
,'S91109D'
,'S91109S'
,'S91111D'
,'S91111S'
,'S91112D'
,'S91112S'
,'S91113D'
,'S91113S'
,'S91114D'
,'S91114S'
,'S91115D'
,'S91115S'
,'S91116D'
,'S91116S'
,'S91119D'
,'S91119S'
,'S91121D'
,'S91121S'
,'S91122D'
,'S91122S'
,'S91123D'
,'S91123S'
,'S91124D'
,'S91124S'
,'S91125D'
,'S91125S'
,'S91126D'
,'S91126S'
,'S91129D'
,'S91129S'
,'S91131D'
,'S91131S'
,'S91132D'
,'S91132S'
,'S91133D'
,'S91133S'
,'S91134D'
,'S91134S'
,'S91135D'
,'S91135S'
,'S91136D'
,'S91136S'
,'S91139D'
,'S91139S'
,'S91141D'
,'S91141S'
,'S91142D'
,'S91142S'
,'S91143D'
,'S91143S'
,'S91144D'
,'S91144S'
,'S91145D'
,'S91145S'
,'S91146D'
,'S91146S'
,'S91149D'
,'S91149S'
,'S91151D'
,'S91151S'
,'S91152D'
,'S91152S'
,'S91153D'
,'S91153S'
,'S91154D'
,'S91154S'
,'S91155D'
,'S91155S'
,'S91156D'
,'S91156S'
,'S91159D'
,'S91159S'
,'S91201D'
,'S91201S'
,'S91202D'
,'S91202S'
,'S91203D'
,'S91203S'
,'S91204D'
,'S91204S'
,'S91205D'
,'S91205S'
,'S91206D'
,'S91206S'
,'S91209D'
,'S91209S'
,'S91211D'
,'S91211S'
,'S91212D'
,'S91212S'
,'S91213D'
,'S91213S'
,'S91214D'
,'S91214S'
,'S91215D'
,'S91215S'
,'S91216D'
,'S91216S'
,'S91219D'
,'S91219S'
,'S91221D'
,'S91221S'
,'S91222D'
,'S91222S'
,'S91223D'
,'S91223S'
,'S91224D'
,'S91224S'
,'S91225D'
,'S91225S'
,'S91226D'
,'S91226S'
,'S91229D'
,'S91229S'
,'S91231D'
,'S91231S'
,'S91232D'
,'S91232S'
,'S91233D'
,'S91233S'
,'S91234D'
,'S91234S'
,'S91235D'
,'S91235S'
,'S91236D'
,'S91236S'
,'S91239D'
,'S91239S'
,'S91241D'
,'S91241S'
,'S91242D'
,'S91242S'
,'S91243D'
,'S91243S'
,'S91244D'
,'S91244S'
,'S91245D'
,'S91245S'
,'S91246D'
,'S91246S'
,'S91249D'
,'S91249S'
,'S91251D'
,'S91251S'
,'S91252D'
,'S91252S'
,'S91253D'
,'S91253S'
,'S91254D'
,'S91254S'
,'S91255D'
,'S91255S'
,'S91256D'
,'S91256S'
,'S91259D'
,'S91259S'
,'S91301D'
,'S91301S'
,'S91302D'
,'S91302S'
,'S91309D'
,'S91309S'
,'S91311D'
,'S91311S'
,'S91312D'
,'S91312S'
,'S91319D'
,'S91319S'
,'S91321D'
,'S91321S'
,'S91322D'
,'S91322S'
,'S91329D'
,'S91329S'
,'S91331D'
,'S91331S'
,'S91332D'
,'S91332S'
,'S91339D'
,'S91339S'
,'S91341D'
,'S91341S'
,'S91342D'
,'S91342S'
,'S91349D'
,'S91349S'
,'S91351D'
,'S91351S'
,'S91352D'
,'S91352S'
,'S91359D'
,'S91359S'
,'S92001D'
,'S92001G'
,'S92001K'
,'S92001P'
,'S92001S'
,'S92002D'
,'S92002G'
,'S92002K'
,'S92002P'
,'S92002S'
,'S92009D'
,'S92009G'
,'S92009K'
,'S92009P'
,'S92009S'
,'S92011D'
,'S92011G'
,'S92011K'
,'S92011P'
,'S92011S'
,'S92012D'
,'S92012G'
,'S92012K'
,'S92012P'
,'S92012S'
,'S92013D'
,'S92013G'
,'S92013K'
,'S92013P'
,'S92013S'
,'S92014D'
,'S92014G'
,'S92014K'
,'S92014P'
,'S92014S'
,'S92015D'
,'S92015G'
,'S92015K'
,'S92015P'
,'S92015S'
,'S92016D'
,'S92016G'
,'S92016K'
,'S92016P'
,'S92016S'
,'S92021D'
,'S92021G'
,'S92021K'
,'S92021P'
,'S92021S'
,'S92022D'
,'S92022G'
,'S92022K'
,'S92022P'
,'S92022S'
,'S92023D'
,'S92023G'
,'S92023K'
,'S92023P'
,'S92023S'
,'S92024D'
,'S92024G'
,'S92024K'
,'S92024P'
,'S92024S'
,'S92025D'
,'S92025G'
,'S92025K'
,'S92025P'
,'S92025S'
,'S92026D'
,'S92026G'
,'S92026K'
,'S92026P'
,'S92026S'
,'S92031D'
,'S92031G'
,'S92031K'
,'S92031P'
,'S92031S'
,'S92032D'
,'S92032G'
,'S92032K'
,'S92032P'
,'S92032S'
,'S92033D'
,'S92033G'
,'S92033K'
,'S92033P'
,'S92033S'
,'S92034D'
,'S92034G'
,'S92034K'
,'S92034P'
,'S92034S'
,'S92035D'
,'S92035G'
,'S92035K'
,'S92035P'
,'S92035S'
,'S92036D'
,'S92036G'
,'S92036K'
,'S92036P'
,'S92036S'
,'S92041D'
,'S92041G'
,'S92041K'
,'S92041P'
,'S92041S'
,'S92042D'
,'S92042G'
,'S92042K'
,'S92042P'
,'S92042S'
,'S92043D'
,'S92043G'
,'S92043K'
,'S92043P'
,'S92043S'
,'S92044D'
,'S92044G'
,'S92044K'
,'S92044P'
,'S92044S'
,'S92045D'
,'S92045G'
,'S92045K'
,'S92045P'
,'S92045S'
,'S92046D'
,'S92046G'
,'S92046K'
,'S92046P'
,'S92046S'
,'S92051D'
,'S92051G'
,'S92051K'
,'S92051P'
,'S92051S'
,'S92052D'
,'S92052G'
,'S92052K'
,'S92052P'
,'S92052S'
,'S92053D'
,'S92053G'
,'S92053K'
,'S92053P'
,'S92053S'
,'S92054D'
,'S92054G'
,'S92054K'
,'S92054P'
,'S92054S'
,'S92055D'
,'S92055G'
,'S92055K'
,'S92055P'
,'S92055S'
,'S92056D'
,'S92056G'
,'S92056K'
,'S92056P'
,'S92056S'
,'S92061D'
,'S92061G'
,'S92061K'
,'S92061P'
,'S92061S'
,'S92062D'
,'S92062G'
,'S92062K'
,'S92062P'
,'S92062S'
,'S92063D'
,'S92063G'
,'S92063K'
,'S92063P'
,'S92063S'
,'S92064D'
,'S92064G'
,'S92064K'
,'S92064P'
,'S92064S'
,'S92065D'
,'S92065G'
,'S92065K'
,'S92065P'
,'S92065S'
,'S92066D'
,'S92066G'
,'S92066K'
,'S92066P'
,'S92066S'
,'S92101D'
,'S92101G'
,'S92101K'
,'S92101P'
,'S92101S'
,'S92102D'
,'S92102G'
,'S92102K'
,'S92102P'
,'S92102S'
,'S92109D'
,'S92109G'
,'S92109K'
,'S92109P'
,'S92109S'
,'S92111D'
,'S92111G'
,'S92111K'
,'S92111P'
,'S92111S'
,'S92112D'
,'S92112G'
,'S92112K'
,'S92112P'
,'S92112S'
,'S92113D'
,'S92113G'
,'S92113K'
,'S92113P'
,'S92113S'
,'S92114D'
,'S92114G'
,'S92114K'
,'S92114P'
,'S92114S'
,'S92115D'
,'S92115G'
,'S92115K'
,'S92115P'
,'S92115S'
,'S92116D'
,'S92116G'
,'S92116K'
,'S92116P'
,'S92116S'
,'S92121D'
,'S92121G'
,'S92121K'
,'S92121P'
,'S92121S'
,'S92122D'
,'S92122G'
,'S92122K'
,'S92122P'
,'S92122S'
,'S92123D'
,'S92123G'
,'S92123K'
,'S92123P'
,'S92123S'
,'S92124D'
,'S92124G'
,'S92124K'
,'S92124P'
,'S92124S'
,'S92125D'
,'S92125G'
,'S92125K'
,'S92125P'
,'S92125S'
,'S92126D'
,'S92126G'
,'S92126K'
,'S92126P'
,'S92126S'
,'S92131D'
,'S92131G'
,'S92131K'
,'S92131P'
,'S92131S'
,'S92132D'
,'S92132G'
,'S92132K'
,'S92132P'
,'S92132S'
,'S92133D'
,'S92133G'
,'S92133K'
,'S92133P'
,'S92133S'
,'S92134D'
,'S92134G'
,'S92134K'
,'S92134P'
,'S92134S'
,'S92135D'
,'S92135G'
,'S92135K'
,'S92135P'
,'S92135S'
,'S92136D'
,'S92136G'
,'S92136K'
,'S92136P'
,'S92136S'
,'S92141D'
,'S92141G'
,'S92141K'
,'S92141P'
,'S92141S'
,'S92142D'
,'S92142G'
,'S92142K'
,'S92142P'
,'S92142S'
,'S92143D'
,'S92143G'
,'S92143K'
,'S92143P'
,'S92143S'
,'S92144D'
,'S92144G'
,'S92144K'
,'S92144P'
,'S92144S'
,'S92145D'
,'S92145G'
,'S92145K'
,'S92145P'
,'S92145S'
,'S92146D'
,'S92146G'
,'S92146K'
,'S92146P'
,'S92146S'
,'S92151D'
,'S92151G'
,'S92151K'
,'S92151P'
,'S92151S'
,'S92152D'
,'S92152G'
,'S92152K'
,'S92152P'
,'S92152S'
,'S92153D'
,'S92153G'
,'S92153K'
,'S92153P'
,'S92153S'
,'S92154D'
,'S92154G'
,'S92154K'
,'S92154P'
,'S92154S'
,'S92155D'
,'S92155G'
,'S92155K'
,'S92155P'
,'S92155S'
,'S92156D'
,'S92156G'
,'S92156K'
,'S92156P'
,'S92156S'
,'S92191D'
,'S92191G'
,'S92191K'
,'S92191P'
,'S92191S'
,'S92192D'
,'S92192G'
,'S92192K'
,'S92192P'
,'S92192S'
,'S92199D'
,'S92199G'
,'S92199K'
,'S92199P'
,'S92199S'
,'S92201D'
,'S92201G'
,'S92201K'
,'S92201P'
,'S92201S'
,'S92202D'
,'S92202G'
,'S92202K'
,'S92202P'
,'S92202S'
,'S92209D'
,'S92209G'
,'S92209K'
,'S92209P'
,'S92209S'
,'S92211D'
,'S92211G'
,'S92211K'
,'S92211P'
,'S92211S'
,'S92212D'
,'S92212G'
,'S92212K'
,'S92212P'
,'S92212S'
,'S92213D'
,'S92213G'
,'S92213K'
,'S92213P'
,'S92213S'
,'S92214D'
,'S92214G'
,'S92214K'
,'S92214P'
,'S92214S'
,'S92215D'
,'S92215G'
,'S92215K'
,'S92215P'
,'S92215S'
,'S92216D'
,'S92216G'
,'S92216K'
,'S92216P'
,'S92216S'
,'S92221D'
,'S92221G'
,'S92221K'
,'S92221P'
,'S92221S'
,'S92222D'
,'S92222G'
,'S92222K'
,'S92222P'
,'S92222S'
,'S92223D'
,'S92223G'
,'S92223K'
,'S92223P'
,'S92223S'
,'S92224D'
,'S92224G'
,'S92224K'
,'S92224P'
,'S92224S'
,'S92225D'
,'S92225G'
,'S92225K'
,'S92225P'
,'S92225S'
,'S92226D'
,'S92226G'
,'S92226K'
,'S92226P'
,'S92226S'
,'S92231D'
,'S92231G'
,'S92231K'
,'S92231P'
,'S92231S'
,'S92232D'
,'S92232G'
,'S92232K'
,'S92232P'
,'S92232S'
,'S92233D'
,'S92233G'
,'S92233K'
,'S92233P'
,'S92233S'
,'S92234D'
,'S92234G'
,'S92234K'
,'S92234P'
,'S92234S'
,'S92235D'
,'S92235G'
,'S92235K'
,'S92235P'
,'S92235S'
,'S92236D'
,'S92236G'
,'S92236K'
,'S92236P'
,'S92236S'
,'S92241D'
,'S92241G'
,'S92241K'
,'S92241P'
,'S92241S'
,'S92242D'
,'S92242G'
,'S92242K'
,'S92242P'
,'S92242S'
,'S92243D'
,'S92243G'
,'S92243K'
,'S92243P'
,'S92243S'
,'S92244D'
,'S92244G'
,'S92244K'
,'S92244P'
,'S92244S'
,'S92245D'
,'S92245G'
,'S92245K'
,'S92245P'
,'S92245S'
,'S92246D'
,'S92246G'
,'S92246K'
,'S92246P'
,'S92246S'
,'S92251D'
,'S92251G'
,'S92251K'
,'S92251P'
,'S92251S'
,'S92252D'
,'S92252G'
,'S92252K'
,'S92252P'
,'S92252S'
,'S92253D'
,'S92253G'
,'S92253K'
,'S92253P'
,'S92253S'
,'S92254D'
,'S92254G'
,'S92254K'
,'S92254P'
,'S92254S'
,'S92255D'
,'S92255G'
,'S92255K'
,'S92255P'
,'S92255S'
,'S92256D'
,'S92256G'
,'S92256K'
,'S92256P'
,'S92256S'
,'S92301D'
,'S92301G'
,'S92301K'
,'S92301P'
,'S92301S'
,'S92302D'
,'S92302G'
,'S92302K'
,'S92302P'
,'S92302S'
,'S92309D'
,'S92309G'
,'S92309K'
,'S92309P'
,'S92309S'
,'S92311D'
,'S92311G'
,'S92311K'
,'S92311P'
,'S92311S'
,'S92312D'
,'S92312G'
,'S92312K'
,'S92312P'
,'S92312S'
,'S92313D'
,'S92313G'
,'S92313K'
,'S92313P'
,'S92313S'
,'S92314D'
,'S92314G'
,'S92314K'
,'S92314P'
,'S92314S'
,'S92315D'
,'S92315G'
,'S92315K'
,'S92315P'
,'S92315S'
,'S92316D'
,'S92316G'
,'S92316K'
,'S92316P'
,'S92316S'
,'S92321D'
,'S92321G'
,'S92321K'
,'S92321P'
,'S92321S'
,'S92322D'
,'S92322G'
,'S92322K'
,'S92322P'
,'S92322S'
,'S92323D'
,'S92323G'
,'S92323K'
,'S92323P'
,'S92323S'
,'S92324D'
,'S92324G'
,'S92324K'
,'S92324P'
,'S92324S'
,'S92325D'
,'S92325G'
,'S92325K'
,'S92325P'
,'S92325S'
,'S92326D'
,'S92326G'
,'S92326K'
,'S92326P'
,'S92326S'
,'S92331D'
,'S92331G'
,'S92331K'
,'S92331P'
,'S92331S'
,'S92332D'
,'S92332G'
,'S92332K'
,'S92332P'
,'S92332S'
,'S92333D'
,'S92333G'
,'S92333K'
,'S92333P'
,'S92333S'
,'S92334D'
,'S92334G'
,'S92334K'
,'S92334P'
,'S92334S'
,'S92335D'
,'S92335G'
,'S92335K'
,'S92335P'
,'S92335S'
,'S92336D'
,'S92336G'
,'S92336K'
,'S92336P'
,'S92336S'
,'S92341D'
,'S92341G'
,'S92341K'
,'S92341P'
,'S92341S'
,'S92342D'
,'S92342G'
,'S92342K'
,'S92342P'
,'S92342S'
,'S92343D'
,'S92343G'
,'S92343K'
,'S92343P'
,'S92343S'
,'S92344D'
,'S92344G'
,'S92344K'
,'S92344P'
,'S92344S'
,'S92345D'
,'S92345G'
,'S92345K'
,'S92345P'
,'S92345S'
,'S92346D'
,'S92346G'
,'S92346K'
,'S92346P'
,'S92346S'
,'S92351D'
,'S92351G'
,'S92351K'
,'S92351P'
,'S92351S'
,'S92352D'
,'S92352G'
,'S92352K'
,'S92352P'
,'S92352S'
,'S92353D'
,'S92353G'
,'S92353K'
,'S92353P'
,'S92353S'
,'S92354D'
,'S92354G'
,'S92354K'
,'S92354P'
,'S92354S'
,'S92355D'
,'S92355G'
,'S92355K'
,'S92355P'
,'S92355S'
,'S92356D'
,'S92356G'
,'S92356K'
,'S92356P'
,'S92356S'
,'S92401D'
,'S92401G'
,'S92401K'
,'S92401P'
,'S92401S'
,'S92402D'
,'S92402G'
,'S92402K'
,'S92402P'
,'S92402S'
,'S92403D'
,'S92403G'
,'S92403K'
,'S92403P'
,'S92403S'
,'S92404D'
,'S92404G'
,'S92404K'
,'S92404P'
,'S92404S'
,'S92405D'
,'S92405G'
,'S92405K'
,'S92405P'
,'S92405S'
,'S92406D'
,'S92406G'
,'S92406K'
,'S92406P'
,'S92406S'
,'S92411D'
,'S92411G'
,'S92411K'
,'S92411P'
,'S92411S'
,'S92412D'
,'S92412G'
,'S92412K'
,'S92412P'
,'S92412S'
,'S92413D'
,'S92413G'
,'S92413K'
,'S92413P'
,'S92413S'
,'S92414D'
,'S92414G'
,'S92414K'
,'S92414P'
,'S92414S'
,'S92415D'
,'S92415G'
,'S92415K'
,'S92415P'
,'S92415S'
,'S92416D'
,'S92416G'
,'S92416K'
,'S92416P'
,'S92416S'
,'S92421D'
,'S92421G'
,'S92421K'
,'S92421P'
,'S92421S'
,'S92422D'
,'S92422G'
,'S92422K'
,'S92422P'
,'S92422S'
,'S92423D'
,'S92423G'
,'S92423K'
,'S92423P'
,'S92423S'
,'S92424D'
,'S92424G'
,'S92424K'
,'S92424P'
,'S92424S'
,'S92425D'
,'S92425G'
,'S92425K'
,'S92425P'
,'S92425S'
,'S92426D'
,'S92426G'
,'S92426K'
,'S92426P'
,'S92426S'
,'S92491D'
,'S92491G'
,'S92491K'
,'S92491P'
,'S92491S'
,'S92492D'
,'S92492G'
,'S92492K'
,'S92492P'
,'S92492S'
,'S92499D'
,'S92499G'
,'S92499K'
,'S92499P'
,'S92499S'
,'S92501D'
,'S92501G'
,'S92501K'
,'S92501P'
,'S92501S'
,'S92502D'
,'S92502G'
,'S92502K'
,'S92502P'
,'S92502S'
,'S92503D'
,'S92503G'
,'S92503K'
,'S92503P'
,'S92503S'
,'S92504D'
,'S92504G'
,'S92504K'
,'S92504P'
,'S92504S'
,'S92505D'
,'S92505G'
,'S92505K'
,'S92505P'
,'S92505S'
,'S92506D'
,'S92506G'
,'S92506K'
,'S92506P'
,'S92506S'
,'S92511D'
,'S92511G'
,'S92511K'
,'S92511P'
,'S92511S'
,'S92512D'
,'S92512G'
,'S92512K'
,'S92512P'
,'S92512S'
,'S92513D'
,'S92513G'
,'S92513K'
,'S92513P'
,'S92513S'
,'S92514D'
,'S92514G'
,'S92514K'
,'S92514P'
,'S92514S'
,'S92515D'
,'S92515G'
,'S92515K'
,'S92515P'
,'S92515S'
,'S92516D'
,'S92516G'
,'S92516K'
,'S92516P'
,'S92516S'
,'S92521D'
,'S92521G'
,'S92521K'
,'S92521P'
,'S92521S'
,'S92522D'
,'S92522G'
,'S92522K'
,'S92522P'
,'S92522S'
,'S92523D'
,'S92523G'
,'S92523K'
,'S92523P'
,'S92523S'
,'S92524D'
,'S92524G'
,'S92524K'
,'S92524P'
,'S92524S'
,'S92525D'
,'S92525G'
,'S92525K'
,'S92525P'
,'S92525S'
,'S92526D'
,'S92526G'
,'S92526K'
,'S92526P'
,'S92526S'
,'S92531D'
,'S92531G'
,'S92531K'
,'S92531P'
,'S92531S'
,'S92532D'
,'S92532G'
,'S92532K'
,'S92532P'
,'S92532S'
,'S92533D'
,'S92533G'
,'S92533K'
,'S92533P'
,'S92533S'
,'S92534D'
,'S92534G'
,'S92534K'
,'S92534P'
,'S92534S'
,'S92535D'
,'S92535G'
,'S92535K'
,'S92535P'
,'S92535S'
,'S92536D'
,'S92536G'
,'S92536K'
,'S92536P'
,'S92536S'
,'S92591D'
,'S92591G'
,'S92591K'
,'S92591P'
,'S92591S'
,'S92592D'
,'S92592G'
,'S92592K'
,'S92592P'
,'S92592S'
,'S92599D'
,'S92599G'
,'S92599K'
,'S92599P'
,'S92599S'
,'S92901D'
,'S92901G'
,'S92901K'
,'S92901P'
,'S92901S'
,'S92902D'
,'S92902G'
,'S92902K'
,'S92902P'
,'S92902S'
,'S92909D'
,'S92909G'
,'S92909K'
,'S92909P'
,'S92909S'
,'S92911D'
,'S92911G'
,'S92911K'
,'S92911P'
,'S92911S'
,'S92912D'
,'S92912G'
,'S92912K'
,'S92912P'
,'S92912S'
,'S92919D'
,'S92919G'
,'S92919K'
,'S92919P'
,'S92919S'
,'S9301XD'
,'S9301XS'
,'S9302XD'
,'S9302XS'
,'S9303XD'
,'S9303XS'
,'S9304XD'
,'S9304XS'
,'S9305XD'
,'S9305XS'
,'S9306XD'
,'S9306XS'
,'S93101D'
,'S93101S'
,'S93102D'
,'S93102S'
,'S93103D'
,'S93103S'
,'S93104D'
,'S93104S'
,'S93105D'
,'S93105S'
,'S93106D'
,'S93106S'
,'S93111D'
,'S93111S'
,'S93112D'
,'S93112S'
,'S93113D'
,'S93113S'
,'S93114D'
,'S93114S'
,'S93115D'
,'S93115S'
,'S93116D'
,'S93116S'
,'S93119D'
,'S93119S'
,'S93121D'
,'S93121S'
,'S93122D'
,'S93122S'
,'S93123D'
,'S93123S'
,'S93124D'
,'S93124S'
,'S93125D'
,'S93125S'
,'S93126D'
,'S93126S'
,'S93129D'
,'S93129S'
,'S93131D'
,'S93131S'
,'S93132D'
,'S93132S'
,'S93133D'
,'S93133S'
,'S93134D'
,'S93134S'
,'S93135D'
,'S93135S'
,'S93136D'
,'S93136S'
,'S93139D'
,'S93139S'
,'S93141D'
,'S93141S'
,'S93142D'
,'S93142S'
,'S93143D'
,'S93143S'
,'S93144D'
,'S93144S'
,'S93145D'
,'S93145S'
,'S93146D'
,'S93146S'
,'S93149D'
,'S93149S'
,'S93301D'
,'S93301S'
,'S93302D'
,'S93302S'
,'S93303D'
,'S93303S'
,'S93304D'
,'S93304S'
,'S93305D'
,'S93305S'
,'S93306D'
,'S93306S'
,'S93311D'
,'S93311S'
,'S93312D'
,'S93312S'
,'S93313D'
,'S93313S'
,'S93314D'
,'S93314S'
,'S93315D'
,'S93315S'
,'S93316D'
,'S93316S'
,'S93321D'
,'S93321S'
,'S93322D'
,'S93322S'
,'S93323D'
,'S93323S'
,'S93324D'
,'S93324S'
,'S93325D'
,'S93325S'
,'S93326D'
,'S93326S'
,'S93331D'
,'S93331S'
,'S93332D'
,'S93332S'
,'S93333D'
,'S93333S'
,'S93334D'
,'S93334S'
,'S93335D'
,'S93335S'
,'S93336D'
,'S93336S'
,'S93401D'
,'S93401S'
,'S93402D'
,'S93402S'
,'S93409D'
,'S93409S'
,'S93411D'
,'S93411S'
,'S93412D'
,'S93412S'
,'S93419D'
,'S93419S'
,'S93421D'
,'S93421S'
,'S93422D'
,'S93422S'
,'S93429D'
,'S93429S'
,'S93431D'
,'S93431S'
,'S93432D'
,'S93432S'
,'S93439D'
,'S93439S'
,'S93491D'
,'S93491S'
,'S93492D'
,'S93492S'
,'S93499D'
,'S93499S'
,'S93501D'
,'S93501S'
,'S93502D'
,'S93502S'
,'S93503D'
,'S93503S'
,'S93504D'
,'S93504S'
,'S93505D'
,'S93505S'
,'S93506D'
,'S93506S'
,'S93509D'
,'S93509S'
,'S93511D'
,'S93511S'
,'S93512D'
,'S93512S'
,'S93513D'
,'S93513S'
,'S93514D'
,'S93514S'
,'S93515D'
,'S93515S'
,'S93516D'
,'S93516S'
,'S93519D'
,'S93519S'
,'S93521D'
,'S93521S'
,'S93522D'
,'S93522S'
,'S93523D'
,'S93523S'
,'S93524D'
,'S93524S'
,'S93525D'
,'S93525S'
,'S93526D'
,'S93526S'
,'S93529D'
,'S93529S'
,'S93601D'
,'S93601S'
,'S93602D'
,'S93602S'
,'S93609D'
,'S93609S'
,'S93611D'
,'S93611S'
,'S93612D'
,'S93612S'
,'S93619D'
,'S93619S'
,'S93621D'
,'S93621S'
,'S93622D'
,'S93622S'
,'S93629D'
,'S93629S'
,'S93691D'
,'S93691S'
,'S93692D'
,'S93692S'
,'S93699D'
,'S93699S'
,'S9400XD'
,'S9400XS'
,'S9401XD'
,'S9401XS'
,'S9402XD'
,'S9402XS'
,'S9410XD'
,'S9410XS'
,'S9411XD'
,'S9411XS'
,'S9412XD'
,'S9412XS'
,'S9420XD'
,'S9420XS'
,'S9421XD'
,'S9421XS'
,'S9422XD'
,'S9422XS'
,'S9430XD'
,'S9430XS'
,'S9431XD'
,'S9431XS'
,'S9432XD'
,'S9432XS'
,'S948X1D'
,'S948X1S'
,'S948X2D'
,'S948X2S'
,'S948X9D'
,'S948X9S'
,'S9490XD'
,'S9490XS'
,'S9491XD'
,'S9491XS'
,'S9492XD'
,'S9492XS'
,'S95001D'
,'S95001S'
,'S95002D'
,'S95002S'
,'S95009D'
,'S95009S'
,'S95011D'
,'S95011S'
,'S95012D'
,'S95012S'
,'S95019D'
,'S95019S'
,'S95091D'
,'S95091S'
,'S95092D'
,'S95092S'
,'S95099D'
,'S95099S'
,'S95101D'
,'S95101S'
,'S95102D'
,'S95102S'
,'S95109D'
,'S95109S'
,'S95111D'
,'S95111S'
,'S95112D'
,'S95112S'
,'S95119D'
,'S95119S'
,'S95191D'
,'S95191S'
,'S95192D'
,'S95192S'
,'S95199D'
,'S95199S'
,'S95201D'
,'S95201S'
,'S95202D'
,'S95202S'
,'S95209D'
,'S95209S'
,'S95211D'
,'S95211S'
,'S95212D'
,'S95212S'
,'S95219D'
,'S95219S'
,'S95291D'
,'S95291S'
,'S95292D'
,'S95292S'
,'S95299D'
,'S95299S'
,'S95801D'
,'S95801S'
,'S95802D'
,'S95802S'
,'S95809D'
,'S95809S'
,'S95811D'
,'S95811S'
,'S95812D'
,'S95812S'
,'S95819D'
,'S95819S'
,'S95891D'
,'S95891S'
,'S95892D'
,'S95892S'
,'S95899D'
,'S95899S'
,'S95901D'
,'S95901S'
,'S95902D'
,'S95902S'
,'S95909D'
,'S95909S'
,'S95911D'
,'S95911S'
,'S95912D'
,'S95912S'
,'S95919D'
,'S95919S'
,'S95991D'
,'S95991S'
,'S95992D'
,'S95992S'
,'S95999D'
,'S95999S'
,'S96001D'
,'S96001S'
,'S96002D'
,'S96002S'
,'S96009D'
,'S96009S'
,'S96011D'
,'S96011S'
,'S96012D'
,'S96012S'
,'S96019D'
,'S96019S'
,'S96021D'
,'S96021S'
,'S96022D'
,'S96022S'
,'S96029D'
,'S96029S'
,'S96091D'
,'S96091S'
,'S96092D'
,'S96092S'
,'S96099D'
,'S96099S'
,'S96101D'
,'S96101S'
,'S96102D'
,'S96102S'
,'S96109D'
,'S96109S'
,'S96111D'
,'S96111S'
,'S96112D'
,'S96112S'
,'S96119D'
,'S96119S'
,'S96121D'
,'S96121S'
,'S96122D'
,'S96122S'
,'S96129D'
,'S96129S'
,'S96191D'
,'S96191S'
,'S96192D'
,'S96192S'
,'S96199D'
,'S96199S'
,'S96201D'
,'S96201S'
,'S96202D'
,'S96202S'
,'S96209D'
,'S96209S'
,'S96211D'
,'S96211S'
,'S96212D'
,'S96212S'
,'S96219D'
,'S96219S'
,'S96221D'
,'S96221S'
,'S96222D'
,'S96222S'
,'S96229D'
,'S96229S'
,'S96291D'
,'S96291S'
,'S96292D'
,'S96292S'
,'S96299D'
,'S96299S'
,'S96801D'
,'S96801S'
,'S96802D'
,'S96802S'
,'S96809D'
,'S96809S'
,'S96811D'
,'S96811S'
,'S96812D'
,'S96812S'
,'S96819D'
,'S96819S'
,'S96821D'
,'S96821S'
,'S96822D'
,'S96822S'
,'S96829D'
,'S96829S'
,'S96891D'
,'S96891S'
,'S96892D'
,'S96892S'
,'S96899D'
,'S96899S'
,'S96901D'
,'S96901S'
,'S96902D'
,'S96902S'
,'S96909D'
,'S96909S'
,'S96911D'
,'S96911S'
,'S96912D'
,'S96912S'
,'S96919D'
,'S96919S'
,'S96921D'
,'S96921S'
,'S96922D'
,'S96922S'
,'S96929D'
,'S96929S'
,'S96991D'
,'S96991S'
,'S96992D'
,'S96992S'
,'S96999D'
,'S96999S'
,'S9700XD'
,'S9700XS'
,'S9701XD'
,'S9701XS'
,'S9702XD'
,'S9702XS'
,'S97101D'
,'S97101S'
,'S97102D'
,'S97102S'
,'S97109D'
,'S97109S'
,'S97111D'
,'S97111S'
,'S97112D'
,'S97112S'
,'S97119D'
,'S97119S'
,'S97121D'
,'S97121S'
,'S97122D'
,'S97122S'
,'S97129D'
,'S97129S'
,'S9780XD'
,'S9780XS'
,'S9781XD'
,'S9781XS'
,'S9782XD'
,'S9782XS'
,'S98011D'
,'S98011S'
,'S98012D'
,'S98012S'
,'S98019D'
,'S98019S'
,'S98021D'
,'S98021S'
,'S98022D'
,'S98022S'
,'S98029D'
,'S98029S'
,'S98111D'
,'S98111S'
,'S98112D'
,'S98112S'
,'S98119D'
,'S98119S'
,'S98121D'
,'S98121S'
,'S98122D'
,'S98122S'
,'S98129D'
,'S98129S'
,'S98131D'
,'S98131S'
,'S98132D'
,'S98132S'
,'S98139D'
,'S98139S'
,'S98141D'
,'S98141S'
,'S98142D'
,'S98142S'
,'S98149D'
,'S98149S'
,'S98211D'
,'S98211S'
,'S98212D'
,'S98212S'
,'S98219D'
,'S98219S'
,'S98221D'
,'S98221S'
,'S98222D'
,'S98222S'
,'S98229D'
,'S98229S'
,'S98311D'
,'S98311S'
,'S98312D'
,'S98312S'
,'S98319D'
,'S98319S'
,'S98321D'
,'S98321S'
,'S98322D'
,'S98322S'
,'S98329D'
,'S98329S'
,'S98911D'
,'S98911S'
,'S98912D'
,'S98912S'
,'S98919D'
,'S98919S'
,'S98921D'
,'S98921S'
,'S98922D'
,'S98922S'
,'S98929D'
,'S98929S'
,'S99811D'
,'S99811S'
,'S99812D'
,'S99812S'
,'S99819D'
,'S99819S'
,'S99821D'
,'S99821S'
,'S99822D'
,'S99822S'
,'S99829D'
,'S99829S'
,'S99911D'
,'S99911S'
,'S99912D'
,'S99912S'
,'S99919D'
,'S99919S'
,'S99921D'
,'S99921S'
,'S99922D'
,'S99922S'
,'S99929D'
,'S99929S'
,'T07'
,'T148'
,'T1490'
,'T1491'
,'T1500XD'
,'T1500XS'
,'T1501XD'
,'T1501XS'
,'T1502XD'
,'T1502XS'
,'T1510XD'
,'T1510XS'
,'T1511XD'
,'T1511XS'
,'T1512XD'
,'T1512XS'
,'T1580XD'
,'T1580XS'
,'T1581XD'
,'T1581XS'
,'T1582XD'
,'T1582XS'
,'T1590XD'
,'T1590XS'
,'T1591XD'
,'T1591XS'
,'T1592XD'
,'T1592XS'
,'T161XXD'
,'T161XXS'
,'T162XXD'
,'T162XXS'
,'T169XXD'
,'T169XXS'
,'T170XXD'
,'T170XXS'
,'T171XXD'
,'T171XXS'
,'T17200D'
,'T17200S'
,'T17208D'
,'T17208S'
,'T17210D'
,'T17210S'
,'T17218D'
,'T17218S'
,'T17220D'
,'T17220S'
,'T17228D'
,'T17228S'
,'T17290D'
,'T17290S'
,'T17298D'
,'T17298S'
,'T17300D'
,'T17300S'
,'T17308D'
,'T17308S'
,'T17310D'
,'T17310S'
,'T17318D'
,'T17318S'
,'T17320D'
,'T17320S'
,'T17328D'
,'T17328S'
,'T17390D'
,'T17390S'
,'T17398D'
,'T17398S'
,'T17400D'
,'T17400S'
,'T17408D'
,'T17408S'
,'T17410D'
,'T17410S'
,'T17418D'
,'T17418S'
,'T17420D'
,'T17420S'
,'T17428D'
,'T17428S'
,'T17490D'
,'T17490S'
,'T17498D'
,'T17498S'
,'T17500D'
,'T17500S'
,'T17508D'
,'T17508S'
,'T17510D'
,'T17510S'
,'T17518D'
,'T17518S'
,'T17520D'
,'T17520S'
,'T17528D'
,'T17528S'
,'T17590D'
,'T17590S'
,'T17598D'
,'T17598S'
,'T17800D'
,'T17800S'
,'T17808D'
,'T17808S'
,'T17810D'
,'T17810S'
,'T17818D'
,'T17818S'
,'T17820D'
,'T17820S'
,'T17828D'
,'T17828S'
,'T17890D'
,'T17890S'
,'T17898D'
,'T17898S'
,'T17900D'
,'T17900S'
,'T17908D'
,'T17908S'
,'T17910D'
,'T17910S'
,'T17918D'
,'T17918S'
,'T17920D'
,'T17920S'
,'T17928D'
,'T17928S'
,'T17990D'
,'T17990S'
,'T17998D'
,'T17998S'
,'T180XXD'
,'T180XXS'
,'T18100D'
,'T18100S'
,'T18108D'
,'T18108S'
,'T18110D'
,'T18110S'
,'T18118D'
,'T18118S'
,'T18120D'
,'T18120S'
,'T18128D'
,'T18128S'
,'T18190D'
,'T18190S'
,'T18198D'
,'T18198S'
,'T182XXD'
,'T182XXS'
,'T183XXD'
,'T183XXS'
,'T184XXD'
,'T184XXS'
,'T185XXD'
,'T185XXS'
,'T188XXD'
,'T188XXS'
,'T189XXD'
,'T189XXS'
,'T190XXD'
,'T190XXS'
,'T191XXD'
,'T191XXS'
,'T192XXD'
,'T192XXS'
,'T193XXD'
,'T193XXS'
,'T194XXD'
,'T194XXS'
,'T198XXD'
,'T198XXS'
,'T199XXD'
,'T199XXS'
,'T2000XD'
,'T2000XS'
,'T20011D'
,'T20011S'
,'T20012D'
,'T20012S'
,'T20019D'
,'T20019S'
,'T2002XD'
,'T2002XS'
,'T2003XD'
,'T2003XS'
,'T2004XD'
,'T2004XS'
,'T2005XD'
,'T2005XS'
,'T2006XD'
,'T2006XS'
,'T2007XD'
,'T2007XS'
,'T2009XD'
,'T2009XS'
,'T2010XD'
,'T2010XS'
,'T20111D'
,'T20111S'
,'T20112D'
,'T20112S'
,'T20119D'
,'T20119S'
,'T2012XD'
,'T2012XS'
,'T2013XD'
,'T2013XS'
,'T2014XD'
,'T2014XS'
,'T2015XD'
,'T2015XS'
,'T2016XD'
,'T2016XS'
,'T2017XD'
,'T2017XS'
,'T2019XD'
,'T2019XS'
,'T2020XD'
,'T2020XS'
,'T20211D'
,'T20211S'
,'T20212D'
,'T20212S'
,'T20219D'
,'T20219S'
,'T2022XD'
,'T2022XS'
,'T2023XD'
,'T2023XS'
,'T2024XD'
,'T2024XS'
,'T2025XD'
,'T2025XS'
,'T2026XD'
,'T2026XS'
,'T2027XD'
,'T2027XS'
,'T2029XD'
,'T2029XS'
,'T2030XD'
,'T2030XS'
,'T20311D'
,'T20311S'
,'T20312D'
,'T20312S'
,'T20319D'
,'T20319S'
,'T2032XD'
,'T2032XS'
,'T2033XD'
,'T2033XS'
,'T2034XD'
,'T2034XS'
,'T2035XD'
,'T2035XS'
,'T2036XD'
,'T2036XS'
,'T2037XD'
,'T2037XS'
,'T2039XD'
,'T2039XS'
,'T2040XD'
,'T2040XS'
,'T20411D'
,'T20411S'
,'T20412D'
,'T20412S'
,'T20419D'
,'T20419S'
,'T2042XD'
,'T2042XS'
,'T2043XD'
,'T2043XS'
,'T2044XD'
,'T2044XS'
,'T2045XD'
,'T2045XS'
,'T2046XD'
,'T2046XS'
,'T2047XD'
,'T2047XS'
,'T2049XD'
,'T2049XS'
,'T2050XD'
,'T2050XS'
,'T20511D'
,'T20511S'
,'T20512D'
,'T20512S'
,'T20519D'
,'T20519S'
,'T2052XD'
,'T2052XS'
,'T2053XD'
,'T2053XS'
,'T2054XD'
,'T2054XS'
,'T2055XD'
,'T2055XS'
,'T2056XD'
,'T2056XS'
,'T2057XD'
,'T2057XS'
,'T2059XD'
,'T2059XS'
,'T2060XD'
,'T2060XS'
,'T20611D'
,'T20611S'
,'T20612D'
,'T20612S'
,'T20619D'
,'T20619S'
,'T2062XD'
,'T2062XS'
,'T2063XD'
,'T2063XS'
,'T2064XD'
,'T2064XS'
,'T2065XD'
,'T2065XS'
,'T2066XD'
,'T2066XS'
,'T2067XD'
,'T2067XS'
,'T2069XD'
,'T2069XS'
,'T2070XD'
,'T2070XS'
,'T20711D'
,'T20711S'
,'T20712D'
,'T20712S'
,'T20719D'
,'T20719S'
,'T2072XD'
,'T2072XS'
,'T2073XD'
,'T2073XS'
,'T2074XD'
,'T2074XS'
,'T2075XD'
,'T2075XS'
,'T2076XD'
,'T2076XS'
,'T2077XD'
,'T2077XS'
,'T2079XD'
,'T2079XS'
,'T2100XD'
,'T2100XS'
,'T2101XD'
,'T2101XS'
,'T2102XD'
,'T2102XS'
,'T2103XD'
,'T2103XS'
,'T2104XD'
,'T2104XS'
,'T2105XD'
,'T2105XS'
,'T2106XD'
,'T2106XS'
,'T2107XD'
,'T2107XS'
,'T2109XD'
,'T2109XS'
,'T2110XD'
,'T2110XS'
,'T2111XD'
,'T2111XS'
,'T2112XD'
,'T2112XS'
,'T2113XD'
,'T2113XS'
,'T2114XD'
,'T2114XS'
,'T2115XD'
,'T2115XS'
,'T2116XD'
,'T2116XS'
,'T2117XD'
,'T2117XS'
,'T2119XD'
,'T2119XS'
,'T2120XD'
,'T2120XS'
,'T2121XD'
,'T2121XS'
,'T2122XD'
,'T2122XS'
,'T2123XD'
,'T2123XS'
,'T2124XD'
,'T2124XS'
,'T2125XD'
,'T2125XS'
,'T2126XD'
,'T2126XS'
,'T2127XD'
,'T2127XS'
,'T2129XD'
,'T2129XS'
,'T2130XD'
,'T2130XS'
,'T2131XD'
,'T2131XS'
,'T2132XD'
,'T2132XS'
,'T2133XD'
,'T2133XS'
,'T2134XD'
,'T2134XS'
,'T2135XD'
,'T2135XS'
,'T2136XD'
,'T2136XS'
,'T2137XD'
,'T2137XS'
,'T2139XD'
,'T2139XS'
,'T2140XD'
,'T2140XS'
,'T2141XD'
,'T2141XS'
,'T2142XD'
,'T2142XS'
,'T2143XD'
,'T2143XS'
,'T2144XD'
,'T2144XS'
,'T2145XD'
,'T2145XS'
,'T2146XD'
,'T2146XS'
,'T2147XD'
,'T2147XS'
,'T2149XD'
,'T2149XS'
,'T2150XD'
,'T2150XS'
,'T2151XD'
,'T2151XS'
,'T2152XD'
,'T2152XS'
,'T2153XD'
,'T2153XS'
,'T2154XD'
,'T2154XS'
,'T2155XD'
,'T2155XS'
,'T2156XD'
,'T2156XS'
,'T2157XD'
,'T2157XS'
,'T2159XD'
,'T2159XS'
,'T2160XD'
,'T2160XS'
,'T2161XD'
,'T2161XS'
,'T2162XD'
,'T2162XS'
,'T2163XD'
,'T2163XS'
,'T2164XD'
,'T2164XS'
,'T2165XD'
,'T2165XS'
,'T2166XD'
,'T2166XS'
,'T2167XD'
,'T2167XS'
,'T2169XD'
,'T2169XS'
,'T2170XD'
,'T2170XS'
,'T2171XD'
,'T2171XS'
,'T2172XD'
,'T2172XS'
,'T2173XD'
,'T2173XS'
,'T2174XD'
,'T2174XS'
,'T2175XD'
,'T2175XS'
,'T2176XD'
,'T2176XS'
,'T2177XD'
,'T2177XS'
,'T2179XD'
,'T2179XS'
,'T2200XD'
,'T2200XS'
,'T22011D'
,'T22011S'
,'T22012D'
,'T22012S'
,'T22019D'
,'T22019S'
,'T22021D'
,'T22021S'
,'T22022D'
,'T22022S'
,'T22029D'
,'T22029S'
,'T22031D'
,'T22031S'
,'T22032D'
,'T22032S'
,'T22039D'
,'T22039S'
,'T22041D'
,'T22041S'
,'T22042D'
,'T22042S'
,'T22049D'
,'T22049S'
,'T22051D'
,'T22051S'
,'T22052D'
,'T22052S'
,'T22059D'
,'T22059S'
,'T22061D'
,'T22061S'
,'T22062D'
,'T22062S'
,'T22069D'
,'T22069S'
,'T22091D'
,'T22091S'
,'T22092D'
,'T22092S'
,'T22099D'
,'T22099S'
,'T2210XD'
,'T2210XS'
,'T22111D'
,'T22111S'
,'T22112D'
,'T22112S'
,'T22119D'
,'T22119S'
,'T22121D'
,'T22121S'
,'T22122D'
,'T22122S'
,'T22129D'
,'T22129S'
,'T22131D'
,'T22131S'
,'T22132D'
,'T22132S'
,'T22139D'
,'T22139S'
,'T22141D'
,'T22141S'
,'T22142D'
,'T22142S'
,'T22149D'
,'T22149S'
,'T22151D'
,'T22151S'
,'T22152D'
,'T22152S'
,'T22159D'
,'T22159S'
,'T22161D'
,'T22161S'
,'T22162D'
,'T22162S'
,'T22169D'
,'T22169S'
,'T22191D'
,'T22191S'
,'T22192D'
,'T22192S'
,'T22199D'
,'T22199S'
,'T2220XD'
,'T2220XS'
,'T22211D'
,'T22211S'
,'T22212D'
,'T22212S'
,'T22219D'
,'T22219S'
,'T22221D'
,'T22221S'
,'T22222D'
,'T22222S'
,'T22229D'
,'T22229S'
,'T22231D'
,'T22231S'
,'T22232D'
,'T22232S'
,'T22239D'
,'T22239S'
,'T22241D'
,'T22241S'
,'T22242D'
,'T22242S'
,'T22249D'
,'T22249S'
,'T22251D'
,'T22251S'
,'T22252D'
,'T22252S'
,'T22259D'
,'T22259S'
,'T22261D'
,'T22261S'
,'T22262D'
,'T22262S'
,'T22269D'
,'T22269S'
,'T22291D'
,'T22291S'
,'T22292D'
,'T22292S'
,'T22299D'
,'T22299S'
,'T2230XD'
,'T2230XS'
,'T22311D'
,'T22311S'
,'T22312D'
,'T22312S'
,'T22319D'
,'T22319S'
,'T22321D'
,'T22321S'
,'T22322D'
,'T22322S'
,'T22329D'
,'T22329S'
,'T22331D'
,'T22331S'
,'T22332D'
,'T22332S'
,'T22339D'
,'T22339S'
,'T22341D'
,'T22341S'
,'T22342D'
,'T22342S'
,'T22349D'
,'T22349S'
,'T22351D'
,'T22351S'
,'T22352D'
,'T22352S'
,'T22359D'
,'T22359S'
,'T22361D'
,'T22361S'
,'T22362D'
,'T22362S'
,'T22369D'
,'T22369S'
,'T22391D'
,'T22391S'
,'T22392D'
,'T22392S'
,'T22399D'
,'T22399S'
,'T2240XD'
,'T2240XS'
,'T22411D'
,'T22411S'
,'T22412D'
,'T22412S'
,'T22419D'
,'T22419S'
,'T22421D'
,'T22421S'
,'T22422D'
,'T22422S'
,'T22429D'
,'T22429S'
,'T22431D'
,'T22431S'
,'T22432D'
,'T22432S'
,'T22439D'
,'T22439S'
,'T22441D'
,'T22441S'
,'T22442D'
,'T22442S'
,'T22449D'
,'T22449S'
,'T22451D'
,'T22451S'
,'T22452D'
,'T22452S'
,'T22459D'
,'T22459S'
,'T22461D'
,'T22461S'
,'T22462D'
,'T22462S'
,'T22469D'
,'T22469S'
,'T22491D'
,'T22491S'
,'T22492D'
,'T22492S'
,'T22499D'
,'T22499S'
,'T2250XD'
,'T2250XS'
,'T22511D'
,'T22511S'
,'T22512D'
,'T22512S'
,'T22519D'
,'T22519S'
,'T22521D'
,'T22521S'
,'T22522D'
,'T22522S'
,'T22529D'
,'T22529S'
,'T22531D'
,'T22531S'
,'T22532D'
,'T22532S'
,'T22539D'
,'T22539S'
,'T22541D'
,'T22541S'
,'T22542D'
,'T22542S'
,'T22549D'
,'T22549S'
,'T22551D'
,'T22551S'
,'T22552D'
,'T22552S'
,'T22559D'
,'T22559S'
,'T22561D'
,'T22561S'
,'T22562D'
,'T22562S'
,'T22569D'
,'T22569S'
,'T22591D'
,'T22591S'
,'T22592D'
,'T22592S'
,'T22599D'
,'T22599S'
,'T2260XD'
,'T2260XS'
,'T22611D'
,'T22611S'
,'T22612D'
,'T22612S'
,'T22619D'
,'T22619S'
,'T22621D'
,'T22621S'
,'T22622D'
,'T22622S'
,'T22629D'
,'T22629S'
,'T22631D'
,'T22631S'
,'T22632D'
,'T22632S'
,'T22639D'
,'T22639S'
,'T22641D'
,'T22641S'
,'T22642D'
,'T22642S'
,'T22649D'
,'T22649S'
,'T22651D'
,'T22651S'
,'T22652D'
,'T22652S'
,'T22659D'
,'T22659S'
,'T22661D'
,'T22661S'
,'T22662D'
,'T22662S'
,'T22669D'
,'T22669S'
,'T22691D'
,'T22691S'
,'T22692D'
,'T22692S'
,'T22699D'
,'T22699S'
,'T2270XD'
,'T2270XS'
,'T22711D'
,'T22711S'
,'T22712D'
,'T22712S'
,'T22719D'
,'T22719S'
,'T22721D'
,'T22721S'
,'T22722D'
,'T22722S'
,'T22729D'
,'T22729S'
,'T22731D'
,'T22731S'
,'T22732D'
,'T22732S'
,'T22739D'
,'T22739S'
,'T22741D'
,'T22741S'
,'T22742D'
,'T22742S'
,'T22749D'
,'T22749S'
,'T22751D'
,'T22751S'
,'T22752D'
,'T22752S'
,'T22759D'
,'T22759S'
,'T22761D'
,'T22761S'
,'T22762D'
,'T22762S'
,'T22769D'
,'T22769S'
,'T22791D'
,'T22791S'
,'T22792D'
,'T22792S'
,'T22799D'
,'T22799S'
,'T23001D'
,'T23001S'
,'T23002D'
,'T23002S'
,'T23009D'
,'T23009S'
,'T23011D'
,'T23011S'
,'T23012D'
,'T23012S'
,'T23019D'
,'T23019S'
,'T23021D'
,'T23021S'
,'T23022D'
,'T23022S'
,'T23029D'
,'T23029S'
,'T23031D'
,'T23031S'
,'T23032D'
,'T23032S'
,'T23039D'
,'T23039S'
,'T23041D'
,'T23041S'
,'T23042D'
,'T23042S'
,'T23049D'
,'T23049S'
,'T23051D'
,'T23051S'
,'T23052D'
,'T23052S'
,'T23059D'
,'T23059S'
,'T23061D'
,'T23061S'
,'T23062D'
,'T23062S'
,'T23069D'
,'T23069S'
,'T23071D'
,'T23071S'
,'T23072D'
,'T23072S'
,'T23079D'
,'T23079S'
,'T23091D'
,'T23091S'
,'T23092D'
,'T23092S'
,'T23099D'
,'T23099S'
,'T23101D'
,'T23101S'
,'T23102D'
,'T23102S'
,'T23109D'
,'T23109S'
,'T23111D'
,'T23111S'
,'T23112D'
,'T23112S'
,'T23119D'
,'T23119S'
,'T23121D'
,'T23121S'
,'T23122D'
,'T23122S'
,'T23129D'
,'T23129S'
,'T23131D'
,'T23131S'
,'T23132D'
,'T23132S'
,'T23139D'
,'T23139S'
,'T23141D'
,'T23141S'
,'T23142D'
,'T23142S'
,'T23149D'
,'T23149S'
,'T23151D'
,'T23151S'
,'T23152D'
,'T23152S'
,'T23159D'
,'T23159S'
,'T23161D'
,'T23161S'
,'T23162D'
,'T23162S'
,'T23169D'
,'T23169S'
,'T23171D'
,'T23171S'
,'T23172D'
,'T23172S'
,'T23179D'
,'T23179S'
,'T23191D'
,'T23191S'
,'T23192D'
,'T23192S'
,'T23199D'
,'T23199S'
,'T23201D'
,'T23201S'
,'T23202D'
,'T23202S'
,'T23209D'
,'T23209S'
,'T23211D'
,'T23211S'
,'T23212D'
,'T23212S'
,'T23219D'
,'T23219S'
,'T23221D'
,'T23221S'
,'T23222D'
,'T23222S'
,'T23229D'
,'T23229S'
,'T23231D'
,'T23231S'
,'T23232D'
,'T23232S'
,'T23239D'
,'T23239S'
,'T23241D'
,'T23241S'
,'T23242D'
,'T23242S'
,'T23249D'
,'T23249S'
,'T23251D'
,'T23251S'
,'T23252D'
,'T23252S'
,'T23259D'
,'T23259S'
,'T23261D'
,'T23261S'
,'T23262D'
,'T23262S'
,'T23269D'
,'T23269S'
,'T23271D'
,'T23271S'
,'T23272D'
,'T23272S'
,'T23279D'
,'T23279S'
,'T23291D'
,'T23291S'
,'T23292D'
,'T23292S'
,'T23299D'
,'T23299S'
,'T23301D'
,'T23301S'
,'T23302D'
,'T23302S'
,'T23309D'
,'T23309S'
,'T23311D'
,'T23311S'
,'T23312D'
,'T23312S'
,'T23319D'
,'T23319S'
,'T23321D'
,'T23321S'
,'T23322D'
,'T23322S'
,'T23329D'
,'T23329S'
,'T23331D'
,'T23331S'
,'T23332D'
,'T23332S'
,'T23339D'
,'T23339S'
,'T23341D'
,'T23341S'
,'T23342D'
,'T23342S'
,'T23349D'
,'T23349S'
,'T23351D'
,'T23351S'
,'T23352D'
,'T23352S'
,'T23359D'
,'T23359S'
,'T23361D'
,'T23361S'
,'T23362D'
,'T23362S'
,'T23369D'
,'T23369S'
,'T23371D'
,'T23371S'
,'T23372D'
,'T23372S'
,'T23379D'
,'T23379S'
,'T23391D'
,'T23391S'
,'T23392D'
,'T23392S'
,'T23399D'
,'T23399S'
,'T23401D'
,'T23401S'
,'T23402D'
,'T23402S'
,'T23409D'
,'T23409S'
,'T23411D'
,'T23411S'
,'T23412D'
,'T23412S'
,'T23419D'
,'T23419S'
,'T23421D'
,'T23421S'
,'T23422D'
,'T23422S'
,'T23429D'
,'T23429S'
,'T23431D'
,'T23431S'
,'T23432D'
,'T23432S'
,'T23439D'
,'T23439S'
,'T23441D'
,'T23441S'
,'T23442D'
,'T23442S'
,'T23449D'
,'T23449S'
,'T23451D'
,'T23451S'
,'T23452D'
,'T23452S'
,'T23459D'
,'T23459S'
,'T23461D'
,'T23461S'
,'T23462D'
,'T23462S'
,'T23469D'
,'T23469S'
,'T23471D'
,'T23471S'
,'T23472D'
,'T23472S'
,'T23479D'
,'T23479S'
,'T23491D'
,'T23491S'
,'T23492D'
,'T23492S'
,'T23499D'
,'T23499S'
,'T23501D'
,'T23501S'
,'T23502D'
,'T23502S'
,'T23509D'
,'T23509S'
,'T23511D'
,'T23511S'
,'T23512D'
,'T23512S'
,'T23519D'
,'T23519S'
,'T23521D'
,'T23521S'
,'T23522D'
,'T23522S'
,'T23529D'
,'T23529S'
,'T23531D'
,'T23531S'
,'T23532D'
,'T23532S'
,'T23539D'
,'T23539S'
,'T23541D'
,'T23541S'
,'T23542D'
,'T23542S'
,'T23549D'
,'T23549S'
,'T23551D'
,'T23551S'
,'T23552D'
,'T23552S'
,'T23559D'
,'T23559S'
,'T23561D'
,'T23561S'
,'T23562D'
,'T23562S'
,'T23569D'
,'T23569S'
,'T23571D'
,'T23571S'
,'T23572D'
,'T23572S'
,'T23579D'
,'T23579S'
,'T23591D'
,'T23591S'
,'T23592D'
,'T23592S'
,'T23599D'
,'T23599S'
,'T23601D'
,'T23601S'
,'T23602D'
,'T23602S'
,'T23609D'
,'T23609S'
,'T23611D'
,'T23611S'
,'T23612D'
,'T23612S'
,'T23619D'
,'T23619S'
,'T23621D'
,'T23621S'
,'T23622D'
,'T23622S'
,'T23629D'
,'T23629S'
,'T23631D'
,'T23631S'
,'T23632D'
,'T23632S'
,'T23639D'
,'T23639S'
,'T23641D'
,'T23641S'
,'T23642D'
,'T23642S'
,'T23649D'
,'T23649S'
,'T23651D'
,'T23651S'
,'T23652D'
,'T23652S'
,'T23659D'
,'T23659S'
,'T23661D'
,'T23661S'
,'T23662D'
,'T23662S'
,'T23669D'
,'T23669S'
,'T23671D'
,'T23671S'
,'T23672D'
,'T23672S'
,'T23679D'
,'T23679S'
,'T23691D'
,'T23691S'
,'T23692D'
,'T23692S'
,'T23699D'
,'T23699S'
,'T23701D'
,'T23701S'
,'T23702D'
,'T23702S'
,'T23709D'
,'T23709S'
,'T23711D'
,'T23711S'
,'T23712D'
,'T23712S'
,'T23719D'
,'T23719S'
,'T23721D'
,'T23721S'
,'T23722D'
,'T23722S'
,'T23729D'
,'T23729S'
,'T23731D'
,'T23731S'
,'T23732D'
,'T23732S'
,'T23739D'
,'T23739S'
,'T23741D'
,'T23741S'
,'T23742D'
,'T23742S'
,'T23749D'
,'T23749S'
,'T23751D'
,'T23751S'
,'T23752D'
,'T23752S'
,'T23759D'
,'T23759S'
,'T23761D'
,'T23761S'
,'T23762D'
,'T23762S'
,'T23769D'
,'T23769S'
,'T23771D'
,'T23771S'
,'T23772D'
,'T23772S'
,'T23779D'
,'T23779S'
,'T23791D'
,'T23791S'
,'T23792D'
,'T23792S'
,'T23799D'
,'T23799S'
,'T24001D'
,'T24001S'
,'T24002D'
,'T24002S'
,'T24009D'
,'T24009S'
,'T24011D'
,'T24011S'
,'T24012D'
,'T24012S'
,'T24019D'
,'T24019S'
,'T24021D'
,'T24021S'
,'T24022D'
,'T24022S'
,'T24029D'
,'T24029S'
,'T24031D'
,'T24031S'
,'T24032D'
,'T24032S'
,'T24039D'
,'T24039S'
,'T24091D'
,'T24091S'
,'T24092D'
,'T24092S'
,'T24099D'
,'T24099S'
,'T24101D'
,'T24101S'
,'T24102D'
,'T24102S'
,'T24109D'
,'T24109S'
,'T24111D'
,'T24111S'
,'T24112D'
,'T24112S'
,'T24119D'
,'T24119S'
,'T24121D'
,'T24121S'
,'T24122D'
,'T24122S'
,'T24129D'
,'T24129S'
,'T24131D'
,'T24131S'
,'T24132D'
,'T24132S'
,'T24139D'
,'T24139S'
,'T24191D'
,'T24191S'
,'T24192D'
,'T24192S'
,'T24199D'
,'T24199S'
,'T24201D'
,'T24201S'
,'T24202D'
,'T24202S'
,'T24209D'
,'T24209S'
,'T24211D'
,'T24211S'
,'T24212D'
,'T24212S'
,'T24219D'
,'T24219S'
,'T24221D'
,'T24221S'
,'T24222D'
,'T24222S'
,'T24229D'
,'T24229S'
,'T24231D'
,'T24231S'
,'T24232D'
,'T24232S'
,'T24239D'
,'T24239S'
,'T24291D'
,'T24291S'
,'T24292D'
,'T24292S'
,'T24299D'
,'T24299S'
,'T24301D'
,'T24301S'
,'T24302D'
,'T24302S'
,'T24309D'
,'T24309S'
,'T24311D'
,'T24311S'
,'T24312D'
,'T24312S'
,'T24319D'
,'T24319S'
,'T24321D'
,'T24321S'
,'T24322D'
,'T24322S'
,'T24329D'
,'T24329S'
,'T24331D'
,'T24331S'
,'T24332D'
,'T24332S'
,'T24339D'
,'T24339S'
,'T24391D'
,'T24391S'
,'T24392D'
,'T24392S'
,'T24399D'
,'T24399S'
,'T24401D'
,'T24401S'
,'T24402D'
,'T24402S'
,'T24409D'
,'T24409S'
,'T24411D'
,'T24411S'
,'T24412D'
,'T24412S'
,'T24419D'
,'T24419S'
,'T24421D'
,'T24421S'
,'T24422D'
,'T24422S'
,'T24429D'
,'T24429S'
,'T24431D'
,'T24431S'
,'T24432D'
,'T24432S'
,'T24439D'
,'T24439S'
,'T24491D'
,'T24491S'
,'T24492D'
,'T24492S'
,'T24499D'
,'T24499S'
,'T24501D'
,'T24501S'
,'T24502D'
,'T24502S'
,'T24509D'
,'T24509S'
,'T24511D'
,'T24511S'
,'T24512D'
,'T24512S'
,'T24519D'
,'T24519S'
,'T24521D'
,'T24521S'
,'T24522D'
,'T24522S'
,'T24529D'
,'T24529S'
,'T24531D'
,'T24531S'
,'T24532D'
,'T24532S'
,'T24539D'
,'T24539S'
,'T24591D'
,'T24591S'
,'T24592D'
,'T24592S'
,'T24599D'
,'T24599S'
,'T24601D'
,'T24601S'
,'T24602D'
,'T24602S'
,'T24609D'
,'T24609S'
,'T24611D'
,'T24611S'
,'T24612D'
,'T24612S'
,'T24619D'
,'T24619S'
,'T24621D'
,'T24621S'
,'T24622D'
,'T24622S'
,'T24629D'
,'T24629S'
,'T24631D'
,'T24631S'
,'T24632D'
,'T24632S'
,'T24639D'
,'T24639S'
,'T24691D'
,'T24691S'
,'T24692D'
,'T24692S'
,'T24699D'
,'T24699S'
,'T24701D'
,'T24701S'
,'T24702D'
,'T24702S'
,'T24709D'
,'T24709S'
,'T24711D'
,'T24711S'
,'T24712D'
,'T24712S'
,'T24719D'
,'T24719S'
,'T24721D'
,'T24721S'
,'T24722D'
,'T24722S'
,'T24729D'
,'T24729S'
,'T24731D'
,'T24731S'
,'T24732D'
,'T24732S'
,'T24739D'
,'T24739S'
,'T24791D'
,'T24791S'
,'T24792D'
,'T24792S'
,'T24799D'
,'T24799S'
,'T25011D'
,'T25011S'
,'T25012D'
,'T25012S'
,'T25019D'
,'T25019S'
,'T25021D'
,'T25021S'
,'T25022D'
,'T25022S'
,'T25029D'
,'T25029S'
,'T25031D'
,'T25031S'
,'T25032D'
,'T25032S'
,'T25039D'
,'T25039S'
,'T25091D'
,'T25091S'
,'T25092D'
,'T25092S'
,'T25099D'
,'T25099S'
,'T25111D'
,'T25111S'
,'T25112D'
,'T25112S'
,'T25119D'
,'T25119S'
,'T25121D'
,'T25121S'
,'T25122D'
,'T25122S'
,'T25129D'
,'T25129S'
,'T25131D'
,'T25131S'
,'T25132D'
,'T25132S'
,'T25139D'
,'T25139S'
,'T25191D'
,'T25191S'
,'T25192D'
,'T25192S'
,'T25199D'
,'T25199S'
,'T25211D'
,'T25211S'
,'T25212D'
,'T25212S'
,'T25219D'
,'T25219S'
,'T25221D'
,'T25221S'
,'T25222D'
,'T25222S'
,'T25229D'
,'T25229S'
,'T25231D'
,'T25231S'
,'T25232D'
,'T25232S'
,'T25239D'
,'T25239S'
,'T25291D'
,'T25291S'
,'T25292D'
,'T25292S'
,'T25299D'
,'T25299S'
,'T25311D'
,'T25311S'
,'T25312D'
,'T25312S'
,'T25319D'
,'T25319S'
,'T25321D'
,'T25321S'
,'T25322D'
,'T25322S'
,'T25329D'
,'T25329S'
,'T25331D'
,'T25331S'
,'T25332D'
,'T25332S'
,'T25339D'
,'T25339S'
,'T25391D'
,'T25391S'
,'T25392D'
,'T25392S'
,'T25399D'
,'T25399S'
,'T25411D'
,'T25411S'
,'T25412D'
,'T25412S'
,'T25419D'
,'T25419S'
,'T25421D'
,'T25421S'
,'T25422D'
,'T25422S'
,'T25429D'
,'T25429S'
,'T25431D'
,'T25431S'
,'T25432D'
,'T25432S'
,'T25439D'
,'T25439S'
,'T25491D'
,'T25491S'
,'T25492D'
,'T25492S'
,'T25499D'
,'T25499S'
,'T25511D'
,'T25511S'
,'T25512D'
,'T25512S'
,'T25519D'
,'T25519S'
,'T25521D'
,'T25521S'
,'T25522D'
,'T25522S'
,'T25529D'
,'T25529S'
,'T25531D'
,'T25531S'
,'T25532D'
,'T25532S'
,'T25539D'
,'T25539S'
,'T25591D'
,'T25591S'
,'T25592D'
,'T25592S'
,'T25599D'
,'T25599S'
,'T25611D'
,'T25611S'
,'T25612D'
,'T25612S'
,'T25619D'
,'T25619S'
,'T25621D'
,'T25621S'
,'T25622D'
,'T25622S'
,'T25629D'
,'T25629S'
,'T25631D'
,'T25631S'
,'T25632D'
,'T25632S'
,'T25639D'
,'T25639S'
,'T25691D'
,'T25691S'
,'T25692D'
,'T25692S'
,'T25699D'
,'T25699S'
,'T25711D'
,'T25711S'
,'T25712D'
,'T25712S'
,'T25719D'
,'T25719S'
,'T25721D'
,'T25721S'
,'T25722D'
,'T25722S'
,'T25729D'
,'T25729S'
,'T25731D'
,'T25731S'
,'T25732D'
,'T25732S'
,'T25739D'
,'T25739S'
,'T25791D'
,'T25791S'
,'T25792D'
,'T25792S'
,'T25799D'
,'T25799S'
,'T2600XD'
,'T2600XS'
,'T2601XD'
,'T2601XS'
,'T2602XD'
,'T2602XS'
,'T2610XD'
,'T2610XS'
,'T2611XD'
,'T2611XS'
,'T2612XD'
,'T2612XS'
,'T2620XD'
,'T2620XS'
,'T2621XD'
,'T2621XS'
,'T2622XD'
,'T2622XS'
,'T2630XD'
,'T2630XS'
,'T2631XD'
,'T2631XS'
,'T2632XD'
,'T2632XS'
,'T2640XD'
,'T2640XS'
,'T2641XD'
,'T2641XS'
,'T2642XD'
,'T2642XS'
,'T2650XD'
,'T2650XS'
,'T2651XD'
,'T2651XS'
,'T2652XD'
,'T2652XS'
,'T2660XD'
,'T2660XS'
,'T2661XD'
,'T2661XS'
,'T2662XD'
,'T2662XS'
,'T2670XD'
,'T2670XS'
,'T2671XD'
,'T2671XS'
,'T2672XD'
,'T2672XS'
,'T2680XD'
,'T2680XS'
,'T2681XD'
,'T2681XS'
,'T2682XD'
,'T2682XS'
,'T2690XD'
,'T2690XS'
,'T2691XD'
,'T2691XS'
,'T2692XD'
,'T2692XS'
,'T270XXD'
,'T270XXS'
,'T271XXD'
,'T271XXS'
,'T272XXD'
,'T272XXS'
,'T273XXD'
,'T273XXS'
,'T274XXD'
,'T274XXS'
,'T275XXD'
,'T275XXS'
,'T276XXD'
,'T276XXS'
,'T277XXD'
,'T277XXS'
,'T280XXD'
,'T280XXS'
,'T281XXD'
,'T281XXS'
,'T282XXD'
,'T282XXS'
,'T283XXD'
,'T283XXS'
,'T2840XD'
,'T2840XS'
,'T28411D'
,'T28411S'
,'T28412D'
,'T28412S'
,'T28419D'
,'T28419S'
,'T2849XD'
,'T2849XS'
,'T285XXD'
,'T285XXS'
,'T286XXD'
,'T286XXS'
,'T287XXD'
,'T287XXS'
,'T288XXD'
,'T288XXS'
,'T2890XD'
,'T2890XS'
,'T28911D'
,'T28911S'
,'T28912D'
,'T28912S'
,'T28919D'
,'T28919S'
,'T2899XD'
,'T2899XS'
,'T300'
,'T304'
,'T310'
,'T3110'
,'T3111'
,'T3120'
,'T3121'
,'T3122'
,'T3130'
,'T3131'
,'T3132'
,'T3133'
,'T3140'
,'T3141'
,'T3142'
,'T3143'
,'T3144'
,'T3150'
,'T3151'
,'T3152'
,'T3153'
,'T3154'
,'T3155'
,'T3160'
,'T3161'
,'T3162'
,'T3163'
,'T3164'
,'T3165'
,'T3166'
,'T3170'
,'T3171'
,'T3172'
,'T3173'
,'T3174'
,'T3175'
,'T3176'
,'T3177'
,'T3180'
,'T3181'
,'T3182'
,'T3183'
,'T3184'
,'T3185'
,'T3186'
,'T3187'
,'T3188'
,'T3190'
,'T3191'
,'T3192'
,'T3193'
,'T3194'
,'T3195'
,'T3196'
,'T3197'
,'T3198'
,'T3199'
,'T320'
,'T3210'
,'T3211'
,'T3220'
,'T3221'
,'T3222'
,'T3230'
,'T3231'
,'T3232'
,'T3233'
,'T3240'
,'T3241'
,'T3242'
,'T3243'
,'T3244'
,'T3250'
,'T3251'
,'T3252'
,'T3253'
,'T3254'
,'T3255'
,'T3260'
,'T3261'
,'T3262'
,'T3263'
,'T3264'
,'T3265'
,'T3266'
,'T3270'
,'T3271'
,'T3272'
,'T3273'
,'T3274'
,'T3275'
,'T3276'
,'T3277'
,'T3280'
,'T3281'
,'T3282'
,'T3283'
,'T3284'
,'T3285'
,'T3286'
,'T3287'
,'T3288'
,'T3290'
,'T3291'
,'T3292'
,'T3293'
,'T3294'
,'T3295'
,'T3296'
,'T3297'
,'T3298'
,'T3299'
,'T33011D'
,'T33011S'
,'T33012D'
,'T33012S'
,'T33019D'
,'T33019S'
,'T3302XD'
,'T3302XS'
,'T3309XD'
,'T3309XS'
,'T331XXD'
,'T331XXS'
,'T332XXD'
,'T332XXS'
,'T333XXD'
,'T333XXS'
,'T3340XD'
,'T3340XS'
,'T3341XD'
,'T3341XS'
,'T3342XD'
,'T3342XS'
,'T33511D'
,'T33511S'
,'T33512D'
,'T33512S'
,'T33519D'
,'T33519S'
,'T33521D'
,'T33521S'
,'T33522D'
,'T33522S'
,'T33529D'
,'T33529S'
,'T33531D'
,'T33531S'
,'T33532D'
,'T33532S'
,'T33539D'
,'T33539S'
,'T3360XD'
,'T3360XS'
,'T3361XD'
,'T3361XS'
,'T3362XD'
,'T3362XS'
,'T3370XD'
,'T3370XS'
,'T3371XD'
,'T3371XS'
,'T3372XD'
,'T3372XS'
,'T33811D'
,'T33811S'
,'T33812D'
,'T33812S'
,'T33819D'
,'T33819S'
,'T33821D'
,'T33821S'
,'T33822D'
,'T33822S'
,'T33829D'
,'T33829S'
,'T33831D'
,'T33831S'
,'T33832D'
,'T33832S'
,'T33839D'
,'T33839S'
,'T3390XD'
,'T3390XS'
,'T3399XD'
,'T3399XS'
,'T34011D'
,'T34011S'
,'T34012D'
,'T34012S'
,'T34019D'
,'T34019S'
,'T3402XD'
,'T3402XS'
,'T3409XD'
,'T3409XS'
,'T341XXD'
,'T341XXS'
,'T342XXD'
,'T342XXS'
,'T343XXD'
,'T343XXS'
,'T3440XD'
,'T3440XS'
,'T3441XD'
,'T3441XS'
,'T3442XD'
,'T3442XS'
,'T34511D'
,'T34511S'
,'T34512D'
,'T34512S'
,'T34519D'
,'T34519S'
,'T34521D'
,'T34521S'
,'T34522D'
,'T34522S'
,'T34529D'
,'T34529S'
,'T34531D'
,'T34531S'
,'T34532D'
,'T34532S'
,'T34539D'
,'T34539S'
,'T3460XD'
,'T3460XS'
,'T3461XD'
,'T3461XS'
,'T3462XD'
,'T3462XS'
,'T3470XD'
,'T3470XS'
,'T3471XD'
,'T3471XS'
,'T3472XD'
,'T3472XS'
,'T34811D'
,'T34811S'
,'T34812D'
,'T34812S'
,'T34819D'
,'T34819S'
,'T34821D'
,'T34821S'
,'T34822D'
,'T34822S'
,'T34829D'
,'T34829S'
,'T34831D'
,'T34831S'
,'T34832D'
,'T34832S'
,'T34839D'
,'T34839S'
,'T3490XD'
,'T3490XS'
,'T3499XD'
,'T3499XS'
,'T360X1D'
,'T360X1S'
,'T360X2D'
,'T360X2S'
,'T360X3D'
,'T360X3S'
,'T360X4D'
,'T360X4S'
,'T360X5D'
,'T360X5S'
,'T360X6D'
,'T360X6S'
,'T361X1D'
,'T361X1S'
,'T361X2D'
,'T361X2S'
,'T361X3D'
,'T361X3S'
,'T361X4D'
,'T361X4S'
,'T361X5D'
,'T361X5S'
,'T361X6D'
,'T361X6S'
,'T362X1D'
,'T362X1S'
,'T362X2D'
,'T362X2S'
,'T362X3D'
,'T362X3S'
,'T362X4D'
,'T362X4S'
,'T362X5D'
,'T362X5S'
,'T362X6D'
,'T362X6S'
,'T363X1D'
,'T363X1S'
,'T363X2D'
,'T363X2S'
,'T363X3D'
,'T363X3S'
,'T363X4D'
,'T363X4S'
,'T363X5D'
,'T363X5S'
,'T363X6D'
,'T363X6S'
,'T364X1D'
,'T364X1S'
,'T364X2D'
,'T364X2S'
,'T364X3D'
,'T364X3S'
,'T364X4D'
,'T364X4S'
,'T364X5D'
,'T364X5S'
,'T364X6D'
,'T364X6S'
,'T365X1D'
,'T365X1S'
,'T365X2D'
,'T365X2S'
,'T365X3D'
,'T365X3S'
,'T365X4D'
,'T365X4S'
,'T365X5D'
,'T365X5S'
,'T365X6D'
,'T365X6S'
,'T366X1D'
,'T366X1S'
,'T366X2D'
,'T366X2S'
,'T366X3D'
,'T366X3S'
,'T366X4D'
,'T366X4S'
,'T366X5D'
,'T366X5S'
,'T366X6D'
,'T366X6S'
,'T367X1D'
,'T367X1S'
,'T367X2D'
,'T367X2S'
,'T367X3D'
,'T367X3S'
,'T367X4D'
,'T367X4S'
,'T367X5D'
,'T367X5S'
,'T367X6D'
,'T367X6S'
,'T368X1D'
,'T368X1S'
,'T368X2D'
,'T368X2S'
,'T368X3D'
,'T368X3S'
,'T368X4D'
,'T368X4S'
,'T368X5D'
,'T368X5S'
,'T368X6D'
,'T368X6S'
,'T3691XD'
,'T3691XS'
,'T3692XD'
,'T3692XS'
,'T3693XD'
,'T3693XS'
,'T3694XD'
,'T3694XS'
,'T3695XD'
,'T3695XS'
,'T3696XD'
,'T3696XS'
,'T370X1D'
,'T370X1S'
,'T370X2D'
,'T370X2S'
,'T370X3D'
,'T370X3S'
,'T370X4D'
,'T370X4S'
,'T370X5D'
,'T370X5S'
,'T370X6D'
,'T370X6S'
,'T371X1D'
,'T371X1S'
,'T371X2D'
,'T371X2S'
,'T371X3D'
,'T371X3S'
,'T371X4D'
,'T371X4S'
,'T371X5D'
,'T371X5S'
,'T371X6D'
,'T371X6S'
,'T372X1D'
,'T372X1S'
,'T372X2D'
,'T372X2S'
,'T372X3D'
,'T372X3S'
,'T372X4D'
,'T372X4S'
,'T372X5D'
,'T372X5S'
,'T372X6D'
,'T372X6S'
,'T373X1D'
,'T373X1S'
,'T373X2D'
,'T373X2S'
,'T373X3D'
,'T373X3S'
,'T373X4D'
,'T373X4S'
,'T373X5D'
,'T373X5S'
,'T373X6D'
,'T373X6S'
,'T374X1D'
,'T374X1S'
,'T374X2D'
,'T374X2S'
,'T374X3D'
,'T374X3S'
,'T374X4D'
,'T374X4S'
,'T374X5D'
,'T374X5S'
,'T374X6D'
,'T374X6S'
,'T375X1D'
,'T375X1S'
,'T375X2D'
,'T375X2S'
,'T375X3D'
,'T375X3S'
,'T375X4D'
,'T375X4S'
,'T375X5D'
,'T375X5S'
,'T375X6D'
,'T375X6S'
,'T378X1D'
,'T378X1S'
,'T378X2D'
,'T378X2S'
,'T378X3D'
,'T378X3S'
,'T378X4D'
,'T378X4S'
,'T378X5D'
,'T378X5S'
,'T378X6D'
,'T378X6S'
,'T3791XD'
,'T3791XS'
,'T3792XD'
,'T3792XS'
,'T3793XD'
,'T3793XS'
,'T3794XD'
,'T3794XS'
,'T3795XD'
,'T3795XS'
,'T3796XD'
,'T3796XS'
,'T380X1D'
,'T380X1S'
,'T380X2D'
,'T380X2S'
,'T380X3D'
,'T380X3S'
,'T380X4D'
,'T380X4S'
,'T380X5D'
,'T380X5S'
,'T380X6D'
,'T380X6S'
,'T381X1D'
,'T381X1S'
,'T381X2D'
,'T381X2S'
,'T381X3D'
,'T381X3S'
,'T381X4D'
,'T381X4S'
,'T381X5D'
,'T381X5S'
,'T381X6D'
,'T381X6S'
,'T382X1D'
,'T382X1S'
,'T382X2D'
,'T382X2S'
,'T382X3D'
,'T382X3S'
,'T382X4D'
,'T382X4S'
,'T382X5D'
,'T382X5S'
,'T382X6D'
,'T382X6S'
,'T383X1D'
,'T383X1S'
,'T383X2D'
,'T383X2S'
,'T383X3D'
,'T383X3S'
,'T383X4D'
,'T383X4S'
,'T383X5D'
,'T383X5S'
,'T383X6D'
,'T383X6S'
,'T384X1D'
,'T384X1S'
,'T384X2D'
,'T384X2S'
,'T384X3D'
,'T384X3S'
,'T384X4D'
,'T384X4S'
,'T384X5D'
,'T384X5S'
,'T384X6D'
,'T384X6S'
,'T385X1D'
,'T385X1S'
,'T385X2D'
,'T385X2S'
,'T385X3D'
,'T385X3S'
,'T385X4D'
,'T385X4S'
,'T385X5D'
,'T385X5S'
,'T385X6D'
,'T385X6S'
,'T386X1D'
,'T386X1S'
,'T386X2D'
,'T386X2S'
,'T386X3D'
,'T386X3S'
,'T386X4D'
,'T386X4S'
,'T386X5D'
,'T386X5S'
,'T386X6D'
,'T386X6S'
,'T387X1D'
,'T387X1S'
,'T387X2D'
,'T387X2S'
,'T387X3D'
,'T387X3S'
,'T387X4D'
,'T387X4S'
,'T387X5D'
,'T387X5S'
,'T387X6D'
,'T387X6S'
,'T38801D'
,'T38801S'
,'T38802D'
,'T38802S'
,'T38803D'
,'T38803S'
,'T38804D'
,'T38804S'
,'T38805D'
,'T38805S'
,'T38806D'
,'T38806S'
,'T38811D'
,'T38811S'
,'T38812D'
,'T38812S'
,'T38813D'
,'T38813S'
,'T38814D'
,'T38814S'
,'T38815D'
,'T38815S'
,'T38816D'
,'T38816S'
,'T38891D'
,'T38891S'
,'T38892D'
,'T38892S'
,'T38893D'
,'T38893S'
,'T38894D'
,'T38894S'
,'T38895D'
,'T38895S'
,'T38896D'
,'T38896S'
,'T38901D'
,'T38901S'
,'T38902D'
,'T38902S'
,'T38903D'
,'T38903S'
,'T38904D'
,'T38904S'
,'T38905D'
,'T38905S'
,'T38906D'
,'T38906S'
,'T38991D'
,'T38991S'
,'T38992D'
,'T38992S'
,'T38993D'
,'T38993S'
,'T38994D'
,'T38994S'
,'T38995D'
,'T38995S'
,'T38996D'
,'T38996S'
,'T39011D'
,'T39011S'
,'T39012D'
,'T39012S'
,'T39013D'
,'T39013S'
,'T39014D'
,'T39014S'
,'T39015D'
,'T39015S'
,'T39016D'
,'T39016S'
,'T39091D'
,'T39091S'
,'T39092D'
,'T39092S'
,'T39093D'
,'T39093S'
,'T39094D'
,'T39094S'
,'T39095D'
,'T39095S'
,'T39096D'
,'T39096S'
,'T391X1D'
,'T391X1S'
,'T391X2D'
,'T391X2S'
,'T391X3D'
,'T391X3S'
,'T391X4D'
,'T391X4S'
,'T391X5D'
,'T391X5S'
,'T391X6D'
,'T391X6S'
,'T392X1D'
,'T392X1S'
,'T392X2D'
,'T392X2S'
,'T392X3D'
,'T392X3S'
,'T392X4D'
,'T392X4S'
,'T392X5D'
,'T392X5S'
,'T392X6D'
,'T392X6S'
,'T39311D'
,'T39311S'
,'T39312D'
,'T39312S'
,'T39313D'
,'T39313S'
,'T39314D'
,'T39314S'
,'T39315D'
,'T39315S'
,'T39316D'
,'T39316S'
,'T39391D'
,'T39391S'
,'T39392D'
,'T39392S'
,'T39393D'
,'T39393S'
,'T39394D'
,'T39394S'
,'T39395D'
,'T39395S'
,'T39396D'
,'T39396S'
,'T394X1D'
,'T394X1S'
,'T394X2D'
,'T394X2S'
,'T394X3D'
,'T394X3S'
,'T394X4D'
,'T394X4S'
,'T394X5D'
,'T394X5S'
,'T394X6D'
,'T394X6S'
,'T398X1D'
,'T398X1S'
,'T398X2D'
,'T398X2S'
,'T398X3D'
,'T398X3S'
,'T398X4D'
,'T398X4S'
,'T398X5D'
,'T398X5S'
,'T398X6D'
,'T398X6S'
,'T3991XD'
,'T3991XS'
,'T3992XD'
,'T3992XS'
,'T3993XD'
,'T3993XS'
,'T3994XD'
,'T3994XS'
,'T3995XD'
,'T3995XS'
,'T3996XD'
,'T3996XS'
,'T400X1D'
,'T400X1S'
,'T400X2D'
,'T400X2S'
,'T400X3D'
,'T400X3S'
,'T400X4D'
,'T400X4S'
,'T400X5D'
,'T400X5S'
,'T400X6D'
,'T400X6S'
,'T401X1D'
,'T401X1S'
,'T401X2D'
,'T401X2S'
,'T401X3D'
,'T401X3S'
,'T401X4D'
,'T401X4S'
,'T401X5D'
,'T401X5S'
,'T402X1D'
,'T402X1S'
,'T402X2D'
,'T402X2S'
,'T402X3D'
,'T402X3S'
,'T402X4D'
,'T402X4S'
,'T402X5D'
,'T402X5S'
,'T402X6D'
,'T402X6S'
,'T403X1D'
,'T403X1S'
,'T403X2D'
,'T403X2S'
,'T403X3D'
,'T403X3S'
,'T403X4D'
,'T403X4S'
,'T403X5D'
,'T403X5S'
,'T403X6D'
,'T403X6S'
,'T404X1D'
,'T404X1S'
,'T404X2D'
,'T404X2S'
,'T404X3D'
,'T404X3S'
,'T404X4D'
,'T404X4S'
,'T404X5D'
,'T404X5S'
,'T404X6D'
,'T404X6S'
,'T405X1D'
,'T405X1S'
,'T405X2D'
,'T405X2S'
,'T405X3D'
,'T405X3S'
,'T405X4D'
,'T405X4S'
,'T405X5D'
,'T405X5S'
,'T405X6D'
,'T405X6S'
,'T40601D'
,'T40601S'
,'T40602D'
,'T40602S'
,'T40603D'
,'T40603S'
,'T40604D'
,'T40604S'
,'T40605D'
,'T40605S'
,'T40606D'
,'T40606S'
,'T40691D'
,'T40691S'
,'T40692D'
,'T40692S'
,'T40693D'
,'T40693S'
,'T40694D'
,'T40694S'
,'T40695D'
,'T40695S'
,'T40696D'
,'T40696S'
,'T407X1D'
,'T407X1S'
,'T407X2D'
,'T407X2S'
,'T407X3D'
,'T407X3S'
,'T407X4D'
,'T407X4S'
,'T407X5D'
,'T407X5S'
,'T407X6D'
,'T407X6S'
,'T408X1D'
,'T408X1S'
,'T408X2D'
,'T408X2S'
,'T408X3D'
,'T408X3S'
,'T408X4D'
,'T408X4S'
,'T408X5D'
,'T408X5S'
,'T40901D'
,'T40901S'
,'T40902D'
,'T40902S'
,'T40903D'
,'T40903S'
,'T40904D'
,'T40904S'
,'T40905D'
,'T40905S'
,'T40906D'
,'T40906S'
,'T40991D'
,'T40991S'
,'T40992D'
,'T40992S'
,'T40993D'
,'T40993S'
,'T40994D'
,'T40994S'
,'T40995D'
,'T40995S'
,'T40996D'
,'T40996S'
,'T410X1D'
,'T410X1S'
,'T410X2D'
,'T410X2S'
,'T410X3D'
,'T410X3S'
,'T410X4D'
,'T410X4S'
,'T410X5D'
,'T410X5S'
,'T410X6D'
,'T410X6S'
,'T411X1D'
,'T411X1S'
,'T411X2D'
,'T411X2S'
,'T411X3D'
,'T411X3S'
,'T411X4D'
,'T411X4S'
,'T411X5D'
,'T411X5S'
,'T411X6D'
,'T411X6S'
,'T41201D'
,'T41201S'
,'T41202D'
,'T41202S'
,'T41203D'
,'T41203S'
,'T41204D'
,'T41204S'
,'T41205D'
,'T41205S'
,'T41206D'
,'T41206S'
,'T41291D'
,'T41291S'
,'T41292D'
,'T41292S'
,'T41293D'
,'T41293S'
,'T41294D'
,'T41294S'
,'T41295D'
,'T41295S'
,'T41296D'
,'T41296S'
,'T413X1D'
,'T413X1S'
,'T413X2D'
,'T413X2S'
,'T413X3D'
,'T413X3S'
,'T413X4D'
,'T413X4S'
,'T413X5D'
,'T413X5S'
,'T413X6D'
,'T413X6S'
,'T4141XD'
,'T4141XS'
,'T4142XD'
,'T4142XS'
,'T4143XD'
,'T4143XS'
,'T4144XD'
,'T4144XS'
,'T4145XD'
,'T4145XS'
,'T4146XD'
,'T4146XS'
,'T415X1D'
,'T415X1S'
,'T415X2D'
,'T415X2S'
,'T415X3D'
,'T415X3S'
,'T415X4D'
,'T415X4S'
,'T415X5D'
,'T415X5S'
,'T415X6D'
,'T415X6S'
,'T420X1D'
,'T420X1S'
,'T420X2D'
,'T420X2S'
,'T420X3D'
,'T420X3S'
,'T420X4D'
,'T420X4S'
,'T420X5D'
,'T420X5S'
,'T420X6D'
,'T420X6S'
,'T421X1D'
,'T421X1S'
,'T421X2D'
,'T421X2S'
,'T421X3D'
,'T421X3S'
,'T421X4D'
,'T421X4S'
,'T421X5D'
,'T421X5S'
,'T421X6D'
,'T421X6S'
,'T422X1D'
,'T422X1S'
,'T422X2D'
,'T422X2S'
,'T422X3D'
,'T422X3S'
,'T422X4D'
,'T422X4S'
,'T422X5D'
,'T422X5S'
,'T422X6D'
,'T422X6S'
,'T423X1D'
,'T423X1S'
,'T423X2D'
,'T423X2S'
,'T423X3D'
,'T423X3S'
,'T423X4D'
,'T423X4S'
,'T423X5D'
,'T423X5S'
,'T423X6D'
,'T423X6S'
,'T424X1D'
,'T424X1S'
,'T424X2D'
,'T424X2S'
,'T424X3D'
,'T424X3S'
,'T424X4D'
,'T424X4S'
,'T424X5D'
,'T424X5S'
,'T424X6D'
,'T424X6S'
,'T425X1D'
,'T425X1S'
,'T425X2D'
,'T425X2S'
,'T425X3D'
,'T425X3S'
,'T425X4D'
,'T425X4S'
,'T425X5D'
,'T425X5S'
,'T425X6D'
,'T425X6S'
,'T426X1D'
,'T426X1S'
,'T426X2D'
,'T426X2S'
,'T426X3D'
,'T426X3S'
,'T426X4D'
,'T426X4S'
,'T426X5D'
,'T426X5S'
,'T426X6D'
,'T426X6S'
,'T4271XD'
,'T4271XS'
,'T4272XD'
,'T4272XS'
,'T4273XD'
,'T4273XS'
,'T4274XD'
,'T4274XS'
,'T4275XD'
,'T4275XS'
,'T4276XD'
,'T4276XS'
,'T428X1D'
,'T428X1S'
,'T428X2D'
,'T428X2S'
,'T428X3D'
,'T428X3S'
,'T428X4D'
,'T428X4S'
,'T428X5D'
,'T428X5S'
,'T428X6D'
,'T428X6S'
,'T43011D'
,'T43011S'
,'T43012D'
,'T43012S'
,'T43013D'
,'T43013S'
,'T43014D'
,'T43014S'
,'T43015D'
,'T43015S'
,'T43016D'
,'T43016S'
,'T43021D'
,'T43021S'
,'T43022D'
,'T43022S'
,'T43023D'
,'T43023S'
,'T43024D'
,'T43024S'
,'T43025D'
,'T43025S'
,'T43026D'
,'T43026S'
,'T431X1D'
,'T431X1S'
,'T431X2D'
,'T431X2S'
,'T431X3D'
,'T431X3S'
,'T431X4D'
,'T431X4S'
,'T431X5D'
,'T431X5S'
,'T431X6D'
,'T431X6S'
,'T43201D'
,'T43201S'
,'T43202D'
,'T43202S'
,'T43203D'
,'T43203S'
,'T43204D'
,'T43204S'
,'T43205D'
,'T43205S'
,'T43206D'
,'T43206S'
,'T43211D'
,'T43211S'
,'T43212D'
,'T43212S'
,'T43213D'
,'T43213S'
,'T43214D'
,'T43214S'
,'T43215D'
,'T43215S'
,'T43216D'
,'T43216S'
,'T43221D'
,'T43221S'
,'T43222D'
,'T43222S'
,'T43223D'
,'T43223S'
,'T43224D'
,'T43224S'
,'T43225D'
,'T43225S'
,'T43226D'
,'T43226S'
,'T43291D'
,'T43291S'
,'T43292D'
,'T43292S'
,'T43293D'
,'T43293S'
,'T43294D'
,'T43294S'
,'T43295D'
,'T43295S'
,'T43296D'
,'T43296S'
,'T433X1D'
,'T433X1S'
,'T433X2D'
,'T433X2S'
,'T433X3D'
,'T433X3S'
,'T433X4D'
,'T433X4S'
,'T433X5D'
,'T433X5S'
,'T433X6D'
,'T433X6S'
,'T434X1D'
,'T434X1S'
,'T434X2D'
,'T434X2S'
,'T434X3D'
,'T434X3S'
,'T434X4D'
,'T434X4S'
,'T434X5D'
,'T434X5S'
,'T434X6D'
,'T434X6S'
,'T43501D'
,'T43501S'
,'T43502D'
,'T43502S'
,'T43503D'
,'T43503S'
,'T43504D'
,'T43504S'
,'T43505D'
,'T43505S'
,'T43506D'
,'T43506S'
,'T43591D'
,'T43591S'
,'T43592D'
,'T43592S'
,'T43593D'
,'T43593S'
,'T43594D'
,'T43594S'
,'T43595D'
,'T43595S'
,'T43596D'
,'T43596S'
,'T43601D'
,'T43601S'
,'T43602D'
,'T43602S'
,'T43603D'
,'T43603S'
,'T43604D'
,'T43604S'
,'T43605D'
,'T43605S'
,'T43606D'
,'T43606S'
,'T43611D'
,'T43611S'
,'T43612D'
,'T43612S'
,'T43613D'
,'T43613S'
,'T43614D'
,'T43614S'
,'T43615D'
,'T43615S'
,'T43616D'
,'T43616S'
,'T43621D'
,'T43621S'
,'T43622D'
,'T43622S'
,'T43623D'
,'T43623S'
,'T43624D'
,'T43624S'
,'T43625D'
,'T43625S'
,'T43626D'
,'T43626S'
,'T43631D'
,'T43631S'
,'T43632D'
,'T43632S'
,'T43633D'
,'T43633S'
,'T43634D'
,'T43634S'
,'T43635D'
,'T43635S'
,'T43636D'
,'T43636S'
,'T43691D'
,'T43691S'
,'T43692D'
,'T43692S'
,'T43693D'
,'T43693S'
,'T43694D'
,'T43694S'
,'T43695D'
,'T43695S'
,'T43696D'
,'T43696S'
,'T438X1D'
,'T438X1S'
,'T438X2D'
,'T438X2S'
,'T438X3D'
,'T438X3S'
,'T438X4D'
,'T438X4S'
,'T438X5D'
,'T438X5S'
,'T438X6D'
,'T438X6S'
,'T4391XD'
,'T4391XS'
,'T4392XD'
,'T4392XS'
,'T4393XD'
,'T4393XS'
,'T4394XD'
,'T4394XS'
,'T4395XD'
,'T4395XS'
,'T4396XD'
,'T4396XS'
,'T440X1D'
,'T440X1S'
,'T440X2D'
,'T440X2S'
,'T440X3D'
,'T440X3S'
,'T440X4D'
,'T440X4S'
,'T440X5D'
,'T440X5S'
,'T440X6D'
,'T440X6S'
,'T441X1D'
,'T441X1S'
,'T441X2D'
,'T441X2S'
,'T441X3D'
,'T441X3S'
,'T441X4D'
,'T441X4S'
,'T441X5D'
,'T441X5S'
,'T441X6D'
,'T441X6S'
,'T442X1D'
,'T442X1S'
,'T442X2D'
,'T442X2S'
,'T442X3D'
,'T442X3S'
,'T442X4D'
,'T442X4S'
,'T442X5D'
,'T442X5S'
,'T442X6D'
,'T442X6S'
,'T443X1D'
,'T443X1S'
,'T443X2D'
,'T443X2S'
,'T443X3D'
,'T443X3S'
,'T443X4D'
,'T443X4S'
,'T443X5D'
,'T443X5S'
,'T443X6D'
,'T443X6S'
,'T444X1D'
,'T444X1S'
,'T444X2D'
,'T444X2S'
,'T444X3D'
,'T444X3S'
,'T444X4D'
,'T444X4S'
,'T444X5D'
,'T444X5S'
,'T444X6D'
,'T444X6S'
,'T445X1D'
,'T445X1S'
,'T445X2D'
,'T445X2S'
,'T445X3D'
,'T445X3S'
,'T445X4D'
,'T445X4S'
,'T445X5D'
,'T445X5S'
,'T445X6D'
,'T445X6S'
,'T446X1D'
,'T446X1S'
,'T446X2D'
,'T446X2S'
,'T446X3D'
,'T446X3S'
,'T446X4D'
,'T446X4S'
,'T446X5D'
,'T446X5S'
,'T446X6D'
,'T446X6S'
,'T447X1D'
,'T447X1S'
,'T447X2D'
,'T447X2S'
,'T447X3D'
,'T447X3S'
,'T447X4D'
,'T447X4S'
,'T447X5D'
,'T447X5S'
,'T447X6D'
,'T447X6S'
,'T448X1D'
,'T448X1S'
,'T448X2D'
,'T448X2S'
,'T448X3D'
,'T448X3S'
,'T448X4D'
,'T448X4S'
,'T448X5D'
,'T448X5S'
,'T448X6D'
,'T448X6S'
,'T44901D'
,'T44901S'
,'T44902D'
,'T44902S'
,'T44903D'
,'T44903S'
,'T44904D'
,'T44904S'
,'T44905D'
,'T44905S'
,'T44906D'
,'T44906S'
,'T44991D'
,'T44991S'
,'T44992D'
,'T44992S'
,'T44993D'
,'T44993S'
,'T44994D'
,'T44994S'
,'T44995D'
,'T44995S'
,'T44996D'
,'T44996S'
,'T450X1D'
,'T450X1S'
,'T450X2D'
,'T450X2S'
,'T450X3D'
,'T450X3S'
,'T450X4D'
,'T450X4S'
,'T450X5D'
,'T450X5S'
,'T450X6D'
,'T450X6S'
,'T451X1D'
,'T451X1S'
,'T451X2D'
,'T451X2S'
,'T451X3D'
,'T451X3S'
,'T451X4D'
,'T451X4S'
,'T451X5D'
,'T451X5S'
,'T451X6D'
,'T451X6S'
,'T452X1D'
,'T452X1S'
,'T452X2D'
,'T452X2S'
,'T452X3D'
,'T452X3S'
,'T452X4D'
,'T452X4S'
,'T452X5D'
,'T452X5S'
,'T452X6D'
,'T452X6S'
,'T453X1D'
,'T453X1S'
,'T453X2D'
,'T453X2S'
,'T453X3D'
,'T453X3S'
,'T453X4D'
,'T453X4S'
,'T453X5D'
,'T453X5S'
,'T453X6D'
,'T453X6S'
,'T454X1D'
,'T454X1S'
,'T454X2D'
,'T454X2S'
,'T454X3D'
,'T454X3S'
,'T454X4D'
,'T454X4S'
,'T454X5D'
,'T454X5S'
,'T454X6D'
,'T454X6S'
,'T45511D'
,'T45511S'
,'T45512D'
,'T45512S'
,'T45513D'
,'T45513S'
,'T45514D'
,'T45514S'
,'T45515D'
,'T45515S'
,'T45516D'
,'T45516S'
,'T45521D'
,'T45521S'
,'T45522D'
,'T45522S'
,'T45523D'
,'T45523S'
,'T45524D'
,'T45524S'
,'T45525D'
,'T45525S'
,'T45526D'
,'T45526S'
,'T45601D'
,'T45601S'
,'T45602D'
,'T45602S'
,'T45603D'
,'T45603S'
,'T45604D'
,'T45604S'
,'T45605D'
,'T45605S'
,'T45606D'
,'T45606S'
,'T45611D'
,'T45611S'
,'T45612D'
,'T45612S'
,'T45613D'
,'T45613S'
,'T45614D'
,'T45614S'
,'T45615D'
,'T45615S'
,'T45616D'
,'T45616S'
,'T45621D'
,'T45621S'
,'T45622D'
,'T45622S'
,'T45623D'
,'T45623S'
,'T45624D'
,'T45624S'
,'T45625D'
,'T45625S'
,'T45626D'
,'T45626S'
,'T45691D'
,'T45691S'
,'T45692D'
,'T45692S'
,'T45693D'
,'T45693S'
,'T45694D'
,'T45694S'
,'T45695D'
,'T45695S'
,'T45696D'
,'T45696S'
,'T457X1D'
,'T457X1S'
,'T457X2D'
,'T457X2S'
,'T457X3D'
,'T457X3S'
,'T457X4D'
,'T457X4S'
,'T457X5D'
,'T457X5S'
,'T457X6D'
,'T457X6S'
,'T458X1D'
,'T458X1S'
,'T458X2D'
,'T458X2S'
,'T458X3D'
,'T458X3S'
,'T458X4D'
,'T458X4S'
,'T458X5D'
,'T458X5S'
,'T458X6D'
,'T458X6S'
,'T4591XD'
,'T4591XS'
,'T4592XD'
,'T4592XS'
,'T4593XD'
,'T4593XS'
,'T4594XD'
,'T4594XS'
,'T4595XD'
,'T4595XS'
,'T4596XD'
,'T4596XS'
,'T460X1D'
,'T460X1S'
,'T460X2D'
,'T460X2S'
,'T460X3D'
,'T460X3S'
,'T460X4D'
,'T460X4S'
,'T460X5D'
,'T460X5S'
,'T460X6D'
,'T460X6S'
,'T461X1D'
,'T461X1S'
,'T461X2D'
,'T461X2S'
,'T461X3D'
,'T461X3S'
,'T461X4D'
,'T461X4S'
,'T461X5D'
,'T461X5S'
,'T461X6D'
,'T461X6S'
,'T462X1D'
,'T462X1S'
,'T462X2D'
,'T462X2S'
,'T462X3D'
,'T462X3S'
,'T462X4D'
,'T462X4S'
,'T462X5D'
,'T462X5S'
,'T462X6D'
,'T462X6S'
,'T463X1D'
,'T463X1S'
,'T463X2D'
,'T463X2S'
,'T463X3D'
,'T463X3S'
,'T463X4D'
,'T463X4S'
,'T463X5D'
,'T463X5S'
,'T463X6D'
,'T463X6S'
,'T464X1D'
,'T464X1S'
,'T464X2D'
,'T464X2S'
,'T464X3D'
,'T464X3S'
,'T464X4D'
,'T464X4S'
,'T464X5D'
,'T464X5S'
,'T464X6D'
,'T464X6S'
,'T465X1D'
,'T465X1S'
,'T465X2D'
,'T465X2S'
,'T465X3D'
,'T465X3S'
,'T465X4D'
,'T465X4S'
,'T465X5D'
,'T465X5S'
,'T465X6D'
,'T465X6S'
,'T466X1D'
,'T466X1S'
,'T466X2D'
,'T466X2S'
,'T466X3D'
,'T466X3S'
,'T466X4D'
,'T466X4S'
,'T466X5D'
,'T466X5S'
,'T466X6D'
,'T466X6S'
,'T467X1D'
,'T467X1S'
,'T467X2D'
,'T467X2S'
,'T467X3D'
,'T467X3S'
,'T467X4D'
,'T467X4S'
,'T467X5D'
,'T467X5S'
,'T467X6D'
,'T467X6S'
,'T468X1D'
,'T468X1S'
,'T468X2D'
,'T468X2S'
,'T468X3D'
,'T468X3S'
,'T468X4D'
,'T468X4S'
,'T468X5D'
,'T468X5S'
,'T468X6D'
,'T468X6S'
,'T46901D'
,'T46901S'
,'T46902D'
,'T46902S'
,'T46903D'
,'T46903S'
,'T46904D'
,'T46904S'
,'T46905D'
,'T46905S'
,'T46906D'
,'T46906S'
,'T46991D'
,'T46991S'
,'T46992D'
,'T46992S'
,'T46993D'
,'T46993S'
,'T46994D'
,'T46994S'
,'T46995D'
,'T46995S'
,'T46996D'
,'T46996S'
,'T470X1D'
,'T470X1S'
,'T470X2D'
,'T470X2S'
,'T470X3D'
,'T470X3S'
,'T470X4D'
,'T470X4S'
,'T470X5D'
,'T470X5S'
,'T470X6D'
,'T470X6S'
,'T471X1D'
,'T471X1S'
,'T471X2D'
,'T471X2S'
,'T471X3D'
,'T471X3S'
,'T471X4D'
,'T471X4S'
,'T471X5D'
,'T471X5S'
,'T471X6D'
,'T471X6S'
,'T472X1D'
,'T472X1S'
,'T472X2D'
,'T472X2S'
,'T472X3D'
,'T472X3S'
,'T472X4D'
,'T472X4S'
,'T472X5D'
,'T472X5S'
,'T472X6D'
,'T472X6S'
,'T473X1D'
,'T473X1S'
,'T473X2D'
,'T473X2S'
,'T473X3D'
,'T473X3S'
,'T473X4D'
,'T473X4S'
,'T473X5D'
,'T473X5S'
,'T473X6D'
,'T473X6S'
,'T474X1D'
,'T474X1S'
,'T474X2D'
,'T474X2S'
,'T474X3D'
,'T474X3S'
,'T474X4D'
,'T474X4S'
,'T474X5D'
,'T474X5S'
,'T474X6D'
,'T474X6S'
,'T475X1D'
,'T475X1S'
,'T475X2D'
,'T475X2S'
,'T475X3D'
,'T475X3S'
,'T475X4D'
,'T475X4S'
,'T475X5D'
,'T475X5S'
,'T475X6D'
,'T475X6S'
,'T476X1D'
,'T476X1S'
,'T476X2D'
,'T476X2S'
,'T476X3D'
,'T476X3S'
,'T476X4D'
,'T476X4S'
,'T476X5D'
,'T476X5S'
,'T476X6D'
,'T476X6S'
,'T477X1D'
,'T477X1S'
,'T477X2D'
,'T477X2S'
,'T477X3D'
,'T477X3S'
,'T477X4D'
,'T477X4S'
,'T477X5D'
,'T477X5S'
,'T477X6D'
,'T477X6S'
,'T478X1D'
,'T478X1S'
,'T478X2D'
,'T478X2S'
,'T478X3D'
,'T478X3S'
,'T478X4D'
,'T478X4S'
,'T478X5D'
,'T478X5S'
,'T478X6D'
,'T478X6S'
,'T4791XD'
,'T4791XS'
,'T4792XD'
,'T4792XS'
,'T4793XD'
,'T4793XS'
,'T4794XD'
,'T4794XS'
,'T4795XD'
,'T4795XS'
,'T4796XD'
,'T4796XS'
,'T480X1D'
,'T480X1S'
,'T480X2D'
,'T480X2S'
,'T480X3D'
,'T480X3S'
,'T480X4D'
,'T480X4S'
,'T480X5D'
,'T480X5S'
,'T480X6D'
,'T480X6S'
,'T481X1D'
,'T481X1S'
,'T481X2D'
,'T481X2S'
,'T481X3D'
,'T481X3S'
,'T481X4D'
,'T481X4S'
,'T481X5D'
,'T481X5S'
,'T481X6D'
,'T481X6S'
,'T48201D'
,'T48201S'
,'T48202D'
,'T48202S'
,'T48203D'
,'T48203S'
,'T48204D'
,'T48204S'
,'T48205D'
,'T48205S'
,'T48206D'
,'T48206S'
,'T48291D'
,'T48291S'
,'T48292D'
,'T48292S'
,'T48293D'
,'T48293S'
,'T48294D'
,'T48294S'
,'T48295D'
,'T48295S'
,'T48296D'
,'T48296S'
,'T483X1D'
,'T483X1S'
,'T483X2D'
,'T483X2S'
,'T483X3D'
,'T483X3S'
,'T483X4D'
,'T483X4S'
,'T483X5D'
,'T483X5S'
,'T483X6D'
,'T483X6S'
,'T484X1D'
,'T484X1S'
,'T484X2D'
,'T484X2S'
,'T484X3D'
,'T484X3S'
,'T484X4D'
,'T484X4S'
,'T484X5D'
,'T484X5S'
,'T484X6D'
,'T484X6S'
,'T485X1D'
,'T485X1S'
,'T485X2D'
,'T485X2S'
,'T485X3D'
,'T485X3S'
,'T485X4D'
,'T485X4S'
,'T485X5D'
,'T485X5S'
,'T485X6D'
,'T485X6S'
,'T486X1D'
,'T486X1S'
,'T486X2D'
,'T486X2S'
,'T486X3D'
,'T486X3S'
,'T486X4D'
,'T486X4S'
,'T486X5D'
,'T486X5S'
,'T486X6D'
,'T486X6S'
,'T48901D'
,'T48901S'
,'T48902D'
,'T48902S'
,'T48903D'
,'T48903S'
,'T48904D'
,'T48904S'
,'T48905D'
,'T48905S'
,'T48906D'
,'T48906S'
,'T48991D'
,'T48991S'
,'T48992D'
,'T48992S'
,'T48993D'
,'T48993S'
,'T48994D'
,'T48994S'
,'T48995D'
,'T48995S'
,'T48996D'
,'T48996S'
,'T490X1D'
,'T490X1S'
,'T490X2D'
,'T490X2S'
,'T490X3D'
,'T490X3S'
,'T490X4D'
,'T490X4S'
,'T490X5D'
,'T490X5S'
,'T490X6D'
,'T490X6S'
,'T491X1D'
,'T491X1S'
,'T491X2D'
,'T491X2S'
,'T491X3D'
,'T491X3S'
,'T491X4D'
,'T491X4S'
,'T491X5D'
,'T491X5S'
,'T491X6D'
,'T491X6S'
,'T492X1D'
,'T492X1S'
,'T492X2D'
,'T492X2S'
,'T492X3D'
,'T492X3S'
,'T492X4D'
,'T492X4S'
,'T492X5D'
,'T492X5S'
,'T492X6D'
,'T492X6S'
,'T493X1D'
,'T493X1S'
,'T493X2D'
,'T493X2S'
,'T493X3D'
,'T493X3S'
,'T493X4D'
,'T493X4S'
,'T493X5D'
,'T493X5S'
,'T493X6D'
,'T493X6S'
,'T494X1D'
,'T494X1S'
,'T494X2D'
,'T494X2S'
,'T494X3D'
,'T494X3S'
,'T494X4D'
,'T494X4S'
,'T494X5D'
,'T494X5S'
,'T494X6D'
,'T494X6S'
,'T495X1D'
,'T495X1S'
,'T495X2D'
,'T495X2S'
,'T495X3D'
,'T495X3S'
,'T495X4D'
,'T495X4S'
,'T495X5D'
,'T495X5S'
,'T495X6D'
,'T495X6S'
,'T496X1D'
,'T496X1S'
,'T496X2D'
,'T496X2S'
,'T496X3D'
,'T496X3S'
,'T496X4D'
,'T496X4S'
,'T496X5D'
,'T496X5S'
,'T496X6D'
,'T496X6S'
,'T497X1D'
,'T497X1S'
,'T497X2D'
,'T497X2S'
,'T497X3D'
,'T497X3S'
,'T497X4D'
,'T497X4S'
,'T497X5D'
,'T497X5S'
,'T497X6D'
,'T497X6S'
,'T498X1D'
,'T498X1S'
,'T498X2D'
,'T498X2S'
,'T498X3D'
,'T498X3S'
,'T498X4D'
,'T498X4S'
,'T498X5D'
,'T498X5S'
,'T498X6D'
,'T498X6S'
,'T4991XD'
,'T4991XS'
,'T4992XD'
,'T4992XS'
,'T4993XD'
,'T4993XS'
,'T4994XD'
,'T4994XS'
,'T4995XD'
,'T4995XS'
,'T4996XD'
,'T4996XS'
,'T500X1D'
,'T500X1S'
,'T500X2D'
,'T500X2S'
,'T500X3D'
,'T500X3S'
,'T500X4D'
,'T500X4S'
,'T500X5D'
,'T500X5S'
,'T500X6D'
,'T500X6S'
,'T501X1D'
,'T501X1S'
,'T501X2D'
,'T501X2S'
,'T501X3D'
,'T501X3S'
,'T501X4D'
,'T501X4S'
,'T501X5D'
,'T501X5S'
,'T501X6D'
,'T501X6S'
,'T502X1D'
,'T502X1S'
,'T502X2D'
,'T502X2S'
,'T502X3D'
,'T502X3S'
,'T502X4D'
,'T502X4S'
,'T502X5D'
,'T502X5S'
,'T502X6D'
,'T502X6S'
,'T503X1D'
,'T503X1S'
,'T503X2D'
,'T503X2S'
,'T503X3D'
,'T503X3S'
,'T503X4D'
,'T503X4S'
,'T503X5D'
,'T503X5S'
,'T503X6D'
,'T503X6S'
,'T504X1D'
,'T504X1S'
,'T504X2D'
,'T504X2S'
,'T504X3D'
,'T504X3S'
,'T504X4D'
,'T504X4S'
,'T504X5D'
,'T504X5S'
,'T504X6D'
,'T504X6S'
,'T505X1D'
,'T505X1S'
,'T505X2D'
,'T505X2S'
,'T505X3D'
,'T505X3S'
,'T505X4D'
,'T505X4S'
,'T505X5D'
,'T505X5S'
,'T505X6D'
,'T505X6S'
,'T506X1D'
,'T506X1S'
,'T506X2D'
,'T506X2S'
,'T506X3D'
,'T506X3S'
,'T506X4D'
,'T506X4S'
,'T506X5D'
,'T506X5S'
,'T506X6D'
,'T506X6S'
,'T507X1D'
,'T507X1S'
,'T507X2D'
,'T507X2S'
,'T507X3D'
,'T507X3S'
,'T507X4D'
,'T507X4S'
,'T507X5D'
,'T507X5S'
,'T507X6D'
,'T507X6S'
,'T508X1D'
,'T508X1S'
,'T508X2D'
,'T508X2S'
,'T508X3D'
,'T508X3S'
,'T508X4D'
,'T508X4S'
,'T508X5D'
,'T508X5S'
,'T508X6D'
,'T508X6S'
,'T50901D'
,'T50901S'
,'T50902D'
,'T50902S'
,'T50903D'
,'T50903S'
,'T50904D'
,'T50904S'
,'T50905D'
,'T50905S'
,'T50906D'
,'T50906S'
,'T50991D'
,'T50991S'
,'T50992D'
,'T50992S'
,'T50993D'
,'T50993S'
,'T50994D'
,'T50994S'
,'T50995D'
,'T50995S'
,'T50996D'
,'T50996S'
,'T50A11D'
,'T50A11S'
,'T50A12D'
,'T50A12S'
,'T50A13D'
,'T50A13S'
,'T50A14D'
,'T50A14S'
,'T50A15D'
,'T50A15S'
,'T50A16D'
,'T50A16S'
,'T50A21D'
,'T50A21S'
,'T50A22D'
,'T50A22S'
,'T50A23D'
,'T50A23S'
,'T50A24D'
,'T50A24S'
,'T50A25D'
,'T50A25S'
,'T50A26D'
,'T50A26S'
,'T50A91D'
,'T50A91S'
,'T50A92D'
,'T50A92S'
,'T50A93D'
,'T50A93S'
,'T50A94D'
,'T50A94S'
,'T50A95D'
,'T50A95S'
,'T50A96D'
,'T50A96S'
,'T50B11D'
,'T50B11S'
,'T50B12D'
,'T50B12S'
,'T50B13D'
,'T50B13S'
,'T50B14D'
,'T50B14S'
,'T50B15D'
,'T50B15S'
,'T50B16D'
,'T50B16S'
,'T50B91D'
,'T50B91S'
,'T50B92D'
,'T50B92S'
,'T50B93D'
,'T50B93S'
,'T50B94D'
,'T50B94S'
,'T50B95D'
,'T50B95S'
,'T50B96D'
,'T50B96S'
,'T50Z11D'
,'T50Z11S'
,'T50Z12D'
,'T50Z12S'
,'T50Z13D'
,'T50Z13S'
,'T50Z14D'
,'T50Z14S'
,'T50Z15D'
,'T50Z15S'
,'T50Z16D'
,'T50Z16S'
,'T50Z91D'
,'T50Z91S'
,'T50Z92D'
,'T50Z92S'
,'T50Z93D'
,'T50Z93S'
,'T50Z94D'
,'T50Z94S'
,'T50Z95D'
,'T50Z95S'
,'T50Z96D'
,'T50Z96S'
,'T510X1D'
,'T510X1S'
,'T510X2D'
,'T510X2S'
,'T510X3D'
,'T510X3S'
,'T510X4D'
,'T510X4S'
,'T511X1D'
,'T511X1S'
,'T511X2D'
,'T511X2S'
,'T511X3D'
,'T511X3S'
,'T511X4D'
,'T511X4S'
,'T512X1D'
,'T512X1S'
,'T512X2D'
,'T512X2S'
,'T512X3D'
,'T512X3S'
,'T512X4D'
,'T512X4S'
,'T513X1D'
,'T513X1S'
,'T513X2D'
,'T513X2S'
,'T513X3D'
,'T513X3S'
,'T513X4D'
,'T513X4S'
,'T518X1D'
,'T518X1S'
,'T518X2D'
,'T518X2S'
,'T518X3D'
,'T518X3S'
,'T518X4D'
,'T518X4S'
,'T5191XD'
,'T5191XS'
,'T5192XD'
,'T5192XS'
,'T5193XD'
,'T5193XS'
,'T5194XD'
,'T5194XS'
,'T520X1D'
,'T520X1S'
,'T520X2D'
,'T520X2S'
,'T520X3D'
,'T520X3S'
,'T520X4D'
,'T520X4S'
,'T521X1D'
,'T521X1S'
,'T521X2D'
,'T521X2S'
,'T521X3D'
,'T521X3S'
,'T521X4D'
,'T521X4S'
,'T522X1D'
,'T522X1S'
,'T522X2D'
,'T522X2S'
,'T522X3D'
,'T522X3S'
,'T522X4D'
,'T522X4S'
,'T523X1D'
,'T523X1S'
,'T523X2D'
,'T523X2S'
,'T523X3D'
,'T523X3S'
,'T523X4D'
,'T523X4S'
,'T524X1D'
,'T524X1S'
,'T524X2D'
,'T524X2S'
,'T524X3D'
,'T524X3S'
,'T524X4D'
,'T524X4S'
,'T528X1D'
,'T528X1S'
,'T528X2D'
,'T528X2S'
,'T528X3D'
,'T528X3S'
,'T528X4D'
,'T528X4S'
,'T5291XD'
,'T5291XS'
,'T5292XD'
,'T5292XS'
,'T5293XD'
,'T5293XS'
,'T5294XD'
,'T5294XS'
,'T530X1D'
,'T530X1S'
,'T530X2D'
,'T530X2S'
,'T530X3D'
,'T530X3S'
,'T530X4D'
,'T530X4S'
,'T531X1D'
,'T531X1S'
,'T531X2D'
,'T531X2S'
,'T531X3D'
,'T531X3S'
,'T531X4D'
,'T531X4S'
,'T532X1D'
,'T532X1S'
,'T532X2D'
,'T532X2S'
,'T532X3D'
,'T532X3S'
,'T532X4D'
,'T532X4S'
,'T533X1D'
,'T533X1S'
,'T533X2D'
,'T533X2S'
,'T533X3D'
,'T533X3S'
,'T533X4D'
,'T533X4S'
,'T534X1D'
,'T534X1S'
,'T534X2D'
,'T534X2S'
,'T534X3D'
,'T534X3S'
,'T534X4D'
,'T534X4S'
,'T535X1D'
,'T535X1S'
,'T535X2D'
,'T535X2S'
,'T535X3D'
,'T535X3S'
,'T535X4D'
,'T535X4S'
,'T536X1D'
,'T536X1S'
,'T536X2D'
,'T536X2S'
,'T536X3D'
,'T536X3S'
,'T536X4D'
,'T536X4S'
,'T537X1D'
,'T537X1S'
,'T537X2D'
,'T537X2S'
,'T537X3D'
,'T537X3S'
,'T537X4D'
,'T537X4S'
,'T5391XD'
,'T5391XS'
,'T5392XD'
,'T5392XS'
,'T5393XD'
,'T5393XS'
,'T5394XD'
,'T5394XS'
,'T540X1D'
,'T540X1S'
,'T540X2D'
,'T540X2S'
,'T540X3D'
,'T540X3S'
,'T540X4D'
,'T540X4S'
,'T541X1D'
,'T541X1S'
,'T541X2D'
,'T541X2S'
,'T541X3D'
,'T541X3S'
,'T541X4D'
,'T541X4S'
,'T542X1D'
,'T542X1S'
,'T542X2D'
,'T542X2S'
,'T542X3D'
,'T542X3S'
,'T542X4D'
,'T542X4S'
,'T543X1D'
,'T543X1S'
,'T543X2D'
,'T543X2S'
,'T543X3D'
,'T543X3S'
,'T543X4D'
,'T543X4S'
,'T5491XD'
,'T5491XS'
,'T5492XD'
,'T5492XS'
,'T5493XD'
,'T5493XS'
,'T5494XD'
,'T5494XS'
,'T550X1D'
,'T550X1S'
,'T550X2D'
,'T550X2S'
,'T550X3D'
,'T550X3S'
,'T550X4D'
,'T550X4S'
,'T551X1D'
,'T551X1S'
,'T551X2D'
,'T551X2S'
,'T551X3D'
,'T551X3S'
,'T551X4D'
,'T551X4S'
,'T560X1D'
,'T560X1S'
,'T560X2D'
,'T560X2S'
,'T560X3D'
,'T560X3S'
,'T560X4D'
,'T560X4S'
,'T561X1D'
,'T561X1S'
,'T561X2D'
,'T561X2S'
,'T561X3D'
,'T561X3S'
,'T561X4D'
,'T561X4S'
,'T562X1D'
,'T562X1S'
,'T562X2D'
,'T562X2S'
,'T562X3D'
,'T562X3S'
,'T562X4D'
,'T562X4S'
,'T563X1D'
,'T563X1S'
,'T563X2D'
,'T563X2S'
,'T563X3D'
,'T563X3S'
,'T563X4D'
,'T563X4S'
,'T564X1D'
,'T564X1S'
,'T564X2D'
,'T564X2S'
,'T564X3D'
,'T564X3S'
,'T564X4D'
,'T564X4S'
,'T565X1D'
,'T565X1S'
,'T565X2D'
,'T565X2S'
,'T565X3D'
,'T565X3S'
,'T565X4D'
,'T565X4S'
,'T566X1D'
,'T566X1S'
,'T566X2D'
,'T566X2S'
,'T566X3D'
,'T566X3S'
,'T566X4D'
,'T566X4S'
,'T567X1D'
,'T567X1S'
,'T567X2D'
,'T567X2S'
,'T567X3D'
,'T567X3S'
,'T567X4D'
,'T567X4S'
,'T56811D'
,'T56811S'
,'T56812D'
,'T56812S'
,'T56813D'
,'T56813S'
,'T56814D'
,'T56814S'
,'T56891D'
,'T56891S'
,'T56892D'
,'T56892S'
,'T56893D'
,'T56893S'
,'T56894D'
,'T56894S'
,'T5691XD'
,'T5691XS'
,'T5692XD'
,'T5692XS'
,'T5693XD'
,'T5693XS'
,'T5694XD'
,'T5694XS'
,'T570X1D'
,'T570X1S'
,'T570X2D'
,'T570X2S'
,'T570X3D'
,'T570X3S'
,'T570X4D'
,'T570X4S'
,'T571X1D'
,'T571X1S'
,'T571X2D'
,'T571X2S'
,'T571X3D'
,'T571X3S'
,'T571X4D'
,'T571X4S'
,'T572X1D'
,'T572X1S'
,'T572X2D'
,'T572X2S'
,'T572X3D'
,'T572X3S'
,'T572X4D'
,'T572X4S'
,'T573X1D'
,'T573X1S'
,'T573X2D'
,'T573X2S'
,'T573X3D'
,'T573X3S'
,'T573X4D'
,'T573X4S'
,'T578X1D'
,'T578X1S'
,'T578X2D'
,'T578X2S'
,'T578X3D'
,'T578X3S'
,'T578X4D'
,'T578X4S'
,'T5791XD'
,'T5791XS'
,'T5792XD'
,'T5792XS'
,'T5793XD'
,'T5793XS'
,'T5794XD'
,'T5794XS'
,'T5801XD'
,'T5801XS'
,'T5802XD'
,'T5802XS'
,'T5803XD'
,'T5803XS'
,'T5804XD'
,'T5804XS'
,'T5811XD'
,'T5811XS'
,'T5812XD'
,'T5812XS'
,'T5813XD'
,'T5813XS'
,'T5814XD'
,'T5814XS'
,'T582X1D'
,'T582X1S'
,'T582X2D'
,'T582X2S'
,'T582X3D'
,'T582X3S'
,'T582X4D'
,'T582X4S'
,'T588X1D'
,'T588X1S'
,'T588X2D'
,'T588X2S'
,'T588X3D'
,'T588X3S'
,'T588X4D'
,'T588X4S'
,'T5891XD'
,'T5891XS'
,'T5892XD'
,'T5892XS'
,'T5893XD'
,'T5893XS'
,'T5894XD'
,'T5894XS'
,'T590X1D'
,'T590X1S'
,'T590X2D'
,'T590X2S'
,'T590X3D'
,'T590X3S'
,'T590X4D'
,'T590X4S'
,'T591X1D'
,'T591X1S'
,'T591X2D'
,'T591X2S'
,'T591X3D'
,'T591X3S'
,'T591X4D'
,'T591X4S'
,'T592X1D'
,'T592X1S'
,'T592X2D'
,'T592X2S'
,'T592X3D'
,'T592X3S'
,'T592X4D'
,'T592X4S'
,'T593X1D'
,'T593X1S'
,'T593X2D'
,'T593X2S'
,'T593X3D'
,'T593X3S'
,'T593X4D'
,'T593X4S'
,'T594X1D'
,'T594X1S'
,'T594X2D'
,'T594X2S'
,'T594X3D'
,'T594X3S'
,'T594X4D'
,'T594X4S'
,'T595X1D'
,'T595X1S'
,'T595X2D'
,'T595X2S'
,'T595X3D'
,'T595X3S'
,'T595X4D'
,'T595X4S'
,'T596X1D'
,'T596X1S'
,'T596X2D'
,'T596X2S'
,'T596X3D'
,'T596X3S'
,'T596X4D'
,'T596X4S'
,'T597X1D'
,'T597X1S'
,'T597X2D'
,'T597X2S'
,'T597X3D'
,'T597X3S'
,'T597X4D'
,'T597X4S'
,'T59811D'
,'T59811S'
,'T59812D'
,'T59812S'
,'T59813D'
,'T59813S'
,'T59814D'
,'T59814S'
,'T59891D'
,'T59891S'
,'T59892D'
,'T59892S'
,'T59893D'
,'T59893S'
,'T59894D'
,'T59894S'
,'T5991XD'
,'T5991XS'
,'T5992XD'
,'T5992XS'
,'T5993XD'
,'T5993XS'
,'T5994XD'
,'T5994XS'
,'T600X1D'
,'T600X1S'
,'T600X2D'
,'T600X2S'
,'T600X3D'
,'T600X3S'
,'T600X4D'
,'T600X4S'
,'T601X1D'
,'T601X1S'
,'T601X2D'
,'T601X2S'
,'T601X3D'
,'T601X3S'
,'T601X4D'
,'T601X4S'
,'T602X1D'
,'T602X1S'
,'T602X2D'
,'T602X2S'
,'T602X3D'
,'T602X3S'
,'T602X4D'
,'T602X4S'
,'T603X1D'
,'T603X1S'
,'T603X2D'
,'T603X2S'
,'T603X3D'
,'T603X3S'
,'T603X4D'
,'T603X4S'
,'T604X1D'
,'T604X1S'
,'T604X2D'
,'T604X2S'
,'T604X3D'
,'T604X3S'
,'T604X4D'
,'T604X4S'
,'T608X1D'
,'T608X1S'
,'T608X2D'
,'T608X2S'
,'T608X3D'
,'T608X3S'
,'T608X4D'
,'T608X4S'
,'T6091XD'
,'T6091XS'
,'T6092XD'
,'T6092XS'
,'T6093XD'
,'T6093XS'
,'T6094XD'
,'T6094XS'
,'T6101XD'
,'T6101XS'
,'T6102XD'
,'T6102XS'
,'T6103XD'
,'T6103XS'
,'T6104XD'
,'T6104XS'
,'T6111XD'
,'T6111XS'
,'T6112XD'
,'T6112XS'
,'T6113XD'
,'T6113XS'
,'T6114XD'
,'T6114XS'
,'T61771D'
,'T61771S'
,'T61772D'
,'T61772S'
,'T61773D'
,'T61773S'
,'T61774D'
,'T61774S'
,'T61781D'
,'T61781S'
,'T61782D'
,'T61782S'
,'T61783D'
,'T61783S'
,'T61784D'
,'T61784S'
,'T618X1D'
,'T618X1S'
,'T618X2D'
,'T618X2S'
,'T618X3D'
,'T618X3S'
,'T618X4D'
,'T618X4S'
,'T6191XD'
,'T6191XS'
,'T6192XD'
,'T6192XS'
,'T6193XD'
,'T6193XS'
,'T6194XD'
,'T6194XS'
,'T620X1D'
,'T620X1S'
,'T620X2D'
,'T620X2S'
,'T620X3D'
,'T620X3S'
,'T620X4D'
,'T620X4S'
,'T621X1D'
,'T621X1S'
,'T621X2D'
,'T621X2S'
,'T621X3D'
,'T621X3S'
,'T621X4D'
,'T621X4S'
,'T622X1D'
,'T622X1S'
,'T622X2D'
,'T622X2S'
,'T622X3D'
,'T622X3S'
,'T622X4D'
,'T622X4S'
,'T628X1D'
,'T628X1S'
,'T628X2D'
,'T628X2S'
,'T628X3D'
,'T628X3S'
,'T628X4D'
,'T628X4S'
,'T6291XD'
,'T6291XS'
,'T6292XD'
,'T6292XS'
,'T6293XD'
,'T6293XS'
,'T6294XD'
,'T6294XS'
,'T63001D'
,'T63001S'
,'T63002D'
,'T63002S'
,'T63003D'
,'T63003S'
,'T63004D'
,'T63004S'
,'T63011D'
,'T63011S'
,'T63012D'
,'T63012S'
,'T63013D'
,'T63013S'
,'T63014D'
,'T63014S'
,'T63021D'
,'T63021S'
,'T63022D'
,'T63022S'
,'T63023D'
,'T63023S'
,'T63024D'
,'T63024S'
,'T63031D'
,'T63031S'
,'T63032D'
,'T63032S'
,'T63033D'
,'T63033S'
,'T63034D'
,'T63034S'
,'T63041D'
,'T63041S'
,'T63042D'
,'T63042S'
,'T63043D'
,'T63043S'
,'T63044D'
,'T63044S'
,'T63061D'
,'T63061S'
,'T63062D'
,'T63062S'
,'T63063D'
,'T63063S'
,'T63064D'
,'T63064S'
,'T63071D'
,'T63071S'
,'T63072D'
,'T63072S'
,'T63073D'
,'T63073S'
,'T63074D'
,'T63074S'
,'T63081D'
,'T63081S'
,'T63082D'
,'T63082S'
,'T63083D'
,'T63083S'
,'T63084D'
,'T63084S'
,'T63091D'
,'T63091S'
,'T63092D'
,'T63092S'
,'T63093D'
,'T63093S'
,'T63094D'
,'T63094S'
,'T63111D'
,'T63111S'
,'T63112D'
,'T63112S'
,'T63113D'
,'T63113S'
,'T63114D'
,'T63114S'
,'T63121D'
,'T63121S'
,'T63122D'
,'T63122S'
,'T63123D'
,'T63123S'
,'T63124D'
,'T63124S'
,'T63191D'
,'T63191S'
,'T63192D'
,'T63192S'
,'T63193D'
,'T63193S'
,'T63194D'
,'T63194S'
,'T632X1D'
,'T632X1S'
,'T632X2D'
,'T632X2S'
,'T632X3D'
,'T632X3S'
,'T632X4D'
,'T632X4S'
,'T63301D'
,'T63301S'
,'T63302D'
,'T63302S'
,'T63303D'
,'T63303S'
,'T63304D'
,'T63304S'
,'T63311D'
,'T63311S'
,'T63312D'
,'T63312S'
,'T63313D'
,'T63313S'
,'T63314D'
,'T63314S'
,'T63321D'
,'T63321S'
,'T63322D'
,'T63322S'
,'T63323D'
,'T63323S'
,'T63324D'
,'T63324S'
,'T63331D'
,'T63331S'
,'T63332D'
,'T63332S'
,'T63333D'
,'T63333S'
,'T63334D'
,'T63334S'
,'T63391D'
,'T63391S'
,'T63392D'
,'T63392S'
,'T63393D'
,'T63393S'
,'T63394D'
,'T63394S'
,'T63411D'
,'T63411S'
,'T63412D'
,'T63412S'
,'T63413D'
,'T63413S'
,'T63414D'
,'T63414S'
,'T63421D'
,'T63421S'
,'T63422D'
,'T63422S'
,'T63423D'
,'T63423S'
,'T63424D'
,'T63424S'
,'T63431D'
,'T63431S'
,'T63432D'
,'T63432S'
,'T63433D'
,'T63433S'
,'T63434D'
,'T63434S'
,'T63441D'
,'T63441S'
,'T63442D'
,'T63442S'
,'T63443D'
,'T63443S'
,'T63444D'
,'T63444S'
,'T63451D'
,'T63451S'
,'T63452D'
,'T63452S'
,'T63453D'
,'T63453S'
,'T63454D'
,'T63454S'
,'T63461D'
,'T63461S'
,'T63462D'
,'T63462S'
,'T63463D'
,'T63463S'
,'T63464D'
,'T63464S'
,'T63481D'
,'T63481S'
,'T63482D'
,'T63482S'
,'T63483D'
,'T63483S'
,'T63484D'
,'T63484S'
,'T63511D'
,'T63511S'
,'T63512D'
,'T63512S'
,'T63513D'
,'T63513S'
,'T63514D'
,'T63514S'
,'T63591D'
,'T63591S'
,'T63592D'
,'T63592S'
,'T63593D'
,'T63593S'
,'T63594D'
,'T63594S'
,'T63611D'
,'T63611S'
,'T63612D'
,'T63612S'
,'T63613D'
,'T63613S'
,'T63614D'
,'T63614S'
,'T63621D'
,'T63621S'
,'T63622D'
,'T63622S'
,'T63623D'
,'T63623S'
,'T63624D'
,'T63624S'
,'T63631D'
,'T63631S'
,'T63632D'
,'T63632S'
,'T63633D'
,'T63633S'
,'T63634D'
,'T63634S'
,'T63691D'
,'T63691S'
,'T63692D'
,'T63692S'
,'T63693D'
,'T63693S'
,'T63694D'
,'T63694S'
,'T63711D'
,'T63711S'
,'T63712D'
,'T63712S'
,'T63713D'
,'T63713S'
,'T63714D'
,'T63714S'
,'T63791D'
,'T63791S'
,'T63792D'
,'T63792S'
,'T63793D'
,'T63793S'
,'T63794D'
,'T63794S'
,'T63811D'
,'T63811S'
,'T63812D'
,'T63812S'
,'T63813D'
,'T63813S'
,'T63814D'
,'T63814S'
,'T63821D'
,'T63821S'
,'T63822D'
,'T63822S'
,'T63823D'
,'T63823S'
,'T63824D'
,'T63824S'
,'T63831D'
,'T63831S'
,'T63832D'
,'T63832S'
,'T63833D'
,'T63833S'
,'T63834D'
,'T63834S'
,'T63891D'
,'T63891S'
,'T63892D'
,'T63892S'
,'T63893D'
,'T63893S'
,'T63894D'
,'T63894S'
,'T6391XD'
,'T6391XS'
,'T6392XD'
,'T6392XS'
,'T6393XD'
,'T6393XS'
,'T6394XD'
,'T6394XS'
,'T6401XD'
,'T6401XS'
,'T6402XD'
,'T6402XS'
,'T6403XD'
,'T6403XS'
,'T6404XD'
,'T6404XS'
,'T6481XD'
,'T6481XS'
,'T6482XD'
,'T6482XS'
,'T6483XD'
,'T6483XS'
,'T6484XD'
,'T6484XS'
,'T650X1D'
,'T650X1S'
,'T650X2D'
,'T650X2S'
,'T650X3D'
,'T650X3S'
,'T650X4D'
,'T650X4S'
,'T651X1D'
,'T651X1S'
,'T651X2D'
,'T651X2S'
,'T651X3D'
,'T651X3S'
,'T651X4D'
,'T651X4S'
,'T65211D'
,'T65211S'
,'T65212D'
,'T65212S'
,'T65213D'
,'T65213S'
,'T65214D'
,'T65214S'
,'T65221D'
,'T65221S'
,'T65222D'
,'T65222S'
,'T65223D'
,'T65223S'
,'T65224D'
,'T65224S'
,'T65291D'
,'T65291S'
,'T65292D'
,'T65292S'
,'T65293D'
,'T65293S'
,'T65294D'
,'T65294S'
,'T653X1D'
,'T653X1S'
,'T653X2D'
,'T653X2S'
,'T653X3D'
,'T653X3S'
,'T653X4D'
,'T653X4S'
,'T654X1D'
,'T654X1S'
,'T654X2D'
,'T654X2S'
,'T654X3D'
,'T654X3S'
,'T654X4D'
,'T654X4S'
,'T655X1D'
,'T655X1S'
,'T655X2D'
,'T655X2S'
,'T655X3D'
,'T655X3S'
,'T655X4D'
,'T655X4S'
,'T656X1D'
,'T656X1S'
,'T656X2D'
,'T656X2S'
,'T656X3D'
,'T656X3S'
,'T656X4D'
,'T656X4S'
,'T65811D'
,'T65811S'
,'T65812D'
,'T65812S'
,'T65813D'
,'T65813S'
,'T65814D'
,'T65814S'
,'T65821D'
,'T65821S'
,'T65822D'
,'T65822S'
,'T65823D'
,'T65823S'
,'T65824D'
,'T65824S'
,'T65831D'
,'T65831S'
,'T65832D'
,'T65832S'
,'T65833D'
,'T65833S'
,'T65834D'
,'T65834S'
,'T65891D'
,'T65891S'
,'T65892D'
,'T65892S'
,'T65893D'
,'T65893S'
,'T65894D'
,'T65894S'
,'T6591XD'
,'T6591XS'
,'T6592XD'
,'T6592XS'
,'T6593XD'
,'T6593XS'
,'T6594XD'
,'T6594XS'
,'T66XXXD'
,'T66XXXS'
,'T670XXD'
,'T670XXS'
,'T671XXD'
,'T671XXS'
,'T672XXD'
,'T672XXS'
,'T673XXD'
,'T673XXS'
,'T674XXD'
,'T674XXS'
,'T675XXD'
,'T675XXS'
,'T676XXD'
,'T676XXS'
,'T677XXD'
,'T677XXS'
,'T678XXD'
,'T678XXS'
,'T679XXD'
,'T679XXS'
,'T68XXXD'
,'T68XXXS'
,'T69011D'
,'T69011S'
,'T69012D'
,'T69012S'
,'T69019D'
,'T69019S'
,'T69021D'
,'T69021S'
,'T69022D'
,'T69022S'
,'T69029D'
,'T69029S'
,'T691XXD'
,'T691XXS'
,'T698XXD'
,'T698XXS'
,'T699XXD'
,'T699XXS'
,'T700XXD'
,'T700XXS'
,'T701XXD'
,'T701XXS'
,'T7020XD'
,'T7020XS'
,'T7029XD'
,'T7029XS'
,'T703XXD'
,'T703XXS'
,'T704XXD'
,'T704XXS'
,'T708XXD'
,'T708XXS'
,'T709XXD'
,'T709XXS'
,'T71111D'
,'T71111S'
,'T71112D'
,'T71112S'
,'T71113D'
,'T71113S'
,'T71114D'
,'T71114S'
,'T71121D'
,'T71121S'
,'T71122D'
,'T71122S'
,'T71123D'
,'T71123S'
,'T71124D'
,'T71124S'
,'T71131D'
,'T71131S'
,'T71132D'
,'T71132S'
,'T71133D'
,'T71133S'
,'T71134D'
,'T71134S'
,'T71141D'
,'T71141S'
,'T71143D'
,'T71143S'
,'T71144D'
,'T71144S'
,'T71151D'
,'T71151S'
,'T71152D'
,'T71152S'
,'T71153D'
,'T71153S'
,'T71154D'
,'T71154S'
,'T71161D'
,'T71161S'
,'T71162D'
,'T71162S'
,'T71163D'
,'T71163S'
,'T71164D'
,'T71164S'
,'T71191D'
,'T71191S'
,'T71192D'
,'T71192S'
,'T71193D'
,'T71193S'
,'T71194D'
,'T71194S'
,'T7120XD'
,'T7120XS'
,'T7121XD'
,'T7121XS'
,'T71221D'
,'T71221S'
,'T71222D'
,'T71222S'
,'T71223D'
,'T71223S'
,'T71224D'
,'T71224S'
,'T71231D'
,'T71231S'
,'T71232D'
,'T71232S'
,'T71233D'
,'T71233S'
,'T71234D'
,'T71234S'
,'T7129XD'
,'T7129XS'
,'T719XXD'
,'T719XXS'
,'T730XXD'
,'T730XXS'
,'T731XXD'
,'T731XXS'
,'T732XXD'
,'T732XXS'
,'T733XXD'
,'T733XXS'
,'T738XXD'
,'T738XXS'
,'T739XXD'
,'T739XXS'
,'T7401XD'
,'T7401XS'
,'T7402XD'
,'T7402XS'
,'T7411XD'
,'T7411XS'
,'T7412XD'
,'T7412XS'
,'T7421XD'
,'T7421XS'
,'T7422XD'
,'T7422XS'
,'T7431XD'
,'T7431XS'
,'T7432XD'
,'T7432XS'
,'T744XXD'
,'T744XXS'
,'T7491XD'
,'T7491XS'
,'T7492XD'
,'T7492XS'
,'T7500XD'
,'T7500XS'
,'T7501XD'
,'T7501XS'
,'T7509XD'
,'T7509XS'
,'T751XXD'
,'T751XXS'
,'T7520XD'
,'T7520XS'
,'T7521XD'
,'T7521XS'
,'T7522XD'
,'T7522XS'
,'T7523XD'
,'T7523XS'
,'T7529XD'
,'T7529XS'
,'T753XXD'
,'T753XXS'
,'T754XXD'
,'T754XXS'
,'T7581XD'
,'T7581XS'
,'T7582XD'
,'T7582XS'
,'T7589XD'
,'T7589XS'
,'T7601XD'
,'T7601XS'
,'T7602XD'
,'T7602XS'
,'T7611XD'
,'T7611XS'
,'T7612XD'
,'T7612XS'
,'T7621XD'
,'T7621XS'
,'T7622XD'
,'T7622XS'
,'T7631XD'
,'T7631XS'
,'T7632XD'
,'T7632XS'
,'T7691XD'
,'T7691XS'
,'T7692XD'
,'T7692XS'
,'T7800XD'
,'T7800XS'
,'T7801XD'
,'T7801XS'
,'T7802XD'
,'T7802XS'
,'T7803XD'
,'T7803XS'
,'T7804XD'
,'T7804XS'
,'T7805XD'
,'T7805XS'
,'T7806XD'
,'T7806XS'
,'T7807XD'
,'T7807XS'
,'T7808XD'
,'T7808XS'
,'T7809XD'
,'T7809XS'
,'T781XXD'
,'T781XXS'
,'T782XXD'
,'T782XXS'
,'T783XXD'
,'T783XXS'
,'T7840XD'
,'T7840XS'
,'T7841XD'
,'T7841XS'
,'T7849XD'
,'T7849XS'
,'T788XXD'
,'T788XXS'
,'T790XXD'
,'T790XXS'
,'T791XXD'
,'T791XXS'
,'T792XXD'
,'T792XXS'
,'T794XXD'
,'T794XXS'
,'T795XXD'
,'T795XXS'
,'T796XXD'
,'T796XXS'
,'T797XXD'
,'T797XXS'
,'T798XXD'
,'T798XXS'
,'T799XXD'
,'T799XXS'
,'T79A0XD'
,'T79A0XS'
,'T79A11D'
,'T79A11S'
,'T79A12D'
,'T79A12S'
,'T79A19D'
,'T79A19S'
,'T79A21D'
,'T79A21S'
,'T79A22D'
,'T79A22S'
,'T79A29D'
,'T79A29S'
,'T79A3XD'
,'T79A3XS'
,'T79A9XD'
,'T79A9XS'
,'T800XXD'
,'T800XXS'
,'T801XXD'
,'T801XXS'
,'T80211D'
,'T80211S'
,'T80212D'
,'T80212S'
,'T80218D'
,'T80218S'
,'T80219D'
,'T80219S'
,'T8022XD'
,'T8022XS'
,'T8029XD'
,'T8029XS'
,'T8030XD'
,'T8030XS'
,'T80310D'
,'T80310S'
,'T80311D'
,'T80311S'
,'T80319D'
,'T80319S'
,'T8039XD'
,'T8039XS'
,'T8040XD'
,'T8040XS'
,'T80410D'
,'T80410S'
,'T80411D'
,'T80411S'
,'T80419D'
,'T80419S'
,'T8049XD'
,'T8049XS'
,'T8051XD'
,'T8051XS'
,'T8052XD'
,'T8052XS'
,'T8059XD'
,'T8059XS'
,'T8061XD'
,'T8061XS'
,'T8062XD'
,'T8062XS'
,'T8069XD'
,'T8069XS'
,'T80810D'
,'T80810S'
,'T80818D'
,'T80818S'
,'T8089XD'
,'T8089XS'
,'T8090XD'
,'T8090XS'
,'T80910D'
,'T80910S'
,'T80911D'
,'T80911S'
,'T80919D'
,'T80919S'
,'T8092XD'
,'T8092XS'
,'T80A0XD'
,'T80A0XS'
,'T80A10D'
,'T80A10S'
,'T80A11D'
,'T80A11S'
,'T80A19D'
,'T80A19S'
,'T80A9XD'
,'T80A9XS'
,'T8110XD'
,'T8110XS'
,'T8111XD'
,'T8111XS'
,'T8112XD'
,'T8112XS'
,'T8119XD'
,'T8119XS'
,'T8130XD'
,'T8130XS'
,'T8131XD'
,'T8131XS'
,'T8132XD'
,'T8132XS'
,'T8133XD'
,'T8133XS'
,'T814XXD'
,'T814XXS'
,'T81500D'
,'T81500S'
,'T81501D'
,'T81501S'
,'T81502D'
,'T81502S'
,'T81503D'
,'T81503S'
,'T81504D'
,'T81504S'
,'T81505D'
,'T81505S'
,'T81506D'
,'T81506S'
,'T81507D'
,'T81507S'
,'T81508D'
,'T81508S'
,'T81509D'
,'T81509S'
,'T81510D'
,'T81510S'
,'T81511D'
,'T81511S'
,'T81512D'
,'T81512S'
,'T81513D'
,'T81513S'
,'T81514D'
,'T81514S'
,'T81515D'
,'T81515S'
,'T81516D'
,'T81516S'
,'T81517D'
,'T81517S'
,'T81518D'
,'T81518S'
,'T81519D'
,'T81519S'
,'T81520D'
,'T81520S'
,'T81521D'
,'T81521S'
,'T81522D'
,'T81522S'
,'T81523D'
,'T81523S'
,'T81524D'
,'T81524S'
,'T81525D'
,'T81525S'
,'T81526D'
,'T81526S'
,'T81527D'
,'T81527S'
,'T81528D'
,'T81528S'
,'T81529D'
,'T81529S'
,'T81530D'
,'T81530S'
,'T81531D'
,'T81531S'
,'T81532D'
,'T81532S'
,'T81533D'
,'T81533S'
,'T81534D'
,'T81534S'
,'T81535D'
,'T81535S'
,'T81536D'
,'T81536S'
,'T81537D'
,'T81537S'
,'T81538D'
,'T81538S'
,'T81539D'
,'T81539S'
,'T81590D'
,'T81590S'
,'T81591D'
,'T81591S'
,'T81592D'
,'T81592S'
,'T81593D'
,'T81593S'
,'T81594D'
,'T81594S'
,'T81595D'
,'T81595S'
,'T81596D'
,'T81596S'
,'T81597D'
,'T81597S'
,'T81598D'
,'T81598S'
,'T81599D'
,'T81599S'
,'T8160XD'
,'T8160XS'
,'T8161XD'
,'T8161XS'
,'T8169XD'
,'T8169XS'
,'T81710D'
,'T81710S'
,'T81711D'
,'T81711S'
,'T81718D'
,'T81718S'
,'T81719D'
,'T81719S'
,'T8172XD'
,'T8172XS'
,'T8181XD'
,'T8181XS'
,'T8182XD'
,'T8182XS'
,'T8183XD'
,'T8183XS'
,'T8189XD'
,'T8189XS'
,'T819XXD'
,'T819XXS'
,'T8201XD'
,'T8201XS'
,'T8202XD'
,'T8202XS'
,'T8203XD'
,'T8203XS'
,'T8209XD'
,'T8209XS'
,'T82110D'
,'T82110S'
,'T82111D'
,'T82111S'
,'T82118D'
,'T82118S'
,'T82119D'
,'T82119S'
,'T82120D'
,'T82120S'
,'T82121D'
,'T82121S'
,'T82128D'
,'T82128S'
,'T82129D'
,'T82129S'
,'T82190D'
,'T82190S'
,'T82191D'
,'T82191S'
,'T82198D'
,'T82198S'
,'T82199D'
,'T82199S'
,'T82211D'
,'T82211S'
,'T82212D'
,'T82212S'
,'T82213D'
,'T82213S'
,'T82218D'
,'T82218S'
,'T82221D'
,'T82221S'
,'T82222D'
,'T82222S'
,'T82223D'
,'T82223S'
,'T82228D'
,'T82228S'
,'T82310D'
,'T82310S'
,'T82311D'
,'T82311S'
,'T82312D'
,'T82312S'
,'T82318D'
,'T82318S'
,'T82319D'
,'T82319S'
,'T82320D'
,'T82320S'
,'T82321D'
,'T82321S'
,'T82322D'
,'T82322S'
,'T82328D'
,'T82328S'
,'T82329D'
,'T82329S'
,'T82330D'
,'T82330S'
,'T82331D'
,'T82331S'
,'T82332D'
,'T82332S'
,'T82338D'
,'T82338S'
,'T82339D'
,'T82339S'
,'T82390D'
,'T82390S'
,'T82391D'
,'T82391S'
,'T82392D'
,'T82392S'
,'T82398D'
,'T82398S'
,'T82399D'
,'T82399S'
,'T8241XD'
,'T8241XS'
,'T8242XD'
,'T8242XS'
,'T8243XD'
,'T8243XS'
,'T8249XD'
,'T8249XS'
,'T82510D'
,'T82510S'
,'T82511D'
,'T82511S'
,'T82512D'
,'T82512S'
,'T82513D'
,'T82513S'
,'T82514D'
,'T82514S'
,'T82515D'
,'T82515S'
,'T82518D'
,'T82518S'
,'T82519D'
,'T82519S'
,'T82520D'
,'T82520S'
,'T82521D'
,'T82521S'
,'T82522D'
,'T82522S'
,'T82523D'
,'T82523S'
,'T82524D'
,'T82524S'
,'T82525D'
,'T82525S'
,'T82528D'
,'T82528S'
,'T82529D'
,'T82529S'
,'T82530D'
,'T82530S'
,'T82531D'
,'T82531S'
,'T82532D'
,'T82532S'
,'T82533D'
,'T82533S'
,'T82534D'
,'T82534S'
,'T82535D'
,'T82535S'
,'T82538D'
,'T82538S'
,'T82539D'
,'T82539S'
,'T82590D'
,'T82590S'
,'T82591D'
,'T82591S'
,'T82592D'
,'T82592S'
,'T82593D'
,'T82593S'
,'T82594D'
,'T82594S'
,'T82595D'
,'T82595S'
,'T82598D'
,'T82598S'
,'T82599D'
,'T82599S'
,'T826XXD'
,'T826XXS'
,'T827XXD'
,'T827XXS'
,'T82817D'
,'T82817S'
,'T82818D'
,'T82818S'
,'T82827D'
,'T82827S'
,'T82828D'
,'T82828S'
,'T82837D'
,'T82837S'
,'T82838D'
,'T82838S'
,'T82847D'
,'T82847S'
,'T82848D'
,'T82848S'
,'T82857D'
,'T82857S'
,'T82858D'
,'T82858S'
,'T82867D'
,'T82867S'
,'T82868D'
,'T82868S'
,'T82897D'
,'T82897S'
,'T82898D'
,'T82898S'
,'T829XXD'
,'T829XXS'
,'T83010D'
,'T83010S'
,'T83018D'
,'T83018S'
,'T83020D'
,'T83020S'
,'T83028D'
,'T83028S'
,'T83030D'
,'T83030S'
,'T83038D'
,'T83038S'
,'T83090D'
,'T83090S'
,'T83098D'
,'T83098S'
,'T83110D'
,'T83110S'
,'T83111D'
,'T83111S'
,'T83112D'
,'T83112S'
,'T83118D'
,'T83118S'
,'T83120D'
,'T83120S'
,'T83121D'
,'T83121S'
,'T83122D'
,'T83122S'
,'T83128D'
,'T83128S'
,'T83190D'
,'T83190S'
,'T83191D'
,'T83191S'
,'T83192D'
,'T83192S'
,'T83198D'
,'T83198S'
,'T8321XD'
,'T8321XS'
,'T8322XD'
,'T8322XS'
,'T8323XD'
,'T8323XS'
,'T8329XD'
,'T8329XS'
,'T8331XD'
,'T8331XS'
,'T8332XD'
,'T8332XS'
,'T8339XD'
,'T8339XS'
,'T83410D'
,'T83410S'
,'T83418D'
,'T83418S'
,'T83420D'
,'T83420S'
,'T83428D'
,'T83428S'
,'T83490D'
,'T83490S'
,'T83498D'
,'T83498S'
,'T8351XD'
,'T8351XS'
,'T8359XD'
,'T8359XS'
,'T836XXD'
,'T836XXS'
,'T83711D'
,'T83711S'
,'T83718D'
,'T83718S'
,'T83721D'
,'T83721S'
,'T83728D'
,'T83728S'
,'T8381XD'
,'T8381XS'
,'T8382XD'
,'T8382XS'
,'T8383XD'
,'T8383XS'
,'T8384XD'
,'T8384XS'
,'T8385XD'
,'T8385XS'
,'T8386XD'
,'T8386XS'
,'T8389XD'
,'T8389XS'
,'T839XXD'
,'T839XXS'
,'T84010D'
,'T84010S'
,'T84011D'
,'T84011S'
,'T84012D'
,'T84012S'
,'T84013D'
,'T84013S'
,'T84018D'
,'T84018S'
,'T84019D'
,'T84019S'
,'T84020D'
,'T84020S'
,'T84021D'
,'T84021S'
,'T84022D'
,'T84022S'
,'T84023D'
,'T84023S'
,'T84028D'
,'T84028S'
,'T84029D'
,'T84029S'
,'T84030D'
,'T84030S'
,'T84031D'
,'T84031S'
,'T84032D'
,'T84032S'
,'T84033D'
,'T84033S'
,'T84038D'
,'T84038S'
,'T84039D'
,'T84039S'
,'T84040D'
,'T84040S'
,'T84041D'
,'T84041S'
,'T84042D'
,'T84042S'
,'T84043D'
,'T84043S'
,'T84048D'
,'T84048S'
,'T84049D'
,'T84049S'
,'T84050D'
,'T84050S'
,'T84051D'
,'T84051S'
,'T84052D'
,'T84052S'
,'T84053D'
,'T84053S'
,'T84058D'
,'T84058S'
,'T84059D'
,'T84059S'
,'T84060D'
,'T84060S'
,'T84061D'
,'T84061S'
,'T84062D'
,'T84062S'
,'T84063D'
,'T84063S'
,'T84068D'
,'T84068S'
,'T84069D'
,'T84069S'
,'T84090D'
,'T84090S'
,'T84091D'
,'T84091S'
,'T84092D'
,'T84092S'
,'T84093D'
,'T84093S'
,'T84098D'
,'T84098S'
,'T84099D'
,'T84099S'
,'T84110D'
,'T84110S'
,'T84111D'
,'T84111S'
,'T84112D'
,'T84112S'
,'T84113D'
,'T84113S'
,'T84114D'
,'T84114S'
,'T84115D'
,'T84115S'
,'T84116D'
,'T84116S'
,'T84117D'
,'T84117S'
,'T84119D'
,'T84119S'
,'T84120D'
,'T84120S'
,'T84121D'
,'T84121S'
,'T84122D'
,'T84122S'
,'T84123D'
,'T84123S'
,'T84124D'
,'T84124S'
,'T84125D'
,'T84125S'
,'T84126D'
,'T84126S'
,'T84127D'
,'T84127S'
,'T84129D'
,'T84129S'
,'T84190D'
,'T84190S'
,'T84191D'
,'T84191S'
,'T84192D'
,'T84192S'
,'T84193D'
,'T84193S'
,'T84194D'
,'T84194S'
,'T84195D'
,'T84195S'
,'T84196D'
,'T84196S'
,'T84197D'
,'T84197S'
,'T84199D'
,'T84199S'
,'T84210D'
,'T84210S'
,'T84213D'
,'T84213S'
,'T84216D'
,'T84216S'
,'T84218D'
,'T84218S'
,'T84220D'
,'T84220S'
,'T84223D'
,'T84223S'
,'T84226D'
,'T84226S'
,'T84228D'
,'T84228S'
,'T84290D'
,'T84290S'
,'T84293D'
,'T84293S'
,'T84296D'
,'T84296S'
,'T84298D'
,'T84298S'
,'T84310D'
,'T84310S'
,'T84318D'
,'T84318S'
,'T84320D'
,'T84320S'
,'T84328D'
,'T84328S'
,'T84390D'
,'T84390S'
,'T84398D'
,'T84398S'
,'T84410D'
,'T84410S'
,'T84418D'
,'T84418S'
,'T84420D'
,'T84420S'
,'T84428D'
,'T84428S'
,'T84490D'
,'T84490S'
,'T84498D'
,'T84498S'
,'T8450XD'
,'T8450XS'
,'T8451XD'
,'T8451XS'
,'T8452XD'
,'T8452XS'
,'T8453XD'
,'T8453XS'
,'T8454XD'
,'T8454XS'
,'T8459XD'
,'T8459XS'
,'T8460XD'
,'T8460XS'
,'T84610D'
,'T84610S'
,'T84611D'
,'T84611S'
,'T84612D'
,'T84612S'
,'T84613D'
,'T84613S'
,'T84614D'
,'T84614S'
,'T84615D'
,'T84615S'
,'T84619D'
,'T84619S'
,'T84620D'
,'T84620S'
,'T84621D'
,'T84621S'
,'T84622D'
,'T84622S'
,'T84623D'
,'T84623S'
,'T84624D'
,'T84624S'
,'T84625D'
,'T84625S'
,'T84629D'
,'T84629S'
,'T8463XD'
,'T8463XS'
,'T8469XD'
,'T8469XS'
,'T847XXD'
,'T847XXS'
,'T8481XD'
,'T8481XS'
,'T8482XD'
,'T8482XS'
,'T8483XD'
,'T8483XS'
,'T8484XD'
,'T8484XS'
,'T8485XD'
,'T8485XS'
,'T8486XD'
,'T8486XS'
,'T8489XD'
,'T8489XS'
,'T849XXD'
,'T849XXS'
,'T8501XD'
,'T8501XS'
,'T8502XD'
,'T8502XS'
,'T8503XD'
,'T8503XS'
,'T8509XD'
,'T8509XS'
,'T85110D'
,'T85110S'
,'T85111D'
,'T85111S'
,'T85112D'
,'T85112S'
,'T85118D'
,'T85118S'
,'T85120D'
,'T85120S'
,'T85121D'
,'T85121S'
,'T85122D'
,'T85122S'
,'T85128D'
,'T85128S'
,'T85190D'
,'T85190S'
,'T85191D'
,'T85191S'
,'T85192D'
,'T85192S'
,'T85199D'
,'T85199S'
,'T8521XD'
,'T8521XS'
,'T8522XD'
,'T8522XS'
,'T8529XD'
,'T8529XS'
,'T85310D'
,'T85310S'
,'T85311D'
,'T85311S'
,'T85318D'
,'T85318S'
,'T85320D'
,'T85320S'
,'T85321D'
,'T85321S'
,'T85328D'
,'T85328S'
,'T85390D'
,'T85390S'
,'T85391D'
,'T85391S'
,'T85398D'
,'T85398S'
,'T8541XD'
,'T8541XS'
,'T8542XD'
,'T8542XS'
,'T8543XD'
,'T8543XS'
,'T8544XD'
,'T8544XS'
,'T8549XD'
,'T8549XS'
,'T85510D'
,'T85510S'
,'T85511D'
,'T85511S'
,'T85518D'
,'T85518S'
,'T85520D'
,'T85520S'
,'T85521D'
,'T85521S'
,'T85528D'
,'T85528S'
,'T85590D'
,'T85590S'
,'T85591D'
,'T85591S'
,'T85598D'
,'T85598S'
,'T85610D'
,'T85610S'
,'T85611D'
,'T85611S'
,'T85612D'
,'T85612S'
,'T85613D'
,'T85613S'
,'T85614D'
,'T85614S'
,'T85618D'
,'T85618S'
,'T85620D'
,'T85620S'
,'T85621D'
,'T85621S'
,'T85622D'
,'T85622S'
,'T85623D'
,'T85623S'
,'T85624D'
,'T85624S'
,'T85628D'
,'T85628S'
,'T85630D'
,'T85630S'
,'T85631D'
,'T85631S'
,'T85633D'
,'T85633S'
,'T85638D'
,'T85638S'
,'T85690D'
,'T85690S'
,'T85691D'
,'T85691S'
,'T85692D'
,'T85692S'
,'T85693D'
,'T85693S'
,'T85694D'
,'T85694S'
,'T85698D'
,'T85698S'
,'T8571XD'
,'T8571XS'
,'T8572XD'
,'T8572XS'
,'T8579XD'
,'T8579XS'
,'T8581XD'
,'T8581XS'
,'T8582XD'
,'T8582XS'
,'T8583XD'
,'T8583XS'
,'T8584XD'
,'T8584XS'
,'T8585XD'
,'T8585XS'
,'T8586XD'
,'T8586XS'
,'T8589XD'
,'T8589XS'
,'T859XXD'
,'T859XXS'
,'T8600'
,'T8601'
,'T8602'
,'T8603'
,'T8609'
,'T8610'
,'T8611'
,'T8612'
,'T8613'
,'T8619'
,'T8620'
,'T8621'
,'T8622'
,'T8623'
,'T86290'
,'T86298'
,'T8630'
,'T8631'
,'T8632'
,'T8633'
,'T8639'
,'T8640'
,'T8641'
,'T8642'
,'T8643'
,'T8649'
,'T865'
,'T86810'
,'T86811'
,'T86812'
,'T86818'
,'T86819'
,'T86820'
,'T86821'
,'T86822'
,'T86828'
,'T86829'
,'T86830'
,'T86831'
,'T86832'
,'T86838'
,'T86839'
,'T86840'
,'T86841'
,'T86842'
,'T86848'
,'T86849'
,'T86850'
,'T86851'
,'T86852'
,'T86858'
,'T86859'
,'T86890'
,'T86891'
,'T86892'
,'T86898'
,'T86899'
,'T8690'
,'T8691'
,'T8692'
,'T8693'
,'T8699'
,'T870X1'
,'T870X2'
,'T870X9'
,'T871X1'
,'T871X2'
,'T871X9'
,'T872'
,'T8730'
,'T8731'
,'T8732'
,'T8733'
,'T8734'
,'T8740'
,'T8741'
,'T8742'
,'T8743'
,'T8744'
,'T8750'
,'T8751'
,'T8752'
,'T8753'
,'T8754'
,'T8781'
,'T8789'
,'T879'
,'T880XXD'
,'T880XXS'
,'T881XXD'
,'T881XXS'
,'T882XXD'
,'T882XXS'
,'T883XXD'
,'T883XXS'
,'T884XXD'
,'T884XXS'
,'T8851XD'
,'T8851XS'
,'T8852XD'
,'T8852XS'
,'T8859XD'
,'T8859XS'
,'T886XXD'
,'T886XXS'
,'T887XXD'
,'T887XXS'
,'T888XXD'
,'T888XXS'
,'T889XXD'
,'T889XXS'
,'V0001XD'
,'V0001XS'
,'V0002XD'
,'V0002XS'
,'V0009XD'
,'V0009XS'
,'V00111D'
,'V00111S'
,'V00112D'
,'V00112S'
,'V00118D'
,'V00118S'
,'V00121D'
,'V00121S'
,'V00122D'
,'V00122S'
,'V00128D'
,'V00128S'
,'V00131D'
,'V00131S'
,'V00132D'
,'V00132S'
,'V00138D'
,'V00138S'
,'V00141D'
,'V00141S'
,'V00142D'
,'V00142S'
,'V00148D'
,'V00148S'
,'V00151D'
,'V00151S'
,'V00152D'
,'V00152S'
,'V00158D'
,'V00158S'
,'V00181D'
,'V00181S'
,'V00182D'
,'V00182S'
,'V00188D'
,'V00188S'
,'V00211D'
,'V00211S'
,'V00212D'
,'V00212S'
,'V00218D'
,'V00218S'
,'V00221D'
,'V00221S'
,'V00222D'
,'V00222S'
,'V00228D'
,'V00228S'
,'V00281D'
,'V00281S'
,'V00282D'
,'V00282S'
,'V00288D'
,'V00288S'
,'V00311D'
,'V00311S'
,'V00312D'
,'V00312S'
,'V00318D'
,'V00318S'
,'V00321D'
,'V00321S'
,'V00322D'
,'V00322S'
,'V00328D'
,'V00328S'
,'V00381D'
,'V00381S'
,'V00382D'
,'V00382S'
,'V00388D'
,'V00388S'
,'V00811D'
,'V00811S'
,'V00812D'
,'V00812S'
,'V00818D'
,'V00818S'
,'V00821D'
,'V00821S'
,'V00822D'
,'V00822S'
,'V00828D'
,'V00828S'
,'V00831D'
,'V00831S'
,'V00832D'
,'V00832S'
,'V00838D'
,'V00838S'
,'V00891D'
,'V00891S'
,'V00892D'
,'V00892S'
,'V00898D'
,'V00898S'
,'V0100XD'
,'V0100XS'
,'V0101XD'
,'V0101XS'
,'V0102XD'
,'V0102XS'
,'V0109XD'
,'V0109XS'
,'V0110XD'
,'V0110XS'
,'V0111XD'
,'V0111XS'
,'V0112XD'
,'V0112XS'
,'V0119XD'
,'V0119XS'
,'V0190XD'
,'V0190XS'
,'V0191XD'
,'V0191XS'
,'V0192XD'
,'V0192XS'
,'V0199XD'
,'V0199XS'
,'V0200XD'
,'V0200XS'
,'V0201XD'
,'V0201XS'
,'V0202XD'
,'V0202XS'
,'V0209XD'
,'V0209XS'
,'V0210XD'
,'V0210XS'
,'V0211XD'
,'V0211XS'
,'V0212XD'
,'V0212XS'
,'V0219XD'
,'V0219XS'
,'V0290XD'
,'V0290XS'
,'V0291XD'
,'V0291XS'
,'V0292XD'
,'V0292XS'
,'V0299XD'
,'V0299XS'
,'V0300XD'
,'V0300XS'
,'V0301XD'
,'V0301XS'
,'V0302XD'
,'V0302XS'
,'V0309XD'
,'V0309XS'
,'V0310XD'
,'V0310XS'
,'V0311XD'
,'V0311XS'
,'V0312XD'
,'V0312XS'
,'V0319XD'
,'V0319XS'
,'V0390XD'
,'V0390XS'
,'V0391XD'
,'V0391XS'
,'V0392XD'
,'V0392XS'
,'V0399XD'
,'V0399XS'
,'V0400XD'
,'V0400XS'
,'V0401XD'
,'V0401XS'
,'V0402XD'
,'V0402XS'
,'V0409XD'
,'V0409XS'
,'V0410XD'
,'V0410XS'
,'V0411XD'
,'V0411XS'
,'V0412XD'
,'V0412XS'
,'V0419XD'
,'V0419XS'
,'V0490XD'
,'V0490XS'
,'V0491XD'
,'V0491XS'
,'V0492XD'
,'V0492XS'
,'V0499XD'
,'V0499XS'
,'V0500XD'
,'V0500XS'
,'V0501XD'
,'V0501XS'
,'V0502XD'
,'V0502XS'
,'V0509XD'
,'V0509XS'
,'V0510XD'
,'V0510XS'
,'V0511XD'
,'V0511XS'
,'V0512XD'
,'V0512XS'
,'V0519XD'
,'V0519XS'
,'V0590XD'
,'V0590XS'
,'V0591XD'
,'V0591XS'
,'V0592XD'
,'V0592XS'
,'V0599XD'
,'V0599XS'
,'V0600XD'
,'V0600XS'
,'V0601XD'
,'V0601XS'
,'V0602XD'
,'V0602XS'
,'V0609XD'
,'V0609XS'
,'V0610XD'
,'V0610XS'
,'V0611XD'
,'V0611XS'
,'V0612XD'
,'V0612XS'
,'V0619XD'
,'V0619XS'
,'V0690XD'
,'V0690XS'
,'V0691XD'
,'V0691XS'
,'V0692XD'
,'V0692XS'
,'V0699XD'
,'V0699XS'
,'V0900XD'
,'V0900XS'
,'V0901XD'
,'V0901XS'
,'V0909XD'
,'V0909XS'
,'V091XXD'
,'V091XXS'
,'V0920XD'
,'V0920XS'
,'V0921XD'
,'V0921XS'
,'V0929XD'
,'V0929XS'
,'V093XXD'
,'V093XXS'
,'V099XXD'
,'V099XXS'
,'V100XXD'
,'V100XXS'
,'V101XXD'
,'V101XXS'
,'V102XXD'
,'V102XXS'
,'V103XXD'
,'V103XXS'
,'V104XXD'
,'V104XXS'
,'V105XXD'
,'V105XXS'
,'V109XXD'
,'V109XXS'
,'V110XXD'
,'V110XXS'
,'V111XXD'
,'V111XXS'
,'V112XXD'
,'V112XXS'
,'V113XXD'
,'V113XXS'
,'V114XXD'
,'V114XXS'
,'V115XXD'
,'V115XXS'
,'V119XXD'
,'V119XXS'
,'V120XXD'
,'V120XXS'
,'V121XXD'
,'V121XXS'
,'V122XXD'
,'V122XXS'
,'V123XXD'
,'V123XXS'
,'V124XXD'
,'V124XXS'
,'V125XXD'
,'V125XXS'
,'V129XXD'
,'V129XXS'
,'V130XXD'
,'V130XXS'
,'V131XXD'
,'V131XXS'
,'V132XXD'
,'V132XXS'
,'V133XXD'
,'V133XXS'
,'V134XXD'
,'V134XXS'
,'V135XXD'
,'V135XXS'
,'V139XXD'
,'V139XXS'
,'V140XXD'
,'V140XXS'
,'V141XXD'
,'V141XXS'
,'V142XXD'
,'V142XXS'
,'V143XXD'
,'V143XXS'
,'V144XXD'
,'V144XXS'
,'V145XXD'
,'V145XXS'
,'V149XXD'
,'V149XXS'
,'V150XXD'
,'V150XXS'
,'V151XXD'
,'V151XXS'
,'V152XXD'
,'V152XXS'
,'V153XXD'
,'V153XXS'
,'V154XXD'
,'V154XXS'
,'V155XXD'
,'V155XXS'
,'V159XXD'
,'V159XXS'
,'V160XXD'
,'V160XXS'
,'V161XXD'
,'V161XXS'
,'V162XXD'
,'V162XXS'
,'V163XXD'
,'V163XXS'
,'V164XXD'
,'V164XXS'
,'V165XXD'
,'V165XXS'
,'V169XXD'
,'V169XXS'
,'V170XXD'
,'V170XXS'
,'V171XXD'
,'V171XXS'
,'V172XXD'
,'V172XXS'
,'V173XXD'
,'V173XXS'
,'V174XXD'
,'V174XXS'
,'V175XXD'
,'V175XXS'
,'V179XXD'
,'V179XXS'
,'V180XXD'
,'V180XXS'
,'V181XXD'
,'V181XXS'
,'V182XXD'
,'V182XXS'
,'V183XXD'
,'V183XXS'
,'V184XXD'
,'V184XXS'
,'V185XXD'
,'V185XXS'
,'V189XXD'
,'V189XXS'
,'V1900XD'
,'V1900XS'
,'V1909XD'
,'V1909XS'
,'V1910XD'
,'V1910XS'
,'V1919XD'
,'V1919XS'
,'V1920XD'
,'V1920XS'
,'V1929XD'
,'V1929XS'
,'V193XXD'
,'V193XXS'
,'V1940XD'
,'V1940XS'
,'V1949XD'
,'V1949XS'
,'V1950XD'
,'V1950XS'
,'V1959XD'
,'V1959XS'
,'V1960XD'
,'V1960XS'
,'V1969XD'
,'V1969XS'
,'V1981XD'
,'V1981XS'
,'V1988XD'
,'V1988XS'
,'V199XXD'
,'V199XXS'
,'V200XXD'
,'V200XXS'
,'V201XXD'
,'V201XXS'
,'V202XXD'
,'V202XXS'
,'V203XXD'
,'V203XXS'
,'V204XXD'
,'V204XXS'
,'V205XXD'
,'V205XXS'
,'V209XXD'
,'V209XXS'
,'V210XXD'
,'V210XXS'
,'V211XXD'
,'V211XXS'
,'V212XXD'
,'V212XXS'
,'V213XXD'
,'V213XXS'
,'V214XXD'
,'V214XXS'
,'V215XXD'
,'V215XXS'
,'V219XXD'
,'V219XXS'
,'V220XXD'
,'V220XXS'
,'V221XXD'
,'V221XXS'
,'V222XXD'
,'V222XXS'
,'V223XXD'
,'V223XXS'
,'V224XXD'
,'V224XXS'
,'V225XXD'
,'V225XXS'
,'V229XXD'
,'V229XXS'
,'V230XXD'
,'V230XXS'
,'V231XXD'
,'V231XXS'
,'V232XXD'
,'V232XXS'
,'V233XXD'
,'V233XXS'
,'V234XXD'
,'V234XXS'
,'V235XXD'
,'V235XXS'
,'V239XXD'
,'V239XXS'
,'V240XXD'
,'V240XXS'
,'V241XXD'
,'V241XXS'
,'V242XXD'
,'V242XXS'
,'V243XXD'
,'V243XXS'
,'V244XXD'
,'V244XXS'
,'V245XXD'
,'V245XXS'
,'V249XXD'
,'V249XXS'
,'V250XXD'
,'V250XXS'
,'V251XXD'
,'V251XXS'
,'V252XXD'
,'V252XXS'
,'V253XXD'
,'V253XXS'
,'V254XXD'
,'V254XXS'
,'V255XXD'
,'V255XXS'
,'V259XXD'
,'V259XXS'
,'V260XXD'
,'V260XXS'
,'V261XXD'
,'V261XXS'
,'V262XXD'
,'V262XXS'
,'V263XXD'
,'V263XXS'
,'V264XXD'
,'V264XXS'
,'V265XXD'
,'V265XXS'
,'V269XXD'
,'V269XXS'
,'V270XXD'
,'V270XXS'
,'V271XXD'
,'V271XXS'
,'V272XXD'
,'V272XXS'
,'V273XXD'
,'V273XXS'
,'V274XXD'
,'V274XXS'
,'V275XXD'
,'V275XXS'
,'V279XXD'
,'V279XXS'
,'V280XXD'
,'V280XXS'
,'V281XXD'
,'V281XXS'
,'V282XXD'
,'V282XXS'
,'V283XXD'
,'V283XXS'
,'V284XXD'
,'V284XXS'
,'V285XXD'
,'V285XXS'
,'V289XXD'
,'V289XXS'
,'V2900XD'
,'V2900XS'
,'V2909XD'
,'V2909XS'
,'V2910XD'
,'V2910XS'
,'V2919XD'
,'V2919XS'
,'V2920XD'
,'V2920XS'
,'V2929XD'
,'V2929XS'
,'V293XXD'
,'V293XXS'
,'V2940XD'
,'V2940XS'
,'V2949XD'
,'V2949XS'
,'V2950XD'
,'V2950XS'
,'V2959XD'
,'V2959XS'
,'V2960XD'
,'V2960XS'
,'V2969XD'
,'V2969XS'
,'V2981XD'
,'V2981XS'
,'V2988XD'
,'V2988XS'
,'V299XXD'
,'V299XXS'
,'V300XXD'
,'V300XXS'
,'V301XXD'
,'V301XXS'
,'V302XXD'
,'V302XXS'
,'V303XXD'
,'V303XXS'
,'V304XXD'
,'V304XXS'
,'V305XXD'
,'V305XXS'
,'V306XXD'
,'V306XXS'
,'V307XXD'
,'V307XXS'
,'V309XXD'
,'V309XXS'
,'V310XXD'
,'V310XXS'
,'V311XXD'
,'V311XXS'
,'V312XXD'
,'V312XXS'
,'V313XXD'
,'V313XXS'
,'V314XXD'
,'V314XXS'
,'V315XXD'
,'V315XXS'
,'V316XXD'
,'V316XXS'
,'V317XXD'
,'V317XXS'
,'V319XXD'
,'V319XXS'
,'V320XXD'
,'V320XXS'
,'V321XXD'
,'V321XXS'
,'V322XXD'
,'V322XXS'
,'V323XXD'
,'V323XXS'
,'V324XXD'
,'V324XXS'
,'V325XXD'
,'V325XXS'
,'V326XXD'
,'V326XXS'
,'V327XXD'
,'V327XXS'
,'V329XXD'
,'V329XXS'
,'V330XXD'
,'V330XXS'
,'V331XXD'
,'V331XXS'
,'V332XXD'
,'V332XXS'
,'V333XXD'
,'V333XXS'
,'V334XXD'
,'V334XXS'
,'V335XXD'
,'V335XXS'
,'V336XXD'
,'V336XXS'
,'V337XXD'
,'V337XXS'
,'V339XXD'
,'V339XXS'
,'V340XXD'
,'V340XXS'
,'V341XXD'
,'V341XXS'
,'V342XXD'
,'V342XXS'
,'V343XXD'
,'V343XXS'
,'V344XXD'
,'V344XXS'
,'V345XXD'
,'V345XXS'
,'V346XXD'
,'V346XXS'
,'V347XXD'
,'V347XXS'
,'V349XXD'
,'V349XXS'
,'V350XXD'
,'V350XXS'
,'V351XXD'
,'V351XXS'
,'V352XXD'
,'V352XXS'
,'V353XXD'
,'V353XXS'
,'V354XXD'
,'V354XXS'
,'V355XXD'
,'V355XXS'
,'V356XXD'
,'V356XXS'
,'V357XXD'
,'V357XXS'
,'V359XXD'
,'V359XXS'
,'V360XXD'
,'V360XXS'
,'V361XXD'
,'V361XXS'
,'V362XXD'
,'V362XXS'
,'V363XXD'
,'V363XXS'
,'V364XXD'
,'V364XXS'
,'V365XXD'
,'V365XXS'
,'V366XXD'
,'V366XXS'
,'V367XXD'
,'V367XXS'
,'V369XXD'
,'V369XXS'
,'V370XXD'
,'V370XXS'
,'V371XXD'
,'V371XXS'
,'V372XXD'
,'V372XXS'
,'V373XXD'
,'V373XXS'
,'V374XXD'
,'V374XXS'
,'V375XXD'
,'V375XXS'
,'V376XXD'
,'V376XXS'
,'V377XXD'
,'V377XXS'
,'V379XXD'
,'V379XXS'
,'V380XXD'
,'V380XXS'
,'V381XXD'
,'V381XXS'
,'V382XXD'
,'V382XXS'
,'V383XXD'
,'V383XXS'
,'V384XXD'
,'V384XXS'
,'V385XXD'
,'V385XXS'
,'V386XXD'
,'V386XXS'
,'V387XXD'
,'V387XXS'
,'V389XXD'
,'V389XXS'
,'V3900XD'
,'V3900XS'
,'V3909XD'
,'V3909XS'
,'V3910XD'
,'V3910XS'
,'V3919XD'
,'V3919XS'
,'V3920XD'
,'V3920XS'
,'V3929XD'
,'V3929XS'
,'V393XXD'
,'V393XXS'
,'V3940XD'
,'V3940XS'
,'V3949XD'
,'V3949XS'
,'V3950XD'
,'V3950XS'
,'V3959XD'
,'V3959XS'
,'V3960XD'
,'V3960XS'
,'V3969XD'
,'V3969XS'
,'V3981XD'
,'V3981XS'
,'V3989XD'
,'V3989XS'
,'V399XXD'
,'V399XXS'
,'V400XXD'
,'V400XXS'
,'V401XXD'
,'V401XXS'
,'V402XXD'
,'V402XXS'
,'V403XXD'
,'V403XXS'
,'V404XXD'
,'V404XXS'
,'V405XXD'
,'V405XXS'
,'V406XXD'
,'V406XXS'
,'V407XXD'
,'V407XXS'
,'V409XXD'
,'V409XXS'
,'V410XXD'
,'V410XXS'
,'V411XXD'
,'V411XXS'
,'V412XXD'
,'V412XXS'
,'V413XXD'
,'V413XXS'
,'V414XXD'
,'V414XXS'
,'V415XXD'
,'V415XXS'
,'V416XXD'
,'V416XXS'
,'V417XXD'
,'V417XXS'
,'V419XXD'
,'V419XXS'
,'V420XXD'
,'V420XXS'
,'V421XXD'
,'V421XXS'
,'V422XXD'
,'V422XXS'
,'V423XXD'
,'V423XXS'
,'V424XXD'
,'V424XXS'
,'V425XXD'
,'V425XXS'
,'V426XXD'
,'V426XXS'
,'V427XXD'
,'V427XXS'
,'V429XXD'
,'V429XXS'
,'V4301XD'
,'V4301XS'
,'V4302XD'
,'V4302XS'
,'V4303XD'
,'V4303XS'
,'V4304XD'
,'V4304XS'
,'V4311XD'
,'V4311XS'
,'V4312XD'
,'V4312XS'
,'V4313XD'
,'V4313XS'
,'V4314XD'
,'V4314XS'
,'V4321XD'
,'V4321XS'
,'V4322XD'
,'V4322XS'
,'V4323XD'
,'V4323XS'
,'V4324XD'
,'V4324XS'
,'V4331XD'
,'V4331XS'
,'V4332XD'
,'V4332XS'
,'V4333XD'
,'V4333XS'
,'V4334XD'
,'V4334XS'
,'V4341XD'
,'V4341XS'
,'V4342XD'
,'V4342XS'
,'V4343XD'
,'V4343XS'
,'V4344XD'
,'V4344XS'
,'V4351XD'
,'V4351XS'
,'V4352XD'
,'V4352XS'
,'V4353XD'
,'V4353XS'
,'V4354XD'
,'V4354XS'
,'V4361XD'
,'V4361XS'
,'V4362XD'
,'V4362XS'
,'V4363XD'
,'V4363XS'
,'V4364XD'
,'V4364XS'
,'V4371XD'
,'V4371XS'
,'V4372XD'
,'V4372XS'
,'V4373XD'
,'V4373XS'
,'V4374XD'
,'V4374XS'
,'V4391XD'
,'V4391XS'
,'V4392XD'
,'V4392XS'
,'V4393XD'
,'V4393XS'
,'V4394XD'
,'V4394XS'
,'V440XXD'
,'V440XXS'
,'V441XXD'
,'V441XXS'
,'V442XXD'
,'V442XXS'
,'V443XXD'
,'V443XXS'
,'V444XXD'
,'V444XXS'
,'V445XXD'
,'V445XXS'
,'V446XXD'
,'V446XXS'
,'V447XXD'
,'V447XXS'
,'V449XXD'
,'V449XXS'
,'V450XXD'
,'V450XXS'
,'V451XXD'
,'V451XXS'
,'V452XXD'
,'V452XXS'
,'V453XXD'
,'V453XXS'
,'V454XXD'
,'V454XXS'
,'V455XXD'
,'V455XXS'
,'V456XXD'
,'V456XXS'
,'V457XXD'
,'V457XXS'
,'V459XXD'
,'V459XXS'
,'V460XXD'
,'V460XXS'
,'V461XXD'
,'V461XXS'
,'V462XXD'
,'V462XXS'
,'V463XXD'
,'V463XXS'
,'V464XXD'
,'V464XXS'
,'V465XXD'
,'V465XXS'
,'V466XXD'
,'V466XXS'
,'V467XXD'
,'V467XXS'
,'V469XXD'
,'V469XXS'
,'V4701XD'
,'V4701XS'
,'V4702XD'
,'V4702XS'
,'V4711XD'
,'V4711XS'
,'V4712XD'
,'V4712XS'
,'V472XXD'
,'V472XXS'
,'V4731XD'
,'V4731XS'
,'V4732XD'
,'V4732XS'
,'V474XXD'
,'V474XXS'
,'V4751XD'
,'V4751XS'
,'V4752XD'
,'V4752XS'
,'V4761XD'
,'V4761XS'
,'V4762XD'
,'V4762XS'
,'V477XXD'
,'V477XXS'
,'V4791XD'
,'V4791XS'
,'V4792XD'
,'V4792XS'
,'V480XXD'
,'V480XXS'
,'V481XXD'
,'V481XXS'
,'V482XXD'
,'V482XXS'
,'V483XXD'
,'V483XXS'
,'V484XXD'
,'V484XXS'
,'V485XXD'
,'V485XXS'
,'V486XXD'
,'V486XXS'
,'V487XXD'
,'V487XXS'
,'V489XXD'
,'V489XXS'
,'V4900XD'
,'V4900XS'
,'V4909XD'
,'V4909XS'
,'V4910XD'
,'V4910XS'
,'V4919XD'
,'V4919XS'
,'V4920XD'
,'V4920XS'
,'V4929XD'
,'V4929XS'
,'V493XXD'
,'V493XXS'
,'V4940XD'
,'V4940XS'
,'V4949XD'
,'V4949XS'
,'V4950XD'
,'V4950XS'
,'V4959XD'
,'V4959XS'
,'V4960XD'
,'V4960XS'
,'V4969XD'
,'V4969XS'
,'V4981XD'
,'V4981XS'
,'V4988XD'
,'V4988XS'
,'V499XXD'
,'V499XXS'
,'V500XXD'
,'V500XXS'
,'V501XXD'
,'V501XXS'
,'V502XXD'
,'V502XXS'
,'V503XXD'
,'V503XXS'
,'V504XXD'
,'V504XXS'
,'V505XXD'
,'V505XXS'
,'V506XXD'
,'V506XXS'
,'V507XXD'
,'V507XXS'
,'V509XXD'
,'V509XXS'
,'V510XXD'
,'V510XXS'
,'V511XXD'
,'V511XXS'
,'V512XXD'
,'V512XXS'
,'V513XXD'
,'V513XXS'
,'V514XXD'
,'V514XXS'
,'V515XXD'
,'V515XXS'
,'V516XXD'
,'V516XXS'
,'V517XXD'
,'V517XXS'
,'V519XXD'
,'V519XXS'
,'V520XXD'
,'V520XXS'
,'V521XXD'
,'V521XXS'
,'V522XXD'
,'V522XXS'
,'V523XXD'
,'V523XXS'
,'V524XXD'
,'V524XXS'
,'V525XXD'
,'V525XXS'
,'V526XXD'
,'V526XXS'
,'V527XXD'
,'V527XXS'
,'V529XXD'
,'V529XXS'
,'V530XXD'
,'V530XXS'
,'V531XXD'
,'V531XXS'
,'V532XXD'
,'V532XXS'
,'V533XXD'
,'V533XXS'
,'V534XXD'
,'V534XXS'
,'V535XXD'
,'V535XXS'
,'V536XXD'
,'V536XXS'
,'V537XXD'
,'V537XXS'
,'V539XXD'
,'V539XXS'
,'V540XXD'
,'V540XXS'
,'V541XXD'
,'V541XXS'
,'V542XXD'
,'V542XXS'
,'V543XXD'
,'V543XXS'
,'V544XXD'
,'V544XXS'
,'V545XXD'
,'V545XXS'
,'V546XXD'
,'V546XXS'
,'V547XXD'
,'V547XXS'
,'V549XXD'
,'V549XXS'
,'V550XXD'
,'V550XXS'
,'V551XXD'
,'V551XXS'
,'V552XXD'
,'V552XXS'
,'V553XXD'
,'V553XXS'
,'V554XXD'
,'V554XXS'
,'V555XXD'
,'V555XXS'
,'V556XXD'
,'V556XXS'
,'V557XXD'
,'V557XXS'
,'V559XXD'
,'V559XXS'
,'V560XXD'
,'V560XXS'
,'V561XXD'
,'V561XXS'
,'V562XXD'
,'V562XXS'
,'V563XXD'
,'V563XXS'
,'V564XXD'
,'V564XXS'
,'V565XXD'
,'V565XXS'
,'V566XXD'
,'V566XXS'
,'V567XXD'
,'V567XXS'
,'V569XXD'
,'V569XXS'
,'V570XXD'
,'V570XXS'
,'V571XXD'
,'V571XXS'
,'V572XXD'
,'V572XXS'
,'V573XXD'
,'V573XXS'
,'V574XXD'
,'V574XXS'
,'V575XXD'
,'V575XXS'
,'V576XXD'
,'V576XXS'
,'V577XXD'
,'V577XXS'
,'V579XXD'
,'V579XXS'
,'V580XXD'
,'V580XXS'
,'V581XXD'
,'V581XXS'
,'V582XXD'
,'V582XXS'
,'V583XXD'
,'V583XXS'
,'V584XXD'
,'V584XXS'
,'V585XXD'
,'V585XXS'
,'V586XXD'
,'V586XXS'
,'V587XXD'
,'V587XXS'
,'V589XXD'
,'V589XXS'
,'V5900XD'
,'V5900XS'
,'V5909XD'
,'V5909XS'
,'V5910XD'
,'V5910XS'
,'V5919XD'
,'V5919XS'
,'V5920XD'
,'V5920XS'
,'V5929XD'
,'V5929XS'
,'V593XXD'
,'V593XXS'
,'V5940XD'
,'V5940XS'
,'V5949XD'
,'V5949XS'
,'V5950XD'
,'V5950XS'
,'V5959XD'
,'V5959XS'
,'V5960XD'
,'V5960XS'
,'V5969XD'
,'V5969XS'
,'V5981XD'
,'V5981XS'
,'V5988XD'
,'V5988XS'
,'V599XXD'
,'V599XXS'
,'V600XXD'
,'V600XXS'
,'V601XXD'
,'V601XXS'
,'V602XXD'
,'V602XXS'
,'V603XXD'
,'V603XXS'
,'V604XXD'
,'V604XXS'
,'V605XXD'
,'V605XXS'
,'V606XXD'
,'V606XXS'
,'V607XXD'
,'V607XXS'
,'V609XXD'
,'V609XXS'
,'V610XXD'
,'V610XXS'
,'V611XXD'
,'V611XXS'
,'V612XXD'
,'V612XXS'
,'V613XXD'
,'V613XXS'
,'V614XXD'
,'V614XXS'
,'V615XXD'
,'V615XXS'
,'V616XXD'
,'V616XXS'
,'V617XXD'
,'V617XXS'
,'V619XXD'
,'V619XXS'
,'V620XXD'
,'V620XXS'
,'V621XXD'
,'V621XXS'
,'V622XXD'
,'V622XXS'
,'V623XXD'
,'V623XXS'
,'V624XXD'
,'V624XXS'
,'V625XXD'
,'V625XXS'
,'V626XXD'
,'V626XXS'
,'V627XXD'
,'V627XXS'
,'V629XXD'
,'V629XXS'
,'V630XXD'
,'V630XXS'
,'V631XXD'
,'V631XXS'
,'V632XXD'
,'V632XXS'
,'V633XXD'
,'V633XXS'
,'V634XXD'
,'V634XXS'
,'V635XXD'
,'V635XXS'
,'V636XXD'
,'V636XXS'
,'V637XXD'
,'V637XXS'
,'V639XXD'
,'V639XXS'
,'V640XXD'
,'V640XXS'
,'V641XXD'
,'V641XXS'
,'V642XXD'
,'V642XXS'
,'V643XXD'
,'V643XXS'
,'V644XXD'
,'V644XXS'
,'V645XXD'
,'V645XXS'
,'V646XXD'
,'V646XXS'
,'V647XXD'
,'V647XXS'
,'V649XXD'
,'V649XXS'
,'V650XXD'
,'V650XXS'
,'V651XXD'
,'V651XXS'
,'V652XXD'
,'V652XXS'
,'V653XXD'
,'V653XXS'
,'V654XXD'
,'V654XXS'
,'V655XXD'
,'V655XXS'
,'V656XXD'
,'V656XXS'
,'V657XXD'
,'V657XXS'
,'V659XXD'
,'V659XXS'
,'V660XXD'
,'V660XXS'
,'V661XXD'
,'V661XXS'
,'V662XXD'
,'V662XXS'
,'V663XXD'
,'V663XXS'
,'V664XXD'
,'V664XXS'
,'V665XXD'
,'V665XXS'
,'V666XXD'
,'V666XXS'
,'V667XXD'
,'V667XXS'
,'V669XXD'
,'V669XXS'
,'V670XXD'
,'V670XXS'
,'V671XXD'
,'V671XXS'
,'V672XXD'
,'V672XXS'
,'V673XXD'
,'V673XXS'
,'V674XXD'
,'V674XXS'
,'V675XXD'
,'V675XXS'
,'V676XXD'
,'V676XXS'
,'V677XXD'
,'V677XXS'
,'V679XXD'
,'V679XXS'
,'V680XXD'
,'V680XXS'
,'V681XXD'
,'V681XXS'
,'V682XXD'
,'V682XXS'
,'V683XXD'
,'V683XXS'
,'V684XXD'
,'V684XXS'
,'V685XXD'
,'V685XXS'
,'V686XXD'
,'V686XXS'
,'V687XXD'
,'V687XXS'
,'V689XXD'
,'V689XXS'
,'V6900XD'
,'V6900XS'
,'V6909XD'
,'V6909XS'
,'V6910XD'
,'V6910XS'
,'V6919XD'
,'V6919XS'
,'V6920XD'
,'V6920XS'
,'V6929XD'
,'V6929XS'
,'V693XXD'
,'V693XXS'
,'V6940XD'
,'V6940XS'
,'V6949XD'
,'V6949XS'
,'V6950XD'
,'V6950XS'
,'V6959XD'
,'V6959XS'
,'V6960XD'
,'V6960XS'
,'V6969XD'
,'V6969XS'
,'V6981XD'
,'V6981XS'
,'V6988XD'
,'V6988XS'
,'V699XXD'
,'V699XXS'
,'V700XXD'
,'V700XXS'
,'V701XXD'
,'V701XXS'
,'V702XXD'
,'V702XXS'
,'V703XXD'
,'V703XXS'
,'V704XXD'
,'V704XXS'
,'V705XXD'
,'V705XXS'
,'V706XXD'
,'V706XXS'
,'V707XXD'
,'V707XXS'
,'V709XXD'
,'V709XXS'
,'V710XXD'
,'V710XXS'
,'V711XXD'
,'V711XXS'
,'V712XXD'
,'V712XXS'
,'V713XXD'
,'V713XXS'
,'V714XXD'
,'V714XXS'
,'V715XXD'
,'V715XXS'
,'V716XXD'
,'V716XXS'
,'V717XXD'
,'V717XXS'
,'V719XXD'
,'V719XXS'
,'V720XXD'
,'V720XXS'
,'V721XXD'
,'V721XXS'
,'V722XXD'
,'V722XXS'
,'V723XXD'
,'V723XXS'
,'V724XXD'
,'V724XXS'
,'V725XXD'
,'V725XXS'
,'V726XXD'
,'V726XXS'
,'V727XXD'
,'V727XXS'
,'V729XXD'
,'V729XXS'
,'V730XXD'
,'V730XXS'
,'V731XXD'
,'V731XXS'
,'V732XXD'
,'V732XXS'
,'V733XXD'
,'V733XXS'
,'V734XXD'
,'V734XXS'
,'V735XXD'
,'V735XXS'
,'V736XXD'
,'V736XXS'
,'V737XXD'
,'V737XXS'
,'V739XXD'
,'V739XXS'
,'V740XXD'
,'V740XXS'
,'V741XXD'
,'V741XXS'
,'V742XXD'
,'V742XXS'
,'V743XXD'
,'V743XXS'
,'V744XXD'
,'V744XXS'
,'V745XXD'
,'V745XXS'
,'V746XXD'
,'V746XXS'
,'V747XXD'
,'V747XXS'
,'V749XXD'
,'V749XXS'
,'V750XXD'
,'V750XXS'
,'V751XXD'
,'V751XXS'
,'V752XXD'
,'V752XXS'
,'V753XXD'
,'V753XXS'
,'V754XXD'
,'V754XXS'
,'V755XXD'
,'V755XXS'
,'V756XXD'
,'V756XXS'
,'V757XXD'
,'V757XXS'
,'V759XXD'
,'V759XXS'
,'V760XXD'
,'V760XXS'
,'V761XXD'
,'V761XXS'
,'V762XXD'
,'V762XXS'
,'V763XXD'
,'V763XXS'
,'V764XXD'
,'V764XXS'
,'V765XXD'
,'V765XXS'
,'V766XXD'
,'V766XXS'
,'V767XXD'
,'V767XXS'
,'V769XXD'
,'V769XXS'
,'V770XXD'
,'V770XXS'
,'V771XXD'
,'V771XXS'
,'V772XXD'
,'V772XXS'
,'V773XXD'
,'V773XXS'
,'V774XXD'
,'V774XXS'
,'V775XXD'
,'V775XXS'
,'V776XXD'
,'V776XXS'
,'V777XXD'
,'V777XXS'
,'V779XXD'
,'V779XXS'
,'V780XXD'
,'V780XXS'
,'V781XXD'
,'V781XXS'
,'V782XXD'
,'V782XXS'
,'V783XXD'
,'V783XXS'
,'V784XXD'
,'V784XXS'
,'V785XXD'
,'V785XXS'
,'V786XXD'
,'V786XXS'
,'V787XXD'
,'V787XXS'
,'V789XXD'
,'V789XXS'
,'V7900XD'
,'V7900XS'
,'V7909XD'
,'V7909XS'
,'V7910XD'
,'V7910XS'
,'V7919XD'
,'V7919XS'
,'V7920XD'
,'V7920XS'
,'V7929XD'
,'V7929XS'
,'V793XXD'
,'V793XXS'
,'V7940XD'
,'V7940XS'
,'V7949XD'
,'V7949XS'
,'V7950XD'
,'V7950XS'
,'V7959XD'
,'V7959XS'
,'V7960XD'
,'V7960XS'
,'V7969XD'
,'V7969XS'
,'V7981XD'
,'V7981XS'
,'V7988XD'
,'V7988XS'
,'V799XXD'
,'V799XXS'
,'V80010D'
,'V80010S'
,'V80018D'
,'V80018S'
,'V8002XD'
,'V8002XS'
,'V8011XD'
,'V8011XS'
,'V8012XD'
,'V8012XS'
,'V8021XD'
,'V8021XS'
,'V8022XD'
,'V8022XS'
,'V8031XD'
,'V8031XS'
,'V8032XD'
,'V8032XS'
,'V8041XD'
,'V8041XS'
,'V8042XD'
,'V8042XS'
,'V8051XD'
,'V8051XS'
,'V8052XD'
,'V8052XS'
,'V8061XD'
,'V8061XS'
,'V8062XD'
,'V8062XS'
,'V80710D'
,'V80710S'
,'V80711D'
,'V80711S'
,'V80720D'
,'V80720S'
,'V80721D'
,'V80721S'
,'V80730D'
,'V80730S'
,'V80731D'
,'V80731S'
,'V80790D'
,'V80790S'
,'V80791D'
,'V80791S'
,'V8081XD'
,'V8081XS'
,'V8082XD'
,'V8082XS'
,'V80910D'
,'V80910S'
,'V80918D'
,'V80918S'
,'V80919D'
,'V80919S'
,'V80920D'
,'V80920S'
,'V80928D'
,'V80928S'
,'V80929D'
,'V80929S'
,'V810XXD'
,'V810XXS'
,'V811XXD'
,'V811XXS'
,'V812XXD'
,'V812XXS'
,'V813XXD'
,'V813XXS'
,'V814XXD'
,'V814XXS'
,'V815XXD'
,'V815XXS'
,'V816XXD'
,'V816XXS'
,'V817XXD'
,'V817XXS'
,'V8181XD'
,'V8181XS'
,'V8182XD'
,'V8182XS'
,'V8183XD'
,'V8183XS'
,'V8189XD'
,'V8189XS'
,'V819XXD'
,'V819XXS'
,'V820XXD'
,'V820XXS'
,'V821XXD'
,'V821XXS'
,'V822XXD'
,'V822XXS'
,'V823XXD'
,'V823XXS'
,'V824XXD'
,'V824XXS'
,'V825XXD'
,'V825XXS'
,'V826XXD'
,'V826XXS'
,'V827XXD'
,'V827XXS'
,'V828XXD'
,'V828XXS'
,'V829XXD'
,'V829XXS'
,'V830XXD'
,'V830XXS'
,'V831XXD'
,'V831XXS'
,'V832XXD'
,'V832XXS'
,'V833XXD'
,'V833XXS'
,'V834XXD'
,'V834XXS'
,'V835XXD'
,'V835XXS'
,'V836XXD'
,'V836XXS'
,'V837XXD'
,'V837XXS'
,'V839XXD'
,'V839XXS'
,'V840XXD'
,'V840XXS'
,'V841XXD'
,'V841XXS'
,'V842XXD'
,'V842XXS'
,'V843XXD'
,'V843XXS'
,'V844XXD'
,'V844XXS'
,'V845XXD'
,'V845XXS'
,'V846XXD'
,'V846XXS'
,'V847XXD'
,'V847XXS'
,'V849XXD'
,'V849XXS'
,'V850XXD'
,'V850XXS'
,'V851XXD'
,'V851XXS'
,'V852XXD'
,'V852XXS'
,'V853XXD'
,'V853XXS'
,'V854XXD'
,'V854XXS'
,'V855XXD'
,'V855XXS'
,'V856XXD'
,'V856XXS'
,'V857XXD'
,'V857XXS'
,'V859XXD'
,'V859XXS'
,'V8601XD'
,'V8601XS'
,'V8602XD'
,'V8602XS'
,'V8603XD'
,'V8603XS'
,'V8604XD'
,'V8604XS'
,'V8609XD'
,'V8609XS'
,'V8611XD'
,'V8611XS'
,'V8612XD'
,'V8612XS'
,'V8613XD'
,'V8613XS'
,'V8614XD'
,'V8614XS'
,'V8619XD'
,'V8619XS'
,'V8621XD'
,'V8621XS'
,'V8622XD'
,'V8622XS'
,'V8623XD'
,'V8623XS'
,'V8624XD'
,'V8624XS'
,'V8629XD'
,'V8629XS'
,'V8631XD'
,'V8631XS'
,'V8632XD'
,'V8632XS'
,'V8633XD'
,'V8633XS'
,'V8634XD'
,'V8634XS'
,'V8639XD'
,'V8639XS'
,'V8641XD'
,'V8641XS'
,'V8642XD'
,'V8642XS'
,'V8643XD'
,'V8643XS'
,'V8644XD'
,'V8644XS'
,'V8649XD'
,'V8649XS'
,'V8651XD'
,'V8651XS'
,'V8652XD'
,'V8652XS'
,'V8653XD'
,'V8653XS'
,'V8654XD'
,'V8654XS'
,'V8659XD'
,'V8659XS'
,'V8661XD'
,'V8661XS'
,'V8662XD'
,'V8662XS'
,'V8663XD'
,'V8663XS'
,'V8664XD'
,'V8664XS'
,'V8669XD'
,'V8669XS'
,'V8671XD'
,'V8671XS'
,'V8672XD'
,'V8672XS'
,'V8673XD'
,'V8673XS'
,'V8674XD'
,'V8674XS'
,'V8679XD'
,'V8679XS'
,'V8691XD'
,'V8691XS'
,'V8692XD'
,'V8692XS'
,'V8693XD'
,'V8693XS'
,'V8694XD'
,'V8694XS'
,'V8699XD'
,'V8699XS'
,'V870XXD'
,'V870XXS'
,'V871XXD'
,'V871XXS'
,'V872XXD'
,'V872XXS'
,'V873XXD'
,'V873XXS'
,'V874XXD'
,'V874XXS'
,'V875XXD'
,'V875XXS'
,'V876XXD'
,'V876XXS'
,'V877XXD'
,'V877XXS'
,'V878XXD'
,'V878XXS'
,'V879XXD'
,'V879XXS'
,'V880XXD'
,'V880XXS'
,'V881XXD'
,'V881XXS'
,'V882XXD'
,'V882XXS'
,'V883XXD'
,'V883XXS'
,'V884XXD'
,'V884XXS'
,'V885XXD'
,'V885XXS'
,'V886XXD'
,'V886XXS'
,'V887XXD'
,'V887XXS'
,'V888XXD'
,'V888XXS'
,'V889XXD'
,'V889XXS'
,'V890XXD'
,'V890XXS'
,'V891XXD'
,'V891XXS'
,'V892XXD'
,'V892XXS'
,'V893XXD'
,'V893XXS'
,'V899XXD'
,'V899XXS'
,'V9000XD'
,'V9000XS'
,'V9001XD'
,'V9001XS'
,'V9002XD'
,'V9002XS'
,'V9003XD'
,'V9003XS'
,'V9004XD'
,'V9004XS'
,'V9005XD'
,'V9005XS'
,'V9006XD'
,'V9006XS'
,'V9008XD'
,'V9008XS'
,'V9009XD'
,'V9009XS'
,'V9010XD'
,'V9010XS'
,'V9011XD'
,'V9011XS'
,'V9012XD'
,'V9012XS'
,'V9013XD'
,'V9013XS'
,'V9014XD'
,'V9014XS'
,'V9015XD'
,'V9015XS'
,'V9016XD'
,'V9016XS'
,'V9018XD'
,'V9018XS'
,'V9019XD'
,'V9019XS'
,'V9020XD'
,'V9020XS'
,'V9021XD'
,'V9021XS'
,'V9022XD'
,'V9022XS'
,'V9023XD'
,'V9023XS'
,'V9024XD'
,'V9024XS'
,'V9025XD'
,'V9025XS'
,'V9026XD'
,'V9026XS'
,'V9027XD'
,'V9027XS'
,'V9028XD'
,'V9028XS'
,'V9029XD'
,'V9029XS'
,'V9030XD'
,'V9030XS'
,'V9031XD'
,'V9031XS'
,'V9032XD'
,'V9032XS'
,'V9033XD'
,'V9033XS'
,'V9034XD'
,'V9034XS'
,'V9035XD'
,'V9035XS'
,'V9036XD'
,'V9036XS'
,'V9037XD'
,'V9037XS'
,'V9038XD'
,'V9038XS'
,'V9039XD'
,'V9039XS'
,'V9080XD'
,'V9080XS'
,'V9081XD'
,'V9081XS'
,'V9082XD'
,'V9082XS'
,'V9083XD'
,'V9083XS'
,'V9084XD'
,'V9084XS'
,'V9085XD'
,'V9085XS'
,'V9086XD'
,'V9086XS'
,'V9087XD'
,'V9087XS'
,'V9088XD'
,'V9088XS'
,'V9089XD'
,'V9089XS'
,'V9100XD'
,'V9100XS'
,'V9101XD'
,'V9101XS'
,'V9102XD'
,'V9102XS'
,'V9103XD'
,'V9103XS'
,'V9104XD'
,'V9104XS'
,'V9105XD'
,'V9105XS'
,'V9106XD'
,'V9106XS'
,'V9107XD'
,'V9107XS'
,'V9108XD'
,'V9108XS'
,'V9109XD'
,'V9109XS'
,'V9110XD'
,'V9110XS'
,'V9111XD'
,'V9111XS'
,'V9112XD'
,'V9112XS'
,'V9113XD'
,'V9113XS'
,'V9114XD'
,'V9114XS'
,'V9115XD'
,'V9115XS'
,'V9116XD'
,'V9116XS'
,'V9118XD'
,'V9118XS'
,'V9119XD'
,'V9119XS'
,'V9120XD'
,'V9120XS'
,'V9121XD'
,'V9121XS'
,'V9122XD'
,'V9122XS'
,'V9123XD'
,'V9123XS'
,'V9124XD'
,'V9124XS'
,'V9125XD'
,'V9125XS'
,'V9126XD'
,'V9126XS'
,'V9129XD'
,'V9129XS'
,'V9130XD'
,'V9130XS'
,'V9131XD'
,'V9131XS'
,'V9132XD'
,'V9132XS'
,'V9133XD'
,'V9133XS'
,'V9134XD'
,'V9134XS'
,'V9135XD'
,'V9135XS'
,'V9136XD'
,'V9136XS'
,'V9137XD'
,'V9137XS'
,'V9138XD'
,'V9138XS'
,'V9139XD'
,'V9139XS'
,'V9180XD'
,'V9180XS'
,'V9181XD'
,'V9181XS'
,'V9182XD'
,'V9182XS'
,'V9183XD'
,'V9183XS'
,'V9184XD'
,'V9184XS'
,'V9185XD'
,'V9185XS'
,'V9186XD'
,'V9186XS'
,'V9187XD'
,'V9187XS'
,'V9188XD'
,'V9188XS'
,'V9189XD'
,'V9189XS'
,'V9200XD'
,'V9200XS'
,'V9201XD'
,'V9201XS'
,'V9202XD'
,'V9202XS'
,'V9203XD'
,'V9203XS'
,'V9204XD'
,'V9204XS'
,'V9205XD'
,'V9205XS'
,'V9206XD'
,'V9206XS'
,'V9207XD'
,'V9207XS'
,'V9208XD'
,'V9208XS'
,'V9209XD'
,'V9209XS'
,'V9210XD'
,'V9210XS'
,'V9211XD'
,'V9211XS'
,'V9212XD'
,'V9212XS'
,'V9213XD'
,'V9213XS'
,'V9214XD'
,'V9214XS'
,'V9215XD'
,'V9215XS'
,'V9216XD'
,'V9216XS'
,'V9219XD'
,'V9219XS'
,'V9220XD'
,'V9220XS'
,'V9221XD'
,'V9221XS'
,'V9222XD'
,'V9222XS'
,'V9223XD'
,'V9223XS'
,'V9224XD'
,'V9224XS'
,'V9225XD'
,'V9225XS'
,'V9226XD'
,'V9226XS'
,'V9227XD'
,'V9227XS'
,'V9228XD'
,'V9228XS'
,'V9229XD'
,'V9229XS'
,'V9300XD'
,'V9300XS'
,'V9301XD'
,'V9301XS'
,'V9302XD'
,'V9302XS'
,'V9303XD'
,'V9303XS'
,'V9304XD'
,'V9304XS'
,'V9309XD'
,'V9309XS'
,'V9310XD'
,'V9310XS'
,'V9311XD'
,'V9311XS'
,'V9312XD'
,'V9312XS'
,'V9313XD'
,'V9313XS'
,'V9314XD'
,'V9314XS'
,'V9319XD'
,'V9319XS'
,'V9320XD'
,'V9320XS'
,'V9321XD'
,'V9321XS'
,'V9322XD'
,'V9322XS'
,'V9323XD'
,'V9323XS'
,'V9324XD'
,'V9324XS'
,'V9329XD'
,'V9329XS'
,'V9330XD'
,'V9330XS'
,'V9331XD'
,'V9331XS'
,'V9332XD'
,'V9332XS'
,'V9333XD'
,'V9333XS'
,'V9334XD'
,'V9334XS'
,'V9335XD'
,'V9335XS'
,'V9336XD'
,'V9336XS'
,'V9338XD'
,'V9338XS'
,'V9339XD'
,'V9339XS'
,'V9340XD'
,'V9340XS'
,'V9341XD'
,'V9341XS'
,'V9342XD'
,'V9342XS'
,'V9343XD'
,'V9343XS'
,'V9344XD'
,'V9344XS'
,'V9348XD'
,'V9348XS'
,'V9349XD'
,'V9349XS'
,'V9350XD'
,'V9350XS'
,'V9351XD'
,'V9351XS'
,'V9352XD'
,'V9352XS'
,'V9353XD'
,'V9353XS'
,'V9354XD'
,'V9354XS'
,'V9359XD'
,'V9359XS'
,'V9360XD'
,'V9360XS'
,'V9361XD'
,'V9361XS'
,'V9362XD'
,'V9362XS'
,'V9363XD'
,'V9363XS'
,'V9364XD'
,'V9364XS'
,'V9369XD'
,'V9369XS'
,'V9380XD'
,'V9380XS'
,'V9381XD'
,'V9381XS'
,'V9382XD'
,'V9382XS'
,'V9383XD'
,'V9383XS'
,'V9384XD'
,'V9384XS'
,'V9385XD'
,'V9385XS'
,'V9386XD'
,'V9386XS'
,'V9387XD'
,'V9387XS'
,'V9388XD'
,'V9388XS'
,'V9389XD'
,'V9389XS'
,'V940XXD'
,'V940XXS'
,'V9411XD'
,'V9411XS'
,'V9412XD'
,'V9412XS'
,'V9421XD'
,'V9421XS'
,'V9422XD'
,'V9422XS'
,'V9431XD'
,'V9431XS'
,'V9432XD'
,'V9432XS'
,'V944XXD'
,'V944XXS'
,'V94810D'
,'V94810S'
,'V94811D'
,'V94811S'
,'V94818D'
,'V94818S'
,'V9489XD'
,'V9489XS'
,'V949XXD'
,'V949XXS'
,'V9500XD'
,'V9500XS'
,'V9501XD'
,'V9501XS'
,'V9502XD'
,'V9502XS'
,'V9503XD'
,'V9503XS'
,'V9504XD'
,'V9504XS'
,'V9505XD'
,'V9505XS'
,'V9509XD'
,'V9509XS'
,'V9510XD'
,'V9510XS'
,'V9511XD'
,'V9511XS'
,'V9512XD'
,'V9512XS'
,'V9513XD'
,'V9513XS'
,'V9514XD'
,'V9514XS'
,'V9515XD'
,'V9515XS'
,'V9519XD'
,'V9519XS'
,'V9520XD'
,'V9520XS'
,'V9521XD'
,'V9521XS'
,'V9522XD'
,'V9522XS'
,'V9523XD'
,'V9523XS'
,'V9524XD'
,'V9524XS'
,'V9525XD'
,'V9525XS'
,'V9529XD'
,'V9529XS'
,'V9530XD'
,'V9530XS'
,'V9531XD'
,'V9531XS'
,'V9532XD'
,'V9532XS'
,'V9533XD'
,'V9533XS'
,'V9534XD'
,'V9534XS'
,'V9535XD'
,'V9535XS'
,'V9539XD'
,'V9539XS'
,'V9540XD'
,'V9540XS'
,'V9541XD'
,'V9541XS'
,'V9542XD'
,'V9542XS'
,'V9543XD'
,'V9543XS'
,'V9544XD'
,'V9544XS'
,'V9545XD'
,'V9545XS'
,'V9549XD'
,'V9549XS'
,'V958XXD'
,'V958XXS'
,'V959XXD'
,'V959XXS'
,'V9600XD'
,'V9600XS'
,'V9601XD'
,'V9601XS'
,'V9602XD'
,'V9602XS'
,'V9603XD'
,'V9603XS'
,'V9604XD'
,'V9604XS'
,'V9605XD'
,'V9605XS'
,'V9609XD'
,'V9609XS'
,'V9610XD'
,'V9610XS'
,'V9611XD'
,'V9611XS'
,'V9612XD'
,'V9612XS'
,'V9613XD'
,'V9613XS'
,'V9614XD'
,'V9614XS'
,'V9615XD'
,'V9615XS'
,'V9619XD'
,'V9619XS'
,'V9620XD'
,'V9620XS'
,'V9621XD'
,'V9621XS'
,'V9622XD'
,'V9622XS'
,'V9623XD'
,'V9623XS'
,'V9624XD'
,'V9624XS'
,'V9625XD'
,'V9625XS'
,'V9629XD'
,'V9629XS'
,'V968XXD'
,'V968XXS'
,'V969XXD'
,'V969XXS'
,'V970XXD'
,'V970XXS'
,'V971XXD'
,'V971XXS'
,'V9721XD'
,'V9721XS'
,'V9722XD'
,'V9722XS'
,'V9729XD'
,'V9729XS'
,'V9731XD'
,'V9731XS'
,'V9732XD'
,'V9732XS'
,'V9733XD'
,'V9733XS'
,'V9739XD'
,'V9739XS'
,'V97810D'
,'V97810S'
,'V97811D'
,'V97811S'
,'V97818D'
,'V97818S'
,'V9789XD'
,'V9789XS'
,'V980XXD'
,'V980XXS'
,'V981XXD'
,'V981XXS'
,'V982XXD'
,'V982XXS'
,'V983XXD'
,'V983XXS'
,'V988XXD'
,'V988XXS'
,'V99XXXD'
,'V99XXXS'
,'W090XXD'
,'W090XXS'
,'W091XXD'
,'W091XXS'
,'W092XXD'
,'W092XXS'
,'W098XXD'
,'W098XXS'
,'W14XXXD'
,'W14XXXS'
,'W15XXXD'
,'W15XXXS'
,'W170XXD'
,'W170XXS'
,'W171XXD'
,'W171XXS'
,'W1801XD'
,'W1801XS'
,'W2100XD'
,'W2100XS'
,'W2101XD'
,'W2101XS'
,'W2102XD'
,'W2102XS'
,'W2103XD'
,'W2103XS'
,'W2104XD'
,'W2104XS'
,'W2105XD'
,'W2105XS'
,'W2106XD'
,'W2106XS'
,'W2107XD'
,'W2107XS'
,'W2109XD'
,'W2109XS'
,'W2111XD'
,'W2111XS'
,'W2112XD'
,'W2112XS'
,'W2113XD'
,'W2113XS'
,'W2119XD'
,'W2119XS'
,'W21210D'
,'W21210S'
,'W21211D'
,'W21211S'
,'W21220D'
,'W21220S'
,'W21221D'
,'W21221S'
,'W2131XD'
,'W2131XS'
,'W2132XD'
,'W2132XS'
,'W2139XD'
,'W2139XS'
,'W214XXD'
,'W214XXS'
,'W2181XD'
,'W2181XS'
,'W2189XD'
,'W2189XS'
,'W219XXD'
,'W219XXS'
,'W300XXD'
,'W300XXS'
,'W301XXD'
,'W301XXS'
,'W302XXD'
,'W302XXS'
,'W303XXD'
,'W303XXS'
,'W3081XD'
,'W3081XS'
,'W3089XD'
,'W3089XS'
,'W309XXD'
,'W309XXS'
,'W310XXD'
,'W310XXS'
,'W311XXD'
,'W311XXS'
,'W312XXD'
,'W312XXS'
,'W313XXD'
,'W313XXS'
,'W3181XD'
,'W3181XS'
,'W3182XD'
,'W3182XS'
,'W3183XD'
,'W3183XS'
,'W3189XD'
,'W3189XS'
,'W319XXD'
,'W319XXS'
,'W320XXD'
,'W320XXS'
,'W321XXD'
,'W321XXS'
,'W3300XD'
,'W3300XS'
,'W3301XD'
,'W3301XS'
,'W3302XD'
,'W3302XS'
,'W3303XD'
,'W3303XS'
,'W3309XD'
,'W3309XS'
,'W3310XD'
,'W3310XS'
,'W3311XD'
,'W3311XS'
,'W3312XD'
,'W3312XS'
,'W3313XD'
,'W3313XS'
,'W3319XD'
,'W3319XS'
,'W3400XD'
,'W3400XS'
,'W34010D'
,'W34010S'
,'W34011D'
,'W34011S'
,'W34018D'
,'W34018S'
,'W3409XD'
,'W3409XS'
,'W3410XD'
,'W3410XS'
,'W34110D'
,'W34110S'
,'W34111D'
,'W34111S'
,'W34118D'
,'W34118S'
,'W3419XD'
,'W3419XS'
,'W35XXXD'
,'W35XXXS'
,'W361XXD'
,'W361XXS'
,'W362XXD'
,'W362XXS'
,'W363XXD'
,'W363XXS'
,'W368XXD'
,'W368XXS'
,'W369XXD'
,'W369XXS'
,'W370XXD'
,'W370XXS'
,'W378XXD'
,'W378XXS'
,'W38XXXD'
,'W38XXXS'
,'W39XXXD'
,'W39XXXS'
,'W400XXD'
,'W400XXS'
,'W401XXD'
,'W401XXS'
,'W408XXD'
,'W408XXS'
,'W409XXD'
,'W409XXS'
,'W52XXXD'
,'W52XXXS'
,'W5601XD'
,'W5601XS'
,'W5602XD'
,'W5602XS'
,'W5609XD'
,'W5609XS'
,'W5611XD'
,'W5611XS'
,'W5612XD'
,'W5612XS'
,'W5619XD'
,'W5619XS'
,'W5621XD'
,'W5621XS'
,'W5622XD'
,'W5622XS'
,'W5629XD'
,'W5629XS'
,'W5631XD'
,'W5631XS'
,'W5632XD'
,'W5632XS'
,'W5639XD'
,'W5639XS'
,'W5641XD'
,'W5641XS'
,'W5642XD'
,'W5642XS'
,'W5649XD'
,'W5649XS'
,'W5651XD'
,'W5651XS'
,'W5652XD'
,'W5652XS'
,'W5659XD'
,'W5659XS'
,'W5681XD'
,'W5681XS'
,'W5682XD'
,'W5682XS'
,'W5689XD'
,'W5689XS'
,'W5801XD'
,'W5801XS'
,'W5802XD'
,'W5802XS'
,'W5803XD'
,'W5803XS'
,'W5809XD'
,'W5809XS'
,'W5811XD'
,'W5811XS'
,'W5812XD'
,'W5812XS'
,'W5813XD'
,'W5813XS'
,'W5819XD'
,'W5819XS'
,'W6101XD'
,'W6101XS'
,'W6102XD'
,'W6102XS'
,'W6109XD'
,'W6109XS'
,'W6111XD'
,'W6111XS'
,'W6112XD'
,'W6112XS'
,'W6119XD'
,'W6119XS'
,'W6121XD'
,'W6121XS'
,'W6122XD'
,'W6122XS'
,'W6129XD'
,'W6129XS'
,'W6132XD'
,'W6132XS'
,'W6133XD'
,'W6133XS'
,'W6139XD'
,'W6139XS'
,'W6142XD'
,'W6142XS'
,'W6143XD'
,'W6143XS'
,'W6149XD'
,'W6149XS'
,'W6151XD'
,'W6151XS'
,'W6152XD'
,'W6152XS'
,'W6159XD'
,'W6159XS'
,'W6161XD'
,'W6161XS'
,'W6162XD'
,'W6162XS'
,'W6169XD'
,'W6169XS'
,'W6191XD'
,'W6191XS'
,'W6192XD'
,'W6192XS'
,'W6199XD'
,'W6199XS'
,'W620XXD'
,'W620XXS'
,'W621XXD'
,'W621XXS'
,'W629XXD'
,'W629XXS'
,'W890XXD'
,'W890XXS'
,'W891XXD'
,'W891XXS'
,'W898XXD'
,'W898XXS'
,'W899XXD'
,'W899XXS'
,'X020XXD'
,'X020XXS'
,'X021XXD'
,'X021XXS'
,'X022XXD'
,'X022XXS'
,'X023XXD'
,'X023XXS'
,'X024XXD'
,'X024XXS'
,'X025XXD'
,'X025XXS'
,'X028XXD'
,'X028XXS'
,'X030XXD'
,'X030XXS'
,'X031XXD'
,'X031XXS'
,'X033XXD'
,'X033XXS'
,'X034XXD'
,'X034XXS'
,'X038XXD'
,'X038XXS'
,'X04XXXD'
,'X04XXXS'
,'X52XXXD'
,'X52XXXS'
,'X710XXD'
,'X710XXS'
,'X711XXD'
,'X711XXS'
,'X712XXD'
,'X712XXS'
,'X713XXD'
,'X713XXS'
,'X718XXD'
,'X718XXS'
,'X719XXD'
,'X719XXS'
,'X72XXXD'
,'X72XXXS'
,'X730XXD'
,'X730XXS'
,'X731XXD'
,'X731XXS'
,'X732XXD'
,'X732XXS'
,'X738XXD'
,'X738XXS'
,'X739XXD'
,'X739XXS'
,'X7401XD'
,'X7401XS'
,'X7402XD'
,'X7402XS'
,'X7409XD'
,'X7409XS'
,'X748XXD'
,'X748XXS'
,'X749XXD'
,'X749XXS'
,'X75XXXD'
,'X75XXXS'
,'X76XXXD'
,'X76XXXS'
,'X770XXD'
,'X770XXS'
,'X771XXD'
,'X771XXS'
,'X772XXD'
,'X772XXS'
,'X773XXD'
,'X773XXS'
,'X778XXD'
,'X778XXS'
,'X779XXD'
,'X779XXS'
,'X810XXD'
,'X810XXS'
,'X811XXD'
,'X811XXS'
,'X818XXD'
,'X818XXS'
,'X820XXD'
,'X820XXS'
,'X821XXD'
,'X821XXS'
,'X822XXD'
,'X822XXS'
,'X828XXD'
,'X828XXS'
,'X830XXD'
,'X830XXS'
,'X831XXD'
,'X831XXS'
,'X832XXD'
,'X832XXS'
,'X838XXD'
,'X838XXS'
,'Y030XXD'
,'Y030XXS'
,'Y038XXD'
,'Y038XXS'
,'Y0701'
,'Y0702'
,'Y0703'
,'Y0704'
,'Y0711'
,'Y0712'
,'Y0713'
,'Y0714'
,'Y07410'
,'Y07411'
,'Y07420'
,'Y07421'
,'Y07430'
,'Y07432'
,'Y07433'
,'Y07434'
,'Y07435'
,'Y07436'
,'Y07490'
,'Y07491'
,'Y07499'
,'Y0750'
,'Y07510'
,'Y07511'
,'Y07512'
,'Y07513'
,'Y07519'
,'Y07521'
,'Y07528'
,'Y07529'
,'Y0753'
,'Y0759'
,'Y079'
,'Y0881XD'
,'Y0881XS'
,'Y0889XD'
,'Y0889XS'
,'Y210XXD'
,'Y210XXS'
,'Y211XXD'
,'Y211XXS'
,'Y212XXD'
,'Y212XXS'
,'Y213XXD'
,'Y213XXS'
,'Y214XXD'
,'Y214XXS'
,'Y218XXD'
,'Y218XXS'
,'Y219XXD'
,'Y219XXS'
,'Y22XXXD'
,'Y22XXXS'
,'Y230XXD'
,'Y230XXS'
,'Y231XXD'
,'Y231XXS'
,'Y232XXD'
,'Y232XXS'
,'Y233XXD'
,'Y233XXS'
,'Y238XXD'
,'Y238XXS'
,'Y239XXD'
,'Y239XXS'
,'Y240XXD'
,'Y240XXS'
,'Y248XXD'
,'Y248XXS'
,'Y249XXD'
,'Y249XXS'
,'Y30XXXD'
,'Y30XXXS'
,'Y32XXXD'
,'Y32XXXS'
,'Y36000D'
,'Y36000S'
,'Y36001D'
,'Y36001S'
,'Y36010D'
,'Y36010S'
,'Y36011D'
,'Y36011S'
,'Y36020D'
,'Y36020S'
,'Y36021D'
,'Y36021S'
,'Y36030D'
,'Y36030S'
,'Y36031D'
,'Y36031S'
,'Y36040D'
,'Y36040S'
,'Y36041D'
,'Y36041S'
,'Y36050D'
,'Y36050S'
,'Y36051D'
,'Y36051S'
,'Y36090D'
,'Y36090S'
,'Y36091D'
,'Y36091S'
,'Y36100D'
,'Y36100S'
,'Y36101D'
,'Y36101S'
,'Y36110D'
,'Y36110S'
,'Y36111D'
,'Y36111S'
,'Y36120D'
,'Y36120S'
,'Y36121D'
,'Y36121S'
,'Y36130D'
,'Y36130S'
,'Y36131D'
,'Y36131S'
,'Y36140D'
,'Y36140S'
,'Y36141D'
,'Y36141S'
,'Y36190D'
,'Y36190S'
,'Y36191D'
,'Y36191S'
,'Y36200D'
,'Y36200S'
,'Y36201D'
,'Y36201S'
,'Y36210D'
,'Y36210S'
,'Y36211D'
,'Y36211S'
,'Y36220D'
,'Y36220S'
,'Y36221D'
,'Y36221S'
,'Y36230D'
,'Y36230S'
,'Y36231D'
,'Y36231S'
,'Y36240D'
,'Y36240S'
,'Y36241D'
,'Y36241S'
,'Y36250D'
,'Y36250S'
,'Y36251D'
,'Y36251S'
,'Y36260D'
,'Y36260S'
,'Y36261D'
,'Y36261S'
,'Y36270D'
,'Y36270S'
,'Y36271D'
,'Y36271S'
,'Y36290D'
,'Y36290S'
,'Y36291D'
,'Y36291S'
,'Y36300D'
,'Y36300S'
,'Y36301D'
,'Y36301S'
,'Y36310D'
,'Y36310S'
,'Y36311D'
,'Y36311S'
,'Y36320D'
,'Y36320S'
,'Y36321D'
,'Y36321S'
,'Y36330D'
,'Y36330S'
,'Y36331D'
,'Y36331S'
,'Y36390D'
,'Y36390S'
,'Y36391D'
,'Y36391S'
,'Y36410D'
,'Y36410S'
,'Y36411D'
,'Y36411S'
,'Y36420D'
,'Y36420S'
,'Y36421D'
,'Y36421S'
,'Y36430D'
,'Y36430S'
,'Y36431D'
,'Y36431S'
,'Y36440D'
,'Y36440S'
,'Y36441D'
,'Y36441S'
,'Y36450D'
,'Y36450S'
,'Y36451D'
,'Y36451S'
,'Y36460D'
,'Y36460S'
,'Y36461D'
,'Y36461S'
,'Y36470D'
,'Y36470S'
,'Y36471D'
,'Y36471S'
,'Y36490D'
,'Y36490S'
,'Y36491D'
,'Y36491S'
,'Y36500D'
,'Y36500S'
,'Y36501D'
,'Y36501S'
,'Y36510D'
,'Y36510S'
,'Y36511D'
,'Y36511S'
,'Y36520D'
,'Y36520S'
,'Y36521D'
,'Y36521S'
,'Y36530D'
,'Y36530S'
,'Y36531D'
,'Y36531S'
,'Y36540D'
,'Y36540S'
,'Y36541D'
,'Y36541S'
,'Y36590D'
,'Y36590S'
,'Y36591D'
,'Y36591S'
,'Y366X0D'
,'Y366X0S'
,'Y366X1D'
,'Y366X1S'
,'Y367X0D'
,'Y367X0S'
,'Y367X1D'
,'Y367X1S'
,'Y36810D'
,'Y36810S'
,'Y36811D'
,'Y36811S'
,'Y36820D'
,'Y36820S'
,'Y36821D'
,'Y36821S'
,'Y36880D'
,'Y36880S'
,'Y36881D'
,'Y36881S'
,'Y36890D'
,'Y36890S'
,'Y36891D'
,'Y36891S'
,'Y3690XD'
,'Y3690XS'
,'Y3691XD'
,'Y3691XS'
,'Y3692XD'
,'Y3692XS'
,'Y37000D'
,'Y37000S'
,'Y37001D'
,'Y37001S'
,'Y37010D'
,'Y37010S'
,'Y37011D'
,'Y37011S'
,'Y37020D'
,'Y37020S'
,'Y37021D'
,'Y37021S'
,'Y37030D'
,'Y37030S'
,'Y37031D'
,'Y37031S'
,'Y37040D'
,'Y37040S'
,'Y37041D'
,'Y37041S'
,'Y37050D'
,'Y37050S'
,'Y37051D'
,'Y37051S'
,'Y37090D'
,'Y37090S'
,'Y37091D'
,'Y37091S'
,'Y37100D'
,'Y37100S'
,'Y37101D'
,'Y37101S'
,'Y37110D'
,'Y37110S'
,'Y37111D'
,'Y37111S'
,'Y37120D'
,'Y37120S'
,'Y37121D'
,'Y37121S'
,'Y37130D'
,'Y37130S'
,'Y37131D'
,'Y37131S'
,'Y37140D'
,'Y37140S'
,'Y37141D'
,'Y37141S'
,'Y37190D'
,'Y37190S'
,'Y37191D'
,'Y37191S'
,'Y37200D'
,'Y37200S'
,'Y37201D'
,'Y37201S'
,'Y37210D'
,'Y37210S'
,'Y37211D'
,'Y37211S'
,'Y37220D'
,'Y37220S'
,'Y37221D'
,'Y37221S'
,'Y37230D'
,'Y37230S'
,'Y37231D'
,'Y37231S'
,'Y37240D'
,'Y37240S'
,'Y37241D'
,'Y37241S'
,'Y37250D'
,'Y37250S'
,'Y37251D'
,'Y37251S'
,'Y37260D'
,'Y37260S'
,'Y37261D'
,'Y37261S'
,'Y37270D'
,'Y37270S'
,'Y37271D'
,'Y37271S'
,'Y37290D'
,'Y37290S'
,'Y37291D'
,'Y37291S'
,'Y37300D'
,'Y37300S'
,'Y37301D'
,'Y37301S'
,'Y37310D'
,'Y37310S'
,'Y37311D'
,'Y37311S'
,'Y37320D'
,'Y37320S'
,'Y37321D'
,'Y37321S'
,'Y37330D'
,'Y37330S'
,'Y37331D'
,'Y37331S'
,'Y37390D'
,'Y37390S'
,'Y37391D'
,'Y37391S'
,'Y37410D'
,'Y37410S'
,'Y37411D'
,'Y37411S'
,'Y37420D'
,'Y37420S'
,'Y37421D'
,'Y37421S'
,'Y37430D'
,'Y37430S'
,'Y37431D'
,'Y37431S'
,'Y37440D'
,'Y37440S'
,'Y37441D'
,'Y37441S'
,'Y37450D'
,'Y37450S'
,'Y37451D'
,'Y37451S'
,'Y37460D'
,'Y37460S'
,'Y37461D'
,'Y37461S'
,'Y37470D'
,'Y37470S'
,'Y37471D'
,'Y37471S'
,'Y37490D'
,'Y37490S'
,'Y37491D'
,'Y37491S'
,'Y37500D'
,'Y37500S'
,'Y37501D'
,'Y37501S'
,'Y37510D'
,'Y37510S'
,'Y37511D'
,'Y37511S'
,'Y37520D'
,'Y37520S'
,'Y37521D'
,'Y37521S'
,'Y37530D'
,'Y37530S'
,'Y37531D'
,'Y37531S'
,'Y37540D'
,'Y37540S'
,'Y37541D'
,'Y37541S'
,'Y37590D'
,'Y37590S'
,'Y37591D'
,'Y37591S'
,'Y376X0D'
,'Y376X0S'
,'Y376X1D'
,'Y376X1S'
,'Y377X0D'
,'Y377X0S'
,'Y377X1D'
,'Y377X1S'
,'Y3790XD'
,'Y3790XS'
,'Y3791XD'
,'Y3791XS'
,'Y3792XD'
,'Y3792XS'
,'Y92000'
,'Y92001'
,'Y92002'
,'Y92003'
,'Y92007'
,'Y92008'
,'Y92009'
,'Y92010'
,'Y92011'
,'Y92012'
,'Y92013'
,'Y92014'
,'Y92015'
,'Y92016'
,'Y92017'
,'Y92018'
,'Y92019'
,'Y92020'
,'Y92021'
,'Y92022'
,'Y92023'
,'Y92024'
,'Y92025'
,'Y92026'
,'Y92027'
,'Y92028'
,'Y92029'
,'Y92030'
,'Y92031'
,'Y92032'
,'Y92038'
,'Y92039'
,'Y92040'
,'Y92041'
,'Y92042'
,'Y92043'
,'Y92044'
,'Y92045'
,'Y92046'
,'Y92048'
,'Y92049'
,'Y92090'
,'Y92091'
,'Y92092'
,'Y92093'
,'Y92094'
,'Y92095'
,'Y92096'
,'Y92098'
,'Y92099'
,'Y9210'
,'Y92110'
,'Y92111'
,'Y92112'
,'Y92113'
,'Y92114'
,'Y92115'
,'Y92116'
,'Y92118'
,'Y92119'
,'Y92120'
,'Y92121'
,'Y92122'
,'Y92123'
,'Y92124'
,'Y92125'
,'Y92126'
,'Y92128'
,'Y92129'
,'Y92130'
,'Y92131'
,'Y92133'
,'Y92135'
,'Y92136'
,'Y92137'
,'Y92138'
,'Y92139'
,'Y92140'
,'Y92141'
,'Y92142'
,'Y92143'
,'Y92146'
,'Y92147'
,'Y92148'
,'Y92149'
,'Y92150'
,'Y92151'
,'Y92152'
,'Y92153'
,'Y92154'
,'Y92155'
,'Y92156'
,'Y92157'
,'Y92158'
,'Y92159'
,'Y92160'
,'Y92161'
,'Y92162'
,'Y92163'
,'Y92168'
,'Y92169'
,'Y92190'
,'Y92191'
,'Y92192'
,'Y92193'
,'Y92194'
,'Y92195'
,'Y92196'
,'Y92197'
,'Y92198'
,'Y92199'
,'Y92210'
,'Y92211'
,'Y92212'
,'Y92213'
,'Y92214'
,'Y92215'
,'Y92218'
,'Y92219'
,'Y9222'
,'Y92230'
,'Y92231'
,'Y92232'
,'Y92233'
,'Y92234'
,'Y92238'
,'Y92239'
,'Y92240'
,'Y92241'
,'Y92242'
,'Y92243'
,'Y92248'
,'Y92250'
,'Y92251'
,'Y92252'
,'Y92253'
,'Y92254'
,'Y92258'
,'Y9226'
,'Y9229'
,'Y92310'
,'Y92311'
,'Y92312'
,'Y92318'
,'Y92320'
,'Y92321'
,'Y92322'
,'Y92328'
,'Y92330'
,'Y92331'
,'Y9234'
,'Y9239'
,'Y92410'
,'Y92411'
,'Y92412'
,'Y92413'
,'Y92414'
,'Y92415'
,'Y92480'
,'Y92481'
,'Y92482'
,'Y92488'
,'Y92510'
,'Y92511'
,'Y92512'
,'Y92513'
,'Y92520'
,'Y92521'
,'Y92522'
,'Y92523'
,'Y92524'
,'Y92530'
,'Y92531'
,'Y92532'
,'Y92538'
,'Y9259'
,'Y9261'
,'Y9262'
,'Y9263'
,'Y9264'
,'Y9265'
,'Y9269'
,'Y9271'
,'Y9272'
,'Y9273'
,'Y9274'
,'Y9279'
,'Y92810'
,'Y92811'
,'Y92812'
,'Y92813'
,'Y92814'
,'Y92815'
,'Y92816'
,'Y92818'
,'Y92820'
,'Y92821'
,'Y92828'
,'Y92830'
,'Y92831'
,'Y92832'
,'Y92833'
,'Y92834'
,'Y92838'
,'Y9284'
,'Y9285'
,'Y9286'
,'Y9289'
,'Y929'
,'Y9301'
,'Y9302'
,'Y9311'
,'Y9312'
,'Y9313'
,'Y9314'
,'Y9315'
,'Y9316'
,'Y9317'
,'Y9318'
,'Y9319'
,'Y9321'
,'Y9322'
,'Y9323'
,'Y9324'
,'Y9329'
,'Y9331'
,'Y9332'
,'Y9333'
,'Y9334'
,'Y9335'
,'Y9339'
,'Y9341'
,'Y9342'
,'Y9343'
,'Y9344'
,'Y9345'
,'Y9349'
,'Y9351'
,'Y9352'
,'Y9353'
,'Y9354'
,'Y9355'
,'Y9356'
,'Y9357'
,'Y9359'
,'Y9361'
,'Y9362'
,'Y9363'
,'Y9364'
,'Y9365'
,'Y9366'
,'Y9367'
,'Y9368'
,'Y9369'
,'Y936A'
,'Y9371'
,'Y9372'
,'Y9373'
,'Y9374'
,'Y9375'
,'Y9379'
,'Y9381'
,'Y9382'
,'Y9383'
,'Y9384'
,'Y9389'
,'Y939'
,'Y93A1'
,'Y93A2'
,'Y93A3'
,'Y93A4'
,'Y93A5'
,'Y93A6'
,'Y93A9'
,'Y93B1'
,'Y93B2'
,'Y93B3'
,'Y93B4'
,'Y93B9'
,'Y93C1'
,'Y93C2'
,'Y93C9'
,'Y93D1'
,'Y93D2'
,'Y93D3'
,'Y93D9'
,'Y93E1'
,'Y93E2'
,'Y93E3'
,'Y93E4'
,'Y93E5'
,'Y93E6'
,'Y93E8'
,'Y93E9'
,'Y93F1'
,'Y93F2'
,'Y93F9'
,'Y93G1'
,'Y93G2'
,'Y93G3'
,'Y93G9'
,'Y93H1'
,'Y93H2'
,'Y93H3'
,'Y93H9'
,'Y93I1'
,'Y93I9'
,'Y93J1'
,'Y93J2'
,'Y93J3'
,'Y93J4'
,'Y93K1'
,'Y93K2'
,'Y93K3'
,'Y93K9'
,'Y990'
,'Y991'
,'Y992'
,'Y998'
,'Y999'
,'Z0000'
,'Z0001'
,'Z00110'
,'Z00111'
,'Z00121'
,'Z00129'
,'Z002'
,'Z003'
,'Z005'
,'Z006'
,'Z0070'
,'Z0071'
,'Z008'
,'Z0100'
,'Z0101'
,'Z0110'
,'Z01110'
,'Z01118'
,'Z0112'
,'Z0120'
,'Z0121'
,'Z0130'
,'Z0131'
,'Z01411'
,'Z01419'
,'Z0142'
,'Z01810'
,'Z01811'
,'Z01812'
,'Z01818'
,'Z0182'
,'Z0183'
,'Z0184'
,'Z0189'
,'Z020'
,'Z021'
,'Z022'
,'Z023'
,'Z024'
,'Z025'
,'Z026'
,'Z0271'
,'Z0279'
,'Z0281'
,'Z0282'
,'Z0283'
,'Z0289'
,'Z029'
,'Z036'
,'Z0371'
,'Z0372'
,'Z0373'
,'Z0374'
,'Z0375'
,'Z0379'
,'Z03810'
,'Z03818'
,'Z0389'
,'Z08'
,'Z09'
,'Z110'
,'Z111'
,'Z112'
,'Z113'
,'Z114'
,'Z1151'
,'Z1159'
,'Z116'
,'Z118'
,'Z119'
,'Z120'
,'Z1210'
,'Z1211'
,'Z1212'
,'Z1213'
,'Z122'
,'Z1231'
,'Z1239'
,'Z124'
,'Z125'
,'Z126'
,'Z1271'
,'Z1272'
,'Z1273'
,'Z1279'
,'Z1281'
,'Z1282'
,'Z1283'
,'Z1289'
,'Z129'
,'Z130'
,'Z131'
,'Z1321'
,'Z13220'
,'Z13228'
,'Z1329'
,'Z134'
,'Z135'
,'Z136'
,'Z1371'
,'Z1379'
,'Z13810'
,'Z13811'
,'Z13818'
,'Z13820'
,'Z13828'
,'Z1383'
,'Z1384'
,'Z13850'
,'Z13858'
,'Z1388'
,'Z1389'
,'Z139'
,'Z1401'
,'Z1402'
,'Z141'
,'Z148'
,'Z1501'
,'Z1502'
,'Z1503'
,'Z1504'
,'Z1509'
,'Z1581'
,'Z1589'
,'Z170'
,'Z171'
,'Z1801'
,'Z1809'
,'Z1810'
,'Z1811'
,'Z1812'
,'Z182'
,'Z1831'
,'Z1832'
,'Z1833'
,'Z1839'
,'Z1881'
,'Z1883'
,'Z1889'
,'Z189'
,'Z220'
,'Z221'
,'Z222'
,'Z2231'
,'Z22321'
,'Z22322'
,'Z22330'
,'Z22338'
,'Z2239'
,'Z224'
,'Z2250'
,'Z2251'
,'Z2252'
,'Z2259'
,'Z226'
,'Z228'
,'Z229'
,'Z23'
,'Z2801'
,'Z2802'
,'Z2803'
,'Z2804'
,'Z2809'
,'Z281'
,'Z2820'
,'Z2821'
,'Z2829'
,'Z283'
,'Z2881'
,'Z2882'
,'Z2889'
,'Z289'
,'Z30011'
,'Z30012'
,'Z30013'
,'Z30014'
,'Z30018'
,'Z30019'
,'Z3002'
,'Z3009'
,'Z302'
,'Z3040'
,'Z3041'
,'Z3042'
,'Z30430'
,'Z30431'
,'Z30432'
,'Z30433'
,'Z3049'
,'Z308'
,'Z309'
,'Z310'
,'Z3141'
,'Z3142'
,'Z31430'
,'Z31438'
,'Z31440'
,'Z31441'
,'Z31448'
,'Z3149'
,'Z315'
,'Z3161'
,'Z3162'
,'Z3169'
,'Z3181'
,'Z3182'
,'Z3183'
,'Z3184'
,'Z3189'
,'Z319'
,'Z3400'
,'Z3401'
,'Z3402'
,'Z3403'
,'Z3480'
,'Z3481'
,'Z3482'
,'Z3483'
,'Z3490'
,'Z3491'
,'Z3492'
,'Z3493'
,'Z36'
,'Z370'
,'Z371'
,'Z372'
,'Z373'
,'Z374'
,'Z3750'
,'Z3751'
,'Z3752'
,'Z3753'
,'Z3754'
,'Z3759'
,'Z3760'
,'Z3761'
,'Z3762'
,'Z3763'
,'Z3764'
,'Z3769'
,'Z377'
,'Z379'
,'Z3800'
,'Z3801'
,'Z381'
,'Z382'
,'Z3830'
,'Z3831'
,'Z384'
,'Z385'
,'Z3861'
,'Z3862'
,'Z3863'
,'Z3864'
,'Z3865'
,'Z3866'
,'Z3868'
,'Z3869'
,'Z387'
,'Z388'
,'Z390'
,'Z391'
,'Z392'
,'Z411'
,'Z412'
,'Z413'
,'Z418'
,'Z419'
,'Z421'
,'Z428'
,'Z430'
,'Z431'
,'Z432'
,'Z433'
,'Z434'
,'Z435'
,'Z436'
,'Z437'
,'Z438'
,'Z439'
,'Z44001'
,'Z44002'
,'Z44009'
,'Z44011'
,'Z44012'
,'Z44019'
,'Z44021'
,'Z44022'
,'Z44029'
,'Z44101'
,'Z44102'
,'Z44109'
,'Z44111'
,'Z44112'
,'Z44119'
,'Z44121'
,'Z44122'
,'Z44129'
,'Z4420'
,'Z4421'
,'Z4422'
,'Z4430'
,'Z4431'
,'Z4432'
,'Z448'
,'Z449'
,'Z45010'
,'Z45018'
,'Z4502'
,'Z4509'
,'Z451'
,'Z452'
,'Z4531'
,'Z45320'
,'Z45321'
,'Z45328'
,'Z4541'
,'Z4542'
,'Z4549'
,'Z45811'
,'Z45812'
,'Z45819'
,'Z4582'
,'Z4589'
,'Z459'
,'Z460'
,'Z461'
,'Z462'
,'Z463'
,'Z464'
,'Z4651'
,'Z4659'
,'Z466'
,'Z4681'
,'Z4682'
,'Z4689'
,'Z469'
,'Z4781'
,'Z4782'
,'Z4789'
,'Z4901'
,'Z4902'
,'Z4931'
,'Z4932'
,'Z510'
,'Z5111'
,'Z5112'
,'Z515'
,'Z5181'
,'Z5189'
,'Z52000'
,'Z52001'
,'Z52008'
,'Z52010'
,'Z52011'
,'Z52018'
,'Z52090'
,'Z52091'
,'Z52098'
,'Z5210'
,'Z5211'
,'Z5219'
,'Z5220'
,'Z5221'
,'Z5229'
,'Z523'
,'Z524'
,'Z525'
,'Z526'
,'Z52810'
,'Z52811'
,'Z52812'
,'Z52813'
,'Z52819'
,'Z5289'
,'Z529'
,'Z590'
,'Z591'
,'Z592'
,'Z593'
,'Z594'
,'Z595'
,'Z596'
,'Z597'
,'Z598'
,'Z599'
,'Z630'
,'Z631'
,'Z6331'
,'Z6332'
,'Z634'
,'Z635'
,'Z636'
,'Z6371'
,'Z6372'
,'Z6379'
,'Z638'
,'Z639'
,'Z650'
,'Z651'
,'Z652'
,'Z653'
,'Z654'
,'Z655'
,'Z658'
,'Z659'
,'Z6710'
,'Z6711'
,'Z6720'
,'Z6721'
,'Z6730'
,'Z6731'
,'Z6740'
,'Z6741'
,'Z6790'
,'Z6791'
,'Z681'
,'Z6820'
,'Z6821'
,'Z6822'
,'Z6823'
,'Z6824'
,'Z6825'
,'Z6826'
,'Z6827'
,'Z6828'
,'Z6829'
,'Z6830'
,'Z6831'
,'Z6832'
,'Z6833'
,'Z6834'
,'Z6835'
,'Z6836'
,'Z6837'
,'Z6838'
,'Z6839'
,'Z6841'
,'Z6842'
,'Z6843'
,'Z6844'
,'Z6845'
,'Z6851'
,'Z6852'
,'Z6853'
,'Z6854'
,'Z720'
,'Z723'
,'Z724'
,'Z7251'
,'Z7252'
,'Z7253'
,'Z726'
,'Z72810'
,'Z72811'
,'Z72820'
,'Z72821'
,'Z7289'
,'Z729'
,'Z7401'
,'Z760'
,'Z761'
,'Z762'
,'Z763'
,'Z764'
,'Z765'
,'Z7681'
,'Z7682'
,'Z7689'
,'Z77110'
,'Z77111'
,'Z77112'
,'Z77118'
,'Z77120'
,'Z77121'
,'Z77122'
,'Z77123'
,'Z77128'
,'Z780'
,'Z781'
,'Z789'
,'Z7901'
,'Z7902'
,'Z791'
,'Z792'
,'Z793'
,'Z794'
,'Z7951'
,'Z7952'
,'Z79810'
,'Z79811'
,'Z79818'
,'Z7982'
,'Z7983'
,'Z79890'
,'Z79891'
,'Z79899'
,'Z800'
,'Z801'
,'Z802'
,'Z803'
,'Z8041'
,'Z8042'
,'Z8043'
,'Z8049'
,'Z8051'
,'Z8052'
,'Z8059'
,'Z806'
,'Z807'
,'Z808'
,'Z809'
,'Z810'
,'Z811'
,'Z812'
,'Z813'
,'Z814'
,'Z818'
,'Z820'
,'Z821'
,'Z822'
,'Z823'
,'Z8241'
,'Z8249'
,'Z825'
,'Z8261'
,'Z8262'
,'Z8269'
,'Z8271'
,'Z8279'
,'Z828'
,'Z830'
,'Z831'
,'Z832'
,'Z833'
,'Z8341'
,'Z8349'
,'Z83511'
,'Z83518'
,'Z8352'
,'Z836'
,'Z8371'
,'Z8379'
,'Z840'
,'Z841'
,'Z842'
,'Z843'
,'Z8481'
,'Z8489'
,'Z8500'
,'Z8501'
,'Z85020'
,'Z85028'
,'Z85030'
,'Z85038'
,'Z85040'
,'Z85048'
,'Z8505'
,'Z85060'
,'Z85068'
,'Z8507'
,'Z8509'
,'Z85110'
,'Z85118'
,'Z8512'
,'Z8520'
,'Z8521'
,'Z8522'
,'Z85230'
,'Z85238'
,'Z8529'
,'Z853'
,'Z8540'
,'Z8541'
,'Z8542'
,'Z8543'
,'Z8544'
,'Z8545'
,'Z8546'
,'Z8547'
,'Z8548'
,'Z8549'
,'Z8550'
,'Z8551'
,'Z85520'
,'Z85528'
,'Z8553'
,'Z8554'
,'Z8559'
,'Z856'
,'Z8571'
,'Z8572'
,'Z8579'
,'Z85810'
,'Z85818'
,'Z85819'
,'Z85820'
,'Z85821'
,'Z85828'
,'Z85830'
,'Z85831'
,'Z85840'
,'Z85841'
,'Z85848'
,'Z85850'
,'Z85858'
,'Z8589'
,'Z859'
,'Z86000'
,'Z86001'
,'Z86008'
,'Z86010'
,'Z86011'
,'Z86012'
,'Z86018'
,'Z8603'
,'Z8611'
,'Z8612'
,'Z8613'
,'Z8614'
,'Z8619'
,'Z862'
,'Z8631'
,'Z8632'
,'Z8639'
,'Z8651'
,'Z8659'
,'Z8661'
,'Z8669'
,'Z86711'
,'Z86718'
,'Z8672'
,'Z8673'
,'Z8674'
,'Z8679'
,'Z8701'
,'Z8709'
,'Z8711'
,'Z8719'
,'Z872'
,'Z87310'
,'Z87311'
,'Z87312'
,'Z8739'
,'Z87410'
,'Z87411'
,'Z87412'
,'Z8742'
,'Z87430'
,'Z87438'
,'Z87440'
,'Z87441'
,'Z87442'
,'Z87448'
,'Z8751'
,'Z8759'
,'Z87710'
,'Z87718'
,'Z87720'
,'Z87721'
,'Z87728'
,'Z87730'
,'Z87738'
,'Z8774'
,'Z8775'
,'Z8776'
,'Z87790'
,'Z87798'
,'Z8781'
,'Z87820'
,'Z87821'
,'Z87828'
,'Z87890'
,'Z87891'
,'Z87892'
,'Z87898'
,'Z880'
,'Z881'
,'Z882'
,'Z883'
,'Z884'
,'Z885'
,'Z886'
,'Z887'
,'Z888'
,'Z889'
,'Z89011'
,'Z89012'
,'Z89019'
,'Z89021'
,'Z89022'
,'Z89029'
,'Z89111'
,'Z89112'
,'Z89119'
,'Z89121'
,'Z89122'
,'Z89129'
,'Z89201'
,'Z89202'
,'Z89209'
,'Z89211'
,'Z89212'
,'Z89219'
,'Z89221'
,'Z89222'
,'Z89229'
,'Z89231'
,'Z89232'
,'Z89239'
,'Z89411'
,'Z89412'
,'Z89419'
,'Z89421'
,'Z89422'
,'Z89429'
,'Z89431'
,'Z89432'
,'Z89439'
,'Z89441'
,'Z89442'
,'Z89449'
,'Z89511'
,'Z89512'
,'Z89519'
,'Z89521'
,'Z89522'
,'Z89529'
,'Z89611'
,'Z89612'
,'Z89619'
,'Z89621'
,'Z89622'
,'Z89629'
,'Z899'
,'Z90710'
,'Z91010'
,'Z91011'
,'Z91012'
,'Z91013'
,'Z91018'
,'Z9102'
,'Z91030'
,'Z91038'
,'Z91040'
,'Z91041'
,'Z91048'
,'Z9109'
,'Z91410'
,'Z91411'
,'Z91412'
,'Z91419'
,'Z9149'
,'Z915'
,'Z9181'
,'Z9182'
,'Z9183'
,'Z9189'
,'Z920'
,'Z9221'
,'Z9222'
,'Z9223'
,'Z92240'
,'Z92241'
,'Z9225'
,'Z9229'
,'Z923'
,'Z9281'
,'Z9282'
,'Z9283'
,'Z9289'
,'Z930'
,'Z931'
,'Z932'
,'Z933'
,'Z934'
,'Z9350'
,'Z9351'
,'Z9352'
,'Z9359'
,'Z936'
,'Z938'
,'Z939'
,'Z940'
,'Z941'
,'Z942'
,'Z943'
,'Z944'
,'Z945'
,'Z946'
,'Z947'
,'Z9481'
,'Z9482'
,'Z9483'
,'Z9484'
,'Z9489'
,'Z949'
,'Z950'
,'Z951'
,'Z952'
,'Z953'
,'Z954'
,'Z955'
,'Z95810'
,'Z95811'
,'Z95812'
,'Z95818'
,'Z95820'
,'Z95828'
,'Z959'
,'Z970'
,'Z9710'
,'Z9711'
,'Z9712'
,'Z9713'
,'Z9714'
,'Z9715'
,'Z9716'
,'Z972'
,'Z973'
,'Z974'
,'Z975'
,'Z978'
,'Z980'
,'Z981'
,'Z982'
,'Z983'
,'Z9841'
,'Z9842'
,'Z9849'
,'Z9851'
,'Z9852'
,'Z9861'
,'Z9862'
,'Z98810'
,'Z98811'
,'Z98818'
,'Z9882'
,'Z9883'
,'Z9884'
,'Z9885'
,'Z9886'
,'Z98870'
,'Z98871'
,'Z9889'
,'Z990'
,'Z9911'
,'Z9912'
,'Z992'
,'Z993'
,'Z9981'
,'Z9989'='1'
OTHER='0'
;
value $poaxmpt_v34fmt
'B900'  /*Sequelae of central nervous system tuberculosis*/
,'B901'  /*Sequelae of genitourinary tuberculosis*/
,'B902'  /*Sequelae of tuberculosis of bones and joints*/
,'B908'  /*Sequelae of tuberculosis of other organs*/
,'B909'  /*Sequelae of respiratory and unspecified tuberculosis*/
,'B91'    /*Sequelae of poliomyelitis*/
,'B92'    /*Sequelae of leprosy*/
,'B940'  /*Sequelae of trachoma*/
,'B941'  /*Sequelae of viral encephalitis*/
,'B942'  /*Sequelae of viral hepatitis*/
,'B948'  /*Sequelae of other specified infectious and parasitic diseases*/
,'B949'  /*Sequelae of unspecified infectious and parasitic disease*/
,'E640'  /*Sequelae of protein-calorie malnutrition*/
,'E641'  /*Sequelae of vitamin A deficiency*/
,'E642'  /*Sequelae of vitamin C deficiency*/
,'E643'  /*Sequelae of rickets*/
,'E648'  /*Sequelae of other nutritional deficiencies*/
,'E649'  /*Sequelae of unspecified nutritional deficiency*/
,'I252'  /*Old myocardial infarction*/
,'I6900'  /*Unspecified sequelae of nontraumatic subarachnoid hemorrhage*/
,'I69010'  /*Attention and concentration deficit following nontraumatic subarachnoid hemorrhage*/
,'I69011'  /*Memory deficit following nontraumatic subarachnoid hemorrhage*/
,'I69012'  /*Visuospatial deficit and spatial neglect following nontraumatic subarachnoid hemorrhage*/
,'I69013'  /*Psychomotor deficit following nontraumatic subarachnoid hemorrhage*/
,'I69014'  /*Frontal lobe and executive function deficit following nontraumatic subarachnoid hemorrhage*/
,'I69015'  /*Cognitive social or emotional deficit following nontraumatic subarachnoid hemorrhage*/
,'I69018'  /*Other symptoms and signs involving cognitive functions following nontraumatic subarachnoid hemorrhage*/
,'I69019'  /*Unspecified symptoms and signs involving cognitive functions following nontraumatic subarachnoid hemorrhage*/
,'I69020'  /*Aphasia following nontraumatic subarachnoid hemorrhage*/
,'I69021'  /*Dysphasia following nontraumatic subarachnoid hemorrhage*/
,'I69022'  /*Dysarthria following nontraumatic subarachnoid hemorrhage*/
,'I69023'  /*Fluency disorder following nontraumatic subarachnoid hemorrhage*/
,'I69028'  /*Other speech and language deficits following nontraumatic subarachnoid hemorrhage*/
,'I69031'  /*Monoplegia of upper limb following nontraumatic subarachnoid hemorrhage affecting right dominant side*/
,'I69032'  /*Monoplegia of upper limb following nontraumatic subarachnoid hemorrhage affecting left dominant side*/
,'I69033'  /*Monoplegia of upper limb following nontraumatic subarachnoid hemorrhage affecting right non-dominant side*/
,'I69034'  /*Monoplegia of upper limb following nontraumatic subarachnoid hemorrhage affecting left non-dominant side*/
,'I69039'  /*Monoplegia of upper limb following nontraumatic subarachnoid hemorrhage affecting unspecified side*/
,'I69041'  /*Monoplegia of lower limb following nontraumatic subarachnoid hemorrhage affecting right dominant side*/
,'I69042'  /*Monoplegia of lower limb following nontraumatic subarachnoid hemorrhage affecting left dominant side*/
,'I69043'  /*Monoplegia of lower limb following nontraumatic subarachnoid hemorrhage affecting right non-dominant side*/
,'I69044'  /*Monoplegia of lower limb following nontraumatic subarachnoid hemorrhage affecting left non-dominant side*/
,'I69049'  /*Monoplegia of lower limb following nontraumatic subarachnoid hemorrhage affecting unspecified side*/
,'I69051'  /*Hemiplegia and hemiparesis following nontraumatic subarachnoid hemorrhage affecting right dominant side*/
,'I69052'  /*Hemiplegia and hemiparesis following nontraumatic subarachnoid hemorrhage affecting left dominant side*/
,'I69053'  /*Hemiplegia and hemiparesis following nontraumatic subarachnoid hemorrhage affecting right non-dominant side*/
,'I69054'  /*Hemiplegia and hemiparesis following nontraumatic subarachnoid hemorrhage affecting left non-dominant side*/
,'I69059'  /*Hemiplegia and hemiparesis following nontraumatic subarachnoid hemorrhage affecting unspecified side*/
,'I69061'  /*Other paralytic syndrome following nontraumatic subarachnoid hemorrhage affecting right dominant side*/
,'I69062'  /*Other paralytic syndrome following nontraumatic subarachnoid hemorrhage affecting left dominant side*/
,'I69063'  /*Other paralytic syndrome following nontraumatic subarachnoid hemorrhage affecting right non-dominant side*/
,'I69064'  /*Other paralytic syndrome following nontraumatic subarachnoid hemorrhage affecting left non-dominant side*/
,'I69065'  /*Other paralytic syndrome following nontraumatic subarachnoid hemorrhage, bilateral*/
,'I69069'  /*Other paralytic syndrome following nontraumatic subarachnoid hemorrhage affecting unspecified side*/
,'I69090'  /*Apraxia following nontraumatic subarachnoid hemorrhage*/
,'I69091'  /*Dysphagia following nontraumatic subarachnoid hemorrhage*/
,'I69092'  /*Facial weakness following nontraumatic subarachnoid hemorrhage*/
,'I69093'  /*Ataxia following nontraumatic subarachnoid hemorrhage*/
,'I69098'  /*Other sequelae following nontraumatic subarachnoid hemorrhage*/
,'I6910'   /*Unspecified sequelae of nontraumatic intracerebral hemorrhage*/
,'I69110'  /*Attention and concentration deficit following nontraumatic intracerebral hemorrhage*/
,'I69111'  /*Memory deficit following nontraumatic intracerebral hemorrhage*/
,'I69112'  /*Visuospatial deficit and spatial neglect following nontraumatic intracerebral hemorrhage*/
,'I69113'  /*Psychomotor deficit following nontraumatic intracerebral hemorrhage*/
,'I69114'  /*Frontal lobe and executive function deficit following nontraumatic intracerebral hemorrhage*/
,'I69115'  /*Cognitive social or emotional deficit following nontraumatic intracerebral hemorrhage*/
,'I69118'  /*Other symptoms and signs involving cognitive functions following nontraumatic intracerebral hemorrhage*/
,'I69119'  /*Unspecified symptoms and signs involving cognitive functions following nontraumatic intracerebral hemorrhage*/
,'I69120'  /*Aphasia following nontraumatic intracerebral hemorrhage*/
,'I69121'  /*Dysphasia following nontraumatic intracerebral hemorrhage*/
,'I69122'  /*Dysarthria following nontraumatic intracerebral hemorrhage*/
,'I69123'  /*Fluency disorder following nontraumatic intracerebral hemorrhage*/
,'I69128'  /*Other speech and language deficits following nontraumatic intracerebral hemorrhage*/
,'I69131'  /*Monoplegia of upper limb following nontraumatic intracerebral hemorrhage affecting right dominant side*/
,'I69132'  /*Monoplegia of upper limb following nontraumatic intracerebral hemorrhage affecting left dominant side*/
,'I69133'  /*Monoplegia of upper limb following nontraumatic intracerebral hemorrhage affecting right non-dominant side*/
,'I69134'  /*Monoplegia of upper limb following nontraumatic intracerebral hemorrhage affecting left non-dominant side*/
,'I69139'  /*Monoplegia of upper limb following nontraumatic intracerebral hemorrhage affecting unspecified side*/
,'I69141'  /*Monoplegia of lower limb following nontraumatic intracerebral hemorrhage affecting right dominant side*/
,'I69142'  /*Monoplegia of lower limb following nontraumatic intracerebral hemorrhage affecting left dominant side*/
,'I69143'  /*Monoplegia of lower limb following nontraumatic intracerebral hemorrhage affecting right non-dominant side*/
,'I69144'  /*Monoplegia of lower limb following nontraumatic intracerebral hemorrhage affecting left non-dominant side*/
,'I69149'  /*Monoplegia of lower limb following nontraumatic intracerebral hemorrhage affecting unspecified side*/
,'I69151'  /*Hemiplegia and hemiparesis following nontraumatic intracerebral hemorrhage affecting right dominant side*/
,'I69152'  /*Hemiplegia and hemiparesis following nontraumatic intracerebral hemorrhage affecting left dominant side*/
,'I69153'  /*Hemiplegia and hemiparesis following nontraumatic intracerebral hemorrhage affecting right non-dominant side*/
,'I69154'  /*Hemiplegia and hemiparesis following nontraumatic intracerebral hemorrhage affecting left non-dominant side*/
,'I69159'  /*Hemiplegia and hemiparesis following nontraumatic intracerebral hemorrhage affecting unspecified side*/
,'I69161'  /*Other paralytic syndrome following nontraumatic intracerebral hemorrhage affecting right dominant side*/
,'I69162'  /*Other paralytic syndrome following nontraumatic intracerebral hemorrhage affecting left dominant side*/
,'I69163'  /*Other paralytic syndrome following nontraumatic intracerebral hemorrhage affecting right non-dominant side*/
,'I69164'  /*Other paralytic syndrome following nontraumatic intracerebral hemorrhage affecting left non-dominant side*/
,'I69165'  /*Other paralytic syndrome following nontraumatic intracerebral hemorrhage, bilateral*/
,'I69169'  /*Other paralytic syndrome following nontraumatic intracerebral hemorrhage affecting unspecified side*/
,'I69190'  /*Apraxia following nontraumatic intracerebral hemorrhage*/
,'I69191'  /*Dysphagia following nontraumatic intracerebral hemorrhage*/
,'I69192'  /*Facial weakness following nontraumatic intracerebral hemorrhage*/
,'I69193'  /*Ataxia following nontraumatic intracerebral hemorrhage*/
,'I69198'  /*Other sequelae of nontraumatic intracerebral hemorrhage*/
,'I6920'   /*Unspecified sequelae of other nontraumatic intracranial hemorrhage*/
,'I69210'  /*Attention and concentration deficit following other nontraumatic intracranial hemorrhage*/
,'I69211'  /*Memory deficit following other nontraumatic intracranial hemorrhage*/
,'I69212'  /*Visuospatial deficit and spatial neglect following other nontraumatic intracranial hemorrhage*/
,'I69213'  /*Psychomotor deficit following other nontraumatic intracranial hemorrhage*/
,'I69214'  /*Frontal lobe and executive function deficit following other nontraumatic intracranial hemorrhage*/
,'I69215'  /*Cognitive social or emotional deficit following other nontraumatic intracranial hemorrhage*/
,'I69218'  /*Other symptoms and signs involving cognitive functions following other nontraumatic intracranial hemorrhage*/
,'I69219'  /*Unspecified symptoms and signs involving cognitive functions following other nontraumatic intracranial hemorrhage*/
,'I69220'  /*Aphasia following other nontraumatic intracranial hemorrhage*/
,'I69221'  /*Dysphasia following other nontraumatic intracranial hemorrhage*/
,'I69222'  /*Dysarthria following other nontraumatic intracranial hemorrhage*/
,'I69223'  /*Fluency disorder following other nontraumatic intracranial hemorrhage*/
,'I69228'  /*Other speech and language deficits following other nontraumatic intracranial hemorrhage*/
,'I69231'  /*Monoplegia of upper limb following other nontraumatic intracranial hemorrhage affecting right dominant side*/
,'I69232'  /*Monoplegia of upper limb following other nontraumatic intracranial hemorrhage affecting left dominant side*/
,'I69233'  /*Monoplegia of upper limb following other nontraumatic intracranial hemorrhage affecting right non-dominant side*/
,'I69234'  /*Monoplegia of upper limb following other nontraumatic intracranial hemorrhage affecting left non-dominant side*/
,'I69239'  /*Monoplegia of upper limb following other nontraumatic intracranial hemorrhage affecting unspecified side*/
,'I69241'  /*Monoplegia of lower limb following other nontraumatic intracranial hemorrhage affecting right dominant side*/
,'I69242'  /*Monoplegia of lower limb following other nontraumatic intracranial hemorrhage affecting left dominant side*/
,'I69243'  /*Monoplegia of lower limb following other nontraumatic intracranial hemorrhage affecting right non-dominant side*/
,'I69244'  /*Monoplegia of lower limb following other nontraumatic intracranial hemorrhage affecting left non-dominant side*/
,'I69249'  /*Monoplegia of lower limb following other nontraumatic intracranial hemorrhage affecting unspecified side*/
,'I69251'  /*Hemiplegia and hemiparesis following other nontraumatic intracranial hemorrhage affecting right dominant side*/
,'I69252'  /*Hemiplegia and hemiparesis following other nontraumatic intracranial hemorrhage affecting left dominant side*/
,'I69253'  /*Hemiplegia and hemiparesis following other nontraumatic intracranial hemorrhage affecting right non-dominant side*/
,'I69254'  /*Hemiplegia and hemiparesis following other nontraumatic intracranial hemorrhage affecting left non-dominant side*/
,'I69259'  /*Hemiplegia and hemiparesis following other nontraumatic intracranial hemorrhage affecting unspecified side*/
,'I69261'  /*Other paralytic syndrome following other nontraumatic intracranial hemorrhage affecting right dominant side*/
,'I69262'  /*Other paralytic syndrome following other nontraumatic intracranial hemorrhage affecting left dominant side*/
,'I69263'  /*Other paralytic syndrome following other nontraumatic intracranial hemorrhage affecting right non-dominant side*/
,'I69264'  /*Other paralytic syndrome following other nontraumatic intracranial hemorrhage affecting left non-dominant side*/
,'I69265'  /*Other paralytic syndrome following other nontraumatic intracranial hemorrhage, bilateral*/
,'I69269'  /*Other paralytic syndrome following other nontraumatic intracranial hemorrhage affecting unspecified side*/
,'I69290'  /*Apraxia following other nontraumatic intracranial hemorrhage*/
,'I69291'  /*Dysphagia following other nontraumatic intracranial hemorrhage*/
,'I69292'  /*Facial weakness following other nontraumatic intracranial hemorrhage*/
,'I69293'  /*Ataxia following other nontraumatic intracranial hemorrhage*/
,'I69298'  /*Other sequelae of other nontraumatic intracranial hemorrhage*/
,'I6930'  /*Unspecified sequelae of cerebral infarction*/
,'I69310'  /*Attention and concentration deficit following cerebral infarction*/
,'I69311'  /*Memory deficit following cerebral infarction*/
,'I69312'  /*Visuospatial deficit and spatial neglect following cerebral infarction*/
,'I69313'  /*Psychomotor deficit following cerebral infarction*/
,'I69314'  /*Frontal lobe and executive function deficit following cerebral infarction*/
,'I69315'  /*Cognitive social or emotional deficit following cerebral infarction*/
,'I69318'  /*Other symptoms and signs involving cognitive functions following cerebral infarction*/
,'I69319'  /*Unspecified symptoms and signs involving cognitive functions following cerebral infarction*/
,'I69320'  /*Aphasia following cerebral infarction*/
,'I69321'  /*Dysphasia following cerebral infarction*/
,'I69322'  /*Dysarthria following cerebral infarction*/
,'I69323'  /*Fluency disorder following cerebral infarction*/
,'I69328'  /*Other speech and language deficits following cerebral infarction*/
,'I69331'  /*Monoplegia of upper limb following cerebral infarction affecting right dominant side*/
,'I69332'  /*Monoplegia of upper limb following cerebral infarction affecting left dominant side*/
,'I69333'  /*Monoplegia of upper limb following cerebral infarction affecting right non-dominant side*/
,'I69334'  /*Monoplegia of upper limb following cerebral infarction affecting left non-dominant side*/
,'I69339'  /*Monoplegia of upper limb following cerebral infarction affecting unspecified side*/
,'I69341'  /*Monoplegia of lower limb following cerebral infarction affecting right dominant side*/
,'I69342'  /*Monoplegia of lower limb following cerebral infarction affecting left dominant side*/
,'I69343'  /*Monoplegia of lower limb following cerebral infarction affecting right non-dominant side*/
,'I69344'  /*Monoplegia of lower limb following cerebral infarction affecting left non-dominant side*/
,'I69349'  /*Monoplegia of lower limb following cerebral infarction affecting unspecified side*/
,'I69351'  /*Hemiplegia and hemiparesis following cerebral infarction affecting right dominant side*/
,'I69352'  /*Hemiplegia and hemiparesis following cerebral infarction affecting left dominant side*/
,'I69353'  /*Hemiplegia and hemiparesis following cerebral infarction affecting right non-dominant side*/
,'I69354'  /*Hemiplegia and hemiparesis following cerebral infarction affecting left non-dominant side*/
,'I69359'  /*Hemiplegia and hemiparesis following cerebral infarction affecting unspecified side*/
,'I69361'  /*Other paralytic syndrome following cerebral infarction affecting right dominant side*/
,'I69362'  /*Other paralytic syndrome following cerebral infarction affecting left dominant side*/
,'I69363'  /*Other paralytic syndrome following cerebral infarction affecting right non-dominant side*/
,'I69364'  /*Other paralytic syndrome following cerebral infarction affecting left non-dominant side*/
,'I69365'  /*Other paralytic syndrome following cerebral infarction, bilateral*/
,'I69369'  /*Other paralytic syndrome following cerebral infarction affecting unspecified side*/
,'I69390'  /*Apraxia following cerebral infarction*/
,'I69391'  /*Dysphagia following cerebral infarction*/
,'I69392'  /*Facial weakness following cerebral infarction*/
,'I69393'  /*Ataxia following cerebral infarction*/
,'I69398'  /*Other sequelae of cerebral infarction*/
,'I6980'  /*Unspecified sequelae of other cerebrovascular disease*/
,'I69810'  /*Attention and concentration deficit following other cerebrovascular disease*/
,'I69811'  /*Memory deficit following other cerebrovascular disease*/
,'I69812'  /*Visuospatial deficit and spatial neglect following other cerebrovascular disease*/
,'I69813'  /*Psychomotor deficit following other cerebrovascular disease*/
,'I69814'  /*Frontal lobe and executive function deficit following other cerebrovascular disease*/
,'I69815'  /*Cognitive social or emotional deficit following other cerebrovascular disease*/
,'I69818'  /*Other symptoms and signs involving cognitive functions following other cerebrovascular disease*/
,'I69819'  /*Unspecified symptoms and signs involving cognitive functions following other cerebrovascular disease*/
,'I69820'  /*Aphasia following other cerebrovascular disease*/
,'I69821'  /*Dysphasia following other cerebrovascular disease*/
,'I69822'  /*Dysarthria following other cerebrovascular disease*/
,'I69823'  /*Fluency disorder following other cerebrovascular disease*/
,'I69828'  /*Other speech and language deficits following other cerebrovascular disease*/
,'I69831'  /*Monoplegia of upper limb following other cerebrovascular disease affecting right dominant side*/
,'I69832'  /*Monoplegia of upper limb following other cerebrovascular disease affecting left dominant side*/
,'I69833'  /*Monoplegia of upper limb following other cerebrovascular disease affecting right non-dominant side*/
,'I69834'  /*Monoplegia of upper limb following other cerebrovascular disease affecting left non-dominant side*/
,'I69839'  /*Monoplegia of upper limb following other cerebrovascular disease affecting unspecified side*/
,'I69841'  /*Monoplegia of lower limb following other cerebrovascular disease affecting right dominant side*/
,'I69842'  /*Monoplegia of lower limb following other cerebrovascular disease affecting left dominant side*/
,'I69843'  /*Monoplegia of lower limb following other cerebrovascular disease affecting right non-dominant side*/
,'I69844'  /*Monoplegia of lower limb following other cerebrovascular disease affecting left non-dominant side*/
,'I69849'  /*Monoplegia of lower limb following other cerebrovascular disease affecting unspecified side*/
,'I69851'  /*Hemiplegia and hemiparesis following other cerebrovascular disease affecting right dominant side*/
,'I69852'  /*Hemiplegia and hemiparesis following other cerebrovascular disease affecting left dominant side*/
,'I69853'  /*Hemiplegia and hemiparesis following other cerebrovascular disease affecting right non-dominant side*/
,'I69854'  /*Hemiplegia and hemiparesis following other cerebrovascular disease affecting left non-dominant side*/
,'I69859'  /*Hemiplegia and hemiparesis following other cerebrovascular disease affecting unspecified side*/
,'I69861'  /*Other paralytic syndrome following other cerebrovascular disease affecting right dominant side*/
,'I69862'  /*Other paralytic syndrome following other cerebrovascular disease affecting left dominant side*/
,'I69863'  /*Other paralytic syndrome following other cerebrovascular disease affecting right non-dominant side*/
,'I69864'  /*Other paralytic syndrome following other cerebrovascular disease affecting left non-dominant side*/
,'I69865'  /*Other paralytic syndrome following other cerebrovascular disease, bilateral*/
,'I69869'  /*Other paralytic syndrome following other cerebrovascular disease affecting unspecified side*/
,'I69890'  /*Apraxia following other cerebrovascular disease*/
,'I69891'  /*Dysphagia following other cerebrovascular disease*/
,'I69892'  /*Facial weakness following other cerebrovascular disease*/
,'I69893'  /*Ataxia following other cerebrovascular disease*/
,'I69898'  /*Other sequelae of other cerebrovascular disease*/
,'I6990'   /*Unspecified sequelae of unspecified cerebrovascular disease*/
,'I69920'  /*Aphasia following unspecified cerebrovascular disease*/
,'I69921'  /*Dysphasia following unspecified cerebrovascular disease*/
,'I69922'  /*Dysarthria following unspecified cerebrovascular disease*/
,'I69923'  /*Fluency disorder following unspecified cerebrovascular disease*/
,'I69928'  /*Other speech and language deficits following unspecified cerebrovascular disease*/
,'I69931'  /*Monoplegia of upper limb following unspecified cerebrovascular disease affecting right dominant side*/
,'I69932'  /*Monoplegia of upper limb following unspecified cerebrovascular disease affecting left dominant side*/
,'I69933'  /*Monoplegia of upper limb following unspecified cerebrovascular disease affecting right non-dominant side*/
,'I69934'  /*Monoplegia of upper limb following unspecified cerebrovascular disease affecting left non-dominant side*/
,'I69939'  /*Monoplegia of upper limb following unspecified cerebrovascular disease affecting unspecified side*/
,'I69941'  /*Monoplegia of lower limb following unspecified cerebrovascular disease affecting right dominant side*/
,'I69942'  /*Monoplegia of lower limb following unspecified cerebrovascular disease affecting left dominant side*/
,'I69943'  /*Monoplegia of lower limb following unspecified cerebrovascular disease affecting right non-dominant side*/
,'I69944'  /*Monoplegia of lower limb following unspecified cerebrovascular disease affecting left non-dominant side*/
,'I69949'  /*Monoplegia of lower limb following unspecified cerebrovascular disease affecting unspecified side*/
,'I69951'  /*Hemiplegia and hemiparesis following unspecified cerebrovascular disease affecting right dominant side*/
,'I69952'  /*Hemiplegia and hemiparesis following unspecified cerebrovascular disease affecting left dominant side*/
,'I69953'  /*Hemiplegia and hemiparesis following unspecified cerebrovascular disease affecting right non-dominant side*/
,'I69954'  /*Hemiplegia and hemiparesis following unspecified cerebrovascular disease affecting left non-dominant side*/
,'I69959'  /*Hemiplegia and hemiparesis following unspecified cerebrovascular disease affecting unspecified side*/
,'I69961'  /*Other paralytic syndrome following unspecified cerebrovascular disease affecting right dominant side*/
,'I69962'  /*Other paralytic syndrome following unspecified cerebrovascular disease affecting left dominant side*/
,'I69963'  /*Other paralytic syndrome following unspecified cerebrovascular disease affecting right non-dominant side*/
,'I69964'  /*Other paralytic syndrome following unspecified cerebrovascular disease affecting left non-dominant side*/
,'I69965'  /*Other paralytic syndrome following unspecified cerebrovascular disease, bilateral*/
,'I69969'  /*Other paralytic syndrome following unspecified cerebrovascular disease affecting unspecified side*/
,'I69990'  /*Apraxia following unspecified cerebrovascular disease*/
,'I69991'  /*Dysphagia following unspecified cerebrovascular disease*/
,'I69992'  /*Facial weakness following unspecified cerebrovascular disease*/
,'I69993'  /*Ataxia following unspecified cerebrovascular disease*/
,'I69998'  /*Other sequelae following unspecified cerebrovascular disease*/
,'M84750D'  /*Atypical femoral fracture, unspecified, subsequent encounter for fracture with routine healing*/
,'M84750G'  /*Atypical femoral fracture, unspecified, subsequent encounter for fracture with delayed healing*/
,'M84750K'  /*Atypical femoral fracture, unspecified, subsequent encounter for fracture with nonunion*/
,'M84750P'  /*Atypical femoral fracture, unspecified, subsequent encounter for fracture with malunion*/
,'M84750S'  /*Atypical femoral fracture, unspecified, sequela*/
,'M84751D'  /*Incomplete atypical femoral fracture, right leg, subsequent encounter for fracture with routine healing*/
,'M84751G'  /*Incomplete atypical femoral fracture, right leg, subsequent encounter for fracture with delayed healing*/
,'M84751K'  /*Incomplete atypical femoral fracture, right leg, subsequent encounter for fracture with nonunion*/
,'M84751P'  /*Incomplete atypical femoral fracture, right leg, subsequent encounter for fracture with malunion*/
,'M84751S'  /*Incomplete atypical femoral fracture, right leg, sequela*/
,'M84752D'  /*Incomplete atypical femoral fracture, left leg, subsequent encounter for fracture with routine healing*/
,'M84752G'  /*Incomplete atypical femoral fracture, left leg, subsequent encounter for fracture with delayed healing*/
,'M84752K'  /*Incomplete atypical femoral fracture, left leg, subsequent encounter for fracture with nonunion*/
,'M84752P'  /*Incomplete atypical femoral fracture, left leg, subsequent encounter for fracture with malunion*/
,'M84752S'  /*Incomplete atypical femoral fracture, left leg, sequela*/
,'M84753D'  /*Incomplete atypical femoral fracture, unspecified leg, subsequent encounter for fracture with routine healing*/
,'M84753G'  /*Incomplete atypical femoral fracture, unspecified leg, subsequent encounter for fracture with delayed healing*/
,'M84753K'  /*Incomplete atypical femoral fracture, unspecified leg, subsequent encounter for fracture with nonunion*/
,'M84753P'  /*Incomplete atypical femoral fracture, unspecified leg, subsequent encounter for fracture with malunion*/
,'M84753S'  /*Incomplete atypical femoral fracture, unspecified leg, sequela*/
,'M84754D'  /*Complete transverse atypical femoral fracture, right leg, subsequent encounter for fracture with routine healing*/
,'M84754G'  /*Complete transverse atypical femoral fracture, right leg, subsequent encounter for fracture with delayed healing*/
,'M84754K'  /*Complete transverse atypical femoral fracture, right leg, subsequent encounter for fracture with nonunion*/
,'M84754P'  /*Complete transverse atypical femoral fracture, right leg, subsequent encounter for fracture with malunion*/
,'M84754S'  /*Complete transverse atypical femoral fracture, right leg, sequela*/
,'M84755D'  /*Complete transverse atypical femoral fracture, left leg, subsequent encounter for fracture with routine healing*/
,'M84755G'  /*Complete transverse atypical femoral fracture, left leg, subsequent encounter for fracture with delayed healing*/
,'M84755K'  /*Complete transverse atypical femoral fracture, left leg, subsequent encounter for fracture with nonunion*/
,'M84755P'  /*Complete transverse atypical femoral fracture, left leg, subsequent encounter for fracture with malunion*/
,'M84755S'  /*Complete transverse atypical femoral fracture, left leg, sequela*/
,'M84756D'  /*Complete transverse atypical femoral fracture, unspecified leg, subsequent encounter for fracture with routine healing*/
,'M84756G'  /*Complete transverse atypical femoral fracture, unspecified leg, subsequent encounter for fracture with delayed healing*/
,'M84756K'  /*Complete transverse atypical femoral fracture, unspecified leg, subsequent encounter for fracture with nonunion*/
,'M84756P'  /*Complete transverse atypical femoral fracture, unspecified leg, subsequent encounter for fracture with malunion*/
,'M84756S'  /*Complete transverse atypical femoral fracture, unspecified leg, sequela*/
,'M84757D'  /*Complete oblique atypical femoral fracture, right leg, subsequent encounter for fracture with routine healing*/
,'M84757G'  /*Complete oblique atypical femoral fracture, right leg, subsequent encounter for fracture with delayed healing*/
,'M84757K'  /*Complete oblique atypical femoral fracture, right leg, subsequent encounter for fracture with nonunion*/
,'M84757P'  /*Complete oblique atypical femoral fracture, right leg, subsequent encounter for fracture with malunion*/
,'M84757S'  /*Complete oblique atypical femoral fracture, right leg, sequela*/
,'M84758D'  /*Complete oblique atypical femoral fracture, left leg, subsequent encounter for fracture with routine healing*/
,'M84758G'  /*Complete oblique atypical femoral fracture, left leg, subsequent encounter for fracture with delayed healing*/
,'M84758K'  /*Complete oblique atypical femoral fracture, left leg, subsequent encounter for fracture with nonunion*/
,'M84758P'  /*Complete oblique atypical femoral fracture, left leg, subsequent encounter for fracture with malunion*/
,'M84758S'  /*Complete oblique atypical femoral fracture, left leg, sequela*/
,'M84759D'  /*Complete oblique atypical femoral fracture, unspecified leg, subsequent encounter for fracture with routine healing*/
,'M84759G'  /*Complete oblique atypical femoral fracture, unspecified leg, subsequent encounter for fracture with delayed healing*/
,'M84759K'  /*Complete oblique atypical femoral fracture, unspecified leg, subsequent encounter for fracture with nonunion*/
,'M84759P'  /*Complete oblique atypical femoral fracture, unspecified leg, subsequent encounter for fracture with malunion*/
,'M84759S'  /*Complete oblique atypical femoral fracture, unspecified leg, sequela*/
,'M96840'  /*Postprocedural hematoma of a musculoskeletal structure following a musculoskeletal system procedure*/
,'M96841'  /*Postprocedural hematoma of a musculoskeletal structure following other procedure*/
,'M9701XD'  /*Periprosthetic fracture around internal prosthetic right hip joint, subsequent encounter*/
,'M9701XS'  /*Periprosthetic fracture around internal prosthetic right hip joint, sequela*/
,'M9702XD'  /*Periprosthetic fracture around internal prosthetic left hip joint, subsequent encounter*/
,'M9702XS'  /*Periprosthetic fracture around internal prosthetic left hip joint, sequela*/
,'M9711XD'  /*Periprosthetic fracture around internal prosthetic right knee joint, subsequent encounter*/
,'M9711XS'  /*Periprosthetic fracture around internal prosthetic right knee joint, sequela*/
,'M9712XD'  /*Periprosthetic fracture around internal prosthetic left knee joint, subsequent encounter*/
,'M9712XS'  /*Periprosthetic fracture around internal prosthetic left knee joint, sequela*/
,'M9721XD'  /*Periprosthetic fracture around internal prosthetic right ankle joint, subsequent encounter*/
,'M9721XS'  /*Periprosthetic fracture around internal prosthetic right ankle joint, sequela*/
,'M9722XD'  /*Periprosthetic fracture around internal prosthetic left ankle joint, subsequent encounter*/
,'M9722XS'  /*Periprosthetic fracture around internal prosthetic left ankle joint, sequela*/
,'M9731XD'  /*Periprosthetic fracture around internal prosthetic right shoulder joint, subsequent encounter*/
,'M9731XS'  /*Periprosthetic fracture around internal prosthetic right shoulder joint, sequela*/
,'M9732XD'  /*Periprosthetic fracture around internal prosthetic left shoulder joint, subsequent encounter*/
,'M9732XS'  /*Periprosthetic fracture around internal prosthetic left shoulder joint, sequela*/
,'M9741XD'  /*Periprosthetic fracture around internal prosthetic right elbow joint, subsequent encounter*/
,'M9741XS'  /*Periprosthetic fracture around internal prosthetic right elbow joint, sequela*/
,'M9742XD'  /*Periprosthetic fracture around internal prosthetic left elbow joint, subsequent encounter*/
,'M9742XS'  /*Periprosthetic fracture around internal prosthetic left elbow joint, sequela*/
,'M978XXD'  /*Periprosthetic fracture around other internal prosthetic joint, subsequent encounter*/
,'M978XXS'  /*Periprosthetic fracture around other internal prosthetic joint, sequela*/
,'M979XXD'  /*Periprosthetic fracture around unspecified internal prosthetic joint, subsequent encounter*/
,'M979XXS'  /*Periprosthetic fracture around unspecified internal prosthetic joint, sequela*/
,'O0900'   /*Supervision of pregnancy with history of infertility, unspecified trimester*/
,'O0901'   /*Supervision of pregnancy with history of infertility, first trimester*/
,'O0902'   /*Supervision of pregnancy with history of infertility, second trimester*/
,'O0903'   /*Supervision of pregnancy with history of infertility, third trimester*/
,'O0910'  /*Supervision of pregnancy with history of ectopic or molar pregnancy, unspecified trimester*/
,'O0911'   /*Supervision of pregnancy with history of ectopic or molar pregnancy, first trimester*/
,'O0912'   /*Supervision of pregnancy with history of ectopic or molar pregnancy, second trimester*/
,'O0913'   /*Supervision of pregnancy with history of ectopic or molar pregnancy, third trimester*/
,'O09211'   /*Supervision of pregnancy with history of pre-term labor, first trimester*/
,'O09212'  /*Supervision of pregnancy with history of pre-term labor, second trimester*/
,'O09213'  /*Supervision of pregnancy with history of pre-term labor, third trimester*/
,'O09219'  /*Supervision of pregnancy with history of pre-term labor, unspecified trimester*/
,'O09291'  /*Supervision of pregnancy with other poor reproductive or obstetric history, first trimester*/
,'O09292'  /*Supervision of pregnancy with other poor reproductive or obstetric history, second trimester*/
,'O09293'  /*Supervision of pregnancy with other poor reproductive or obstetric history, third trimester*/
,'O09299'  /*Supervision of pregnancy with other poor reproductive or obstetric history, unspecified trimester*/
,'O0930'  /*Supervision of pregnancy with insufficient antenatal care, unspecified trimester*/
,'O0931'  /*Supervision of pregnancy with insufficient antenatal care, first trimester*/
,'O0932'  /*Supervision of pregnancy with insufficient antenatal care, second trimester*/
,'O0933'  /*Supervision of pregnancy with insufficient antenatal care, third trimester*/
,'O0940'  /*Supervision of pregnancy with grand multiparity, unspecified trimester*/
,'O0941'  /*Supervision of pregnancy with grand multiparity, first trimester*/
,'O0942'  /*Supervision of pregnancy with grand multiparity, second trimester*/
,'O0943'  /*Supervision of pregnancy with grand multiparity, third trimester*/
,'O09511'  /*Supervision of elderly primigravida, first trimester*/
,'O09512'  /*Supervision of elderly primigravida, second trimester*/
,'O09513'  /*Supervision of elderly primigravida, third trimester*/
,'O09519'  /*Supervision of elderly primigravida, unspecified trimester*/
,'O09521'  /*Supervision of elderly multigravida, first trimester*/
,'O09522'  /*Supervision of elderly multigravida, second trimester*/
,'O09523'  /*Supervision of elderly multigravida, third trimester*/
,'O09529'  /*Supervision of elderly multigravida, unspecified trimester*/
,'O09611'  /*Supervision of young primigravida, first trimester*/
,'O09612'  /*Supervision of young primigravida, second trimester*/
,'O09613'  /*Supervision of young primigravida, third trimester*/
,'O09619'  /*Supervision of young primigravida, unspecified trimester*/
,'O09621'  /*Supervision of young multigravida, first trimester*/
,'O09622'  /*Supervision of young multigravida, second trimester*/
,'O09623'  /*Supervision of young multigravida, third trimester*/
,'O09629'  /*Supervision of young multigravida, unspecified trimester*/
,'O0970'  /*Supervision of high risk pregnancy due to social problems, unspecified trimester*/
,'O0971'  /*Supervision of high risk pregnancy due to social problems, first trimester*/
,'O0972'  /*Supervision of high risk pregnancy due to social problems, second trimester*/
,'O0973'  /*Supervision of high risk pregnancy due to social problems, third trimester*/
,'O09811'  /*Supervision of pregnancy resulting from assisted reproductive technology, first trimester*/
,'O09812'  /*Supervision of pregnancy resulting from assisted reproductive technology, second trimester*/
,'O09813'  /*Supervision of pregnancy resulting from assisted reproductive technology, third trimester*/
,'O09819'  /*Supervision of pregnancy resulting from assisted reproductive technology, unspecified trimester*/
,'O09821'  /*Supervision of pregnancy with history of in utero procedure during previous pregnancy, first trimester*/
,'O09822'  /*Supervision of pregnancy with history of in utero procedure during previous pregnancy, second trimester*/
,'O09823'  /*Supervision of pregnancy with history of in utero procedure during previous pregnancy, third trimester*/
,'O09829'  /*Supervision of pregnancy with history of in utero procedure during previous pregnancy, unspecified trimester*/
,'O09891'  /*Supervision of other high risk pregnancies, first trimester*/
,'O09892'  /*Supervision of other high risk pregnancies, second trimester*/
,'O09893'  /*Supervision of other high risk pregnancies, third trimester*/
,'O09899'  /*Supervision of other high risk pregnancies, unspecified trimester*/
,'O0990'  /*Supervision of high risk pregnancy, unspecified, unspecified trimester*/
,'O0991'  /*Supervision of high risk pregnancy, unspecified, first trimester*/
,'O0992'  /*Supervision of high risk pregnancy, unspecified, second trimester*/
,'O0993'  /*Supervision of high risk pregnancy, unspecified, third trimester*/
,'O665'  /*Attempted application of vacuum extractor and forceps*/
,'O80'  /*Encounter for full-term uncomplicated delivery*/
,'O94'  /*Sequelae of complication of pregnancy, childbirth, and the puerperium*/
,'P000'  /*Newborn affected by maternal hypertensive disorders*/
,'P001'  /*Newborn (suspected to be) affected by maternal renal and urinary tract diseases*/
,'P002'  /*Newborn affected by maternal infectious and parasitic diseases*/
,'P003'  /*Newborn affected by other maternal circulatory and respiratory diseases*/
,'P004'  /*Newborn affected by maternal nutritional disorders*/
,'P005'  /*Newborn affected by maternal injury*/
,'P006'  /*Newborn affected by surgical procedure on mother*/
,'P007'  /*Newborn affected by other medical procedures on mother, not elsewhere classified*/
,'P0081'  /*Newborn affected by periodontal disease in mother*/
,'P0089'  /*Newborn affected by other maternal conditions*/
,'P009'  /*Newborn affected by unspecified maternal condition*/
,'Q000'  /*Anencephaly*/
,'Q001'  /*Craniorachischisis*/
,'Q002'  /*Iniencephaly*/
,'Q010'  /*Frontal encephalocele*/
,'Q011'  /*Nasofrontal encephalocele*/
,'Q012'  /*Occipital encephalocele*/
,'Q018'  /*Encephalocele of other sites*/
,'Q019'  /*Encephalocele, unspecified*/
,'Q02'  /*Microcephaly*/
,'Q030'  /*Malformations of aqueduct of Sylvius*/
,'Q031'  /*Atresia of foramina of Magendie and Luschka*/
,'Q038'  /*Other congenital hydrocephalus*/
,'Q039'  /*Congenital hydrocephalus, unspecified*/
,'Q040'  /*Congenital malformations of corpus callosum*/
,'Q041'  /*Arhinencephaly*/
,'Q042'  /*Holoprosencephaly*/
,'Q043'  /*Other reduction deformities of brain*/
,'Q044'  /*Septo-optic dysplasia of brain*/
,'Q045'  /*Megalencephaly*/
,'Q046'  /*Congenital cerebral cysts*/
,'Q048'  /*Other specified congenital malformations of brain*/
,'Q049'  /*Congenital malformation of brain, unspecified*/
,'Q050'  /*Cervical spina bifida with hydrocephalus*/
,'Q051'  /*Thoracic spina bifida with hydrocephalus*/
,'Q052'  /*Lumbar spina bifida with hydrocephalus*/
,'Q053'  /*Sacral spina bifida with hydrocephalus*/
,'Q054'  /*Unspecified spina bifida with hydrocephalus*/
,'Q055'  /*Cervical spina bifida without hydrocephalus*/
,'Q056'  /*Thoracic spina bifida without hydrocephalus*/
,'Q057'  /*Lumbar spina bifida without hydrocephalus*/
,'Q058'  /*Sacral spina bifida without hydrocephalus*/
,'Q059'  /*Spina bifida, unspecified*/
,'Q060'  /*Amyelia*/
,'Q061'  /*Hypoplasia and dysplasia of spinal cord*/
,'Q062'  /*Diastematomyelia*/
,'Q063'  /*Other congenital cauda equina malformations*/
,'Q064'  /*Hydromyelia*/
,'Q068'  /*Other specified congenital malformations of spinal cord*/
,'Q069'  /*Congenital malformation of spinal cord, unspecified*/
,'Q0700'  /*Arnold-Chiari syndrome without spina bifida or hydrocephalus*/
,'Q0701'  /*Arnold-Chiari syndrome with spina bifida*/
,'Q0702'  /*Arnold-Chiari syndrome with hydrocephalus*/
,'Q0703'  /*Arnold-Chiari syndrome with spina bifida and hydrocephalus*/
,'Q078'  /*Other specified congenital malformations of nervous system*/
,'Q079'  /*Congenital malformation of nervous system, unspecified*/
,'Q100'  /*Congenital ptosis*/
,'Q101'  /*Congenital ectropion*/
,'Q102'  /*Congenital entropion*/
,'Q103'  /*Other congenital malformations of eyelid*/
,'Q104'  /*Absence and agenesis of lacrimal apparatus*/
,'Q105'  /*Congenital stenosis and stricture of lacrimal duct*/
,'Q106'  /*Other congenital malformations of lacrimal apparatus*/
,'Q107'  /*Congenital malformation of orbit*/
,'Q110'  /*Cystic eyeball*/
,'Q111'  /*Other anophthalmos*/
,'Q112'  /*Microphthalmos*/
,'Q113'  /*Macrophthalmos*/
,'Q120'  /*Congenital cataract*/
,'Q121'  /*Congenital displaced lens*/
,'Q122'  /*Coloboma of lens*/
,'Q123'  /*Congenital aphakia*/
,'Q124'  /*Spherophakia*/
,'Q128'  /*Other congenital lens malformations*/
,'Q129'  /*Congenital lens malformation, unspecified*/
,'Q130'  /*Coloboma of iris*/
,'Q131'  /*Absence of iris*/
,'Q132'  /*Other congenital malformations of iris*/
,'Q133'  /*Congenital corneal opacity*/
,'Q134'  /*Other congenital corneal malformations*/
,'Q135'  /*Blue sclera*/
,'Q1381'  /*Rieger's anomaly*/
,'Q1389'  /*Other congenital malformations of anterior segment of eye*/
,'Q139'  /*Congenital malformation of anterior segment of eye, unspecified*/
,'Q140'  /*Congenital malformation of vitreous humor*/
,'Q141'  /*Congenital malformation of retina*/
,'Q142'  /*Congenital malformation of optic disc*/
,'Q143'  /*Congenital malformation of choroid*/
,'Q148'  /*Other congenital malformations of posterior segment of eye*/
,'Q149'  /*Congenital malformation of posterior segment of eye, unspecified*/
,'Q150'  /*Congenital glaucoma*/
,'Q158'  /*Other specified congenital malformations of eye*/
,'Q159'  /*Congenital malformation of eye, unspecified*/
,'Q160'  /*Congenital absence of (ear) auricle*/
,'Q161'  /*Congenital absence, atresia and stricture of auditory canal (external)*/
,'Q162'  /*Absence of eustachian tube*/
,'Q163'  /*Congenital malformation of ear ossicles*/
,'Q164'  /*Other congenital malformations of middle ear*/
,'Q165'  /*Congenital malformation of inner ear*/
,'Q169'  /*Congenital malformation of ear causing impairment of hearing, unspecified*/
,'Q170'  /*Accessory auricle*/
,'Q171'  /*Macrotia*/
,'Q172'  /*Microtia*/
,'Q173'  /*Other misshapen ear*/
,'Q174'  /*Misplaced ear*/
,'Q175'  /*Prominent ear*/
,'Q178'  /*Other specified congenital malformations of ear*/
,'Q179'  /*Congenital malformation of ear, unspecified*/
,'Q180'  /*Sinus, fistula and cyst of branchial cleft*/
,'Q181'  /*Preauricular sinus and cyst*/
,'Q182'  /*Other branchial cleft malformations*/
,'Q183'  /*Webbing of neck*/
,'Q184'  /*Macrostomia*/
,'Q185'  /*Microstomia*/
,'Q186'  /*Macrocheilia*/
,'Q187'  /*Microcheilia*/
,'Q188'  /*Other specified congenital malformations of face and neck*/
,'Q189'  /*Congenital malformation of face and neck, unspecified*/
,'Q200'  /*Common arterial trunk*/
,'Q201'  /*Double outlet right ventricle*/
,'Q202'  /*Double outlet left ventricle*/
,'Q203'  /*Discordant ventriculoarterial connection*/
,'Q204'  /*Double inlet ventricle*/
,'Q205'  /*Discordant atrioventricular connection*/
,'Q206'  /*Isomerism of atrial appendages*/
,'Q208'  /*Other congenital malformations of cardiac chambers and connections*/
,'Q209'  /*Congenital malformation of cardiac chambers and connections, unspecified*/
,'Q210'  /*Ventricular septal defect*/
,'Q211'  /*Atrial septal defect*/
,'Q212'  /*Atrioventricular septal defect*/
,'Q213'  /*Tetralogy of Fallot*/
,'Q214'  /*Aortopulmonary septal defect*/
,'Q218'  /*Other congenital malformations of cardiac septa*/
,'Q219'  /*Congenital malformation of cardiac septum, unspecified*/
,'Q220'  /*Pulmonary valve atresia*/
,'Q221'  /*Congenital pulmonary valve stenosis*/
,'Q222'  /*Congenital pulmonary valve insufficiency*/
,'Q223'  /*Other congenital malformations of pulmonary valve*/
,'Q224'  /*Congenital tricuspid stenosis*/
,'Q225'  /*Ebstein's anomaly*/
,'Q226'  /*Hypoplastic right heart syndrome*/
,'Q228'  /*Other congenital malformations of tricuspid valve*/
,'Q229'  /*Congenital malformation of tricuspid valve, unspecified*/
,'Q230'  /*Congenital stenosis of aortic valve*/
,'Q231'  /*Congenital insufficiency of aortic valve*/
,'Q232'  /*Congenital mitral stenosis*/
,'Q233'  /*Congenital mitral insufficiency*/
,'Q234'  /*Hypoplastic left heart syndrome*/
,'Q238'  /*Other congenital malformations of aortic and mitral valves*/
,'Q239'  /*Congenital malformation of aortic and mitral valves, unspecified*/
,'Q240'  /*Dextrocardia*/
,'Q241'  /*Levocardia*/
,'Q242'  /*Cor triatriatum*/
,'Q243'  /*Pulmonary infundibular stenosis*/
,'Q244'  /*Congenital subaortic stenosis*/
,'Q245'  /*Malformation of coronary vessels*/
,'Q246'  /*Congenital heart block*/
,'Q248'  /*Other specified congenital malformations of heart*/
,'Q249'  /*Congenital malformation of heart, unspecified*/
,'Q250'  /*Patent ductus arteriosus*/
,'Q251'  /*Coarctation of aorta*/
,'Q2521'  /*Interruption of aortic arch*/
,'Q2529'  /*Other atresia of aorta*/
,'Q253'  /*Supravalvular aortic stenosis*/
,'Q2540'  /*Congenital malformation of aorta unspecified*/
,'Q2541'  /*Absence and aplasia of aorta*/
,'Q2542'  /*Hypoplasia of aorta*/
,'Q2543'  /*Congenital aneurysm of aorta*/
,'Q2544'  /*Congenital dilation of aorta*/
,'Q2545'  /*Double aortic arch*/
,'Q2546'  /*Tortuous aortic arch*/
,'Q2547'  /*Right aortic arch*/
,'Q2548'  /*Anomalous origin of subclavian artery*/
,'Q2549'  /*Other congenital malformations of aorta*/
,'Q255'  /*Atresia of pulmonary artery*/
,'Q256'  /*Stenosis of pulmonary artery*/
,'Q2571'  /*Coarctation of pulmonary artery*/
,'Q2572'  /*Congenital pulmonary arteriovenous malformation*/
,'Q2579'  /*Other congenital malformations of pulmonary artery*/
,'Q258'  /*Other congenital malformations of other great arteries*/
,'Q259'  /*Congenital malformation of great arteries, unspecified*/
,'Q260'  /*Congenital stenosis of vena cava*/
,'Q261'  /*Persistent left superior vena cava*/
,'Q262'  /*Total anomalous pulmonary venous connection*/
,'Q263'  /*Partial anomalous pulmonary venous connection*/
,'Q264'  /*Anomalous pulmonary venous connection, unspecified*/
,'Q265'  /*Anomalous portal venous connection*/
,'Q266'  /*Portal vein-hepatic artery fistula*/
,'Q268'  /*Other congenital malformations of great veins*/
,'Q269'  /*Congenital malformation of great vein, unspecified*/
,'Q270'  /*Congenital absence and hypoplasia of umbilical artery*/
,'Q271'  /*Congenital renal artery stenosis*/
,'Q272'  /*Other congenital malformations of renal artery*/
,'Q2730'  /*Arteriovenous malformation, site unspecified*/
,'Q2731'  /*Arteriovenous malformation of vessel of upper limb*/
,'Q2732'  /*Arteriovenous malformation of vessel of lower limb*/
,'Q2733'  /*Arteriovenous malformation of digestive system vessel*/
,'Q2734'  /*Arteriovenous malformation of renal vessel*/
,'Q2739'  /*Arteriovenous malformation, other site*/
,'Q274'  /*Congenital phlebectasia*/
,'Q278'  /*Other specified congenital malformations of peripheral vascular system*/
,'Q279'  /*Congenital malformation of peripheral vascular system, unspecified*/
,'Q280'  /*Arteriovenous malformation of precerebral vessels*/
,'Q281'  /*Other malformations of precerebral vessels*/
,'Q282'  /*Arteriovenous malformation of cerebral vessels*/
,'Q283'  /*Other malformations of cerebral vessels*/
,'Q288'  /*Other specified congenital malformations of circulatory system*/
,'Q289'  /*Congenital malformation of circulatory system, unspecified*/
,'Q300'  /*Choanal atresia*/
,'Q301'  /*Agenesis and underdevelopment of nose*/
,'Q302'  /*Fissured, notched and cleft nose*/
,'Q303'  /*Congenital perforated nasal septum*/
,'Q308'  /*Other congenital malformations of nose*/
,'Q309'  /*Congenital malformation of nose, unspecified*/
,'Q310'  /*Web of larynx*/
,'Q311'  /*Congenital subglottic stenosis*/
,'Q312'  /*Laryngeal hypoplasia*/
,'Q313'  /*Laryngocele*/
,'Q315'  /*Congenital laryngomalacia*/
,'Q318'  /*Other congenital malformations of larynx*/
,'Q319'  /*Congenital malformation of larynx, unspecified*/
,'Q320'  /*Congenital tracheomalacia*/
,'Q321'  /*Other congenital malformations of trachea*/
,'Q322'  /*Congenital bronchomalacia*/
,'Q323'  /*Congenital stenosis of bronchus*/
,'Q324'  /*Other congenital malformations of bronchus*/
,'Q330'  /*Congenital cystic lung*/
,'Q331'  /*Accessory lobe of lung*/
,'Q332'  /*Sequestration of lung*/
,'Q333'  /*Agenesis of lung*/
,'Q334'  /*Congenital bronchiectasis*/
,'Q335'  /*Ectopic tissue in lung*/
,'Q336'  /*Congenital hypoplasia and dysplasia of lung*/
,'Q338'  /*Other congenital malformations of lung*/
,'Q339'  /*Congenital malformation of lung, unspecified*/
,'Q340'  /*Anomaly of pleura*/
,'Q341'  /*Congenital cyst of mediastinum*/
,'Q348'  /*Other specified congenital malformations of respiratory system*/
,'Q349'  /*Congenital malformation of respiratory system, unspecified*/
,'Q351'  /*Cleft hard palate*/
,'Q353'  /*Cleft soft palate*/
,'Q355'  /*Cleft hard palate with cleft soft palate*/
,'Q357'  /*Cleft uvula*/
,'Q359'  /*Cleft palate, unspecified*/
,'Q360'  /*Cleft lip, bilateral*/
,'Q361'  /*Cleft lip, median*/
,'Q369'  /*Cleft lip, unilateral*/
,'Q370'  /*Cleft hard palate with bilateral cleft lip*/
,'Q371'  /*Cleft hard palate with unilateral cleft lip*/
,'Q372'  /*Cleft soft palate with bilateral cleft lip*/
,'Q373'  /*Cleft soft palate with unilateral cleft lip*/
,'Q374'  /*Cleft hard and soft palate with bilateral cleft lip*/
,'Q375'  /*Cleft hard and soft palate with unilateral cleft lip*/
,'Q378'  /*Unspecified cleft palate with bilateral cleft lip*/
,'Q379'  /*Unspecified cleft palate with unilateral cleft lip*/
,'Q380'  /*Congenital malformations of lips, not elsewhere classified*/
,'Q381'  /*Ankyloglossia*/
,'Q382'  /*Macroglossia*/
,'Q383'  /*Other congenital malformations of tongue*/
,'Q384'  /*Congenital malformations of salivary glands and ducts*/
,'Q385'  /*Congenital malformations of palate, not elsewhere classified*/
,'Q386'  /*Other congenital malformations of mouth*/
,'Q387'  /*Congenital pharyngeal pouch*/
,'Q388'  /*Other congenital malformations of pharynx*/
,'Q390'  /*Atresia of esophagus without fistula*/
,'Q391'  /*Atresia of esophagus with tracheo-esophageal fistula*/
,'Q392'  /*Congenital tracheo-esophageal fistula without atresia*/
,'Q393'  /*Congenital stenosis and stricture of esophagus*/
,'Q394'  /*Esophageal web*/
,'Q395'  /*Congenital dilatation of esophagus*/
,'Q396'  /*Congenital diverticulum of esophagus*/
,'Q398'  /*Other congenital malformations of esophagus*/
,'Q399'  /*Congenital malformation of esophagus, unspecified*/
,'Q400'  /*Congenital hypertrophic pyloric stenosis*/
,'Q401'  /*Congenital hiatus hernia*/
,'Q402'  /*Other specified congenital malformations of stomach*/
,'Q403'  /*Congenital malformation of stomach, unspecified*/
,'Q408'  /*Other specified congenital malformations of upper alimentary tract*/
,'Q409'  /*Congenital malformation of upper alimentary tract, unspecified*/
,'Q410'  /*Congenital absence, atresia and stenosis of duodenum*/
,'Q411'  /*Congenital absence, atresia and stenosis of jejunum*/
,'Q412'  /*Congenital absence, atresia and stenosis of ileum*/
,'Q418'  /*Congenital absence, atresia and stenosis of other specified parts of small intestine*/
,'Q419'  /*Congenital absence, atresia and stenosis of small intestine, part unspecified*/
,'Q420'  /*Congenital absence, atresia and stenosis of rectum with fistula*/
,'Q421'  /*Congenital absence, atresia and stenosis of rectum without fistula*/
,'Q422'  /*Congenital absence, atresia and stenosis of anus with fistula*/
,'Q423'  /*Congenital absence, atresia and stenosis of anus without fistula*/
,'Q428'  /*Congenital absence, atresia and stenosis of other parts of large intestine*/
,'Q429'  /*Congenital absence, atresia and stenosis of large intestine, part unspecified*/
,'Q430'  /*Meckel's diverticulum (displaced) (hypertrophic)*/
,'Q431'  /*Hirschsprung's disease*/
,'Q432'  /*Other congenital functional disorders of colon*/
,'Q433'  /*Congenital malformations of intestinal fixation*/
,'Q434'  /*Duplication of intestine*/
,'Q435'  /*Ectopic anus*/
,'Q436'  /*Congenital fistula of rectum and anus*/
,'Q437'  /*Persistent cloaca*/
,'Q438'  /*Other specified congenital malformations of intestine*/
,'Q439'  /*Congenital malformation of intestine, unspecified*/
,'Q440'  /*Agenesis, aplasia and hypoplasia of gallbladder*/
,'Q441'  /*Other congenital malformations of gallbladder*/
,'Q442'  /*Atresia of bile ducts*/
,'Q443'  /*Congenital stenosis and stricture of bile ducts*/
,'Q444'  /*Choledochal cyst*/
,'Q445'  /*Other congenital malformations of bile ducts*/
,'Q446'  /*Cystic disease of liver*/
,'Q447'  /*Other congenital malformations of liver*/
,'Q450'  /*Agenesis, aplasia and hypoplasia of pancreas*/
,'Q451'  /*Annular pancreas*/
,'Q452'  /*Congenital pancreatic cyst*/
,'Q453'  /*Other congenital malformations of pancreas and pancreatic duct*/
,'Q458'  /*Other specified congenital malformations of digestive system*/
,'Q459'  /*Congenital malformation of digestive system, unspecified*/
,'Q5001'  /*Congenital absence of ovary, unilateral*/
,'Q5002'  /*Congenital absence of ovary, bilateral*/
,'Q501'  /*Developmental ovarian cyst*/
,'Q502'  /*Congenital torsion of ovary*/
,'Q5031'  /*Accessory ovary*/
,'Q5032'  /*Ovarian streak*/
,'Q5039'  /*Other congenital malformation of ovary*/
,'Q504'  /*Embryonic cyst of fallopian tube*/
,'Q505'  /*Embryonic cyst of broad ligament*/
,'Q506'  /*Other congenital malformations of fallopian tube and broad ligament*/
,'Q510'  /*Agenesis and aplasia of uterus*/
,'Q5110'  /*Doubling of uterus with doubling of cervix and vagina without obstruction*/
,'Q5111'  /*Doubling of uterus with doubling of cervix and vagina with obstruction*/
,'Q512'  /*Other doubling of uterus*/
,'Q513'  /*Bicornate uterus*/
,'Q514'  /*Unicornate uterus*/
,'Q515'  /*Agenesis and aplasia of cervix*/
,'Q516'  /*Embryonic cyst of cervix*/
,'Q517'  /*Congenital fistulae between uterus and digestive and urinary tracts*/
,'Q51810'  /*Arcuate uterus*/
,'Q51811'  /*Hypoplasia of uterus*/
,'Q51818'  /*Other congenital malformations of uterus*/
,'Q51820'  /*Cervical duplication*/
,'Q51821'  /*Hypoplasia of cervix*/
,'Q51828'  /*Other congenital malformations of cervix*/
,'Q519'  /*Congenital malformation of uterus and cervix, unspecified*/
,'Q520'  /*Congenital absence of vagina*/
,'Q5210'  /*Doubling of vagina, unspecified*/
,'Q5211'  /*Transverse vaginal septum*/
,'Q52120'  /*Longitudinal vaginal septum, nonobstructing*/
,'Q52121'  /*Longitudinal vaginal septum, obstructing, right side*/
,'Q52122'  /*Longitudinal vaginal septum, obstructing, left side*/
,'Q52123'  /*Longitudinal vaginal septum, microperforate, right side*/
,'Q52124'  /*Longitudinal vaginal septum, microperforate, left side*/
,'Q52129'  /*Other and unspecified longitudinal vaginal septum*/
,'Q522'  /*Congenital rectovaginal fistula*/
,'Q523'  /*Imperforate hymen*/
,'Q524'  /*Other congenital malformations of vagina*/
,'Q525'  /*Fusion of labia*/
,'Q526'  /*Congenital malformation of clitoris*/
,'Q5270'  /*Unspecified congenital malformations of vulva*/
,'Q5271'  /*Congenital absence of vulva*/
,'Q5279'  /*Other congenital malformations of vulva*/
,'Q528'  /*Other specified congenital malformations of female genitalia*/
,'Q529'  /*Congenital malformation of female genitalia, unspecified*/
,'Q5300'  /*Ectopic testis, unspecified*/
,'Q5301'  /*Ectopic testis, unilateral*/
,'Q5302'  /*Ectopic testes, bilateral*/
,'Q5310'  /*Unspecified undescended testicle, unilateral*/
,'Q5311'  /*Abdominal testis, unilateral*/
,'Q5312'  /*Ectopic perineal testis, unilateral*/
,'Q5320'  /*Undescended testicle, unspecified, bilateral*/
,'Q5321'  /*Abdominal testis, bilateral*/
,'Q5322'  /*Ectopic perineal testis, bilateral*/
,'Q539'  /*Undescended testicle, unspecified*/
,'Q540'  /*Hypospadias, balanic*/
,'Q541'  /*Hypospadias, penile*/
,'Q542'  /*Hypospadias, penoscrotal*/
,'Q543'  /*Hypospadias, perineal*/
,'Q544'  /*Congenital chordee*/
,'Q548'  /*Other hypospadias*/
,'Q549'  /*Hypospadias, unspecified*/
,'Q550'  /*Absence and aplasia of testis*/
,'Q551'  /*Hypoplasia of testis and scrotum*/
,'Q5520'  /*Unspecified congenital malformations of testis and scrotum*/
,'Q5521'  /*Polyorchism*/
,'Q5522'  /*Retractile testis*/
,'Q5523'  /*Scrotal transposition*/
,'Q5529'  /*Other congenital malformations of testis and scrotum*/
,'Q553'  /*Atresia of vas deferens*/
,'Q554'  /*Other congenital malformations of vas deferens, epididymis, seminal vesicles and prostate*/
,'Q555'  /*Congenital absence and aplasia of penis*/
,'Q5561'  /*Curvature of penis (lateral)*/
,'Q5562'  /*Hypoplasia of penis*/
,'Q5563'  /*Congenital torsion of penis*/
,'Q5564'  /*Hidden penis*/
,'Q5569'  /*Other congenital malformation of penis*/
,'Q557'  /*Congenital vasocutaneous fistula*/
,'Q558'  /*Other specified congenital malformations of male genital organs*/
,'Q559'  /*Congenital malformation of male genital organ, unspecified*/
,'Q560'  /*Hermaphroditism, not elsewhere classified*/
,'Q561'  /*Male pseudohermaphroditism, not elsewhere classified*/
,'Q562'  /*Female pseudohermaphroditism, not elsewhere classified*/
,'Q563'  /*Pseudohermaphroditism, unspecified*/
,'Q564'  /*Indeterminate sex, unspecified*/
,'Q600'  /*Renal agenesis, unilateral*/
,'Q601'  /*Renal agenesis, bilateral*/
,'Q602'  /*Renal agenesis, unspecified*/
,'Q603'  /*Renal hypoplasia, unilateral*/
,'Q604'  /*Renal hypoplasia, bilateral*/
,'Q605'  /*Renal hypoplasia, unspecified*/
,'Q606'  /*Potter's syndrome*/
,'Q6100'  /*Congenital renal cyst, unspecified*/
,'Q6101'  /*Congenital single renal cyst*/
,'Q6102'  /*Congenital multiple renal cysts*/
,'Q6111'  /*Cystic dilatation of collecting ducts*/
,'Q6119'  /*Other polycystic kidney, infantile type*/
,'Q612'  /*Polycystic kidney, adult type*/
,'Q613'  /*Polycystic kidney, unspecified*/
,'Q614'  /*Renal dysplasia*/
,'Q615'  /*Medullary cystic kidney*/
,'Q618'  /*Other cystic kidney diseases*/
,'Q619'  /*Cystic kidney disease, unspecified*/
,'Q620'  /*Congenital hydronephrosis*/
,'Q6210'  /*Congenital occlusion of ureter, unspecified*/
,'Q6211'  /*Congenital occlusion of ureteropelvic junction*/
,'Q6212'  /*Congenital occlusion of ureterovesical orifice*/
,'Q622'  /*Congenital megaureter*/
,'Q6231'  /*Congenital ureterocele, orthotopic*/
,'Q6232'  /*Cecoureterocele*/
,'Q6239'  /*Other obstructive defects of renal pelvis and ureter*/
,'Q624'  /*Agenesis of ureter*/
,'Q625'  /*Duplication of ureter*/
,'Q6260'  /*Malposition of ureter, unspecified*/
,'Q6261'  /*Deviation of ureter*/
,'Q6262'  /*Displacement of ureter*/
,'Q6263'  /*Anomalous implantation of ureter*/
,'Q6269'  /*Other malposition of ureter*/
,'Q627'  /*Congenital vesico-uretero-renal reflux*/
,'Q628'  /*Other congenital malformations of ureter*/
,'Q630'  /*Accessory kidney*/
,'Q631'  /*Lobulated, fused and horseshoe kidney*/
,'Q632'  /*Ectopic kidney*/
,'Q633'  /*Hyperplastic and giant kidney*/
,'Q638'  /*Other specified congenital malformations of kidney*/
,'Q639'  /*Congenital malformation of kidney, unspecified*/
,'Q640'  /*Epispadias*/
,'Q6410'  /*Exstrophy of urinary bladder, unspecified*/
,'Q6411'  /*Supravesical fissure of urinary bladder*/
,'Q6412'  /*Cloacal extrophy of urinary bladder*/
,'Q6419'  /*Other exstrophy of urinary bladder*/
,'Q642'  /*Congenital posterior urethral valves*/
,'Q6431'  /*Congenital bladder neck obstruction*/
,'Q6432'  /*Congenital stricture of urethra*/
,'Q6433'  /*Congenital stricture of urinary meatus*/
,'Q6439'  /*Other atresia and stenosis of urethra and bladder neck*/
,'Q644'  /*Malformation of urachus*/
,'Q645'  /*Congenital absence of bladder and urethra*/
,'Q646'  /*Congenital diverticulum of bladder*/
,'Q6470'  /*Unspecified congenital malformation of bladder and urethra*/
,'Q6471'  /*Congenital prolapse of urethra*/
,'Q6472'  /*Congenital prolapse of urinary meatus*/
,'Q6473'  /*Congenital urethrorectal fistula*/
,'Q6474'  /*Double urethra*/
,'Q6475'  /*Double urinary meatus*/
,'Q6479'  /*Other congenital malformations of bladder and urethra*/
,'Q648'  /*Other specified congenital malformations of urinary system*/
,'Q649'  /*Congenital malformation of urinary system, unspecified*/
,'Q6500'  /*Congenital dislocation of unspecified hip, unilateral*/
,'Q6501'  /*Congenital dislocation of right hip, unilateral*/
,'Q6502'  /*Congenital dislocation of left hip, unilateral*/
,'Q651'  /*Congenital dislocation of hip, bilateral*/
,'Q652'  /*Congenital dislocation of hip, unspecified*/
,'Q6530'  /*Congenital partial dislocation of unspecified hip, unilateral*/
,'Q6531'  /*Congenital partial dislocation of right hip, unilateral*/
,'Q6532'  /*Congenital partial dislocation of left hip, unilateral*/
,'Q654'  /*Congenital partial dislocation of hip, bilateral*/
,'Q655'  /*Congenital partial dislocation of hip, unspecified*/
,'Q656'  /*Congenital unstable hip*/
,'Q6581'  /*Congenital coxa valga*/
,'Q6582'  /*Congenital coxa vara*/
,'Q6589'  /*Other specified congenital deformities of hip*/
,'Q659'  /*Congenital deformity of hip, unspecified*/
,'Q660'  /*Congenital talipes equinovarus*/
,'Q661'  /*Congenital talipes calcaneovarus*/
,'Q6621'  /*Congenital metatarsus primus varus*/
,'Q6622'  /*Congenital metatarsus adductus*/
,'Q663'  /*Other congenital varus deformities of feet*/
,'Q664'  /*Congenital talipes calcaneovalgus*/
,'Q6650'  /*Congenital pes planus, unspecified foot*/
,'Q6651'  /*Congenital pes planus, right foot*/
,'Q6652'  /*Congenital pes planus, left foot*/
,'Q666'  /*Other congenital valgus deformities of feet*/
,'Q667'  /*Congenital pes cavus*/
,'Q6680'  /*Congenital vertical talus deformity, unspecified foot*/
,'Q6681'  /*Congenital vertical talus deformity, right foot*/
,'Q6682'  /*Congenital vertical talus deformity, left foot*/
,'Q6689'  /*Other specified congenital deformities of feet*/
,'Q669'  /*Congenital deformity of feet, unspecified*/
,'Q670'  /*Congenital facial asymmetry*/
,'Q671'  /*Congenital compression facies*/
,'Q672'  /*Dolichocephaly*/
,'Q673'  /*Plagiocephaly*/
,'Q674'  /*Other congenital deformities of skull, face and jaw*/
,'Q675'  /*Congenital deformity of spine*/
,'Q676'  /*Pectus excavatum*/
,'Q677'  /*Pectus carinatum*/
,'Q678'  /*Other congenital deformities of chest*/
,'Q680'  /*Congenital deformity of sternocleidomastoid muscle*/
,'Q681'  /*Congenital deformity of finger(s) and hand*/
,'Q682'  /*Congenital deformity of knee*/
,'Q683'  /*Congenital bowing of femur*/
,'Q684'  /*Congenital bowing of tibia and fibula*/
,'Q685'  /*Congenital bowing of long bones of leg, unspecified*/
,'Q686'  /*Discoid meniscus*/
,'Q688'  /*Other specified congenital musculoskeletal deformities*/
,'Q690'  /*Accessory finger(s)*/
,'Q691'  /*Accessory thumb(s)*/
,'Q692'  /*Accessory toe(s)*/
,'Q699'  /*Polydactyly, unspecified*/
,'Q7000'  /*Fused fingers, unspecified hand*/
,'Q7001'  /*Fused fingers, right hand*/
,'Q7002'  /*Fused fingers, left hand*/
,'Q7003'  /*Fused fingers, bilateral*/
,'Q7010'  /*Webbed fingers, unspecified hand*/
,'Q7011'  /*Webbed fingers, right hand*/
,'Q7012'  /*Webbed fingers, left hand*/
,'Q7013'  /*Webbed fingers, bilateral*/
,'Q7020'  /*Fused toes, unspecified foot*/
,'Q7021'  /*Fused toes, right foot*/
,'Q7022'  /*Fused toes, left foot*/
,'Q7023'  /*Fused toes, bilateral*/
,'Q7030'  /*Webbed toes, unspecified foot*/
,'Q7031'  /*Webbed toes, right foot*/
,'Q7032'  /*Webbed toes, left foot*/
,'Q7033'  /*Webbed toes, bilateral*/
,'Q704'  /*Polysyndactyly, unspecified*/
,'Q709'  /*Syndactyly, unspecified*/
,'Q7100'  /*Congenital complete absence of unspecified upper limb*/
,'Q7101'  /*Congenital complete absence of right upper limb*/
,'Q7102'  /*Congenital complete absence of left upper limb*/
,'Q7103'  /*Congenital complete absence of upper limb, bilateral*/
,'Q7110'  /*Congenital absence of unspecified upper arm and forearm with hand present*/
,'Q7111'  /*Congenital absence of right upper arm and forearm with hand present*/
,'Q7112'  /*Congenital absence of left upper arm and forearm with hand present*/
,'Q7113'  /*Congenital absence of upper arm and forearm with hand present, bilateral*/
,'Q7120'  /*Congenital absence of both forearm and hand, unspecified upper limb*/
,'Q7121'  /*Congenital absence of both forearm and hand, right upper limb*/
,'Q7122'  /*Congenital absence of both forearm and hand, left upper limb*/
,'Q7123'  /*Congenital absence of both forearm and hand, bilateral*/
,'Q7130'  /*Congenital absence of unspecified hand and finger*/
,'Q7131'  /*Congenital absence of right hand and finger*/
,'Q7132'  /*Congenital absence of left hand and finger*/
,'Q7133'  /*Congenital absence of hand and finger, bilateral*/
,'Q7140'  /*Longitudinal reduction defect of unspecified radius*/
,'Q7141'  /*Longitudinal reduction defect of right radius*/
,'Q7142'  /*Longitudinal reduction defect of left radius*/
,'Q7143'  /*Longitudinal reduction defect of radius, bilateral*/
,'Q7150'  /*Longitudinal reduction defect of unspecified ulna*/
,'Q7151'  /*Longitudinal reduction defect of right ulna*/
,'Q7152'  /*Longitudinal reduction defect of left ulna*/
,'Q7153'  /*Longitudinal reduction defect of ulna, bilateral*/
,'Q7160'  /*Lobster-claw hand, unspecified hand*/
,'Q7161'  /*Lobster-claw right hand*/
,'Q7162'  /*Lobster-claw left hand*/
,'Q7163'  /*Lobster-claw hand, bilateral*/
,'Q71811'  /*Congenital shortening of right upper limb*/
,'Q71812'  /*Congenital shortening of left upper limb*/
,'Q71813'  /*Congenital shortening of upper limb, bilateral*/
,'Q71819'  /*Congenital shortening of unspecified upper limb*/
,'Q71891'  /*Other reduction defects of right upper limb*/
,'Q71892'  /*Other reduction defects of left upper limb*/
,'Q71893'  /*Other reduction defects of upper limb, bilateral*/
,'Q71899'  /*Other reduction defects of unspecified upper limb*/
,'Q7190'  /*Unspecified reduction defect of unspecified upper limb*/
,'Q7191'  /*Unspecified reduction defect of right upper limb*/
,'Q7192'  /*Unspecified reduction defect of left upper limb*/
,'Q7193'  /*Unspecified reduction defect of upper limb, bilateral*/
,'Q7200'  /*Congenital complete absence of unspecified lower limb*/
,'Q7201'  /*Congenital complete absence of right lower limb*/
,'Q7202'  /*Congenital complete absence of left lower limb*/
,'Q7203'  /*Congenital complete absence of lower limb, bilateral*/
,'Q7210'  /*Congenital absence of unspecified thigh and lower leg with foot present*/
,'Q7211'  /*Congenital absence of right thigh and lower leg with foot present*/
,'Q7212'  /*Congenital absence of left thigh and lower leg with foot present*/
,'Q7213'  /*Congenital absence of thigh and lower leg with foot present, bilateral*/
,'Q7220'  /*Congenital absence of both lower leg and foot, unspecified lower limb*/
,'Q7221'  /*Congenital absence of both lower leg and foot, right lower limb*/
,'Q7222'  /*Congenital absence of both lower leg and foot, left lower limb*/
,'Q7223'  /*Congenital absence of both lower leg and foot, bilateral*/
,'Q7230'  /*Congenital absence of unspecified foot and toe(s)*/
,'Q7231'  /*Congenital absence of right foot and toe(s)*/
,'Q7232'  /*Congenital absence of left foot and toe(s)*/
,'Q7233'  /*Congenital absence of foot and toe(s), bilateral*/
,'Q7240'  /*Longitudinal reduction defect of unspecified femur*/
,'Q7241'  /*Longitudinal reduction defect of right femur*/
,'Q7242'  /*Longitudinal reduction defect of left femur*/
,'Q7243'  /*Longitudinal reduction defect of femur, bilateral*/
,'Q7250'  /*Longitudinal reduction defect of unspecified tibia*/
,'Q7251'  /*Longitudinal reduction defect of right tibia*/
,'Q7252'  /*Longitudinal reduction defect of left tibia*/
,'Q7253'  /*Longitudinal reduction defect of tibia, bilateral*/
,'Q7260'  /*Longitudinal reduction defect of unspecified fibula*/
,'Q7261'  /*Longitudinal reduction defect of right fibula*/
,'Q7262'  /*Longitudinal reduction defect of left fibula*/
,'Q7263'  /*Longitudinal reduction defect of fibula, bilateral*/
,'Q7270'  /*Split foot, unspecified lower limb*/
,'Q7271'  /*Split foot, right lower limb*/
,'Q7272'  /*Split foot, left lower limb*/
,'Q7273'  /*Split foot, bilateral*/
,'Q72811'  /*Congenital shortening of right lower limb*/
,'Q72812'  /*Congenital shortening of left lower limb*/
,'Q72813'  /*Congenital shortening of lower limb, bilateral*/
,'Q72819'  /*Congenital shortening of unspecified lower limb*/
,'Q72891'  /*Other reduction defects of right lower limb*/
,'Q72892'  /*Other reduction defects of left lower limb*/
,'Q72893'  /*Other reduction defects of lower limb, bilateral*/
,'Q72899'  /*Other reduction defects of unspecified lower limb*/
,'Q7290'  /*Unspecified reduction defect of unspecified lower limb*/
,'Q7291'  /*Unspecified reduction defect of right lower limb*/
,'Q7292'  /*Unspecified reduction defect of left lower limb*/
,'Q7293'  /*Unspecified reduction defect of lower limb, bilateral*/
,'Q730'  /*Congenital absence of unspecified limb(s)*/
,'Q731'  /*Phocomelia, unspecified limb(s)*/
,'Q738'  /*Other reduction defects of unspecified limb(s)*/
,'Q740'  /*Other congenital malformations of upper limb(s), including shoulder girdle*/
,'Q741'  /*Congenital malformation of knee*/
,'Q742'  /*Other congenital malformations of lower limb(s), including pelvic girdle*/
,'Q743'  /*Arthrogryposis multiplex congenita*/
,'Q748'  /*Other specified congenital malformations of limb(s)*/
,'Q749'  /*Unspecified congenital malformation of limb(s)*/
,'Q750'  /*Craniosynostosis*/
,'Q751'  /*Craniofacial dysostosis*/
,'Q752'  /*Hypertelorism*/
,'Q753'  /*Macrocephaly*/
,'Q754'  /*Mandibulofacial dysostosis*/
,'Q755'  /*Oculomandibular dysostosis*/
,'Q758'  /*Other specified congenital malformations of skull and face bones*/
,'Q759'  /*Congenital malformation of skull and face bones, unspecified*/
,'Q760'  /*Spina bifida occulta*/
,'Q761'  /*Klippel-Feil syndrome*/
,'Q762'  /*Congenital spondylolisthesis*/
,'Q763'  /*Congenital scoliosis due to congenital bony malformation*/
,'Q76411'  /*Congenital kyphosis, occipito-atlanto-axial region*/
,'Q76412'  /*Congenital kyphosis, cervical region*/
,'Q76413'  /*Congenital kyphosis, cervicothoracic region*/
,'Q76414'  /*Congenital kyphosis, thoracic region*/
,'Q76415'  /*Congenital kyphosis, thoracolumbar region*/
,'Q76419'  /*Congenital kyphosis, unspecified region*/
,'Q76425'  /*Congenital lordosis, thoracolumbar region*/
,'Q76426'  /*Congenital lordosis, lumbar region*/
,'Q76427'  /*Congenital lordosis, lumbosacral region*/
,'Q76428'  /*Congenital lordosis, sacral and sacrococcygeal region*/
,'Q76429'  /*Congenital lordosis, unspecified region*/
,'Q7649'  /*Other congenital malformations of spine, not associated with scoliosis*/
,'Q765'  /*Cervical rib*/
,'Q766'  /*Other congenital malformations of ribs*/
,'Q767'  /*Congenital malformation of sternum*/
,'Q768'  /*Other congenital malformations of bony thorax*/
,'Q769'  /*Congenital malformation of bony thorax, unspecified*/
,'Q770'  /*Achondrogenesis*/
,'Q771'  /*Thanatophoric short stature*/
,'Q772'  /*Short rib syndrome*/
,'Q773'  /*Chondrodysplasia punctata*/
,'Q774'  /*Achondroplasia*/
,'Q775'  /*Diastrophic dysplasia*/
,'Q776'  /*Chondroectodermal dysplasia*/
,'Q777'  /*Spondyloepiphyseal dysplasia*/
,'Q778'  /*Other osteochondrodysplasia with defects of growth of tubular bones and spine*/
,'Q779'  /*Osteochondrodysplasia with defects of growth of tubular bones and spine, unspecified*/
,'Q780'  /*Osteogenesis imperfecta*/
,'Q781'  /*Polyostotic fibrous dysplasia*/
,'Q782'  /*Osteopetrosis*/
,'Q783'  /*Progressive diaphyseal dysplasia*/
,'Q784'  /*Enchondromatosis*/
,'Q785'  /*Metaphyseal dysplasia*/
,'Q786'  /*Multiple congenital exostoses*/
,'Q788'  /*Other specified osteochondrodysplasias*/
,'Q789'  /*Osteochondrodysplasia, unspecified*/
,'Q790'  /*Congenital diaphragmatic hernia*/
,'Q791'  /*Other congenital malformations of diaphragm*/
,'Q792'  /*Exomphalos*/
,'Q793'  /*Gastroschisis*/
,'Q794'  /*Prune belly syndrome*/
,'Q7951'  /*Congenital hernia of bladder*/
,'Q7959'  /*Other congenital malformations of abdominal wall*/
,'Q796'  /*Ehlers-Danlos syndrome*/
,'Q798'  /*Other congenital malformations of musculoskeletal system*/
,'Q799'  /*Congenital malformation of musculoskeletal system, unspecified*/
,'Q800'  /*Ichthyosis vulgaris*/
,'Q801'  /*X-linked ichthyosis*/
,'Q802'  /*Lamellar ichthyosis*/
,'Q803'  /*Congenital bullous ichthyosiform erythroderma*/
,'Q804'  /*Harlequin fetus*/
,'Q808'  /*Other congenital ichthyosis*/
,'Q809'  /*Congenital ichthyosis, unspecified*/
,'Q810'  /*Epidermolysis bullosa simplex*/
,'Q811'  /*Epidermolysis bullosa letalis*/
,'Q812'  /*Epidermolysis bullosa dystrophica*/
,'Q818'  /*Other epidermolysis bullosa*/
,'Q819'  /*Epidermolysis bullosa, unspecified*/
,'Q820'  /*Hereditary lymphedema*/
,'Q821'  /*Xeroderma pigmentosum*/
,'Q822'  /*Mastocytosis*/
,'Q823'  /*Incontinentia pigmenti*/
,'Q824'  /*Ectodermal dysplasia (anhidrotic)*/
,'Q825'  /*Congenital non-neoplastic nevus*/
,'Q826'  /*Congenital sacral dimple*/
,'Q828'  /*Other specified congenital malformations of skin*/
,'Q829'  /*Congenital malformation of skin, unspecified*/
,'Q830'  /*Congenital absence of breast with absent nipple*/
,'Q831'  /*Accessory breast*/
,'Q832'  /*Absent nipple*/
,'Q833'  /*Accessory nipple*/
,'Q838'  /*Other congenital malformations of breast*/
,'Q839'  /*Congenital malformation of breast, unspecified*/
,'Q840'  /*Congenital alopecia*/
,'Q841'  /*Congenital morphological disturbances of hair, not elsewhere classified*/
,'Q842'  /*Other congenital malformations of hair*/
,'Q843'  /*Anonychia*/
,'Q844'  /*Congenital leukonychia*/
,'Q845'  /*Enlarged and hypertrophic nails*/
,'Q846'  /*Other congenital malformations of nails*/
,'Q848'  /*Other specified congenital malformations of integument*/
,'Q849'  /*Congenital malformation of integument, unspecified*/
,'Q8500'  /*Neurofibromatosis, unspecified*/
,'Q8501'  /*Neurofibromatosis, type 1*/
,'Q8502'  /*Neurofibromatosis, type 2*/
,'Q8503'  /*Schwannomatosis*/
,'Q8509'  /*Other neurofibromatosis*/
,'Q851'  /*Tuberous sclerosis*/
,'Q858'  /*Other phakomatoses, not elsewhere classified*/
,'Q859'  /*Phakomatosis, unspecified*/
,'Q860'  /*Fetal alcohol syndrome (dysmorphic)*/
,'Q861'  /*Fetal hydantoin syndrome*/
,'Q862'  /*Dysmorphism due to warfarin*/
,'Q868'  /*Other congenital malformation syndromes due to known exogenous causes*/
,'Q870'  /*Congenital malformation syndromes predominantly affecting facial appearance*/
,'Q871'  /*Congenital malformation syndromes predominantly associated with short stature*/
,'Q872'  /*Congenital malformation syndromes predominantly involving limbs*/
,'Q873'  /*Congenital malformation syndromes involving early overgrowth*/
,'Q8740'  /*Marfan's syndrome, unspecified*/
,'Q87410'  /*Marfan's syndrome with aortic dilation*/
,'Q87418'  /*Marfan's syndrome with other cardiovascular manifestations*/
,'Q8742'  /*Marfan's syndrome with ocular manifestations*/
,'Q8743'  /*Marfan's syndrome with skeletal manifestation*/
,'Q875'  /*Other congenital malformation syndromes with other skeletal changes*/
,'Q8781'  /*Alport syndrome*/
,'Q8782'  /*Arterial tortuosity syndrome*/
,'Q8789'  /*Other specified congenital malformation syndromes, not elsewhere classified*/
,'Q8901'  /*Asplenia (congenital)*/
,'Q8909'  /*Congenital malformations of spleen*/
,'Q891'  /*Congenital malformations of adrenal gland*/
,'Q892'  /*Congenital malformations of other endocrine glands*/
,'Q893'  /*Situs inversus*/
,'Q894'  /*Conjoined twins*/
,'Q897'  /*Multiple congenital malformations, not elsewhere classified*/
,'Q898'  /*Other specified congenital malformations*/
,'Q899'  /*Congenital malformation, unspecified*/
,'Q900'  /*Trisomy 21, nonmosaicism (meiotic nondisjunction)*/
,'Q901'  /*Trisomy 21, mosaicism (mitotic nondisjunction)*/
,'Q902'  /*Trisomy 21, translocation*/
,'Q909'  /*Down syndrome, unspecified*/
,'Q910'  /*Trisomy 18, nonmosaicism (meiotic nondisjunction)*/
,'Q911'  /*Trisomy 18, mosaicism (mitotic nondisjunction)*/
,'Q912'  /*Trisomy 18, translocation*/
,'Q913'  /*Trisomy 18, unspecified*/
,'Q914'  /*Trisomy 13, nonmosaicism (meiotic nondisjunction)*/
,'Q915'  /*Trisomy 13, mosaicism (mitotic nondisjunction)*/
,'Q916'  /*Trisomy 13, translocation*/
,'Q917'  /*Trisomy 13, unspecified*/
,'Q920'  /*Whole chromosome trisomy, nonmosaicism (meiotic nondisjunction)*/
,'Q921'  /*Whole chromosome trisomy, mosaicism (mitotic nondisjunction)*/
,'Q922'  /*Partial trisomy*/
,'Q925'  /*Duplications with other complex rearrangements*/
,'Q9261'  /*Marker chromosomes in normal individual*/
,'Q9262'  /*Marker chromosomes in abnormal individual*/
,'Q927'  /*Triploidy and polyploidy*/
,'Q928'  /*Other specified trisomies and partial trisomies of autosomes*/
,'Q929'  /*Trisomy and partial trisomy of autosomes, unspecified*/
,'Q930'  /*Whole chromosome monosomy, nonmosaicism (meiotic nondisjunction)*/
,'Q931'  /*Whole chromosome monosomy, mosaicism (mitotic nondisjunction)*/
,'Q932'  /*Chromosome replaced with ring, dicentric or isochromosome*/
,'Q933'  /*Deletion of short arm of chromosome 4*/
,'Q934'  /*Deletion of short arm of chromosome 5*/
,'Q935'  /*Other deletions of part of a chromosome*/
,'Q937'  /*Deletions with other complex rearrangements*/
,'Q9381'  /*Velo-cardio-facial syndrome*/
,'Q9388'  /*Other microdeletions*/
,'Q9389'  /*Other deletions from the autosomes*/
,'Q939'  /*Deletion from autosomes, unspecified*/
,'Q950'  /*Balanced translocation and insertion in normal individual*/
,'Q951'  /*Chromosome inversion in normal individual*/
,'Q952'  /*Balanced autosomal rearrangement in abnormal individual*/
,'Q953'  /*Balanced sex/autosomal rearrangement in abnormal individual*/
,'Q955'  /*Individual with autosomal fragile site*/
,'Q958'  /*Other balanced rearrangements and structural markers*/
,'Q959'  /*Balanced rearrangement and structural marker, unspecified*/
,'Q960'  /*Karyotype 45, X*/
,'Q961'  /*Karyotype 46, X iso (Xq)*/
,'Q962'  /*Karyotype 46, X with abnormal sex chromosome, except iso (Xq)*/
,'Q963'  /*Mosaicism, 45, X/46, XX or XY*/
,'Q964'  /*Mosaicism, 45, X/other cell line(s) with abnormal sex chromosome*/
,'Q968'  /*Other variants of Turner's syndrome*/
,'Q969'  /*Turner's syndrome, unspecified*/
,'Q970'  /*Karyotype 47, XXX*/
,'Q971'  /*Female with more than three X chromosomes*/
,'Q972'  /*Mosaicism, lines with various numbers of X chromosomes*/
,'Q973'  /*Female with 46, XY karyotype*/
,'Q978'  /*Other specified sex chromosome abnormalities, female phenotype*/
,'Q979'  /*Sex chromosome abnormality, female phenotype, unspecified*/
,'Q980'  /*Klinefelter syndrome karyotype 47, XXY*/
,'Q981'  /*Klinefelter syndrome, male with more than two X chromosomes*/
,'Q983'  /*Other male with 46, XX karyotype*/
,'Q984'  /*Klinefelter syndrome, unspecified*/
,'Q985'  /*Karyotype 47, XYY*/
,'Q986'  /*Male with structurally abnormal sex chromosome*/
,'Q987'  /*Male with sex chromosome mosaicism*/
,'Q988'  /*Other specified sex chromosome abnormalities, male phenotype*/
,'Q989'  /*Sex chromosome abnormality, male phenotype, unspecified*/
,'Q990'  /*Chimera 46, XX/46, XY*/
,'Q991'  /*46, XX true hermaphrodite*/
,'Q992'  /*Fragile X chromosome*/
,'Q998'  /*Other specified chromosome abnormalities*/
,'Q999'  /*Chromosomal abnormality, unspecified*/
,'S0000XD'  /*Unspecified superficial injury of scalp, subsequent encounter*/
,'S0000XS'  /*Unspecified superficial injury of scalp, sequela*/
,'S0001XD'  /*Abrasion of scalp, subsequent encounter*/
,'S0001XS'  /*Abrasion of scalp, sequela*/
,'S0002XD'  /*Blister (nonthermal) of scalp, subsequent encounter*/
,'S0002XS'  /*Blister (nonthermal) of scalp, sequela*/
,'S0003XD'  /*Contusion of scalp, subsequent encounter*/
,'S0003XS'  /*Contusion of scalp, sequela*/
,'S0004XD'  /*External constriction of part of scalp, subsequent encounter*/
,'S0004XS'  /*External constriction of part of scalp, sequela*/
,'S0005XD'  /*Superficial foreign body of scalp, subsequent encounter*/
,'S0005XS'  /*Superficial foreign body of scalp, sequela*/
,'S0006XD'  /*Insect bite (nonvenomous) of scalp, subsequent encounter*/
,'S0006XS'  /*Insect bite (nonvenomous) of scalp, sequela*/
,'S0007XD'  /*Other superficial bite of scalp, subsequent encounter*/
,'S0007XS'  /*Other superficial bite of scalp, sequela*/
,'S0010XD'  /*Contusion of unspecified eyelid and periocular area, subsequent encounter*/
,'S0010XS'  /*Contusion of unspecified eyelid and periocular area, sequela*/
,'S0011XD'  /*Contusion of right eyelid and periocular area, subsequent encounter*/
,'S0011XS'  /*Contusion of right eyelid and periocular area, sequela*/
,'S0012XD'  /*Contusion of left eyelid and periocular area, subsequent encounter*/
,'S0012XS'  /*Contusion of left eyelid and periocular area, sequela*/
,'S00201D'  /*Unspecified superficial injury of right eyelid and periocular area, subsequent encounter*/
,'S00201S'  /*Unspecified superficial injury of right eyelid and periocular area, sequela*/
,'S00202D'  /*Unspecified superficial injury of left eyelid and periocular area, subsequent encounter*/
,'S00202S'  /*Unspecified superficial injury of left eyelid and periocular area, sequela*/
,'S00209D'  /*Unspecified superficial injury of unspecified eyelid and periocular area, subsequent encounter*/
,'S00209S'  /*Unspecified superficial injury of unspecified eyelid and periocular area, sequela*/
,'S00211D'  /*Abrasion of right eyelid and periocular area, subsequent encounter*/
,'S00211S'  /*Abrasion of right eyelid and periocular area, sequela*/
,'S00212D'  /*Abrasion of left eyelid and periocular area, subsequent encounter*/
,'S00212S'  /*Abrasion of left eyelid and periocular area, sequela*/
,'S00219D'  /*Abrasion of unspecified eyelid and periocular area, subsequent encounter*/
,'S00219S'  /*Abrasion of unspecified eyelid and periocular area, sequela*/
,'S00221D'  /*Blister (nonthermal) of right eyelid and periocular area, subsequent encounter*/
,'S00221S'  /*Blister (nonthermal) of right eyelid and periocular area, sequela*/
,'S00222D'  /*Blister (nonthermal) of left eyelid and periocular area, subsequent encounter*/
,'S00222S'  /*Blister (nonthermal) of left eyelid and periocular area, sequela*/
,'S00229D'  /*Blister (nonthermal) of unspecified eyelid and periocular area, subsequent encounter*/
,'S00229S'  /*Blister (nonthermal) of unspecified eyelid and periocular area, sequela*/
,'S00241D'  /*External constriction of right eyelid and periocular area, subsequent encounter*/
,'S00241S'  /*External constriction of right eyelid and periocular area, sequela*/
,'S00242D'  /*External constriction of left eyelid and periocular area, subsequent encounter*/
,'S00242S'  /*External constriction of left eyelid and periocular area, sequela*/
,'S00249D'  /*External constriction of unspecified eyelid and periocular area, subsequent encounter*/
,'S00249S'  /*External constriction of unspecified eyelid and periocular area, sequela*/
,'S00251D'  /*Superficial foreign body of right eyelid and periocular area, subsequent encounter*/
,'S00251S'  /*Superficial foreign body of right eyelid and periocular area, sequela*/
,'S00252D'  /*Superficial foreign body of left eyelid and periocular area, subsequent encounter*/
,'S00252S'  /*Superficial foreign body of left eyelid and periocular area, sequela*/
,'S00259D'  /*Superficial foreign body of unspecified eyelid and periocular area, subsequent encounter*/
,'S00259S'  /*Superficial foreign body of unspecified eyelid and periocular area, sequela*/
,'S00261D'  /*Insect bite (nonvenomous) of right eyelid and periocular area, subsequent encounter*/
,'S00261S'  /*Insect bite (nonvenomous) of right eyelid and periocular area, sequela*/
,'S00262D'  /*Insect bite (nonvenomous) of left eyelid and periocular area, subsequent encounter*/
,'S00262S'  /*Insect bite (nonvenomous) of left eyelid and periocular area, sequela*/
,'S00269D'  /*Insect bite (nonvenomous) of unspecified eyelid and periocular area, subsequent encounter*/
,'S00269S'  /*Insect bite (nonvenomous) of unspecified eyelid and periocular area, sequela*/
,'S00271D'  /*Other superficial bite of right eyelid and periocular area, subsequent encounter*/
,'S00271S'  /*Other superficial bite of right eyelid and periocular area, sequela*/
,'S00272D'  /*Other superficial bite of left eyelid and periocular area, subsequent encounter*/
,'S00272S'  /*Other superficial bite of left eyelid and periocular area, sequela*/
,'S00279D'  /*Other superficial bite of unspecified eyelid and periocular area, subsequent encounter*/
,'S00279S'  /*Other superficial bite of unspecified eyelid and periocular area, sequela*/
,'S0030XD'  /*Unspecified superficial injury of nose, subsequent encounter*/
,'S0030XS'  /*Unspecified superficial injury of nose, sequela*/
,'S0031XD'  /*Abrasion of nose, subsequent encounter*/
,'S0031XS'  /*Abrasion of nose, sequela*/
,'S0032XD'  /*Blister (nonthermal) of nose, subsequent encounter*/
,'S0032XS'  /*Blister (nonthermal) of nose, sequela*/
,'S0033XD'  /*Contusion of nose, subsequent encounter*/
,'S0033XS'  /*Contusion of nose, sequela*/
,'S0034XD'  /*External constriction of nose, subsequent encounter*/
,'S0034XS'  /*External constriction of nose, sequela*/
,'S0035XD'  /*Superficial foreign body of nose, subsequent encounter*/
,'S0035XS'  /*Superficial foreign body of nose, sequela*/
,'S0036XD'  /*Insect bite (nonvenomous) of nose, subsequent encounter*/
,'S0036XS'  /*Insect bite (nonvenomous) of nose, sequela*/
,'S0037XD'  /*Other superficial bite of nose, subsequent encounter*/
,'S0037XS'  /*Other superficial bite of nose, sequela*/
,'S00401D'  /*Unspecified superficial injury of right ear, subsequent encounter*/
,'S00401S'  /*Unspecified superficial injury of right ear, sequela*/
,'S00402D'  /*Unspecified superficial injury of left ear, subsequent encounter*/
,'S00402S'  /*Unspecified superficial injury of left ear, sequela*/
,'S00409D'  /*Unspecified superficial injury of unspecified ear, subsequent encounter*/
,'S00409S'  /*Unspecified superficial injury of unspecified ear, sequela*/
,'S00411D'  /*Abrasion of right ear, subsequent encounter*/
,'S00411S'  /*Abrasion of right ear, sequela*/
,'S00412D'  /*Abrasion of left ear, subsequent encounter*/
,'S00412S'  /*Abrasion of left ear, sequela*/
,'S00419D'  /*Abrasion of unspecified ear, subsequent encounter*/
,'S00419S'  /*Abrasion of unspecified ear, sequela*/
,'S00421D'  /*Blister (nonthermal) of right ear, subsequent encounter*/
,'S00421S'  /*Blister (nonthermal) of right ear, sequela*/
,'S00422D'  /*Blister (nonthermal) of left ear, subsequent encounter*/
,'S00422S'  /*Blister (nonthermal) of left ear, sequela*/
,'S00429D'  /*Blister (nonthermal) of unspecified ear, subsequent encounter*/
,'S00429S'  /*Blister (nonthermal) of unspecified ear, sequela*/
,'S00431D'  /*Contusion of right ear, subsequent encounter*/
,'S00431S'  /*Contusion of right ear, sequela*/
,'S00432D'  /*Contusion of left ear, subsequent encounter*/
,'S00432S'  /*Contusion of left ear, sequela*/
,'S00439D'  /*Contusion of unspecified ear, subsequent encounter*/
,'S00439S'  /*Contusion of unspecified ear, sequela*/
,'S00441D'  /*External constriction of right ear, subsequent encounter*/
,'S00441S'  /*External constriction of right ear, sequela*/
,'S00442D'  /*External constriction of left ear, subsequent encounter*/
,'S00442S'  /*External constriction of left ear, sequela*/
,'S00449D'  /*External constriction of unspecified ear, subsequent encounter*/
,'S00449S'  /*External constriction of unspecified ear, sequela*/
,'S00451D'  /*Superficial foreign body of right ear, subsequent encounter*/
,'S00451S'  /*Superficial foreign body of right ear, sequela*/
,'S00452D'  /*Superficial foreign body of left ear, subsequent encounter*/
,'S00452S'  /*Superficial foreign body of left ear, sequela*/
,'S00459D'  /*Superficial foreign body of unspecified ear, subsequent encounter*/
,'S00459S'  /*Superficial foreign body of unspecified ear, sequela*/
,'S00461D'  /*Insect bite (nonvenomous) of right ear, subsequent encounter*/
,'S00461S'  /*Insect bite (nonvenomous) of right ear, sequela*/
,'S00462D'  /*Insect bite (nonvenomous) of left ear, subsequent encounter*/
,'S00462S'  /*Insect bite (nonvenomous) of left ear, sequela*/
,'S00469D'  /*Insect bite (nonvenomous) of unspecified ear, subsequent encounter*/
,'S00469S'  /*Insect bite (nonvenomous) of unspecified ear, sequela*/
,'S00471D'  /*Other superficial bite of right ear, subsequent encounter*/
,'S00471S'  /*Other superficial bite of right ear, sequela*/
,'S00472D'  /*Other superficial bite of left ear, subsequent encounter*/
,'S00472S'  /*Other superficial bite of left ear, sequela*/
,'S00479D'  /*Other superficial bite of unspecified ear, subsequent encounter*/
,'S00479S'  /*Other superficial bite of unspecified ear, sequela*/
,'S00501D'  /*Unspecified superficial injury of lip, subsequent encounter*/
,'S00501S'  /*Unspecified superficial injury of lip, sequela*/
,'S00502D'  /*Unspecified superficial injury of oral cavity, subsequent encounter*/
,'S00502S'  /*Unspecified superficial injury of oral cavity, sequela*/
,'S00511D'  /*Abrasion of lip, subsequent encounter*/
,'S00511S'  /*Abrasion of lip, sequela*/
,'S00512D'  /*Abrasion of oral cavity, subsequent encounter*/
,'S00512S'  /*Abrasion of oral cavity, sequela*/
,'S00521D'  /*Blister (nonthermal) of lip, subsequent encounter*/
,'S00521S'  /*Blister (nonthermal) of lip, sequela*/
,'S00522D'  /*Blister (nonthermal) of oral cavity, subsequent encounter*/
,'S00522S'  /*Blister (nonthermal) of oral cavity, sequela*/
,'S00531D'  /*Contusion of lip, subsequent encounter*/
,'S00531S'  /*Contusion of lip, sequela*/
,'S00532D'  /*Contusion of oral cavity, subsequent encounter*/
,'S00532S'  /*Contusion of oral cavity, sequela*/
,'S00541D'  /*External constriction of lip, subsequent encounter*/
,'S00541S'  /*External constriction of lip, sequela*/
,'S00542D'  /*External constriction of oral cavity, subsequent encounter*/
,'S00542S'  /*External constriction of oral cavity, sequela*/
,'S00551D'  /*Superficial foreign body of lip, subsequent encounter*/
,'S00551S'  /*Superficial foreign body of lip, sequela*/
,'S00552D'  /*Superficial foreign body of oral cavity, subsequent encounter*/
,'S00552S'  /*Superficial foreign body of oral cavity, sequela*/
,'S00561D'  /*Insect bite (nonvenomous) of lip, subsequent encounter*/
,'S00561S'  /*Insect bite (nonvenomous) of lip, sequela*/
,'S00562D'  /*Insect bite (nonvenomous) of oral cavity, subsequent encounter*/
,'S00562S'  /*Insect bite (nonvenomous) of oral cavity, sequela*/
,'S00571D'  /*Other superficial bite of lip, subsequent encounter*/
,'S00571S'  /*Other superficial bite of lip, sequela*/
,'S00572D'  /*Other superficial bite of oral cavity, subsequent encounter*/
,'S00572S'  /*Other superficial bite of oral cavity, sequela*/
,'S0080XD'  /*Unspecified superficial injury of other part of head, subsequent encounter*/
,'S0080XS'  /*Unspecified superficial injury of other part of head, sequela*/
,'S0081XD'  /*Abrasion of other part of head, subsequent encounter*/
,'S0081XS'  /*Abrasion of other part of head, sequela*/
,'S0082XD'  /*Blister (nonthermal) of other part of head, subsequent encounter*/
,'S0082XS'  /*Blister (nonthermal) of other part of head, sequela*/
,'S0083XD'  /*Contusion of other part of head, subsequent encounter*/
,'S0083XS'  /*Contusion of other part of head, sequela*/
,'S0084XD'  /*External constriction of other part of head, subsequent encounter*/
,'S0084XS'  /*External constriction of other part of head, sequela*/
,'S0085XD'  /*Superficial foreign body of other part of head, subsequent encounter*/
,'S0085XS'  /*Superficial foreign body of other part of head, sequela*/
,'S0086XD'  /*Insect bite (nonvenomous) of other part of head, subsequent encounter*/
,'S0086XS'  /*Insect bite (nonvenomous) of other part of head, sequela*/
,'S0087XD'  /*Other superficial bite of other part of head, subsequent encounter*/
,'S0087XS'  /*Other superficial bite of other part of head, sequela*/
,'S0090XD'  /*Unspecified superficial injury of unspecified part of head, subsequent encounter*/
,'S0090XS'  /*Unspecified superficial injury of unspecified part of head, sequela*/
,'S0091XD'  /*Abrasion of unspecified part of head, subsequent encounter*/
,'S0091XS'  /*Abrasion of unspecified part of head, sequela*/
,'S0092XD'  /*Blister (nonthermal) of unspecified part of head, subsequent encounter*/
,'S0092XS'  /*Blister (nonthermal) of unspecified part of head, sequela*/
,'S0093XD'  /*Contusion of unspecified part of head, subsequent encounter*/
,'S0093XS'  /*Contusion of unspecified part of head, sequela*/
,'S0094XD'  /*External constriction of unspecified part of head, subsequent encounter*/
,'S0094XS'  /*External constriction of unspecified part of head, sequela*/
,'S0095XD'  /*Superficial foreign body of unspecified part of head, subsequent encounter*/
,'S0095XS'  /*Superficial foreign body of unspecified part of head, sequela*/
,'S0096XD'  /*Insect bite (nonvenomous) of unspecified part of head, subsequent encounter*/
,'S0096XS'  /*Insect bite (nonvenomous) of unspecified part of head, sequela*/
,'S0097XD'  /*Other superficial bite of unspecified part of head, subsequent encounter*/
,'S0097XS'  /*Other superficial bite of unspecified part of head, sequela*/
,'S0100XD'  /*Unspecified open wound of scalp, subsequent encounter*/
,'S0100XS'  /*Unspecified open wound of scalp, sequela*/
,'S0101XD'  /*Laceration without foreign body of scalp, subsequent encounter*/
,'S0101XS'  /*Laceration without foreign body of scalp, sequela*/
,'S0102XD'  /*Laceration with foreign body of scalp, subsequent encounter*/
,'S0102XS'  /*Laceration with foreign body of scalp, sequela*/
,'S0103XD'  /*Puncture wound without foreign body of scalp, subsequent encounter*/
,'S0103XS'  /*Puncture wound without foreign body of scalp, sequela*/
,'S0104XD'  /*Puncture wound with foreign body of scalp, subsequent encounter*/
,'S0104XS'  /*Puncture wound with foreign body of scalp, sequela*/
,'S0105XD'  /*Open bite of scalp, subsequent encounter*/
,'S0105XS'  /*Open bite of scalp, sequela*/
,'S01101D'  /*Unspecified open wound of right eyelid and periocular area, subsequent encounter*/
,'S01101S'  /*Unspecified open wound of right eyelid and periocular area, sequela*/
,'S01102D'  /*Unspecified open wound of left eyelid and periocular area, subsequent encounter*/
,'S01102S'  /*Unspecified open wound of left eyelid and periocular area, sequela*/
,'S01109D'  /*Unspecified open wound of unspecified eyelid and periocular area, subsequent encounter*/
,'S01109S'  /*Unspecified open wound of unspecified eyelid and periocular area, sequela*/
,'S01111D'  /*Laceration without foreign body of right eyelid and periocular area, subsequent encounter*/
,'S01111S'  /*Laceration without foreign body of right eyelid and periocular area, sequela*/
,'S01112D'  /*Laceration without foreign body of left eyelid and periocular area, subsequent encounter*/
,'S01112S'  /*Laceration without foreign body of left eyelid and periocular area, sequela*/
,'S01119D'  /*Laceration without foreign body of unspecified eyelid and periocular area, subsequent encounter*/
,'S01119S'  /*Laceration without foreign body of unspecified eyelid and periocular area, sequela*/
,'S01121D'  /*Laceration with foreign body of right eyelid and periocular area, subsequent encounter*/
,'S01121S'  /*Laceration with foreign body of right eyelid and periocular area, sequela*/
,'S01122D'  /*Laceration with foreign body of left eyelid and periocular area, subsequent encounter*/
,'S01122S'  /*Laceration with foreign body of left eyelid and periocular area, sequela*/
,'S01129D'  /*Laceration with foreign body of unspecified eyelid and periocular area, subsequent encounter*/
,'S01129S'  /*Laceration with foreign body of unspecified eyelid and periocular area, sequela*/
,'S01131D'  /*Puncture wound without foreign body of right eyelid and periocular area, subsequent encounter*/
,'S01131S'  /*Puncture wound without foreign body of right eyelid and periocular area, sequela*/
,'S01132D'  /*Puncture wound without foreign body of left eyelid and periocular area, subsequent encounter*/
,'S01132S'  /*Puncture wound without foreign body of left eyelid and periocular area, sequela*/
,'S01139D'  /*Puncture wound without foreign body of unspecified eyelid and periocular area, subsequent encounter*/
,'S01139S'  /*Puncture wound without foreign body of unspecified eyelid and periocular area, sequela*/
,'S01141D'  /*Puncture wound with foreign body of right eyelid and periocular area, subsequent encounter*/
,'S01141S'  /*Puncture wound with foreign body of right eyelid and periocular area, sequela*/
,'S01142D'  /*Puncture wound with foreign body of left eyelid and periocular area, subsequent encounter*/
,'S01142S'  /*Puncture wound with foreign body of left eyelid and periocular area, sequela*/
,'S01149D'  /*Puncture wound with foreign body of unspecified eyelid and periocular area, subsequent encounter*/
,'S01149S'  /*Puncture wound with foreign body of unspecified eyelid and periocular area, sequela*/
,'S01151D'  /*Open bite of right eyelid and periocular area, subsequent encounter*/
,'S01151S'  /*Open bite of right eyelid and periocular area, sequela*/
,'S01152D'  /*Open bite of left eyelid and periocular area, subsequent encounter*/
,'S01152S'  /*Open bite of left eyelid and periocular area, sequela*/
,'S01159D'  /*Open bite of unspecified eyelid and periocular area, subsequent encounter*/
,'S01159S'  /*Open bite of unspecified eyelid and periocular area, sequela*/
,'S0120XD'  /*Unspecified open wound of nose, subsequent encounter*/
,'S0120XS'  /*Unspecified open wound of nose, sequela*/
,'S0121XD'  /*Laceration without foreign body of nose, subsequent encounter*/
,'S0121XS'  /*Laceration without foreign body of nose, sequela*/
,'S0122XD'  /*Laceration with foreign body of nose, subsequent encounter*/
,'S0122XS'  /*Laceration with foreign body of nose, sequela*/
,'S0123XD'  /*Puncture wound without foreign body of nose, subsequent encounter*/
,'S0123XS'  /*Puncture wound without foreign body of nose, sequela*/
,'S0124XD'  /*Puncture wound with foreign body of nose, subsequent encounter*/
,'S0124XS'  /*Puncture wound with foreign body of nose, sequela*/
,'S0125XD'  /*Open bite of nose, subsequent encounter*/
,'S0125XS'  /*Open bite of nose, sequela*/
,'S01301D'  /*Unspecified open wound of right ear, subsequent encounter*/
,'S01301S'  /*Unspecified open wound of right ear, sequela*/
,'S01302D'  /*Unspecified open wound of left ear, subsequent encounter*/
,'S01302S'  /*Unspecified open wound of left ear, sequela*/
,'S01309D'  /*Unspecified open wound of unspecified ear, subsequent encounter*/
,'S01309S'  /*Unspecified open wound of unspecified ear, sequela*/
,'S01311D'  /*Laceration without foreign body of right ear, subsequent encounter*/
,'S01311S'  /*Laceration without foreign body of right ear, sequela*/
,'S01312D'  /*Laceration without foreign body of left ear, subsequent encounter*/
,'S01312S'  /*Laceration without foreign body of left ear, sequela*/
,'S01319D'  /*Laceration without foreign body of unspecified ear, subsequent encounter*/
,'S01319S'  /*Laceration without foreign body of unspecified ear, sequela*/
,'S01321D'  /*Laceration with foreign body of right ear, subsequent encounter*/
,'S01321S'  /*Laceration with foreign body of right ear, sequela*/
,'S01322D'  /*Laceration with foreign body of left ear, subsequent encounter*/
,'S01322S'  /*Laceration with foreign body of left ear, sequela*/
,'S01329D'  /*Laceration with foreign body of unspecified ear, subsequent encounter*/
,'S01329S'  /*Laceration with foreign body of unspecified ear, sequela*/
,'S01331D'  /*Puncture wound without foreign body of right ear, subsequent encounter*/
,'S01331S'  /*Puncture wound without foreign body of right ear, sequela*/
,'S01332D'  /*Puncture wound without foreign body of left ear, subsequent encounter*/
,'S01332S'  /*Puncture wound without foreign body of left ear, sequela*/
,'S01339D'  /*Puncture wound without foreign body of unspecified ear, subsequent encounter*/
,'S01339S'  /*Puncture wound without foreign body of unspecified ear, sequela*/
,'S01341D'  /*Puncture wound with foreign body of right ear, subsequent encounter*/
,'S01341S'  /*Puncture wound with foreign body of right ear, sequela*/
,'S01342D'  /*Puncture wound with foreign body of left ear, subsequent encounter*/
,'S01342S'  /*Puncture wound with foreign body of left ear, sequela*/
,'S01349D'  /*Puncture wound with foreign body of unspecified ear, subsequent encounter*/
,'S01349S'  /*Puncture wound with foreign body of unspecified ear, sequela*/
,'S01351D'  /*Open bite of right ear, subsequent encounter*/
,'S01351S'  /*Open bite of right ear, sequela*/
,'S01352D'  /*Open bite of left ear, subsequent encounter*/
,'S01352S'  /*Open bite of left ear, sequela*/
,'S01359D'  /*Open bite of unspecified ear, subsequent encounter*/
,'S01359S'  /*Open bite of unspecified ear, sequela*/
,'S01401D'  /*Unspecified open wound of right cheek and temporomandibular area, subsequent encounter*/
,'S01401S'  /*Unspecified open wound of right cheek and temporomandibular area, sequela*/
,'S01402D'  /*Unspecified open wound of left cheek and temporomandibular area, subsequent encounter*/
,'S01402S'  /*Unspecified open wound of left cheek and temporomandibular area, sequela*/
,'S01409D'  /*Unspecified open wound of unspecified cheek and temporomandibular area, subsequent encounter*/
,'S01409S'  /*Unspecified open wound of unspecified cheek and temporomandibular area, sequela*/
,'S01411D'  /*Laceration without foreign body of right cheek and temporomandibular area, subsequent encounter*/
,'S01411S'  /*Laceration without foreign body of right cheek and temporomandibular area, sequela*/
,'S01412D'  /*Laceration without foreign body of left cheek and temporomandibular area, subsequent encounter*/
,'S01412S'  /*Laceration without foreign body of left cheek and temporomandibular area, sequela*/
,'S01419D'  /*Laceration without foreign body of unspecified cheek and temporomandibular area, subsequent encounter*/
,'S01419S'  /*Laceration without foreign body of unspecified cheek and temporomandibular area, sequela*/
,'S01421D'  /*Laceration with foreign body of right cheek and temporomandibular area, subsequent encounter*/
,'S01421S'  /*Laceration with foreign body of right cheek and temporomandibular area, sequela*/
,'S01422D'  /*Laceration with foreign body of left cheek and temporomandibular area, subsequent encounter*/
,'S01422S'  /*Laceration with foreign body of left cheek and temporomandibular area, sequela*/
,'S01429D'  /*Laceration with foreign body of unspecified cheek and temporomandibular area, subsequent encounter*/
,'S01429S'  /*Laceration with foreign body of unspecified cheek and temporomandibular area, sequela*/
,'S01431D'  /*Puncture wound without foreign body of right cheek and temporomandibular area, subsequent encounter*/
,'S01431S'  /*Puncture wound without foreign body of right cheek and temporomandibular area, sequela*/
,'S01432D'  /*Puncture wound without foreign body of left cheek and temporomandibular area, subsequent encounter*/
,'S01432S'  /*Puncture wound without foreign body of left cheek and temporomandibular area, sequela*/
,'S01439D'  /*Puncture wound without foreign body of unspecified cheek and temporomandibular area, subsequent encounter*/
,'S01439S'  /*Puncture wound without foreign body of unspecified cheek and temporomandibular area, sequela*/
,'S01441D'  /*Puncture wound with foreign body of right cheek and temporomandibular area, subsequent encounter*/
,'S01441S'  /*Puncture wound with foreign body of right cheek and temporomandibular area, sequela*/
,'S01442D'  /*Puncture wound with foreign body of left cheek and temporomandibular area, subsequent encounter*/
,'S01442S'  /*Puncture wound with foreign body of left cheek and temporomandibular area, sequela*/
,'S01449D'  /*Puncture wound with foreign body of unspecified cheek and temporomandibular area, subsequent encounter*/
,'S01449S'  /*Puncture wound with foreign body of unspecified cheek and temporomandibular area, sequela*/
,'S01451D'  /*Open bite of right cheek and temporomandibular area, subsequent encounter*/
,'S01451S'  /*Open bite of right cheek and temporomandibular area, sequela*/
,'S01452D'  /*Open bite of left cheek and temporomandibular area, subsequent encounter*/
,'S01452S'  /*Open bite of left cheek and temporomandibular area, sequela*/
,'S01459D'  /*Open bite of unspecified cheek and temporomandibular area, subsequent encounter*/
,'S01459S'  /*Open bite of unspecified cheek and temporomandibular area, sequela*/
,'S01501D'  /*Unspecified open wound of lip, subsequent encounter*/
,'S01501S'  /*Unspecified open wound of lip, sequela*/
,'S01502D'  /*Unspecified open wound of oral cavity, subsequent encounter*/
,'S01502S'  /*Unspecified open wound of oral cavity, sequela*/
,'S01511D'  /*Laceration without foreign body of lip, subsequent encounter*/
,'S01511S'  /*Laceration without foreign body of lip, sequela*/
,'S01512D'  /*Laceration without foreign body of oral cavity, subsequent encounter*/
,'S01512S'  /*Laceration without foreign body of oral cavity, sequela*/
,'S01521D'  /*Laceration with foreign body of lip, subsequent encounter*/
,'S01521S'  /*Laceration with foreign body of lip, sequela*/
,'S01522D'  /*Laceration with foreign body of oral cavity, subsequent encounter*/
,'S01522S'  /*Laceration with foreign body of oral cavity, sequela*/
,'S01531D'  /*Puncture wound without foreign body of lip, subsequent encounter*/
,'S01531S'  /*Puncture wound without foreign body of lip, sequela*/
,'S01532D'  /*Puncture wound without foreign body of oral cavity, subsequent encounter*/
,'S01532S'  /*Puncture wound without foreign body of oral cavity, sequela*/
,'S01541D'  /*Puncture wound with foreign body of lip, subsequent encounter*/
,'S01541S'  /*Puncture wound with foreign body of lip, sequela*/
,'S01542D'  /*Puncture wound with foreign body of oral cavity, subsequent encounter*/
,'S01542S'  /*Puncture wound with foreign body of oral cavity, sequela*/
,'S01551D'  /*Open bite of lip, subsequent encounter*/
,'S01551S'  /*Open bite of lip, sequela*/
,'S01552D'  /*Open bite of oral cavity, subsequent encounter*/
,'S01552S'  /*Open bite of oral cavity, sequela*/
,'S0180XD'  /*Unspecified open wound of other part of head, subsequent encounter*/
,'S0180XS'  /*Unspecified open wound of other part of head, sequela*/
,'S0181XD'  /*Laceration without foreign body of other part of head, subsequent encounter*/
,'S0181XS'  /*Laceration without foreign body of other part of head, sequela*/
,'S0182XD'  /*Laceration with foreign body of other part of head, subsequent encounter*/
,'S0182XS'  /*Laceration with foreign body of other part of head, sequela*/
,'S0183XD'  /*Puncture wound without foreign body of other part of head, subsequent encounter*/
,'S0183XS'  /*Puncture wound without foreign body of other part of head, sequela*/
,'S0184XD'  /*Puncture wound with foreign body of other part of head, subsequent encounter*/
,'S0184XS'  /*Puncture wound with foreign body of other part of head, sequela*/
,'S0185XD'  /*Open bite of other part of head, subsequent encounter*/
,'S0185XS'  /*Open bite of other part of head, sequela*/
,'S0190XD'  /*Unspecified open wound of unspecified part of head, subsequent encounter*/
,'S0190XS'  /*Unspecified open wound of unspecified part of head, sequela*/
,'S0191XD'  /*Laceration without foreign body of unspecified part of head, subsequent encounter*/
,'S0191XS'  /*Laceration without foreign body of unspecified part of head, sequela*/
,'S0192XD'  /*Laceration with foreign body of unspecified part of head, subsequent encounter*/
,'S0192XS'  /*Laceration with foreign body of unspecified part of head, sequela*/
,'S0193XD'  /*Puncture wound without foreign body of unspecified part of head, subsequent encounter*/
,'S0193XS'  /*Puncture wound without foreign body of unspecified part of head, sequela*/
,'S0194XD'  /*Puncture wound with foreign body of unspecified part of head, subsequent encounter*/
,'S0194XS'  /*Puncture wound with foreign body of unspecified part of head, sequela*/
,'S0195XD'  /*Open bite of unspecified part of head, subsequent encounter*/
,'S0195XS'  /*Open bite of unspecified part of head, sequela*/
,'S020XXD'  /*Fracture of vault of skull, subsequent encounter for fracture with routine healing*/
,'S020XXG'  /*Fracture of vault of skull, subsequent encounter for fracture with delayed healing*/
,'S020XXK'  /*Fracture of vault of skull, subsequent encounter for fracture with nonunion*/
,'S020XXS'  /*Fracture of vault of skull, sequela*/
,'S02101D'  /*Fracture of base of skull, right side, subsequent encounter for fracture with routine healing*/
,'S02101G'  /*Fracture of base of skull, right side, subsequent encounter for fracture with delayed healing*/
,'S02101K'  /*Fracture of base of skull, right side, subsequent encounter for fracture with nonunion*/
,'S02101S'  /*Fracture of base of skull, right side, sequela*/
,'S02102D'  /*Fracture of base of skull, left side, subsequent encounter for fracture with routine healing*/
,'S02102G'  /*Fracture of base of skull, left side, subsequent encounter for fracture with delayed healing*/
,'S02102K'  /*Fracture of base of skull, left side, subsequent encounter for fracture with nonunion*/
,'S02102S'  /*Fracture of base of skull, left side, sequela*/
,'S02109D'  /*Fracture of base of skull, unspecified side, subsequent encounter for fracture with routine healing*/
,'S02109G'  /*Fracture of base of skull, unspecified side, subsequent encounter for fracture with delayed healing*/
,'S02109K'  /*Fracture of base of skull, unspecified side, subsequent encounter for fracture with nonunion*/
,'S02109S'  /*Fracture of base of skull, unspecified side, sequela*/
,'S02110D'  /*Type I occipital condyle fracture, unspecified side, subsequent encounter for fracture with routine healing*/
,'S02110G'  /*Type I occipital condyle fracture, unspecified side, subsequent encounter for fracture with delayed healing*/
,'S02110K'  /*Type I occipital condyle fracture, unspecified side, subsequent encounter for fracture with nonunion*/
,'S02110S'  /*Type I occipital condyle fracture, unspecified side, sequela*/
,'S02111D'  /*Type II occipital condyle fracture, unspecified side, subsequent encounter for fracture with routine healing*/
,'S02111G'  /*Type II occipital condyle fracture, unspecified side, subsequent encounter for fracture with delayed healing*/
,'S02111K'  /*Type II occipital condyle fracture, unspecified side, subsequent encounter for fracture with nonunion*/
,'S02111S'  /*Type II occipital condyle fracture, unspecified side, sequela*/
,'S02112D'  /*Type III occipital condyle fracture, unspecified side, subsequent encounter for fracture with routine healing*/
,'S02112G'  /*Type III occipital condyle fracture, unspecified side, subsequent encounter for fracture with delayed healing*/
,'S02112K'  /*Type III occipital condyle fracture, unspecified side, subsequent encounter for fracture with nonunion*/
,'S02112S'  /*Type III occipital condyle fracture, unspecified side, sequela*/
,'S02113D'  /*Unspecified occipital condyle fracture, subsequent encounter for fracture with routine healing*/
,'S02113G'  /*Unspecified occipital condyle fracture, subsequent encounter for fracture with delayed healing*/
,'S02113K'  /*Unspecified occipital condyle fracture, subsequent encounter for fracture with nonunion*/
,'S02113S'  /*Unspecified occipital condyle fracture, sequela*/
,'S02118D'  /*Other fracture or occiput, unspecified side, subsequent encounter for fracture with routine healing*/
,'S02118G'  /*Other fracture or occiput, unspecified side, subsequent encounter for fracture with delayed healing*/
,'S02118K'  /*Other fracture or occiput, unspecified side, subsequent encounter for fracture with nonunion*/
,'S02118S'  /*Other fracture or occiput, unspecified side, sequela*/
,'S02119D'  /*Unspecified fracture of occiput, subsequent encounter for fracture with routine healing*/
,'S02119G'  /*Unspecified fracture of occiput, subsequent encounter for fracture with delayed healing*/
,'S02119K'  /*Unspecified fracture of occiput, subsequent encounter for fracture with nonunion*/
,'S02119S'  /*Unspecified fracture of occiput, sequela*/
,'S0211AG'  /*Type I occipital condyle fracture, right side, subsequent encounter for fracture with delayed healing*/
,'S0211AK'  /*Type I occipital condyle fracture, right side, subsequent encounter for fracture with nonunion*/
,'S0211AS'  /*Type I occipital condyle fracture, right side, sequela*/
,'S0211BD'  /*Type I occipital condyle fracture, left side, subsequent encounter for fracture with routine healing*/
,'S0211BG'  /*Type I occipital condyle fracture, left side, subsequent encounter for fracture with delayed healing*/
,'S0211BK'  /*Type I occipital condyle fracture, left side, subsequent encounter for fracture with nonunion*/
,'S0211BS'  /*Type I occipital condyle fracture, left side, sequela*/
,'S0211CG'  /*Type II occipital condyle fracture, right side, subsequent encounter for fracture with delayed healing*/
,'S0211CK'  /*Type II occipital condyle fracture, right side, subsequent encounter for fracture with nonunion*/
,'S0211CS'  /*Type II occipital condyle fracture, right side, sequela*/
,'S0211DD'  /*Type II occipital condyle fracture, left side, subsequent encounter for fracture with routine healing*/
,'S0211DG'  /*Type II occipital condyle fracture, left side, subsequent encounter for fracture with delayed healing*/
,'S0211DK'  /*Type II occipital condyle fracture, left side, subsequent encounter for fracture with nonunion*/
,'S0211DS'  /*Type II occipital condyle fracture, left side, sequela*/
,'S0211ED'  /*Type III occipital condyle fracture, right side, subsequent encounter for fracture with routine healing*/
,'S0211EG'  /*Type III occipital condyle fracture, right side, subsequent encounter for fracture with delayed healing*/
,'S0211EK'  /*Type III occipital condyle fracture, right side, subsequent encounter for fracture with nonunion*/
,'S0211ES'  /*Type III occipital condyle fracture, right side, sequela*/
,'S0211FD'  /*Type III occipital condyle fracture, left side, subsequent encounter for fracture with routine healing*/
,'S0211FG'  /*Type III occipital condyle fracture, left side, subsequent encounter for fracture with delayed healing*/
,'S0211FK'  /*Type III occipital condyle fracture, left side, subsequent encounter for fracture with nonunion*/
,'S0211FS'  /*Type III occipital condyle fracture, left side, sequela*/
,'S0211GD'  /*Other fracture or occiput, right side, subsequent encounter for fracture with routine healing*/
,'S0211GG'  /*Other fracture or occiput, right side, subsequent encounter for fracture with delayed healing*/
,'S0211GK'  /*Other fracture or occiput, right side, subsequent encounter for fracture with nonunion*/
,'S0211GS'  /*Other fracture or occiput, right side, sequela*/
,'S0211HD'  /*Other fracture or occiput, left side, subsequent encounter for fracture with routine healing*/
,'S0211HG'  /*Other fracture or occiput, left side, subsequent encounter for fracture with delayed healing*/
,'S0211HK'  /*Other fracture or occiput, left side, subsequent encounter for fracture with nonunion*/
,'S0211HS'  /*Other fracture or occiput, left side, sequela*/
,'S0219XD'  /*Other fracture of base of skull, subsequent encounter for fracture with routine healing*/
,'S0219XG'  /*Other fracture of base of skull, subsequent encounter for fracture with delayed healing*/
,'S0219XK'  /*Other fracture of base of skull, subsequent encounter for fracture with nonunion*/
,'S0219XS'  /*Other fracture of base of skull, sequela*/
,'S022XXD'  /*Fracture of nasal bones, subsequent encounter for fracture with routine healing*/
,'S022XXG'  /*Fracture of nasal bones, subsequent encounter for fracture with delayed healing*/
,'S022XXK'  /*Fracture of nasal bones, subsequent encounter for fracture with nonunion*/
,'S022XXS'  /*Fracture of nasal bones, sequela*/
,'S0230XD'  /*Fracture of orbital floor, unspecified side, subsequent encounter for fracture with routine healing*/
,'S0230XG'  /*Fracture of orbital floor, unspecified side, subsequent encounter for fracture with delayed healing*/
,'S0230XK'  /*Fracture of orbital floor, unspecified side, subsequent encounter for fracture with nonunion*/
,'S0230XS'  /*Fracture of orbital floor, unspecified side, sequela*/
,'S0231XD'  /*Fracture of orbital floor, right side, subsequent encounter for fracture with routine healing*/
,'S0231XG'  /*Fracture of orbital floor, right side, subsequent encounter for fracture with delayed healing*/
,'S0231XK'  /*Fracture of orbital floor, right side, subsequent encounter for fracture with nonunion*/
,'S0231XS'  /*Fracture of orbital floor, right side, sequela*/
,'S0232XD'  /*Fracture of orbital floor, left side, subsequent encounter for fracture with routine healing*/
,'S0232XG'  /*Fracture of orbital floor, left side, subsequent encounter for fracture with delayed healing*/
,'S0232XK'  /*Fracture of orbital floor, left side, subsequent encounter for fracture with nonunion*/
,'S0232XS'  /*Fracture of orbital floor, left side, sequela*/
,'S02400D'  /*Malar fracture, unspecified side, subsequent encounter for fracture with routine healing*/
,'S02400G'  /*Malar fracture, unspecified side, subsequent encounter for fracture with delayed healing*/
,'S02400K'  /*Malar fracture, unspecified side, subsequent encounter for fracture with nonunion*/
,'S02400S'  /*Malar fracture, unspecified side, sequela*/
,'S02401D'  /*Maxillary fracture, unspecified side, subsequent encounter for fracture with routine healing*/
,'S02401G'  /*Maxillary fracture, unspecified side, subsequent encounter for fracture with delayed healing*/
,'S02401K'  /*Maxillary fracture, unspecified side, subsequent encounter for fracture with nonunion*/
,'S02401S'  /*Maxillary fracture, unspecified side, sequela*/
,'S02402D'  /*Zygomatic fracture, unspecified side, subsequent encounter for fracture with routine healing*/
,'S02402G'  /*Zygomatic fracture, unspecified side, subsequent encounter for fracture with delayed healing*/
,'S02402K'  /*Zygomatic fracture, unspecified side, subsequent encounter for fracture with nonunion*/
,'S02402S'  /*Zygomatic fracture, unspecified side, sequela*/
,'S0240AD'  /*Malar fracture, right side, subsequent encounter for fracture with routine healing*/
,'S0240AG'  /*Malar fracture, right side, subsequent encounter for fracture with delayed healing*/
,'S0240AK'  /*Malar fracture, right side, subsequent encounter for fracture with nonunion*/
,'S0240AS'  /*Malar fracture, right side, sequela*/
,'S0240BD'  /*Malar fracture, left side, subsequent encounter for fracture with routine healing*/
,'S0240BG'  /*Malar fracture, left side, subsequent encounter for fracture with delayed healing*/
,'S0240BK'  /*Malar fracture, left side, subsequent encounter for fracture with nonunion*/
,'S0240BS'  /*Malar fracture, left side, sequela*/
,'S0240CD'  /*Maxillary fracture, right side, subsequent encounter for fracture with routine healing*/
,'S0240CG'  /*Maxillary fracture, right side, subsequent encounter for fracture with delayed healing*/
,'S0240CK'  /*Maxillary fracture, right side, subsequent encounter for fracture with nonunion*/
,'S0240CS'  /*Maxillary fracture, right side, sequela*/
,'S0240DD'  /*Maxillary fracture, left side, subsequent encounter for fracture with routine healing*/
,'S0240DG'  /*Maxillary fracture, left side, subsequent encounter for fracture with delayed healing*/
,'S0240DK'  /*Maxillary fracture, left side, subsequent encounter for fracture with nonunion*/
,'S0240DS'  /*Maxillary fracture, left side, sequela*/
,'S0240ED'  /*Zygomatic fracture, right side, subsequent encounter for fracture with routine healing*/
,'S0240EG'  /*Zygomatic fracture, right side, subsequent encounter for fracture with delayed healing*/
,'S0240EK'  /*Zygomatic fracture, right side, subsequent encounter for fracture with nonunion*/
,'S0240ES'  /*Zygomatic fracture, right side, sequela*/
,'S0240FD'  /*Zygomatic fracture, left side, subsequent encounter for fracture with routine healing*/
,'S0240FG'  /*Zygomatic fracture, left side, subsequent encounter for fracture with delayed healing*/
,'S0240FK'  /*Zygomatic fracture, left side, subsequent encounter for fracture with nonunion*/
,'S0240FS'  /*Zygomatic fracture, left side, sequela*/
,'S02411D'  /*LeFort I fracture, subsequent encounter for fracture with routine healing*/
,'S02411G'  /*LeFort I fracture, subsequent encounter for fracture with delayed healing*/
,'S02411K'  /*LeFort I fracture, subsequent encounter for fracture with nonunion*/
,'S02411S'  /*LeFort I fracture, sequela*/
,'S02412D'  /*LeFort II fracture, subsequent encounter for fracture with routine healing*/
,'S02412G'  /*LeFort II fracture, subsequent encounter for fracture with delayed healing*/
,'S02412K'  /*LeFort II fracture, subsequent encounter for fracture with nonunion*/
,'S02412S'  /*LeFort II fracture, sequela*/
,'S02413D'  /*LeFort III fracture, subsequent encounter for fracture with routine healing*/
,'S02413G'  /*LeFort III fracture, subsequent encounter for fracture with delayed healing*/
,'S02413K'  /*LeFort III fracture, subsequent encounter for fracture with nonunion*/
,'S02413S'  /*LeFort III fracture, sequela*/
,'S0242XD'  /*Fracture of alveolus of maxilla, subsequent encounter for fracture with routine healing*/
,'S0242XG'  /*Fracture of alveolus of maxilla, subsequent encounter for fracture with delayed healing*/
,'S0242XK'  /*Fracture of alveolus of maxilla, subsequent encounter for fracture with nonunion*/
,'S0242XS'  /*Fracture of alveolus of maxilla, sequela*/
,'S025XXD'  /*Fracture of tooth (traumatic), subsequent encounter for fracture with routine healing*/
,'S025XXG'  /*Fracture of tooth (traumatic), subsequent encounter for fracture with delayed healing*/
,'S025XXK'  /*Fracture of tooth (traumatic), subsequent encounter for fracture with nonunion*/
,'S025XXS'  /*Fracture of tooth (traumatic), sequela*/
,'S02600D'  /*Fracture of unspecified part of body of mandible, unspecified side, subsequent encounter for fracture with routine healing*/
,'S02600G'  /*Fracture of unspecified part of body of mandible, unspecified side, subsequent encounter for fracture with delayed healing*/
,'S02600K'  /*Fracture of unspecified part of body of mandible, unspecified side, subsequent encounter for fracture with nonunion*/
,'S02600S'  /*Fracture of unspecified part of body of mandible, unspecified side, sequela*/
,'S02601D'  /*Fracture of unspecified part of body of right mandible, subsequent encounter for fracture with routine healing*/
,'S02601G'  /*Fracture of unspecified part of body of right mandible, subsequent encounter for fracture with delayed healing*/
,'S02601K'  /*Fracture of unspecified part of body of right mandible, subsequent encounter for fracture with nonunion*/
,'S02601S'  /*Fracture of unspecified part of body of right mandible, sequela*/
,'S02602D'  /*Fracture of unspecified part of body of left mandible, subsequent encounter for fracture with routine healing*/
,'S02602G'  /*Fracture of unspecified part of body of left mandible, subsequent encounter for fracture with delayed healing*/
,'S02602K'  /*Fracture of unspecified part of body of left mandible, subsequent encounter for fracture with nonunion*/
,'S02602S'  /*Fracture of unspecified part of body of left mandible, sequela*/
,'S02609D'  /*Fracture of mandible, unspecified, subsequent encounter for fracture with routine healing*/
,'S02609G'  /*Fracture of mandible, unspecified, subsequent encounter for fracture with delayed healing*/
,'S02609K'  /*Fracture of mandible, unspecified, subsequent encounter for fracture with nonunion*/
,'S02609S'  /*Fracture of mandible, unspecified, sequela*/
,'S02610D'  /*Fracture of condylar process of mandible, unspecified side, subsequent encounter for fracture with routine healing*/
,'S02610G'  /*Fracture of condylar process of mandible, unspecified side, subsequent encounter for fracture with delayed healing*/
,'S02610K'  /*Fracture of condylar process of mandible, unspecified side, subsequent encounter for fracture with nonunion*/
,'S02610S'  /*Fracture of condylar process of mandible, unspecified side, sequela*/
,'S02611D'  /*Fracture of condylar process of right mandible, subsequent encounter for fracture with routine healing*/
,'S02611G'  /*Fracture of condylar process of right mandible, subsequent encounter for fracture with delayed healing*/
,'S02611K'  /*Fracture of condylar process of right mandible, subsequent encounter for fracture with nonunion*/
,'S02611S'  /*Fracture of condylar process of right mandible, sequela*/
,'S02612D'  /*Fracture of condylar process of left mandible, subsequent encounter for fracture with routine healing*/
,'S02612G'  /*Fracture of condylar process of left mandible, subsequent encounter for fracture with delayed healing*/
,'S02612K'  /*Fracture of condylar process of left mandible, subsequent encounter for fracture with nonunion*/
,'S02612S'  /*Fracture of condylar process of left mandible, sequela*/
,'S02620D'  /*Fracture of subcondylar process of mandible, unspecified side, subsequent encounter for fracture with routine healing*/
,'S02620G'  /*Fracture of subcondylar process of mandible, unspecified side, subsequent encounter for fracture with delayed healing*/
,'S02620K'  /*Fracture of subcondylar process of mandible, unspecified side, subsequent encounter for fracture with nonunion*/
,'S02620S'  /*Fracture of subcondylar process of mandible, unspecified side, sequela*/
,'S02621D'  /*Fracture of subcondylar process of right mandible, subsequent encounter for fracture with routine healing*/
,'S02621G'  /*Fracture of subcondylar process of right mandible, subsequent encounter for fracture with delayed healing*/
,'S02621K'  /*Fracture of subcondylar process of right mandible, subsequent encounter for fracture with nonunion*/
,'S02621S'  /*Fracture of subcondylar process of right mandible, sequela*/
,'S02622D'  /*Fracture of subcondylar process of left mandible, subsequent encounter for fracture with routine healing*/
,'S02622G'  /*Fracture of subcondylar process of left mandible, subsequent encounter for fracture with delayed healing*/
,'S02622K'  /*Fracture of subcondylar process of left mandible, subsequent encounter for fracture with nonunion*/
,'S02622S'  /*Fracture of subcondylar process of left mandible, sequela*/
,'S02630D'  /*Fracture of coronoid process of mandible, unspecified side, subsequent encounter for fracture with routine healing*/
,'S02630G'  /*Fracture of coronoid process of mandible, unspecified side, subsequent encounter for fracture with delayed healing*/
,'S02630K'  /*Fracture of coronoid process of mandible, unspecified side, subsequent encounter for fracture with nonunion*/
,'S02630S'  /*Fracture of coronoid process of mandible, unspecified side, sequela*/
,'S02631D'  /*Fracture of coronoid process of right mandible, subsequent encounter for fracture with routine healing*/
,'S02631G'  /*Fracture of coronoid process of right mandible, subsequent encounter for fracture with delayed healing*/
,'S02631K'  /*Fracture of coronoid process of right mandible, subsequent encounter for fracture with nonunion*/
,'S02631S'  /*Fracture of coronoid process of right mandible, sequela*/
,'S02632D'  /*Fracture of coronoid process of left mandible, subsequent encounter for fracture with routine healing*/
,'S02632G'  /*Fracture of coronoid process of left mandible, subsequent encounter for fracture with delayed healing*/
,'S02632K'  /*Fracture of coronoid process of left mandible, subsequent encounter for fracture with nonunion*/
,'S02632S'  /*Fracture of coronoid process of left mandible, sequela*/
,'S02640D'  /*Fracture of ramus of mandible, unspecified side, subsequent encounter for fracture with routine healing*/
,'S02640G'  /*Fracture of ramus of mandible, unspecified side, subsequent encounter for fracture with delayed healing*/
,'S02640K'  /*Fracture of ramus of mandible, unspecified side, subsequent encounter for fracture with nonunion*/
,'S02640S'  /*Fracture of ramus of mandible, unspecified side, sequela*/
,'S02641D'  /*Fracture of ramus of right mandible, subsequent encounter for fracture with routine healing*/
,'S02641G'  /*Fracture of ramus of right mandible, subsequent encounter for fracture with delayed healing*/
,'S02641K'  /*Fracture of ramus of right mandible, subsequent encounter for fracture with nonunion*/
,'S02641S'  /*Fracture of ramus of right mandible, sequela*/
,'S02642D'  /*Fracture of ramus of left mandible, subsequent encounter for fracture with routine healing*/
,'S02642G'  /*Fracture of ramus of left mandible, subsequent encounter for fracture with delayed healing*/
,'S02642K'  /*Fracture of ramus of left mandible, subsequent encounter for fracture with nonunion*/
,'S02642S'  /*Fracture of ramus of left mandible, sequela*/
,'S02650D'  /*Fracture of angle of mandible, unspecified side, subsequent encounter for fracture with routine healing*/
,'S02650G'  /*Fracture of angle of mandible, unspecified side, subsequent encounter for fracture with delayed healing*/
,'S02650K'  /*Fracture of angle of mandible, unspecified side, subsequent encounter for fracture with nonunion*/
,'S02650S'  /*Fracture of angle of mandible, unspecified side, sequela*/
,'S02651D'  /*Fracture of angle of right mandible, subsequent encounter for fracture with routine healing*/
,'S02651G'  /*Fracture of angle of right mandible, subsequent encounter for fracture with delayed healing*/
,'S02651K'  /*Fracture of angle of right mandible, subsequent encounter for fracture with nonunion*/
,'S02651S'  /*Fracture of angle of right mandible, sequela*/
,'S02652D'  /*Fracture of angle of left mandible, subsequent encounter for fracture with routine healing*/
,'S02652G'  /*Fracture of angle of left mandible, subsequent encounter for fracture with delayed healing*/
,'S02652K'  /*Fracture of angle of left mandible, subsequent encounter for fracture with nonunion*/
,'S02652S'  /*Fracture of angle of left mandible, sequela*/
,'S0266XD'  /*Fracture of symphysis of mandible, subsequent encounter for fracture with routine healing*/
,'S0266XG'  /*Fracture of symphysis of mandible, subsequent encounter for fracture with delayed healing*/
,'S0266XK'  /*Fracture of symphysis of mandible, subsequent encounter for fracture with nonunion*/
,'S0266XS'  /*Fracture of symphysis of mandible, sequela*/
,'S02670D'  /*Fracture of alveolus of mandible, unspecified side, subsequent encounter for fracture with routine healing*/
,'S02670G'  /*Fracture of alveolus of mandible, unspecified side, subsequent encounter for fracture with delayed healing*/
,'S02670K'  /*Fracture of alveolus of mandible, unspecified side, subsequent encounter for fracture with nonunion*/
,'S02670S'  /*Fracture of alveolus of mandible, unspecified side, sequela*/
,'S02671D'  /*Fracture of alveolus of right mandible, subsequent encounter for fracture with routine healing*/
,'S02671G'  /*Fracture of alveolus of right mandible, subsequent encounter for fracture with delayed healing*/
,'S02671K'  /*Fracture of alveolus of right mandible, subsequent encounter for fracture with nonunion*/
,'S02671S'  /*Fracture of alveolus of right mandible, sequela*/
,'S02672D'  /*Fracture of alveolus of left mandible, subsequent encounter for fracture with routine healing*/
,'S02672G'  /*Fracture of alveolus of left mandible, subsequent encounter for fracture with delayed healing*/
,'S02672K'  /*Fracture of alveolus of left mandible, subsequent encounter for fracture with nonunion*/
,'S02672S'  /*Fracture of alveolus of left mandible, sequela*/
,'S0269XD'  /*Fracture of mandible of other specified site, subsequent encounter for fracture with routine healing*/
,'S0269XG'  /*Fracture of mandible of other specified site, subsequent encounter for fracture with delayed healing*/
,'S0269XK'  /*Fracture of mandible of other specified site, subsequent encounter for fracture with nonunion*/
,'S0269XS'  /*Fracture of mandible of other specified site, sequela*/
,'S0280XD'  /*Fracture of other specified skull and facial bones, unspecified side, subsequent encounter for fracture with routine healing*/
,'S0280XG'  /*Fracture of other specified skull and facial bones, unspecified side, subsequent encounter for fracture with delayed healing*/
,'S0280XK'  /*Fracture of other specified skull and facial bones, unspecified side, subsequent encounter for fracture with nonunion*/
,'S0280XS'  /*Fracture of other specified skull and facial bones, unspecified side, sequela*/
,'S0281XD'  /*Fracture of other specified skull and facial bones, right side, subsequent encounter for fracture with routine healing*/
,'S0281XG'  /*Fracture of other specified skull and facial bones, right side, subsequent encounter for fracture with delayed healing*/
,'S0281XK'  /*Fracture of other specified skull and facial bones, right side, subsequent encounter for fracture with nonunion*/
,'S0281XS'  /*Fracture of other specified skull and facial bones, right side, sequela*/
,'S0282XD'  /*Fracture of other specified skull and facial bones, left side, subsequent encounter for fracture with routine healing*/
,'S0282XG'  /*Fracture of other specified skull and facial bones, left side, subsequent encounter for fracture with delayed healing*/
,'S0282XK'  /*Fracture of other specified skull and facial bones, left side, subsequent encounter for fracture with nonunion*/
,'S0282XS'  /*Fracture of other specified skull and facial bones, left side, sequela*/
,'S0291XD'  /*Unspecified fracture of skull, subsequent encounter for fracture with routine healing*/
,'S0291XG'  /*Unspecified fracture of skull, subsequent encounter for fracture with delayed healing*/
,'S0291XK'  /*Unspecified fracture of skull, subsequent encounter for fracture with nonunion*/
,'S0291XS'  /*Unspecified fracture of skull, sequela*/
,'S0292XD'  /*Unspecified fracture of facial bones, subsequent encounter for fracture with routine healing*/
,'S0292XG'  /*Unspecified fracture of facial bones, subsequent encounter for fracture with delayed healing*/
,'S0292XK'  /*Unspecified fracture of facial bones, subsequent encounter for fracture with nonunion*/
,'S0292XS'  /*Unspecified fracture of facial bones, sequela*/
,'S0300XD'  /*Dislocation of jaw, unspecified side, subsequent encounter*/
,'S0300XS'  /*Dislocation of jaw, unspecified side, sequela*/
,'S0301XD'  /*Dislocation of jaw, right side, subsequent encounter*/
,'S0301XS'  /*Dislocation of jaw, right side, sequela*/
,'S0302XD'  /*Dislocation of jaw, left side, subsequent encounter*/
,'S0302XS'  /*Dislocation of jaw, left side, sequela*/
,'S0303XD'  /*Dislocation of jaw, bilateral, subsequent encounter*/
,'S0303XS'  /*Dislocation of jaw, bilateral, sequela*/
,'S031XXD'  /*Dislocation of septal cartilage of nose, subsequent encounter*/
,'S031XXS'  /*Dislocation of septal cartilage of nose, sequela*/
,'S032XXD'  /*Dislocation of tooth, subsequent encounter*/
,'S032XXS'  /*Dislocation of tooth, sequela*/
,'S0340XD'  /*Sprain of jaw, unspecified side, subsequent encounter*/
,'S0340XS'  /*Sprain of jaw, unspecified side, sequela*/
,'S0341XD'  /*Sprain of jaw, right side, subsequent encounter*/
,'S0341XS'  /*Sprain of jaw, right side, sequela*/
,'S0342XD'  /*Sprain of jaw, left side, subsequent encounter*/
,'S0342XS'  /*Sprain of jaw, left side, sequela*/
,'S0343XD'  /*Sprain of jaw, bilateral, subsequent encounter*/
,'S0343XS'  /*Sprain of jaw, bilateral, sequela*/
,'S038XXD'  /*Sprain of joints and ligaments of other parts of head, subsequent encounter*/
,'S038XXS'  /*Sprain of joints and ligaments of other parts of head, sequela*/
,'S039XXD'  /*Sprain of joints and ligaments of unspecified parts of head, subsequent encounter*/
,'S039XXS'  /*Sprain of joints and ligaments of unspecified parts of head, sequela*/
,'S04011D'  /*Injury of optic nerve, right eye, subsequent encounter*/
,'S04011S'  /*Injury of optic nerve, right eye, sequela*/
,'S04012D'  /*Injury of optic nerve, left eye, subsequent encounter*/
,'S04012S'  /*Injury of optic nerve, left eye, sequela*/
,'S04019D'  /*Injury of optic nerve, unspecified eye, subsequent encounter*/
,'S04019S'  /*Injury of optic nerve, unspecified eye, sequela*/
,'S0402XD'  /*Injury of optic chiasm, subsequent encounter*/
,'S0402XS'  /*Injury of optic chiasm, sequela*/
,'S04031D'  /*Injury of optic tract and pathways, right eye, subsequent encounter*/
,'S04031S'  /*Injury of optic tract and pathways, right eye, sequela*/
,'S04032D'  /*Injury of optic tract and pathways, left eye, subsequent encounter*/
,'S04032S'  /*Injury of optic tract and pathways, left eye, sequela*/
,'S04039D'  /*Injury of optic tract and pathways, unspecified eye, subsequent encounter*/
,'S04039S'  /*Injury of optic tract and pathways, unspecified eye, sequela*/
,'S04041D'  /*Injury of visual cortex, right eye, subsequent encounter*/
,'S04041S'  /*Injury of visual cortex, right eye, sequela*/
,'S04042D'  /*Injury of visual cortex, left eye, subsequent encounter*/
,'S04042S'  /*Injury of visual cortex, left eye, sequela*/
,'S04049D'  /*Injury of visual cortex, unspecified eye, subsequent encounter*/
,'S04049S'  /*Injury of visual cortex, unspecified eye, sequela*/
,'S0410XD'  /*Injury of oculomotor nerve, unspecified side, subsequent encounter*/
,'S0410XS'  /*Injury of oculomotor nerve, unspecified side, sequela*/
,'S0411XD'  /*Injury of oculomotor nerve, right side, subsequent encounter*/
,'S0411XS'  /*Injury of oculomotor nerve, right side, sequela*/
,'S0412XD'  /*Injury of oculomotor nerve, left side, subsequent encounter*/
,'S0412XS'  /*Injury of oculomotor nerve, left side, sequela*/
,'S0420XD'  /*Injury of trochlear nerve, unspecified side, subsequent encounter*/
,'S0420XS'  /*Injury of trochlear nerve, unspecified side, sequela*/
,'S0421XD'  /*Injury of trochlear nerve, right side, subsequent encounter*/
,'S0421XS'  /*Injury of trochlear nerve, right side, sequela*/
,'S0422XD'  /*Injury of trochlear nerve, left side, subsequent encounter*/
,'S0422XS'  /*Injury of trochlear nerve, left side, sequela*/
,'S0430XD'  /*Injury of trigeminal nerve, unspecified side, subsequent encounter*/
,'S0430XS'  /*Injury of trigeminal nerve, unspecified side, sequela*/
,'S0431XD'  /*Injury of trigeminal nerve, right side, subsequent encounter*/
,'S0431XS'  /*Injury of trigeminal nerve, right side, sequela*/
,'S0432XD'  /*Injury of trigeminal nerve, left side, subsequent encounter*/
,'S0432XS'  /*Injury of trigeminal nerve, left side, sequela*/
,'S0440XD'  /*Injury of abducent nerve, unspecified side, subsequent encounter*/
,'S0440XS'  /*Injury of abducent nerve, unspecified side, sequela*/
,'S0441XD'  /*Injury of abducent nerve, right side, subsequent encounter*/
,'S0441XS'  /*Injury of abducent nerve, right side, sequela*/
,'S0442XD'  /*Injury of abducent nerve, left side, subsequent encounter*/
,'S0442XS'  /*Injury of abducent nerve, left side, sequela*/
,'S0450XD'  /*Injury of facial nerve, unspecified side, subsequent encounter*/
,'S0450XS'  /*Injury of facial nerve, unspecified side, sequela*/
,'S0451XD'  /*Injury of facial nerve, right side, subsequent encounter*/
,'S0451XS'  /*Injury of facial nerve, right side, sequela*/
,'S0452XD'  /*Injury of facial nerve, left side, subsequent encounter*/
,'S0452XS'  /*Injury of facial nerve, left side, sequela*/
,'S0460XD'  /*Injury of acoustic nerve, unspecified side, subsequent encounter*/
,'S0460XS'  /*Injury of acoustic nerve, unspecified side, sequela*/
,'S0461XD'  /*Injury of acoustic nerve, right side, subsequent encounter*/
,'S0461XS'  /*Injury of acoustic nerve, right side, sequela*/
,'S0462XD'  /*Injury of acoustic nerve, left side, subsequent encounter*/
,'S0462XS'  /*Injury of acoustic nerve, left side, sequela*/
,'S0470XD'  /*Injury of accessory nerve, unspecified side, subsequent encounter*/
,'S0470XS'  /*Injury of accessory nerve, unspecified side, sequela*/
,'S0471XD'  /*Injury of accessory nerve, right side, subsequent encounter*/
,'S0471XS'  /*Injury of accessory nerve, right side, sequela*/
,'S0472XD'  /*Injury of accessory nerve, left side, subsequent encounter*/
,'S0472XS'  /*Injury of accessory nerve, left side, sequela*/
,'S04811D'  /*Injury of olfactory [1st ] nerve, right side, subsequent encounter*/
,'S04811S'  /*Injury of olfactory [1st ] nerve, right side, sequela*/
,'S04812D'  /*Injury of olfactory [1st ] nerve, left side, subsequent encounter*/
,'S04812S'  /*Injury of olfactory [1st ] nerve, left side, sequela*/
,'S04819D'  /*Injury of olfactory [1st ] nerve, unspecified side, subsequent encounter*/
,'S04819S'  /*Injury of olfactory [1st ] nerve, unspecified side, sequela*/
,'S04891D'  /*Injury of other cranial nerves, right side, subsequent encounter*/
,'S04891S'  /*Injury of other cranial nerves, right side, sequela*/
,'S04892D'  /*Injury of other cranial nerves, left side, subsequent encounter*/
,'S04892S'  /*Injury of other cranial nerves, left side, sequela*/
,'S04899D'  /*Injury of other cranial nerves, unspecified side, subsequent encounter*/
,'S04899S'  /*Injury of other cranial nerves, unspecified side, sequela*/
,'S049XXD'  /*Injury of unspecified cranial nerve, subsequent encounter*/
,'S049XXS'  /*Injury of unspecified cranial nerve, sequela*/
,'S0500XD'  /*Injury of conjunctiva and corneal abrasion without foreign body, unspecified eye, subsequent encounter*/
,'S0500XS'  /*Injury of conjunctiva and corneal abrasion without foreign body, unspecified eye, sequela*/
,'S0501XD'  /*Injury of conjunctiva and corneal abrasion without foreign body, right eye, subsequent encounter*/
,'S0501XS'  /*Injury of conjunctiva and corneal abrasion without foreign body, right eye, sequela*/
,'S0502XD'  /*Injury of conjunctiva and corneal abrasion without foreign body, left eye, subsequent encounter*/
,'S0502XS'  /*Injury of conjunctiva and corneal abrasion without foreign body, left eye, sequela*/
,'S0510XD'  /*Contusion of eyeball and orbital tissues, unspecified eye, subsequent encounter*/
,'S0510XS'  /*Contusion of eyeball and orbital tissues, unspecified eye, sequela*/
,'S0511XD'  /*Contusion of eyeball and orbital tissues, right eye, subsequent encounter*/
,'S0511XS'  /*Contusion of eyeball and orbital tissues, right eye, sequela*/
,'S0512XD'  /*Contusion of eyeball and orbital tissues, left eye, subsequent encounter*/
,'S0512XS'  /*Contusion of eyeball and orbital tissues, left eye, sequela*/
,'S0520XD'  /*Ocular laceration and rupture with prolapse or loss of intraocular tissue, unspecified eye, subsequent encounter*/
,'S0520XS'  /*Ocular laceration and rupture with prolapse or loss of intraocular tissue, unspecified eye, sequela*/
,'S0521XD'  /*Ocular laceration and rupture with prolapse or loss of intraocular tissue, right eye, subsequent encounter*/
,'S0521XS'  /*Ocular laceration and rupture with prolapse or loss of intraocular tissue, right eye, sequela*/
,'S0522XD'  /*Ocular laceration and rupture with prolapse or loss of intraocular tissue, left eye, subsequent encounter*/
,'S0522XS'  /*Ocular laceration and rupture with prolapse or loss of intraocular tissue, left eye, sequela*/
,'S0530XD'  /*Ocular laceration without prolapse or loss of intraocular tissue, unspecified eye, subsequent encounter*/
,'S0530XS'  /*Ocular laceration without prolapse or loss of intraocular tissue, unspecified eye, sequela*/
,'S0531XD'  /*Ocular laceration without prolapse or loss of intraocular tissue, right eye, subsequent encounter*/
,'S0531XS'  /*Ocular laceration without prolapse or loss of intraocular tissue, right eye, sequela*/
,'S0532XD'  /*Ocular laceration without prolapse or loss of intraocular tissue, left eye, subsequent encounter*/
,'S0532XS'  /*Ocular laceration without prolapse or loss of intraocular tissue, left eye, sequela*/
,'S0540XD'  /*Penetrating wound of orbit with or without foreign body, unspecified eye, subsequent encounter*/
,'S0540XS'  /*Penetrating wound of orbit with or without foreign body, unspecified eye, sequela*/
,'S0541XD'  /*Penetrating wound of orbit with or without foreign body, right eye, subsequent encounter*/
,'S0541XS'  /*Penetrating wound of orbit with or without foreign body, right eye, sequela*/
,'S0542XD'  /*Penetrating wound of orbit with or without foreign body, left eye, subsequent encounter*/
,'S0542XS'  /*Penetrating wound of orbit with or without foreign body, left eye, sequela*/
,'S0550XD'  /*Penetrating wound with foreign body of unspecified eyeball, subsequent encounter*/
,'S0550XS'  /*Penetrating wound with foreign body of unspecified eyeball, sequela*/
,'S0551XD'  /*Penetrating wound with foreign body of right eyeball, subsequent encounter*/
,'S0551XS'  /*Penetrating wound with foreign body of right eyeball, sequela*/
,'S0552XD'  /*Penetrating wound with foreign body of left eyeball, subsequent encounter*/
,'S0552XS'  /*Penetrating wound with foreign body of left eyeball, sequela*/
,'S0560XD'  /*Penetrating wound without foreign body of unspecified eyeball, subsequent encounter*/
,'S0560XS'  /*Penetrating wound without foreign body of unspecified eyeball, sequela*/
,'S0561XD'  /*Penetrating wound without foreign body of right eyeball, subsequent encounter*/
,'S0561XS'  /*Penetrating wound without foreign body of right eyeball, sequela*/
,'S0562XD'  /*Penetrating wound without foreign body of left eyeball, subsequent encounter*/
,'S0562XS'  /*Penetrating wound without foreign body of left eyeball, sequela*/
,'S0570XD'  /*Avulsion of unspecified eye, subsequent encounter*/
,'S0570XS'  /*Avulsion of unspecified eye, sequela*/
,'S0571XD'  /*Avulsion of right eye, subsequent encounter*/
,'S0571XS'  /*Avulsion of right eye, sequela*/
,'S0572XD'  /*Avulsion of left eye, subsequent encounter*/
,'S0572XS'  /*Avulsion of left eye, sequela*/
,'S058X1D'  /*Other injuries of right eye and orbit, subsequent encounter*/
,'S058X1S'  /*Other injuries of right eye and orbit, sequela*/
,'S058X2D'  /*Other injuries of left eye and orbit, subsequent encounter*/
,'S058X2S'  /*Other injuries of left eye and orbit, sequela*/
,'S058X9D'  /*Other injuries of unspecified eye and orbit, subsequent encounter*/
,'S058X9S'  /*Other injuries of unspecified eye and orbit, sequela*/
,'S0590XD'  /*Unspecified injury of unspecified eye and orbit, subsequent encounter*/
,'S0590XS'  /*Unspecified injury of unspecified eye and orbit, sequela*/
,'S0591XD'  /*Unspecified injury of right eye and orbit, subsequent encounter*/
,'S0591XS'  /*Unspecified injury of right eye and orbit, sequela*/
,'S0592XD'  /*Unspecified injury of left eye and orbit, subsequent encounter*/
,'S0592XS'  /*Unspecified injury of left eye and orbit, sequela*/
,'S060X0D'  /*Concussion without loss of consciousness, subsequent encounter*/
,'S060X0S'  /*Concussion without loss of consciousness, sequela*/
,'S060X1D'  /*Concussion with loss of consciousness of 30 minutes or less, subsequent encounter*/
,'S060X1S'  /*Concussion with loss of consciousness of 30 minutes or less, sequela*/
,'S060X9D'  /*Concussion with loss of consciousness of unspecified duration, subsequent encounter*/
,'S060X9S'  /*Concussion with loss of consciousness of unspecified duration, sequela*/
,'S061X0D'  /*Traumatic cerebral edema without loss of consciousness, subsequent encounter*/
,'S061X0S'  /*Traumatic cerebral edema without loss of consciousness, sequela*/
,'S061X1D'  /*Traumatic cerebral edema with loss of consciousness of 30 minutes or less, subsequent encounter*/
,'S061X1S'  /*Traumatic cerebral edema with loss of consciousness of 30 minutes or less, sequela*/
,'S061X2D'  /*Traumatic cerebral edema with loss of consciousness of 31 minutes to 59 minutes, subsequent encounter*/
,'S061X2S'  /*Traumatic cerebral edema with loss of consciousness of 31 minutes to 59 minutes, sequela*/
,'S061X3D'  /*Traumatic cerebral edema with loss of consciousness of 1 hour to 5 hours 59 minutes, subsequent encounter*/
,'S061X3S'  /*Traumatic cerebral edema with loss of consciousness of 1 hour to 5 hours 59 minutes, sequela*/
,'S061X4D'  /*Traumatic cerebral edema with loss of consciousness of 6 hours to 24 hours, subsequent encounter*/
,'S061X4S'  /*Traumatic cerebral edema with loss of consciousness of 6 hours to 24 hours, sequela*/
,'S061X5D'  /*Traumatic cerebral edema with loss of consciousness greater than 24 hours with return to pre-existing conscious level, subsequent encounter*/
,'S061X5S'  /*Traumatic cerebral edema with loss of consciousness greater than 24 hours with return to pre-existing conscious level, sequela*/
,'S061X6D'  /*Traumatic cerebral edema with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, subsequent encounter*/
,'S061X6S'  /*Traumatic cerebral edema with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, sequela*/
,'S061X7D'  /*Traumatic cerebral edema with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, subsequent encounter*/
,'S061X7S'  /*Traumatic cerebral edema with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, sequela*/
,'S061X8D'  /*Traumatic cerebral edema with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, subsequent encounter*/
,'S061X8S'  /*Traumatic cerebral edema with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, sequela*/
,'S061X9D'  /*Traumatic cerebral edema with loss of consciousness of unspecified duration, subsequent encounter*/
,'S061X9S'  /*Traumatic cerebral edema with loss of consciousness of unspecified duration, sequela*/
,'S062X0D'  /*Diffuse traumatic brain injury without loss of consciousness, subsequent encounter*/
,'S062X0S'  /*Diffuse traumatic brain injury without loss of consciousness, sequela*/
,'S062X1D'  /*Diffuse traumatic brain injury with loss of consciousness of 30 minutes or less, subsequent encounter*/
,'S062X1S'  /*Diffuse traumatic brain injury with loss of consciousness of 30 minutes or less, sequela*/
,'S062X2D'  /*Diffuse traumatic brain injury with loss of consciousness of 31 minutes to 59 minutes, subsequent encounter*/
,'S062X2S'  /*Diffuse traumatic brain injury with loss of consciousness of 31 minutes to 59 minutes, sequela*/
,'S062X3D'  /*Diffuse traumatic brain injury with loss of consciousness of 1 hour to 5 hours 59 minutes, subsequent encounter*/
,'S062X3S'  /*Diffuse traumatic brain injury with loss of consciousness of 1 hour to 5 hours 59 minutes, sequela*/
,'S062X4D'  /*Diffuse traumatic brain injury with loss of consciousness of 6 hours to 24 hours, subsequent encounter*/
,'S062X4S'  /*Diffuse traumatic brain injury with loss of consciousness of 6 hours to 24 hours, sequela*/
,'S062X5D'  /*Diffuse traumatic brain injury with loss of consciousness greater than 24 hours with return to pre-existing conscious levels, subsequent encounter*/
,'S062X5S'  /*Diffuse traumatic brain injury with loss of consciousness greater than 24 hours with return to pre-existing conscious levels, sequela*/
,'S062X6D'  /*Diffuse traumatic brain injury with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, subsequent encounter*/
,'S062X6S'  /*Diffuse traumatic brain injury with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, sequela*/
,'S062X7D'  /*Diffuse traumatic brain injury with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, subsequent encounter*/
,'S062X7S'  /*Diffuse traumatic brain injury with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, sequela*/
,'S062X8D'  /*Diffuse traumatic brain injury with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, subsequent encounter*/
,'S062X8S'  /*Diffuse traumatic brain injury with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, sequela*/
,'S062X9D'  /*Diffuse traumatic brain injury with loss of consciousness of unspecified duration, subsequent encounter*/
,'S062X9S'  /*Diffuse traumatic brain injury with loss of consciousness of unspecified duration, sequela*/
,'S06300D'  /*Unspecified focal traumatic brain injury without loss of consciousness, subsequent encounter*/
,'S06300S'  /*Unspecified focal traumatic brain injury without loss of consciousness, sequela*/
,'S06301D'  /*Unspecified focal traumatic brain injury with loss of consciousness of 30 minutes or less, subsequent encounter*/
,'S06301S'  /*Unspecified focal traumatic brain injury with loss of consciousness of 30 minutes or less, sequela*/
,'S06302D'  /*Unspecified focal traumatic brain injury with loss of consciousness of 31 minutes to 59 minutes, subsequent encounter*/
,'S06302S'  /*Unspecified focal traumatic brain injury with loss of consciousness of 31 minutes to 59 minutes, sequela*/
,'S06303D'  /*Unspecified focal traumatic brain injury with loss of consciousness of 1 hour to 5 hours 59 minutes, subsequent encounter*/
,'S06303S'  /*Unspecified focal traumatic brain injury with loss of consciousness of 1 hour to 5 hours 59 minutes, sequela*/
,'S06304D'  /*Unspecified focal traumatic brain injury with loss of consciousness of 6 hours to 24 hours, subsequent encounter*/
,'S06304S'  /*Unspecified focal traumatic brain injury with loss of consciousness of 6 hours to 24 hours, sequela*/
,'S06305D'  /*Unspecified focal traumatic brain injury with loss of consciousness greater than 24 hours with return to pre-existing conscious level, subsequent encounter*/
,'S06305S'  /*Unspecified focal traumatic brain injury with loss of consciousness greater than 24 hours with return to pre-existing conscious level, sequela*/
,'S06306D'  /*Unspecified focal traumatic brain injury with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, subsequent encounter*/
,'S06306S'  /*Unspecified focal traumatic brain injury with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, sequela*/
,'S06307D'  /*Unspecified focal traumatic brain injury with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, subsequent encounter*/
,'S06307S'  /*Unspecified focal traumatic brain injury with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, sequela*/
,'S06308D'  /*Unspecified focal traumatic brain injury with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, subsequent encounter*/
,'S06308S'  /*Unspecified focal traumatic brain injury with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, sequela*/
,'S06309D'  /*Unspecified focal traumatic brain injury with loss of consciousness of unspecified duration, subsequent encounter*/
,'S06309S'  /*Unspecified focal traumatic brain injury with loss of consciousness of unspecified duration, sequela*/
,'S06310D'  /*Contusion and laceration of right cerebrum without loss of consciousness, subsequent encounter*/
,'S06310S'  /*Contusion and laceration of right cerebrum without loss of consciousness, sequela*/
,'S06311D'  /*Contusion and laceration of right cerebrum with loss of consciousness of 30 minutes or less, subsequent encounter*/
,'S06311S'  /*Contusion and laceration of right cerebrum with loss of consciousness of 30 minutes or less, sequela*/
,'S06312D'  /*Contusion and laceration of right cerebrum with loss of consciousness of 31 minutes to 59 minutes, subsequent encounter*/
,'S06312S'  /*Contusion and laceration of right cerebrum with loss of consciousness of 31 minutes to 59 minutes, sequela*/
,'S06313D'  /*Contusion and laceration of right cerebrum with loss of consciousness of 1 hour to 5 hours 59 minutes, subsequent encounter*/
,'S06313S'  /*Contusion and laceration of right cerebrum with loss of consciousness of 1 hour to 5 hours 59 minutes, sequela*/
,'S06314D'  /*Contusion and laceration of right cerebrum with loss of consciousness of 6 hours to 24 hours, subsequent encounter*/
,'S06314S'  /*Contusion and laceration of right cerebrum with loss of consciousness of 6 hours to 24 hours, sequela*/
,'S06315D'  /*Contusion and laceration of right cerebrum with loss of consciousness greater than 24 hours with return to pre-existing conscious level, subsequent encounter*/
,'S06315S'  /*Contusion and laceration of right cerebrum with loss of consciousness greater than 24 hours with return to pre-existing conscious level, sequela*/
,'S06316D'  /*Contusion and laceration of right cerebrum with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, subsequent encounter*/
,'S06316S'  /*Contusion and laceration of right cerebrum with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, sequela*/
,'S06317D'  /*Contusion and laceration of right cerebrum with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, subsequent encounter*/
,'S06317S'  /*Contusion and laceration of right cerebrum with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, sequela*/
,'S06318D'  /*Contusion and laceration of right cerebrum with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, subsequent encounter*/
,'S06318S'  /*Contusion and laceration of right cerebrum with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, sequela*/
,'S06319D'  /*Contusion and laceration of right cerebrum with loss of consciousness of unspecified duration, subsequent encounter*/
,'S06319S'  /*Contusion and laceration of right cerebrum with loss of consciousness of unspecified duration, sequela*/
,'S06320D'  /*Contusion and laceration of left cerebrum without loss of consciousness, subsequent encounter*/
,'S06320S'  /*Contusion and laceration of left cerebrum without loss of consciousness, sequela*/
,'S06321D'  /*Contusion and laceration of left cerebrum with loss of consciousness of 30 minutes or less, subsequent encounter*/
,'S06321S'  /*Contusion and laceration of left cerebrum with loss of consciousness of 30 minutes or less, sequela*/
,'S06322D'  /*Contusion and laceration of left cerebrum with loss of consciousness of 31 minutes to 59 minutes, subsequent encounter*/
,'S06322S'  /*Contusion and laceration of left cerebrum with loss of consciousness of 31 minutes to 59 minutes, sequela*/
,'S06323D'  /*Contusion and laceration of left cerebrum with loss of consciousness of 1 hour to 5 hours 59 minutes, subsequent encounter*/
,'S06323S'  /*Contusion and laceration of left cerebrum with loss of consciousness of 1 hour to 5 hours 59 minutes, sequela*/
,'S06324D'  /*Contusion and laceration of left cerebrum with loss of consciousness of 6 hours to 24 hours, subsequent encounter*/
,'S06324S'  /*Contusion and laceration of left cerebrum with loss of consciousness of 6 hours to 24 hours, sequela*/
,'S06325D'  /*Contusion and laceration of left cerebrum with loss of consciousness greater than 24 hours with return to pre-existing conscious level, subsequent encounter*/
,'S06325S'  /*Contusion and laceration of left cerebrum with loss of consciousness greater than 24 hours with return to pre-existing conscious level, sequela*/
,'S06326D'  /*Contusion and laceration of left cerebrum with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, subsequent encounter*/
,'S06326S'  /*Contusion and laceration of left cerebrum with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, sequela*/
,'S06327D'  /*Contusion and laceration of left cerebrum with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, subsequent encounter*/
,'S06327S'  /*Contusion and laceration of left cerebrum with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, sequela*/
,'S06328D'  /*Contusion and laceration of left cerebrum with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, subsequent encounter*/
,'S06328S'  /*Contusion and laceration of left cerebrum with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, sequela*/
,'S06329D'  /*Contusion and laceration of left cerebrum with loss of consciousness of unspecified duration, subsequent encounter*/
,'S06329S'  /*Contusion and laceration of left cerebrum with loss of consciousness of unspecified duration, sequela*/
,'S06330D'  /*Contusion and laceration of cerebrum, unspecified, without loss of consciousness, subsequent encounter*/
,'S06330S'  /*Contusion and laceration of cerebrum, unspecified, without loss of consciousness, sequela*/
,'S06331D'  /*Contusion and laceration of cerebrum, unspecified, with loss of consciousness of 30 minutes or less, subsequent encounter*/
,'S06331S'  /*Contusion and laceration of cerebrum, unspecified, with loss of consciousness of 30 minutes or less, sequela*/
,'S06332D'  /*Contusion and laceration of cerebrum, unspecified, with loss of consciousness of 31 minutes to 59 minutes, subsequent encounter*/
,'S06332S'  /*Contusion and laceration of cerebrum, unspecified, with loss of consciousness of 31 minutes to 59 minutes, sequela*/
,'S06333D'  /*Contusion and laceration of cerebrum, unspecified, with loss of consciousness of 1 hour to 5 hours 59 minutes, subsequent encounter*/
,'S06333S'  /*Contusion and laceration of cerebrum, unspecified, with loss of consciousness of 1 hour to 5 hours 59 minutes, sequela*/
,'S06334D'  /*Contusion and laceration of cerebrum, unspecified, with loss of consciousness of 6 hours to 24 hours, subsequent encounter*/
,'S06334S'  /*Contusion and laceration of cerebrum, unspecified, with loss of consciousness of 6 hours to 24 hours, sequela*/
,'S06335D'  /*Contusion and laceration of cerebrum, unspecified, with loss of consciousness greater than 24 hours with return to pre-existing conscious level, subsequent encounter*/
,'S06335S'  /*Contusion and laceration of cerebrum, unspecified, with loss of consciousness greater than 24 hours with return to pre-existing conscious level, sequela*/
,'S06336D'  /*Contusion and laceration of cerebrum, unspecified, with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, subsequent encounter*/
,'S06336S'  /*Contusion and laceration of cerebrum, unspecified, with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, sequela*/
,'S06337D'  /*Contusion and laceration of cerebrum, unspecified, with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, subsequent encounter*/
,'S06337S'  /*Contusion and laceration of cerebrum, unspecified, with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, sequela*/
,'S06338D'  /*Contusion and laceration of cerebrum, unspecified, with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, subsequent encounter*/
,'S06338S'  /*Contusion and laceration of cerebrum, unspecified, with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, sequela*/
,'S06339D'  /*Contusion and laceration of cerebrum, unspecified, with loss of consciousness of unspecified duration, subsequent encounter*/
,'S06339S'  /*Contusion and laceration of cerebrum, unspecified, with loss of consciousness of unspecified duration, sequela*/
,'S06340D'  /*Traumatic hemorrhage of right cerebrum without loss of consciousness, subsequent encounter*/
,'S06340S'  /*Traumatic hemorrhage of right cerebrum without loss of consciousness, sequela*/
,'S06341D'  /*Traumatic hemorrhage of right cerebrum with loss of consciousness of 30 minutes or less, subsequent encounter*/
,'S06341S'  /*Traumatic hemorrhage of right cerebrum with loss of consciousness of 30 minutes or less, sequela*/
,'S06342D'  /*Traumatic hemorrhage of right cerebrum with loss of consciousness of 31 minutes to 59 minutes, subsequent encounter*/
,'S06342S'  /*Traumatic hemorrhage of right cerebrum with loss of consciousness of 31 minutes to 59 minutes, sequela*/
,'S06343D'  /*Traumatic hemorrhage of right cerebrum with loss of consciousness of 1 hours to 5 hours 59 minutes, subsequent encounter*/
,'S06343S'  /*Traumatic hemorrhage of right cerebrum with loss of consciousness of 1 hours to 5 hours 59 minutes, sequela*/
,'S06344D'  /*Traumatic hemorrhage of right cerebrum with loss of consciousness of 6 hours to 24 hours, subsequent encounter*/
,'S06344S'  /*Traumatic hemorrhage of right cerebrum with loss of consciousness of 6 hours to 24 hours, sequela*/
,'S06345D'  /*Traumatic hemorrhage of right cerebrum with loss of consciousness greater than 24 hours with return to pre-existing conscious level, subsequent encounter*/
,'S06345S'  /*Traumatic hemorrhage of right cerebrum with loss of consciousness greater than 24 hours with return to pre-existing conscious level, sequela*/
,'S06346D'  /*Traumatic hemorrhage of right cerebrum with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, subsequent encounter*/
,'S06346S'  /*Traumatic hemorrhage of right cerebrum with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, sequela*/
,'S06347D'  /*Traumatic hemorrhage of right cerebrum with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, subsequent encounter*/
,'S06347S'  /*Traumatic hemorrhage of right cerebrum with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, sequela*/
,'S06348D'  /*Traumatic hemorrhage of right cerebrum with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, subsequent encounter*/
,'S06348S'  /*Traumatic hemorrhage of right cerebrum with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, sequela*/
,'S06349D'  /*Traumatic hemorrhage of right cerebrum with loss of consciousness of unspecified duration, subsequent encounter*/
,'S06349S'  /*Traumatic hemorrhage of right cerebrum with loss of consciousness of unspecified duration, sequela*/
,'S06350D'  /*Traumatic hemorrhage of left cerebrum without loss of consciousness, subsequent encounter*/
,'S06350S'  /*Traumatic hemorrhage of left cerebrum without loss of consciousness, sequela*/
,'S06351D'  /*Traumatic hemorrhage of left cerebrum with loss of consciousness of 30 minutes or less, subsequent encounter*/
,'S06351S'  /*Traumatic hemorrhage of left cerebrum with loss of consciousness of 30 minutes or less, sequela*/
,'S06352D'  /*Traumatic hemorrhage of left cerebrum with loss of consciousness of 31 minutes to 59 minutes, subsequent encounter*/
,'S06352S'  /*Traumatic hemorrhage of left cerebrum with loss of consciousness of 31 minutes to 59 minutes, sequela*/
,'S06353D'  /*Traumatic hemorrhage of left cerebrum with loss of consciousness of 1 hours to 5 hours 59 minutes, subsequent encounter*/
,'S06353S'  /*Traumatic hemorrhage of left cerebrum with loss of consciousness of 1 hours to 5 hours 59 minutes, sequela*/
,'S06354D'  /*Traumatic hemorrhage of left cerebrum with loss of consciousness of 6 hours to 24 hours, subsequent encounter*/
,'S06354S'  /*Traumatic hemorrhage of left cerebrum with loss of consciousness of 6 hours to 24 hours, sequela*/
,'S06355D'  /*Traumatic hemorrhage of left cerebrum with loss of consciousness greater than 24 hours with return to pre-existing conscious level, subsequent encounter*/
,'S06355S'  /*Traumatic hemorrhage of left cerebrum with loss of consciousness greater than 24 hours with return to pre-existing conscious level, sequela*/
,'S06356D'  /*Traumatic hemorrhage of left cerebrum with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, subsequent encounter*/
,'S06356S'  /*Traumatic hemorrhage of left cerebrum with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, sequela*/
,'S06357D'  /*Traumatic hemorrhage of left cerebrum with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, subsequent encounter*/
,'S06357S'  /*Traumatic hemorrhage of left cerebrum with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, sequela*/
,'S06358D'  /*Traumatic hemorrhage of left cerebrum with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, subsequent encounter*/
,'S06358S'  /*Traumatic hemorrhage of left cerebrum with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, sequela*/
,'S06359D'  /*Traumatic hemorrhage of left cerebrum with loss of consciousness of unspecified duration, subsequent encounter*/
,'S06359S'  /*Traumatic hemorrhage of left cerebrum with loss of consciousness of unspecified duration, sequela*/
,'S06360D'  /*Traumatic hemorrhage of cerebrum, unspecified, without loss of consciousness, subsequent encounter*/
,'S06360S'  /*Traumatic hemorrhage of cerebrum, unspecified, without loss of consciousness, sequela*/
,'S06361D'  /*Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness of 30 minutes or less, subsequent encounter*/
,'S06361S'  /*Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness of 30 minutes or less, sequela*/
,'S06362D'  /*Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness of 31 minutes to 59 minutes, subsequent encounter*/
,'S06362S'  /*Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness of 31 minutes to 59 minutes, sequela*/
,'S06363D'  /*Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness of 1 hours to 5 hours 59 minutes, subsequent encounter*/
,'S06363S'  /*Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness of 1 hours to 5 hours 59 minutes, sequela*/
,'S06364D'  /*Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness of 6 hours to 24 hours, subsequent encounter*/
,'S06364S'  /*Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness of 6 hours to 24 hours, sequela*/
,'S06365D'  /*Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness greater than 24 hours with return to pre-existing conscious level, subsequent encounter*/
,'S06365S'  /*Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness greater than 24 hours with return to pre-existing conscious level, sequela*/
,'S06366D'  /*Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, subsequent encounter*/
,'S06366S'  /*Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, sequela*/
,'S06367D'  /*Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, subsequent encounter*/
,'S06367S'  /*Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, sequela*/
,'S06368D'  /*Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, subsequent encounter*/
,'S06368S'  /*Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, sequela*/
,'S06369D'  /*Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness of unspecified duration, subsequent encounter*/
,'S06369S'  /*Traumatic hemorrhage of cerebrum, unspecified, with loss of consciousness of unspecified duration, sequela*/
,'S06370D'  /*Contusion, laceration, and hemorrhage of cerebellum without loss of consciousness, subsequent encounter*/
,'S06370S'  /*Contusion, laceration, and hemorrhage of cerebellum without loss of consciousness, sequela*/
,'S06371D'  /*Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness of 30 minutes or less, subsequent encounter*/
,'S06371S'  /*Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness of 30 minutes or less, sequela*/
,'S06372D'  /*Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness of 31 minutes to 59 minutes, subsequent encounter*/
,'S06372S'  /*Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness of 31 minutes to 59 minutes, sequela*/
,'S06373D'  /*Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness of 1 hour to 5 hours 59 minutes, subsequent encounter*/
,'S06373S'  /*Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness of 1 hour to 5 hours 59 minutes, sequela*/
,'S06374D'  /*Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness of 6 hours to 24 hours, subsequent encounter*/
,'S06374S'  /*Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness of 6 hours to 24 hours, sequela*/
,'S06375D'  /*Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness greater than 24 hours with return to pre-existing conscious level, subsequent encounter*/
,'S06375S'  /*Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness greater than 24 hours with return to pre-existing conscious level, sequela*/
,'S06376D'  /*Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, subsequent encounter*/
,'S06376S'  /*Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, sequela*/
,'S06377D'  /*Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, subsequent encounter*/
,'S06377S'  /*Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, sequela*/
,'S06378D'  /*Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, subsequent encounter*/
,'S06378S'  /*Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, sequela*/
,'S06379D'  /*Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness of unspecified duration, subsequent encounter*/
,'S06379S'  /*Contusion, laceration, and hemorrhage of cerebellum with loss of consciousness of unspecified duration, sequela*/
,'S06380D'  /*Contusion, laceration, and hemorrhage of brainstem without loss of consciousness, subsequent encounter*/
,'S06380S'  /*Contusion, laceration, and hemorrhage of brainstem without loss of consciousness, sequela*/
,'S06381D'  /*Contusion, laceration, and hemorrhage of brainstem with loss of consciousness of 30 minutes or less, subsequent encounter*/
,'S06381S'  /*Contusion, laceration, and hemorrhage of brainstem with loss of consciousness of 30 minutes or less, sequela*/
,'S06382D'  /*Contusion, laceration, and hemorrhage of brainstem with loss of consciousness of 31 minutes to 59 minutes, subsequent encounter*/
,'S06382S'  /*Contusion, laceration, and hemorrhage of brainstem with loss of consciousness of 31 minutes to 59 minutes, sequela*/
,'S06383D'  /*Contusion, laceration, and hemorrhage of brainstem with loss of consciousness of 1 hour to 5 hours 59 minutes, subsequent encounter*/
,'S06383S'  /*Contusion, laceration, and hemorrhage of brainstem with loss of consciousness of 1 hour to 5 hours 59 minutes, sequela*/
,'S06384D'  /*Contusion, laceration, and hemorrhage of brainstem with loss of consciousness of 6 hours to 24 hours, subsequent encounter*/
,'S06384S'  /*Contusion, laceration, and hemorrhage of brainstem with loss of consciousness of 6 hours to 24 hours, sequela*/
,'S06385D'  /*Contusion, laceration, and hemorrhage of brainstem with loss of consciousness greater than 24 hours with return to pre-existing conscious level, subsequent encounter*/
,'S06385S'  /*Contusion, laceration, and hemorrhage of brainstem with loss of consciousness greater than 24 hours with return to pre-existing conscious level, sequela*/
,'S06386D'  /*Contusion, laceration, and hemorrhage of brainstem with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, subsequent encounter*/
,'S06386S'  /*Contusion, laceration, and hemorrhage of brainstem with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, sequela*/
,'S06387D'  /*Contusion, laceration, and hemorrhage of brainstem with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, subsequent encounter*/
,'S06387S'  /*Contusion, laceration, and hemorrhage of brainstem with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, sequela*/
,'S06388D'  /*Contusion, laceration, and hemorrhage of brainstem with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, subsequent encounter*/
,'S06388S'  /*Contusion, laceration, and hemorrhage of brainstem with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, sequela*/
,'S06389D'  /*Contusion, laceration, and hemorrhage of brainstem with loss of consciousness of unspecified duration, subsequent encounter*/
,'S06389S'  /*Contusion, laceration, and hemorrhage of brainstem with loss of consciousness of unspecified duration, sequela*/
,'S064X0D'  /*Epidural hemorrhage without loss of consciousness, subsequent encounter*/
,'S064X0S'  /*Epidural hemorrhage without loss of consciousness, sequela*/
,'S064X1D'  /*Epidural hemorrhage with loss of consciousness of 30 minutes or less, subsequent encounter*/
,'S064X1S'  /*Epidural hemorrhage with loss of consciousness of 30 minutes or less, sequela*/
,'S064X2D'  /*Epidural hemorrhage with loss of consciousness of 31 minutes to 59 minutes, subsequent encounter*/
,'S064X2S'  /*Epidural hemorrhage with loss of consciousness of 31 minutes to 59 minutes, sequela*/
,'S064X3D'  /*Epidural hemorrhage with loss of consciousness of 1 hour to 5 hours 59 minutes, subsequent encounter*/
,'S064X3S'  /*Epidural hemorrhage with loss of consciousness of 1 hour to 5 hours 59 minutes, sequela*/
,'S064X4D'  /*Epidural hemorrhage with loss of consciousness of 6 hours to 24 hours, subsequent encounter*/
,'S064X4S'  /*Epidural hemorrhage with loss of consciousness of 6 hours to 24 hours, sequela*/
,'S064X5D'  /*Epidural hemorrhage with loss of consciousness greater than 24 hours with return to pre-existing conscious level, subsequent encounter*/
,'S064X5S'  /*Epidural hemorrhage with loss of consciousness greater than 24 hours with return to pre-existing conscious level, sequela*/
,'S064X6D'  /*Epidural hemorrhage with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, subsequent encounter*/
,'S064X6S'  /*Epidural hemorrhage with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, sequela*/
,'S064X7D'  /*Epidural hemorrhage with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, subsequent encounter*/
,'S064X7S'  /*Epidural hemorrhage with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, sequela*/
,'S064X8D'  /*Epidural hemorrhage with loss of consciousness of any duration with death due to other causes prior to regaining consciousness, subsequent encounter*/
,'S064X8S'  /*Epidural hemorrhage with loss of consciousness of any duration with death due to other causes prior to regaining consciousness, sequela*/
,'S064X9D'  /*Epidural hemorrhage with loss of consciousness of unspecified duration, subsequent encounter*/
,'S064X9S'  /*Epidural hemorrhage with loss of consciousness of unspecified duration, sequela*/
,'S065X0D'  /*Traumatic subdural hemorrhage without loss of consciousness, subsequent encounter*/
,'S065X0S'  /*Traumatic subdural hemorrhage without loss of consciousness, sequela*/
,'S065X1D'  /*Traumatic subdural hemorrhage with loss of consciousness of 30 minutes or less, subsequent encounter*/
,'S065X1S'  /*Traumatic subdural hemorrhage with loss of consciousness of 30 minutes or less, sequela*/
,'S065X2D'  /*Traumatic subdural hemorrhage with loss of consciousness of 31 minutes to 59 minutes, subsequent encounter*/
,'S065X2S'  /*Traumatic subdural hemorrhage with loss of consciousness of 31 minutes to 59 minutes, sequela*/
,'S065X3D'  /*Traumatic subdural hemorrhage with loss of consciousness of 1 hour to 5 hours 59 minutes, subsequent encounter*/
,'S065X3S'  /*Traumatic subdural hemorrhage with loss of consciousness of 1 hour to 5 hours 59 minutes, sequela*/
,'S065X4D'  /*Traumatic subdural hemorrhage with loss of consciousness of 6 hours to 24 hours, subsequent encounter*/
,'S065X4S'  /*Traumatic subdural hemorrhage with loss of consciousness of 6 hours to 24 hours, sequela*/
,'S065X5D'  /*Traumatic subdural hemorrhage with loss of consciousness greater than 24 hours with return to pre-existing conscious level, subsequent encounter*/
,'S065X5S'  /*Traumatic subdural hemorrhage with loss of consciousness greater than 24 hours with return to pre-existing conscious level, sequela*/
,'S065X6D'  /*Traumatic subdural hemorrhage with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, subsequent encounter*/
,'S065X6S'  /*Traumatic subdural hemorrhage with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, sequela*/
,'S065X7D'  /*Traumatic subdural hemorrhage with loss of consciousness of any duration with death due to brain injury before regaining consciousness, subsequent encounter*/
,'S065X7S'  /*Traumatic subdural hemorrhage with loss of consciousness of any duration with death due to brain injury before regaining consciousness, sequela*/
,'S065X8D'  /*Traumatic subdural hemorrhage with loss of consciousness of any duration with death due to other cause before regaining consciousness, subsequent encounter*/
,'S065X8S'  /*Traumatic subdural hemorrhage with loss of consciousness of any duration with death due to other cause before regaining consciousness, sequela*/
,'S065X9D'  /*Traumatic subdural hemorrhage with loss of consciousness of unspecified duration, subsequent encounter*/
,'S065X9S'  /*Traumatic subdural hemorrhage with loss of consciousness of unspecified duration, sequela*/
,'S066X0D'  /*Traumatic subarachnoid hemorrhage without loss of consciousness, subsequent encounter*/
,'S066X0S'  /*Traumatic subarachnoid hemorrhage without loss of consciousness, sequela*/
,'S066X1D'  /*Traumatic subarachnoid hemorrhage with loss of consciousness of 30 minutes or less, subsequent encounter*/
,'S066X1S'  /*Traumatic subarachnoid hemorrhage with loss of consciousness of 30 minutes or less, sequela*/
,'S066X2D'  /*Traumatic subarachnoid hemorrhage with loss of consciousness of 31 minutes to 59 minutes, subsequent encounter*/
,'S066X2S'  /*Traumatic subarachnoid hemorrhage with loss of consciousness of 31 minutes to 59 minutes, sequela*/
,'S066X3D'  /*Traumatic subarachnoid hemorrhage with loss of consciousness of 1 hour to 5 hours 59 minutes, subsequent encounter*/
,'S066X3S'  /*Traumatic subarachnoid hemorrhage with loss of consciousness of 1 hour to 5 hours 59 minutes, sequela*/
,'S066X4D'  /*Traumatic subarachnoid hemorrhage with loss of consciousness of 6 hours to 24 hours, subsequent encounter*/
,'S066X4S'  /*Traumatic subarachnoid hemorrhage with loss of consciousness of 6 hours to 24 hours, sequela*/
,'S066X5D'  /*Traumatic subarachnoid hemorrhage with loss of consciousness greater than 24 hours with return to pre-existing conscious level, subsequent encounter*/
,'S066X5S'  /*Traumatic subarachnoid hemorrhage with loss of consciousness greater than 24 hours with return to pre-existing conscious level, sequela*/
,'S066X6D'  /*Traumatic subarachnoid hemorrhage with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, subsequent encounter*/
,'S066X6S'  /*Traumatic subarachnoid hemorrhage with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, sequela*/
,'S066X7D'  /*Traumatic subarachnoid hemorrhage with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, subsequent encounter*/
,'S066X7S'  /*Traumatic subarachnoid hemorrhage with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, sequela*/
,'S066X8D'  /*Traumatic subarachnoid hemorrhage with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, subsequent encounter*/
,'S066X8S'  /*Traumatic subarachnoid hemorrhage with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, sequela*/
,'S066X9D'  /*Traumatic subarachnoid hemorrhage with loss of consciousness of unspecified duration, subsequent encounter*/
,'S066X9S'  /*Traumatic subarachnoid hemorrhage with loss of consciousness of unspecified duration, sequela*/
,'S06810D'  /*Injury of right internal carotid artery, intracranial portion, not elsewhere classified without loss of consciousness, subsequent encounter*/
,'S06810S'  /*Injury of right internal carotid artery, intracranial portion, not elsewhere classified without loss of consciousness, sequela*/
,'S06811D'  /*Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 30 minutes or less, subsequent encounter*/
,'S06811S'  /*Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 30 minutes or less, sequela*/
,'S06812D'  /*Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 31 minutes to 59 minutes, subsequent encounter*/
,'S06812S'  /*Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 31 minutes to 59 minutes, sequela*/
,'S06813D'  /*Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 1 hour to 5 hours 59 minutes, subsequent encounter*/
,'S06813S'  /*Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 1 hour to 5 hours 59 minutes, sequela*/
,'S06814D'  /*Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 6 hours to 24 hours, subsequent encounter*/
,'S06814S'  /*Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 6 hours to 24 hours, sequela*/
,'S06815D'  /*Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness greater than 24 hours with return to pre-existing conscious level, subsequent encounter*/
,'S06815S'  /*Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness greater than 24 hours with return to pre-existing conscious level, sequela*/
,'S06816D'  /*Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, subsequent encounter*/
,'S06816S'  /*Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, sequela*/
,'S06817D'  /*Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, subsequent encounter*/
,'S06817S'  /*Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, sequela*/
,'S06818D'  /*Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, subsequent encounter*/
,'S06818S'  /*Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, sequela*/
,'S06819D'  /*Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of unspecified duration, subsequent encounter*/
,'S06819S'  /*Injury of right internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of unspecified duration, sequela*/
,'S06820D'  /*Injury of left internal carotid artery, intracranial portion, not elsewhere classified without loss of consciousness, subsequent encounter*/
,'S06820S'  /*Injury of left internal carotid artery, intracranial portion, not elsewhere classified without loss of consciousness, sequela*/
,'S06821D'  /*Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 30 minutes or less, subsequent encounter*/
,'S06821S'  /*Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 30 minutes or less, sequela*/
,'S06822D'  /*Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 31 minutes to 59 minutes, subsequent encounter*/
,'S06822S'  /*Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 31 minutes to 59 minutes, sequela*/
,'S06823D'  /*Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 1 hour to 5 hours 59 minutes, subsequent encounter*/
,'S06823S'  /*Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 1 hour to 5 hours 59 minutes, sequela*/
,'S06824D'  /*Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 6 hours to 24 hours, subsequent encounter*/
,'S06824S'  /*Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of 6 hours to 24 hours, sequela*/
,'S06825D'  /*Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness greater than 24 hours with return to pre-existing conscious level, subsequent encounter*/
,'S06825S'  /*Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness greater than 24 hours with return to pre-existing conscious level, sequela*/
,'S06826D'  /*Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, subsequent encounter*/
,'S06826S'  /*Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, sequela*/
,'S06827D'  /*Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, subsequent encounter*/
,'S06827S'  /*Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, sequela*/
,'S06828D'  /*Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, subsequent encounter*/
,'S06828S'  /*Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, sequela*/
,'S06829D'  /*Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of unspecified duration, subsequent encounter*/
,'S06829S'  /*Injury of left internal carotid artery, intracranial portion, not elsewhere classified with loss of consciousness of unspecified duration, sequela*/
,'S06890D'  /*Other specified intracranial injury without loss of consciousness, subsequent encounter*/
,'S06890S'  /*Other specified intracranial injury without loss of consciousness, sequela*/
,'S06891D'  /*Other specified intracranial injury with loss of consciousness of 30 minutes or less, subsequent encounter*/
,'S06891S'  /*Other specified intracranial injury with loss of consciousness of 30 minutes or less, sequela*/
,'S06892D'  /*Other specified intracranial injury with loss of consciousness of 31 minutes to 59 minutes, subsequent encounter*/
,'S06892S'  /*Other specified intracranial injury with loss of consciousness of 31 minutes to 59 minutes, sequela*/
,'S06893D'  /*Other specified intracranial injury with loss of consciousness of 1 hour to 5 hours 59 minutes, subsequent encounter*/
,'S06893S'  /*Other specified intracranial injury with loss of consciousness of 1 hour to 5 hours 59 minutes, sequela*/
,'S06894D'  /*Other specified intracranial injury with loss of consciousness of 6 hours to 24 hours, subsequent encounter*/
,'S06894S'  /*Other specified intracranial injury with loss of consciousness of 6 hours to 24 hours, sequela*/
,'S06895D'  /*Other specified intracranial injury with loss of consciousness greater than 24 hours with return to pre-existing conscious level, subsequent encounter*/
,'S06895S'  /*Other specified intracranial injury with loss of consciousness greater than 24 hours with return to pre-existing conscious level, sequela*/
,'S06896D'  /*Other specified intracranial injury with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, subsequent encounter*/
,'S06896S'  /*Other specified intracranial injury with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, sequela*/
,'S06897D'  /*Other specified intracranial injury with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, subsequent encounter*/
,'S06897S'  /*Other specified intracranial injury with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, sequela*/
,'S06898D'  /*Other specified intracranial injury with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, subsequent encounter*/
,'S06898S'  /*Other specified intracranial injury with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, sequela*/
,'S06899D'  /*Other specified intracranial injury with loss of consciousness of unspecified duration, subsequent encounter*/
,'S06899S'  /*Other specified intracranial injury with loss of consciousness of unspecified duration, sequela*/
,'S069X0D'  /*Unspecified intracranial injury without loss of consciousness, subsequent encounter*/
,'S069X0S'  /*Unspecified intracranial injury without loss of consciousness, sequela*/
,'S069X1D'  /*Unspecified intracranial injury with loss of consciousness of 30 minutes or less, subsequent encounter*/
,'S069X1S'  /*Unspecified intracranial injury with loss of consciousness of 30 minutes or less, sequela*/
,'S069X2D'  /*Unspecified intracranial injury with loss of consciousness of 31 minutes to 59 minutes, subsequent encounter*/
,'S069X2S'  /*Unspecified intracranial injury with loss of consciousness of 31 minutes to 59 minutes, sequela*/
,'S069X3D'  /*Unspecified intracranial injury with loss of consciousness of 1 hour to 5 hours 59 minutes, subsequent encounter*/
,'S069X3S'  /*Unspecified intracranial injury with loss of consciousness of 1 hour to 5 hours 59 minutes, sequela*/
,'S069X4D'  /*Unspecified intracranial injury with loss of consciousness of 6 hours to 24 hours, subsequent encounter*/
,'S069X4S'  /*Unspecified intracranial injury with loss of consciousness of 6 hours to 24 hours, sequela*/
,'S069X5D'  /*Unspecified intracranial injury with loss of consciousness greater than 24 hours with return to pre-existing conscious level, subsequent encounter*/
,'S069X5S'  /*Unspecified intracranial injury with loss of consciousness greater than 24 hours with return to pre-existing conscious level, sequela*/
,'S069X6D'  /*Unspecified intracranial injury with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, subsequent encounter*/
,'S069X6S'  /*Unspecified intracranial injury with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, sequela*/
,'S069X7D'  /*Unspecified intracranial injury with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, subsequent encounter*/
,'S069X7S'  /*Unspecified intracranial injury with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, sequela*/
,'S069X8D'  /*Unspecified intracranial injury with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, subsequent encounter*/
,'S069X8S'  /*Unspecified intracranial injury with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, sequela*/
,'S069X9D'  /*Unspecified intracranial injury with loss of consciousness of unspecified duration, subsequent encounter*/
,'S069X9S'  /*Unspecified intracranial injury with loss of consciousness of unspecified duration, sequela*/
,'S070XXD'  /*Crushing injury of face, subsequent encounter*/
,'S070XXS'  /*Crushing injury of face, sequela*/
,'S071XXD'  /*Crushing injury of skull, subsequent encounter*/
,'S071XXS'  /*Crushing injury of skull, sequela*/
,'S078XXD'  /*Crushing injury of other parts of head, subsequent encounter*/
,'S078XXS'  /*Crushing injury of other parts of head, sequela*/
,'S079XXD'  /*Crushing injury of head, part unspecified, subsequent encounter*/
,'S079XXS'  /*Crushing injury of head, part unspecified, sequela*/
,'S080XXD'  /*Avulsion of scalp, subsequent encounter*/
,'S080XXS'  /*Avulsion of scalp, sequela*/
,'S08111D'  /*Complete traumatic amputation of right ear, subsequent encounter*/
,'S08111S'  /*Complete traumatic amputation of right ear, sequela*/
,'S08112D'  /*Complete traumatic amputation of left ear, subsequent encounter*/
,'S08112S'  /*Complete traumatic amputation of left ear, sequela*/
,'S08119D'  /*Complete traumatic amputation of unspecified ear, subsequent encounter*/
,'S08119S'  /*Complete traumatic amputation of unspecified ear, sequela*/
,'S08121D'  /*Partial traumatic amputation of right ear, subsequent encounter*/
,'S08121S'  /*Partial traumatic amputation of right ear, sequela*/
,'S08122D'  /*Partial traumatic amputation of left ear, subsequent encounter*/
,'S08122S'  /*Partial traumatic amputation of left ear, sequela*/
,'S08129D'  /*Partial traumatic amputation of unspecified ear, subsequent encounter*/
,'S08129S'  /*Partial traumatic amputation of unspecified ear, sequela*/
,'S08811D'  /*Complete traumatic amputation of nose, subsequent encounter*/
,'S08811S'  /*Complete traumatic amputation of nose, sequela*/
,'S08812D'  /*Partial traumatic amputation of nose, subsequent encounter*/
,'S08812S'  /*Partial traumatic amputation of nose, sequela*/
,'S0889XD'  /*Traumatic amputation of other parts of head, subsequent encounter*/
,'S0889XS'  /*Traumatic amputation of other parts of head, sequela*/
,'S090XXD'  /*Injury of blood vessels of head, not elsewhere classified, subsequent encounter*/
,'S090XXS'  /*Injury of blood vessels of head, not elsewhere classified, sequela*/
,'S0910XD'  /*Unspecified injury of muscle and tendon of head, subsequent encounter*/
,'S0910XS'  /*Unspecified injury of muscle and tendon of head, sequela*/
,'S0911XD'  /*Strain of muscle and tendon of head, subsequent encounter*/
,'S0911XS'  /*Strain of muscle and tendon of head, sequela*/
,'S0912XD'  /*Laceration of muscle and tendon of head, subsequent encounter*/
,'S0912XS'  /*Laceration of muscle and tendon of head, sequela*/
,'S0919XD'  /*Other specified injury of muscle and tendon of head, subsequent encounter*/
,'S0919XS'  /*Other specified injury of muscle and tendon of head, sequela*/
,'S0920XD'  /*Traumatic rupture of unspecified ear drum, subsequent encounter*/
,'S0920XS'  /*Traumatic rupture of unspecified ear drum, sequela*/
,'S0921XD'  /*Traumatic rupture of right ear drum, subsequent encounter*/
,'S0921XS'  /*Traumatic rupture of right ear drum, sequela*/
,'S0922XD'  /*Traumatic rupture of left ear drum, subsequent encounter*/
,'S0922XS'  /*Traumatic rupture of left ear drum, sequela*/
,'S09301D'  /*Unspecified injury of right middle and inner ear, subsequent encounter*/
,'S09301S'  /*Unspecified injury of right middle and inner ear, sequela*/
,'S09302D'  /*Unspecified injury of left middle and inner ear, subsequent encounter*/
,'S09302S'  /*Unspecified injury of left middle and inner ear, sequela*/
,'S09309D'  /*Unspecified injury of unspecified middle and inner ear, subsequent encounter*/
,'S09309S'  /*Unspecified injury of unspecified middle and inner ear, sequela*/
,'S09311D'  /*Primary blast injury of right ear, subsequent encounter*/
,'S09311S'  /*Primary blast injury of right ear, sequela*/
,'S09312D'  /*Primary blast injury of left ear, subsequent encounter*/
,'S09312S'  /*Primary blast injury of left ear, sequela*/
,'S09313D'  /*Primary blast injury of ear, bilateral, subsequent encounter*/
,'S09313S'  /*Primary blast injury of ear, bilateral, sequela*/
,'S09319D'  /*Primary blast injury of unspecified ear, subsequent encounter*/
,'S09319S'  /*Primary blast injury of unspecified ear, sequela*/
,'S09391D'  /*Other specified injury of right middle and inner ear, subsequent encounter*/
,'S09391S'  /*Other specified injury of right middle and inner ear, sequela*/
,'S09392D'  /*Other specified injury of left middle and inner ear, subsequent encounter*/
,'S09392S'  /*Other specified injury of left middle and inner ear, sequela*/
,'S09399D'  /*Other specified injury of unspecified middle and inner ear, subsequent encounter*/
,'S09399S'  /*Other specified injury of unspecified middle and inner ear, sequela*/
,'S098XXD'  /*Other specified injuries of head, subsequent encounter*/
,'S098XXS'  /*Other specified injuries of head, sequela*/
,'S0990XD'  /*Unspecified injury of head, subsequent encounter*/
,'S0990XS'  /*Unspecified injury of head, sequela*/
,'S0991XD'  /*Unspecified injury of ear, subsequent encounter*/
,'S0991XS'  /*Unspecified injury of ear, sequela*/
,'S0992XD'  /*Unspecified injury of nose, subsequent encounter*/
,'S0992XS'  /*Unspecified injury of nose, sequela*/
,'S0993XD'  /*Unspecified injury of face, subsequent encounter*/
,'S0993XS'  /*Unspecified injury of face, sequela*/
,'S100XXD'  /*Contusion of throat, subsequent encounter*/
,'S100XXS'  /*Contusion of throat, sequela*/
,'S1010XD'  /*Unspecified superficial injuries of throat, subsequent encounter*/
,'S1010XS'  /*Unspecified superficial injuries of throat, sequela*/
,'S1011XD'  /*Abrasion of throat, subsequent encounter*/
,'S1011XS'  /*Abrasion of throat, sequela*/
,'S1012XD'  /*Blister (nonthermal) of throat, subsequent encounter*/
,'S1012XS'  /*Blister (nonthermal) of throat, sequela*/
,'S1014XD'  /*External constriction of part of throat, subsequent encounter*/
,'S1014XS'  /*External constriction of part of throat, sequela*/
,'S1015XD'  /*Superficial foreign body of throat, subsequent encounter*/
,'S1015XS'  /*Superficial foreign body of throat, sequela*/
,'S1016XD'  /*Insect bite (nonvenomous) of throat, subsequent encounter*/
,'S1016XS'  /*Insect bite (nonvenomous) of throat, sequela*/
,'S1017XD'  /*Other superficial bite of throat, subsequent encounter*/
,'S1017XS'  /*Other superficial bite of throat, sequela*/
,'S1080XD'  /*Unspecified superficial injury of other specified part of neck, subsequent encounter*/
,'S1080XS'  /*Unspecified superficial injury of other specified part of neck, sequela*/
,'S1081XD'  /*Abrasion of other specified part of neck, subsequent encounter*/
,'S1081XS'  /*Abrasion of other specified part of neck, sequela*/
,'S1082XD'  /*Blister (nonthermal) of other specified part of neck, subsequent encounter*/
,'S1082XS'  /*Blister (nonthermal) of other specified part of neck, sequela*/
,'S1083XD'  /*Contusion of other specified part of neck, subsequent encounter*/
,'S1083XS'  /*Contusion of other specified part of neck, sequela*/
,'S1084XD'  /*External constriction of other specified part of neck, subsequent encounter*/
,'S1084XS'  /*External constriction of other specified part of neck, sequela*/
,'S1085XD'  /*Superficial foreign body of other specified part of neck, subsequent encounter*/
,'S1085XS'  /*Superficial foreign body of other specified part of neck, sequela*/
,'S1086XD'  /*Insect bite of other specified part of neck, subsequent encounter*/
,'S1086XS'  /*Insect bite of other specified part of neck, sequela*/
,'S1087XD'  /*Other superficial bite of other specified part of neck, subsequent encounter*/
,'S1087XS'  /*Other superficial bite of other specified part of neck, sequela*/
,'S1090XD'  /*Unspecified superficial injury of unspecified part of neck, subsequent encounter*/
,'S1090XS'  /*Unspecified superficial injury of unspecified part of neck, sequela*/
,'S1091XD'  /*Abrasion of unspecified part of neck, subsequent encounter*/
,'S1091XS'  /*Abrasion of unspecified part of neck, sequela*/
,'S1092XD'  /*Blister (nonthermal) of unspecified part of neck, subsequent encounter*/
,'S1092XS'  /*Blister (nonthermal) of unspecified part of neck, sequela*/
,'S1093XD'  /*Contusion of unspecified part of neck, subsequent encounter*/
,'S1093XS'  /*Contusion of unspecified part of neck, sequela*/
,'S1094XD'  /*External constriction of unspecified part of neck, subsequent encounter*/
,'S1094XS'  /*External constriction of unspecified part of neck, sequela*/
,'S1095XD'  /*Superficial foreign body of unspecified part of neck, subsequent encounter*/
,'S1095XS'  /*Superficial foreign body of unspecified part of neck, sequela*/
,'S1096XD'  /*Insect bite of unspecified part of neck, subsequent encounter*/
,'S1096XS'  /*Insect bite of unspecified part of neck, sequela*/
,'S1097XD'  /*Other superficial bite of unspecified part of neck, subsequent encounter*/
,'S1097XS'  /*Other superficial bite of unspecified part of neck, sequela*/
,'S11011D'  /*Laceration without foreign body of larynx, subsequent encounter*/
,'S11011S'  /*Laceration without foreign body of larynx, sequela*/
,'S11012D'  /*Laceration with foreign body of larynx, subsequent encounter*/
,'S11012S'  /*Laceration with foreign body of larynx, sequela*/
,'S11013D'  /*Puncture wound without foreign body of larynx, subsequent encounter*/
,'S11013S'  /*Puncture wound without foreign body of larynx, sequela*/
,'S11014D'  /*Puncture wound with foreign body of larynx, subsequent encounter*/
,'S11014S'  /*Puncture wound with foreign body of larynx, sequela*/
,'S11015D'  /*Open bite of larynx, subsequent encounter*/
,'S11015S'  /*Open bite of larynx, sequela*/
,'S11019D'  /*Unspecified open wound of larynx, subsequent encounter*/
,'S11019S'  /*Unspecified open wound of larynx, sequela*/
,'S11021D'  /*Laceration without foreign body of trachea, subsequent encounter*/
,'S11021S'  /*Laceration without foreign body of trachea, sequela*/
,'S11022D'  /*Laceration with foreign body of trachea, subsequent encounter*/
,'S11022S'  /*Laceration with foreign body of trachea, sequela*/
,'S11023D'  /*Puncture wound without foreign body of trachea, subsequent encounter*/
,'S11023S'  /*Puncture wound without foreign body of trachea, sequela*/
,'S11024D'  /*Puncture wound with foreign body of trachea, subsequent encounter*/
,'S11024S'  /*Puncture wound with foreign body of trachea, sequela*/
,'S11025D'  /*Open bite of trachea, subsequent encounter*/
,'S11025S'  /*Open bite of trachea, sequela*/
,'S11029D'  /*Unspecified open wound of trachea, subsequent encounter*/
,'S11029S'  /*Unspecified open wound of trachea, sequela*/
,'S11031D'  /*Laceration without foreign body of vocal cord, subsequent encounter*/
,'S11031S'  /*Laceration without foreign body of vocal cord, sequela*/
,'S11032D'  /*Laceration with foreign body of vocal cord, subsequent encounter*/
,'S11032S'  /*Laceration with foreign body of vocal cord, sequela*/
,'S11033D'  /*Puncture wound without foreign body of vocal cord, subsequent encounter*/
,'S11033S'  /*Puncture wound without foreign body of vocal cord, sequela*/
,'S11034D'  /*Puncture wound with foreign body of vocal cord, subsequent encounter*/
,'S11034S'  /*Puncture wound with foreign body of vocal cord, sequela*/
,'S11035D'  /*Open bite of vocal cord, subsequent encounter*/
,'S11035S'  /*Open bite of vocal cord, sequela*/
,'S11039D'  /*Unspecified open wound of vocal cord, subsequent encounter*/
,'S11039S'  /*Unspecified open wound of vocal cord, sequela*/
,'S1110XD'  /*Unspecified open wound of thyroid gland, subsequent encounter*/
,'S1110XS'  /*Unspecified open wound of thyroid gland, sequela*/
,'S1111XD'  /*Laceration without foreign body of thyroid gland, subsequent encounter*/
,'S1111XS'  /*Laceration without foreign body of thyroid gland, sequela*/
,'S1112XD'  /*Laceration with foreign body of thyroid gland, subsequent encounter*/
,'S1112XS'  /*Laceration with foreign body of thyroid gland, sequela*/
,'S1113XD'  /*Puncture wound without foreign body of thyroid gland, subsequent encounter*/
,'S1113XS'  /*Puncture wound without foreign body of thyroid gland, sequela*/
,'S1114XD'  /*Puncture wound with foreign body of thyroid gland, subsequent encounter*/
,'S1114XS'  /*Puncture wound with foreign body of thyroid gland, sequela*/
,'S1115XD'  /*Open bite of thyroid gland, subsequent encounter*/
,'S1115XS'  /*Open bite of thyroid gland, sequela*/
,'S1120XD'  /*Unspecified open wound of pharynx and cervical esophagus, subsequent encounter*/
,'S1120XS'  /*Unspecified open wound of pharynx and cervical esophagus, sequela*/
,'S1121XD'  /*Laceration without foreign body of pharynx and cervical esophagus, subsequent encounter*/
,'S1121XS'  /*Laceration without foreign body of pharynx and cervical esophagus, sequela*/
,'S1122XD'  /*Laceration with foreign body of pharynx and cervical esophagus, subsequent encounter*/
,'S1122XS'  /*Laceration with foreign body of pharynx and cervical esophagus, sequela*/
,'S1123XD'  /*Puncture wound without foreign body of pharynx and cervical esophagus, subsequent encounter*/
,'S1123XS'  /*Puncture wound without foreign body of pharynx and cervical esophagus, sequela*/
,'S1124XD'  /*Puncture wound with foreign body of pharynx and cervical esophagus, subsequent encounter*/
,'S1124XS'  /*Puncture wound with foreign body of pharynx and cervical esophagus, sequela*/
,'S1125XD'  /*Open bite of pharynx and cervical esophagus, subsequent encounter*/
,'S1125XS'  /*Open bite of pharynx and cervical esophagus, sequela*/
,'S1180XD'  /*Unspecified open wound of other specified part of neck, subsequent encounter*/
,'S1180XS'  /*Unspecified open wound of other specified part of neck, sequela*/
,'S1181XD'  /*Laceration without foreign body of other specified part of neck, subsequent encounter*/
,'S1181XS'  /*Laceration without foreign body of other specified part of neck, sequela*/
,'S1182XD'  /*Laceration with foreign body of other specified part of neck, subsequent encounter*/
,'S1182XS'  /*Laceration with foreign body of other specified part of neck, sequela*/
,'S1183XD'  /*Puncture wound without foreign body of other specified part of neck, subsequent encounter*/
,'S1183XS'  /*Puncture wound without foreign body of other specified part of neck, sequela*/
,'S1184XD'  /*Puncture wound with foreign body of other specified part of neck, subsequent encounter*/
,'S1184XS'  /*Puncture wound with foreign body of other specified part of neck, sequela*/
,'S1185XD'  /*Open bite of other specified part of neck, subsequent encounter*/
,'S1185XS'  /*Open bite of other specified part of neck, sequela*/
,'S1189XD'  /*Other open wound of other specified part of neck, subsequent encounter*/
,'S1189XS'  /*Other open wound of other specified part of neck, sequela*/
,'S1190XD'  /*Unspecified open wound of unspecified part of neck, subsequent encounter*/
,'S1190XS'  /*Unspecified open wound of unspecified part of neck, sequela*/
,'S1191XD'  /*Laceration without foreign body of unspecified part of neck, subsequent encounter*/
,'S1191XS'  /*Laceration without foreign body of unspecified part of neck, sequela*/
,'S1192XD'  /*Laceration with foreign body of unspecified part of neck, subsequent encounter*/
,'S1192XS'  /*Laceration with foreign body of unspecified part of neck, sequela*/
,'S1193XD'  /*Puncture wound without foreign body of unspecified part of neck, subsequent encounter*/
,'S1193XS'  /*Puncture wound without foreign body of unspecified part of neck, sequela*/
,'S1194XD'  /*Puncture wound with foreign body of unspecified part of neck, subsequent encounter*/
,'S1194XS'  /*Puncture wound with foreign body of unspecified part of neck, sequela*/
,'S1195XD'  /*Open bite of unspecified part of neck, subsequent encounter*/
,'S1195XS'  /*Open bite of unspecified part of neck, sequela*/
,'S12000D'  /*Unspecified displaced fracture of first cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12000G'  /*Unspecified displaced fracture of first cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12000K'  /*Unspecified displaced fracture of first cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12000S'  /*Unspecified displaced fracture of first cervical vertebra, sequela*/
,'S12001D'  /*Unspecified nondisplaced fracture of first cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12001G'  /*Unspecified nondisplaced fracture of first cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12001K'  /*Unspecified nondisplaced fracture of first cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12001S'  /*Unspecified nondisplaced fracture of first cervical vertebra, sequela*/
,'S1201XD'  /*Stable burst fracture of first cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S1201XG'  /*Stable burst fracture of first cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S1201XK'  /*Stable burst fracture of first cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S1201XS'  /*Stable burst fracture of first cervical vertebra, sequela*/
,'S1202XD'  /*Unstable burst fracture of first cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S1202XG'  /*Unstable burst fracture of first cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S1202XK'  /*Unstable burst fracture of first cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S1202XS'  /*Unstable burst fracture of first cervical vertebra, sequela*/
,'S12030D'  /*Displaced posterior arch fracture of first cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12030G'  /*Displaced posterior arch fracture of first cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12030K'  /*Displaced posterior arch fracture of first cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12030S'  /*Displaced posterior arch fracture of first cervical vertebra, sequela*/
,'S12031D'  /*Nondisplaced posterior arch fracture of first cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12031G'  /*Nondisplaced posterior arch fracture of first cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12031K'  /*Nondisplaced posterior arch fracture of first cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12031S'  /*Nondisplaced posterior arch fracture of first cervical vertebra, sequela*/
,'S12040D'  /*Displaced lateral mass fracture of first cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12040G'  /*Displaced lateral mass fracture of first cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12040K'  /*Displaced lateral mass fracture of first cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12040S'  /*Displaced lateral mass fracture of first cervical vertebra, sequela*/
,'S12041D'  /*Nondisplaced lateral mass fracture of first cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12041G'  /*Nondisplaced lateral mass fracture of first cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12041K'  /*Nondisplaced lateral mass fracture of first cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12041S'  /*Nondisplaced lateral mass fracture of first cervical vertebra, sequela*/
,'S12090D'  /*Other displaced fracture of first cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12090G'  /*Other displaced fracture of first cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12090K'  /*Other displaced fracture of first cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12090S'  /*Other displaced fracture of first cervical vertebra, sequela*/
,'S12091D'  /*Other nondisplaced fracture of first cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12091G'  /*Other nondisplaced fracture of first cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12091K'  /*Other nondisplaced fracture of first cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12091S'  /*Other nondisplaced fracture of first cervical vertebra, sequela*/
,'S12100D'  /*Unspecified displaced fracture of second cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12100G'  /*Unspecified displaced fracture of second cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12100K'  /*Unspecified displaced fracture of second cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12100S'  /*Unspecified displaced fracture of second cervical vertebra, sequela*/
,'S12101D'  /*Unspecified nondisplaced fracture of second cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12101G'  /*Unspecified nondisplaced fracture of second cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12101K'  /*Unspecified nondisplaced fracture of second cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12101S'  /*Unspecified nondisplaced fracture of second cervical vertebra, sequela*/
,'S12110D'  /*Anterior displaced Type II dens fracture, subsequent encounter for fracture with routine healing*/
,'S12110G'  /*Anterior displaced Type II dens fracture, subsequent encounter for fracture with delayed healing*/
,'S12110K'  /*Anterior displaced Type II dens fracture, subsequent encounter for fracture with nonunion*/
,'S12110S'  /*Anterior displaced Type II dens fracture, sequela*/
,'S12111D'  /*Posterior displaced Type II dens fracture, subsequent encounter for fracture with routine healing*/
,'S12111G'  /*Posterior displaced Type II dens fracture, subsequent encounter for fracture with delayed healing*/
,'S12111K'  /*Posterior displaced Type II dens fracture, subsequent encounter for fracture with nonunion*/
,'S12111S'  /*Posterior displaced Type II dens fracture, sequela*/
,'S12112D'  /*Nondisplaced Type II dens fracture, subsequent encounter for fracture with routine healing*/
,'S12112G'  /*Nondisplaced Type II dens fracture, subsequent encounter for fracture with delayed healing*/
,'S12112K'  /*Nondisplaced Type II dens fracture, subsequent encounter for fracture with nonunion*/
,'S12112S'  /*Nondisplaced Type II dens fracture, sequela*/
,'S12120D'  /*Other displaced dens fracture, subsequent encounter for fracture with routine healing*/
,'S12120G'  /*Other displaced dens fracture, subsequent encounter for fracture with delayed healing*/
,'S12120K'  /*Other displaced dens fracture, subsequent encounter for fracture with nonunion*/
,'S12120S'  /*Other displaced dens fracture, sequela*/
,'S12121D'  /*Other nondisplaced dens fracture, subsequent encounter for fracture with routine healing*/
,'S12121G'  /*Other nondisplaced dens fracture, subsequent encounter for fracture with delayed healing*/
,'S12121K'  /*Other nondisplaced dens fracture, subsequent encounter for fracture with nonunion*/
,'S12121S'  /*Other nondisplaced dens fracture, sequela*/
,'S12130D'  /*Unspecified traumatic displaced spondylolisthesis of second cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12130G'  /*Unspecified traumatic displaced spondylolisthesis of second cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12130K'  /*Unspecified traumatic displaced spondylolisthesis of second cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12130S'  /*Unspecified traumatic displaced spondylolisthesis of second cervical vertebra, sequela*/
,'S12131D'  /*Unspecified traumatic nondisplaced spondylolisthesis of second cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12131G'  /*Unspecified traumatic nondisplaced spondylolisthesis of second cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12131K'  /*Unspecified traumatic nondisplaced spondylolisthesis of second cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12131S'  /*Unspecified traumatic nondisplaced spondylolisthesis of second cervical vertebra, sequela*/
,'S1214XD'  /*Type III traumatic spondylolisthesis of second cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S1214XG'  /*Type III traumatic spondylolisthesis of second cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S1214XK'  /*Type III traumatic spondylolisthesis of second cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S1214XS'  /*Type III traumatic spondylolisthesis of second cervical vertebra, sequela*/
,'S12150D'  /*Other traumatic displaced spondylolisthesis of second cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12150G'  /*Other traumatic displaced spondylolisthesis of second cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12150K'  /*Other traumatic displaced spondylolisthesis of second cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12150S'  /*Other traumatic displaced spondylolisthesis of second cervical vertebra, sequela*/
,'S12151D'  /*Other traumatic nondisplaced spondylolisthesis of second cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12151G'  /*Other traumatic nondisplaced spondylolisthesis of second cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12151K'  /*Other traumatic nondisplaced spondylolisthesis of second cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12151S'  /*Other traumatic nondisplaced spondylolisthesis of second cervical vertebra, sequela*/
,'S12190D'  /*Other displaced fracture of second cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12190G'  /*Other displaced fracture of second cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12190K'  /*Other displaced fracture of second cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12190S'  /*Other displaced fracture of second cervical vertebra, sequela*/
,'S12191D'  /*Other nondisplaced fracture of second cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12191G'  /*Other nondisplaced fracture of second cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12191K'  /*Other nondisplaced fracture of second cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12191S'  /*Other nondisplaced fracture of second cervical vertebra, sequela*/
,'S12200D'  /*Unspecified displaced fracture of third cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12200G'  /*Unspecified displaced fracture of third cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12200K'  /*Unspecified displaced fracture of third cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12200S'  /*Unspecified displaced fracture of third cervical vertebra, sequela*/
,'S12201D'  /*Unspecified nondisplaced fracture of third cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12201G'  /*Unspecified nondisplaced fracture of third cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12201K'  /*Unspecified nondisplaced fracture of third cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12201S'  /*Unspecified nondisplaced fracture of third cervical vertebra, sequela*/
,'S12230D'  /*Unspecified traumatic displaced spondylolisthesis of third cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12230G'  /*Unspecified traumatic displaced spondylolisthesis of third cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12230K'  /*Unspecified traumatic displaced spondylolisthesis of third cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12230S'  /*Unspecified traumatic displaced spondylolisthesis of third cervical vertebra, sequela*/
,'S12231D'  /*Unspecified traumatic nondisplaced spondylolisthesis of third cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12231G'  /*Unspecified traumatic nondisplaced spondylolisthesis of third cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12231K'  /*Unspecified traumatic nondisplaced spondylolisthesis of third cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12231S'  /*Unspecified traumatic nondisplaced spondylolisthesis of third cervical vertebra, sequela*/
,'S1224XD'  /*Type III traumatic spondylolisthesis of third cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S1224XG'  /*Type III traumatic spondylolisthesis of third cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S1224XK'  /*Type III traumatic spondylolisthesis of third cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S1224XS'  /*Type III traumatic spondylolisthesis of third cervical vertebra, sequela*/
,'S12250D'  /*Other traumatic displaced spondylolisthesis of third cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12250G'  /*Other traumatic displaced spondylolisthesis of third cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12250K'  /*Other traumatic displaced spondylolisthesis of third cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12250S'  /*Other traumatic displaced spondylolisthesis of third cervical vertebra, sequela*/
,'S12251D'  /*Other traumatic nondisplaced spondylolisthesis of third cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12251G'  /*Other traumatic nondisplaced spondylolisthesis of third cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12251K'  /*Other traumatic nondisplaced spondylolisthesis of third cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12251S'  /*Other traumatic nondisplaced spondylolisthesis of third cervical vertebra, sequela*/
,'S12290D'  /*Other displaced fracture of third cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12290G'  /*Other displaced fracture of third cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12290K'  /*Other displaced fracture of third cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12290S'  /*Other displaced fracture of third cervical vertebra, sequela*/
,'S12291D'  /*Other nondisplaced fracture of third cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12291G'  /*Other nondisplaced fracture of third cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12291K'  /*Other nondisplaced fracture of third cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12291S'  /*Other nondisplaced fracture of third cervical vertebra, sequela*/
,'S12300D'  /*Unspecified displaced fracture of fourth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12300G'  /*Unspecified displaced fracture of fourth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12300K'  /*Unspecified displaced fracture of fourth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12300S'  /*Unspecified displaced fracture of fourth cervical vertebra, sequela*/
,'S12301D'  /*Unspecified nondisplaced fracture of fourth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12301G'  /*Unspecified nondisplaced fracture of fourth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12301K'  /*Unspecified nondisplaced fracture of fourth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12301S'  /*Unspecified nondisplaced fracture of fourth cervical vertebra, sequela*/
,'S12330D'  /*Unspecified traumatic displaced spondylolisthesis of fourth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12330G'  /*Unspecified traumatic displaced spondylolisthesis of fourth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12330K'  /*Unspecified traumatic displaced spondylolisthesis of fourth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12330S'  /*Unspecified traumatic displaced spondylolisthesis of fourth cervical vertebra, sequela*/
,'S12331D'  /*Unspecified traumatic nondisplaced spondylolisthesis of fourth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12331G'  /*Unspecified traumatic nondisplaced spondylolisthesis of fourth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12331K'  /*Unspecified traumatic nondisplaced spondylolisthesis of fourth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12331S'  /*Unspecified traumatic nondisplaced spondylolisthesis of fourth cervical vertebra, sequela*/
,'S1234XD'  /*Type III traumatic spondylolisthesis of fourth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S1234XG'  /*Type III traumatic spondylolisthesis of fourth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S1234XK'  /*Type III traumatic spondylolisthesis of fourth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S1234XS'  /*Type III traumatic spondylolisthesis of fourth cervical vertebra, sequela*/
,'S12350D'  /*Other traumatic displaced spondylolisthesis of fourth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12350G'  /*Other traumatic displaced spondylolisthesis of fourth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12350K'  /*Other traumatic displaced spondylolisthesis of fourth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12350S'  /*Other traumatic displaced spondylolisthesis of fourth cervical vertebra, sequela*/
,'S12351D'  /*Other traumatic nondisplaced spondylolisthesis of fourth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12351G'  /*Other traumatic nondisplaced spondylolisthesis of fourth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12351K'  /*Other traumatic nondisplaced spondylolisthesis of fourth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12351S'  /*Other traumatic nondisplaced spondylolisthesis of fourth cervical vertebra, sequela*/
,'S12390D'  /*Other displaced fracture of fourth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12390G'  /*Other displaced fracture of fourth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12390K'  /*Other displaced fracture of fourth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12390S'  /*Other displaced fracture of fourth cervical vertebra, sequela*/
,'S12391D'  /*Other nondisplaced fracture of fourth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12391G'  /*Other nondisplaced fracture of fourth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12391K'  /*Other nondisplaced fracture of fourth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12391S'  /*Other nondisplaced fracture of fourth cervical vertebra, sequela*/
,'S12400D'  /*Unspecified displaced fracture of fifth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12400G'  /*Unspecified displaced fracture of fifth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12400K'  /*Unspecified displaced fracture of fifth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12400S'  /*Unspecified displaced fracture of fifth cervical vertebra, sequela*/
,'S12401D'  /*Unspecified nondisplaced fracture of fifth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12401G'  /*Unspecified nondisplaced fracture of fifth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12401K'  /*Unspecified nondisplaced fracture of fifth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12401S'  /*Unspecified nondisplaced fracture of fifth cervical vertebra, sequela*/
,'S12430D'  /*Unspecified traumatic displaced spondylolisthesis of fifth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12430G'  /*Unspecified traumatic displaced spondylolisthesis of fifth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12430K'  /*Unspecified traumatic displaced spondylolisthesis of fifth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12430S'  /*Unspecified traumatic displaced spondylolisthesis of fifth cervical vertebra, sequela*/
,'S12431D'  /*Unspecified traumatic nondisplaced spondylolisthesis of fifth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12431G'  /*Unspecified traumatic nondisplaced spondylolisthesis of fifth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12431K'  /*Unspecified traumatic nondisplaced spondylolisthesis of fifth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12431S'  /*Unspecified traumatic nondisplaced spondylolisthesis of fifth cervical vertebra, sequela*/
,'S1244XD'  /*Type III traumatic spondylolisthesis of fifth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S1244XG'  /*Type III traumatic spondylolisthesis of fifth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S1244XK'  /*Type III traumatic spondylolisthesis of fifth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S1244XS'  /*Type III traumatic spondylolisthesis of fifth cervical vertebra, sequela*/
,'S12450D'  /*Other traumatic displaced spondylolisthesis of fifth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12450G'  /*Other traumatic displaced spondylolisthesis of fifth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12450K'  /*Other traumatic displaced spondylolisthesis of fifth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12450S'  /*Other traumatic displaced spondylolisthesis of fifth cervical vertebra, sequela*/
,'S12451D'  /*Other traumatic nondisplaced spondylolisthesis of fifth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12451G'  /*Other traumatic nondisplaced spondylolisthesis of fifth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12451K'  /*Other traumatic nondisplaced spondylolisthesis of fifth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12451S'  /*Other traumatic nondisplaced spondylolisthesis of fifth cervical vertebra, sequela*/
,'S12490D'  /*Other displaced fracture of fifth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12490G'  /*Other displaced fracture of fifth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12490K'  /*Other displaced fracture of fifth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12490S'  /*Other displaced fracture of fifth cervical vertebra, sequela*/
,'S12491D'  /*Other nondisplaced fracture of fifth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12491G'  /*Other nondisplaced fracture of fifth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12491K'  /*Other nondisplaced fracture of fifth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12491S'  /*Other nondisplaced fracture of fifth cervical vertebra, sequela*/
,'S12500D'  /*Unspecified displaced fracture of sixth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12500G'  /*Unspecified displaced fracture of sixth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12500K'  /*Unspecified displaced fracture of sixth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12500S'  /*Unspecified displaced fracture of sixth cervical vertebra, sequela*/
,'S12501D'  /*Unspecified nondisplaced fracture of sixth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12501G'  /*Unspecified nondisplaced fracture of sixth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12501K'  /*Unspecified nondisplaced fracture of sixth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12501S'  /*Unspecified nondisplaced fracture of sixth cervical vertebra, sequela*/
,'S12530D'  /*Unspecified traumatic displaced spondylolisthesis of sixth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12530G'  /*Unspecified traumatic displaced spondylolisthesis of sixth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12530K'  /*Unspecified traumatic displaced spondylolisthesis of sixth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12530S'  /*Unspecified traumatic displaced spondylolisthesis of sixth cervical vertebra, sequela*/
,'S12531D'  /*Unspecified traumatic nondisplaced spondylolisthesis of sixth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12531G'  /*Unspecified traumatic nondisplaced spondylolisthesis of sixth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12531K'  /*Unspecified traumatic nondisplaced spondylolisthesis of sixth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12531S'  /*Unspecified traumatic nondisplaced spondylolisthesis of sixth cervical vertebra, sequela*/
,'S1254XD'  /*Type III traumatic spondylolisthesis of sixth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S1254XG'  /*Type III traumatic spondylolisthesis of sixth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S1254XK'  /*Type III traumatic spondylolisthesis of sixth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S1254XS'  /*Type III traumatic spondylolisthesis of sixth cervical vertebra, sequela*/
,'S12550D'  /*Other traumatic displaced spondylolisthesis of sixth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12550G'  /*Other traumatic displaced spondylolisthesis of sixth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12550K'  /*Other traumatic displaced spondylolisthesis of sixth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12550S'  /*Other traumatic displaced spondylolisthesis of sixth cervical vertebra, sequela*/
,'S12551D'  /*Other traumatic nondisplaced spondylolisthesis of sixth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12551G'  /*Other traumatic nondisplaced spondylolisthesis of sixth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12551K'  /*Other traumatic nondisplaced spondylolisthesis of sixth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12551S'  /*Other traumatic nondisplaced spondylolisthesis of sixth cervical vertebra, sequela*/
,'S12590D'  /*Other displaced fracture of sixth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12590G'  /*Other displaced fracture of sixth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12590K'  /*Other displaced fracture of sixth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12590S'  /*Other displaced fracture of sixth cervical vertebra, sequela*/
,'S12591D'  /*Other nondisplaced fracture of sixth cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12591G'  /*Other nondisplaced fracture of sixth cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12591K'  /*Other nondisplaced fracture of sixth cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12591S'  /*Other nondisplaced fracture of sixth cervical vertebra, sequela*/
,'S12600D'  /*Unspecified displaced fracture of seventh cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12600G'  /*Unspecified displaced fracture of seventh cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12600K'  /*Unspecified displaced fracture of seventh cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12600S'  /*Unspecified displaced fracture of seventh cervical vertebra, sequela*/
,'S12601D'  /*Unspecified nondisplaced fracture of seventh cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12601G'  /*Unspecified nondisplaced fracture of seventh cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12601K'  /*Unspecified nondisplaced fracture of seventh cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12601S'  /*Unspecified nondisplaced fracture of seventh cervical vertebra, sequela*/
,'S12630D'  /*Unspecified traumatic displaced spondylolisthesis of seventh cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12630G'  /*Unspecified traumatic displaced spondylolisthesis of seventh cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12630K'  /*Unspecified traumatic displaced spondylolisthesis of seventh cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12630S'  /*Unspecified traumatic displaced spondylolisthesis of seventh cervical vertebra, sequela*/
,'S12631D'  /*Unspecified traumatic nondisplaced spondylolisthesis of seventh cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12631G'  /*Unspecified traumatic nondisplaced spondylolisthesis of seventh cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12631K'  /*Unspecified traumatic nondisplaced spondylolisthesis of seventh cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12631S'  /*Unspecified traumatic nondisplaced spondylolisthesis of seventh cervical vertebra, sequela*/
,'S1264XD'  /*Type III traumatic spondylolisthesis of seventh cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S1264XG'  /*Type III traumatic spondylolisthesis of seventh cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S1264XK'  /*Type III traumatic spondylolisthesis of seventh cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S1264XS'  /*Type III traumatic spondylolisthesis of seventh cervical vertebra, sequela*/
,'S12650D'  /*Other traumatic displaced spondylolisthesis of seventh cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12650G'  /*Other traumatic displaced spondylolisthesis of seventh cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12650K'  /*Other traumatic displaced spondylolisthesis of seventh cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12650S'  /*Other traumatic displaced spondylolisthesis of seventh cervical vertebra, sequela*/
,'S12651D'  /*Other traumatic nondisplaced spondylolisthesis of seventh cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12651G'  /*Other traumatic nondisplaced spondylolisthesis of seventh cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12651K'  /*Other traumatic nondisplaced spondylolisthesis of seventh cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12651S'  /*Other traumatic nondisplaced spondylolisthesis of seventh cervical vertebra, sequela*/
,'S12690D'  /*Other displaced fracture of seventh cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12690G'  /*Other displaced fracture of seventh cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12690K'  /*Other displaced fracture of seventh cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12690S'  /*Other displaced fracture of seventh cervical vertebra, sequela*/
,'S12691D'  /*Other nondisplaced fracture of seventh cervical vertebra, subsequent encounter for fracture with routine healing*/
,'S12691G'  /*Other nondisplaced fracture of seventh cervical vertebra, subsequent encounter for fracture with delayed healing*/
,'S12691K'  /*Other nondisplaced fracture of seventh cervical vertebra, subsequent encounter for fracture with nonunion*/
,'S12691S'  /*Other nondisplaced fracture of seventh cervical vertebra, sequela*/
,'S128XXD'  /*Fracture of other parts of neck, subsequent encounter*/
,'S128XXS'  /*Fracture of other parts of neck, sequela*/
,'S129XXD'  /*Fracture of neck, unspecified, subsequent encounter*/
,'S129XXS'  /*Fracture of neck, unspecified, sequela*/
,'S130XXD'  /*Traumatic rupture of cervical intervertebral disc, subsequent encounter*/
,'S130XXS'  /*Traumatic rupture of cervical intervertebral disc, sequela*/
,'S13100D'  /*Subluxation of unspecified cervical vertebrae, subsequent encounter*/
,'S13100S'  /*Subluxation of unspecified cervical vertebrae, sequela*/
,'S13101D'  /*Dislocation of unspecified cervical vertebrae, subsequent encounter*/
,'S13101S'  /*Dislocation of unspecified cervical vertebrae, sequela*/
,'S13110D'  /*Subluxation of C0/C1 cervical vertebrae, subsequent encounter*/
,'S13110S'  /*Subluxation of C0/C1 cervical vertebrae, sequela*/
,'S13111D'  /*Dislocation of C0/C1 cervical vertebrae, subsequent encounter*/
,'S13111S'  /*Dislocation of C0/C1 cervical vertebrae, sequela*/
,'S13120D'  /*Subluxation of C1/C2 cervical vertebrae, subsequent encounter*/
,'S13120S'  /*Subluxation of C1/C2 cervical vertebrae, sequela*/
,'S13121D'  /*Dislocation of C1/C2 cervical vertebrae, subsequent encounter*/
,'S13121S'  /*Dislocation of C1/C2 cervical vertebrae, sequela*/
,'S13130D'  /*Subluxation of C2/C3 cervical vertebrae, subsequent encounter*/
,'S13130S'  /*Subluxation of C2/C3 cervical vertebrae, sequela*/
,'S13131D'  /*Dislocation of C2/C3 cervical vertebrae, subsequent encounter*/
,'S13131S'  /*Dislocation of C2/C3 cervical vertebrae, sequela*/
,'S13140D'  /*Subluxation of C3/C4 cervical vertebrae, subsequent encounter*/
,'S13140S'  /*Subluxation of C3/C4 cervical vertebrae, sequela*/
,'S13141D'  /*Dislocation of C3/C4 cervical vertebrae, subsequent encounter*/
,'S13141S'  /*Dislocation of C3/C4 cervical vertebrae, sequela*/
,'S13150D'  /*Subluxation of C4/C5 cervical vertebrae, subsequent encounter*/
,'S13150S'  /*Subluxation of C4/C5 cervical vertebrae, sequela*/
,'S13151D'  /*Dislocation of C4/C5 cervical vertebrae, subsequent encounter*/
,'S13151S'  /*Dislocation of C4/C5 cervical vertebrae, sequela*/
,'S13160D'  /*Subluxation of C5/C6 cervical vertebrae, subsequent encounter*/
,'S13160S'  /*Subluxation of C5/C6 cervical vertebrae, sequela*/
,'S13161D'  /*Dislocation of C5/C6 cervical vertebrae, subsequent encounter*/
,'S13161S'  /*Dislocation of C5/C6 cervical vertebrae, sequela*/
,'S13170D'  /*Subluxation of C6/C7 cervical vertebrae, subsequent encounter*/
,'S13170S'  /*Subluxation of C6/C7 cervical vertebrae, sequela*/
,'S13171D'  /*Dislocation of C6/C7 cervical vertebrae, subsequent encounter*/
,'S13171S'  /*Dislocation of C6/C7 cervical vertebrae, sequela*/
,'S13180D'  /*Subluxation of C7/T1 cervical vertebrae, subsequent encounter*/
,'S13180S'  /*Subluxation of C7/T1 cervical vertebrae, sequela*/
,'S13181D'  /*Dislocation of C7/T1 cervical vertebrae, subsequent encounter*/
,'S13181S'  /*Dislocation of C7/T1 cervical vertebrae, sequela*/
,'S1320XD'  /*Dislocation of unspecified parts of neck, subsequent encounter*/
,'S1320XS'  /*Dislocation of unspecified parts of neck, sequela*/
,'S1329XD'  /*Dislocation of other parts of neck, subsequent encounter*/
,'S1329XS'  /*Dislocation of other parts of neck, sequela*/
,'S134XXD'  /*Sprain of ligaments of cervical spine, subsequent encounter*/
,'S134XXS'  /*Sprain of ligaments of cervical spine, sequela*/
,'S135XXD'  /*Sprain of thyroid region, subsequent encounter*/
,'S135XXS'  /*Sprain of thyroid region, sequela*/
,'S138XXD'  /*Sprain of joints and ligaments of other parts of neck, subsequent encounter*/
,'S138XXS'  /*Sprain of joints and ligaments of other parts of neck, sequela*/
,'S139XXD'  /*Sprain of joints and ligaments of unspecified parts of neck, subsequent encounter*/
,'S139XXS'  /*Sprain of joints and ligaments of unspecified parts of neck, sequela*/
,'S140XXD'  /*Concussion and edema of cervical spinal cord, subsequent encounter*/
,'S140XXS'  /*Concussion and edema of cervical spinal cord, sequela*/
,'S14101D'  /*Unspecified injury at C1 level of cervical spinal cord, subsequent encounter*/
,'S14101S'  /*Unspecified injury at C1 level of cervical spinal cord, sequela*/
,'S14102D'  /*Unspecified injury at C2 level of cervical spinal cord, subsequent encounter*/
,'S14102S'  /*Unspecified injury at C2 level of cervical spinal cord, sequela*/
,'S14103D'  /*Unspecified injury at C3 level of cervical spinal cord, subsequent encounter*/
,'S14103S'  /*Unspecified injury at C3 level of cervical spinal cord, sequela*/
,'S14104D'  /*Unspecified injury at C4 level of cervical spinal cord, subsequent encounter*/
,'S14104S'  /*Unspecified injury at C4 level of cervical spinal cord, sequela*/
,'S14105D'  /*Unspecified injury at C5 level of cervical spinal cord, subsequent encounter*/
,'S14105S'  /*Unspecified injury at C5 level of cervical spinal cord, sequela*/
,'S14106D'  /*Unspecified injury at C6 level of cervical spinal cord, subsequent encounter*/
,'S14106S'  /*Unspecified injury at C6 level of cervical spinal cord, sequela*/
,'S14107D'  /*Unspecified injury at C7 level of cervical spinal cord, subsequent encounter*/
,'S14107S'  /*Unspecified injury at C7 level of cervical spinal cord, sequela*/
,'S14108D'  /*Unspecified injury at C8 level of cervical spinal cord, subsequent encounter*/
,'S14108S'  /*Unspecified injury at C8 level of cervical spinal cord, sequela*/
,'S14109D'  /*Unspecified injury at unspecified level of cervical spinal cord, subsequent encounter*/
,'S14109S'  /*Unspecified injury at unspecified level of cervical spinal cord, sequela*/
,'S14111D'  /*Complete lesion at C1 level of cervical spinal cord, subsequent encounter*/
,'S14111S'  /*Complete lesion at C1 level of cervical spinal cord, sequela*/
,'S14112D'  /*Complete lesion at C2 level of cervical spinal cord, subsequent encounter*/
,'S14112S'  /*Complete lesion at C2 level of cervical spinal cord, sequela*/
,'S14113D'  /*Complete lesion at C3 level of cervical spinal cord, subsequent encounter*/
,'S14113S'  /*Complete lesion at C3 level of cervical spinal cord, sequela*/
,'S14114D'  /*Complete lesion at C4 level of cervical spinal cord, subsequent encounter*/
,'S14114S'  /*Complete lesion at C4 level of cervical spinal cord, sequela*/
,'S14115D'  /*Complete lesion at C5 level of cervical spinal cord, subsequent encounter*/
,'S14115S'  /*Complete lesion at C5 level of cervical spinal cord, sequela*/
,'S14116D'  /*Complete lesion at C6 level of cervical spinal cord, subsequent encounter*/
,'S14116S'  /*Complete lesion at C6 level of cervical spinal cord, sequela*/
,'S14117D'  /*Complete lesion at C7 level of cervical spinal cord, subsequent encounter*/
,'S14117S'  /*Complete lesion at C7 level of cervical spinal cord, sequela*/
,'S14118D'  /*Complete lesion at C8 level of cervical spinal cord, subsequent encounter*/
,'S14118S'  /*Complete lesion at C8 level of cervical spinal cord, sequela*/
,'S14119D'  /*Complete lesion at unspecified level of cervical spinal cord, subsequent encounter*/
,'S14119S'  /*Complete lesion at unspecified level of cervical spinal cord, sequela*/
,'S14121D'  /*Central cord syndrome at C1 level of cervical spinal cord, subsequent encounter*/
,'S14121S'  /*Central cord syndrome at C1 level of cervical spinal cord, sequela*/
,'S14122D'  /*Central cord syndrome at C2 level of cervical spinal cord, subsequent encounter*/
,'S14122S'  /*Central cord syndrome at C2 level of cervical spinal cord, sequela*/
,'S14123D'  /*Central cord syndrome at C3 level of cervical spinal cord, subsequent encounter*/
,'S14123S'  /*Central cord syndrome at C3 level of cervical spinal cord, sequela*/
,'S14124D'  /*Central cord syndrome at C4 level of cervical spinal cord, subsequent encounter*/
,'S14124S'  /*Central cord syndrome at C4 level of cervical spinal cord, sequela*/
,'S14125D'  /*Central cord syndrome at C5 level of cervical spinal cord, subsequent encounter*/
,'S14125S'  /*Central cord syndrome at C5 level of cervical spinal cord, sequela*/
,'S14126D'  /*Central cord syndrome at C6 level of cervical spinal cord, subsequent encounter*/
,'S14126S'  /*Central cord syndrome at C6 level of cervical spinal cord, sequela*/
,'S14127D'  /*Central cord syndrome at C7 level of cervical spinal cord, subsequent encounter*/
,'S14127S'  /*Central cord syndrome at C7 level of cervical spinal cord, sequela*/
,'S14128D'  /*Central cord syndrome at C8 level of cervical spinal cord, subsequent encounter*/
,'S14128S'  /*Central cord syndrome at C8 level of cervical spinal cord, sequela*/
,'S14129D'  /*Central cord syndrome at unspecified level of cervical spinal cord, subsequent encounter*/
,'S14129S'  /*Central cord syndrome at unspecified level of cervical spinal cord, sequela*/
,'S14131D'  /*Anterior cord syndrome at C1 level of cervical spinal cord, subsequent encounter*/
,'S14131S'  /*Anterior cord syndrome at C1 level of cervical spinal cord, sequela*/
,'S14132D'  /*Anterior cord syndrome at C2 level of cervical spinal cord, subsequent encounter*/
,'S14132S'  /*Anterior cord syndrome at C2 level of cervical spinal cord, sequela*/
,'S14133D'  /*Anterior cord syndrome at C3 level of cervical spinal cord, subsequent encounter*/
,'S14133S'  /*Anterior cord syndrome at C3 level of cervical spinal cord, sequela*/
,'S14134D'  /*Anterior cord syndrome at C4 level of cervical spinal cord, subsequent encounter*/
,'S14134S'  /*Anterior cord syndrome at C4 level of cervical spinal cord, sequela*/
,'S14135D'  /*Anterior cord syndrome at C5 level of cervical spinal cord, subsequent encounter*/
,'S14135S'  /*Anterior cord syndrome at C5 level of cervical spinal cord, sequela*/
,'S14136D'  /*Anterior cord syndrome at C6 level of cervical spinal cord, subsequent encounter*/
,'S14136S'  /*Anterior cord syndrome at C6 level of cervical spinal cord, sequela*/
,'S14137D'  /*Anterior cord syndrome at C7 level of cervical spinal cord, subsequent encounter*/
,'S14137S'  /*Anterior cord syndrome at C7 level of cervical spinal cord, sequela*/
,'S14138D'  /*Anterior cord syndrome at C8 level of cervical spinal cord, subsequent encounter*/
,'S14138S'  /*Anterior cord syndrome at C8 level of cervical spinal cord, sequela*/
,'S14139D'  /*Anterior cord syndrome at unspecified level of cervical spinal cord, subsequent encounter*/
,'S14139S'  /*Anterior cord syndrome at unspecified level of cervical spinal cord, sequela*/
,'S14141D'  /*Brown-Sequard syndrome at C1 level of cervical spinal cord, subsequent encounter*/
,'S14141S'  /*Brown-Sequard syndrome at C1 level of cervical spinal cord, sequela*/
,'S14142D'  /*Brown-Sequard syndrome at C2 level of cervical spinal cord, subsequent encounter*/
,'S14142S'  /*Brown-Sequard syndrome at C2 level of cervical spinal cord, sequela*/
,'S14143D'  /*Brown-Sequard syndrome at C3 level of cervical spinal cord, subsequent encounter*/
,'S14143S'  /*Brown-Sequard syndrome at C3 level of cervical spinal cord, sequela*/
,'S14144D'  /*Brown-Sequard syndrome at C4 level of cervical spinal cord, subsequent encounter*/
,'S14144S'  /*Brown-Sequard syndrome at C4 level of cervical spinal cord, sequela*/
,'S14145D'  /*Brown-Sequard syndrome at C5 level of cervical spinal cord, subsequent encounter*/
,'S14145S'  /*Brown-Sequard syndrome at C5 level of cervical spinal cord, sequela*/
,'S14146D'  /*Brown-Sequard syndrome at C6 level of cervical spinal cord, subsequent encounter*/
,'S14146S'  /*Brown-Sequard syndrome at C6 level of cervical spinal cord, sequela*/
,'S14147D'  /*Brown-Sequard syndrome at C7 level of cervical spinal cord, subsequent encounter*/
,'S14147S'  /*Brown-Sequard syndrome at C7 level of cervical spinal cord, sequela*/
,'S14148D'  /*Brown-Sequard syndrome at C8 level of cervical spinal cord, subsequent encounter*/
,'S14148S'  /*Brown-Sequard syndrome at C8 level of cervical spinal cord, sequela*/
,'S14149D'  /*Brown-Sequard syndrome at unspecified level of cervical spinal cord, subsequent encounter*/
,'S14149S'  /*Brown-Sequard syndrome at unspecified level of cervical spinal cord, sequela*/
,'S14151D'  /*Other incomplete lesion at C1 level of cervical spinal cord, subsequent encounter*/
,'S14151S'  /*Other incomplete lesion at C1 level of cervical spinal cord, sequela*/
,'S14152D'  /*Other incomplete lesion at C2 level of cervical spinal cord, subsequent encounter*/
,'S14152S'  /*Other incomplete lesion at C2 level of cervical spinal cord, sequela*/
,'S14153D'  /*Other incomplete lesion at C3 level of cervical spinal cord, subsequent encounter*/
,'S14153S'  /*Other incomplete lesion at C3 level of cervical spinal cord, sequela*/
,'S14154D'  /*Other incomplete lesion at C4 level of cervical spinal cord, subsequent encounter*/
,'S14154S'  /*Other incomplete lesion at C4 level of cervical spinal cord, sequela*/
,'S14155D'  /*Other incomplete lesion at C5 level of cervical spinal cord, subsequent encounter*/
,'S14155S'  /*Other incomplete lesion at C5 level of cervical spinal cord, sequela*/
,'S14156D'  /*Other incomplete lesion at C6 level of cervical spinal cord, subsequent encounter*/
,'S14156S'  /*Other incomplete lesion at C6 level of cervical spinal cord, sequela*/
,'S14157D'  /*Other incomplete lesion at C7 level of cervical spinal cord, subsequent encounter*/
,'S14157S'  /*Other incomplete lesion at C7 level of cervical spinal cord, sequela*/
,'S14158D'  /*Other incomplete lesion at C8 level of cervical spinal cord, subsequent encounter*/
,'S14158S'  /*Other incomplete lesion at C8 level of cervical spinal cord, sequela*/
,'S14159D'  /*Other incomplete lesion at unspecified level of cervical spinal cord, subsequent encounter*/
,'S14159S'  /*Other incomplete lesion at unspecified level of cervical spinal cord, sequela*/
,'S142XXD'  /*Injury of nerve root of cervical spine, subsequent encounter*/
,'S142XXS'  /*Injury of nerve root of cervical spine, sequela*/
,'S143XXD'  /*Injury of brachial plexus, subsequent encounter*/
,'S143XXS'  /*Injury of brachial plexus, sequela*/
,'S144XXD'  /*Injury of peripheral nerves of neck, subsequent encounter*/
,'S144XXS'  /*Injury of peripheral nerves of neck, sequela*/
,'S145XXD'  /*Injury of cervical sympathetic nerves, subsequent encounter*/
,'S145XXS'  /*Injury of cervical sympathetic nerves, sequela*/
,'S148XXD'  /*Injury of other specified nerves of neck, subsequent encounter*/
,'S148XXS'  /*Injury of other specified nerves of neck, sequela*/
,'S149XXD'  /*Injury of unspecified nerves of neck, subsequent encounter*/
,'S149XXS'  /*Injury of unspecified nerves of neck, sequela*/
,'S15001D'  /*Unspecified injury of right carotid artery, subsequent encounter*/
,'S15001S'  /*Unspecified injury of right carotid artery, sequela*/
,'S15002D'  /*Unspecified injury of left carotid artery, subsequent encounter*/
,'S15002S'  /*Unspecified injury of left carotid artery, sequela*/
,'S15009D'  /*Unspecified injury of unspecified carotid artery, subsequent encounter*/
,'S15009S'  /*Unspecified injury of unspecified carotid artery, sequela*/
,'S15011D'  /*Minor laceration of right carotid artery, subsequent encounter*/
,'S15011S'  /*Minor laceration of right carotid artery, sequela*/
,'S15012D'  /*Minor laceration of left carotid artery, subsequent encounter*/
,'S15012S'  /*Minor laceration of left carotid artery, sequela*/
,'S15019D'  /*Minor laceration of unspecified carotid artery, subsequent encounter*/
,'S15019S'  /*Minor laceration of unspecified carotid artery, sequela*/
,'S15021D'  /*Major laceration of right carotid artery, subsequent encounter*/
,'S15021S'  /*Major laceration of right carotid artery, sequela*/
,'S15022D'  /*Major laceration of left carotid artery, subsequent encounter*/
,'S15022S'  /*Major laceration of left carotid artery, sequela*/
,'S15029D'  /*Major laceration of unspecified carotid artery, subsequent encounter*/
,'S15029S'  /*Major laceration of unspecified carotid artery, sequela*/
,'S15091D'  /*Other specified injury of right carotid artery, subsequent encounter*/
,'S15091S'  /*Other specified injury of right carotid artery, sequela*/
,'S15092D'  /*Other specified injury of left carotid artery, subsequent encounter*/
,'S15092S'  /*Other specified injury of left carotid artery, sequela*/
,'S15099D'  /*Other specified injury of unspecified carotid artery, subsequent encounter*/
,'S15099S'  /*Other specified injury of unspecified carotid artery, sequela*/
,'S15101D'  /*Unspecified injury of right vertebral artery, subsequent encounter*/
,'S15101S'  /*Unspecified injury of right vertebral artery, sequela*/
,'S15102D'  /*Unspecified injury of left vertebral artery, subsequent encounter*/
,'S15102S'  /*Unspecified injury of left vertebral artery, sequela*/
,'S15109D'  /*Unspecified injury of unspecified vertebral artery, subsequent encounter*/
,'S15109S'  /*Unspecified injury of unspecified vertebral artery, sequela*/
,'S15111D'  /*Minor laceration of right vertebral artery, subsequent encounter*/
,'S15111S'  /*Minor laceration of right vertebral artery, sequela*/
,'S15112D'  /*Minor laceration of left vertebral artery, subsequent encounter*/
,'S15112S'  /*Minor laceration of left vertebral artery, sequela*/
,'S15119D'  /*Minor laceration of unspecified vertebral artery, subsequent encounter*/
,'S15119S'  /*Minor laceration of unspecified vertebral artery, sequela*/
,'S15121D'  /*Major laceration of right vertebral artery, subsequent encounter*/
,'S15121S'  /*Major laceration of right vertebral artery, sequela*/
,'S15122D'  /*Major laceration of left vertebral artery, subsequent encounter*/
,'S15122S'  /*Major laceration of left vertebral artery, sequela*/
,'S15129D'  /*Major laceration of unspecified vertebral artery, subsequent encounter*/
,'S15129S'  /*Major laceration of unspecified vertebral artery, sequela*/
,'S15191D'  /*Other specified injury of right vertebral artery, subsequent encounter*/
,'S15191S'  /*Other specified injury of right vertebral artery, sequela*/
,'S15192D'  /*Other specified injury of left vertebral artery, subsequent encounter*/
,'S15192S'  /*Other specified injury of left vertebral artery, sequela*/
,'S15199D'  /*Other specified injury of unspecified vertebral artery, subsequent encounter*/
,'S15199S'  /*Other specified injury of unspecified vertebral artery, sequela*/
,'S15201D'  /*Unspecified injury of right external jugular vein, subsequent encounter*/
,'S15201S'  /*Unspecified injury of right external jugular vein, sequela*/
,'S15202D'  /*Unspecified injury of left external jugular vein, subsequent encounter*/
,'S15202S'  /*Unspecified injury of left external jugular vein, sequela*/
,'S15209D'  /*Unspecified injury of unspecified external jugular vein, subsequent encounter*/
,'S15209S'  /*Unspecified injury of unspecified external jugular vein, sequela*/
,'S15211D'  /*Minor laceration of right external jugular vein, subsequent encounter*/
,'S15211S'  /*Minor laceration of right external jugular vein, sequela*/
,'S15212D'  /*Minor laceration of left external jugular vein, subsequent encounter*/
,'S15212S'  /*Minor laceration of left external jugular vein, sequela*/
,'S15219D'  /*Minor laceration of unspecified external jugular vein, subsequent encounter*/
,'S15219S'  /*Minor laceration of unspecified external jugular vein, sequela*/
,'S15221D'  /*Major laceration of right external jugular vein, subsequent encounter*/
,'S15221S'  /*Major laceration of right external jugular vein, sequela*/
,'S15222D'  /*Major laceration of left external jugular vein, subsequent encounter*/
,'S15222S'  /*Major laceration of left external jugular vein, sequela*/
,'S15229D'  /*Major laceration of unspecified external jugular vein, subsequent encounter*/
,'S15229S'  /*Major laceration of unspecified external jugular vein, sequela*/
,'S15291D'  /*Other specified injury of right external jugular vein, subsequent encounter*/
,'S15291S'  /*Other specified injury of right external jugular vein, sequela*/
,'S15292D'  /*Other specified injury of left external jugular vein, subsequent encounter*/
,'S15292S'  /*Other specified injury of left external jugular vein, sequela*/
,'S15299D'  /*Other specified injury of unspecified external jugular vein, subsequent encounter*/
,'S15299S'  /*Other specified injury of unspecified external jugular vein, sequela*/
,'S15301D'  /*Unspecified injury of right internal jugular vein, subsequent encounter*/
,'S15301S'  /*Unspecified injury of right internal jugular vein, sequela*/
,'S15302D'  /*Unspecified injury of left internal jugular vein, subsequent encounter*/
,'S15302S'  /*Unspecified injury of left internal jugular vein, sequela*/
,'S15309D'  /*Unspecified injury of unspecified internal jugular vein, subsequent encounter*/
,'S15309S'  /*Unspecified injury of unspecified internal jugular vein, sequela*/
,'S15311D'  /*Minor laceration of right internal jugular vein, subsequent encounter*/
,'S15311S'  /*Minor laceration of right internal jugular vein, sequela*/
,'S15312D'  /*Minor laceration of left internal jugular vein, subsequent encounter*/
,'S15312S'  /*Minor laceration of left internal jugular vein, sequela*/
,'S15319D'  /*Minor laceration of unspecified internal jugular vein, subsequent encounter*/
,'S15319S'  /*Minor laceration of unspecified internal jugular vein, sequela*/
,'S15321D'  /*Major laceration of right internal jugular vein, subsequent encounter*/
,'S15321S'  /*Major laceration of right internal jugular vein, sequela*/
,'S15322D'  /*Major laceration of left internal jugular vein, subsequent encounter*/
,'S15322S'  /*Major laceration of left internal jugular vein, sequela*/
,'S15329D'  /*Major laceration of unspecified internal jugular vein, subsequent encounter*/
,'S15329S'  /*Major laceration of unspecified internal jugular vein, sequela*/
,'S15391D'  /*Other specified injury of right internal jugular vein, subsequent encounter*/
,'S15391S'  /*Other specified injury of right internal jugular vein, sequela*/
,'S15392D'  /*Other specified injury of left internal jugular vein, subsequent encounter*/
,'S15392S'  /*Other specified injury of left internal jugular vein, sequela*/
,'S15399D'  /*Other specified injury of unspecified internal jugular vein, subsequent encounter*/
,'S15399S'  /*Other specified injury of unspecified internal jugular vein, sequela*/
,'S158XXD'  /*Injury of other specified blood vessels at neck level, subsequent encounter*/
,'S158XXS'  /*Injury of other specified blood vessels at neck level, sequela*/
,'S159XXD'  /*Injury of unspecified blood vessel at neck level, subsequent encounter*/
,'S159XXS'  /*Injury of unspecified blood vessel at neck level, sequela*/
,'S161XXD'  /*Strain of muscle, fascia and tendon at neck level, subsequent encounter*/
,'S161XXS'  /*Strain of muscle, fascia and tendon at neck level, sequela*/
,'S162XXD'  /*Laceration of muscle, fascia and tendon at neck level, subsequent encounter*/
,'S162XXS'  /*Laceration of muscle, fascia and tendon at neck level, sequela*/
,'S168XXD'  /*Other specified injury of muscle, fascia and tendon at neck level, subsequent encounter*/
,'S168XXS'  /*Other specified injury of muscle, fascia and tendon at neck level, sequela*/
,'S169XXD'  /*Unspecified injury of muscle, fascia and tendon at neck level, subsequent encounter*/
,'S169XXS'  /*Unspecified injury of muscle, fascia and tendon at neck level, sequela*/
,'S170XXD'  /*Crushing injury of larynx and trachea, subsequent encounter*/
,'S170XXS'  /*Crushing injury of larynx and trachea, sequela*/
,'S178XXD'  /*Crushing injury of other specified parts of neck, subsequent encounter*/
,'S178XXS'  /*Crushing injury of other specified parts of neck, sequela*/
,'S179XXD'  /*Crushing injury of neck, part unspecified, subsequent encounter*/
,'S179XXS'  /*Crushing injury of neck, part unspecified, sequela*/
,'S1980XD'  /*Other specified injuries of unspecified part of neck, subsequent encounter*/
,'S1980XS'  /*Other specified injuries of unspecified part of neck, sequela*/
,'S1981XD'  /*Other specified injuries of larynx, subsequent encounter*/
,'S1981XS'  /*Other specified injuries of larynx, sequela*/
,'S1982XD'  /*Other specified injuries of cervical trachea, subsequent encounter*/
,'S1982XS'  /*Other specified injuries of cervical trachea, sequela*/
,'S1983XD'  /*Other specified injuries of vocal cord, subsequent encounter*/
,'S1983XS'  /*Other specified injuries of vocal cord, sequela*/
,'S1984XD'  /*Other specified injuries of thyroid gland, subsequent encounter*/
,'S1984XS'  /*Other specified injuries of thyroid gland, sequela*/
,'S1985XD'  /*Other specified injuries of pharynx and cervical esophagus, subsequent encounter*/
,'S1985XS'  /*Other specified injuries of pharynx and cervical esophagus, sequela*/
,'S1989XD'  /*Other specified injuries of other specified part of neck, subsequent encounter*/
,'S1989XS'  /*Other specified injuries of other specified part of neck, sequela*/
,'S199XXD'  /*Unspecified injury of neck, subsequent encounter*/
,'S199XXS'  /*Unspecified injury of neck, sequela*/
,'S2000XD'  /*Contusion of breast, unspecified breast, subsequent encounter*/
,'S2000XS'  /*Contusion of breast, unspecified breast, sequela*/
,'S2001XD'  /*Contusion of right breast, subsequent encounter*/
,'S2001XS'  /*Contusion of right breast, sequela*/
,'S2002XD'  /*Contusion of left breast, subsequent encounter*/
,'S2002XS'  /*Contusion of left breast, sequela*/
,'S20101D'  /*Unspecified superficial injuries of breast, right breast, subsequent encounter*/
,'S20101S'  /*Unspecified superficial injuries of breast, right breast, sequela*/
,'S20102D'  /*Unspecified superficial injuries of breast, left breast, subsequent encounter*/
,'S20102S'  /*Unspecified superficial injuries of breast, left breast, sequela*/
,'S20109D'  /*Unspecified superficial injuries of breast, unspecified breast, subsequent encounter*/
,'S20109S'  /*Unspecified superficial injuries of breast, unspecified breast, sequela*/
,'S20111D'  /*Abrasion of breast, right breast, subsequent encounter*/
,'S20111S'  /*Abrasion of breast, right breast, sequela*/
,'S20112D'  /*Abrasion of breast, left breast, subsequent encounter*/
,'S20112S'  /*Abrasion of breast, left breast, sequela*/
,'S20119D'  /*Abrasion of breast, unspecified breast, subsequent encounter*/
,'S20119S'  /*Abrasion of breast, unspecified breast, sequela*/
,'S20121D'  /*Blister (nonthermal) of breast, right breast, subsequent encounter*/
,'S20121S'  /*Blister (nonthermal) of breast, right breast, sequela*/
,'S20122D'  /*Blister (nonthermal) of breast, left breast, subsequent encounter*/
,'S20122S'  /*Blister (nonthermal) of breast, left breast, sequela*/
,'S20129D'  /*Blister (nonthermal) of breast, unspecified breast, subsequent encounter*/
,'S20129S'  /*Blister (nonthermal) of breast, unspecified breast, sequela*/
,'S20141D'  /*External constriction of part of breast, right breast, subsequent encounter*/
,'S20141S'  /*External constriction of part of breast, right breast, sequela*/
,'S20142D'  /*External constriction of part of breast, left breast, subsequent encounter*/
,'S20142S'  /*External constriction of part of breast, left breast, sequela*/
,'S20149D'  /*External constriction of part of breast, unspecified breast, subsequent encounter*/
,'S20149S'  /*External constriction of part of breast, unspecified breast, sequela*/
,'S20151D'  /*Superficial foreign body of breast, right breast, subsequent encounter*/
,'S20151S'  /*Superficial foreign body of breast, right breast, sequela*/
,'S20152D'  /*Superficial foreign body of breast, left breast, subsequent encounter*/
,'S20152S'  /*Superficial foreign body of breast, left breast, sequela*/
,'S20159D'  /*Superficial foreign body of breast, unspecified breast, subsequent encounter*/
,'S20159S'  /*Superficial foreign body of breast, unspecified breast, sequela*/
,'S20161D'  /*Insect bite (nonvenomous) of breast, right breast, subsequent encounter*/
,'S20161S'  /*Insect bite (nonvenomous) of breast, right breast, sequela*/
,'S20162D'  /*Insect bite (nonvenomous) of breast, left breast, subsequent encounter*/
,'S20162S'  /*Insect bite (nonvenomous) of breast, left breast, sequela*/
,'S20169D'  /*Insect bite (nonvenomous) of breast, unspecified breast, subsequent encounter*/
,'S20169S'  /*Insect bite (nonvenomous) of breast, unspecified breast, sequela*/
,'S20171D'  /*Other superficial bite of breast, right breast, subsequent encounter*/
,'S20171S'  /*Other superficial bite of breast, right breast, sequela*/
,'S20172D'  /*Other superficial bite of breast, left breast, subsequent encounter*/
,'S20172S'  /*Other superficial bite of breast, left breast, sequela*/
,'S20179D'  /*Other superficial bite of breast, unspecified breast, subsequent encounter*/
,'S20179S'  /*Other superficial bite of breast, unspecified breast, sequela*/
,'S2020XD'  /*Contusion of thorax, unspecified, subsequent encounter*/
,'S2020XS'  /*Contusion of thorax, unspecified, sequela*/
,'S20211D'  /*Contusion of right front wall of thorax, subsequent encounter*/
,'S20211S'  /*Contusion of right front wall of thorax, sequela*/
,'S20212D'  /*Contusion of left front wall of thorax, subsequent encounter*/
,'S20212S'  /*Contusion of left front wall of thorax, sequela*/
,'S20219D'  /*Contusion of unspecified front wall of thorax, subsequent encounter*/
,'S20219S'  /*Contusion of unspecified front wall of thorax, sequela*/
,'S20221D'  /*Contusion of right back wall of thorax, subsequent encounter*/
,'S20221S'  /*Contusion of right back wall of thorax, sequela*/
,'S20222D'  /*Contusion of left back wall of thorax, subsequent encounter*/
,'S20222S'  /*Contusion of left back wall of thorax, sequela*/
,'S20229D'  /*Contusion of unspecified back wall of thorax, subsequent encounter*/
,'S20229S'  /*Contusion of unspecified back wall of thorax, sequela*/
,'S20301D'  /*Unspecified superficial injuries of right front wall of thorax, subsequent encounter*/
,'S20301S'  /*Unspecified superficial injuries of right front wall of thorax, sequela*/
,'S20302D'  /*Unspecified superficial injuries of left front wall of thorax, subsequent encounter*/
,'S20302S'  /*Unspecified superficial injuries of left front wall of thorax, sequela*/
,'S20309D'  /*Unspecified superficial injuries of unspecified front wall of thorax, subsequent encounter*/
,'S20309S'  /*Unspecified superficial injuries of unspecified front wall of thorax, sequela*/
,'S20311D'  /*Abrasion of right front wall of thorax, subsequent encounter*/
,'S20311S'  /*Abrasion of right front wall of thorax, sequela*/
,'S20312D'  /*Abrasion of left front wall of thorax, subsequent encounter*/
,'S20312S'  /*Abrasion of left front wall of thorax, sequela*/
,'S20319D'  /*Abrasion of unspecified front wall of thorax, subsequent encounter*/
,'S20319S'  /*Abrasion of unspecified front wall of thorax, sequela*/
,'S20321D'  /*Blister (nonthermal) of right front wall of thorax, subsequent encounter*/
,'S20321S'  /*Blister (nonthermal) of right front wall of thorax, sequela*/
,'S20322D'  /*Blister (nonthermal) of left front wall of thorax, subsequent encounter*/
,'S20322S'  /*Blister (nonthermal) of left front wall of thorax, sequela*/
,'S20329D'  /*Blister (nonthermal) of unspecified front wall of thorax, subsequent encounter*/
,'S20329S'  /*Blister (nonthermal) of unspecified front wall of thorax, sequela*/
,'S20341D'  /*External constriction of right front wall of thorax, subsequent encounter*/
,'S20341S'  /*External constriction of right front wall of thorax, sequela*/
,'S20342D'  /*External constriction of left front wall of thorax, subsequent encounter*/
,'S20342S'  /*External constriction of left front wall of thorax, sequela*/
,'S20349D'  /*External constriction of unspecified front wall of thorax, subsequent encounter*/
,'S20349S'  /*External constriction of unspecified front wall of thorax, sequela*/
,'S20351D'  /*Superficial foreign body of right front wall of thorax, subsequent encounter*/
,'S20351S'  /*Superficial foreign body of right front wall of thorax, sequela*/
,'S20352D'  /*Superficial foreign body of left front wall of thorax, subsequent encounter*/
,'S20352S'  /*Superficial foreign body of left front wall of thorax, sequela*/
,'S20359D'  /*Superficial foreign body of unspecified front wall of thorax, subsequent encounter*/
,'S20359S'  /*Superficial foreign body of unspecified front wall of thorax, sequela*/
,'S20361D'  /*Insect bite (nonvenomous) of right front wall of thorax, subsequent encounter*/
,'S20361S'  /*Insect bite (nonvenomous) of right front wall of thorax, sequela*/
,'S20362D'  /*Insect bite (nonvenomous) of left front wall of thorax, subsequent encounter*/
,'S20362S'  /*Insect bite (nonvenomous) of left front wall of thorax, sequela*/
,'S20369D'  /*Insect bite (nonvenomous) of unspecified front wall of thorax, subsequent encounter*/
,'S20369S'  /*Insect bite (nonvenomous) of unspecified front wall of thorax, sequela*/
,'S20371D'  /*Other superficial bite of right front wall of thorax, subsequent encounter*/
,'S20371S'  /*Other superficial bite of right front wall of thorax, sequela*/
,'S20372D'  /*Other superficial bite of left front wall of thorax, subsequent encounter*/
,'S20372S'  /*Other superficial bite of left front wall of thorax, sequela*/
,'S20379D'  /*Other superficial bite of unspecified front wall of thorax, subsequent encounter*/
,'S20379S'  /*Other superficial bite of unspecified front wall of thorax, sequela*/
,'S20401D'  /*Unspecified superficial injuries of right back wall of thorax, subsequent encounter*/
,'S20401S'  /*Unspecified superficial injuries of right back wall of thorax, sequela*/
,'S20402D'  /*Unspecified superficial injuries of left back wall of thorax, subsequent encounter*/
,'S20402S'  /*Unspecified superficial injuries of left back wall of thorax, sequela*/
,'S20409D'  /*Unspecified superficial injuries of unspecified back wall of thorax, subsequent encounter*/
,'S20409S'  /*Unspecified superficial injuries of unspecified back wall of thorax, sequela*/
,'S20411D'  /*Abrasion of right back wall of thorax, subsequent encounter*/
,'S20411S'  /*Abrasion of right back wall of thorax, sequela*/
,'S20412D'  /*Abrasion of left back wall of thorax, subsequent encounter*/
,'S20412S'  /*Abrasion of left back wall of thorax, sequela*/
,'S20419D'  /*Abrasion of unspecified back wall of thorax, subsequent encounter*/
,'S20419S'  /*Abrasion of unspecified back wall of thorax, sequela*/
,'S20421D'  /*Blister (nonthermal) of right back wall of thorax, subsequent encounter*/
,'S20421S'  /*Blister (nonthermal) of right back wall of thorax, sequela*/
,'S20422D'  /*Blister (nonthermal) of left back wall of thorax, subsequent encounter*/
,'S20422S'  /*Blister (nonthermal) of left back wall of thorax, sequela*/
,'S20429D'  /*Blister (nonthermal) of unspecified back wall of thorax, subsequent encounter*/
,'S20429S'  /*Blister (nonthermal) of unspecified back wall of thorax, sequela*/
,'S20441D'  /*External constriction of right back wall of thorax, subsequent encounter*/
,'S20441S'  /*External constriction of right back wall of thorax, sequela*/
,'S20442D'  /*External constriction of left back wall of thorax, subsequent encounter*/
,'S20442S'  /*External constriction of left back wall of thorax, sequela*/
,'S20449D'  /*External constriction of unspecified back wall of thorax, subsequent encounter*/
,'S20449S'  /*External constriction of unspecified back wall of thorax, sequela*/
,'S20451D'  /*Superficial foreign body of right back wall of thorax, subsequent encounter*/
,'S20451S'  /*Superficial foreign body of right back wall of thorax, sequela*/
,'S20452D'  /*Superficial foreign body of left back wall of thorax, subsequent encounter*/
,'S20452S'  /*Superficial foreign body of left back wall of thorax, sequela*/
,'S20459D'  /*Superficial foreign body of unspecified back wall of thorax, subsequent encounter*/
,'S20459S'  /*Superficial foreign body of unspecified back wall of thorax, sequela*/
,'S20461D'  /*Insect bite (nonvenomous) of right back wall of thorax, subsequent encounter*/
,'S20461S'  /*Insect bite (nonvenomous) of right back wall of thorax, sequela*/
,'S20462D'  /*Insect bite (nonvenomous) of left back wall of thorax, subsequent encounter*/
,'S20462S'  /*Insect bite (nonvenomous) of left back wall of thorax, sequela*/
,'S20469D'  /*Insect bite (nonvenomous) of unspecified back wall of thorax, subsequent encounter*/
,'S20469S'  /*Insect bite (nonvenomous) of unspecified back wall of thorax, sequela*/
,'S20471D'  /*Other superficial bite of right back wall of thorax, subsequent encounter*/
,'S20471S'  /*Other superficial bite of right back wall of thorax, sequela*/
,'S20472D'  /*Other superficial bite of left back wall of thorax, subsequent encounter*/
,'S20472S'  /*Other superficial bite of left back wall of thorax, sequela*/
,'S20479D'  /*Other superficial bite of unspecified back wall of thorax, subsequent encounter*/
,'S20479S'  /*Other superficial bite of unspecified back wall of thorax, sequela*/
,'S2090XD'  /*Unspecified superficial injury of unspecified parts of thorax, subsequent encounter*/
,'S2090XS'  /*Unspecified superficial injury of unspecified parts of thorax, sequela*/
,'S2091XD'  /*Abrasion of unspecified parts of thorax, subsequent encounter*/
,'S2091XS'  /*Abrasion of unspecified parts of thorax, sequela*/
,'S2092XD'  /*Blister (nonthermal) of unspecified parts of thorax, subsequent encounter*/
,'S2092XS'  /*Blister (nonthermal) of unspecified parts of thorax, sequela*/
,'S2094XD'  /*External constriction of unspecified parts of thorax, subsequent encounter*/
,'S2094XS'  /*External constriction of unspecified parts of thorax, sequela*/
,'S2095XD'  /*Superficial foreign body of unspecified parts of thorax, subsequent encounter*/
,'S2095XS'  /*Superficial foreign body of unspecified parts of thorax, sequela*/
,'S2096XD'  /*Insect bite (nonvenomous) of unspecified parts of thorax, subsequent encounter*/
,'S2096XS'  /*Insect bite (nonvenomous) of unspecified parts of thorax, sequela*/
,'S2097XD'  /*Other superficial bite of unspecified parts of thorax, subsequent encounter*/
,'S2097XS'  /*Other superficial bite of unspecified parts of thorax, sequela*/
,'S21001D'  /*Unspecified open wound of right breast, subsequent encounter*/
,'S21001S'  /*Unspecified open wound of right breast, sequela*/
,'S21002D'  /*Unspecified open wound of left breast, subsequent encounter*/
,'S21002S'  /*Unspecified open wound of left breast, sequela*/
,'S21009D'  /*Unspecified open wound of unspecified breast, subsequent encounter*/
,'S21009S'  /*Unspecified open wound of unspecified breast, sequela*/
,'S21011D'  /*Laceration without foreign body of right breast, subsequent encounter*/
,'S21011S'  /*Laceration without foreign body of right breast, sequela*/
,'S21012D'  /*Laceration without foreign body of left breast, subsequent encounter*/
,'S21012S'  /*Laceration without foreign body of left breast, sequela*/
,'S21019D'  /*Laceration without foreign body of unspecified breast, subsequent encounter*/
,'S21019S'  /*Laceration without foreign body of unspecified breast, sequela*/
,'S21021D'  /*Laceration with foreign body of right breast, subsequent encounter*/
,'S21021S'  /*Laceration with foreign body of right breast, sequela*/
,'S21022D'  /*Laceration with foreign body of left breast, subsequent encounter*/
,'S21022S'  /*Laceration with foreign body of left breast, sequela*/
,'S21029D'  /*Laceration with foreign body of unspecified breast, subsequent encounter*/
,'S21029S'  /*Laceration with foreign body of unspecified breast, sequela*/
,'S21031D'  /*Puncture wound without foreign body of right breast, subsequent encounter*/
,'S21031S'  /*Puncture wound without foreign body of right breast, sequela*/
,'S21032D'  /*Puncture wound without foreign body of left breast, subsequent encounter*/
,'S21032S'  /*Puncture wound without foreign body of left breast, sequela*/
,'S21039D'  /*Puncture wound without foreign body of unspecified breast, subsequent encounter*/
,'S21039S'  /*Puncture wound without foreign body of unspecified breast, sequela*/
,'S21041D'  /*Puncture wound with foreign body of right breast, subsequent encounter*/
,'S21041S'  /*Puncture wound with foreign body of right breast, sequela*/
,'S21042D'  /*Puncture wound with foreign body of left breast, subsequent encounter*/
,'S21042S'  /*Puncture wound with foreign body of left breast, sequela*/
,'S21049D'  /*Puncture wound with foreign body of unspecified breast, subsequent encounter*/
,'S21049S'  /*Puncture wound with foreign body of unspecified breast, sequela*/
,'S21051D'  /*Open bite of right breast, subsequent encounter*/
,'S21051S'  /*Open bite of right breast, sequela*/
,'S21052D'  /*Open bite of left breast, subsequent encounter*/
,'S21052S'  /*Open bite of left breast, sequela*/
,'S21059D'  /*Open bite of unspecified breast, subsequent encounter*/
,'S21059S'  /*Open bite of unspecified breast, sequela*/
,'S21101D'  /*Unspecified open wound of right front wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21101S'  /*Unspecified open wound of right front wall of thorax without penetration into thoracic cavity, sequela*/
,'S21102D'  /*Unspecified open wound of left front wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21102S'  /*Unspecified open wound of left front wall of thorax without penetration into thoracic cavity, sequela*/
,'S21109D'  /*Unspecified open wound of unspecified front wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21109S'  /*Unspecified open wound of unspecified front wall of thorax without penetration into thoracic cavity, sequela*/
,'S21111D'  /*Laceration without foreign body of right front wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21111S'  /*Laceration without foreign body of right front wall of thorax without penetration into thoracic cavity, sequela*/
,'S21112D'  /*Laceration without foreign body of left front wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21112S'  /*Laceration without foreign body of left front wall of thorax without penetration into thoracic cavity, sequela*/
,'S21119D'  /*Laceration without foreign body of unspecified front wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21119S'  /*Laceration without foreign body of unspecified front wall of thorax without penetration into thoracic cavity, sequela*/
,'S21121D'  /*Laceration with foreign body of right front wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21121S'  /*Laceration with foreign body of right front wall of thorax without penetration into thoracic cavity, sequela*/
,'S21122D'  /*Laceration with foreign body of left front wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21122S'  /*Laceration with foreign body of left front wall of thorax without penetration into thoracic cavity, sequela*/
,'S21129D'  /*Laceration with foreign body of unspecified front wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21129S'  /*Laceration with foreign body of unspecified front wall of thorax without penetration into thoracic cavity, sequela*/
,'S21131D'  /*Puncture wound without foreign body of right front wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21131S'  /*Puncture wound without foreign body of right front wall of thorax without penetration into thoracic cavity, sequela*/
,'S21132D'  /*Puncture wound without foreign body of left front wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21132S'  /*Puncture wound without foreign body of left front wall of thorax without penetration into thoracic cavity, sequela*/
,'S21139D'  /*Puncture wound without foreign body of unspecified front wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21139S'  /*Puncture wound without foreign body of unspecified front wall of thorax without penetration into thoracic cavity, sequela*/
,'S21141D'  /*Puncture wound with foreign body of right front wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21141S'  /*Puncture wound with foreign body of right front wall of thorax without penetration into thoracic cavity, sequela*/
,'S21142D'  /*Puncture wound with foreign body of left front wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21142S'  /*Puncture wound with foreign body of left front wall of thorax without penetration into thoracic cavity, sequela*/
,'S21149D'  /*Puncture wound with foreign body of unspecified front wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21149S'  /*Puncture wound with foreign body of unspecified front wall of thorax without penetration into thoracic cavity, sequela*/
,'S21151D'  /*Open bite of right front wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21151S'  /*Open bite of right front wall of thorax without penetration into thoracic cavity, sequela*/
,'S21152D'  /*Open bite of left front wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21152S'  /*Open bite of left front wall of thorax without penetration into thoracic cavity, sequela*/
,'S21159D'  /*Open bite of unspecified front wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21159S'  /*Open bite of unspecified front wall of thorax without penetration into thoracic cavity, sequela*/
,'S21201D'  /*Unspecified open wound of right back wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21201S'  /*Unspecified open wound of right back wall of thorax without penetration into thoracic cavity, sequela*/
,'S21202D'  /*Unspecified open wound of left back wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21202S'  /*Unspecified open wound of left back wall of thorax without penetration into thoracic cavity, sequela*/
,'S21209D'  /*Unspecified open wound of unspecified back wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21209S'  /*Unspecified open wound of unspecified back wall of thorax without penetration into thoracic cavity, sequela*/
,'S21211D'  /*Laceration without foreign body of right back wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21211S'  /*Laceration without foreign body of right back wall of thorax without penetration into thoracic cavity, sequela*/
,'S21212D'  /*Laceration without foreign body of left back wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21212S'  /*Laceration without foreign body of left back wall of thorax without penetration into thoracic cavity, sequela*/
,'S21219D'  /*Laceration without foreign body of unspecified back wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21219S'  /*Laceration without foreign body of unspecified back wall of thorax without penetration into thoracic cavity, sequela*/
,'S21221D'  /*Laceration with foreign body of right back wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21221S'  /*Laceration with foreign body of right back wall of thorax without penetration into thoracic cavity, sequela*/
,'S21222D'  /*Laceration with foreign body of left back wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21222S'  /*Laceration with foreign body of left back wall of thorax without penetration into thoracic cavity, sequela*/
,'S21229D'  /*Laceration with foreign body of unspecified back wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21229S'  /*Laceration with foreign body of unspecified back wall of thorax without penetration into thoracic cavity, sequela*/
,'S21231D'  /*Puncture wound without foreign body of right back wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21231S'  /*Puncture wound without foreign body of right back wall of thorax without penetration into thoracic cavity, sequela*/
,'S21232D'  /*Puncture wound without foreign body of left back wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21232S'  /*Puncture wound without foreign body of left back wall of thorax without penetration into thoracic cavity, sequela*/
,'S21239D'  /*Puncture wound without foreign body of unspecified back wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21239S'  /*Puncture wound without foreign body of unspecified back wall of thorax without penetration into thoracic cavity, sequela*/
,'S21241D'  /*Puncture wound with foreign body of right back wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21241S'  /*Puncture wound with foreign body of right back wall of thorax without penetration into thoracic cavity, sequela*/
,'S21242D'  /*Puncture wound with foreign body of left back wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21242S'  /*Puncture wound with foreign body of left back wall of thorax without penetration into thoracic cavity, sequela*/
,'S21249D'  /*Puncture wound with foreign body of unspecified back wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21249S'  /*Puncture wound with foreign body of unspecified back wall of thorax without penetration into thoracic cavity, sequela*/
,'S21251D'  /*Open bite of right back wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21251S'  /*Open bite of right back wall of thorax without penetration into thoracic cavity, sequela*/
,'S21252D'  /*Open bite of left back wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21252S'  /*Open bite of left back wall of thorax without penetration into thoracic cavity, sequela*/
,'S21259D'  /*Open bite of unspecified back wall of thorax without penetration into thoracic cavity, subsequent encounter*/
,'S21259S'  /*Open bite of unspecified back wall of thorax without penetration into thoracic cavity, sequela*/
,'S21301D'  /*Unspecified open wound of right front wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21301S'  /*Unspecified open wound of right front wall of thorax with penetration into thoracic cavity, sequela*/
,'S21302D'  /*Unspecified open wound of left front wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21302S'  /*Unspecified open wound of left front wall of thorax with penetration into thoracic cavity, sequela*/
,'S21309D'  /*Unspecified open wound of unspecified front wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21309S'  /*Unspecified open wound of unspecified front wall of thorax with penetration into thoracic cavity, sequela*/
,'S21311D'  /*Laceration without foreign body of right front wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21311S'  /*Laceration without foreign body of right front wall of thorax with penetration into thoracic cavity, sequela*/
,'S21312D'  /*Laceration without foreign body of left front wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21312S'  /*Laceration without foreign body of left front wall of thorax with penetration into thoracic cavity, sequela*/
,'S21319D'  /*Laceration without foreign body of unspecified front wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21319S'  /*Laceration without foreign body of unspecified front wall of thorax with penetration into thoracic cavity, sequela*/
,'S21321D'  /*Laceration with foreign body of right front wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21321S'  /*Laceration with foreign body of right front wall of thorax with penetration into thoracic cavity, sequela*/
,'S21322D'  /*Laceration with foreign body of left front wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21322S'  /*Laceration with foreign body of left front wall of thorax with penetration into thoracic cavity, sequela*/
,'S21329D'  /*Laceration with foreign body of unspecified front wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21329S'  /*Laceration with foreign body of unspecified front wall of thorax with penetration into thoracic cavity, sequela*/
,'S21331D'  /*Puncture wound without foreign body of right front wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21331S'  /*Puncture wound without foreign body of right front wall of thorax with penetration into thoracic cavity, sequela*/
,'S21332D'  /*Puncture wound without foreign body of left front wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21332S'  /*Puncture wound without foreign body of left front wall of thorax with penetration into thoracic cavity, sequela*/
,'S21339D'  /*Puncture wound without foreign body of unspecified front wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21339S'  /*Puncture wound without foreign body of unspecified front wall of thorax with penetration into thoracic cavity, sequela*/
,'S21341D'  /*Puncture wound with foreign body of right front wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21341S'  /*Puncture wound with foreign body of right front wall of thorax with penetration into thoracic cavity, sequela*/
,'S21342D'  /*Puncture wound with foreign body of left front wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21342S'  /*Puncture wound with foreign body of left front wall of thorax with penetration into thoracic cavity, sequela*/
,'S21349D'  /*Puncture wound with foreign body of unspecified front wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21349S'  /*Puncture wound with foreign body of unspecified front wall of thorax with penetration into thoracic cavity, sequela*/
,'S21351D'  /*Open bite of right front wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21351S'  /*Open bite of right front wall of thorax with penetration into thoracic cavity, sequela*/
,'S21352D'  /*Open bite of left front wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21352S'  /*Open bite of left front wall of thorax with penetration into thoracic cavity, sequela*/
,'S21359D'  /*Open bite of unspecified front wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21359S'  /*Open bite of unspecified front wall of thorax with penetration into thoracic cavity, sequela*/
,'S21401D'  /*Unspecified open wound of right back wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21401S'  /*Unspecified open wound of right back wall of thorax with penetration into thoracic cavity, sequela*/
,'S21402D'  /*Unspecified open wound of left back wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21402S'  /*Unspecified open wound of left back wall of thorax with penetration into thoracic cavity, sequela*/
,'S21409D'  /*Unspecified open wound of unspecified back wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21409S'  /*Unspecified open wound of unspecified back wall of thorax with penetration into thoracic cavity, sequela*/
,'S21411D'  /*Laceration without foreign body of right back wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21411S'  /*Laceration without foreign body of right back wall of thorax with penetration into thoracic cavity, sequela*/
,'S21412D'  /*Laceration without foreign body of left back wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21412S'  /*Laceration without foreign body of left back wall of thorax with penetration into thoracic cavity, sequela*/
,'S21419D'  /*Laceration without foreign body of unspecified back wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21419S'  /*Laceration without foreign body of unspecified back wall of thorax with penetration into thoracic cavity, sequela*/
,'S21421D'  /*Laceration with foreign body of right back wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21421S'  /*Laceration with foreign body of right back wall of thorax with penetration into thoracic cavity, sequela*/
,'S21422D'  /*Laceration with foreign body of left back wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21422S'  /*Laceration with foreign body of left back wall of thorax with penetration into thoracic cavity, sequela*/
,'S21429D'  /*Laceration with foreign body of unspecified back wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21429S'  /*Laceration with foreign body of unspecified back wall of thorax with penetration into thoracic cavity, sequela*/
,'S21431D'  /*Puncture wound without foreign body of right back wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21431S'  /*Puncture wound without foreign body of right back wall of thorax with penetration into thoracic cavity, sequela*/
,'S21432D'  /*Puncture wound without foreign body of left back wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21432S'  /*Puncture wound without foreign body of left back wall of thorax with penetration into thoracic cavity, sequela*/
,'S21439D'  /*Puncture wound without foreign body of unspecified back wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21439S'  /*Puncture wound without foreign body of unspecified back wall of thorax with penetration into thoracic cavity, sequela*/
,'S21441D'  /*Puncture wound with foreign body of right back wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21441S'  /*Puncture wound with foreign body of right back wall of thorax with penetration into thoracic cavity, sequela*/
,'S21442D'  /*Puncture wound with foreign body of left back wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21442S'  /*Puncture wound with foreign body of left back wall of thorax with penetration into thoracic cavity, sequela*/
,'S21449D'  /*Puncture wound with foreign body of unspecified back wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21449S'  /*Puncture wound with foreign body of unspecified back wall of thorax with penetration into thoracic cavity, sequela*/
,'S21451D'  /*Open bite of right back wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21451S'  /*Open bite of right back wall of thorax with penetration into thoracic cavity, sequela*/
,'S21452D'  /*Open bite of left back wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21452S'  /*Open bite of left back wall of thorax with penetration into thoracic cavity, sequela*/
,'S21459D'  /*Open bite of unspecified back wall of thorax with penetration into thoracic cavity, subsequent encounter*/
,'S21459S'  /*Open bite of unspecified back wall of thorax with penetration into thoracic cavity, sequela*/
,'S2190XD'  /*Unspecified open wound of unspecified part of thorax, subsequent encounter*/
,'S2190XS'  /*Unspecified open wound of unspecified part of thorax, sequela*/
,'S2191XD'  /*Laceration without foreign body of unspecified part of thorax, subsequent encounter*/
,'S2191XS'  /*Laceration without foreign body of unspecified part of thorax, sequela*/
,'S2192XD'  /*Laceration with foreign body of unspecified part of thorax, subsequent encounter*/
,'S2192XS'  /*Laceration with foreign body of unspecified part of thorax, sequela*/
,'S2193XD'  /*Puncture wound without foreign body of unspecified part of thorax, subsequent encounter*/
,'S2193XS'  /*Puncture wound without foreign body of unspecified part of thorax, sequela*/
,'S2194XD'  /*Puncture wound with foreign body of unspecified part of thorax, subsequent encounter*/
,'S2194XS'  /*Puncture wound with foreign body of unspecified part of thorax, sequela*/
,'S2195XD'  /*Open bite of unspecified part of thorax, subsequent encounter*/
,'S2195XS'  /*Open bite of unspecified part of thorax, sequela*/
,'S22000D'  /*Wedge compression fracture of unspecified thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22000G'  /*Wedge compression fracture of unspecified thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22000K'  /*Wedge compression fracture of unspecified thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22000S'  /*Wedge compression fracture of unspecified thoracic vertebra, sequela*/
,'S22001D'  /*Stable burst fracture of unspecified thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22001G'  /*Stable burst fracture of unspecified thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22001K'  /*Stable burst fracture of unspecified thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22001S'  /*Stable burst fracture of unspecified thoracic vertebra, sequela*/
,'S22002D'  /*Unstable burst fracture of unspecified thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22002G'  /*Unstable burst fracture of unspecified thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22002K'  /*Unstable burst fracture of unspecified thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22002S'  /*Unstable burst fracture of unspecified thoracic vertebra, sequela*/
,'S22008D'  /*Other fracture of unspecified thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22008G'  /*Other fracture of unspecified thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22008K'  /*Other fracture of unspecified thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22008S'  /*Other fracture of unspecified thoracic vertebra, sequela*/
,'S22009D'  /*Unspecified fracture of unspecified thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22009G'  /*Unspecified fracture of unspecified thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22009K'  /*Unspecified fracture of unspecified thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22009S'  /*Unspecified fracture of unspecified thoracic vertebra, sequela*/
,'S22010D'  /*Wedge compression fracture of first thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22010G'  /*Wedge compression fracture of first thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22010K'  /*Wedge compression fracture of first thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22010S'  /*Wedge compression fracture of first thoracic vertebra, sequela*/
,'S22011D'  /*Stable burst fracture of first thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22011G'  /*Stable burst fracture of first thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22011K'  /*Stable burst fracture of first thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22011S'  /*Stable burst fracture of first thoracic vertebra, sequela*/
,'S22012D'  /*Unstable burst fracture of first thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22012G'  /*Unstable burst fracture of first thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22012K'  /*Unstable burst fracture of first thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22012S'  /*Unstable burst fracture of first thoracic vertebra, sequela*/
,'S22018D'  /*Other fracture of first thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22018G'  /*Other fracture of first thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22018K'  /*Other fracture of first thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22018S'  /*Other fracture of first thoracic vertebra, sequela*/
,'S22019D'  /*Unspecified fracture of first thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22019G'  /*Unspecified fracture of first thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22019K'  /*Unspecified fracture of first thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22019S'  /*Unspecified fracture of first thoracic vertebra, sequela*/
,'S22020D'  /*Wedge compression fracture of second thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22020G'  /*Wedge compression fracture of second thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22020K'  /*Wedge compression fracture of second thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22020S'  /*Wedge compression fracture of second thoracic vertebra, sequela*/
,'S22021D'  /*Stable burst fracture of second thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22021G'  /*Stable burst fracture of second thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22021K'  /*Stable burst fracture of second thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22021S'  /*Stable burst fracture of second thoracic vertebra, sequela*/
,'S22022D'  /*Unstable burst fracture of second thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22022G'  /*Unstable burst fracture of second thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22022K'  /*Unstable burst fracture of second thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22022S'  /*Unstable burst fracture of second thoracic vertebra, sequela*/
,'S22028D'  /*Other fracture of second thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22028G'  /*Other fracture of second thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22028K'  /*Other fracture of second thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22028S'  /*Other fracture of second thoracic vertebra, sequela*/
,'S22029D'  /*Unspecified fracture of second thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22029G'  /*Unspecified fracture of second thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22029K'  /*Unspecified fracture of second thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22029S'  /*Unspecified fracture of second thoracic vertebra, sequela*/
,'S22030D'  /*Wedge compression fracture of third thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22030G'  /*Wedge compression fracture of third thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22030K'  /*Wedge compression fracture of third thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22030S'  /*Wedge compression fracture of third thoracic vertebra, sequela*/
,'S22031D'  /*Stable burst fracture of third thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22031G'  /*Stable burst fracture of third thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22031K'  /*Stable burst fracture of third thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22031S'  /*Stable burst fracture of third thoracic vertebra, sequela*/
,'S22032D'  /*Unstable burst fracture of third thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22032G'  /*Unstable burst fracture of third thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22032K'  /*Unstable burst fracture of third thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22032S'  /*Unstable burst fracture of third thoracic vertebra, sequela*/
,'S22038D'  /*Other fracture of third thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22038G'  /*Other fracture of third thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22038K'  /*Other fracture of third thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22038S'  /*Other fracture of third thoracic vertebra, sequela*/
,'S22039D'  /*Unspecified fracture of third thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22039G'  /*Unspecified fracture of third thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22039K'  /*Unspecified fracture of third thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22039S'  /*Unspecified fracture of third thoracic vertebra, sequela*/
,'S22040D'  /*Wedge compression fracture of fourth thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22040G'  /*Wedge compression fracture of fourth thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22040K'  /*Wedge compression fracture of fourth thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22040S'  /*Wedge compression fracture of fourth thoracic vertebra, sequela*/
,'S22041D'  /*Stable burst fracture of fourth thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22041G'  /*Stable burst fracture of fourth thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22041K'  /*Stable burst fracture of fourth thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22041S'  /*Stable burst fracture of fourth thoracic vertebra, sequela*/
,'S22042D'  /*Unstable burst fracture of fourth thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22042G'  /*Unstable burst fracture of fourth thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22042K'  /*Unstable burst fracture of fourth thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22042S'  /*Unstable burst fracture of fourth thoracic vertebra, sequela*/
,'S22048D'  /*Other fracture of fourth thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22048G'  /*Other fracture of fourth thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22048K'  /*Other fracture of fourth thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22048S'  /*Other fracture of fourth thoracic vertebra, sequela*/
,'S22049D'  /*Unspecified fracture of fourth thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22049G'  /*Unspecified fracture of fourth thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22049K'  /*Unspecified fracture of fourth thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22049S'  /*Unspecified fracture of fourth thoracic vertebra, sequela*/
,'S22050D'  /*Wedge compression fracture of T5-T6 vertebra, subsequent encounter for fracture with routine healing*/
,'S22050G'  /*Wedge compression fracture of T5-T6 vertebra, subsequent encounter for fracture with delayed healing*/
,'S22050K'  /*Wedge compression fracture of T5-T6 vertebra, subsequent encounter for fracture with nonunion*/
,'S22050S'  /*Wedge compression fracture of T5-T6 vertebra, sequela*/
,'S22051D'  /*Stable burst fracture of T5-T6 vertebra, subsequent encounter for fracture with routine healing*/
,'S22051G'  /*Stable burst fracture of T5-T6 vertebra, subsequent encounter for fracture with delayed healing*/
,'S22051K'  /*Stable burst fracture of T5-T6 vertebra, subsequent encounter for fracture with nonunion*/
,'S22051S'  /*Stable burst fracture of T5-T6 vertebra, sequela*/
,'S22052D'  /*Unstable burst fracture of T5-T6 vertebra, subsequent encounter for fracture with routine healing*/
,'S22052G'  /*Unstable burst fracture of T5-T6 vertebra, subsequent encounter for fracture with delayed healing*/
,'S22052K'  /*Unstable burst fracture of T5-T6 vertebra, subsequent encounter for fracture with nonunion*/
,'S22052S'  /*Unstable burst fracture of T5-T6 vertebra, sequela*/
,'S22058D'  /*Other fracture of T5-T6 vertebra, subsequent encounter for fracture with routine healing*/
,'S22058G'  /*Other fracture of T5-T6 vertebra, subsequent encounter for fracture with delayed healing*/
,'S22058K'  /*Other fracture of T5-T6 vertebra, subsequent encounter for fracture with nonunion*/
,'S22058S'  /*Other fracture of T5-T6 vertebra, sequela*/
,'S22059D'  /*Unspecified fracture of T5-T6 vertebra, subsequent encounter for fracture with routine healing*/
,'S22059G'  /*Unspecified fracture of T5-T6 vertebra, subsequent encounter for fracture with delayed healing*/
,'S22059K'  /*Unspecified fracture of T5-T6 vertebra, subsequent encounter for fracture with nonunion*/
,'S22059S'  /*Unspecified fracture of T5-T6 vertebra, sequela*/
,'S22060D'  /*Wedge compression fracture of T7-T8 vertebra, subsequent encounter for fracture with routine healing*/
,'S22060G'  /*Wedge compression fracture of T7-T8 vertebra, subsequent encounter for fracture with delayed healing*/
,'S22060K'  /*Wedge compression fracture of T7-T8 vertebra, subsequent encounter for fracture with nonunion*/
,'S22060S'  /*Wedge compression fracture of T7-T8 vertebra, sequela*/
,'S22061D'  /*Stable burst fracture of T7-T8 vertebra, subsequent encounter for fracture with routine healing*/
,'S22061G'  /*Stable burst fracture of T7-T8 vertebra, subsequent encounter for fracture with delayed healing*/
,'S22061K'  /*Stable burst fracture of T7-T8 vertebra, subsequent encounter for fracture with nonunion*/
,'S22061S'  /*Stable burst fracture of T7-T8 vertebra, sequela*/
,'S22062D'  /*Unstable burst fracture of T7-T8 vertebra, subsequent encounter for fracture with routine healing*/
,'S22062G'  /*Unstable burst fracture of T7-T8 vertebra, subsequent encounter for fracture with delayed healing*/
,'S22062K'  /*Unstable burst fracture of T7-T8 vertebra, subsequent encounter for fracture with nonunion*/
,'S22062S'  /*Unstable burst fracture of T7-T8 vertebra, sequela*/
,'S22068D'  /*Other fracture of T7-T8 thoracic vertebra, subsequent encounter for fracture with routine healing*/
,'S22068G'  /*Other fracture of T7-T8 thoracic vertebra, subsequent encounter for fracture with delayed healing*/
,'S22068K'  /*Other fracture of T7-T8 thoracic vertebra, subsequent encounter for fracture with nonunion*/
,'S22068S'  /*Other fracture of T7-T8 thoracic vertebra, sequela*/
,'S22069D'  /*Unspecified fracture of T7-T8 vertebra, subsequent encounter for fracture with routine healing*/
,'S22069G'  /*Unspecified fracture of T7-T8 vertebra, subsequent encounter for fracture with delayed healing*/
,'S22069K'  /*Unspecified fracture of T7-T8 vertebra, subsequent encounter for fracture with nonunion*/
,'S22069S'  /*Unspecified fracture of T7-T8 vertebra, sequela*/
,'S22070D'  /*Wedge compression fracture of T9-T10 vertebra, subsequent encounter for fracture with routine healing*/
,'S22070G'  /*Wedge compression fracture of T9-T10 vertebra, subsequent encounter for fracture with delayed healing*/
,'S22070K'  /*Wedge compression fracture of T9-T10 vertebra, subsequent encounter for fracture with nonunion*/
,'S22070S'  /*Wedge compression fracture of T9-T10 vertebra, sequela*/
,'S22071D'  /*Stable burst fracture of T9-T10 vertebra, subsequent encounter for fracture with routine healing*/
,'S22071G'  /*Stable burst fracture of T9-T10 vertebra, subsequent encounter for fracture with delayed healing*/
,'S22071K'  /*Stable burst fracture of T9-T10 vertebra, subsequent encounter for fracture with nonunion*/
,'S22071S'  /*Stable burst fracture of T9-T10 vertebra, sequela*/
,'S22072D'  /*Unstable burst fracture of T9-T10 vertebra, subsequent encounter for fracture with routine healing*/
,'S22072G'  /*Unstable burst fracture of T9-T10 vertebra, subsequent encounter for fracture with delayed healing*/
,'S22072K'  /*Unstable burst fracture of T9-T10 vertebra, subsequent encounter for fracture with nonunion*/
,'S22072S'  /*Unstable burst fracture of T9-T10 vertebra, sequela*/
,'S22078D'  /*Other fracture of T9-T10 vertebra, subsequent encounter for fracture with routine healing*/
,'S22078G'  /*Other fracture of T9-T10 vertebra, subsequent encounter for fracture with delayed healing*/
,'S22078K'  /*Other fracture of T9-T10 vertebra, subsequent encounter for fracture with nonunion*/
,'S22078S'  /*Other fracture of T9-T10 vertebra, sequela*/
,'S22079D'  /*Unspecified fracture of T9-T10 vertebra, subsequent encounter for fracture with routine healing*/
,'S22079G'  /*Unspecified fracture of T9-T10 vertebra, subsequent encounter for fracture with delayed healing*/
,'S22079K'  /*Unspecified fracture of T9-T10 vertebra, subsequent encounter for fracture with nonunion*/
,'S22079S'  /*Unspecified fracture of T9-T10 vertebra, sequela*/
,'S22080D'  /*Wedge compression fracture of T11-T12 vertebra, subsequent encounter for fracture with routine healing*/
,'S22080G'  /*Wedge compression fracture of T11-T12 vertebra, subsequent encounter for fracture with delayed healing*/
,'S22080K'  /*Wedge compression fracture of T11-T12 vertebra, subsequent encounter for fracture with nonunion*/
,'S22080S'  /*Wedge compression fracture of T11-T12 vertebra, sequela*/
,'S22081D'  /*Stable burst fracture of T11-T12 vertebra, subsequent encounter for fracture with routine healing*/
,'S22081G'  /*Stable burst fracture of T11-T12 vertebra, subsequent encounter for fracture with delayed healing*/
,'S22081K'  /*Stable burst fracture of T11-T12 vertebra, subsequent encounter for fracture with nonunion*/
,'S22081S'  /*Stable burst fracture of T11-T12 vertebra, sequela*/
,'S22082D'  /*Unstable burst fracture of T11-T12 vertebra, subsequent encounter for fracture with routine healing*/
,'S22082G'  /*Unstable burst fracture of T11-T12 vertebra, subsequent encounter for fracture with delayed healing*/
,'S22082K'  /*Unstable burst fracture of T11-T12 vertebra, subsequent encounter for fracture with nonunion*/
,'S22082S'  /*Unstable burst fracture of T11-T12 vertebra, sequela*/
,'S22088D'  /*Other fracture of T11-T12 vertebra, subsequent encounter for fracture with routine healing*/
,'S22088G'  /*Other fracture of T11-T12 vertebra, subsequent encounter for fracture with delayed healing*/
,'S22088K'  /*Other fracture of T11-T12 vertebra, subsequent encounter for fracture with nonunion*/
,'S22088S'  /*Other fracture of T11-T12 vertebra, sequela*/
,'S22089D'  /*Unspecified fracture of T11-T12 vertebra, subsequent encounter for fracture with routine healing*/
,'S22089G'  /*Unspecified fracture of T11-T12 vertebra, subsequent encounter for fracture with delayed healing*/
,'S22089K'  /*Unspecified fracture of T11-T12 vertebra, subsequent encounter for fracture with nonunion*/
,'S22089S'  /*Unspecified fracture of T11-T12 vertebra, sequela*/
,'S2220XD'  /*Unspecified fracture of sternum, subsequent encounter for fracture with routine healing*/
,'S2220XG'  /*Unspecified fracture of sternum, subsequent encounter for fracture with delayed healing*/
,'S2220XK'  /*Unspecified fracture of sternum, subsequent encounter for fracture with nonunion*/
,'S2220XS'  /*Unspecified fracture of sternum, sequela*/
,'S2221XD'  /*Fracture of manubrium, subsequent encounter for fracture with routine healing*/
,'S2221XG'  /*Fracture of manubrium, subsequent encounter for fracture with delayed healing*/
,'S2221XK'  /*Fracture of manubrium, subsequent encounter for fracture with nonunion*/
,'S2221XS'  /*Fracture of manubrium, sequela*/
,'S2222XD'  /*Fracture of body of sternum, subsequent encounter for fracture with routine healing*/
,'S2222XG'  /*Fracture of body of sternum, subsequent encounter for fracture with delayed healing*/
,'S2222XK'  /*Fracture of body of sternum, subsequent encounter for fracture with nonunion*/
,'S2222XS'  /*Fracture of body of sternum, sequela*/
,'S2223XD'  /*Sternal manubrial dissociation, subsequent encounter for fracture with routine healing*/
,'S2223XG'  /*Sternal manubrial dissociation, subsequent encounter for fracture with delayed healing*/
,'S2223XK'  /*Sternal manubrial dissociation, subsequent encounter for fracture with nonunion*/
,'S2223XS'  /*Sternal manubrial dissociation, sequela*/
,'S2224XD'  /*Fracture of xiphoid process, subsequent encounter for fracture with routine healing*/
,'S2224XG'  /*Fracture of xiphoid process, subsequent encounter for fracture with delayed healing*/
,'S2224XK'  /*Fracture of xiphoid process, subsequent encounter for fracture with nonunion*/
,'S2224XS'  /*Fracture of xiphoid process, sequela*/
,'S2231XD'  /*Fracture of one rib, right side, subsequent encounter for fracture with routine healing*/
,'S2231XG'  /*Fracture of one rib, right side, subsequent encounter for fracture with delayed healing*/
,'S2231XK'  /*Fracture of one rib, right side, subsequent encounter for fracture with nonunion*/
,'S2231XS'  /*Fracture of one rib, right side, sequela*/
,'S2232XD'  /*Fracture of one rib, left side, subsequent encounter for fracture with routine healing*/
,'S2232XG'  /*Fracture of one rib, left side, subsequent encounter for fracture with delayed healing*/
,'S2232XK'  /*Fracture of one rib, left side, subsequent encounter for fracture with nonunion*/
,'S2232XS'  /*Fracture of one rib, left side, sequela*/
,'S2239XD'  /*Fracture of one rib, unspecified side, subsequent encounter for fracture with routine healing*/
,'S2239XG'  /*Fracture of one rib, unspecified side, subsequent encounter for fracture with delayed healing*/
,'S2239XK'  /*Fracture of one rib, unspecified side, subsequent encounter for fracture with nonunion*/
,'S2239XS'  /*Fracture of one rib, unspecified side, sequela*/
,'S2241XD'  /*Multiple fractures of ribs, right side, subsequent encounter for fracture with routine healing*/
,'S2241XG'  /*Multiple fractures of ribs, right side, subsequent encounter for fracture with delayed healing*/
,'S2241XK'  /*Multiple fractures of ribs, right side, subsequent encounter for fracture with nonunion*/
,'S2241XS'  /*Multiple fractures of ribs, right side, sequela*/
,'S2242XD'  /*Multiple fractures of ribs, left side, subsequent encounter for fracture with routine healing*/
,'S2242XG'  /*Multiple fractures of ribs, left side, subsequent encounter for fracture with delayed healing*/
,'S2242XK'  /*Multiple fractures of ribs, left side, subsequent encounter for fracture with nonunion*/
,'S2242XS'  /*Multiple fractures of ribs, left side, sequela*/
,'S2243XD'  /*Multiple fractures of ribs, bilateral, subsequent encounter for fracture with routine healing*/
,'S2243XG'  /*Multiple fractures of ribs, bilateral, subsequent encounter for fracture with delayed healing*/
,'S2243XK'  /*Multiple fractures of ribs, bilateral, subsequent encounter for fracture with nonunion*/
,'S2243XS'  /*Multiple fractures of ribs, bilateral, sequela*/
,'S2249XD'  /*Multiple fractures of ribs, unspecified side, subsequent encounter for fracture with routine healing*/
,'S2249XG'  /*Multiple fractures of ribs, unspecified side, subsequent encounter for fracture with delayed healing*/
,'S2249XK'  /*Multiple fractures of ribs, unspecified side, subsequent encounter for fracture with nonunion*/
,'S2249XS'  /*Multiple fractures of ribs, unspecified side, sequela*/
,'S225XXD'  /*Flail chest, subsequent encounter for fracture with routine healing*/
,'S225XXG'  /*Flail chest, subsequent encounter for fracture with delayed healing*/
,'S225XXK'  /*Flail chest, subsequent encounter for fracture with nonunion*/
,'S225XXS'  /*Flail chest, sequela*/
,'S229XXD'  /*Fracture of bony thorax, part unspecified, subsequent encounter for fracture with routine healing*/
,'S229XXG'  /*Fracture of bony thorax, part unspecified, subsequent encounter for fracture with delayed healing*/
,'S229XXK'  /*Fracture of bony thorax, part unspecified, subsequent encounter for fracture with nonunion*/
,'S229XXS'  /*Fracture of bony thorax, part unspecified, sequela*/
,'S230XXD'  /*Traumatic rupture of thoracic intervertebral disc, subsequent encounter*/
,'S230XXS'  /*Traumatic rupture of thoracic intervertebral disc, sequela*/
,'S23100D'  /*Subluxation of unspecified thoracic vertebra, subsequent encounter*/
,'S23100S'  /*Subluxation of unspecified thoracic vertebra, sequela*/
,'S23101D'  /*Dislocation of unspecified thoracic vertebra, subsequent encounter*/
,'S23101S'  /*Dislocation of unspecified thoracic vertebra, sequela*/
,'S23110D'  /*Subluxation of T1/T2 thoracic vertebra, subsequent encounter*/
,'S23110S'  /*Subluxation of T1/T2 thoracic vertebra, sequela*/
,'S23111D'  /*Dislocation of T1/T2 thoracic vertebra, subsequent encounter*/
,'S23111S'  /*Dislocation of T1/T2 thoracic vertebra, sequela*/
,'S23120D'  /*Subluxation of T2/T3 thoracic vertebra, subsequent encounter*/
,'S23120S'  /*Subluxation of T2/T3 thoracic vertebra, sequela*/
,'S23121D'  /*Dislocation of T2/T3 thoracic vertebra, subsequent encounter*/
,'S23121S'  /*Dislocation of T2/T3 thoracic vertebra, sequela*/
,'S23122D'  /*Subluxation of T3/T4 thoracic vertebra, subsequent encounter*/
,'S23122S'  /*Subluxation of T3/T4 thoracic vertebra, sequela*/
,'S23123D'  /*Dislocation of T3/T4 thoracic vertebra, subsequent encounter*/
,'S23123S'  /*Dislocation of T3/T4 thoracic vertebra, sequela*/
,'S23130D'  /*Subluxation of T4/T5 thoracic vertebra, subsequent encounter*/
,'S23130S'  /*Subluxation of T4/T5 thoracic vertebra, sequela*/
,'S23131D'  /*Dislocation of T4/T5 thoracic vertebra, subsequent encounter*/
,'S23131S'  /*Dislocation of T4/T5 thoracic vertebra, sequela*/
,'S23132D'  /*Subluxation of T5/T6 thoracic vertebra, subsequent encounter*/
,'S23132S'  /*Subluxation of T5/T6 thoracic vertebra, sequela*/
,'S23133D'  /*Dislocation of T5/T6 thoracic vertebra, subsequent encounter*/
,'S23133S'  /*Dislocation of T5/T6 thoracic vertebra, sequela*/
,'S23140D'  /*Subluxation of T6/T7 thoracic vertebra, subsequent encounter*/
,'S23140S'  /*Subluxation of T6/T7 thoracic vertebra, sequela*/
,'S23141D'  /*Dislocation of T6/T7 thoracic vertebra, subsequent encounter*/
,'S23141S'  /*Dislocation of T6/T7 thoracic vertebra, sequela*/
,'S23142D'  /*Subluxation of T7/T8 thoracic vertebra, subsequent encounter*/
,'S23142S'  /*Subluxation of T7/T8 thoracic vertebra, sequela*/
,'S23143D'  /*Dislocation of T7/T8 thoracic vertebra, subsequent encounter*/
,'S23143S'  /*Dislocation of T7/T8 thoracic vertebra, sequela*/
,'S23150D'  /*Subluxation of T8/T9 thoracic vertebra, subsequent encounter*/
,'S23150S'  /*Subluxation of T8/T9 thoracic vertebra, sequela*/
,'S23151D'  /*Dislocation of T8/T9 thoracic vertebra, subsequent encounter*/
,'S23151S'  /*Dislocation of T8/T9 thoracic vertebra, sequela*/
,'S23152D'  /*Subluxation of T9/T10 thoracic vertebra, subsequent encounter*/
,'S23152S'  /*Subluxation of T9/T10 thoracic vertebra, sequela*/
,'S23153D'  /*Dislocation of T9/T10 thoracic vertebra, subsequent encounter*/
,'S23153S'  /*Dislocation of T9/T10 thoracic vertebra, sequela*/
,'S23160D'  /*Subluxation of T10/T11 thoracic vertebra, subsequent encounter*/
,'S23160S'  /*Subluxation of T10/T11 thoracic vertebra, sequela*/
,'S23161D'  /*Dislocation of T10/T11 thoracic vertebra, subsequent encounter*/
,'S23161S'  /*Dislocation of T10/T11 thoracic vertebra, sequela*/
,'S23162D'  /*Subluxation of T11/T12 thoracic vertebra, subsequent encounter*/
,'S23162S'  /*Subluxation of T11/T12 thoracic vertebra, sequela*/
,'S23163D'  /*Dislocation of T11/T12 thoracic vertebra, subsequent encounter*/
,'S23163S'  /*Dislocation of T11/T12 thoracic vertebra, sequela*/
,'S23170D'  /*Subluxation of T12/L1 thoracic vertebra, subsequent encounter*/
,'S23170S'  /*Subluxation of T12/L1 thoracic vertebra, sequela*/
,'S23171D'  /*Dislocation of T12/L1 thoracic vertebra, subsequent encounter*/
,'S23171S'  /*Dislocation of T12/L1 thoracic vertebra, sequela*/
,'S2320XD'  /*Dislocation of unspecified part of thorax, subsequent encounter*/
,'S2320XS'  /*Dislocation of unspecified part of thorax, sequela*/
,'S2329XD'  /*Dislocation of other parts of thorax, subsequent encounter*/
,'S2329XS'  /*Dislocation of other parts of thorax, sequela*/
,'S233XXD'  /*Sprain of ligaments of thoracic spine, subsequent encounter*/
,'S233XXS'  /*Sprain of ligaments of thoracic spine, sequela*/
,'S2341XD'  /*Sprain of ribs, subsequent encounter*/
,'S2341XS'  /*Sprain of ribs, sequela*/
,'S23420D'  /*Sprain of sternoclavicular (joint) (ligament), subsequent encounter*/
,'S23420S'  /*Sprain of sternoclavicular (joint) (ligament), sequela*/
,'S23421D'  /*Sprain of chondrosternal joint, subsequent encounter*/
,'S23421S'  /*Sprain of chondrosternal joint, sequela*/
,'S23428D'  /*Other sprain of sternum, subsequent encounter*/
,'S23428S'  /*Other sprain of sternum, sequela*/
,'S23429D'  /*Unspecified sprain of sternum, subsequent encounter*/
,'S23429S'  /*Unspecified sprain of sternum, sequela*/
,'S238XXD'  /*Sprain of other specified parts of thorax, subsequent encounter*/
,'S238XXS'  /*Sprain of other specified parts of thorax, sequela*/
,'S239XXD'  /*Sprain of unspecified parts of thorax, subsequent encounter*/
,'S239XXS'  /*Sprain of unspecified parts of thorax, sequela*/
,'S240XXD'  /*Concussion and edema of thoracic spinal cord, subsequent encounter*/
,'S240XXS'  /*Concussion and edema of thoracic spinal cord, sequela*/
,'S24101D'  /*Unspecified injury at T1 level of thoracic spinal cord, subsequent encounter*/
,'S24101S'  /*Unspecified injury at T1 level of thoracic spinal cord, sequela*/
,'S24102D'  /*Unspecified injury at T2-T6 level of thoracic spinal cord, subsequent encounter*/
,'S24102S'  /*Unspecified injury at T2-T6 level of thoracic spinal cord, sequela*/
,'S24103D'  /*Unspecified injury at T7-T10 level of thoracic spinal cord, subsequent encounter*/
,'S24103S'  /*Unspecified injury at T7-T10 level of thoracic spinal cord, sequela*/
,'S24104D'  /*Unspecified injury at T11-T12 level of thoracic spinal cord, subsequent encounter*/
,'S24104S'  /*Unspecified injury at T11-T12 level of thoracic spinal cord, sequela*/
,'S24109D'  /*Unspecified injury at unspecified level of thoracic spinal cord, subsequent encounter*/
,'S24109S'  /*Unspecified injury at unspecified level of thoracic spinal cord, sequela*/
,'S24111D'  /*Complete lesion at T1 level of thoracic spinal cord, subsequent encounter*/
,'S24111S'  /*Complete lesion at T1 level of thoracic spinal cord, sequela*/
,'S24112D'  /*Complete lesion at T2-T6 level of thoracic spinal cord, subsequent encounter*/
,'S24112S'  /*Complete lesion at T2-T6 level of thoracic spinal cord, sequela*/
,'S24113D'  /*Complete lesion at T7-T10 level of thoracic spinal cord, subsequent encounter*/
,'S24113S'  /*Complete lesion at T7-T10 level of thoracic spinal cord, sequela*/
,'S24114D'  /*Complete lesion at T11-T12 level of thoracic spinal cord, subsequent encounter*/
,'S24114S'  /*Complete lesion at T11-T12 level of thoracic spinal cord, sequela*/
,'S24119D'  /*Complete lesion at unspecified level of thoracic spinal cord, subsequent encounter*/
,'S24119S'  /*Complete lesion at unspecified level of thoracic spinal cord, sequela*/
,'S24131D'  /*Anterior cord syndrome at T1 level of thoracic spinal cord, subsequent encounter*/
,'S24131S'  /*Anterior cord syndrome at T1 level of thoracic spinal cord, sequela*/
,'S24132D'  /*Anterior cord syndrome at T2-T6 level of thoracic spinal cord, subsequent encounter*/
,'S24132S'  /*Anterior cord syndrome at T2-T6 level of thoracic spinal cord, sequela*/
,'S24133D'  /*Anterior cord syndrome at T7-T10 level of thoracic spinal cord, subsequent encounter*/
,'S24133S'  /*Anterior cord syndrome at T7-T10 level of thoracic spinal cord, sequela*/
,'S24134D'  /*Anterior cord syndrome at T11-T12 level of thoracic spinal cord, subsequent encounter*/
,'S24134S'  /*Anterior cord syndrome at T11-T12 level of thoracic spinal cord, sequela*/
,'S24139D'  /*Anterior cord syndrome at unspecified level of thoracic spinal cord, subsequent encounter*/
,'S24139S'  /*Anterior cord syndrome at unspecified level of thoracic spinal cord, sequela*/
,'S24141D'  /*Brown-Sequard syndrome at T1 level of thoracic spinal cord, subsequent encounter*/
,'S24141S'  /*Brown-Sequard syndrome at T1 level of thoracic spinal cord, sequela*/
,'S24142D'  /*Brown-Sequard syndrome at T2-T6 level of thoracic spinal cord, subsequent encounter*/
,'S24142S'  /*Brown-Sequard syndrome at T2-T6 level of thoracic spinal cord, sequela*/
,'S24143D'  /*Brown-Sequard syndrome at T7-T10 level of thoracic spinal cord, subsequent encounter*/
,'S24143S'  /*Brown-Sequard syndrome at T7-T10 level of thoracic spinal cord, sequela*/
,'S24144D'  /*Brown-Sequard syndrome at T11-T12 level of thoracic spinal cord, subsequent encounter*/
,'S24144S'  /*Brown-Sequard syndrome at T11-T12 level of thoracic spinal cord, sequela*/
,'S24149D'  /*Brown-Sequard syndrome at unspecified level of thoracic spinal cord, subsequent encounter*/
,'S24149S'  /*Brown-Sequard syndrome at unspecified level of thoracic spinal cord, sequela*/
,'S24151D'  /*Other incomplete lesion at T1 level of thoracic spinal cord, subsequent encounter*/
,'S24151S'  /*Other incomplete lesion at T1 level of thoracic spinal cord, sequela*/
,'S24152D'  /*Other incomplete lesion at T2-T6 level of thoracic spinal cord, subsequent encounter*/
,'S24152S'  /*Other incomplete lesion at T2-T6 level of thoracic spinal cord, sequela*/
,'S24153D'  /*Other incomplete lesion at T7-T10 level of thoracic spinal cord, subsequent encounter*/
,'S24153S'  /*Other incomplete lesion at T7-T10 level of thoracic spinal cord, sequela*/
,'S24154D'  /*Other incomplete lesion at T11-T12 level of thoracic spinal cord, subsequent encounter*/
,'S24154S'  /*Other incomplete lesion at T11-T12 level of thoracic spinal cord, sequela*/
,'S24159D'  /*Other incomplete lesion at unspecified level of thoracic spinal cord, subsequent encounter*/
,'S24159S'  /*Other incomplete lesion at unspecified level of thoracic spinal cord, sequela*/
,'S242XXD'  /*Injury of nerve root of thoracic spine, subsequent encounter*/
,'S242XXS'  /*Injury of nerve root of thoracic spine, sequela*/
,'S243XXD'  /*Injury of peripheral nerves of thorax, subsequent encounter*/
,'S243XXS'  /*Injury of peripheral nerves of thorax, sequela*/
,'S244XXD'  /*Injury of thoracic sympathetic nervous system, subsequent encounter*/
,'S244XXS'  /*Injury of thoracic sympathetic nervous system, sequela*/
,'S248XXD'  /*Injury of other specified nerves of thorax, subsequent encounter*/
,'S248XXS'  /*Injury of other specified nerves of thorax, sequela*/
,'S249XXD'  /*Injury of unspecified nerve of thorax, subsequent encounter*/
,'S249XXS'  /*Injury of unspecified nerve of thorax, sequela*/
,'S2500XD'  /*Unspecified injury of thoracic aorta, subsequent encounter*/
,'S2500XS'  /*Unspecified injury of thoracic aorta, sequela*/
,'S2501XD'  /*Minor laceration of thoracic aorta, subsequent encounter*/
,'S2501XS'  /*Minor laceration of thoracic aorta, sequela*/
,'S2502XD'  /*Major laceration of thoracic aorta, subsequent encounter*/
,'S2502XS'  /*Major laceration of thoracic aorta, sequela*/
,'S2509XD'  /*Other specified injury of thoracic aorta, subsequent encounter*/
,'S2509XS'  /*Other specified injury of thoracic aorta, sequela*/
,'S25101D'  /*Unspecified injury of right innominate or subclavian artery, subsequent encounter*/
,'S25101S'  /*Unspecified injury of right innominate or subclavian artery, sequela*/
,'S25102D'  /*Unspecified injury of left innominate or subclavian artery, subsequent encounter*/
,'S25102S'  /*Unspecified injury of left innominate or subclavian artery, sequela*/
,'S25109D'  /*Unspecified injury of unspecified innominate or subclavian artery, subsequent encounter*/
,'S25109S'  /*Unspecified injury of unspecified innominate or subclavian artery, sequela*/
,'S25111D'  /*Minor laceration of right innominate or subclavian artery, subsequent encounter*/
,'S25111S'  /*Minor laceration of right innominate or subclavian artery, sequela*/
,'S25112D'  /*Minor laceration of left innominate or subclavian artery, subsequent encounter*/
,'S25112S'  /*Minor laceration of left innominate or subclavian artery, sequela*/
,'S25119D'  /*Minor laceration of unspecified innominate or subclavian artery, subsequent encounter*/
,'S25119S'  /*Minor laceration of unspecified innominate or subclavian artery, sequela*/
,'S25121D'  /*Major laceration of right innominate or subclavian artery, subsequent encounter*/
,'S25121S'  /*Major laceration of right innominate or subclavian artery, sequela*/
,'S25122D'  /*Major laceration of left innominate or subclavian artery, subsequent encounter*/
,'S25122S'  /*Major laceration of left innominate or subclavian artery, sequela*/
,'S25129D'  /*Major laceration of unspecified innominate or subclavian artery, subsequent encounter*/
,'S25129S'  /*Major laceration of unspecified innominate or subclavian artery, sequela*/
,'S25191D'  /*Other specified injury of right innominate or subclavian artery, subsequent encounter*/
,'S25191S'  /*Other specified injury of right innominate or subclavian artery, sequela*/
,'S25192D'  /*Other specified injury of left innominate or subclavian artery, subsequent encounter*/
,'S25192S'  /*Other specified injury of left innominate or subclavian artery, sequela*/
,'S25199D'  /*Other specified injury of unspecified innominate or subclavian artery, subsequent encounter*/
,'S25199S'  /*Other specified injury of unspecified innominate or subclavian artery, sequela*/
,'S2520XD'  /*Unspecified injury of superior vena cava, subsequent encounter*/
,'S2520XS'  /*Unspecified injury of superior vena cava, sequela*/
,'S2521XD'  /*Minor laceration of superior vena cava, subsequent encounter*/
,'S2521XS'  /*Minor laceration of superior vena cava, sequela*/
,'S2522XD'  /*Major laceration of superior vena cava, subsequent encounter*/
,'S2522XS'  /*Major laceration of superior vena cava, sequela*/
,'S2529XD'  /*Other specified injury of superior vena cava, subsequent encounter*/
,'S2529XS'  /*Other specified injury of superior vena cava, sequela*/
,'S25301D'  /*Unspecified injury of right innominate or subclavian vein, subsequent encounter*/
,'S25301S'  /*Unspecified injury of right innominate or subclavian vein, sequela*/
,'S25302D'  /*Unspecified injury of left innominate or subclavian vein, subsequent encounter*/
,'S25302S'  /*Unspecified injury of left innominate or subclavian vein, sequela*/
,'S25309D'  /*Unspecified injury of unspecified innominate or subclavian vein, subsequent encounter*/
,'S25309S'  /*Unspecified injury of unspecified innominate or subclavian vein, sequela*/
,'S25311D'  /*Minor laceration of right innominate or subclavian vein, subsequent encounter*/
,'S25311S'  /*Minor laceration of right innominate or subclavian vein, sequela*/
,'S25312D'  /*Minor laceration of left innominate or subclavian vein, subsequent encounter*/
,'S25312S'  /*Minor laceration of left innominate or subclavian vein, sequela*/
,'S25319D'  /*Minor laceration of unspecified innominate or subclavian vein, subsequent encounter*/
,'S25319S'  /*Minor laceration of unspecified innominate or subclavian vein, sequela*/
,'S25321D'  /*Major laceration of right innominate or subclavian vein, subsequent encounter*/
,'S25321S'  /*Major laceration of right innominate or subclavian vein, sequela*/
,'S25322D'  /*Major laceration of left innominate or subclavian vein, subsequent encounter*/
,'S25322S'  /*Major laceration of left innominate or subclavian vein, sequela*/
,'S25329D'  /*Major laceration of unspecified innominate or subclavian vein, subsequent encounter*/
,'S25329S'  /*Major laceration of unspecified innominate or subclavian vein, sequela*/
,'S25391D'  /*Other specified injury of right innominate or subclavian vein, subsequent encounter*/
,'S25391S'  /*Other specified injury of right innominate or subclavian vein, sequela*/
,'S25392D'  /*Other specified injury of left innominate or subclavian vein, subsequent encounter*/
,'S25392S'  /*Other specified injury of left innominate or subclavian vein, sequela*/
,'S25399D'  /*Other specified injury of unspecified innominate or subclavian vein, subsequent encounter*/
,'S25399S'  /*Other specified injury of unspecified innominate or subclavian vein, sequela*/
,'S25401D'  /*Unspecified injury of right pulmonary blood vessels, subsequent encounter*/
,'S25401S'  /*Unspecified injury of right pulmonary blood vessels, sequela*/
,'S25402D'  /*Unspecified injury of left pulmonary blood vessels, subsequent encounter*/
,'S25402S'  /*Unspecified injury of left pulmonary blood vessels, sequela*/
,'S25409D'  /*Unspecified injury of unspecified pulmonary blood vessels, subsequent encounter*/
,'S25409S'  /*Unspecified injury of unspecified pulmonary blood vessels, sequela*/
,'S25411D'  /*Minor laceration of right pulmonary blood vessels, subsequent encounter*/
,'S25411S'  /*Minor laceration of right pulmonary blood vessels, sequela*/
,'S25412D'  /*Minor laceration of left pulmonary blood vessels, subsequent encounter*/
,'S25412S'  /*Minor laceration of left pulmonary blood vessels, sequela*/
,'S25419D'  /*Minor laceration of unspecified pulmonary blood vessels, subsequent encounter*/
,'S25419S'  /*Minor laceration of unspecified pulmonary blood vessels, sequela*/
,'S25421D'  /*Major laceration of right pulmonary blood vessels, subsequent encounter*/
,'S25421S'  /*Major laceration of right pulmonary blood vessels, sequela*/
,'S25422D'  /*Major laceration of left pulmonary blood vessels, subsequent encounter*/
,'S25422S'  /*Major laceration of left pulmonary blood vessels, sequela*/
,'S25429D'  /*Major laceration of unspecified pulmonary blood vessels, subsequent encounter*/
,'S25429S'  /*Major laceration of unspecified pulmonary blood vessels, sequela*/
,'S25491D'  /*Other specified injury of right pulmonary blood vessels, subsequent encounter*/
,'S25491S'  /*Other specified injury of right pulmonary blood vessels, sequela*/
,'S25492D'  /*Other specified injury of left pulmonary blood vessels, subsequent encounter*/
,'S25492S'  /*Other specified injury of left pulmonary blood vessels, sequela*/
,'S25499D'  /*Other specified injury of unspecified pulmonary blood vessels, subsequent encounter*/
,'S25499S'  /*Other specified injury of unspecified pulmonary blood vessels, sequela*/
,'S25501D'  /*Unspecified injury of intercostal blood vessels, right side, subsequent encounter*/
,'S25501S'  /*Unspecified injury of intercostal blood vessels, right side, sequela*/
,'S25502D'  /*Unspecified injury of intercostal blood vessels, left side, subsequent encounter*/
,'S25502S'  /*Unspecified injury of intercostal blood vessels, left side, sequela*/
,'S25509D'  /*Unspecified injury of intercostal blood vessels, unspecified side, subsequent encounter*/
,'S25509S'  /*Unspecified injury of intercostal blood vessels, unspecified side, sequela*/
,'S25511D'  /*Laceration of intercostal blood vessels, right side, subsequent encounter*/
,'S25511S'  /*Laceration of intercostal blood vessels, right side, sequela*/
,'S25512D'  /*Laceration of intercostal blood vessels, left side, subsequent encounter*/
,'S25512S'  /*Laceration of intercostal blood vessels, left side, sequela*/
,'S25519D'  /*Laceration of intercostal blood vessels, unspecified side, subsequent encounter*/
,'S25519S'  /*Laceration of intercostal blood vessels, unspecified side, sequela*/
,'S25591D'  /*Other specified injury of intercostal blood vessels, right side, subsequent encounter*/
,'S25591S'  /*Other specified injury of intercostal blood vessels, right side, sequela*/
,'S25592D'  /*Other specified injury of intercostal blood vessels, left side, subsequent encounter*/
,'S25592S'  /*Other specified injury of intercostal blood vessels, left side, sequela*/
,'S25599D'  /*Other specified injury of intercostal blood vessels, unspecified side, subsequent encounter*/
,'S25599S'  /*Other specified injury of intercostal blood vessels, unspecified side, sequela*/
,'S25801D'  /*Unspecified injury of other blood vessels of thorax, right side, subsequent encounter*/
,'S25801S'  /*Unspecified injury of other blood vessels of thorax, right side, sequela*/
,'S25802D'  /*Unspecified injury of other blood vessels of thorax, left side, subsequent encounter*/
,'S25802S'  /*Unspecified injury of other blood vessels of thorax, left side, sequela*/
,'S25809D'  /*Unspecified injury of other blood vessels of thorax, unspecified side, subsequent encounter*/
,'S25809S'  /*Unspecified injury of other blood vessels of thorax, unspecified side, sequela*/
,'S25811D'  /*Laceration of other blood vessels of thorax, right side, subsequent encounter*/
,'S25811S'  /*Laceration of other blood vessels of thorax, right side, sequela*/
,'S25812D'  /*Laceration of other blood vessels of thorax, left side, subsequent encounter*/
,'S25812S'  /*Laceration of other blood vessels of thorax, left side, sequela*/
,'S25819D'  /*Laceration of other blood vessels of thorax, unspecified side, subsequent encounter*/
,'S25819S'  /*Laceration of other blood vessels of thorax, unspecified side, sequela*/
,'S25891D'  /*Other specified injury of other blood vessels of thorax, right side, subsequent encounter*/
,'S25891S'  /*Other specified injury of other blood vessels of thorax, right side, sequela*/
,'S25892D'  /*Other specified injury of other blood vessels of thorax, left side, subsequent encounter*/
,'S25892S'  /*Other specified injury of other blood vessels of thorax, left side, sequela*/
,'S25899D'  /*Other specified injury of other blood vessels of thorax, unspecified side, subsequent encounter*/
,'S25899S'  /*Other specified injury of other blood vessels of thorax, unspecified side, sequela*/
,'S2590XD'  /*Unspecified injury of unspecified blood vessel of thorax, subsequent encounter*/
,'S2590XS'  /*Unspecified injury of unspecified blood vessel of thorax, sequela*/
,'S2591XD'  /*Laceration of unspecified blood vessel of thorax, subsequent encounter*/
,'S2591XS'  /*Laceration of unspecified blood vessel of thorax, sequela*/
,'S2599XD'  /*Other specified injury of unspecified blood vessel of thorax, subsequent encounter*/
,'S2599XS'  /*Other specified injury of unspecified blood vessel of thorax, sequela*/
,'S2600XD'  /*Unspecified injury of heart with hemopericardium, subsequent encounter*/
,'S2600XS'  /*Unspecified injury of heart with hemopericardium, sequela*/
,'S2601XD'  /*Contusion of heart with hemopericardium, subsequent encounter*/
,'S2601XS'  /*Contusion of heart with hemopericardium, sequela*/
,'S26020D'  /*Mild laceration of heart with hemopericardium, subsequent encounter*/
,'S26020S'  /*Mild laceration of heart with hemopericardium, sequela*/
,'S26021D'  /*Moderate laceration of heart with hemopericardium, subsequent encounter*/
,'S26021S'  /*Moderate laceration of heart with hemopericardium, sequela*/
,'S26022D'  /*Major laceration of heart with hemopericardium, subsequent encounter*/
,'S26022S'  /*Major laceration of heart with hemopericardium, sequela*/
,'S2609XD'  /*Other injury of heart with hemopericardium, subsequent encounter*/
,'S2609XS'  /*Other injury of heart with hemopericardium, sequela*/
,'S2610XD'  /*Unspecified injury of heart without hemopericardium, subsequent encounter*/
,'S2610XS'  /*Unspecified injury of heart without hemopericardium, sequela*/
,'S2611XD'  /*Contusion of heart without hemopericardium, subsequent encounter*/
,'S2611XS'  /*Contusion of heart without hemopericardium, sequela*/
,'S2612XD'  /*Laceration of heart without hemopericardium, subsequent encounter*/
,'S2612XS'  /*Laceration of heart without hemopericardium, sequela*/
,'S2619XD'  /*Other injury of heart without hemopericardium, subsequent encounter*/
,'S2619XS'  /*Other injury of heart without hemopericardium, sequela*/
,'S2690XD'  /*Unspecified injury of heart, unspecified with or without hemopericardium, subsequent encounter*/
,'S2690XS'  /*Unspecified injury of heart, unspecified with or without hemopericardium, sequela*/
,'S2691XD'  /*Contusion of heart, unspecified with or without hemopericardium, subsequent encounter*/
,'S2691XS'  /*Contusion of heart, unspecified with or without hemopericardium, sequela*/
,'S2692XD'  /*Laceration of heart, unspecified with or without hemopericardium, subsequent encounter*/
,'S2692XS'  /*Laceration of heart, unspecified with or without hemopericardium, sequela*/
,'S2699XD'  /*Other injury of heart, unspecified with or without hemopericardium, subsequent encounter*/
,'S2699XS'  /*Other injury of heart, unspecified with or without hemopericardium, sequela*/
,'S270XXD'  /*Traumatic pneumothorax, subsequent encounter*/
,'S270XXS'  /*Traumatic pneumothorax, sequela*/
,'S271XXD'  /*Traumatic hemothorax, subsequent encounter*/
,'S271XXS'  /*Traumatic hemothorax, sequela*/
,'S272XXD'  /*Traumatic hemopneumothorax, subsequent encounter*/
,'S272XXS'  /*Traumatic hemopneumothorax, sequela*/
,'S27301D'  /*Unspecified injury of lung, unilateral, subsequent encounter*/
,'S27301S'  /*Unspecified injury of lung, unilateral, sequela*/
,'S27302D'  /*Unspecified injury of lung, bilateral, subsequent encounter*/
,'S27302S'  /*Unspecified injury of lung, bilateral, sequela*/
,'S27309D'  /*Unspecified injury of lung, unspecified, subsequent encounter*/
,'S27309S'  /*Unspecified injury of lung, unspecified, sequela*/
,'S27311D'  /*Primary blast injury of lung, unilateral, subsequent encounter*/
,'S27311S'  /*Primary blast injury of lung, unilateral, sequela*/
,'S27312D'  /*Primary blast injury of lung, bilateral, subsequent encounter*/
,'S27312S'  /*Primary blast injury of lung, bilateral, sequela*/
,'S27319D'  /*Primary blast injury of lung, unspecified, subsequent encounter*/
,'S27319S'  /*Primary blast injury of lung, unspecified, sequela*/
,'S27321D'  /*Contusion of lung, unilateral, subsequent encounter*/
,'S27321S'  /*Contusion of lung, unilateral, sequela*/
,'S27322D'  /*Contusion of lung, bilateral, subsequent encounter*/
,'S27322S'  /*Contusion of lung, bilateral, sequela*/
,'S27329D'  /*Contusion of lung, unspecified, subsequent encounter*/
,'S27329S'  /*Contusion of lung, unspecified, sequela*/
,'S27331D'  /*Laceration of lung, unilateral, subsequent encounter*/
,'S27331S'  /*Laceration of lung, unilateral, sequela*/
,'S27332D'  /*Laceration of lung, bilateral, subsequent encounter*/
,'S27332S'  /*Laceration of lung, bilateral, sequela*/
,'S27339D'  /*Laceration of lung, unspecified, subsequent encounter*/
,'S27339S'  /*Laceration of lung, unspecified, sequela*/
,'S27391D'  /*Other injuries of lung, unilateral, subsequent encounter*/
,'S27391S'  /*Other injuries of lung, unilateral, sequela*/
,'S27392D'  /*Other injuries of lung, bilateral, subsequent encounter*/
,'S27392S'  /*Other injuries of lung, bilateral, sequela*/
,'S27399D'  /*Other injuries of lung, unspecified, subsequent encounter*/
,'S27399S'  /*Other injuries of lung, unspecified, sequela*/
,'S27401D'  /*Unspecified injury of bronchus, unilateral, subsequent encounter*/
,'S27401S'  /*Unspecified injury of bronchus, unilateral, sequela*/
,'S27402D'  /*Unspecified injury of bronchus, bilateral, subsequent encounter*/
,'S27402S'  /*Unspecified injury of bronchus, bilateral, sequela*/
,'S27409D'  /*Unspecified injury of bronchus, unspecified, subsequent encounter*/
,'S27409S'  /*Unspecified injury of bronchus, unspecified, sequela*/
,'S27411D'  /*Primary blast injury of bronchus, unilateral, subsequent encounter*/
,'S27411S'  /*Primary blast injury of bronchus, unilateral, sequela*/
,'S27412D'  /*Primary blast injury of bronchus, bilateral, subsequent encounter*/
,'S27412S'  /*Primary blast injury of bronchus, bilateral, sequela*/
,'S27419D'  /*Primary blast injury of bronchus, unspecified, subsequent encounter*/
,'S27419S'  /*Primary blast injury of bronchus, unspecified, sequela*/
,'S27421D'  /*Contusion of bronchus, unilateral, subsequent encounter*/
,'S27421S'  /*Contusion of bronchus, unilateral, sequela*/
,'S27422D'  /*Contusion of bronchus, bilateral, subsequent encounter*/
,'S27422S'  /*Contusion of bronchus, bilateral, sequela*/
,'S27429D'  /*Contusion of bronchus, unspecified, subsequent encounter*/
,'S27429S'  /*Contusion of bronchus, unspecified, sequela*/
,'S27431D'  /*Laceration of bronchus, unilateral, subsequent encounter*/
,'S27431S'  /*Laceration of bronchus, unilateral, sequela*/
,'S27432D'  /*Laceration of bronchus, bilateral, subsequent encounter*/
,'S27432S'  /*Laceration of bronchus, bilateral, sequela*/
,'S27439D'  /*Laceration of bronchus, unspecified, subsequent encounter*/
,'S27439S'  /*Laceration of bronchus, unspecified, sequela*/
,'S27491D'  /*Other injury of bronchus, unilateral, subsequent encounter*/
,'S27491S'  /*Other injury of bronchus, unilateral, sequela*/
,'S27492D'  /*Other injury of bronchus, bilateral, subsequent encounter*/
,'S27492S'  /*Other injury of bronchus, bilateral, sequela*/
,'S27499D'  /*Other injury of bronchus, unspecified, subsequent encounter*/
,'S27499S'  /*Other injury of bronchus, unspecified, sequela*/
,'S2750XD'  /*Unspecified injury of thoracic trachea, subsequent encounter*/
,'S2750XS'  /*Unspecified injury of thoracic trachea, sequela*/
,'S2751XD'  /*Primary blast injury of thoracic trachea, subsequent encounter*/
,'S2751XS'  /*Primary blast injury of thoracic trachea, sequela*/
,'S2752XD'  /*Contusion of thoracic trachea, subsequent encounter*/
,'S2752XS'  /*Contusion of thoracic trachea, sequela*/
,'S2753XD'  /*Laceration of thoracic trachea, subsequent encounter*/
,'S2753XS'  /*Laceration of thoracic trachea, sequela*/
,'S2759XD'  /*Other injury of thoracic trachea, subsequent encounter*/
,'S2759XS'  /*Other injury of thoracic trachea, sequela*/
,'S2760XD'  /*Unspecified injury of pleura, subsequent encounter*/
,'S2760XS'  /*Unspecified injury of pleura, sequela*/
,'S2763XD'  /*Laceration of pleura, subsequent encounter*/
,'S2763XS'  /*Laceration of pleura, sequela*/
,'S2769XD'  /*Other injury of pleura, subsequent encounter*/
,'S2769XS'  /*Other injury of pleura, sequela*/
,'S27802D'  /*Contusion of diaphragm, subsequent encounter*/
,'S27802S'  /*Contusion of diaphragm, sequela*/
,'S27803D'  /*Laceration of diaphragm, subsequent encounter*/
,'S27803S'  /*Laceration of diaphragm, sequela*/
,'S27808D'  /*Other injury of diaphragm, subsequent encounter*/
,'S27808S'  /*Other injury of diaphragm, sequela*/
,'S27809D'  /*Unspecified injury of diaphragm, subsequent encounter*/
,'S27809S'  /*Unspecified injury of diaphragm, sequela*/
,'S27812D'  /*Contusion of esophagus (thoracic part), subsequent encounter*/
,'S27812S'  /*Contusion of esophagus (thoracic part), sequela*/
,'S27813D'  /*Laceration of esophagus (thoracic part), subsequent encounter*/
,'S27813S'  /*Laceration of esophagus (thoracic part), sequela*/
,'S27818D'  /*Other injury of esophagus (thoracic part), subsequent encounter*/
,'S27818S'  /*Other injury of esophagus (thoracic part), sequela*/
,'S27819D'  /*Unspecified injury of esophagus (thoracic part), subsequent encounter*/
,'S27819S'  /*Unspecified injury of esophagus (thoracic part), sequela*/
,'S27892D'  /*Contusion of other specified intrathoracic organs, subsequent encounter*/
,'S27892S'  /*Contusion of other specified intrathoracic organs, sequela*/
,'S27893D'  /*Laceration of other specified intrathoracic organs, subsequent encounter*/
,'S27893S'  /*Laceration of other specified intrathoracic organs, sequela*/
,'S27898D'  /*Other injury of other specified intrathoracic organs, subsequent encounter*/
,'S27898S'  /*Other injury of other specified intrathoracic organs, sequela*/
,'S27899D'  /*Unspecified injury of other specified intrathoracic organs, subsequent encounter*/
,'S27899S'  /*Unspecified injury of other specified intrathoracic organs, sequela*/
,'S279XXD'  /*Injury of unspecified intrathoracic organ, subsequent encounter*/
,'S279XXS'  /*Injury of unspecified intrathoracic organ, sequela*/
,'S280XXD'  /*Crushed chest, subsequent encounter*/
,'S280XXS'  /*Crushed chest, sequela*/
,'S281XXD'  /*Traumatic amputation (partial) of part of thorax, except breast, subsequent encounter*/
,'S281XXS'  /*Traumatic amputation (partial) of part of thorax, except breast, sequela*/
,'S28211D'  /*Complete traumatic amputation of right breast, subsequent encounter*/
,'S28211S'  /*Complete traumatic amputation of right breast, sequela*/
,'S28212D'  /*Complete traumatic amputation of left breast, subsequent encounter*/
,'S28212S'  /*Complete traumatic amputation of left breast, sequela*/
,'S28219D'  /*Complete traumatic amputation of unspecified breast, subsequent encounter*/
,'S28219S'  /*Complete traumatic amputation of unspecified breast, sequela*/
,'S28221D'  /*Partial traumatic amputation of right breast, subsequent encounter*/
,'S28221S'  /*Partial traumatic amputation of right breast, sequela*/
,'S28222D'  /*Partial traumatic amputation of left breast, subsequent encounter*/
,'S28222S'  /*Partial traumatic amputation of left breast, sequela*/
,'S28229D'  /*Partial traumatic amputation of unspecified breast, subsequent encounter*/
,'S28229S'  /*Partial traumatic amputation of unspecified breast, sequela*/
,'S29001D'  /*Unspecified injury of muscle and tendon of front wall of thorax, subsequent encounter*/
,'S29001S'  /*Unspecified injury of muscle and tendon of front wall of thorax, sequela*/
,'S29002D'  /*Unspecified injury of muscle and tendon of back wall of thorax, subsequent encounter*/
,'S29002S'  /*Unspecified injury of muscle and tendon of back wall of thorax, sequela*/
,'S29009D'  /*Unspecified injury of muscle and tendon of unspecified wall of thorax, subsequent encounter*/
,'S29009S'  /*Unspecified injury of muscle and tendon of unspecified wall of thorax, sequela*/
,'S29011D'  /*Strain of muscle and tendon of front wall of thorax, subsequent encounter*/
,'S29011S'  /*Strain of muscle and tendon of front wall of thorax, sequela*/
,'S29012D'  /*Strain of muscle and tendon of back wall of thorax, subsequent encounter*/
,'S29012S'  /*Strain of muscle and tendon of back wall of thorax, sequela*/
,'S29019D'  /*Strain of muscle and tendon of unspecified wall of thorax, subsequent encounter*/
,'S29019S'  /*Strain of muscle and tendon of unspecified wall of thorax, sequela*/
,'S29021D'  /*Laceration of muscle and tendon of front wall of thorax, subsequent encounter*/
,'S29021S'  /*Laceration of muscle and tendon of front wall of thorax, sequela*/
,'S29022D'  /*Laceration of muscle and tendon of back wall of thorax, subsequent encounter*/
,'S29022S'  /*Laceration of muscle and tendon of back wall of thorax, sequela*/
,'S29029D'  /*Laceration of muscle and tendon of unspecified wall of thorax, subsequent encounter*/
,'S29029S'  /*Laceration of muscle and tendon of unspecified wall of thorax, sequela*/
,'S29091D'  /*Other injury of muscle and tendon of front wall of thorax, subsequent encounter*/
,'S29091S'  /*Other injury of muscle and tendon of front wall of thorax, sequela*/
,'S29092D'  /*Other injury of muscle and tendon of back wall of thorax, subsequent encounter*/
,'S29092S'  /*Other injury of muscle and tendon of back wall of thorax, sequela*/
,'S29099D'  /*Other injury of muscle and tendon of unspecified wall of thorax, subsequent encounter*/
,'S29099S'  /*Other injury of muscle and tendon of unspecified wall of thorax, sequela*/
,'S298XXD'  /*Other specified injuries of thorax, subsequent encounter*/
,'S298XXS'  /*Other specified injuries of thorax, sequela*/
,'S299XXD'  /*Unspecified injury of thorax, subsequent encounter*/
,'S299XXS'  /*Unspecified injury of thorax, sequela*/
,'S300XXD'  /*Contusion of lower back and pelvis, subsequent encounter*/
,'S300XXS'  /*Contusion of lower back and pelvis, sequela*/
,'S301XXD'  /*Contusion of abdominal wall, subsequent encounter*/
,'S301XXS'  /*Contusion of abdominal wall, sequela*/
,'S30201D'  /*Contusion of unspecified external genital organ, male, subsequent encounter*/
,'S30201S'  /*Contusion of unspecified external genital organ, male, sequela*/
,'S30202D'  /*Contusion of unspecified external genital organ, female, subsequent encounter*/
,'S30202S'  /*Contusion of unspecified external genital organ, female, sequela*/
,'S3021XD'  /*Contusion of penis, subsequent encounter*/
,'S3021XS'  /*Contusion of penis, sequela*/
,'S3022XD'  /*Contusion of scrotum and testes, subsequent encounter*/
,'S3022XS'  /*Contusion of scrotum and testes, sequela*/
,'S3023XD'  /*Contusion of vagina and vulva, subsequent encounter*/
,'S3023XS'  /*Contusion of vagina and vulva, sequela*/
,'S303XXD'  /*Contusion of anus, subsequent encounter*/
,'S303XXS'  /*Contusion of anus, sequela*/
,'S30810D'  /*Abrasion of lower back and pelvis, subsequent encounter*/
,'S30810S'  /*Abrasion of lower back and pelvis, sequela*/
,'S30811D'  /*Abrasion of abdominal wall, subsequent encounter*/
,'S30811S'  /*Abrasion of abdominal wall, sequela*/
,'S30812D'  /*Abrasion of penis, subsequent encounter*/
,'S30812S'  /*Abrasion of penis, sequela*/
,'S30813D'  /*Abrasion of scrotum and testes, subsequent encounter*/
,'S30813S'  /*Abrasion of scrotum and testes, sequela*/
,'S30814D'  /*Abrasion of vagina and vulva, subsequent encounter*/
,'S30814S'  /*Abrasion of vagina and vulva, sequela*/
,'S30815D'  /*Abrasion of unspecified external genital organs, male, subsequent encounter*/
,'S30815S'  /*Abrasion of unspecified external genital organs, male, sequela*/
,'S30816D'  /*Abrasion of unspecified external genital organs, female, subsequent encounter*/
,'S30816S'  /*Abrasion of unspecified external genital organs, female, sequela*/
,'S30817D'  /*Abrasion of anus, subsequent encounter*/
,'S30817S'  /*Abrasion of anus, sequela*/
,'S30820D'  /*Blister (nonthermal) of lower back and pelvis, subsequent encounter*/
,'S30820S'  /*Blister (nonthermal) of lower back and pelvis, sequela*/
,'S30821D'  /*Blister (nonthermal) of abdominal wall, subsequent encounter*/
,'S30821S'  /*Blister (nonthermal) of abdominal wall, sequela*/
,'S30822D'  /*Blister (nonthermal) of penis, subsequent encounter*/
,'S30822S'  /*Blister (nonthermal) of penis, sequela*/
,'S30823D'  /*Blister (nonthermal) of scrotum and testes, subsequent encounter*/
,'S30823S'  /*Blister (nonthermal) of scrotum and testes, sequela*/
,'S30824D'  /*Blister (nonthermal) of vagina and vulva, subsequent encounter*/
,'S30824S'  /*Blister (nonthermal) of vagina and vulva, sequela*/
,'S30825D'  /*Blister (nonthermal) of unspecified external genital organs, male, subsequent encounter*/
,'S30825S'  /*Blister (nonthermal) of unspecified external genital organs, male, sequela*/
,'S30826D'  /*Blister (nonthermal) of unspecified external genital organs, female, subsequent encounter*/
,'S30826S'  /*Blister (nonthermal) of unspecified external genital organs, female, sequela*/
,'S30827D'  /*Blister (nonthermal) of anus, subsequent encounter*/
,'S30827S'  /*Blister (nonthermal) of anus, sequela*/
,'S30840D'  /*External constriction of lower back and pelvis, subsequent encounter*/
,'S30840S'  /*External constriction of lower back and pelvis, sequela*/
,'S30841D'  /*External constriction of abdominal wall, subsequent encounter*/
,'S30841S'  /*External constriction of abdominal wall, sequela*/
,'S30842D'  /*External constriction of penis, subsequent encounter*/
,'S30842S'  /*External constriction of penis, sequela*/
,'S30843D'  /*External constriction of scrotum and testes, subsequent encounter*/
,'S30843S'  /*External constriction of scrotum and testes, sequela*/
,'S30844D'  /*External constriction of vagina and vulva, subsequent encounter*/
,'S30844S'  /*External constriction of vagina and vulva, sequela*/
,'S30845D'  /*External constriction of unspecified external genital organs, male, subsequent encounter*/
,'S30845S'  /*External constriction of unspecified external genital organs, male, sequela*/
,'S30846D'  /*External constriction of unspecified external genital organs, female, subsequent encounter*/
,'S30846S'  /*External constriction of unspecified external genital organs, female, sequela*/
,'S30850D'  /*Superficial foreign body of lower back and pelvis, subsequent encounter*/
,'S30850S'  /*Superficial foreign body of lower back and pelvis, sequela*/
,'S30851D'  /*Superficial foreign body of abdominal wall, subsequent encounter*/
,'S30851S'  /*Superficial foreign body of abdominal wall, sequela*/
,'S30852D'  /*Superficial foreign body of penis, subsequent encounter*/
,'S30852S'  /*Superficial foreign body of penis, sequela*/
,'S30853D'  /*Superficial foreign body of scrotum and testes, subsequent encounter*/
,'S30853S'  /*Superficial foreign body of scrotum and testes, sequela*/
,'S30854D'  /*Superficial foreign body of vagina and vulva, subsequent encounter*/
,'S30854S'  /*Superficial foreign body of vagina and vulva, sequela*/
,'S30855D'  /*Superficial foreign body of unspecified external genital organs, male, subsequent encounter*/
,'S30855S'  /*Superficial foreign body of unspecified external genital organs, male, sequela*/
,'S30856D'  /*Superficial foreign body of unspecified external genital organs, female, subsequent encounter*/
,'S30856S'  /*Superficial foreign body of unspecified external genital organs, female, sequela*/
,'S30857D'  /*Superficial foreign body of anus, subsequent encounter*/
,'S30857S'  /*Superficial foreign body of anus, sequela*/
,'S30860D'  /*Insect bite (nonvenomous) of lower back and pelvis, subsequent encounter*/
,'S30860S'  /*Insect bite (nonvenomous) of lower back and pelvis, sequela*/
,'S30861D'  /*Insect bite (nonvenomous) of abdominal wall, subsequent encounter*/
,'S30861S'  /*Insect bite (nonvenomous) of abdominal wall, sequela*/
,'S30862D'  /*Insect bite (nonvenomous) of penis, subsequent encounter*/
,'S30862S'  /*Insect bite (nonvenomous) of penis, sequela*/
,'S30863D'  /*Insect bite (nonvenomous) of scrotum and testes, subsequent encounter*/
,'S30863S'  /*Insect bite (nonvenomous) of scrotum and testes, sequela*/
,'S30864D'  /*Insect bite (nonvenomous) of vagina and vulva, subsequent encounter*/
,'S30864S'  /*Insect bite (nonvenomous) of vagina and vulva, sequela*/
,'S30865D'  /*Insect bite (nonvenomous) of unspecified external genital organs, male, subsequent encounter*/
,'S30865S'  /*Insect bite (nonvenomous) of unspecified external genital organs, male, sequela*/
,'S30866D'  /*Insect bite (nonvenomous) of unspecified external genital organs, female, subsequent encounter*/
,'S30866S'  /*Insect bite (nonvenomous) of unspecified external genital organs, female, sequela*/
,'S30867D'  /*Insect bite (nonvenomous) of anus, subsequent encounter*/
,'S30867S'  /*Insect bite (nonvenomous) of anus, sequela*/
,'S30870D'  /*Other superficial bite of lower back and pelvis, subsequent encounter*/
,'S30870S'  /*Other superficial bite of lower back and pelvis, sequela*/
,'S30871D'  /*Other superficial bite of abdominal wall, subsequent encounter*/
,'S30871S'  /*Other superficial bite of abdominal wall, sequela*/
,'S30872D'  /*Other superficial bite of penis, subsequent encounter*/
,'S30872S'  /*Other superficial bite of penis, sequela*/
,'S30873D'  /*Other superficial bite of scrotum and testes, subsequent encounter*/
,'S30873S'  /*Other superficial bite of scrotum and testes, sequela*/
,'S30874D'  /*Other superficial bite of vagina and vulva, subsequent encounter*/
,'S30874S'  /*Other superficial bite of vagina and vulva, sequela*/
,'S30875D'  /*Other superficial bite of unspecified external genital organs, male, subsequent encounter*/
,'S30875S'  /*Other superficial bite of unspecified external genital organs, male, sequela*/
,'S30876D'  /*Other superficial bite of unspecified external genital organs, female, subsequent encounter*/
,'S30876S'  /*Other superficial bite of unspecified external genital organs, female, sequela*/
,'S30877D'  /*Other superficial bite of anus, subsequent encounter*/
,'S30877S'  /*Other superficial bite of anus, sequela*/
,'S3091XD'  /*Unspecified superficial injury of lower back and pelvis, subsequent encounter*/
,'S3091XS'  /*Unspecified superficial injury of lower back and pelvis, sequela*/
,'S3092XD'  /*Unspecified superficial injury of abdominal wall, subsequent encounter*/
,'S3092XS'  /*Unspecified superficial injury of abdominal wall, sequela*/
,'S3093XD'  /*Unspecified superficial injury of penis, subsequent encounter*/
,'S3093XS'  /*Unspecified superficial injury of penis, sequela*/
,'S3094XD'  /*Unspecified superficial injury of scrotum and testes, subsequent encounter*/
,'S3094XS'  /*Unspecified superficial injury of scrotum and testes, sequela*/
,'S3095XD'  /*Unspecified superficial injury of vagina and vulva, subsequent encounter*/
,'S3095XS'  /*Unspecified superficial injury of vagina and vulva, sequela*/
,'S3096XD'  /*Unspecified superficial injury of unspecified external genital organs, male, subsequent encounter*/
,'S3096XS'  /*Unspecified superficial injury of unspecified external genital organs, male, sequela*/
,'S3097XD'  /*Unspecified superficial injury of unspecified external genital organs, female, subsequent encounter*/
,'S3097XS'  /*Unspecified superficial injury of unspecified external genital organs, female, sequela*/
,'S3098XD'  /*Unspecified superficial injury of anus, subsequent encounter*/
,'S3098XS'  /*Unspecified superficial injury of anus, sequela*/
,'S31000D'  /*Unspecified open wound of lower back and pelvis without penetration into retroperitoneum, subsequent encounter*/
,'S31000S'  /*Unspecified open wound of lower back and pelvis without penetration into retroperitoneum, sequela*/
,'S31001D'  /*Unspecified open wound of lower back and pelvis with penetration into retroperitoneum, subsequent encounter*/
,'S31001S'  /*Unspecified open wound of lower back and pelvis with penetration into retroperitoneum, sequela*/
,'S31010D'  /*Laceration without foreign body of lower back and pelvis without penetration into retroperitoneum, subsequent encounter*/
,'S31010S'  /*Laceration without foreign body of lower back and pelvis without penetration into retroperitoneum, sequela*/
,'S31011D'  /*Laceration without foreign body of lower back and pelvis with penetration into retroperitoneum, subsequent encounter*/
,'S31011S'  /*Laceration without foreign body of lower back and pelvis with penetration into retroperitoneum, sequela*/
,'S31020D'  /*Laceration with foreign body of lower back and pelvis without penetration into retroperitoneum, subsequent encounter*/
,'S31020S'  /*Laceration with foreign body of lower back and pelvis without penetration into retroperitoneum, sequela*/
,'S31021D'  /*Laceration with foreign body of lower back and pelvis with penetration into retroperitoneum, subsequent encounter*/
,'S31021S'  /*Laceration with foreign body of lower back and pelvis with penetration into retroperitoneum, sequela*/
,'S31030D'  /*Puncture wound without foreign body of lower back and pelvis without penetration into retroperitoneum, subsequent encounter*/
,'S31030S'  /*Puncture wound without foreign body of lower back and pelvis without penetration into retroperitoneum, sequela*/
,'S31031D'  /*Puncture wound without foreign body of lower back and pelvis with penetration into retroperitoneum, subsequent encounter*/
,'S31031S'  /*Puncture wound without foreign body of lower back and pelvis with penetration into retroperitoneum, sequela*/
,'S31040D'  /*Puncture wound with foreign body of lower back and pelvis without penetration into retroperitoneum, subsequent encounter*/
,'S31040S'  /*Puncture wound with foreign body of lower back and pelvis without penetration into retroperitoneum, sequela*/
,'S31041D'  /*Puncture wound with foreign body of lower back and pelvis with penetration into retroperitoneum, subsequent encounter*/
,'S31041S'  /*Puncture wound with foreign body of lower back and pelvis with penetration into retroperitoneum, sequela*/
,'S31050D'  /*Open bite of lower back and pelvis without penetration into retroperitoneum, subsequent encounter*/
,'S31050S'  /*Open bite of lower back and pelvis without penetration into retroperitoneum, sequela*/
,'S31051D'  /*Open bite of lower back and pelvis with penetration into retroperitoneum, subsequent encounter*/
,'S31051S'  /*Open bite of lower back and pelvis with penetration into retroperitoneum, sequela*/
,'S31100D'  /*Unspecified open wound of abdominal wall, right upper quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31100S'  /*Unspecified open wound of abdominal wall, right upper quadrant without penetration into peritoneal cavity, sequela*/
,'S31101D'  /*Unspecified open wound of abdominal wall, left upper quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31101S'  /*Unspecified open wound of abdominal wall, left upper quadrant without penetration into peritoneal cavity, sequela*/
,'S31102D'  /*Unspecified open wound of abdominal wall, epigastric region without penetration into peritoneal cavity, subsequent encounter*/
,'S31102S'  /*Unspecified open wound of abdominal wall, epigastric region without penetration into peritoneal cavity, sequela*/
,'S31103D'  /*Unspecified open wound of abdominal wall, right lower quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31103S'  /*Unspecified open wound of abdominal wall, right lower quadrant without penetration into peritoneal cavity, sequela*/
,'S31104D'  /*Unspecified open wound of abdominal wall, left lower quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31104S'  /*Unspecified open wound of abdominal wall, left lower quadrant without penetration into peritoneal cavity, sequela*/
,'S31105D'  /*Unspecified open wound of abdominal wall, periumbilic region without penetration into peritoneal cavity, subsequent encounter*/
,'S31105S'  /*Unspecified open wound of abdominal wall, periumbilic region without penetration into peritoneal cavity, sequela*/
,'S31109D'  /*Unspecified open wound of abdominal wall, unspecified quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31109S'  /*Unspecified open wound of abdominal wall, unspecified quadrant without penetration into peritoneal cavity, sequela*/
,'S31110D'  /*Laceration without foreign body of abdominal wall, right upper quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31110S'  /*Laceration without foreign body of abdominal wall, right upper quadrant without penetration into peritoneal cavity, sequela*/
,'S31111D'  /*Laceration without foreign body of abdominal wall, left upper quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31111S'  /*Laceration without foreign body of abdominal wall, left upper quadrant without penetration into peritoneal cavity, sequela*/
,'S31112D'  /*Laceration without foreign body of abdominal wall, epigastric region without penetration into peritoneal cavity, subsequent encounter*/
,'S31112S'  /*Laceration without foreign body of abdominal wall, epigastric region without penetration into peritoneal cavity, sequela*/
,'S31113D'  /*Laceration without foreign body of abdominal wall, right lower quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31113S'  /*Laceration without foreign body of abdominal wall, right lower quadrant without penetration into peritoneal cavity, sequela*/
,'S31114D'  /*Laceration without foreign body of abdominal wall, left lower quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31114S'  /*Laceration without foreign body of abdominal wall, left lower quadrant without penetration into peritoneal cavity, sequela*/
,'S31115D'  /*Laceration without foreign body of abdominal wall, periumbilic region without penetration into peritoneal cavity, subsequent encounter*/
,'S31115S'  /*Laceration without foreign body of abdominal wall, periumbilic region without penetration into peritoneal cavity, sequela*/
,'S31119D'  /*Laceration without foreign body of abdominal wall, unspecified quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31119S'  /*Laceration without foreign body of abdominal wall, unspecified quadrant without penetration into peritoneal cavity, sequela*/
,'S31120D'  /*Laceration of abdominal wall with foreign body, right upper quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31120S'  /*Laceration of abdominal wall with foreign body, right upper quadrant without penetration into peritoneal cavity, sequela*/
,'S31121D'  /*Laceration of abdominal wall with foreign body, left upper quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31121S'  /*Laceration of abdominal wall with foreign body, left upper quadrant without penetration into peritoneal cavity, sequela*/
,'S31122D'  /*Laceration of abdominal wall with foreign body, epigastric region without penetration into peritoneal cavity, subsequent encounter*/
,'S31122S'  /*Laceration of abdominal wall with foreign body, epigastric region without penetration into peritoneal cavity, sequela*/
,'S31123D'  /*Laceration of abdominal wall with foreign body, right lower quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31123S'  /*Laceration of abdominal wall with foreign body, right lower quadrant without penetration into peritoneal cavity, sequela*/
,'S31124D'  /*Laceration of abdominal wall with foreign body, left lower quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31124S'  /*Laceration of abdominal wall with foreign body, left lower quadrant without penetration into peritoneal cavity, sequela*/
,'S31125D'  /*Laceration of abdominal wall with foreign body, periumbilic region without penetration into peritoneal cavity, subsequent encounter*/
,'S31125S'  /*Laceration of abdominal wall with foreign body, periumbilic region without penetration into peritoneal cavity, sequela*/
,'S31129D'  /*Laceration of abdominal wall with foreign body, unspecified quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31129S'  /*Laceration of abdominal wall with foreign body, unspecified quadrant without penetration into peritoneal cavity, sequela*/
,'S31130D'  /*Puncture wound of abdominal wall without foreign body, right upper quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31130S'  /*Puncture wound of abdominal wall without foreign body, right upper quadrant without penetration into peritoneal cavity, sequela*/
,'S31131D'  /*Puncture wound of abdominal wall without foreign body, left upper quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31131S'  /*Puncture wound of abdominal wall without foreign body, left upper quadrant without penetration into peritoneal cavity, sequela*/
,'S31132D'  /*Puncture wound of abdominal wall without foreign body, epigastric region without penetration into peritoneal cavity, subsequent encounter*/
,'S31132S'  /*Puncture wound of abdominal wall without foreign body, epigastric region without penetration into peritoneal cavity, sequela*/
,'S31133D'  /*Puncture wound of abdominal wall without foreign body, right lower quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31133S'  /*Puncture wound of abdominal wall without foreign body, right lower quadrant without penetration into peritoneal cavity, sequela*/
,'S31134D'  /*Puncture wound of abdominal wall without foreign body, left lower quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31134S'  /*Puncture wound of abdominal wall without foreign body, left lower quadrant without penetration into peritoneal cavity, sequela*/
,'S31135D'  /*Puncture wound of abdominal wall without foreign body, periumbilic region without penetration into peritoneal cavity, subsequent encounter*/
,'S31135S'  /*Puncture wound of abdominal wall without foreign body, periumbilic region without penetration into peritoneal cavity, sequela*/
,'S31139D'  /*Puncture wound of abdominal wall without foreign body, unspecified quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31139S'  /*Puncture wound of abdominal wall without foreign body, unspecified quadrant without penetration into peritoneal cavity, sequela*/
,'S31140D'  /*Puncture wound of abdominal wall with foreign body, right upper quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31140S'  /*Puncture wound of abdominal wall with foreign body, right upper quadrant without penetration into peritoneal cavity, sequela*/
,'S31141D'  /*Puncture wound of abdominal wall with foreign body, left upper quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31141S'  /*Puncture wound of abdominal wall with foreign body, left upper quadrant without penetration into peritoneal cavity, sequela*/
,'S31142D'  /*Puncture wound of abdominal wall with foreign body, epigastric region without penetration into peritoneal cavity, subsequent encounter*/
,'S31142S'  /*Puncture wound of abdominal wall with foreign body, epigastric region without penetration into peritoneal cavity, sequela*/
,'S31143D'  /*Puncture wound of abdominal wall with foreign body, right lower quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31143S'  /*Puncture wound of abdominal wall with foreign body, right lower quadrant without penetration into peritoneal cavity, sequela*/
,'S31144D'  /*Puncture wound of abdominal wall with foreign body, left lower quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31144S'  /*Puncture wound of abdominal wall with foreign body, left lower quadrant without penetration into peritoneal cavity, sequela*/
,'S31145D'  /*Puncture wound of abdominal wall with foreign body, periumbilic region without penetration into peritoneal cavity, subsequent encounter*/
,'S31145S'  /*Puncture wound of abdominal wall with foreign body, periumbilic region without penetration into peritoneal cavity, sequela*/
,'S31149D'  /*Puncture wound of abdominal wall with foreign body, unspecified quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31149S'  /*Puncture wound of abdominal wall with foreign body, unspecified quadrant without penetration into peritoneal cavity, sequela*/
,'S31150D'  /*Open bite of abdominal wall, right upper quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31150S'  /*Open bite of abdominal wall, right upper quadrant without penetration into peritoneal cavity, sequela*/
,'S31151D'  /*Open bite of abdominal wall, left upper quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31151S'  /*Open bite of abdominal wall, left upper quadrant without penetration into peritoneal cavity, sequela*/
,'S31152D'  /*Open bite of abdominal wall, epigastric region without penetration into peritoneal cavity, subsequent encounter*/
,'S31152S'  /*Open bite of abdominal wall, epigastric region without penetration into peritoneal cavity, sequela*/
,'S31153D'  /*Open bite of abdominal wall, right lower quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31153S'  /*Open bite of abdominal wall, right lower quadrant without penetration into peritoneal cavity, sequela*/
,'S31154D'  /*Open bite of abdominal wall, left lower quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31154S'  /*Open bite of abdominal wall, left lower quadrant without penetration into peritoneal cavity, sequela*/
,'S31155D'  /*Open bite of abdominal wall, periumbilic region without penetration into peritoneal cavity, subsequent encounter*/
,'S31155S'  /*Open bite of abdominal wall, periumbilic region without penetration into peritoneal cavity, sequela*/
,'S31159D'  /*Open bite of abdominal wall, unspecified quadrant without penetration into peritoneal cavity, subsequent encounter*/
,'S31159S'  /*Open bite of abdominal wall, unspecified quadrant without penetration into peritoneal cavity, sequela*/
,'S3120XD'  /*Unspecified open wound of penis, subsequent encounter*/
,'S3120XS'  /*Unspecified open wound of penis, sequela*/
,'S3121XD'  /*Laceration without foreign body of penis, subsequent encounter*/
,'S3121XS'  /*Laceration without foreign body of penis, sequela*/
,'S3122XD'  /*Laceration with foreign body of penis, subsequent encounter*/
,'S3122XS'  /*Laceration with foreign body of penis, sequela*/
,'S3123XD'  /*Puncture wound without foreign body of penis, subsequent encounter*/
,'S3123XS'  /*Puncture wound without foreign body of penis, sequela*/
,'S3124XD'  /*Puncture wound with foreign body of penis, subsequent encounter*/
,'S3124XS'  /*Puncture wound with foreign body of penis, sequela*/
,'S3125XD'  /*Open bite of penis, subsequent encounter*/
,'S3125XS'  /*Open bite of penis, sequela*/
,'S3130XD'  /*Unspecified open wound of scrotum and testes, subsequent encounter*/
,'S3130XS'  /*Unspecified open wound of scrotum and testes, sequela*/
,'S3131XD'  /*Laceration without foreign body of scrotum and testes, subsequent encounter*/
,'S3131XS'  /*Laceration without foreign body of scrotum and testes, sequela*/
,'S3132XD'  /*Laceration with foreign body of scrotum and testes, subsequent encounter*/
,'S3132XS'  /*Laceration with foreign body of scrotum and testes, sequela*/
,'S3133XD'  /*Puncture wound without foreign body of scrotum and testes, subsequent encounter*/
,'S3133XS'  /*Puncture wound without foreign body of scrotum and testes, sequela*/
,'S3134XD'  /*Puncture wound with foreign body of scrotum and testes, subsequent encounter*/
,'S3134XS'  /*Puncture wound with foreign body of scrotum and testes, sequela*/
,'S3135XD'  /*Open bite of scrotum and testes, subsequent encounter*/
,'S3135XS'  /*Open bite of scrotum and testes, sequela*/
,'S3140XD'  /*Unspecified open wound of vagina and vulva, subsequent encounter*/
,'S3140XS'  /*Unspecified open wound of vagina and vulva, sequela*/
,'S3141XD'  /*Laceration without foreign body of vagina and vulva, subsequent encounter*/
,'S3141XS'  /*Laceration without foreign body of vagina and vulva, sequela*/
,'S3142XD'  /*Laceration with foreign body of vagina and vulva, subsequent encounter*/
,'S3142XS'  /*Laceration with foreign body of vagina and vulva, sequela*/
,'S3143XD'  /*Puncture wound without foreign body of vagina and vulva, subsequent encounter*/
,'S3143XS'  /*Puncture wound without foreign body of vagina and vulva, sequela*/
,'S3144XD'  /*Puncture wound with foreign body of vagina and vulva, subsequent encounter*/
,'S3144XS'  /*Puncture wound with foreign body of vagina and vulva, sequela*/
,'S3145XD'  /*Open bite of vagina and vulva, subsequent encounter*/
,'S3145XS'  /*Open bite of vagina and vulva, sequela*/
,'S31501D'  /*Unspecified open wound of unspecified external genital organs, male, subsequent encounter*/
,'S31501S'  /*Unspecified open wound of unspecified external genital organs, male, sequela*/
,'S31502D'  /*Unspecified open wound of unspecified external genital organs, female, subsequent encounter*/
,'S31502S'  /*Unspecified open wound of unspecified external genital organs, female, sequela*/
,'S31511D'  /*Laceration without foreign body of unspecified external genital organs, male, subsequent encounter*/
,'S31511S'  /*Laceration without foreign body of unspecified external genital organs, male, sequela*/
,'S31512D'  /*Laceration without foreign body of unspecified external genital organs, female, subsequent encounter*/
,'S31512S'  /*Laceration without foreign body of unspecified external genital organs, female, sequela*/
,'S31521D'  /*Laceration with foreign body of unspecified external genital organs, male, subsequent encounter*/
,'S31521S'  /*Laceration with foreign body of unspecified external genital organs, male, sequela*/
,'S31522D'  /*Laceration with foreign body of unspecified external genital organs, female, subsequent encounter*/
,'S31522S'  /*Laceration with foreign body of unspecified external genital organs, female, sequela*/
,'S31531D'  /*Puncture wound without foreign body of unspecified external genital organs, male, subsequent encounter*/
,'S31531S'  /*Puncture wound without foreign body of unspecified external genital organs, male, sequela*/
,'S31532D'  /*Puncture wound without foreign body of unspecified external genital organs, female, subsequent encounter*/
,'S31532S'  /*Puncture wound without foreign body of unspecified external genital organs, female, sequela*/
,'S31541D'  /*Puncture wound with foreign body of unspecified external genital organs, male, subsequent encounter*/
,'S31541S'  /*Puncture wound with foreign body of unspecified external genital organs, male, sequela*/
,'S31542D'  /*Puncture wound with foreign body of unspecified external genital organs, female, subsequent encounter*/
,'S31542S'  /*Puncture wound with foreign body of unspecified external genital organs, female, sequela*/
,'S31551D'  /*Open bite of unspecified external genital organs, male, subsequent encounter*/
,'S31551S'  /*Open bite of unspecified external genital organs, male, sequela*/
,'S31552D'  /*Open bite of unspecified external genital organs, female, subsequent encounter*/
,'S31552S'  /*Open bite of unspecified external genital organs, female, sequela*/
,'S31600D'  /*Unspecified open wound of abdominal wall, right upper quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31600S'  /*Unspecified open wound of abdominal wall, right upper quadrant with penetration into peritoneal cavity, sequela*/
,'S31601D'  /*Unspecified open wound of abdominal wall, left upper quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31601S'  /*Unspecified open wound of abdominal wall, left upper quadrant with penetration into peritoneal cavity, sequela*/
,'S31602D'  /*Unspecified open wound of abdominal wall, epigastric region with penetration into peritoneal cavity, subsequent encounter*/
,'S31602S'  /*Unspecified open wound of abdominal wall, epigastric region with penetration into peritoneal cavity, sequela*/
,'S31603D'  /*Unspecified open wound of abdominal wall, right lower quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31603S'  /*Unspecified open wound of abdominal wall, right lower quadrant with penetration into peritoneal cavity, sequela*/
,'S31604D'  /*Unspecified open wound of abdominal wall, left lower quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31604S'  /*Unspecified open wound of abdominal wall, left lower quadrant with penetration into peritoneal cavity, sequela*/
,'S31605D'  /*Unspecified open wound of abdominal wall, periumbilic region with penetration into peritoneal cavity, subsequent encounter*/
,'S31605S'  /*Unspecified open wound of abdominal wall, periumbilic region with penetration into peritoneal cavity, sequela*/
,'S31609D'  /*Unspecified open wound of abdominal wall, unspecified quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31609S'  /*Unspecified open wound of abdominal wall, unspecified quadrant with penetration into peritoneal cavity, sequela*/
,'S31610D'  /*Laceration without foreign body of abdominal wall, right upper quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31610S'  /*Laceration without foreign body of abdominal wall, right upper quadrant with penetration into peritoneal cavity, sequela*/
,'S31611D'  /*Laceration without foreign body of abdominal wall, left upper quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31611S'  /*Laceration without foreign body of abdominal wall, left upper quadrant with penetration into peritoneal cavity, sequela*/
,'S31612D'  /*Laceration without foreign body of abdominal wall, epigastric region with penetration into peritoneal cavity, subsequent encounter*/
,'S31612S'  /*Laceration without foreign body of abdominal wall, epigastric region with penetration into peritoneal cavity, sequela*/
,'S31613D'  /*Laceration without foreign body of abdominal wall, right lower quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31613S'  /*Laceration without foreign body of abdominal wall, right lower quadrant with penetration into peritoneal cavity, sequela*/
,'S31614D'  /*Laceration without foreign body of abdominal wall, left lower quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31614S'  /*Laceration without foreign body of abdominal wall, left lower quadrant with penetration into peritoneal cavity, sequela*/
,'S31615D'  /*Laceration without foreign body of abdominal wall, periumbilic region with penetration into peritoneal cavity, subsequent encounter*/
,'S31615S'  /*Laceration without foreign body of abdominal wall, periumbilic region with penetration into peritoneal cavity, sequela*/
,'S31619D'  /*Laceration without foreign body of abdominal wall, unspecified quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31619S'  /*Laceration without foreign body of abdominal wall, unspecified quadrant with penetration into peritoneal cavity, sequela*/
,'S31620D'  /*Laceration with foreign body of abdominal wall, right upper quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31620S'  /*Laceration with foreign body of abdominal wall, right upper quadrant with penetration into peritoneal cavity, sequela*/
,'S31621D'  /*Laceration with foreign body of abdominal wall, left upper quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31621S'  /*Laceration with foreign body of abdominal wall, left upper quadrant with penetration into peritoneal cavity, sequela*/
,'S31622D'  /*Laceration with foreign body of abdominal wall, epigastric region with penetration into peritoneal cavity, subsequent encounter*/
,'S31622S'  /*Laceration with foreign body of abdominal wall, epigastric region with penetration into peritoneal cavity, sequela*/
,'S31623D'  /*Laceration with foreign body of abdominal wall, right lower quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31623S'  /*Laceration with foreign body of abdominal wall, right lower quadrant with penetration into peritoneal cavity, sequela*/
,'S31624D'  /*Laceration with foreign body of abdominal wall, left lower quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31624S'  /*Laceration with foreign body of abdominal wall, left lower quadrant with penetration into peritoneal cavity, sequela*/
,'S31625D'  /*Laceration with foreign body of abdominal wall, periumbilic region with penetration into peritoneal cavity, subsequent encounter*/
,'S31625S'  /*Laceration with foreign body of abdominal wall, periumbilic region with penetration into peritoneal cavity, sequela*/
,'S31629D'  /*Laceration with foreign body of abdominal wall, unspecified quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31629S'  /*Laceration with foreign body of abdominal wall, unspecified quadrant with penetration into peritoneal cavity, sequela*/
,'S31630D'  /*Puncture wound without foreign body of abdominal wall, right upper quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31630S'  /*Puncture wound without foreign body of abdominal wall, right upper quadrant with penetration into peritoneal cavity, sequela*/
,'S31631D'  /*Puncture wound without foreign body of abdominal wall, left upper quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31631S'  /*Puncture wound without foreign body of abdominal wall, left upper quadrant with penetration into peritoneal cavity, sequela*/
,'S31632D'  /*Puncture wound without foreign body of abdominal wall, epigastric region with penetration into peritoneal cavity, subsequent encounter*/
,'S31632S'  /*Puncture wound without foreign body of abdominal wall, epigastric region with penetration into peritoneal cavity, sequela*/
,'S31633D'  /*Puncture wound without foreign body of abdominal wall, right lower quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31633S'  /*Puncture wound without foreign body of abdominal wall, right lower quadrant with penetration into peritoneal cavity, sequela*/
,'S31634D'  /*Puncture wound without foreign body of abdominal wall, left lower quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31634S'  /*Puncture wound without foreign body of abdominal wall, left lower quadrant with penetration into peritoneal cavity, sequela*/
,'S31635D'  /*Puncture wound without foreign body of abdominal wall, periumbilic region with penetration into peritoneal cavity, subsequent encounter*/
,'S31635S'  /*Puncture wound without foreign body of abdominal wall, periumbilic region with penetration into peritoneal cavity, sequela*/
,'S31639D'  /*Puncture wound without foreign body of abdominal wall, unspecified quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31639S'  /*Puncture wound without foreign body of abdominal wall, unspecified quadrant with penetration into peritoneal cavity, sequela*/
,'S31640D'  /*Puncture wound with foreign body of abdominal wall, right upper quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31640S'  /*Puncture wound with foreign body of abdominal wall, right upper quadrant with penetration into peritoneal cavity, sequela*/
,'S31641D'  /*Puncture wound with foreign body of abdominal wall, left upper quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31641S'  /*Puncture wound with foreign body of abdominal wall, left upper quadrant with penetration into peritoneal cavity, sequela*/
,'S31642D'  /*Puncture wound with foreign body of abdominal wall, epigastric region with penetration into peritoneal cavity, subsequent encounter*/
,'S31642S'  /*Puncture wound with foreign body of abdominal wall, epigastric region with penetration into peritoneal cavity, sequela*/
,'S31643D'  /*Puncture wound with foreign body of abdominal wall, right lower quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31643S'  /*Puncture wound with foreign body of abdominal wall, right lower quadrant with penetration into peritoneal cavity, sequela*/
,'S31644D'  /*Puncture wound with foreign body of abdominal wall, left lower quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31644S'  /*Puncture wound with foreign body of abdominal wall, left lower quadrant with penetration into peritoneal cavity, sequela*/
,'S31645D'  /*Puncture wound with foreign body of abdominal wall, periumbilic region with penetration into peritoneal cavity, subsequent encounter*/
,'S31645S'  /*Puncture wound with foreign body of abdominal wall, periumbilic region with penetration into peritoneal cavity, sequela*/
,'S31649D'  /*Puncture wound with foreign body of abdominal wall, unspecified quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31649S'  /*Puncture wound with foreign body of abdominal wall, unspecified quadrant with penetration into peritoneal cavity, sequela*/
,'S31650D'  /*Open bite of abdominal wall, right upper quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31650S'  /*Open bite of abdominal wall, right upper quadrant with penetration into peritoneal cavity, sequela*/
,'S31651D'  /*Open bite of abdominal wall, left upper quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31651S'  /*Open bite of abdominal wall, left upper quadrant with penetration into peritoneal cavity, sequela*/
,'S31652D'  /*Open bite of abdominal wall, epigastric region with penetration into peritoneal cavity, subsequent encounter*/
,'S31652S'  /*Open bite of abdominal wall, epigastric region with penetration into peritoneal cavity, sequela*/
,'S31653D'  /*Open bite of abdominal wall, right lower quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31653S'  /*Open bite of abdominal wall, right lower quadrant with penetration into peritoneal cavity, sequela*/
,'S31654D'  /*Open bite of abdominal wall, left lower quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31654S'  /*Open bite of abdominal wall, left lower quadrant with penetration into peritoneal cavity, sequela*/
,'S31655D'  /*Open bite of abdominal wall, periumbilic region with penetration into peritoneal cavity, subsequent encounter*/
,'S31655S'  /*Open bite of abdominal wall, periumbilic region with penetration into peritoneal cavity, sequela*/
,'S31659D'  /*Open bite of abdominal wall, unspecified quadrant with penetration into peritoneal cavity, subsequent encounter*/
,'S31659S'  /*Open bite of abdominal wall, unspecified quadrant with penetration into peritoneal cavity, sequela*/
,'S31801D'  /*Laceration without foreign body of unspecified buttock, subsequent encounter*/
,'S31801S'  /*Laceration without foreign body of unspecified buttock, sequela*/
,'S31802D'  /*Laceration with foreign body of unspecified buttock, subsequent encounter*/
,'S31802S'  /*Laceration with foreign body of unspecified buttock, sequela*/
,'S31803D'  /*Puncture wound without foreign body of unspecified buttock, subsequent encounter*/
,'S31803S'  /*Puncture wound without foreign body of unspecified buttock, sequela*/
,'S31804D'  /*Puncture wound with foreign body of unspecified buttock, subsequent encounter*/
,'S31804S'  /*Puncture wound with foreign body of unspecified buttock, sequela*/
,'S31805D'  /*Open bite of unspecified buttock, subsequent encounter*/
,'S31805S'  /*Open bite of unspecified buttock, sequela*/
,'S31809D'  /*Unspecified open wound of unspecified buttock, subsequent encounter*/
,'S31809S'  /*Unspecified open wound of unspecified buttock, sequela*/
,'S31811D'  /*Laceration without foreign body of right buttock, subsequent encounter*/
,'S31811S'  /*Laceration without foreign body of right buttock, sequela*/
,'S31812D'  /*Laceration with foreign body of right buttock, subsequent encounter*/
,'S31812S'  /*Laceration with foreign body of right buttock, sequela*/
,'S31813D'  /*Puncture wound without foreign body of right buttock, subsequent encounter*/
,'S31813S'  /*Puncture wound without foreign body of right buttock, sequela*/
,'S31814D'  /*Puncture wound with foreign body of right buttock, subsequent encounter*/
,'S31814S'  /*Puncture wound with foreign body of right buttock, sequela*/
,'S31815D'  /*Open bite of right buttock, subsequent encounter*/
,'S31815S'  /*Open bite of right buttock, sequela*/
,'S31819D'  /*Unspecified open wound of right buttock, subsequent encounter*/
,'S31819S'  /*Unspecified open wound of right buttock, sequela*/
,'S31821D'  /*Laceration without foreign body of left buttock, subsequent encounter*/
,'S31821S'  /*Laceration without foreign body of left buttock, sequela*/
,'S31822D'  /*Laceration with foreign body of left buttock, subsequent encounter*/
,'S31822S'  /*Laceration with foreign body of left buttock, sequela*/
,'S31823D'  /*Puncture wound without foreign body of left buttock, subsequent encounter*/
,'S31823S'  /*Puncture wound without foreign body of left buttock, sequela*/
,'S31824D'  /*Puncture wound with foreign body of left buttock, subsequent encounter*/
,'S31824S'  /*Puncture wound with foreign body of left buttock, sequela*/
,'S31825D'  /*Open bite of left buttock, subsequent encounter*/
,'S31825S'  /*Open bite of left buttock, sequela*/
,'S31829D'  /*Unspecified open wound of left buttock, subsequent encounter*/
,'S31829S'  /*Unspecified open wound of left buttock, sequela*/
,'S31831D'  /*Laceration without foreign body of anus, subsequent encounter*/
,'S31831S'  /*Laceration without foreign body of anus, sequela*/
,'S31832D'  /*Laceration with foreign body of anus, subsequent encounter*/
,'S31832S'  /*Laceration with foreign body of anus, sequela*/
,'S31833D'  /*Puncture wound without foreign body of anus, subsequent encounter*/
,'S31833S'  /*Puncture wound without foreign body of anus, sequela*/
,'S31834D'  /*Puncture wound with foreign body of anus, subsequent encounter*/
,'S31834S'  /*Puncture wound with foreign body of anus, sequela*/
,'S31835D'  /*Open bite of anus, subsequent encounter*/
,'S31835S'  /*Open bite of anus, sequela*/
,'S31839D'  /*Unspecified open wound of anus, subsequent encounter*/
,'S31839S'  /*Unspecified open wound of anus, sequela*/
,'S32000D'  /*Wedge compression fracture of unspecified lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32000G'  /*Wedge compression fracture of unspecified lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32000K'  /*Wedge compression fracture of unspecified lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32000S'  /*Wedge compression fracture of unspecified lumbar vertebra, sequela*/
,'S32001D'  /*Stable burst fracture of unspecified lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32001G'  /*Stable burst fracture of unspecified lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32001K'  /*Stable burst fracture of unspecified lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32001S'  /*Stable burst fracture of unspecified lumbar vertebra, sequela*/
,'S32002D'  /*Unstable burst fracture of unspecified lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32002G'  /*Unstable burst fracture of unspecified lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32002K'  /*Unstable burst fracture of unspecified lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32002S'  /*Unstable burst fracture of unspecified lumbar vertebra, sequela*/
,'S32008D'  /*Other fracture of unspecified lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32008G'  /*Other fracture of unspecified lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32008K'  /*Other fracture of unspecified lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32008S'  /*Other fracture of unspecified lumbar vertebra, sequela*/
,'S32009D'  /*Unspecified fracture of unspecified lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32009G'  /*Unspecified fracture of unspecified lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32009K'  /*Unspecified fracture of unspecified lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32009S'  /*Unspecified fracture of unspecified lumbar vertebra, sequela*/
,'S32010D'  /*Wedge compression fracture of first lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32010G'  /*Wedge compression fracture of first lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32010K'  /*Wedge compression fracture of first lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32010S'  /*Wedge compression fracture of first lumbar vertebra, sequela*/
,'S32011D'  /*Stable burst fracture of first lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32011G'  /*Stable burst fracture of first lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32011K'  /*Stable burst fracture of first lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32011S'  /*Stable burst fracture of first lumbar vertebra, sequela*/
,'S32012D'  /*Unstable burst fracture of first lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32012G'  /*Unstable burst fracture of first lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32012K'  /*Unstable burst fracture of first lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32012S'  /*Unstable burst fracture of first lumbar vertebra, sequela*/
,'S32018D'  /*Other fracture of first lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32018G'  /*Other fracture of first lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32018K'  /*Other fracture of first lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32018S'  /*Other fracture of first lumbar vertebra, sequela*/
,'S32019D'  /*Unspecified fracture of first lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32019G'  /*Unspecified fracture of first lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32019K'  /*Unspecified fracture of first lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32019S'  /*Unspecified fracture of first lumbar vertebra, sequela*/
,'S32020D'  /*Wedge compression fracture of second lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32020G'  /*Wedge compression fracture of second lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32020K'  /*Wedge compression fracture of second lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32020S'  /*Wedge compression fracture of second lumbar vertebra, sequela*/
,'S32021D'  /*Stable burst fracture of second lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32021G'  /*Stable burst fracture of second lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32021K'  /*Stable burst fracture of second lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32021S'  /*Stable burst fracture of second lumbar vertebra, sequela*/
,'S32022D'  /*Unstable burst fracture of second lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32022G'  /*Unstable burst fracture of second lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32022K'  /*Unstable burst fracture of second lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32022S'  /*Unstable burst fracture of second lumbar vertebra, sequela*/
,'S32028D'  /*Other fracture of second lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32028G'  /*Other fracture of second lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32028K'  /*Other fracture of second lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32028S'  /*Other fracture of second lumbar vertebra, sequela*/
,'S32029D'  /*Unspecified fracture of second lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32029G'  /*Unspecified fracture of second lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32029K'  /*Unspecified fracture of second lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32029S'  /*Unspecified fracture of second lumbar vertebra, sequela*/
,'S32030D'  /*Wedge compression fracture of third lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32030G'  /*Wedge compression fracture of third lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32030K'  /*Wedge compression fracture of third lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32030S'  /*Wedge compression fracture of third lumbar vertebra, sequela*/
,'S32031D'  /*Stable burst fracture of third lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32031G'  /*Stable burst fracture of third lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32031K'  /*Stable burst fracture of third lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32031S'  /*Stable burst fracture of third lumbar vertebra, sequela*/
,'S32032D'  /*Unstable burst fracture of third lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32032G'  /*Unstable burst fracture of third lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32032K'  /*Unstable burst fracture of third lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32032S'  /*Unstable burst fracture of third lumbar vertebra, sequela*/
,'S32038D'  /*Other fracture of third lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32038G'  /*Other fracture of third lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32038K'  /*Other fracture of third lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32038S'  /*Other fracture of third lumbar vertebra, sequela*/
,'S32039D'  /*Unspecified fracture of third lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32039G'  /*Unspecified fracture of third lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32039K'  /*Unspecified fracture of third lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32039S'  /*Unspecified fracture of third lumbar vertebra, sequela*/
,'S32040D'  /*Wedge compression fracture of fourth lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32040G'  /*Wedge compression fracture of fourth lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32040K'  /*Wedge compression fracture of fourth lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32040S'  /*Wedge compression fracture of fourth lumbar vertebra, sequela*/
,'S32041D'  /*Stable burst fracture of fourth lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32041G'  /*Stable burst fracture of fourth lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32041K'  /*Stable burst fracture of fourth lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32041S'  /*Stable burst fracture of fourth lumbar vertebra, sequela*/
,'S32042D'  /*Unstable burst fracture of fourth lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32042G'  /*Unstable burst fracture of fourth lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32042K'  /*Unstable burst fracture of fourth lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32042S'  /*Unstable burst fracture of fourth lumbar vertebra, sequela*/
,'S32048D'  /*Other fracture of fourth lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32048G'  /*Other fracture of fourth lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32048K'  /*Other fracture of fourth lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32048S'  /*Other fracture of fourth lumbar vertebra, sequela*/
,'S32049D'  /*Unspecified fracture of fourth lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32049G'  /*Unspecified fracture of fourth lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32049K'  /*Unspecified fracture of fourth lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32049S'  /*Unspecified fracture of fourth lumbar vertebra, sequela*/
,'S32050D'  /*Wedge compression fracture of fifth lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32050G'  /*Wedge compression fracture of fifth lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32050K'  /*Wedge compression fracture of fifth lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32050S'  /*Wedge compression fracture of fifth lumbar vertebra, sequela*/
,'S32051D'  /*Stable burst fracture of fifth lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32051G'  /*Stable burst fracture of fifth lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32051K'  /*Stable burst fracture of fifth lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32051S'  /*Stable burst fracture of fifth lumbar vertebra, sequela*/
,'S32052D'  /*Unstable burst fracture of fifth lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32052G'  /*Unstable burst fracture of fifth lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32052K'  /*Unstable burst fracture of fifth lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32052S'  /*Unstable burst fracture of fifth lumbar vertebra, sequela*/
,'S32058D'  /*Other fracture of fifth lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32058G'  /*Other fracture of fifth lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32058K'  /*Other fracture of fifth lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32058S'  /*Other fracture of fifth lumbar vertebra, sequela*/
,'S32059D'  /*Unspecified fracture of fifth lumbar vertebra, subsequent encounter for fracture with routine healing*/
,'S32059G'  /*Unspecified fracture of fifth lumbar vertebra, subsequent encounter for fracture with delayed healing*/
,'S32059K'  /*Unspecified fracture of fifth lumbar vertebra, subsequent encounter for fracture with nonunion*/
,'S32059S'  /*Unspecified fracture of fifth lumbar vertebra, sequela*/
,'S3210XD'  /*Unspecified fracture of sacrum, subsequent encounter for fracture with routine healing*/
,'S3210XG'  /*Unspecified fracture of sacrum, subsequent encounter for fracture with delayed healing*/
,'S3210XK'  /*Unspecified fracture of sacrum, subsequent encounter for fracture with nonunion*/
,'S3210XS'  /*Unspecified fracture of sacrum, sequela*/
,'S32110D'  /*Nondisplaced Zone I fracture of sacrum, subsequent encounter for fracture with routine healing*/
,'S32110G'  /*Nondisplaced Zone I fracture of sacrum, subsequent encounter for fracture with delayed healing*/
,'S32110K'  /*Nondisplaced Zone I fracture of sacrum, subsequent encounter for fracture with nonunion*/
,'S32110S'  /*Nondisplaced Zone I fracture of sacrum, sequela*/
,'S32111D'  /*Minimally displaced Zone I fracture of sacrum, subsequent encounter for fracture with routine healing*/
,'S32111G'  /*Minimally displaced Zone I fracture of sacrum, subsequent encounter for fracture with delayed healing*/
,'S32111K'  /*Minimally displaced Zone I fracture of sacrum, subsequent encounter for fracture with nonunion*/
,'S32111S'  /*Minimally displaced Zone I fracture of sacrum, sequela*/
,'S32112D'  /*Severely displaced Zone I fracture of sacrum, subsequent encounter for fracture with routine healing*/
,'S32112G'  /*Severely displaced Zone I fracture of sacrum, subsequent encounter for fracture with delayed healing*/
,'S32112K'  /*Severely displaced Zone I fracture of sacrum, subsequent encounter for fracture with nonunion*/
,'S32112S'  /*Severely displaced Zone I fracture of sacrum, sequela*/
,'S32119D'  /*Unspecified Zone I fracture of sacrum, subsequent encounter for fracture with routine healing*/
,'S32119G'  /*Unspecified Zone I fracture of sacrum, subsequent encounter for fracture with delayed healing*/
,'S32119K'  /*Unspecified Zone I fracture of sacrum, subsequent encounter for fracture with nonunion*/
,'S32119S'  /*Unspecified Zone I fracture of sacrum, sequela*/
,'S32120D'  /*Nondisplaced Zone II fracture of sacrum, subsequent encounter for fracture with routine healing*/
,'S32120G'  /*Nondisplaced Zone II fracture of sacrum, subsequent encounter for fracture with delayed healing*/
,'S32120K'  /*Nondisplaced Zone II fracture of sacrum, subsequent encounter for fracture with nonunion*/
,'S32120S'  /*Nondisplaced Zone II fracture of sacrum, sequela*/
,'S32121D'  /*Minimally displaced Zone II fracture of sacrum, subsequent encounter for fracture with routine healing*/
,'S32121G'  /*Minimally displaced Zone II fracture of sacrum, subsequent encounter for fracture with delayed healing*/
,'S32121K'  /*Minimally displaced Zone II fracture of sacrum, subsequent encounter for fracture with nonunion*/
,'S32121S'  /*Minimally displaced Zone II fracture of sacrum, sequela*/
,'S32122D'  /*Severely displaced Zone II fracture of sacrum, subsequent encounter for fracture with routine healing*/
,'S32122G'  /*Severely displaced Zone II fracture of sacrum, subsequent encounter for fracture with delayed healing*/
,'S32122K'  /*Severely displaced Zone II fracture of sacrum, subsequent encounter for fracture with nonunion*/
,'S32122S'  /*Severely displaced Zone II fracture of sacrum, sequela*/
,'S32129D'  /*Unspecified Zone II fracture of sacrum, subsequent encounter for fracture with routine healing*/
,'S32129G'  /*Unspecified Zone II fracture of sacrum, subsequent encounter for fracture with delayed healing*/
,'S32129K'  /*Unspecified Zone II fracture of sacrum, subsequent encounter for fracture with nonunion*/
,'S32129S'  /*Unspecified Zone II fracture of sacrum, sequela*/
,'S32130D'  /*Nondisplaced Zone III fracture of sacrum, subsequent encounter for fracture with routine healing*/
,'S32130G'  /*Nondisplaced Zone III fracture of sacrum, subsequent encounter for fracture with delayed healing*/
,'S32130K'  /*Nondisplaced Zone III fracture of sacrum, subsequent encounter for fracture with nonunion*/
,'S32130S'  /*Nondisplaced Zone III fracture of sacrum, sequela*/
,'S32131D'  /*Minimally displaced Zone III fracture of sacrum, subsequent encounter for fracture with routine healing*/
,'S32131G'  /*Minimally displaced Zone III fracture of sacrum, subsequent encounter for fracture with delayed healing*/
,'S32131K'  /*Minimally displaced Zone III fracture of sacrum, subsequent encounter for fracture with nonunion*/
,'S32131S'  /*Minimally displaced Zone III fracture of sacrum, sequela*/
,'S32132D'  /*Severely displaced Zone III fracture of sacrum, subsequent encounter for fracture with routine healing*/
,'S32132G'  /*Severely displaced Zone III fracture of sacrum, subsequent encounter for fracture with delayed healing*/
,'S32132K'  /*Severely displaced Zone III fracture of sacrum, subsequent encounter for fracture with nonunion*/
,'S32132S'  /*Severely displaced Zone III fracture of sacrum, sequela*/
,'S32139D'  /*Unspecified Zone III fracture of sacrum, subsequent encounter for fracture with routine healing*/
,'S32139G'  /*Unspecified Zone III fracture of sacrum, subsequent encounter for fracture with delayed healing*/
,'S32139K'  /*Unspecified Zone III fracture of sacrum, subsequent encounter for fracture with nonunion*/
,'S32139S'  /*Unspecified Zone III fracture of sacrum, sequela*/
,'S3214XD'  /*Type 1 fracture of sacrum, subsequent encounter for fracture with routine healing*/
,'S3214XG'  /*Type 1 fracture of sacrum, subsequent encounter for fracture with delayed healing*/
,'S3214XK'  /*Type 1 fracture of sacrum, subsequent encounter for fracture with nonunion*/
,'S3214XS'  /*Type 1 fracture of sacrum, sequela*/
,'S3215XD'  /*Type 2 fracture of sacrum, subsequent encounter for fracture with routine healing*/
,'S3215XG'  /*Type 2 fracture of sacrum, subsequent encounter for fracture with delayed healing*/
,'S3215XK'  /*Type 2 fracture of sacrum, subsequent encounter for fracture with nonunion*/
,'S3215XS'  /*Type 2 fracture of sacrum, sequela*/
,'S3216XD'  /*Type 3 fracture of sacrum, subsequent encounter for fracture with routine healing*/
,'S3216XG'  /*Type 3 fracture of sacrum, subsequent encounter for fracture with delayed healing*/
,'S3216XK'  /*Type 3 fracture of sacrum, subsequent encounter for fracture with nonunion*/
,'S3216XS'  /*Type 3 fracture of sacrum, sequela*/
,'S3217XD'  /*Type 4 fracture of sacrum, subsequent encounter for fracture with routine healing*/
,'S3217XG'  /*Type 4 fracture of sacrum, subsequent encounter for fracture with delayed healing*/
,'S3217XK'  /*Type 4 fracture of sacrum, subsequent encounter for fracture with nonunion*/
,'S3217XS'  /*Type 4 fracture of sacrum, sequela*/
,'S3219XD'  /*Other fracture of sacrum, subsequent encounter for fracture with routine healing*/
,'S3219XG'  /*Other fracture of sacrum, subsequent encounter for fracture with delayed healing*/
,'S3219XK'  /*Other fracture of sacrum, subsequent encounter for fracture with nonunion*/
,'S3219XS'  /*Other fracture of sacrum, sequela*/
,'S322XXD'  /*Fracture of coccyx, subsequent encounter for fracture with routine healing*/
,'S322XXG'  /*Fracture of coccyx, subsequent encounter for fracture with delayed healing*/
,'S322XXK'  /*Fracture of coccyx, subsequent encounter for fracture with nonunion*/
,'S322XXS'  /*Fracture of coccyx, sequela*/
,'S32301D'  /*Unspecified fracture of right ilium, subsequent encounter for fracture with routine healing*/
,'S32301G'  /*Unspecified fracture of right ilium, subsequent encounter for fracture with delayed healing*/
,'S32301K'  /*Unspecified fracture of right ilium, subsequent encounter for fracture with nonunion*/
,'S32301S'  /*Unspecified fracture of right ilium, sequela*/
,'S32302D'  /*Unspecified fracture of left ilium, subsequent encounter for fracture with routine healing*/
,'S32302G'  /*Unspecified fracture of left ilium, subsequent encounter for fracture with delayed healing*/
,'S32302K'  /*Unspecified fracture of left ilium, subsequent encounter for fracture with nonunion*/
,'S32302S'  /*Unspecified fracture of left ilium, sequela*/
,'S32309D'  /*Unspecified fracture of unspecified ilium, subsequent encounter for fracture with routine healing*/
,'S32309G'  /*Unspecified fracture of unspecified ilium, subsequent encounter for fracture with delayed healing*/
,'S32309K'  /*Unspecified fracture of unspecified ilium, subsequent encounter for fracture with nonunion*/
,'S32309S'  /*Unspecified fracture of unspecified ilium, sequela*/
,'S32311D'  /*Displaced avulsion fracture of right ilium, subsequent encounter for fracture with routine healing*/
,'S32311G'  /*Displaced avulsion fracture of right ilium, subsequent encounter for fracture with delayed healing*/
,'S32311K'  /*Displaced avulsion fracture of right ilium, subsequent encounter for fracture with nonunion*/
,'S32311S'  /*Displaced avulsion fracture of right ilium, sequela*/
,'S32312D'  /*Displaced avulsion fracture of left ilium, subsequent encounter for fracture with routine healing*/
,'S32312G'  /*Displaced avulsion fracture of left ilium, subsequent encounter for fracture with delayed healing*/
,'S32312K'  /*Displaced avulsion fracture of left ilium, subsequent encounter for fracture with nonunion*/
,'S32312S'  /*Displaced avulsion fracture of left ilium, sequela*/
,'S32313D'  /*Displaced avulsion fracture of unspecified ilium, subsequent encounter for fracture with routine healing*/
,'S32313G'  /*Displaced avulsion fracture of unspecified ilium, subsequent encounter for fracture with delayed healing*/
,'S32313K'  /*Displaced avulsion fracture of unspecified ilium, subsequent encounter for fracture with nonunion*/
,'S32313S'  /*Displaced avulsion fracture of unspecified ilium, sequela*/
,'S32314D'  /*Nondisplaced avulsion fracture of right ilium, subsequent encounter for fracture with routine healing*/
,'S32314G'  /*Nondisplaced avulsion fracture of right ilium, subsequent encounter for fracture with delayed healing*/
,'S32314K'  /*Nondisplaced avulsion fracture of right ilium, subsequent encounter for fracture with nonunion*/
,'S32314S'  /*Nondisplaced avulsion fracture of right ilium, sequela*/
,'S32315D'  /*Nondisplaced avulsion fracture of left ilium, subsequent encounter for fracture with routine healing*/
,'S32315G'  /*Nondisplaced avulsion fracture of left ilium, subsequent encounter for fracture with delayed healing*/
,'S32315K'  /*Nondisplaced avulsion fracture of left ilium, subsequent encounter for fracture with nonunion*/
,'S32315S'  /*Nondisplaced avulsion fracture of left ilium, sequela*/
,'S32316D'  /*Nondisplaced avulsion fracture of unspecified ilium, subsequent encounter for fracture with routine healing*/
,'S32316G'  /*Nondisplaced avulsion fracture of unspecified ilium, subsequent encounter for fracture with delayed healing*/
,'S32316K'  /*Nondisplaced avulsion fracture of unspecified ilium, subsequent encounter for fracture with nonunion*/
,'S32316S'  /*Nondisplaced avulsion fracture of unspecified ilium, sequela*/
,'S32391D'  /*Other fracture of right ilium, subsequent encounter for fracture with routine healing*/
,'S32391G'  /*Other fracture of right ilium, subsequent encounter for fracture with delayed healing*/
,'S32391K'  /*Other fracture of right ilium, subsequent encounter for fracture with nonunion*/
,'S32391S'  /*Other fracture of right ilium, sequela*/
,'S32392D'  /*Other fracture of left ilium, subsequent encounter for fracture with routine healing*/
,'S32392G'  /*Other fracture of left ilium, subsequent encounter for fracture with delayed healing*/
,'S32392K'  /*Other fracture of left ilium, subsequent encounter for fracture with nonunion*/
,'S32392S'  /*Other fracture of left ilium, sequela*/
,'S32399D'  /*Other fracture of unspecified ilium, subsequent encounter for fracture with routine healing*/
,'S32399G'  /*Other fracture of unspecified ilium, subsequent encounter for fracture with delayed healing*/
,'S32399K'  /*Other fracture of unspecified ilium, subsequent encounter for fracture with nonunion*/
,'S32399S'  /*Other fracture of unspecified ilium, sequela*/
,'S32401D'  /*Unspecified fracture of right acetabulum, subsequent encounter for fracture with routine healing*/
,'S32401G'  /*Unspecified fracture of right acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32401K'  /*Unspecified fracture of right acetabulum, subsequent encounter for fracture with nonunion*/
,'S32401S'  /*Unspecified fracture of right acetabulum, sequela*/
,'S32402D'  /*Unspecified fracture of left acetabulum, subsequent encounter for fracture with routine healing*/
,'S32402G'  /*Unspecified fracture of left acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32402K'  /*Unspecified fracture of left acetabulum, subsequent encounter for fracture with nonunion*/
,'S32402S'  /*Unspecified fracture of left acetabulum, sequela*/
,'S32409D'  /*Unspecified fracture of unspecified acetabulum, subsequent encounter for fracture with routine healing*/
,'S32409G'  /*Unspecified fracture of unspecified acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32409K'  /*Unspecified fracture of unspecified acetabulum, subsequent encounter for fracture with nonunion*/
,'S32409S'  /*Unspecified fracture of unspecified acetabulum, sequela*/
,'S32411D'  /*Displaced fracture of anterior wall of right acetabulum, subsequent encounter for fracture with routine healing*/
,'S32411G'  /*Displaced fracture of anterior wall of right acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32411K'  /*Displaced fracture of anterior wall of right acetabulum, subsequent encounter for fracture with nonunion*/
,'S32411S'  /*Displaced fracture of anterior wall of right acetabulum, sequela*/
,'S32412D'  /*Displaced fracture of anterior wall of left acetabulum, subsequent encounter for fracture with routine healing*/
,'S32412G'  /*Displaced fracture of anterior wall of left acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32412K'  /*Displaced fracture of anterior wall of left acetabulum, subsequent encounter for fracture with nonunion*/
,'S32412S'  /*Displaced fracture of anterior wall of left acetabulum, sequela*/
,'S32413D'  /*Displaced fracture of anterior wall of unspecified acetabulum, subsequent encounter for fracture with routine healing*/
,'S32413G'  /*Displaced fracture of anterior wall of unspecified acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32413K'  /*Displaced fracture of anterior wall of unspecified acetabulum, subsequent encounter for fracture with nonunion*/
,'S32413S'  /*Displaced fracture of anterior wall of unspecified acetabulum, sequela*/
,'S32414D'  /*Nondisplaced fracture of anterior wall of right acetabulum, subsequent encounter for fracture with routine healing*/
,'S32414G'  /*Nondisplaced fracture of anterior wall of right acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32414K'  /*Nondisplaced fracture of anterior wall of right acetabulum, subsequent encounter for fracture with nonunion*/
,'S32414S'  /*Nondisplaced fracture of anterior wall of right acetabulum, sequela*/
,'S32415D'  /*Nondisplaced fracture of anterior wall of left acetabulum, subsequent encounter for fracture with routine healing*/
,'S32415G'  /*Nondisplaced fracture of anterior wall of left acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32415K'  /*Nondisplaced fracture of anterior wall of left acetabulum, subsequent encounter for fracture with nonunion*/
,'S32415S'  /*Nondisplaced fracture of anterior wall of left acetabulum, sequela*/
,'S32416D'  /*Nondisplaced fracture of anterior wall of unspecified acetabulum, subsequent encounter for fracture with routine healing*/
,'S32416G'  /*Nondisplaced fracture of anterior wall of unspecified acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32416K'  /*Nondisplaced fracture of anterior wall of unspecified acetabulum, subsequent encounter for fracture with nonunion*/
,'S32416S'  /*Nondisplaced fracture of anterior wall of unspecified acetabulum, sequela*/
,'S32421D'  /*Displaced fracture of posterior wall of right acetabulum, subsequent encounter for fracture with routine healing*/
,'S32421G'  /*Displaced fracture of posterior wall of right acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32421K'  /*Displaced fracture of posterior wall of right acetabulum, subsequent encounter for fracture with nonunion*/
,'S32421S'  /*Displaced fracture of posterior wall of right acetabulum, sequela*/
,'S32422D'  /*Displaced fracture of posterior wall of left acetabulum, subsequent encounter for fracture with routine healing*/
,'S32422G'  /*Displaced fracture of posterior wall of left acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32422K'  /*Displaced fracture of posterior wall of left acetabulum, subsequent encounter for fracture with nonunion*/
,'S32422S'  /*Displaced fracture of posterior wall of left acetabulum, sequela*/
,'S32423D'  /*Displaced fracture of posterior wall of unspecified acetabulum, subsequent encounter for fracture with routine healing*/
,'S32423G'  /*Displaced fracture of posterior wall of unspecified acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32423K'  /*Displaced fracture of posterior wall of unspecified acetabulum, subsequent encounter for fracture with nonunion*/
,'S32423S'  /*Displaced fracture of posterior wall of unspecified acetabulum, sequela*/
,'S32424D'  /*Nondisplaced fracture of posterior wall of right acetabulum, subsequent encounter for fracture with routine healing*/
,'S32424G'  /*Nondisplaced fracture of posterior wall of right acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32424K'  /*Nondisplaced fracture of posterior wall of right acetabulum, subsequent encounter for fracture with nonunion*/
,'S32424S'  /*Nondisplaced fracture of posterior wall of right acetabulum, sequela*/
,'S32425D'  /*Nondisplaced fracture of posterior wall of left acetabulum, subsequent encounter for fracture with routine healing*/
,'S32425G'  /*Nondisplaced fracture of posterior wall of left acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32425K'  /*Nondisplaced fracture of posterior wall of left acetabulum, subsequent encounter for fracture with nonunion*/
,'S32425S'  /*Nondisplaced fracture of posterior wall of left acetabulum, sequela*/
,'S32426D'  /*Nondisplaced fracture of posterior wall of unspecified acetabulum, subsequent encounter for fracture with routine healing*/
,'S32426G'  /*Nondisplaced fracture of posterior wall of unspecified acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32426K'  /*Nondisplaced fracture of posterior wall of unspecified acetabulum, subsequent encounter for fracture with nonunion*/
,'S32426S'  /*Nondisplaced fracture of posterior wall of unspecified acetabulum, sequela*/
,'S32431D'  /*Displaced fracture of anterior column [iliopubic] of right acetabulum, subsequent encounter for fracture with routine healing*/
,'S32431G'  /*Displaced fracture of anterior column [iliopubic] of right acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32431K'  /*Displaced fracture of anterior column [iliopubic] of right acetabulum, subsequent encounter for fracture with nonunion*/
,'S32431S'  /*Displaced fracture of anterior column [iliopubic] of right acetabulum, sequela*/
,'S32432D'  /*Displaced fracture of anterior column [iliopubic] of left acetabulum, subsequent encounter for fracture with routine healing*/
,'S32432G'  /*Displaced fracture of anterior column [iliopubic] of left acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32432K'  /*Displaced fracture of anterior column [iliopubic] of left acetabulum, subsequent encounter for fracture with nonunion*/
,'S32432S'  /*Displaced fracture of anterior column [iliopubic] of left acetabulum, sequela*/
,'S32433D'  /*Displaced fracture of anterior column [iliopubic] of unspecified acetabulum, subsequent encounter for fracture with routine healing*/
,'S32433G'  /*Displaced fracture of anterior column [iliopubic] of unspecified acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32433K'  /*Displaced fracture of anterior column [iliopubic] of unspecified acetabulum, subsequent encounter for fracture with nonunion*/
,'S32433S'  /*Displaced fracture of anterior column [iliopubic] of unspecified acetabulum, sequela*/
,'S32434D'  /*Nondisplaced fracture of anterior column [iliopubic] of right acetabulum, subsequent encounter for fracture with routine healing*/
,'S32434G'  /*Nondisplaced fracture of anterior column [iliopubic] of right acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32434K'  /*Nondisplaced fracture of anterior column [iliopubic] of right acetabulum, subsequent encounter for fracture with nonunion*/
,'S32434S'  /*Nondisplaced fracture of anterior column [iliopubic] of right acetabulum, sequela*/
,'S32435D'  /*Nondisplaced fracture of anterior column [iliopubic] of left acetabulum, subsequent encounter for fracture with routine healing*/
,'S32435G'  /*Nondisplaced fracture of anterior column [iliopubic] of left acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32435K'  /*Nondisplaced fracture of anterior column [iliopubic] of left acetabulum, subsequent encounter for fracture with nonunion*/
,'S32435S'  /*Nondisplaced fracture of anterior column [iliopubic] of left acetabulum, sequela*/
,'S32436D'  /*Nondisplaced fracture of anterior column [iliopubic] of unspecified acetabulum, subsequent encounter for fracture with routine healing*/
,'S32436G'  /*Nondisplaced fracture of anterior column [iliopubic] of unspecified acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32436K'  /*Nondisplaced fracture of anterior column [iliopubic] of unspecified acetabulum, subsequent encounter for fracture with nonunion*/
,'S32436S'  /*Nondisplaced fracture of anterior column [iliopubic] of unspecified acetabulum, sequela*/
,'S32441D'  /*Displaced fracture of posterior column [ilioischial] of right acetabulum, subsequent encounter for fracture with routine healing*/
,'S32441G'  /*Displaced fracture of posterior column [ilioischial] of right acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32441K'  /*Displaced fracture of posterior column [ilioischial] of right acetabulum, subsequent encounter for fracture with nonunion*/
,'S32441S'  /*Displaced fracture of posterior column [ilioischial] of right acetabulum, sequela*/
,'S32442D'  /*Displaced fracture of posterior column [ilioischial] of left acetabulum, subsequent encounter for fracture with routine healing*/
,'S32442G'  /*Displaced fracture of posterior column [ilioischial] of left acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32442K'  /*Displaced fracture of posterior column [ilioischial] of left acetabulum, subsequent encounter for fracture with nonunion*/
,'S32442S'  /*Displaced fracture of posterior column [ilioischial] of left acetabulum, sequela*/
,'S32443D'  /*Displaced fracture of posterior column [ilioischial] of unspecified acetabulum, subsequent encounter for fracture with routine healing*/
,'S32443G'  /*Displaced fracture of posterior column [ilioischial] of unspecified acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32443K'  /*Displaced fracture of posterior column [ilioischial] of unspecified acetabulum, subsequent encounter for fracture with nonunion*/
,'S32443S'  /*Displaced fracture of posterior column [ilioischial] of unspecified acetabulum, sequela*/
,'S32444D'  /*Nondisplaced fracture of posterior column [ilioischial] of right acetabulum, subsequent encounter for fracture with routine healing*/
,'S32444G'  /*Nondisplaced fracture of posterior column [ilioischial] of right acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32444K'  /*Nondisplaced fracture of posterior column [ilioischial] of right acetabulum, subsequent encounter for fracture with nonunion*/
,'S32444S'  /*Nondisplaced fracture of posterior column [ilioischial] of right acetabulum, sequela*/
,'S32445D'  /*Nondisplaced fracture of posterior column [ilioischial] of left acetabulum, subsequent encounter for fracture with routine healing*/
,'S32445G'  /*Nondisplaced fracture of posterior column [ilioischial] of left acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32445K'  /*Nondisplaced fracture of posterior column [ilioischial] of left acetabulum, subsequent encounter for fracture with nonunion*/
,'S32445S'  /*Nondisplaced fracture of posterior column [ilioischial] of left acetabulum, sequela*/
,'S32446D'  /*Nondisplaced fracture of posterior column [ilioischial] of unspecified acetabulum, subsequent encounter for fracture with routine healing*/
,'S32446G'  /*Nondisplaced fracture of posterior column [ilioischial] of unspecified acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32446K'  /*Nondisplaced fracture of posterior column [ilioischial] of unspecified acetabulum, subsequent encounter for fracture with nonunion*/
,'S32446S'  /*Nondisplaced fracture of posterior column [ilioischial] of unspecified acetabulum, sequela*/
,'S32451D'  /*Displaced transverse fracture of right acetabulum, subsequent encounter for fracture with routine healing*/
,'S32451G'  /*Displaced transverse fracture of right acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32451K'  /*Displaced transverse fracture of right acetabulum, subsequent encounter for fracture with nonunion*/
,'S32451S'  /*Displaced transverse fracture of right acetabulum, sequela*/
,'S32452D'  /*Displaced transverse fracture of left acetabulum, subsequent encounter for fracture with routine healing*/
,'S32452G'  /*Displaced transverse fracture of left acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32452K'  /*Displaced transverse fracture of left acetabulum, subsequent encounter for fracture with nonunion*/
,'S32452S'  /*Displaced transverse fracture of left acetabulum, sequela*/
,'S32453D'  /*Displaced transverse fracture of unspecified acetabulum, subsequent encounter for fracture with routine healing*/
,'S32453G'  /*Displaced transverse fracture of unspecified acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32453K'  /*Displaced transverse fracture of unspecified acetabulum, subsequent encounter for fracture with nonunion*/
,'S32453S'  /*Displaced transverse fracture of unspecified acetabulum, sequela*/
,'S32454D'  /*Nondisplaced transverse fracture of right acetabulum, subsequent encounter for fracture with routine healing*/
,'S32454G'  /*Nondisplaced transverse fracture of right acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32454K'  /*Nondisplaced transverse fracture of right acetabulum, subsequent encounter for fracture with nonunion*/
,'S32454S'  /*Nondisplaced transverse fracture of right acetabulum, sequela*/
,'S32455D'  /*Nondisplaced transverse fracture of left acetabulum, subsequent encounter for fracture with routine healing*/
,'S32455G'  /*Nondisplaced transverse fracture of left acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32455K'  /*Nondisplaced transverse fracture of left acetabulum, subsequent encounter for fracture with nonunion*/
,'S32455S'  /*Nondisplaced transverse fracture of left acetabulum, sequela*/
,'S32456D'  /*Nondisplaced transverse fracture of unspecified acetabulum, subsequent encounter for fracture with routine healing*/
,'S32456G'  /*Nondisplaced transverse fracture of unspecified acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32456K'  /*Nondisplaced transverse fracture of unspecified acetabulum, subsequent encounter for fracture with nonunion*/
,'S32456S'  /*Nondisplaced transverse fracture of unspecified acetabulum, sequela*/
,'S32461D'  /*Displaced associated transverse-posterior fracture of right acetabulum, subsequent encounter for fracture with routine healing*/
,'S32461G'  /*Displaced associated transverse-posterior fracture of right acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32461K'  /*Displaced associated transverse-posterior fracture of right acetabulum, subsequent encounter for fracture with nonunion*/
,'S32461S'  /*Displaced associated transverse-posterior fracture of right acetabulum, sequela*/
,'S32462D'  /*Displaced associated transverse-posterior fracture of left acetabulum, subsequent encounter for fracture with routine healing*/
,'S32462G'  /*Displaced associated transverse-posterior fracture of left acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32462K'  /*Displaced associated transverse-posterior fracture of left acetabulum, subsequent encounter for fracture with nonunion*/
,'S32462S'  /*Displaced associated transverse-posterior fracture of left acetabulum, sequela*/
,'S32463D'  /*Displaced associated transverse-posterior fracture of unspecified acetabulum, subsequent encounter for fracture with routine healing*/
,'S32463G'  /*Displaced associated transverse-posterior fracture of unspecified acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32463K'  /*Displaced associated transverse-posterior fracture of unspecified acetabulum, subsequent encounter for fracture with nonunion*/
,'S32463S'  /*Displaced associated transverse-posterior fracture of unspecified acetabulum, sequela*/
,'S32464D'  /*Nondisplaced associated transverse-posterior fracture of right acetabulum, subsequent encounter for fracture with routine healing*/
,'S32464G'  /*Nondisplaced associated transverse-posterior fracture of right acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32464K'  /*Nondisplaced associated transverse-posterior fracture of right acetabulum, subsequent encounter for fracture with nonunion*/
,'S32464S'  /*Nondisplaced associated transverse-posterior fracture of right acetabulum, sequela*/
,'S32465D'  /*Nondisplaced associated transverse-posterior fracture of left acetabulum, subsequent encounter for fracture with routine healing*/
,'S32465G'  /*Nondisplaced associated transverse-posterior fracture of left acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32465K'  /*Nondisplaced associated transverse-posterior fracture of left acetabulum, subsequent encounter for fracture with nonunion*/
,'S32465S'  /*Nondisplaced associated transverse-posterior fracture of left acetabulum, sequela*/
,'S32466D'  /*Nondisplaced associated transverse-posterior fracture of unspecified acetabulum, subsequent encounter for fracture with routine healing*/
,'S32466G'  /*Nondisplaced associated transverse-posterior fracture of unspecified acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32466K'  /*Nondisplaced associated transverse-posterior fracture of unspecified acetabulum, subsequent encounter for fracture with nonunion*/
,'S32466S'  /*Nondisplaced associated transverse-posterior fracture of unspecified acetabulum, sequela*/
,'S32471D'  /*Displaced fracture of medial wall of right acetabulum, subsequent encounter for fracture with routine healing*/
,'S32471G'  /*Displaced fracture of medial wall of right acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32471K'  /*Displaced fracture of medial wall of right acetabulum, subsequent encounter for fracture with nonunion*/
,'S32471S'  /*Displaced fracture of medial wall of right acetabulum, sequela*/
,'S32472D'  /*Displaced fracture of medial wall of left acetabulum, subsequent encounter for fracture with routine healing*/
,'S32472G'  /*Displaced fracture of medial wall of left acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32472K'  /*Displaced fracture of medial wall of left acetabulum, subsequent encounter for fracture with nonunion*/
,'S32472S'  /*Displaced fracture of medial wall of left acetabulum, sequela*/
,'S32473D'  /*Displaced fracture of medial wall of unspecified acetabulum, subsequent encounter for fracture with routine healing*/
,'S32473G'  /*Displaced fracture of medial wall of unspecified acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32473K'  /*Displaced fracture of medial wall of unspecified acetabulum, subsequent encounter for fracture with nonunion*/
,'S32473S'  /*Displaced fracture of medial wall of unspecified acetabulum, sequela*/
,'S32474D'  /*Nondisplaced fracture of medial wall of right acetabulum, subsequent encounter for fracture with routine healing*/
,'S32474G'  /*Nondisplaced fracture of medial wall of right acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32474K'  /*Nondisplaced fracture of medial wall of right acetabulum, subsequent encounter for fracture with nonunion*/
,'S32474S'  /*Nondisplaced fracture of medial wall of right acetabulum, sequela*/
,'S32475D'  /*Nondisplaced fracture of medial wall of left acetabulum, subsequent encounter for fracture with routine healing*/
,'S32475G'  /*Nondisplaced fracture of medial wall of left acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32475K'  /*Nondisplaced fracture of medial wall of left acetabulum, subsequent encounter for fracture with nonunion*/
,'S32475S'  /*Nondisplaced fracture of medial wall of left acetabulum, sequela*/
,'S32476D'  /*Nondisplaced fracture of medial wall of unspecified acetabulum, subsequent encounter for fracture with routine healing*/
,'S32476G'  /*Nondisplaced fracture of medial wall of unspecified acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32476K'  /*Nondisplaced fracture of medial wall of unspecified acetabulum, subsequent encounter for fracture with nonunion*/
,'S32476S'  /*Nondisplaced fracture of medial wall of unspecified acetabulum, sequela*/
,'S32481D'  /*Displaced dome fracture of right acetabulum, subsequent encounter for fracture with routine healing*/
,'S32481G'  /*Displaced dome fracture of right acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32481K'  /*Displaced dome fracture of right acetabulum, subsequent encounter for fracture with nonunion*/
,'S32481S'  /*Displaced dome fracture of right acetabulum, sequela*/
,'S32482D'  /*Displaced dome fracture of left acetabulum, subsequent encounter for fracture with routine healing*/
,'S32482G'  /*Displaced dome fracture of left acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32482K'  /*Displaced dome fracture of left acetabulum, subsequent encounter for fracture with nonunion*/
,'S32482S'  /*Displaced dome fracture of left acetabulum, sequela*/
,'S32483D'  /*Displaced dome fracture of unspecified acetabulum, subsequent encounter for fracture with routine healing*/
,'S32483G'  /*Displaced dome fracture of unspecified acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32483K'  /*Displaced dome fracture of unspecified acetabulum, subsequent encounter for fracture with nonunion*/
,'S32483S'  /*Displaced dome fracture of unspecified acetabulum, sequela*/
,'S32484D'  /*Nondisplaced dome fracture of right acetabulum, subsequent encounter for fracture with routine healing*/
,'S32484G'  /*Nondisplaced dome fracture of right acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32484K'  /*Nondisplaced dome fracture of right acetabulum, subsequent encounter for fracture with nonunion*/
,'S32484S'  /*Nondisplaced dome fracture of right acetabulum, sequela*/
,'S32485D'  /*Nondisplaced dome fracture of left acetabulum, subsequent encounter for fracture with routine healing*/
,'S32485G'  /*Nondisplaced dome fracture of left acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32485K'  /*Nondisplaced dome fracture of left acetabulum, subsequent encounter for fracture with nonunion*/
,'S32485S'  /*Nondisplaced dome fracture of left acetabulum, sequela*/
,'S32486D'  /*Nondisplaced dome fracture of unspecified acetabulum, subsequent encounter for fracture with routine healing*/
,'S32486G'  /*Nondisplaced dome fracture of unspecified acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32486K'  /*Nondisplaced dome fracture of unspecified acetabulum, subsequent encounter for fracture with nonunion*/
,'S32486S'  /*Nondisplaced dome fracture of unspecified acetabulum, sequela*/
,'S32491D'  /*Other specified fracture of right acetabulum, subsequent encounter for fracture with routine healing*/
,'S32491G'  /*Other specified fracture of right acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32491K'  /*Other specified fracture of right acetabulum, subsequent encounter for fracture with nonunion*/
,'S32491S'  /*Other specified fracture of right acetabulum, sequela*/
,'S32492D'  /*Other specified fracture of left acetabulum, subsequent encounter for fracture with routine healing*/
,'S32492G'  /*Other specified fracture of left acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32492K'  /*Other specified fracture of left acetabulum, subsequent encounter for fracture with nonunion*/
,'S32492S'  /*Other specified fracture of left acetabulum, sequela*/
,'S32499D'  /*Other specified fracture of unspecified acetabulum, subsequent encounter for fracture with routine healing*/
,'S32499G'  /*Other specified fracture of unspecified acetabulum, subsequent encounter for fracture with delayed healing*/
,'S32499K'  /*Other specified fracture of unspecified acetabulum, subsequent encounter for fracture with nonunion*/
,'S32499S'  /*Other specified fracture of unspecified acetabulum, sequela*/
,'S32501D'  /*Unspecified fracture of right pubis, subsequent encounter for fracture with routine healing*/
,'S32501G'  /*Unspecified fracture of right pubis, subsequent encounter for fracture with delayed healing*/
,'S32501K'  /*Unspecified fracture of right pubis, subsequent encounter for fracture with nonunion*/
,'S32501S'  /*Unspecified fracture of right pubis, sequela*/
,'S32502D'  /*Unspecified fracture of left pubis, subsequent encounter for fracture with routine healing*/
,'S32502G'  /*Unspecified fracture of left pubis, subsequent encounter for fracture with delayed healing*/
,'S32502K'  /*Unspecified fracture of left pubis, subsequent encounter for fracture with nonunion*/
,'S32502S'  /*Unspecified fracture of left pubis, sequela*/
,'S32509D'  /*Unspecified fracture of unspecified pubis, subsequent encounter for fracture with routine healing*/
,'S32509G'  /*Unspecified fracture of unspecified pubis, subsequent encounter for fracture with delayed healing*/
,'S32509K'  /*Unspecified fracture of unspecified pubis, subsequent encounter for fracture with nonunion*/
,'S32509S'  /*Unspecified fracture of unspecified pubis, sequela*/
,'S32511D'  /*Fracture of superior rim of right pubis, subsequent encounter for fracture with routine healing*/
,'S32511G'  /*Fracture of superior rim of right pubis, subsequent encounter for fracture with delayed healing*/
,'S32511K'  /*Fracture of superior rim of right pubis, subsequent encounter for fracture with nonunion*/
,'S32511S'  /*Fracture of superior rim of right pubis, sequela*/
,'S32512D'  /*Fracture of superior rim of left pubis, subsequent encounter for fracture with routine healing*/
,'S32512G'  /*Fracture of superior rim of left pubis, subsequent encounter for fracture with delayed healing*/
,'S32512K'  /*Fracture of superior rim of left pubis, subsequent encounter for fracture with nonunion*/
,'S32512S'  /*Fracture of superior rim of left pubis, sequela*/
,'S32519D'  /*Fracture of superior rim of unspecified pubis, subsequent encounter for fracture with routine healing*/
,'S32519G'  /*Fracture of superior rim of unspecified pubis, subsequent encounter for fracture with delayed healing*/
,'S32519K'  /*Fracture of superior rim of unspecified pubis, subsequent encounter for fracture with nonunion*/
,'S32519S'  /*Fracture of superior rim of unspecified pubis, sequela*/
,'S32591D'  /*Other specified fracture of right pubis, subsequent encounter for fracture with routine healing*/
,'S32591G'  /*Other specified fracture of right pubis, subsequent encounter for fracture with delayed healing*/
,'S32591K'  /*Other specified fracture of right pubis, subsequent encounter for fracture with nonunion*/
,'S32591S'  /*Other specified fracture of right pubis, sequela*/
,'S32592D'  /*Other specified fracture of left pubis, subsequent encounter for fracture with routine healing*/
,'S32592G'  /*Other specified fracture of left pubis, subsequent encounter for fracture with delayed healing*/
,'S32592K'  /*Other specified fracture of left pubis, subsequent encounter for fracture with nonunion*/
,'S32592S'  /*Other specified fracture of left pubis, sequela*/
,'S32599D'  /*Other specified fracture of unspecified pubis, subsequent encounter for fracture with routine healing*/
,'S32599G'  /*Other specified fracture of unspecified pubis, subsequent encounter for fracture with delayed healing*/
,'S32599K'  /*Other specified fracture of unspecified pubis, subsequent encounter for fracture with nonunion*/
,'S32599S'  /*Other specified fracture of unspecified pubis, sequela*/
,'S32601D'  /*Unspecified fracture of right ischium, subsequent encounter for fracture with routine healing*/
,'S32601G'  /*Unspecified fracture of right ischium, subsequent encounter for fracture with delayed healing*/
,'S32601K'  /*Unspecified fracture of right ischium, subsequent encounter for fracture with nonunion*/
,'S32601S'  /*Unspecified fracture of right ischium, sequela*/
,'S32602D'  /*Unspecified fracture of left ischium, subsequent encounter for fracture with routine healing*/
,'S32602G'  /*Unspecified fracture of left ischium, subsequent encounter for fracture with delayed healing*/
,'S32602K'  /*Unspecified fracture of left ischium, subsequent encounter for fracture with nonunion*/
,'S32602S'  /*Unspecified fracture of left ischium, sequela*/
,'S32609D'  /*Unspecified fracture of unspecified ischium, subsequent encounter for fracture with routine healing*/
,'S32609G'  /*Unspecified fracture of unspecified ischium, subsequent encounter for fracture with delayed healing*/
,'S32609K'  /*Unspecified fracture of unspecified ischium, subsequent encounter for fracture with nonunion*/
,'S32609S'  /*Unspecified fracture of unspecified ischium, sequela*/
,'S32611D'  /*Displaced avulsion fracture of right ischium, subsequent encounter for fracture with routine healing*/
,'S32611G'  /*Displaced avulsion fracture of right ischium, subsequent encounter for fracture with delayed healing*/
,'S32611K'  /*Displaced avulsion fracture of right ischium, subsequent encounter for fracture with nonunion*/
,'S32611S'  /*Displaced avulsion fracture of right ischium, sequela*/
,'S32612D'  /*Displaced avulsion fracture of left ischium, subsequent encounter for fracture with routine healing*/
,'S32612G'  /*Displaced avulsion fracture of left ischium, subsequent encounter for fracture with delayed healing*/
,'S32612K'  /*Displaced avulsion fracture of left ischium, subsequent encounter for fracture with nonunion*/
,'S32612S'  /*Displaced avulsion fracture of left ischium, sequela*/
,'S32613D'  /*Displaced avulsion fracture of unspecified ischium, subsequent encounter for fracture with routine healing*/
,'S32613G'  /*Displaced avulsion fracture of unspecified ischium, subsequent encounter for fracture with delayed healing*/
,'S32613K'  /*Displaced avulsion fracture of unspecified ischium, subsequent encounter for fracture with nonunion*/
,'S32613S'  /*Displaced avulsion fracture of unspecified ischium, sequela*/
,'S32614D'  /*Nondisplaced avulsion fracture of right ischium, subsequent encounter for fracture with routine healing*/
,'S32614G'  /*Nondisplaced avulsion fracture of right ischium, subsequent encounter for fracture with delayed healing*/
,'S32614K'  /*Nondisplaced avulsion fracture of right ischium, subsequent encounter for fracture with nonunion*/
,'S32614S'  /*Nondisplaced avulsion fracture of right ischium, sequela*/
,'S32615D'  /*Nondisplaced avulsion fracture of left ischium, subsequent encounter for fracture with routine healing*/
,'S32615G'  /*Nondisplaced avulsion fracture of left ischium, subsequent encounter for fracture with delayed healing*/
,'S32615K'  /*Nondisplaced avulsion fracture of left ischium, subsequent encounter for fracture with nonunion*/
,'S32615S'  /*Nondisplaced avulsion fracture of left ischium, sequela*/
,'S32616D'  /*Nondisplaced avulsion fracture of unspecified ischium, subsequent encounter for fracture with routine healing*/
,'S32616G'  /*Nondisplaced avulsion fracture of unspecified ischium, subsequent encounter for fracture with delayed healing*/
,'S32616K'  /*Nondisplaced avulsion fracture of unspecified ischium, subsequent encounter for fracture with nonunion*/
,'S32616S'  /*Nondisplaced avulsion fracture of unspecified ischium, sequela*/
,'S32691D'  /*Other specified fracture of right ischium, subsequent encounter for fracture with routine healing*/
,'S32691G'  /*Other specified fracture of right ischium, subsequent encounter for fracture with delayed healing*/
,'S32691K'  /*Other specified fracture of right ischium, subsequent encounter for fracture with nonunion*/
,'S32691S'  /*Other specified fracture of right ischium, sequela*/
,'S32692D'  /*Other specified fracture of left ischium, subsequent encounter for fracture with routine healing*/
,'S32692G'  /*Other specified fracture of left ischium, subsequent encounter for fracture with delayed healing*/
,'S32692K'  /*Other specified fracture of left ischium, subsequent encounter for fracture with nonunion*/
,'S32692S'  /*Other specified fracture of left ischium, sequela*/
,'S32699D'  /*Other specified fracture of unspecified ischium, subsequent encounter for fracture with routine healing*/
,'S32699G'  /*Other specified fracture of unspecified ischium, subsequent encounter for fracture with delayed healing*/
,'S32699K'  /*Other specified fracture of unspecified ischium, subsequent encounter for fracture with nonunion*/
,'S32699S'  /*Other specified fracture of unspecified ischium, sequela*/
,'S32810D'  /*Multiple fractures of pelvis with stable disruption of pelvic ring, subsequent encounter for fracture with routine healing*/
,'S32810G'  /*Multiple fractures of pelvis with stable disruption of pelvic ring, subsequent encounter for fracture with delayed healing*/
,'S32810K'  /*Multiple fractures of pelvis with stable disruption of pelvic ring, subsequent encounter for fracture with nonunion*/
,'S32810S'  /*Multiple fractures of pelvis with stable disruption of pelvic ring, sequela*/
,'S32811D'  /*Multiple fractures of pelvis with unstable disruption of pelvic ring, subsequent encounter for fracture with routine healing*/
,'S32811G'  /*Multiple fractures of pelvis with unstable disruption of pelvic ring, subsequent encounter for fracture with delayed healing*/
,'S32811K'  /*Multiple fractures of pelvis with unstable disruption of pelvic ring, subsequent encounter for fracture with nonunion*/
,'S32811S'  /*Multiple fractures of pelvis with unstable disruption of pelvic ring, sequela*/
,'S3282XD'  /*Multiple fractures of pelvis without disruption of pelvic ring, subsequent encounter for fracture with routine healing*/
,'S3282XG'  /*Multiple fractures of pelvis without disruption of pelvic ring, subsequent encounter for fracture with delayed healing*/
,'S3282XK'  /*Multiple fractures of pelvis without disruption of pelvic ring, subsequent encounter for fracture with nonunion*/
,'S3282XS'  /*Multiple fractures of pelvis without disruption of pelvic ring, sequela*/
,'S3289XD'  /*Fracture of other parts of pelvis, subsequent encounter for fracture with routine healing*/
,'S3289XG'  /*Fracture of other parts of pelvis, subsequent encounter for fracture with delayed healing*/
,'S3289XK'  /*Fracture of other parts of pelvis, subsequent encounter for fracture with nonunion*/
,'S3289XS'  /*Fracture of other parts of pelvis, sequela*/
,'S329XXD'  /*Fracture of unspecified parts of lumbosacral spine and pelvis, subsequent encounter for fracture with routine healing*/
,'S329XXG'  /*Fracture of unspecified parts of lumbosacral spine and pelvis, subsequent encounter for fracture with delayed healing*/
,'S329XXK'  /*Fracture of unspecified parts of lumbosacral spine and pelvis, subsequent encounter for fracture with nonunion*/
,'S329XXS'  /*Fracture of unspecified parts of lumbosacral spine and pelvis, sequela*/
,'S330XXD'  /*Traumatic rupture of lumbar intervertebral disc, subsequent encounter*/
,'S330XXS'  /*Traumatic rupture of lumbar intervertebral disc, sequela*/
,'S33100D'  /*Subluxation of unspecified lumbar vertebra, subsequent encounter*/
,'S33100S'  /*Subluxation of unspecified lumbar vertebra, sequela*/
,'S33101D'  /*Dislocation of unspecified lumbar vertebra, subsequent encounter*/
,'S33101S'  /*Dislocation of unspecified lumbar vertebra, sequela*/
,'S33110D'  /*Subluxation of L1/L2 lumbar vertebra, subsequent encounter*/
,'S33110S'  /*Subluxation of L1/L2 lumbar vertebra, sequela*/
,'S33111D'  /*Dislocation of L1/L2 lumbar vertebra, subsequent encounter*/
,'S33111S'  /*Dislocation of L1/L2 lumbar vertebra, sequela*/
,'S33120D'  /*Subluxation of L2/L3 lumbar vertebra, subsequent encounter*/
,'S33120S'  /*Subluxation of L2/L3 lumbar vertebra, sequela*/
,'S33121D'  /*Dislocation of L2/L3 lumbar vertebra, subsequent encounter*/
,'S33121S'  /*Dislocation of L2/L3 lumbar vertebra, sequela*/
,'S33130D'  /*Subluxation of L3/L4 lumbar vertebra, subsequent encounter*/
,'S33130S'  /*Subluxation of L3/L4 lumbar vertebra, sequela*/
,'S33131D'  /*Dislocation of L3/L4 lumbar vertebra, subsequent encounter*/
,'S33131S'  /*Dislocation of L3/L4 lumbar vertebra, sequela*/
,'S33140D'  /*Subluxation of L4/L5 lumbar vertebra, subsequent encounter*/
,'S33140S'  /*Subluxation of L4/L5 lumbar vertebra, sequela*/
,'S33141D'  /*Dislocation of L4/L5 lumbar vertebra, subsequent encounter*/
,'S33141S'  /*Dislocation of L4/L5 lumbar vertebra, sequela*/
,'S332XXD'  /*Dislocation of sacroiliac and sacrococcygeal joint, subsequent encounter*/
,'S332XXS'  /*Dislocation of sacroiliac and sacrococcygeal joint, sequela*/
,'S3330XD'  /*Dislocation of unspecified parts of lumbar spine and pelvis, subsequent encounter*/
,'S3330XS'  /*Dislocation of unspecified parts of lumbar spine and pelvis, sequela*/
,'S3339XD'  /*Dislocation of other parts of lumbar spine and pelvis, subsequent encounter*/
,'S3339XS'  /*Dislocation of other parts of lumbar spine and pelvis, sequela*/
,'S334XXD'  /*Traumatic rupture of symphysis pubis, subsequent encounter*/
,'S334XXS'  /*Traumatic rupture of symphysis pubis, sequela*/
,'S335XXD'  /*Sprain of ligaments of lumbar spine, subsequent encounter*/
,'S335XXS'  /*Sprain of ligaments of lumbar spine, sequela*/
,'S336XXD'  /*Sprain of sacroiliac joint, subsequent encounter*/
,'S336XXS'  /*Sprain of sacroiliac joint, sequela*/
,'S338XXD'  /*Sprain of other parts of lumbar spine and pelvis, subsequent encounter*/
,'S338XXS'  /*Sprain of other parts of lumbar spine and pelvis, sequela*/
,'S339XXD'  /*Sprain of unspecified parts of lumbar spine and pelvis, subsequent encounter*/
,'S339XXS'  /*Sprain of unspecified parts of lumbar spine and pelvis, sequela*/
,'S3401XD'  /*Concussion and edema of lumbar spinal cord, subsequent encounter*/
,'S3401XS'  /*Concussion and edema of lumbar spinal cord, sequela*/
,'S3402XD'  /*Concussion and edema of sacral spinal cord, subsequent encounter*/
,'S3402XS'  /*Concussion and edema of sacral spinal cord, sequela*/
,'S34101D'  /*Unspecified injury to L1 level of lumbar spinal cord, subsequent encounter*/
,'S34101S'  /*Unspecified injury to L1 level of lumbar spinal cord, sequela*/
,'S34102D'  /*Unspecified injury to L2 level of lumbar spinal cord, subsequent encounter*/
,'S34102S'  /*Unspecified injury to L2 level of lumbar spinal cord, sequela*/
,'S34103D'  /*Unspecified injury to L3 level of lumbar spinal cord, subsequent encounter*/
,'S34103S'  /*Unspecified injury to L3 level of lumbar spinal cord, sequela*/
,'S34104D'  /*Unspecified injury to L4 level of lumbar spinal cord, subsequent encounter*/
,'S34104S'  /*Unspecified injury to L4 level of lumbar spinal cord, sequela*/
,'S34105D'  /*Unspecified injury to L5 level of lumbar spinal cord, subsequent encounter*/
,'S34105S'  /*Unspecified injury to L5 level of lumbar spinal cord, sequela*/
,'S34109D'  /*Unspecified injury to unspecified level of lumbar spinal cord, subsequent encounter*/
,'S34109S'  /*Unspecified injury to unspecified level of lumbar spinal cord, sequela*/
,'S34111D'  /*Complete lesion of L1 level of lumbar spinal cord, subsequent encounter*/
,'S34111S'  /*Complete lesion of L1 level of lumbar spinal cord, sequela*/
,'S34112D'  /*Complete lesion of L2 level of lumbar spinal cord, subsequent encounter*/
,'S34112S'  /*Complete lesion of L2 level of lumbar spinal cord, sequela*/
,'S34113D'  /*Complete lesion of L3 level of lumbar spinal cord, subsequent encounter*/
,'S34113S'  /*Complete lesion of L3 level of lumbar spinal cord, sequela*/
,'S34114D'  /*Complete lesion of L4 level of lumbar spinal cord, subsequent encounter*/
,'S34114S'  /*Complete lesion of L4 level of lumbar spinal cord, sequela*/
,'S34115D'  /*Complete lesion of L5 level of lumbar spinal cord, subsequent encounter*/
,'S34115S'  /*Complete lesion of L5 level of lumbar spinal cord, sequela*/
,'S34119D'  /*Complete lesion of unspecified level of lumbar spinal cord, subsequent encounter*/
,'S34119S'  /*Complete lesion of unspecified level of lumbar spinal cord, sequela*/
,'S34121D'  /*Incomplete lesion of L1 level of lumbar spinal cord, subsequent encounter*/
,'S34121S'  /*Incomplete lesion of L1 level of lumbar spinal cord, sequela*/
,'S34122D'  /*Incomplete lesion of L2 level of lumbar spinal cord, subsequent encounter*/
,'S34122S'  /*Incomplete lesion of L2 level of lumbar spinal cord, sequela*/
,'S34123D'  /*Incomplete lesion of L3 level of lumbar spinal cord, subsequent encounter*/
,'S34123S'  /*Incomplete lesion of L3 level of lumbar spinal cord, sequela*/
,'S34124D'  /*Incomplete lesion of L4 level of lumbar spinal cord, subsequent encounter*/
,'S34124S'  /*Incomplete lesion of L4 level of lumbar spinal cord, sequela*/
,'S34125D'  /*Incomplete lesion of L5 level of lumbar spinal cord, subsequent encounter*/
,'S34125S'  /*Incomplete lesion of L5 level of lumbar spinal cord, sequela*/
,'S34129D'  /*Incomplete lesion of unspecified level of lumbar spinal cord, subsequent encounter*/
,'S34129S'  /*Incomplete lesion of unspecified level of lumbar spinal cord, sequela*/
,'S34131D'  /*Complete lesion of sacral spinal cord, subsequent encounter*/
,'S34131S'  /*Complete lesion of sacral spinal cord, sequela*/
,'S34132D'  /*Incomplete lesion of sacral spinal cord, subsequent encounter*/
,'S34132S'  /*Incomplete lesion of sacral spinal cord, sequela*/
,'S34139D'  /*Unspecified injury to sacral spinal cord, subsequent encounter*/
,'S34139S'  /*Unspecified injury to sacral spinal cord, sequela*/
,'S3421XD'  /*Injury of nerve root of lumbar spine, subsequent encounter*/
,'S3421XS'  /*Injury of nerve root of lumbar spine, sequela*/
,'S3422XD'  /*Injury of nerve root of sacral spine, subsequent encounter*/
,'S3422XS'  /*Injury of nerve root of sacral spine, sequela*/
,'S343XXD'  /*Injury of cauda equina, subsequent encounter*/
,'S343XXS'  /*Injury of cauda equina, sequela*/
,'S344XXD'  /*Injury of lumbosacral plexus, subsequent encounter*/
,'S344XXS'  /*Injury of lumbosacral plexus, sequela*/
,'S345XXD'  /*Injury of lumbar, sacral and pelvic sympathetic nerves, subsequent encounter*/
,'S345XXS'  /*Injury of lumbar, sacral and pelvic sympathetic nerves, sequela*/
,'S346XXD'  /*Injury of peripheral nerve(s) at abdomen, lower back and pelvis level, subsequent encounter*/
,'S346XXS'  /*Injury of peripheral nerve(s) at abdomen, lower back and pelvis level, sequela*/
,'S348XXD'  /*Injury of other nerves at abdomen, lower back and pelvis level, subsequent encounter*/
,'S348XXS'  /*Injury of other nerves at abdomen, lower back and pelvis level, sequela*/
,'S349XXD'  /*Injury of unspecified nerves at abdomen, lower back and pelvis level, subsequent encounter*/
,'S349XXS'  /*Injury of unspecified nerves at abdomen, lower back and pelvis level, sequela*/
,'S3500XD'  /*Unspecified injury of abdominal aorta, subsequent encounter*/
,'S3500XS'  /*Unspecified injury of abdominal aorta, sequela*/
,'S3501XD'  /*Minor laceration of abdominal aorta, subsequent encounter*/
,'S3501XS'  /*Minor laceration of abdominal aorta, sequela*/
,'S3502XD'  /*Major laceration of abdominal aorta, subsequent encounter*/
,'S3502XS'  /*Major laceration of abdominal aorta, sequela*/
,'S3509XD'  /*Other injury of abdominal aorta, subsequent encounter*/
,'S3509XS'  /*Other injury of abdominal aorta, sequela*/
,'S3510XD'  /*Unspecified injury of inferior vena cava, subsequent encounter*/
,'S3510XS'  /*Unspecified injury of inferior vena cava, sequela*/
,'S3511XD'  /*Minor laceration of inferior vena cava, subsequent encounter*/
,'S3511XS'  /*Minor laceration of inferior vena cava, sequela*/
,'S3512XD'  /*Major laceration of inferior vena cava, subsequent encounter*/
,'S3512XS'  /*Major laceration of inferior vena cava, sequela*/
,'S3519XD'  /*Other injury of inferior vena cava, subsequent encounter*/
,'S3519XS'  /*Other injury of inferior vena cava, sequela*/
,'S35211D'  /*Minor laceration of celiac artery, subsequent encounter*/
,'S35211S'  /*Minor laceration of celiac artery, sequela*/
,'S35212D'  /*Major laceration of celiac artery, subsequent encounter*/
,'S35212S'  /*Major laceration of celiac artery, sequela*/
,'S35218D'  /*Other injury of celiac artery, subsequent encounter*/
,'S35218S'  /*Other injury of celiac artery, sequela*/
,'S35219D'  /*Unspecified injury of celiac artery, subsequent encounter*/
,'S35219S'  /*Unspecified injury of celiac artery, sequela*/
,'S35221D'  /*Minor laceration of superior mesenteric artery, subsequent encounter*/
,'S35221S'  /*Minor laceration of superior mesenteric artery, sequela*/
,'S35222D'  /*Major laceration of superior mesenteric artery, subsequent encounter*/
,'S35222S'  /*Major laceration of superior mesenteric artery, sequela*/
,'S35228D'  /*Other injury of superior mesenteric artery, subsequent encounter*/
,'S35228S'  /*Other injury of superior mesenteric artery, sequela*/
,'S35229D'  /*Unspecified injury of superior mesenteric artery, subsequent encounter*/
,'S35229S'  /*Unspecified injury of superior mesenteric artery, sequela*/
,'S35231D'  /*Minor laceration of inferior mesenteric artery, subsequent encounter*/
,'S35231S'  /*Minor laceration of inferior mesenteric artery, sequela*/
,'S35232D'  /*Major laceration of inferior mesenteric artery, subsequent encounter*/
,'S35232S'  /*Major laceration of inferior mesenteric artery, sequela*/
,'S35238D'  /*Other injury of inferior mesenteric artery, subsequent encounter*/
,'S35238S'  /*Other injury of inferior mesenteric artery, sequela*/
,'S35239D'  /*Unspecified injury of inferior mesenteric artery, subsequent encounter*/
,'S35239S'  /*Unspecified injury of inferior mesenteric artery, sequela*/
,'S35291D'  /*Minor laceration of branches of celiac and mesenteric artery, subsequent encounter*/
,'S35291S'  /*Minor laceration of branches of celiac and mesenteric artery, sequela*/
,'S35292D'  /*Major laceration of branches of celiac and mesenteric artery, subsequent encounter*/
,'S35292S'  /*Major laceration of branches of celiac and mesenteric artery, sequela*/
,'S35298D'  /*Other injury of branches of celiac and mesenteric artery, subsequent encounter*/
,'S35298S'  /*Other injury of branches of celiac and mesenteric artery, sequela*/
,'S35299D'  /*Unspecified injury of branches of celiac and mesenteric artery, subsequent encounter*/
,'S35299S'  /*Unspecified injury of branches of celiac and mesenteric artery, sequela*/
,'S35311D'  /*Laceration of portal vein, subsequent encounter*/
,'S35311S'  /*Laceration of portal vein, sequela*/
,'S35318D'  /*Other specified injury of portal vein, subsequent encounter*/
,'S35318S'  /*Other specified injury of portal vein, sequela*/
,'S35319D'  /*Unspecified injury of portal vein, subsequent encounter*/
,'S35319S'  /*Unspecified injury of portal vein, sequela*/
,'S35321D'  /*Laceration of splenic vein, subsequent encounter*/
,'S35321S'  /*Laceration of splenic vein, sequela*/
,'S35328D'  /*Other specified injury of splenic vein, subsequent encounter*/
,'S35328S'  /*Other specified injury of splenic vein, sequela*/
,'S35329D'  /*Unspecified injury of splenic vein, subsequent encounter*/
,'S35329S'  /*Unspecified injury of splenic vein, sequela*/
,'S35331D'  /*Laceration of superior mesenteric vein, subsequent encounter*/
,'S35331S'  /*Laceration of superior mesenteric vein, sequela*/
,'S35338D'  /*Other specified injury of superior mesenteric vein, subsequent encounter*/
,'S35338S'  /*Other specified injury of superior mesenteric vein, sequela*/
,'S35339D'  /*Unspecified injury of superior mesenteric vein, subsequent encounter*/
,'S35339S'  /*Unspecified injury of superior mesenteric vein, sequela*/
,'S35341D'  /*Laceration of inferior mesenteric vein, subsequent encounter*/
,'S35341S'  /*Laceration of inferior mesenteric vein, sequela*/
,'S35348D'  /*Other specified injury of inferior mesenteric vein, subsequent encounter*/
,'S35348S'  /*Other specified injury of inferior mesenteric vein, sequela*/
,'S35349D'  /*Unspecified injury of inferior mesenteric vein, subsequent encounter*/
,'S35349S'  /*Unspecified injury of inferior mesenteric vein, sequela*/
,'S35401D'  /*Unspecified injury of right renal artery, subsequent encounter*/
,'S35401S'  /*Unspecified injury of right renal artery, sequela*/
,'S35402D'  /*Unspecified injury of left renal artery, subsequent encounter*/
,'S35402S'  /*Unspecified injury of left renal artery, sequela*/
,'S35403D'  /*Unspecified injury of unspecified renal artery, subsequent encounter*/
,'S35403S'  /*Unspecified injury of unspecified renal artery, sequela*/
,'S35404D'  /*Unspecified injury of right renal vein, subsequent encounter*/
,'S35404S'  /*Unspecified injury of right renal vein, sequela*/
,'S35405D'  /*Unspecified injury of left renal vein, subsequent encounter*/
,'S35405S'  /*Unspecified injury of left renal vein, sequela*/
,'S35406D'  /*Unspecified injury of unspecified renal vein, subsequent encounter*/
,'S35406S'  /*Unspecified injury of unspecified renal vein, sequela*/
,'S35411D'  /*Laceration of right renal artery, subsequent encounter*/
,'S35411S'  /*Laceration of right renal artery, sequela*/
,'S35412D'  /*Laceration of left renal artery, subsequent encounter*/
,'S35412S'  /*Laceration of left renal artery, sequela*/
,'S35413D'  /*Laceration of unspecified renal artery, subsequent encounter*/
,'S35413S'  /*Laceration of unspecified renal artery, sequela*/
,'S35414D'  /*Laceration of right renal vein, subsequent encounter*/
,'S35414S'  /*Laceration of right renal vein, sequela*/
,'S35415D'  /*Laceration of left renal vein, subsequent encounter*/
,'S35415S'  /*Laceration of left renal vein, sequela*/
,'S35416D'  /*Laceration of unspecified renal vein, subsequent encounter*/
,'S35416S'  /*Laceration of unspecified renal vein, sequela*/
,'S35491D'  /*Other specified injury of right renal artery, subsequent encounter*/
,'S35491S'  /*Other specified injury of right renal artery, sequela*/
,'S35492D'  /*Other specified injury of left renal artery, subsequent encounter*/
,'S35492S'  /*Other specified injury of left renal artery, sequela*/
,'S35493D'  /*Other specified injury of unspecified renal artery, subsequent encounter*/
,'S35493S'  /*Other specified injury of unspecified renal artery, sequela*/
,'S35494D'  /*Other specified injury of right renal vein, subsequent encounter*/
,'S35494S'  /*Other specified injury of right renal vein, sequela*/
,'S35495D'  /*Other specified injury of left renal vein, subsequent encounter*/
,'S35495S'  /*Other specified injury of left renal vein, sequela*/
,'S35496D'  /*Other specified injury of unspecified renal vein, subsequent encounter*/
,'S35496S'  /*Other specified injury of unspecified renal vein, sequela*/
,'S3550XD'  /*Injury of unspecified iliac blood vessel(s), subsequent encounter*/
,'S3550XS'  /*Injury of unspecified iliac blood vessel(s), sequela*/
,'S35511D'  /*Injury of right iliac artery, subsequent encounter*/
,'S35511S'  /*Injury of right iliac artery, sequela*/
,'S35512D'  /*Injury of left iliac artery, subsequent encounter*/
,'S35512S'  /*Injury of left iliac artery, sequela*/
,'S35513D'  /*Injury of unspecified iliac artery, subsequent encounter*/
,'S35513S'  /*Injury of unspecified iliac artery, sequela*/
,'S35514D'  /*Injury of right iliac vein, subsequent encounter*/
,'S35514S'  /*Injury of right iliac vein, sequela*/
,'S35515D'  /*Injury of left iliac vein, subsequent encounter*/
,'S35515S'  /*Injury of left iliac vein, sequela*/
,'S35516D'  /*Injury of unspecified iliac vein, subsequent encounter*/
,'S35516S'  /*Injury of unspecified iliac vein, sequela*/
,'S35531D'  /*Injury of right uterine artery, subsequent encounter*/
,'S35531S'  /*Injury of right uterine artery, sequela*/
,'S35532D'  /*Injury of left uterine artery, subsequent encounter*/
,'S35532S'  /*Injury of left uterine artery, sequela*/
,'S35533D'  /*Injury of unspecified uterine artery, subsequent encounter*/
,'S35533S'  /*Injury of unspecified uterine artery, sequela*/
,'S35534D'  /*Injury of right uterine vein, subsequent encounter*/
,'S35534S'  /*Injury of right uterine vein, sequela*/
,'S35535D'  /*Injury of left uterine vein, subsequent encounter*/
,'S35535S'  /*Injury of left uterine vein, sequela*/
,'S35536D'  /*Injury of unspecified uterine vein, subsequent encounter*/
,'S35536S'  /*Injury of unspecified uterine vein, sequela*/
,'S3559XD'  /*Injury of other iliac blood vessels, subsequent encounter*/
,'S3559XS'  /*Injury of other iliac blood vessels, sequela*/
,'S358X1D'  /*Laceration of other blood vessels at abdomen, lower back and pelvis level, subsequent encounter*/
,'S358X1S'  /*Laceration of other blood vessels at abdomen, lower back and pelvis level, sequela*/
,'S358X8D'  /*Other specified injury of other blood vessels at abdomen, lower back and pelvis level, subsequent encounter*/
,'S358X8S'  /*Other specified injury of other blood vessels at abdomen, lower back and pelvis level, sequela*/
,'S358X9D'  /*Unspecified injury of other blood vessels at abdomen, lower back and pelvis level, subsequent encounter*/
,'S358X9S'  /*Unspecified injury of other blood vessels at abdomen, lower back and pelvis level, sequela*/
,'S3590XD'  /*Unspecified injury of unspecified blood vessel at abdomen, lower back and pelvis level, subsequent encounter*/
,'S3590XS'  /*Unspecified injury of unspecified blood vessel at abdomen, lower back and pelvis level, sequela*/
,'S3591XD'  /*Laceration of unspecified blood vessel at abdomen, lower back and pelvis level, subsequent encounter*/
,'S3591XS'  /*Laceration of unspecified blood vessel at abdomen, lower back and pelvis level, sequela*/
,'S3599XD'  /*Other specified injury of unspecified blood vessel at abdomen, lower back and pelvis level, subsequent encounter*/
,'S3599XS'  /*Other specified injury of unspecified blood vessel at abdomen, lower back and pelvis level, sequela*/
,'S3600XD'  /*Unspecified injury of spleen, subsequent encounter*/
,'S3600XS'  /*Unspecified injury of spleen, sequela*/
,'S36020D'  /*Minor contusion of spleen, subsequent encounter*/
,'S36020S'  /*Minor contusion of spleen, sequela*/
,'S36021D'  /*Major contusion of spleen, subsequent encounter*/
,'S36021S'  /*Major contusion of spleen, sequela*/
,'S36029D'  /*Unspecified contusion of spleen, subsequent encounter*/
,'S36029S'  /*Unspecified contusion of spleen, sequela*/
,'S36030D'  /*Superficial (capsular) laceration of spleen, subsequent encounter*/
,'S36030S'  /*Superficial (capsular) laceration of spleen, sequela*/
,'S36031D'  /*Moderate laceration of spleen, subsequent encounter*/
,'S36031S'  /*Moderate laceration of spleen, sequela*/
,'S36032D'  /*Major laceration of spleen, subsequent encounter*/
,'S36032S'  /*Major laceration of spleen, sequela*/
,'S36039D'  /*Unspecified laceration of spleen, subsequent encounter*/
,'S36039S'  /*Unspecified laceration of spleen, sequela*/
,'S3609XD'  /*Other injury of spleen, subsequent encounter*/
,'S3609XS'  /*Other injury of spleen, sequela*/
,'S36112D'  /*Contusion of liver, subsequent encounter*/
,'S36112S'  /*Contusion of liver, sequela*/
,'S36113D'  /*Laceration of liver, unspecified degree, subsequent encounter*/
,'S36113S'  /*Laceration of liver, unspecified degree, sequela*/
,'S36114D'  /*Minor laceration of liver, subsequent encounter*/
,'S36114S'  /*Minor laceration of liver, sequela*/
,'S36115D'  /*Moderate laceration of liver, subsequent encounter*/
,'S36115S'  /*Moderate laceration of liver, sequela*/
,'S36116D'  /*Major laceration of liver, subsequent encounter*/
,'S36116S'  /*Major laceration of liver, sequela*/
,'S36118D'  /*Other injury of liver, subsequent encounter*/
,'S36118S'  /*Other injury of liver, sequela*/
,'S36119D'  /*Unspecified injury of liver, subsequent encounter*/
,'S36119S'  /*Unspecified injury of liver, sequela*/
,'S36122D'  /*Contusion of gallbladder, subsequent encounter*/
,'S36122S'  /*Contusion of gallbladder, sequela*/
,'S36123D'  /*Laceration of gallbladder, subsequent encounter*/
,'S36123S'  /*Laceration of gallbladder, sequela*/
,'S36128D'  /*Other injury of gallbladder, subsequent encounter*/
,'S36128S'  /*Other injury of gallbladder, sequela*/
,'S36129D'  /*Unspecified injury of gallbladder, subsequent encounter*/
,'S36129S'  /*Unspecified injury of gallbladder, sequela*/
,'S3613XD'  /*Injury of bile duct, subsequent encounter*/
,'S3613XS'  /*Injury of bile duct, sequela*/
,'S36200D'  /*Unspecified injury of head of pancreas, subsequent encounter*/
,'S36200S'  /*Unspecified injury of head of pancreas, sequela*/
,'S36201D'  /*Unspecified injury of body of pancreas, subsequent encounter*/
,'S36201S'  /*Unspecified injury of body of pancreas, sequela*/
,'S36202D'  /*Unspecified injury of tail of pancreas, subsequent encounter*/
,'S36202S'  /*Unspecified injury of tail of pancreas, sequela*/
,'S36209D'  /*Unspecified injury of unspecified part of pancreas, subsequent encounter*/
,'S36209S'  /*Unspecified injury of unspecified part of pancreas, sequela*/
,'S36220D'  /*Contusion of head of pancreas, subsequent encounter*/
,'S36220S'  /*Contusion of head of pancreas, sequela*/
,'S36221D'  /*Contusion of body of pancreas, subsequent encounter*/
,'S36221S'  /*Contusion of body of pancreas, sequela*/
,'S36222D'  /*Contusion of tail of pancreas, subsequent encounter*/
,'S36222S'  /*Contusion of tail of pancreas, sequela*/
,'S36229D'  /*Contusion of unspecified part of pancreas, subsequent encounter*/
,'S36229S'  /*Contusion of unspecified part of pancreas, sequela*/
,'S36230D'  /*Laceration of head of pancreas, unspecified degree, subsequent encounter*/
,'S36230S'  /*Laceration of head of pancreas, unspecified degree, sequela*/
,'S36231D'  /*Laceration of body of pancreas, unspecified degree, subsequent encounter*/
,'S36231S'  /*Laceration of body of pancreas, unspecified degree, sequela*/
,'S36232D'  /*Laceration of tail of pancreas, unspecified degree, subsequent encounter*/
,'S36232S'  /*Laceration of tail of pancreas, unspecified degree, sequela*/
,'S36239D'  /*Laceration of unspecified part of pancreas, unspecified degree, subsequent encounter*/
,'S36239S'  /*Laceration of unspecified part of pancreas, unspecified degree, sequela*/
,'S36240D'  /*Minor laceration of head of pancreas, subsequent encounter*/
,'S36240S'  /*Minor laceration of head of pancreas, sequela*/
,'S36241D'  /*Minor laceration of body of pancreas, subsequent encounter*/
,'S36241S'  /*Minor laceration of body of pancreas, sequela*/
,'S36242D'  /*Minor laceration of tail of pancreas, subsequent encounter*/
,'S36242S'  /*Minor laceration of tail of pancreas, sequela*/
,'S36249D'  /*Minor laceration of unspecified part of pancreas, subsequent encounter*/
,'S36249S'  /*Minor laceration of unspecified part of pancreas, sequela*/
,'S36250D'  /*Moderate laceration of head of pancreas, subsequent encounter*/
,'S36250S'  /*Moderate laceration of head of pancreas, sequela*/
,'S36251D'  /*Moderate laceration of body of pancreas, subsequent encounter*/
,'S36251S'  /*Moderate laceration of body of pancreas, sequela*/
,'S36252D'  /*Moderate laceration of tail of pancreas, subsequent encounter*/
,'S36252S'  /*Moderate laceration of tail of pancreas, sequela*/
,'S36259D'  /*Moderate laceration of unspecified part of pancreas, subsequent encounter*/
,'S36259S'  /*Moderate laceration of unspecified part of pancreas, sequela*/
,'S36260D'  /*Major laceration of head of pancreas, subsequent encounter*/
,'S36260S'  /*Major laceration of head of pancreas, sequela*/
,'S36261D'  /*Major laceration of body of pancreas, subsequent encounter*/
,'S36261S'  /*Major laceration of body of pancreas, sequela*/
,'S36262D'  /*Major laceration of tail of pancreas, subsequent encounter*/
,'S36262S'  /*Major laceration of tail of pancreas, sequela*/
,'S36269D'  /*Major laceration of unspecified part of pancreas, subsequent encounter*/
,'S36269S'  /*Major laceration of unspecified part of pancreas, sequela*/
,'S36290D'  /*Other injury of head of pancreas, subsequent encounter*/
,'S36290S'  /*Other injury of head of pancreas, sequela*/
,'S36291D'  /*Other injury of body of pancreas, subsequent encounter*/
,'S36291S'  /*Other injury of body of pancreas, sequela*/
,'S36292D'  /*Other injury of tail of pancreas, subsequent encounter*/
,'S36292S'  /*Other injury of tail of pancreas, sequela*/
,'S36299D'  /*Other injury of unspecified part of pancreas, subsequent encounter*/
,'S36299S'  /*Other injury of unspecified part of pancreas, sequela*/
,'S3630XD'  /*Unspecified injury of stomach, subsequent encounter*/
,'S3630XS'  /*Unspecified injury of stomach, sequela*/
,'S3632XD'  /*Contusion of stomach, subsequent encounter*/
,'S3632XS'  /*Contusion of stomach, sequela*/
,'S3633XD'  /*Laceration of stomach, subsequent encounter*/
,'S3633XS'  /*Laceration of stomach, sequela*/
,'S3639XD'  /*Other injury of stomach, subsequent encounter*/
,'S3639XS'  /*Other injury of stomach, sequela*/
,'S36400D'  /*Unspecified injury of duodenum, subsequent encounter*/
,'S36400S'  /*Unspecified injury of duodenum, sequela*/
,'S36408D'  /*Unspecified injury of other part of small intestine, subsequent encounter*/
,'S36408S'  /*Unspecified injury of other part of small intestine, sequela*/
,'S36409D'  /*Unspecified injury of unspecified part of small intestine, subsequent encounter*/
,'S36409S'  /*Unspecified injury of unspecified part of small intestine, sequela*/
,'S36410D'  /*Primary blast injury of duodenum, subsequent encounter*/
,'S36410S'  /*Primary blast injury of duodenum, sequela*/
,'S36418D'  /*Primary blast injury of other part of small intestine, subsequent encounter*/
,'S36418S'  /*Primary blast injury of other part of small intestine, sequela*/
,'S36419D'  /*Primary blast injury of unspecified part of small intestine, subsequent encounter*/
,'S36419S'  /*Primary blast injury of unspecified part of small intestine, sequela*/
,'S36420D'  /*Contusion of duodenum, subsequent encounter*/
,'S36420S'  /*Contusion of duodenum, sequela*/
,'S36428D'  /*Contusion of other part of small intestine, subsequent encounter*/
,'S36428S'  /*Contusion of other part of small intestine, sequela*/
,'S36429D'  /*Contusion of unspecified part of small intestine, subsequent encounter*/
,'S36429S'  /*Contusion of unspecified part of small intestine, sequela*/
,'S36430D'  /*Laceration of duodenum, subsequent encounter*/
,'S36430S'  /*Laceration of duodenum, sequela*/
,'S36438D'  /*Laceration of other part of small intestine, subsequent encounter*/
,'S36438S'  /*Laceration of other part of small intestine, sequela*/
,'S36439D'  /*Laceration of unspecified part of small intestine, subsequent encounter*/
,'S36439S'  /*Laceration of unspecified part of small intestine, sequela*/
,'S36490D'  /*Other injury of duodenum, subsequent encounter*/
,'S36490S'  /*Other injury of duodenum, sequela*/
,'S36498D'  /*Other injury of other part of small intestine, subsequent encounter*/
,'S36498S'  /*Other injury of other part of small intestine, sequela*/
,'S36499D'  /*Other injury of unspecified part of small intestine, subsequent encounter*/
,'S36499S'  /*Other injury of unspecified part of small intestine, sequela*/
,'S36500D'  /*Unspecified injury of ascending [right] colon, subsequent encounter*/
,'S36500S'  /*Unspecified injury of ascending [right] colon, sequela*/
,'S36501D'  /*Unspecified injury of transverse colon, subsequent encounter*/
,'S36501S'  /*Unspecified injury of transverse colon, sequela*/
,'S36502D'  /*Unspecified injury of descending [left] colon, subsequent encounter*/
,'S36502S'  /*Unspecified injury of descending [left] colon, sequela*/
,'S36503D'  /*Unspecified injury of sigmoid colon, subsequent encounter*/
,'S36503S'  /*Unspecified injury of sigmoid colon, sequela*/
,'S36508D'  /*Unspecified injury of other part of colon, subsequent encounter*/
,'S36508S'  /*Unspecified injury of other part of colon, sequela*/
,'S36509D'  /*Unspecified injury of unspecified part of colon, subsequent encounter*/
,'S36509S'  /*Unspecified injury of unspecified part of colon, sequela*/
,'S36510D'  /*Primary blast injury of ascending [right] colon, subsequent encounter*/
,'S36510S'  /*Primary blast injury of ascending [right] colon, sequela*/
,'S36511D'  /*Primary blast injury of transverse colon, subsequent encounter*/
,'S36511S'  /*Primary blast injury of transverse colon, sequela*/
,'S36512D'  /*Primary blast injury of descending [left] colon, subsequent encounter*/
,'S36512S'  /*Primary blast injury of descending [left] colon, sequela*/
,'S36513D'  /*Primary blast injury of sigmoid colon, subsequent encounter*/
,'S36513S'  /*Primary blast injury of sigmoid colon, sequela*/
,'S36518D'  /*Primary blast injury of other part of colon, subsequent encounter*/
,'S36518S'  /*Primary blast injury of other part of colon, sequela*/
,'S36519D'  /*Primary blast injury of unspecified part of colon, subsequent encounter*/
,'S36519S'  /*Primary blast injury of unspecified part of colon, sequela*/
,'S36520D'  /*Contusion of ascending [right] colon, subsequent encounter*/
,'S36520S'  /*Contusion of ascending [right] colon, sequela*/
,'S36521D'  /*Contusion of transverse colon, subsequent encounter*/
,'S36521S'  /*Contusion of transverse colon, sequela*/
,'S36522D'  /*Contusion of descending [left] colon, subsequent encounter*/
,'S36522S'  /*Contusion of descending [left] colon, sequela*/
,'S36523D'  /*Contusion of sigmoid colon, subsequent encounter*/
,'S36523S'  /*Contusion of sigmoid colon, sequela*/
,'S36528D'  /*Contusion of other part of colon, subsequent encounter*/
,'S36528S'  /*Contusion of other part of colon, sequela*/
,'S36529D'  /*Contusion of unspecified part of colon, subsequent encounter*/
,'S36529S'  /*Contusion of unspecified part of colon, sequela*/
,'S36530D'  /*Laceration of ascending [right] colon, subsequent encounter*/
,'S36530S'  /*Laceration of ascending [right] colon, sequela*/
,'S36531D'  /*Laceration of transverse colon, subsequent encounter*/
,'S36531S'  /*Laceration of transverse colon, sequela*/
,'S36532D'  /*Laceration of descending [left] colon, subsequent encounter*/
,'S36532S'  /*Laceration of descending [left] colon, sequela*/
,'S36533D'  /*Laceration of sigmoid colon, subsequent encounter*/
,'S36533S'  /*Laceration of sigmoid colon, sequela*/
,'S36538D'  /*Laceration of other part of colon, subsequent encounter*/
,'S36538S'  /*Laceration of other part of colon, sequela*/
,'S36539D'  /*Laceration of unspecified part of colon, subsequent encounter*/
,'S36539S'  /*Laceration of unspecified part of colon, sequela*/
,'S36590D'  /*Other injury of ascending [right] colon, subsequent encounter*/
,'S36590S'  /*Other injury of ascending [right] colon, sequela*/
,'S36591D'  /*Other injury of transverse colon, subsequent encounter*/
,'S36591S'  /*Other injury of transverse colon, sequela*/
,'S36592D'  /*Other injury of descending [left] colon, subsequent encounter*/
,'S36592S'  /*Other injury of descending [left] colon, sequela*/
,'S36593D'  /*Other injury of sigmoid colon, subsequent encounter*/
,'S36593S'  /*Other injury of sigmoid colon, sequela*/
,'S36598D'  /*Other injury of other part of colon, subsequent encounter*/
,'S36598S'  /*Other injury of other part of colon, sequela*/
,'S36599D'  /*Other injury of unspecified part of colon, subsequent encounter*/
,'S36599S'  /*Other injury of unspecified part of colon, sequela*/
,'S3660XD'  /*Unspecified injury of rectum, subsequent encounter*/
,'S3660XS'  /*Unspecified injury of rectum, sequela*/
,'S3661XD'  /*Primary blast injury of rectum, subsequent encounter*/
,'S3661XS'  /*Primary blast injury of rectum, sequela*/
,'S3662XD'  /*Contusion of rectum, subsequent encounter*/
,'S3662XS'  /*Contusion of rectum, sequela*/
,'S3663XD'  /*Laceration of rectum, subsequent encounter*/
,'S3663XS'  /*Laceration of rectum, sequela*/
,'S3669XD'  /*Other injury of rectum, subsequent encounter*/
,'S3669XS'  /*Other injury of rectum, sequela*/
,'S3681XD'  /*Injury of peritoneum, subsequent encounter*/
,'S3681XS'  /*Injury of peritoneum, sequela*/
,'S36892D'  /*Contusion of other intra-abdominal organs, subsequent encounter*/
,'S36892S'  /*Contusion of other intra-abdominal organs, sequela*/
,'S36893D'  /*Laceration of other intra-abdominal organs, subsequent encounter*/
,'S36893S'  /*Laceration of other intra-abdominal organs, sequela*/
,'S36898D'  /*Other injury of other intra-abdominal organs, subsequent encounter*/
,'S36898S'  /*Other injury of other intra-abdominal organs, sequela*/
,'S36899D'  /*Unspecified injury of other intra-abdominal organs, subsequent encounter*/
,'S36899S'  /*Unspecified injury of other intra-abdominal organs, sequela*/
,'S3690XD'  /*Unspecified injury of unspecified intra-abdominal organ, subsequent encounter*/
,'S3690XS'  /*Unspecified injury of unspecified intra-abdominal organ, sequela*/
,'S3692XD'  /*Contusion of unspecified intra-abdominal organ, subsequent encounter*/
,'S3692XS'  /*Contusion of unspecified intra-abdominal organ, sequela*/
,'S3693XD'  /*Laceration of unspecified intra-abdominal organ, subsequent encounter*/
,'S3693XS'  /*Laceration of unspecified intra-abdominal organ, sequela*/
,'S3699XD'  /*Other injury of unspecified intra-abdominal organ, subsequent encounter*/
,'S3699XS'  /*Other injury of unspecified intra-abdominal organ, sequela*/
,'S37001D'  /*Unspecified injury of right kidney, subsequent encounter*/
,'S37001S'  /*Unspecified injury of right kidney, sequela*/
,'S37002D'  /*Unspecified injury of left kidney, subsequent encounter*/
,'S37002S'  /*Unspecified injury of left kidney, sequela*/
,'S37009D'  /*Unspecified injury of unspecified kidney, subsequent encounter*/
,'S37009S'  /*Unspecified injury of unspecified kidney, sequela*/
,'S37011D'  /*Minor contusion of right kidney, subsequent encounter*/
,'S37011S'  /*Minor contusion of right kidney, sequela*/
,'S37012D'  /*Minor contusion of left kidney, subsequent encounter*/
,'S37012S'  /*Minor contusion of left kidney, sequela*/
,'S37019D'  /*Minor contusion of unspecified kidney, subsequent encounter*/
,'S37019S'  /*Minor contusion of unspecified kidney, sequela*/
,'S37021D'  /*Major contusion of right kidney, subsequent encounter*/
,'S37021S'  /*Major contusion of right kidney, sequela*/
,'S37022D'  /*Major contusion of left kidney, subsequent encounter*/
,'S37022S'  /*Major contusion of left kidney, sequela*/
,'S37029D'  /*Major contusion of unspecified kidney, subsequent encounter*/
,'S37029S'  /*Major contusion of unspecified kidney, sequela*/
,'S37031D'  /*Laceration of right kidney, unspecified degree, subsequent encounter*/
,'S37031S'  /*Laceration of right kidney, unspecified degree, sequela*/
,'S37032D'  /*Laceration of left kidney, unspecified degree, subsequent encounter*/
,'S37032S'  /*Laceration of left kidney, unspecified degree, sequela*/
,'S37039D'  /*Laceration of unspecified kidney, unspecified degree, subsequent encounter*/
,'S37039S'  /*Laceration of unspecified kidney, unspecified degree, sequela*/
,'S37041D'  /*Minor laceration of right kidney, subsequent encounter*/
,'S37041S'  /*Minor laceration of right kidney, sequela*/
,'S37042D'  /*Minor laceration of left kidney, subsequent encounter*/
,'S37042S'  /*Minor laceration of left kidney, sequela*/
,'S37049D'  /*Minor laceration of unspecified kidney, subsequent encounter*/
,'S37049S'  /*Minor laceration of unspecified kidney, sequela*/
,'S37051D'  /*Moderate laceration of right kidney, subsequent encounter*/
,'S37051S'  /*Moderate laceration of right kidney, sequela*/
,'S37052D'  /*Moderate laceration of left kidney, subsequent encounter*/
,'S37052S'  /*Moderate laceration of left kidney, sequela*/
,'S37059D'  /*Moderate laceration of unspecified kidney, subsequent encounter*/
,'S37059S'  /*Moderate laceration of unspecified kidney, sequela*/
,'S37061D'  /*Major laceration of right kidney, subsequent encounter*/
,'S37061S'  /*Major laceration of right kidney, sequela*/
,'S37062D'  /*Major laceration of left kidney, subsequent encounter*/
,'S37062S'  /*Major laceration of left kidney, sequela*/
,'S37069D'  /*Major laceration of unspecified kidney, subsequent encounter*/
,'S37069S'  /*Major laceration of unspecified kidney, sequela*/
,'S37091D'  /*Other injury of right kidney, subsequent encounter*/
,'S37091S'  /*Other injury of right kidney, sequela*/
,'S37092D'  /*Other injury of left kidney, subsequent encounter*/
,'S37092S'  /*Other injury of left kidney, sequela*/
,'S37099D'  /*Other injury of unspecified kidney, subsequent encounter*/
,'S37099S'  /*Other injury of unspecified kidney, sequela*/
,'S3710XD'  /*Unspecified injury of ureter, subsequent encounter*/
,'S3710XS'  /*Unspecified injury of ureter, sequela*/
,'S3712XD'  /*Contusion of ureter, subsequent encounter*/
,'S3712XS'  /*Contusion of ureter, sequela*/
,'S3713XD'  /*Laceration of ureter, subsequent encounter*/
,'S3713XS'  /*Laceration of ureter, sequela*/
,'S3719XD'  /*Other injury of ureter, subsequent encounter*/
,'S3719XS'  /*Other injury of ureter, sequela*/
,'S3720XD'  /*Unspecified injury of bladder, subsequent encounter*/
,'S3720XS'  /*Unspecified injury of bladder, sequela*/
,'S3722XD'  /*Contusion of bladder, subsequent encounter*/
,'S3722XS'  /*Contusion of bladder, sequela*/
,'S3723XD'  /*Laceration of bladder, subsequent encounter*/
,'S3723XS'  /*Laceration of bladder, sequela*/
,'S3729XD'  /*Other injury of bladder, subsequent encounter*/
,'S3729XS'  /*Other injury of bladder, sequela*/
,'S3730XD'  /*Unspecified injury of urethra, subsequent encounter*/
,'S3730XS'  /*Unspecified injury of urethra, sequela*/
,'S3732XD'  /*Contusion of urethra, subsequent encounter*/
,'S3732XS'  /*Contusion of urethra, sequela*/
,'S3733XD'  /*Laceration of urethra, subsequent encounter*/
,'S3733XS'  /*Laceration of urethra, sequela*/
,'S3739XD'  /*Other injury of urethra, subsequent encounter*/
,'S3739XS'  /*Other injury of urethra, sequela*/
,'S37401D'  /*Unspecified injury of ovary, unilateral, subsequent encounter*/
,'S37401S'  /*Unspecified injury of ovary, unilateral, sequela*/
,'S37402D'  /*Unspecified injury of ovary, bilateral, subsequent encounter*/
,'S37402S'  /*Unspecified injury of ovary, bilateral, sequela*/
,'S37409D'  /*Unspecified injury of ovary, unspecified, subsequent encounter*/
,'S37409S'  /*Unspecified injury of ovary, unspecified, sequela*/
,'S37421D'  /*Contusion of ovary, unilateral, subsequent encounter*/
,'S37421S'  /*Contusion of ovary, unilateral, sequela*/
,'S37422D'  /*Contusion of ovary, bilateral, subsequent encounter*/
,'S37422S'  /*Contusion of ovary, bilateral, sequela*/
,'S37429D'  /*Contusion of ovary, unspecified, subsequent encounter*/
,'S37429S'  /*Contusion of ovary, unspecified, sequela*/
,'S37431D'  /*Laceration of ovary, unilateral, subsequent encounter*/
,'S37431S'  /*Laceration of ovary, unilateral, sequela*/
,'S37432D'  /*Laceration of ovary, bilateral, subsequent encounter*/
,'S37432S'  /*Laceration of ovary, bilateral, sequela*/
,'S37439D'  /*Laceration of ovary, unspecified, subsequent encounter*/
,'S37439S'  /*Laceration of ovary, unspecified, sequela*/
,'S37491D'  /*Other injury of ovary, unilateral, subsequent encounter*/
,'S37491S'  /*Other injury of ovary, unilateral, sequela*/
,'S37492D'  /*Other injury of ovary, bilateral, subsequent encounter*/
,'S37492S'  /*Other injury of ovary, bilateral, sequela*/
,'S37499D'  /*Other injury of ovary, unspecified, subsequent encounter*/
,'S37499S'  /*Other injury of ovary, unspecified, sequela*/
,'S37501D'  /*Unspecified injury of fallopian tube, unilateral, subsequent encounter*/
,'S37501S'  /*Unspecified injury of fallopian tube, unilateral, sequela*/
,'S37502D'  /*Unspecified injury of fallopian tube, bilateral, subsequent encounter*/
,'S37502S'  /*Unspecified injury of fallopian tube, bilateral, sequela*/
,'S37509D'  /*Unspecified injury of fallopian tube, unspecified, subsequent encounter*/
,'S37509S'  /*Unspecified injury of fallopian tube, unspecified, sequela*/
,'S37511D'  /*Primary blast injury of fallopian tube, unilateral, subsequent encounter*/
,'S37511S'  /*Primary blast injury of fallopian tube, unilateral, sequela*/
,'S37512D'  /*Primary blast injury of fallopian tube, bilateral, subsequent encounter*/
,'S37512S'  /*Primary blast injury of fallopian tube, bilateral, sequela*/
,'S37519D'  /*Primary blast injury of fallopian tube, unspecified, subsequent encounter*/
,'S37519S'  /*Primary blast injury of fallopian tube, unspecified, sequela*/
,'S37521D'  /*Contusion of fallopian tube, unilateral, subsequent encounter*/
,'S37521S'  /*Contusion of fallopian tube, unilateral, sequela*/
,'S37522D'  /*Contusion of fallopian tube, bilateral, subsequent encounter*/
,'S37522S'  /*Contusion of fallopian tube, bilateral, sequela*/
,'S37529D'  /*Contusion of fallopian tube, unspecified, subsequent encounter*/
,'S37529S'  /*Contusion of fallopian tube, unspecified, sequela*/
,'S37531D'  /*Laceration of fallopian tube, unilateral, subsequent encounter*/
,'S37531S'  /*Laceration of fallopian tube, unilateral, sequela*/
,'S37532D'  /*Laceration of fallopian tube, bilateral, subsequent encounter*/
,'S37532S'  /*Laceration of fallopian tube, bilateral, sequela*/
,'S37539D'  /*Laceration of fallopian tube, unspecified, subsequent encounter*/
,'S37539S'  /*Laceration of fallopian tube, unspecified, sequela*/
,'S37591D'  /*Other injury of fallopian tube, unilateral, subsequent encounter*/
,'S37591S'  /*Other injury of fallopian tube, unilateral, sequela*/
,'S37592D'  /*Other injury of fallopian tube, bilateral, subsequent encounter*/
,'S37592S'  /*Other injury of fallopian tube, bilateral, sequela*/
,'S37599D'  /*Other injury of fallopian tube, unspecified, subsequent encounter*/
,'S37599S'  /*Other injury of fallopian tube, unspecified, sequela*/
,'S3760XD'  /*Unspecified injury of uterus, subsequent encounter*/
,'S3760XS'  /*Unspecified injury of uterus, sequela*/
,'S3762XD'  /*Contusion of uterus, subsequent encounter*/
,'S3762XS'  /*Contusion of uterus, sequela*/
,'S3763XD'  /*Laceration of uterus, subsequent encounter*/
,'S3763XS'  /*Laceration of uterus, sequela*/
,'S3769XD'  /*Other injury of uterus, subsequent encounter*/
,'S3769XS'  /*Other injury of uterus, sequela*/
,'S37812D'  /*Contusion of adrenal gland, subsequent encounter*/
,'S37812S'  /*Contusion of adrenal gland, sequela*/
,'S37813D'  /*Laceration of adrenal gland, subsequent encounter*/
,'S37813S'  /*Laceration of adrenal gland, sequela*/
,'S37818D'  /*Other injury of adrenal gland, subsequent encounter*/
,'S37818S'  /*Other injury of adrenal gland, sequela*/
,'S37819D'  /*Unspecified injury of adrenal gland, subsequent encounter*/
,'S37819S'  /*Unspecified injury of adrenal gland, sequela*/
,'S37822D'  /*Contusion of prostate, subsequent encounter*/
,'S37822S'  /*Contusion of prostate, sequela*/
,'S37823D'  /*Laceration of prostate, subsequent encounter*/
,'S37823S'  /*Laceration of prostate, sequela*/
,'S37828D'  /*Other injury of prostate, subsequent encounter*/
,'S37828S'  /*Other injury of prostate, sequela*/
,'S37829D'  /*Unspecified injury of prostate, subsequent encounter*/
,'S37829S'  /*Unspecified injury of prostate, sequela*/
,'S37892D'  /*Contusion of other urinary and pelvic organ, subsequent encounter*/
,'S37892S'  /*Contusion of other urinary and pelvic organ, sequela*/
,'S37893D'  /*Laceration of other urinary and pelvic organ, subsequent encounter*/
,'S37893S'  /*Laceration of other urinary and pelvic organ, sequela*/
,'S37898D'  /*Other injury of other urinary and pelvic organ, subsequent encounter*/
,'S37898S'  /*Other injury of other urinary and pelvic organ, sequela*/
,'S37899D'  /*Unspecified injury of other urinary and pelvic organ, subsequent encounter*/
,'S37899S'  /*Unspecified injury of other urinary and pelvic organ, sequela*/
,'S3790XD'  /*Unspecified injury of unspecified urinary and pelvic organ, subsequent encounter*/
,'S3790XS'  /*Unspecified injury of unspecified urinary and pelvic organ, sequela*/
,'S3792XD'  /*Contusion of unspecified urinary and pelvic organ, subsequent encounter*/
,'S3792XS'  /*Contusion of unspecified urinary and pelvic organ, sequela*/
,'S3793XD'  /*Laceration of unspecified urinary and pelvic organ, subsequent encounter*/
,'S3793XS'  /*Laceration of unspecified urinary and pelvic organ, sequela*/
,'S3799XD'  /*Other injury of unspecified urinary and pelvic organ, subsequent encounter*/
,'S3799XS'  /*Other injury of unspecified urinary and pelvic organ, sequela*/
,'S38001D'  /*Crushing injury of unspecified external genital organs, male, subsequent encounter*/
,'S38001S'  /*Crushing injury of unspecified external genital organs, male, sequela*/
,'S38002D'  /*Crushing injury of unspecified external genital organs, female, subsequent encounter*/
,'S38002S'  /*Crushing injury of unspecified external genital organs, female, sequela*/
,'S3801XD'  /*Crushing injury of penis, subsequent encounter*/
,'S3801XS'  /*Crushing injury of penis, sequela*/
,'S3802XD'  /*Crushing injury of scrotum and testis, subsequent encounter*/
,'S3802XS'  /*Crushing injury of scrotum and testis, sequela*/
,'S3803XD'  /*Crushing injury of vulva, subsequent encounter*/
,'S3803XS'  /*Crushing injury of vulva, sequela*/
,'S381XXD'  /*Crushing injury of abdomen, lower back, and pelvis, subsequent encounter*/
,'S381XXS'  /*Crushing injury of abdomen, lower back, and pelvis, sequela*/
,'S38211D'  /*Complete traumatic amputation of female external genital organs, subsequent encounter*/
,'S38211S'  /*Complete traumatic amputation of female external genital organs, sequela*/
,'S38212D'  /*Partial traumatic amputation of female external genital organs, subsequent encounter*/
,'S38212S'  /*Partial traumatic amputation of female external genital organs, sequela*/
,'S38221D'  /*Complete traumatic amputation of penis, subsequent encounter*/
,'S38221S'  /*Complete traumatic amputation of penis, sequela*/
,'S38222D'  /*Partial traumatic amputation of penis, subsequent encounter*/
,'S38222S'  /*Partial traumatic amputation of penis, sequela*/
,'S38231D'  /*Complete traumatic amputation of scrotum and testis, subsequent encounter*/
,'S38231S'  /*Complete traumatic amputation of scrotum and testis, sequela*/
,'S38232D'  /*Partial traumatic amputation of scrotum and testis, subsequent encounter*/
,'S38232S'  /*Partial traumatic amputation of scrotum and testis, sequela*/
,'S383XXD'  /*Transection (partial) of abdomen, subsequent encounter*/
,'S383XXS'  /*Transection (partial) of abdomen, sequela*/
,'S39001D'  /*Unspecified injury of muscle, fascia and tendon of abdomen, subsequent encounter*/
,'S39001S'  /*Unspecified injury of muscle, fascia and tendon of abdomen, sequela*/
,'S39002D'  /*Unspecified injury of muscle, fascia and tendon of lower back, subsequent encounter*/
,'S39002S'  /*Unspecified injury of muscle, fascia and tendon of lower back, sequela*/
,'S39003D'  /*Unspecified injury of muscle, fascia and tendon of pelvis, subsequent encounter*/
,'S39003S'  /*Unspecified injury of muscle, fascia and tendon of pelvis, sequela*/
,'S39011D'  /*Strain of muscle, fascia and tendon of abdomen, subsequent encounter*/
,'S39011S'  /*Strain of muscle, fascia and tendon of abdomen, sequela*/
,'S39012D'  /*Strain of muscle, fascia and tendon of lower back, subsequent encounter*/
,'S39012S'  /*Strain of muscle, fascia and tendon of lower back, sequela*/
,'S39013D'  /*Strain of muscle, fascia and tendon of pelvis, subsequent encounter*/
,'S39013S'  /*Strain of muscle, fascia and tendon of pelvis, sequela*/
,'S39021D'  /*Laceration of muscle, fascia and tendon of abdomen, subsequent encounter*/
,'S39021S'  /*Laceration of muscle, fascia and tendon of abdomen, sequela*/
,'S39022D'  /*Laceration of muscle, fascia and tendon of lower back, subsequent encounter*/
,'S39022S'  /*Laceration of muscle, fascia and tendon of lower back, sequela*/
,'S39023D'  /*Laceration of muscle, fascia and tendon of pelvis, subsequent encounter*/
,'S39023S'  /*Laceration of muscle, fascia and tendon of pelvis, sequela*/
,'S39091D'  /*Other injury of muscle, fascia and tendon of abdomen, subsequent encounter*/
,'S39091S'  /*Other injury of muscle, fascia and tendon of abdomen, sequela*/
,'S39092D'  /*Other injury of muscle, fascia and tendon of lower back, subsequent encounter*/
,'S39092S'  /*Other injury of muscle, fascia and tendon of lower back, sequela*/
,'S39093D'  /*Other injury of muscle, fascia and tendon of pelvis, subsequent encounter*/
,'S39093S'  /*Other injury of muscle, fascia and tendon of pelvis, sequela*/
,'S3981XD'  /*Other specified injuries of abdomen, subsequent encounter*/
,'S3981XS'  /*Other specified injuries of abdomen, sequela*/
,'S3982XD'  /*Other specified injuries of lower back, subsequent encounter*/
,'S3982XS'  /*Other specified injuries of lower back, sequela*/
,'S3983XD'  /*Other specified injuries of pelvis, subsequent encounter*/
,'S3983XS'  /*Other specified injuries of pelvis, sequela*/
,'S39840D'  /*Fracture of corpus cavernosum penis, subsequent encounter*/
,'S39840S'  /*Fracture of corpus cavernosum penis, sequela*/
,'S39848D'  /*Other specified injuries of external genitals, subsequent encounter*/
,'S39848S'  /*Other specified injuries of external genitals, sequela*/
,'S3991XD'  /*Unspecified injury of abdomen, subsequent encounter*/
,'S3991XS'  /*Unspecified injury of abdomen, sequela*/
,'S3992XD'  /*Unspecified injury of lower back, subsequent encounter*/
,'S3992XS'  /*Unspecified injury of lower back, sequela*/
,'S3993XD'  /*Unspecified injury of pelvis, subsequent encounter*/
,'S3993XS'  /*Unspecified injury of pelvis, sequela*/
,'S3994XD'  /*Unspecified injury of external genitals, subsequent encounter*/
,'S3994XS'  /*Unspecified injury of external genitals, sequela*/
,'S40011D'  /*Contusion of right shoulder, subsequent encounter*/
,'S40011S'  /*Contusion of right shoulder, sequela*/
,'S40012D'  /*Contusion of left shoulder, subsequent encounter*/
,'S40012S'  /*Contusion of left shoulder, sequela*/
,'S40019D'  /*Contusion of unspecified shoulder, subsequent encounter*/
,'S40019S'  /*Contusion of unspecified shoulder, sequela*/
,'S40021D'  /*Contusion of right upper arm, subsequent encounter*/
,'S40021S'  /*Contusion of right upper arm, sequela*/
,'S40022D'  /*Contusion of left upper arm, subsequent encounter*/
,'S40022S'  /*Contusion of left upper arm, sequela*/
,'S40029D'  /*Contusion of unspecified upper arm, subsequent encounter*/
,'S40029S'  /*Contusion of unspecified upper arm, sequela*/
,'S40211D'  /*Abrasion of right shoulder, subsequent encounter*/
,'S40211S'  /*Abrasion of right shoulder, sequela*/
,'S40212D'  /*Abrasion of left shoulder, subsequent encounter*/
,'S40212S'  /*Abrasion of left shoulder, sequela*/
,'S40219D'  /*Abrasion of unspecified shoulder, subsequent encounter*/
,'S40219S'  /*Abrasion of unspecified shoulder, sequela*/
,'S40221D'  /*Blister (nonthermal) of right shoulder, subsequent encounter*/
,'S40221S'  /*Blister (nonthermal) of right shoulder, sequela*/
,'S40222D'  /*Blister (nonthermal) of left shoulder, subsequent encounter*/
,'S40222S'  /*Blister (nonthermal) of left shoulder, sequela*/
,'S40229D'  /*Blister (nonthermal) of unspecified shoulder, subsequent encounter*/
,'S40229S'  /*Blister (nonthermal) of unspecified shoulder, sequela*/
,'S40241D'  /*External constriction of right shoulder, subsequent encounter*/
,'S40241S'  /*External constriction of right shoulder, sequela*/
,'S40242D'  /*External constriction of left shoulder, subsequent encounter*/
,'S40242S'  /*External constriction of left shoulder, sequela*/
,'S40249D'  /*External constriction of unspecified shoulder, subsequent encounter*/
,'S40249S'  /*External constriction of unspecified shoulder, sequela*/
,'S40251D'  /*Superficial foreign body of right shoulder, subsequent encounter*/
,'S40251S'  /*Superficial foreign body of right shoulder, sequela*/
,'S40252D'  /*Superficial foreign body of left shoulder, subsequent encounter*/
,'S40252S'  /*Superficial foreign body of left shoulder, sequela*/
,'S40259D'  /*Superficial foreign body of unspecified shoulder, subsequent encounter*/
,'S40259S'  /*Superficial foreign body of unspecified shoulder, sequela*/
,'S40261D'  /*Insect bite (nonvenomous) of right shoulder, subsequent encounter*/
,'S40261S'  /*Insect bite (nonvenomous) of right shoulder, sequela*/
,'S40262D'  /*Insect bite (nonvenomous) of left shoulder, subsequent encounter*/
,'S40262S'  /*Insect bite (nonvenomous) of left shoulder, sequela*/
,'S40269D'  /*Insect bite (nonvenomous) of unspecified shoulder, subsequent encounter*/
,'S40269S'  /*Insect bite (nonvenomous) of unspecified shoulder, sequela*/
,'S40271D'  /*Other superficial bite of right shoulder, subsequent encounter*/
,'S40271S'  /*Other superficial bite of right shoulder, sequela*/
,'S40272D'  /*Other superficial bite of left shoulder, subsequent encounter*/
,'S40272S'  /*Other superficial bite of left shoulder, sequela*/
,'S40279D'  /*Other superficial bite of unspecified shoulder, subsequent encounter*/
,'S40279S'  /*Other superficial bite of unspecified shoulder, sequela*/
,'S40811D'  /*Abrasion of right upper arm, subsequent encounter*/
,'S40811S'  /*Abrasion of right upper arm, sequela*/
,'S40812D'  /*Abrasion of left upper arm, subsequent encounter*/
,'S40812S'  /*Abrasion of left upper arm, sequela*/
,'S40819D'  /*Abrasion of unspecified upper arm, subsequent encounter*/
,'S40819S'  /*Abrasion of unspecified upper arm, sequela*/
,'S40821D'  /*Blister (nonthermal) of right upper arm, subsequent encounter*/
,'S40821S'  /*Blister (nonthermal) of right upper arm, sequela*/
,'S40822D'  /*Blister (nonthermal) of left upper arm, subsequent encounter*/
,'S40822S'  /*Blister (nonthermal) of left upper arm, sequela*/
,'S40829D'  /*Blister (nonthermal) of unspecified upper arm, subsequent encounter*/
,'S40829S'  /*Blister (nonthermal) of unspecified upper arm, sequela*/
,'S40841D'  /*External constriction of right upper arm, subsequent encounter*/
,'S40841S'  /*External constriction of right upper arm, sequela*/
,'S40842D'  /*External constriction of left upper arm, subsequent encounter*/
,'S40842S'  /*External constriction of left upper arm, sequela*/
,'S40849D'  /*External constriction of unspecified upper arm, subsequent encounter*/
,'S40849S'  /*External constriction of unspecified upper arm, sequela*/
,'S40851D'  /*Superficial foreign body of right upper arm, subsequent encounter*/
,'S40851S'  /*Superficial foreign body of right upper arm, sequela*/
,'S40852D'  /*Superficial foreign body of left upper arm, subsequent encounter*/
,'S40852S'  /*Superficial foreign body of left upper arm, sequela*/
,'S40859D'  /*Superficial foreign body of unspecified upper arm, subsequent encounter*/
,'S40859S'  /*Superficial foreign body of unspecified upper arm, sequela*/
,'S40861D'  /*Insect bite (nonvenomous) of right upper arm, subsequent encounter*/
,'S40861S'  /*Insect bite (nonvenomous) of right upper arm, sequela*/
,'S40862D'  /*Insect bite (nonvenomous) of left upper arm, subsequent encounter*/
,'S40862S'  /*Insect bite (nonvenomous) of left upper arm, sequela*/
,'S40869D'  /*Insect bite (nonvenomous) of unspecified upper arm, subsequent encounter*/
,'S40869S'  /*Insect bite (nonvenomous) of unspecified upper arm, sequela*/
,'S40871D'  /*Other superficial bite of right upper arm, subsequent encounter*/
,'S40871S'  /*Other superficial bite of right upper arm, sequela*/
,'S40872D'  /*Other superficial bite of left upper arm, subsequent encounter*/
,'S40872S'  /*Other superficial bite of left upper arm, sequela*/
,'S40879D'  /*Other superficial bite of unspecified upper arm, subsequent encounter*/
,'S40879S'  /*Other superficial bite of unspecified upper arm, sequela*/
,'S40911D'  /*Unspecified superficial injury of right shoulder, subsequent encounter*/
,'S40911S'  /*Unspecified superficial injury of right shoulder, sequela*/
,'S40912D'  /*Unspecified superficial injury of left shoulder, subsequent encounter*/
,'S40912S'  /*Unspecified superficial injury of left shoulder, sequela*/
,'S40919D'  /*Unspecified superficial injury of unspecified shoulder, subsequent encounter*/
,'S40919S'  /*Unspecified superficial injury of unspecified shoulder, sequela*/
,'S40921D'  /*Unspecified superficial injury of right upper arm, subsequent encounter*/
,'S40921S'  /*Unspecified superficial injury of right upper arm, sequela*/
,'S40922D'  /*Unspecified superficial injury of left upper arm, subsequent encounter*/
,'S40922S'  /*Unspecified superficial injury of left upper arm, sequela*/
,'S40929D'  /*Unspecified superficial injury of unspecified upper arm, subsequent encounter*/
,'S40929S'  /*Unspecified superficial injury of unspecified upper arm, sequela*/
,'S41001D'  /*Unspecified open wound of right shoulder, subsequent encounter*/
,'S41001S'  /*Unspecified open wound of right shoulder, sequela*/
,'S41002D'  /*Unspecified open wound of left shoulder, subsequent encounter*/
,'S41002S'  /*Unspecified open wound of left shoulder, sequela*/
,'S41009D'  /*Unspecified open wound of unspecified shoulder, subsequent encounter*/
,'S41009S'  /*Unspecified open wound of unspecified shoulder, sequela*/
,'S41011D'  /*Laceration without foreign body of right shoulder, subsequent encounter*/
,'S41011S'  /*Laceration without foreign body of right shoulder, sequela*/
,'S41012D'  /*Laceration without foreign body of left shoulder, subsequent encounter*/
,'S41012S'  /*Laceration without foreign body of left shoulder, sequela*/
,'S41019D'  /*Laceration without foreign body of unspecified shoulder, subsequent encounter*/
,'S41019S'  /*Laceration without foreign body of unspecified shoulder, sequela*/
,'S41021D'  /*Laceration with foreign body of right shoulder, subsequent encounter*/
,'S41021S'  /*Laceration with foreign body of right shoulder, sequela*/
,'S41022D'  /*Laceration with foreign body of left shoulder, subsequent encounter*/
,'S41022S'  /*Laceration with foreign body of left shoulder, sequela*/
,'S41029D'  /*Laceration with foreign body of unspecified shoulder, subsequent encounter*/
,'S41029S'  /*Laceration with foreign body of unspecified shoulder, sequela*/
,'S41031D'  /*Puncture wound without foreign body of right shoulder, subsequent encounter*/
,'S41031S'  /*Puncture wound without foreign body of right shoulder, sequela*/
,'S41032D'  /*Puncture wound without foreign body of left shoulder, subsequent encounter*/
,'S41032S'  /*Puncture wound without foreign body of left shoulder, sequela*/
,'S41039D'  /*Puncture wound without foreign body of unspecified shoulder, subsequent encounter*/
,'S41039S'  /*Puncture wound without foreign body of unspecified shoulder, sequela*/
,'S41041D'  /*Puncture wound with foreign body of right shoulder, subsequent encounter*/
,'S41041S'  /*Puncture wound with foreign body of right shoulder, sequela*/
,'S41042D'  /*Puncture wound with foreign body of left shoulder, subsequent encounter*/
,'S41042S'  /*Puncture wound with foreign body of left shoulder, sequela*/
,'S41049D'  /*Puncture wound with foreign body of unspecified shoulder, subsequent encounter*/
,'S41049S'  /*Puncture wound with foreign body of unspecified shoulder, sequela*/
,'S41051D'  /*Open bite of right shoulder, subsequent encounter*/
,'S41051S'  /*Open bite of right shoulder, sequela*/
,'S41052D'  /*Open bite of left shoulder, subsequent encounter*/
,'S41052S'  /*Open bite of left shoulder, sequela*/
,'S41059D'  /*Open bite of unspecified shoulder, subsequent encounter*/
,'S41059S'  /*Open bite of unspecified shoulder, sequela*/
,'S41101D'  /*Unspecified open wound of right upper arm, subsequent encounter*/
,'S41101S'  /*Unspecified open wound of right upper arm, sequela*/
,'S41102D'  /*Unspecified open wound of left upper arm, subsequent encounter*/
,'S41102S'  /*Unspecified open wound of left upper arm, sequela*/
,'S41109D'  /*Unspecified open wound of unspecified upper arm, subsequent encounter*/
,'S41109S'  /*Unspecified open wound of unspecified upper arm, sequela*/
,'S41111D'  /*Laceration without foreign body of right upper arm, subsequent encounter*/
,'S41111S'  /*Laceration without foreign body of right upper arm, sequela*/
,'S41112D'  /*Laceration without foreign body of left upper arm, subsequent encounter*/
,'S41112S'  /*Laceration without foreign body of left upper arm, sequela*/
,'S41119D'  /*Laceration without foreign body of unspecified upper arm, subsequent encounter*/
,'S41119S'  /*Laceration without foreign body of unspecified upper arm, sequela*/
,'S41121D'  /*Laceration with foreign body of right upper arm, subsequent encounter*/
,'S41121S'  /*Laceration with foreign body of right upper arm, sequela*/
,'S41122D'  /*Laceration with foreign body of left upper arm, subsequent encounter*/
,'S41122S'  /*Laceration with foreign body of left upper arm, sequela*/
,'S41129D'  /*Laceration with foreign body of unspecified upper arm, subsequent encounter*/
,'S41129S'  /*Laceration with foreign body of unspecified upper arm, sequela*/
,'S41131D'  /*Puncture wound without foreign body of right upper arm, subsequent encounter*/
,'S41131S'  /*Puncture wound without foreign body of right upper arm, sequela*/
,'S41132D'  /*Puncture wound without foreign body of left upper arm, subsequent encounter*/
,'S41132S'  /*Puncture wound without foreign body of left upper arm, sequela*/
,'S41139D'  /*Puncture wound without foreign body of unspecified upper arm, subsequent encounter*/
,'S41139S'  /*Puncture wound without foreign body of unspecified upper arm, sequela*/
,'S41141D'  /*Puncture wound with foreign body of right upper arm, subsequent encounter*/
,'S41141S'  /*Puncture wound with foreign body of right upper arm, sequela*/
,'S41142D'  /*Puncture wound with foreign body of left upper arm, subsequent encounter*/
,'S41142S'  /*Puncture wound with foreign body of left upper arm, sequela*/
,'S41149D'  /*Puncture wound with foreign body of unspecified upper arm, subsequent encounter*/
,'S41149S'  /*Puncture wound with foreign body of unspecified upper arm, sequela*/
,'S41151D'  /*Open bite of right upper arm, subsequent encounter*/
,'S41151S'  /*Open bite of right upper arm, sequela*/
,'S41152D'  /*Open bite of left upper arm, subsequent encounter*/
,'S41152S'  /*Open bite of left upper arm, sequela*/
,'S41159D'  /*Open bite of unspecified upper arm, subsequent encounter*/
,'S41159S'  /*Open bite of unspecified upper arm, sequela*/
,'S42001D'  /*Fracture of unspecified part of right clavicle, subsequent encounter for fracture with routine healing*/
,'S42001G'  /*Fracture of unspecified part of right clavicle, subsequent encounter for fracture with delayed healing*/
,'S42001K'  /*Fracture of unspecified part of right clavicle, subsequent encounter for fracture with nonunion*/
,'S42001P'  /*Fracture of unspecified part of right clavicle, subsequent encounter for fracture with malunion*/
,'S42001S'  /*Fracture of unspecified part of right clavicle, sequela*/
,'S42002D'  /*Fracture of unspecified part of left clavicle, subsequent encounter for fracture with routine healing*/
,'S42002G'  /*Fracture of unspecified part of left clavicle, subsequent encounter for fracture with delayed healing*/
,'S42002K'  /*Fracture of unspecified part of left clavicle, subsequent encounter for fracture with nonunion*/
,'S42002P'  /*Fracture of unspecified part of left clavicle, subsequent encounter for fracture with malunion*/
,'S42002S'  /*Fracture of unspecified part of left clavicle, sequela*/
,'S42009D'  /*Fracture of unspecified part of unspecified clavicle, subsequent encounter for fracture with routine healing*/
,'S42009G'  /*Fracture of unspecified part of unspecified clavicle, subsequent encounter for fracture with delayed healing*/
,'S42009K'  /*Fracture of unspecified part of unspecified clavicle, subsequent encounter for fracture with nonunion*/
,'S42009P'  /*Fracture of unspecified part of unspecified clavicle, subsequent encounter for fracture with malunion*/
,'S42009S'  /*Fracture of unspecified part of unspecified clavicle, sequela*/
,'S42011D'  /*Anterior displaced fracture of sternal end of right clavicle, subsequent encounter for fracture with routine healing*/
,'S42011G'  /*Anterior displaced fracture of sternal end of right clavicle, subsequent encounter for fracture with delayed healing*/
,'S42011K'  /*Anterior displaced fracture of sternal end of right clavicle, subsequent encounter for fracture with nonunion*/
,'S42011P'  /*Anterior displaced fracture of sternal end of right clavicle, subsequent encounter for fracture with malunion*/
,'S42011S'  /*Anterior displaced fracture of sternal end of right clavicle, sequela*/
,'S42012D'  /*Anterior displaced fracture of sternal end of left clavicle, subsequent encounter for fracture with routine healing*/
,'S42012G'  /*Anterior displaced fracture of sternal end of left clavicle, subsequent encounter for fracture with delayed healing*/
,'S42012K'  /*Anterior displaced fracture of sternal end of left clavicle, subsequent encounter for fracture with nonunion*/
,'S42012P'  /*Anterior displaced fracture of sternal end of left clavicle, subsequent encounter for fracture with malunion*/
,'S42012S'  /*Anterior displaced fracture of sternal end of left clavicle, sequela*/
,'S42013D'  /*Anterior displaced fracture of sternal end of unspecified clavicle, subsequent encounter for fracture with routine healing*/
,'S42013G'  /*Anterior displaced fracture of sternal end of unspecified clavicle, subsequent encounter for fracture with delayed healing*/
,'S42013K'  /*Anterior displaced fracture of sternal end of unspecified clavicle, subsequent encounter for fracture with nonunion*/
,'S42013P'  /*Anterior displaced fracture of sternal end of unspecified clavicle, subsequent encounter for fracture with malunion*/
,'S42013S'  /*Anterior displaced fracture of sternal end of unspecified clavicle, sequela*/
,'S42014D'  /*Posterior displaced fracture of sternal end of right clavicle, subsequent encounter for fracture with routine healing*/
,'S42014G'  /*Posterior displaced fracture of sternal end of right clavicle, subsequent encounter for fracture with delayed healing*/
,'S42014K'  /*Posterior displaced fracture of sternal end of right clavicle, subsequent encounter for fracture with nonunion*/
,'S42014P'  /*Posterior displaced fracture of sternal end of right clavicle, subsequent encounter for fracture with malunion*/
,'S42014S'  /*Posterior displaced fracture of sternal end of right clavicle, sequela*/
,'S42015D'  /*Posterior displaced fracture of sternal end of left clavicle, subsequent encounter for fracture with routine healing*/
,'S42015G'  /*Posterior displaced fracture of sternal end of left clavicle, subsequent encounter for fracture with delayed healing*/
,'S42015K'  /*Posterior displaced fracture of sternal end of left clavicle, subsequent encounter for fracture with nonunion*/
,'S42015P'  /*Posterior displaced fracture of sternal end of left clavicle, subsequent encounter for fracture with malunion*/
,'S42015S'  /*Posterior displaced fracture of sternal end of left clavicle, sequela*/
,'S42016D'  /*Posterior displaced fracture of sternal end of unspecified clavicle, subsequent encounter for fracture with routine healing*/
,'S42016G'  /*Posterior displaced fracture of sternal end of unspecified clavicle, subsequent encounter for fracture with delayed healing*/
,'S42016K'  /*Posterior displaced fracture of sternal end of unspecified clavicle, subsequent encounter for fracture with nonunion*/
,'S42016P'  /*Posterior displaced fracture of sternal end of unspecified clavicle, subsequent encounter for fracture with malunion*/
,'S42016S'  /*Posterior displaced fracture of sternal end of unspecified clavicle, sequela*/
,'S42017D'  /*Nondisplaced fracture of sternal end of right clavicle, subsequent encounter for fracture with routine healing*/
,'S42017G'  /*Nondisplaced fracture of sternal end of right clavicle, subsequent encounter for fracture with delayed healing*/
,'S42017K'  /*Nondisplaced fracture of sternal end of right clavicle, subsequent encounter for fracture with nonunion*/
,'S42017P'  /*Nondisplaced fracture of sternal end of right clavicle, subsequent encounter for fracture with malunion*/
,'S42017S'  /*Nondisplaced fracture of sternal end of right clavicle, sequela*/
,'S42018D'  /*Nondisplaced fracture of sternal end of left clavicle, subsequent encounter for fracture with routine healing*/
,'S42018G'  /*Nondisplaced fracture of sternal end of left clavicle, subsequent encounter for fracture with delayed healing*/
,'S42018K'  /*Nondisplaced fracture of sternal end of left clavicle, subsequent encounter for fracture with nonunion*/
,'S42018P'  /*Nondisplaced fracture of sternal end of left clavicle, subsequent encounter for fracture with malunion*/
,'S42018S'  /*Nondisplaced fracture of sternal end of left clavicle, sequela*/
,'S42019D'  /*Nondisplaced fracture of sternal end of unspecified clavicle, subsequent encounter for fracture with routine healing*/
,'S42019G'  /*Nondisplaced fracture of sternal end of unspecified clavicle, subsequent encounter for fracture with delayed healing*/
,'S42019K'  /*Nondisplaced fracture of sternal end of unspecified clavicle, subsequent encounter for fracture with nonunion*/
,'S42019P'  /*Nondisplaced fracture of sternal end of unspecified clavicle, subsequent encounter for fracture with malunion*/
,'S42019S'  /*Nondisplaced fracture of sternal end of unspecified clavicle, sequela*/
,'S42021D'  /*Displaced fracture of shaft of right clavicle, subsequent encounter for fracture with routine healing*/
,'S42021G'  /*Displaced fracture of shaft of right clavicle, subsequent encounter for fracture with delayed healing*/
,'S42021K'  /*Displaced fracture of shaft of right clavicle, subsequent encounter for fracture with nonunion*/
,'S42021P'  /*Displaced fracture of shaft of right clavicle, subsequent encounter for fracture with malunion*/
,'S42021S'  /*Displaced fracture of shaft of right clavicle, sequela*/
,'S42022D'  /*Displaced fracture of shaft of left clavicle, subsequent encounter for fracture with routine healing*/
,'S42022G'  /*Displaced fracture of shaft of left clavicle, subsequent encounter for fracture with delayed healing*/
,'S42022K'  /*Displaced fracture of shaft of left clavicle, subsequent encounter for fracture with nonunion*/
,'S42022P'  /*Displaced fracture of shaft of left clavicle, subsequent encounter for fracture with malunion*/
,'S42022S'  /*Displaced fracture of shaft of left clavicle, sequela*/
,'S42023D'  /*Displaced fracture of shaft of unspecified clavicle, subsequent encounter for fracture with routine healing*/
,'S42023G'  /*Displaced fracture of shaft of unspecified clavicle, subsequent encounter for fracture with delayed healing*/
,'S42023K'  /*Displaced fracture of shaft of unspecified clavicle, subsequent encounter for fracture with nonunion*/
,'S42023P'  /*Displaced fracture of shaft of unspecified clavicle, subsequent encounter for fracture with malunion*/
,'S42023S'  /*Displaced fracture of shaft of unspecified clavicle, sequela*/
,'S42024D'  /*Nondisplaced fracture of shaft of right clavicle, subsequent encounter for fracture with routine healing*/
,'S42024G'  /*Nondisplaced fracture of shaft of right clavicle, subsequent encounter for fracture with delayed healing*/
,'S42024K'  /*Nondisplaced fracture of shaft of right clavicle, subsequent encounter for fracture with nonunion*/
,'S42024P'  /*Nondisplaced fracture of shaft of right clavicle, subsequent encounter for fracture with malunion*/
,'S42024S'  /*Nondisplaced fracture of shaft of right clavicle, sequela*/
,'S42025D'  /*Nondisplaced fracture of shaft of left clavicle, subsequent encounter for fracture with routine healing*/
,'S42025G'  /*Nondisplaced fracture of shaft of left clavicle, subsequent encounter for fracture with delayed healing*/
,'S42025K'  /*Nondisplaced fracture of shaft of left clavicle, subsequent encounter for fracture with nonunion*/
,'S42025P'  /*Nondisplaced fracture of shaft of left clavicle, subsequent encounter for fracture with malunion*/
,'S42025S'  /*Nondisplaced fracture of shaft of left clavicle, sequela*/
,'S42026D'  /*Nondisplaced fracture of shaft of unspecified clavicle, subsequent encounter for fracture with routine healing*/
,'S42026G'  /*Nondisplaced fracture of shaft of unspecified clavicle, subsequent encounter for fracture with delayed healing*/
,'S42026K'  /*Nondisplaced fracture of shaft of unspecified clavicle, subsequent encounter for fracture with nonunion*/
,'S42026P'  /*Nondisplaced fracture of shaft of unspecified clavicle, subsequent encounter for fracture with malunion*/
,'S42026S'  /*Nondisplaced fracture of shaft of unspecified clavicle, sequela*/
,'S42031D'  /*Displaced fracture of lateral end of right clavicle, subsequent encounter for fracture with routine healing*/
,'S42031G'  /*Displaced fracture of lateral end of right clavicle, subsequent encounter for fracture with delayed healing*/
,'S42031K'  /*Displaced fracture of lateral end of right clavicle, subsequent encounter for fracture with nonunion*/
,'S42031P'  /*Displaced fracture of lateral end of right clavicle, subsequent encounter for fracture with malunion*/
,'S42031S'  /*Displaced fracture of lateral end of right clavicle, sequela*/
,'S42032D'  /*Displaced fracture of lateral end of left clavicle, subsequent encounter for fracture with routine healing*/
,'S42032G'  /*Displaced fracture of lateral end of left clavicle, subsequent encounter for fracture with delayed healing*/
,'S42032K'  /*Displaced fracture of lateral end of left clavicle, subsequent encounter for fracture with nonunion*/
,'S42032P'  /*Displaced fracture of lateral end of left clavicle, subsequent encounter for fracture with malunion*/
,'S42032S'  /*Displaced fracture of lateral end of left clavicle, sequela*/
,'S42033D'  /*Displaced fracture of lateral end of unspecified clavicle, subsequent encounter for fracture with routine healing*/
,'S42033G'  /*Displaced fracture of lateral end of unspecified clavicle, subsequent encounter for fracture with delayed healing*/
,'S42033K'  /*Displaced fracture of lateral end of unspecified clavicle, subsequent encounter for fracture with nonunion*/
,'S42033P'  /*Displaced fracture of lateral end of unspecified clavicle, subsequent encounter for fracture with malunion*/
,'S42033S'  /*Displaced fracture of lateral end of unspecified clavicle, sequela*/
,'S42034D'  /*Nondisplaced fracture of lateral end of right clavicle, subsequent encounter for fracture with routine healing*/
,'S42034G'  /*Nondisplaced fracture of lateral end of right clavicle, subsequent encounter for fracture with delayed healing*/
,'S42034K'  /*Nondisplaced fracture of lateral end of right clavicle, subsequent encounter for fracture with nonunion*/
,'S42034P'  /*Nondisplaced fracture of lateral end of right clavicle, subsequent encounter for fracture with malunion*/
,'S42034S'  /*Nondisplaced fracture of lateral end of right clavicle, sequela*/
,'S42035D'  /*Nondisplaced fracture of lateral end of left clavicle, subsequent encounter for fracture with routine healing*/
,'S42035G'  /*Nondisplaced fracture of lateral end of left clavicle, subsequent encounter for fracture with delayed healing*/
,'S42035K'  /*Nondisplaced fracture of lateral end of left clavicle, subsequent encounter for fracture with nonunion*/
,'S42035P'  /*Nondisplaced fracture of lateral end of left clavicle, subsequent encounter for fracture with malunion*/
,'S42035S'  /*Nondisplaced fracture of lateral end of left clavicle, sequela*/
,'S42036D'  /*Nondisplaced fracture of lateral end of unspecified clavicle, subsequent encounter for fracture with routine healing*/
,'S42036G'  /*Nondisplaced fracture of lateral end of unspecified clavicle, subsequent encounter for fracture with delayed healing*/
,'S42036K'  /*Nondisplaced fracture of lateral end of unspecified clavicle, subsequent encounter for fracture with nonunion*/
,'S42036P'  /*Nondisplaced fracture of lateral end of unspecified clavicle, subsequent encounter for fracture with malunion*/
,'S42036S'  /*Nondisplaced fracture of lateral end of unspecified clavicle, sequela*/
,'S42101D'  /*Fracture of unspecified part of scapula, right shoulder, subsequent encounter for fracture with routine healing*/
,'S42101G'  /*Fracture of unspecified part of scapula, right shoulder, subsequent encounter for fracture with delayed healing*/
,'S42101K'  /*Fracture of unspecified part of scapula, right shoulder, subsequent encounter for fracture with nonunion*/
,'S42101P'  /*Fracture of unspecified part of scapula, right shoulder, subsequent encounter for fracture with malunion*/
,'S42101S'  /*Fracture of unspecified part of scapula, right shoulder, sequela*/
,'S42102D'  /*Fracture of unspecified part of scapula, left shoulder, subsequent encounter for fracture with routine healing*/
,'S42102G'  /*Fracture of unspecified part of scapula, left shoulder, subsequent encounter for fracture with delayed healing*/
,'S42102K'  /*Fracture of unspecified part of scapula, left shoulder, subsequent encounter for fracture with nonunion*/
,'S42102P'  /*Fracture of unspecified part of scapula, left shoulder, subsequent encounter for fracture with malunion*/
,'S42102S'  /*Fracture of unspecified part of scapula, left shoulder, sequela*/
,'S42109D'  /*Fracture of unspecified part of scapula, unspecified shoulder, subsequent encounter for fracture with routine healing*/
,'S42109G'  /*Fracture of unspecified part of scapula, unspecified shoulder, subsequent encounter for fracture with delayed healing*/
,'S42109K'  /*Fracture of unspecified part of scapula, unspecified shoulder, subsequent encounter for fracture with nonunion*/
,'S42109P'  /*Fracture of unspecified part of scapula, unspecified shoulder, subsequent encounter for fracture with malunion*/
,'S42109S'  /*Fracture of unspecified part of scapula, unspecified shoulder, sequela*/
,'S42111D'  /*Displaced fracture of body of scapula, right shoulder, subsequent encounter for fracture with routine healing*/
,'S42111G'  /*Displaced fracture of body of scapula, right shoulder, subsequent encounter for fracture with delayed healing*/
,'S42111K'  /*Displaced fracture of body of scapula, right shoulder, subsequent encounter for fracture with nonunion*/
,'S42111P'  /*Displaced fracture of body of scapula, right shoulder, subsequent encounter for fracture with malunion*/
,'S42111S'  /*Displaced fracture of body of scapula, right shoulder, sequela*/
,'S42112D'  /*Displaced fracture of body of scapula, left shoulder, subsequent encounter for fracture with routine healing*/
,'S42112G'  /*Displaced fracture of body of scapula, left shoulder, subsequent encounter for fracture with delayed healing*/
,'S42112K'  /*Displaced fracture of body of scapula, left shoulder, subsequent encounter for fracture with nonunion*/
,'S42112P'  /*Displaced fracture of body of scapula, left shoulder, subsequent encounter for fracture with malunion*/
,'S42112S'  /*Displaced fracture of body of scapula, left shoulder, sequela*/
,'S42113D'  /*Displaced fracture of body of scapula, unspecified shoulder, subsequent encounter for fracture with routine healing*/
,'S42113G'  /*Displaced fracture of body of scapula, unspecified shoulder, subsequent encounter for fracture with delayed healing*/
,'S42113K'  /*Displaced fracture of body of scapula, unspecified shoulder, subsequent encounter for fracture with nonunion*/
,'S42113P'  /*Displaced fracture of body of scapula, unspecified shoulder, subsequent encounter for fracture with malunion*/
,'S42113S'  /*Displaced fracture of body of scapula, unspecified shoulder, sequela*/
,'S42114D'  /*Nondisplaced fracture of body of scapula, right shoulder, subsequent encounter for fracture with routine healing*/
,'S42114G'  /*Nondisplaced fracture of body of scapula, right shoulder, subsequent encounter for fracture with delayed healing*/
,'S42114K'  /*Nondisplaced fracture of body of scapula, right shoulder, subsequent encounter for fracture with nonunion*/
,'S42114P'  /*Nondisplaced fracture of body of scapula, right shoulder, subsequent encounter for fracture with malunion*/
,'S42114S'  /*Nondisplaced fracture of body of scapula, right shoulder, sequela*/
,'S42115D'  /*Nondisplaced fracture of body of scapula, left shoulder, subsequent encounter for fracture with routine healing*/
,'S42115G'  /*Nondisplaced fracture of body of scapula, left shoulder, subsequent encounter for fracture with delayed healing*/
,'S42115K'  /*Nondisplaced fracture of body of scapula, left shoulder, subsequent encounter for fracture with nonunion*/
,'S42115P'  /*Nondisplaced fracture of body of scapula, left shoulder, subsequent encounter for fracture with malunion*/
,'S42115S'  /*Nondisplaced fracture of body of scapula, left shoulder, sequela*/
,'S42116D'  /*Nondisplaced fracture of body of scapula, unspecified shoulder, subsequent encounter for fracture with routine healing*/
,'S42116G'  /*Nondisplaced fracture of body of scapula, unspecified shoulder, subsequent encounter for fracture with delayed healing*/
,'S42116K'  /*Nondisplaced fracture of body of scapula, unspecified shoulder, subsequent encounter for fracture with nonunion*/
,'S42116P'  /*Nondisplaced fracture of body of scapula, unspecified shoulder, subsequent encounter for fracture with malunion*/
,'S42116S'  /*Nondisplaced fracture of body of scapula, unspecified shoulder, sequela*/
,'S42121D'  /*Displaced fracture of acromial process, right shoulder, subsequent encounter for fracture with routine healing*/
,'S42121G'  /*Displaced fracture of acromial process, right shoulder, subsequent encounter for fracture with delayed healing*/
,'S42121K'  /*Displaced fracture of acromial process, right shoulder, subsequent encounter for fracture with nonunion*/
,'S42121P'  /*Displaced fracture of acromial process, right shoulder, subsequent encounter for fracture with malunion*/
,'S42121S'  /*Displaced fracture of acromial process, right shoulder, sequela*/
,'S42122D'  /*Displaced fracture of acromial process, left shoulder, subsequent encounter for fracture with routine healing*/
,'S42122G'  /*Displaced fracture of acromial process, left shoulder, subsequent encounter for fracture with delayed healing*/
,'S42122K'  /*Displaced fracture of acromial process, left shoulder, subsequent encounter for fracture with nonunion*/
,'S42122P'  /*Displaced fracture of acromial process, left shoulder, subsequent encounter for fracture with malunion*/
,'S42122S'  /*Displaced fracture of acromial process, left shoulder, sequela*/
,'S42123D'  /*Displaced fracture of acromial process, unspecified shoulder, subsequent encounter for fracture with routine healing*/
,'S42123G'  /*Displaced fracture of acromial process, unspecified shoulder, subsequent encounter for fracture with delayed healing*/
,'S42123K'  /*Displaced fracture of acromial process, unspecified shoulder, subsequent encounter for fracture with nonunion*/
,'S42123P'  /*Displaced fracture of acromial process, unspecified shoulder, subsequent encounter for fracture with malunion*/
,'S42123S'  /*Displaced fracture of acromial process, unspecified shoulder, sequela*/
,'S42124D'  /*Nondisplaced fracture of acromial process, right shoulder, subsequent encounter for fracture with routine healing*/
,'S42124G'  /*Nondisplaced fracture of acromial process, right shoulder, subsequent encounter for fracture with delayed healing*/
,'S42124K'  /*Nondisplaced fracture of acromial process, right shoulder, subsequent encounter for fracture with nonunion*/
,'S42124P'  /*Nondisplaced fracture of acromial process, right shoulder, subsequent encounter for fracture with malunion*/
,'S42124S'  /*Nondisplaced fracture of acromial process, right shoulder, sequela*/
,'S42125D'  /*Nondisplaced fracture of acromial process, left shoulder, subsequent encounter for fracture with routine healing*/
,'S42125G'  /*Nondisplaced fracture of acromial process, left shoulder, subsequent encounter for fracture with delayed healing*/
,'S42125K'  /*Nondisplaced fracture of acromial process, left shoulder, subsequent encounter for fracture with nonunion*/
,'S42125P'  /*Nondisplaced fracture of acromial process, left shoulder, subsequent encounter for fracture with malunion*/
,'S42125S'  /*Nondisplaced fracture of acromial process, left shoulder, sequela*/
,'S42126D'  /*Nondisplaced fracture of acromial process, unspecified shoulder, subsequent encounter for fracture with routine healing*/
,'S42126G'  /*Nondisplaced fracture of acromial process, unspecified shoulder, subsequent encounter for fracture with delayed healing*/
,'S42126K'  /*Nondisplaced fracture of acromial process, unspecified shoulder, subsequent encounter for fracture with nonunion*/
,'S42126P'  /*Nondisplaced fracture of acromial process, unspecified shoulder, subsequent encounter for fracture with malunion*/
,'S42126S'  /*Nondisplaced fracture of acromial process, unspecified shoulder, sequela*/
,'S42131D'  /*Displaced fracture of coracoid process, right shoulder, subsequent encounter for fracture with routine healing*/
,'S42131G'  /*Displaced fracture of coracoid process, right shoulder, subsequent encounter for fracture with delayed healing*/
,'S42131K'  /*Displaced fracture of coracoid process, right shoulder, subsequent encounter for fracture with nonunion*/
,'S42131P'  /*Displaced fracture of coracoid process, right shoulder, subsequent encounter for fracture with malunion*/
,'S42131S'  /*Displaced fracture of coracoid process, right shoulder, sequela*/
,'S42132D'  /*Displaced fracture of coracoid process, left shoulder, subsequent encounter for fracture with routine healing*/
,'S42132G'  /*Displaced fracture of coracoid process, left shoulder, subsequent encounter for fracture with delayed healing*/
,'S42132K'  /*Displaced fracture of coracoid process, left shoulder, subsequent encounter for fracture with nonunion*/
,'S42132P'  /*Displaced fracture of coracoid process, left shoulder, subsequent encounter for fracture with malunion*/
,'S42132S'  /*Displaced fracture of coracoid process, left shoulder, sequela*/
,'S42133D'  /*Displaced fracture of coracoid process, unspecified shoulder, subsequent encounter for fracture with routine healing*/
,'S42133G'  /*Displaced fracture of coracoid process, unspecified shoulder, subsequent encounter for fracture with delayed healing*/
,'S42133K'  /*Displaced fracture of coracoid process, unspecified shoulder, subsequent encounter for fracture with nonunion*/
,'S42133P'  /*Displaced fracture of coracoid process, unspecified shoulder, subsequent encounter for fracture with malunion*/
,'S42133S'  /*Displaced fracture of coracoid process, unspecified shoulder, sequela*/
,'S42134D'  /*Nondisplaced fracture of coracoid process, right shoulder, subsequent encounter for fracture with routine healing*/
,'S42134G'  /*Nondisplaced fracture of coracoid process, right shoulder, subsequent encounter for fracture with delayed healing*/
,'S42134K'  /*Nondisplaced fracture of coracoid process, right shoulder, subsequent encounter for fracture with nonunion*/
,'S42134P'  /*Nondisplaced fracture of coracoid process, right shoulder, subsequent encounter for fracture with malunion*/
,'S42134S'  /*Nondisplaced fracture of coracoid process, right shoulder, sequela*/
,'S42135D'  /*Nondisplaced fracture of coracoid process, left shoulder, subsequent encounter for fracture with routine healing*/
,'S42135G'  /*Nondisplaced fracture of coracoid process, left shoulder, subsequent encounter for fracture with delayed healing*/
,'S42135K'  /*Nondisplaced fracture of coracoid process, left shoulder, subsequent encounter for fracture with nonunion*/
,'S42135P'  /*Nondisplaced fracture of coracoid process, left shoulder, subsequent encounter for fracture with malunion*/
,'S42135S'  /*Nondisplaced fracture of coracoid process, left shoulder, sequela*/
,'S42136D'  /*Nondisplaced fracture of coracoid process, unspecified shoulder, subsequent encounter for fracture with routine healing*/
,'S42136G'  /*Nondisplaced fracture of coracoid process, unspecified shoulder, subsequent encounter for fracture with delayed healing*/
,'S42136K'  /*Nondisplaced fracture of coracoid process, unspecified shoulder, subsequent encounter for fracture with nonunion*/
,'S42136P'  /*Nondisplaced fracture of coracoid process, unspecified shoulder, subsequent encounter for fracture with malunion*/
,'S42136S'  /*Nondisplaced fracture of coracoid process, unspecified shoulder, sequela*/
,'S42141D'  /*Displaced fracture of glenoid cavity of scapula, right shoulder, subsequent encounter for fracture with routine healing*/
,'S42141G'  /*Displaced fracture of glenoid cavity of scapula, right shoulder, subsequent encounter for fracture with delayed healing*/
,'S42141K'  /*Displaced fracture of glenoid cavity of scapula, right shoulder, subsequent encounter for fracture with nonunion*/
,'S42141P'  /*Displaced fracture of glenoid cavity of scapula, right shoulder, subsequent encounter for fracture with malunion*/
,'S42141S'  /*Displaced fracture of glenoid cavity of scapula, right shoulder, sequela*/
,'S42142D'  /*Displaced fracture of glenoid cavity of scapula, left shoulder, subsequent encounter for fracture with routine healing*/
,'S42142G'  /*Displaced fracture of glenoid cavity of scapula, left shoulder, subsequent encounter for fracture with delayed healing*/
,'S42142K'  /*Displaced fracture of glenoid cavity of scapula, left shoulder, subsequent encounter for fracture with nonunion*/
,'S42142P'  /*Displaced fracture of glenoid cavity of scapula, left shoulder, subsequent encounter for fracture with malunion*/
,'S42142S'  /*Displaced fracture of glenoid cavity of scapula, left shoulder, sequela*/
,'S42143D'  /*Displaced fracture of glenoid cavity of scapula, unspecified shoulder, subsequent encounter for fracture with routine healing*/
,'S42143G'  /*Displaced fracture of glenoid cavity of scapula, unspecified shoulder, subsequent encounter for fracture with delayed healing*/
,'S42143K'  /*Displaced fracture of glenoid cavity of scapula, unspecified shoulder, subsequent encounter for fracture with nonunion*/
,'S42143P'  /*Displaced fracture of glenoid cavity of scapula, unspecified shoulder, subsequent encounter for fracture with malunion*/
,'S42143S'  /*Displaced fracture of glenoid cavity of scapula, unspecified shoulder, sequela*/
,'S42144D'  /*Nondisplaced fracture of glenoid cavity of scapula, right shoulder, subsequent encounter for fracture with routine healing*/
,'S42144G'  /*Nondisplaced fracture of glenoid cavity of scapula, right shoulder, subsequent encounter for fracture with delayed healing*/
,'S42144K'  /*Nondisplaced fracture of glenoid cavity of scapula, right shoulder, subsequent encounter for fracture with nonunion*/
,'S42144P'  /*Nondisplaced fracture of glenoid cavity of scapula, right shoulder, subsequent encounter for fracture with malunion*/
,'S42144S'  /*Nondisplaced fracture of glenoid cavity of scapula, right shoulder, sequela*/
,'S42145D'  /*Nondisplaced fracture of glenoid cavity of scapula, left shoulder, subsequent encounter for fracture with routine healing*/
,'S42145G'  /*Nondisplaced fracture of glenoid cavity of scapula, left shoulder, subsequent encounter for fracture with delayed healing*/
,'S42145K'  /*Nondisplaced fracture of glenoid cavity of scapula, left shoulder, subsequent encounter for fracture with nonunion*/
,'S42145P'  /*Nondisplaced fracture of glenoid cavity of scapula, left shoulder, subsequent encounter for fracture with malunion*/
,'S42145S'  /*Nondisplaced fracture of glenoid cavity of scapula, left shoulder, sequela*/
,'S42146D'  /*Nondisplaced fracture of glenoid cavity of scapula, unspecified shoulder, subsequent encounter for fracture with routine healing*/
,'S42146G'  /*Nondisplaced fracture of glenoid cavity of scapula, unspecified shoulder, subsequent encounter for fracture with delayed healing*/
,'S42146K'  /*Nondisplaced fracture of glenoid cavity of scapula, unspecified shoulder, subsequent encounter for fracture with nonunion*/
,'S42146P'  /*Nondisplaced fracture of glenoid cavity of scapula, unspecified shoulder, subsequent encounter for fracture with malunion*/
,'S42146S'  /*Nondisplaced fracture of glenoid cavity of scapula, unspecified shoulder, sequela*/
,'S42151D'  /*Displaced fracture of neck of scapula, right shoulder, subsequent encounter for fracture with routine healing*/
,'S42151G'  /*Displaced fracture of neck of scapula, right shoulder, subsequent encounter for fracture with delayed healing*/
,'S42151K'  /*Displaced fracture of neck of scapula, right shoulder, subsequent encounter for fracture with nonunion*/
,'S42151P'  /*Displaced fracture of neck of scapula, right shoulder, subsequent encounter for fracture with malunion*/
,'S42151S'  /*Displaced fracture of neck of scapula, right shoulder, sequela*/
,'S42152D'  /*Displaced fracture of neck of scapula, left shoulder, subsequent encounter for fracture with routine healing*/
,'S42152G'  /*Displaced fracture of neck of scapula, left shoulder, subsequent encounter for fracture with delayed healing*/
,'S42152K'  /*Displaced fracture of neck of scapula, left shoulder, subsequent encounter for fracture with nonunion*/
,'S42152P'  /*Displaced fracture of neck of scapula, left shoulder, subsequent encounter for fracture with malunion*/
,'S42152S'  /*Displaced fracture of neck of scapula, left shoulder, sequela*/
,'S42153D'  /*Displaced fracture of neck of scapula, unspecified shoulder, subsequent encounter for fracture with routine healing*/
,'S42153G'  /*Displaced fracture of neck of scapula, unspecified shoulder, subsequent encounter for fracture with delayed healing*/
,'S42153K'  /*Displaced fracture of neck of scapula, unspecified shoulder, subsequent encounter for fracture with nonunion*/
,'S42153P'  /*Displaced fracture of neck of scapula, unspecified shoulder, subsequent encounter for fracture with malunion*/
,'S42153S'  /*Displaced fracture of neck of scapula, unspecified shoulder, sequela*/
,'S42154D'  /*Nondisplaced fracture of neck of scapula, right shoulder, subsequent encounter for fracture with routine healing*/
,'S42154G'  /*Nondisplaced fracture of neck of scapula, right shoulder, subsequent encounter for fracture with delayed healing*/
,'S42154K'  /*Nondisplaced fracture of neck of scapula, right shoulder, subsequent encounter for fracture with nonunion*/
,'S42154P'  /*Nondisplaced fracture of neck of scapula, right shoulder, subsequent encounter for fracture with malunion*/
,'S42154S'  /*Nondisplaced fracture of neck of scapula, right shoulder, sequela*/
,'S42155D'  /*Nondisplaced fracture of neck of scapula, left shoulder, subsequent encounter for fracture with routine healing*/
,'S42155G'  /*Nondisplaced fracture of neck of scapula, left shoulder, subsequent encounter for fracture with delayed healing*/
,'S42155K'  /*Nondisplaced fracture of neck of scapula, left shoulder, subsequent encounter for fracture with nonunion*/
,'S42155P'  /*Nondisplaced fracture of neck of scapula, left shoulder, subsequent encounter for fracture with malunion*/
,'S42155S'  /*Nondisplaced fracture of neck of scapula, left shoulder, sequela*/
,'S42156D'  /*Nondisplaced fracture of neck of scapula, unspecified shoulder, subsequent encounter for fracture with routine healing*/
,'S42156G'  /*Nondisplaced fracture of neck of scapula, unspecified shoulder, subsequent encounter for fracture with delayed healing*/
,'S42156K'  /*Nondisplaced fracture of neck of scapula, unspecified shoulder, subsequent encounter for fracture with nonunion*/
,'S42156P'  /*Nondisplaced fracture of neck of scapula, unspecified shoulder, subsequent encounter for fracture with malunion*/
,'S42156S'  /*Nondisplaced fracture of neck of scapula, unspecified shoulder, sequela*/
,'S42191D'  /*Fracture of other part of scapula, right shoulder, subsequent encounter for fracture with routine healing*/
,'S42191G'  /*Fracture of other part of scapula, right shoulder, subsequent encounter for fracture with delayed healing*/
,'S42191K'  /*Fracture of other part of scapula, right shoulder, subsequent encounter for fracture with nonunion*/
,'S42191P'  /*Fracture of other part of scapula, right shoulder, subsequent encounter for fracture with malunion*/
,'S42191S'  /*Fracture of other part of scapula, right shoulder, sequela*/
,'S42192D'  /*Fracture of other part of scapula, left shoulder, subsequent encounter for fracture with routine healing*/
,'S42192G'  /*Fracture of other part of scapula, left shoulder, subsequent encounter for fracture with delayed healing*/
,'S42192K'  /*Fracture of other part of scapula, left shoulder, subsequent encounter for fracture with nonunion*/
,'S42192P'  /*Fracture of other part of scapula, left shoulder, subsequent encounter for fracture with malunion*/
,'S42192S'  /*Fracture of other part of scapula, left shoulder, sequela*/
,'S42199D'  /*Fracture of other part of scapula, unspecified shoulder, subsequent encounter for fracture with routine healing*/
,'S42199G'  /*Fracture of other part of scapula, unspecified shoulder, subsequent encounter for fracture with delayed healing*/
,'S42199K'  /*Fracture of other part of scapula, unspecified shoulder, subsequent encounter for fracture with nonunion*/
,'S42199P'  /*Fracture of other part of scapula, unspecified shoulder, subsequent encounter for fracture with malunion*/
,'S42199S'  /*Fracture of other part of scapula, unspecified shoulder, sequela*/
,'S42201D'  /*Unspecified fracture of upper end of right humerus, subsequent encounter for fracture with routine healing*/
,'S42201G'  /*Unspecified fracture of upper end of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42201K'  /*Unspecified fracture of upper end of right humerus, subsequent encounter for fracture with nonunion*/
,'S42201P'  /*Unspecified fracture of upper end of right humerus, subsequent encounter for fracture with malunion*/
,'S42201S'  /*Unspecified fracture of upper end of right humerus, sequela*/
,'S42202D'  /*Unspecified fracture of upper end of left humerus, subsequent encounter for fracture with routine healing*/
,'S42202G'  /*Unspecified fracture of upper end of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42202K'  /*Unspecified fracture of upper end of left humerus, subsequent encounter for fracture with nonunion*/
,'S42202P'  /*Unspecified fracture of upper end of left humerus, subsequent encounter for fracture with malunion*/
,'S42202S'  /*Unspecified fracture of upper end of left humerus, sequela*/
,'S42209D'  /*Unspecified fracture of upper end of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42209G'  /*Unspecified fracture of upper end of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42209K'  /*Unspecified fracture of upper end of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42209P'  /*Unspecified fracture of upper end of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42209S'  /*Unspecified fracture of upper end of unspecified humerus, sequela*/
,'S42211D'  /*Unspecified displaced fracture of surgical neck of right humerus, subsequent encounter for fracture with routine healing*/
,'S42211G'  /*Unspecified displaced fracture of surgical neck of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42211K'  /*Unspecified displaced fracture of surgical neck of right humerus, subsequent encounter for fracture with nonunion*/
,'S42211P'  /*Unspecified displaced fracture of surgical neck of right humerus, subsequent encounter for fracture with malunion*/
,'S42211S'  /*Unspecified displaced fracture of surgical neck of right humerus, sequela*/
,'S42212D'  /*Unspecified displaced fracture of surgical neck of left humerus, subsequent encounter for fracture with routine healing*/
,'S42212G'  /*Unspecified displaced fracture of surgical neck of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42212K'  /*Unspecified displaced fracture of surgical neck of left humerus, subsequent encounter for fracture with nonunion*/
,'S42212P'  /*Unspecified displaced fracture of surgical neck of left humerus, subsequent encounter for fracture with malunion*/
,'S42212S'  /*Unspecified displaced fracture of surgical neck of left humerus, sequela*/
,'S42213D'  /*Unspecified displaced fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42213G'  /*Unspecified displaced fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42213K'  /*Unspecified displaced fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42213P'  /*Unspecified displaced fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42213S'  /*Unspecified displaced fracture of surgical neck of unspecified humerus, sequela*/
,'S42214D'  /*Unspecified nondisplaced fracture of surgical neck of right humerus, subsequent encounter for fracture with routine healing*/
,'S42214G'  /*Unspecified nondisplaced fracture of surgical neck of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42214K'  /*Unspecified nondisplaced fracture of surgical neck of right humerus, subsequent encounter for fracture with nonunion*/
,'S42214P'  /*Unspecified nondisplaced fracture of surgical neck of right humerus, subsequent encounter for fracture with malunion*/
,'S42214S'  /*Unspecified nondisplaced fracture of surgical neck of right humerus, sequela*/
,'S42215D'  /*Unspecified nondisplaced fracture of surgical neck of left humerus, subsequent encounter for fracture with routine healing*/
,'S42215G'  /*Unspecified nondisplaced fracture of surgical neck of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42215K'  /*Unspecified nondisplaced fracture of surgical neck of left humerus, subsequent encounter for fracture with nonunion*/
,'S42215P'  /*Unspecified nondisplaced fracture of surgical neck of left humerus, subsequent encounter for fracture with malunion*/
,'S42215S'  /*Unspecified nondisplaced fracture of surgical neck of left humerus, sequela*/
,'S42216D'  /*Unspecified nondisplaced fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42216G'  /*Unspecified nondisplaced fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42216K'  /*Unspecified nondisplaced fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42216P'  /*Unspecified nondisplaced fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42216S'  /*Unspecified nondisplaced fracture of surgical neck of unspecified humerus, sequela*/
,'S42221D'  /*2-part displaced fracture of surgical neck of right humerus, subsequent encounter for fracture with routine healing*/
,'S42221G'  /*2-part displaced fracture of surgical neck of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42221K'  /*2-part displaced fracture of surgical neck of right humerus, subsequent encounter for fracture with nonunion*/
,'S42221P'  /*2-part displaced fracture of surgical neck of right humerus, subsequent encounter for fracture with malunion*/
,'S42221S'  /*2-part displaced fracture of surgical neck of right humerus, sequela*/
,'S42222D'  /*2-part displaced fracture of surgical neck of left humerus, subsequent encounter for fracture with routine healing*/
,'S42222G'  /*2-part displaced fracture of surgical neck of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42222K'  /*2-part displaced fracture of surgical neck of left humerus, subsequent encounter for fracture with nonunion*/
,'S42222P'  /*2-part displaced fracture of surgical neck of left humerus, subsequent encounter for fracture with malunion*/
,'S42222S'  /*2-part displaced fracture of surgical neck of left humerus, sequela*/
,'S42223D'  /*2-part displaced fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42223G'  /*2-part displaced fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42223K'  /*2-part displaced fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42223P'  /*2-part displaced fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42223S'  /*2-part displaced fracture of surgical neck of unspecified humerus, sequela*/
,'S42224D'  /*2-part nondisplaced fracture of surgical neck of right humerus, subsequent encounter for fracture with routine healing*/
,'S42224G'  /*2-part nondisplaced fracture of surgical neck of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42224K'  /*2-part nondisplaced fracture of surgical neck of right humerus, subsequent encounter for fracture with nonunion*/
,'S42224P'  /*2-part nondisplaced fracture of surgical neck of right humerus, subsequent encounter for fracture with malunion*/
,'S42224S'  /*2-part nondisplaced fracture of surgical neck of right humerus, sequela*/
,'S42225D'  /*2-part nondisplaced fracture of surgical neck of left humerus, subsequent encounter for fracture with routine healing*/
,'S42225G'  /*2-part nondisplaced fracture of surgical neck of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42225K'  /*2-part nondisplaced fracture of surgical neck of left humerus, subsequent encounter for fracture with nonunion*/
,'S42225P'  /*2-part nondisplaced fracture of surgical neck of left humerus, subsequent encounter for fracture with malunion*/
,'S42225S'  /*2-part nondisplaced fracture of surgical neck of left humerus, sequela*/
,'S42226D'  /*2-part nondisplaced fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42226G'  /*2-part nondisplaced fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42226K'  /*2-part nondisplaced fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42226P'  /*2-part nondisplaced fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42226S'  /*2-part nondisplaced fracture of surgical neck of unspecified humerus, sequela*/
,'S42231D'  /*3-part fracture of surgical neck of right humerus, subsequent encounter for fracture with routine healing*/
,'S42231G'  /*3-part fracture of surgical neck of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42231K'  /*3-part fracture of surgical neck of right humerus, subsequent encounter for fracture with nonunion*/
,'S42231P'  /*3-part fracture of surgical neck of right humerus, subsequent encounter for fracture with malunion*/
,'S42231S'  /*3-part fracture of surgical neck of right humerus, sequela*/
,'S42232D'  /*3-part fracture of surgical neck of left humerus, subsequent encounter for fracture with routine healing*/
,'S42232G'  /*3-part fracture of surgical neck of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42232K'  /*3-part fracture of surgical neck of left humerus, subsequent encounter for fracture with nonunion*/
,'S42232P'  /*3-part fracture of surgical neck of left humerus, subsequent encounter for fracture with malunion*/
,'S42232S'  /*3-part fracture of surgical neck of left humerus, sequela*/
,'S42239D'  /*3-part fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42239G'  /*3-part fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42239K'  /*3-part fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42239P'  /*3-part fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42239S'  /*3-part fracture of surgical neck of unspecified humerus, sequela*/
,'S42241D'  /*4-part fracture of surgical neck of right humerus, subsequent encounter for fracture with routine healing*/
,'S42241G'  /*4-part fracture of surgical neck of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42241K'  /*4-part fracture of surgical neck of right humerus, subsequent encounter for fracture with nonunion*/
,'S42241P'  /*4-part fracture of surgical neck of right humerus, subsequent encounter for fracture with malunion*/
,'S42241S'  /*4-part fracture of surgical neck of right humerus, sequela*/
,'S42242D'  /*4-part fracture of surgical neck of left humerus, subsequent encounter for fracture with routine healing*/
,'S42242G'  /*4-part fracture of surgical neck of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42242K'  /*4-part fracture of surgical neck of left humerus, subsequent encounter for fracture with nonunion*/
,'S42242P'  /*4-part fracture of surgical neck of left humerus, subsequent encounter for fracture with malunion*/
,'S42242S'  /*4-part fracture of surgical neck of left humerus, sequela*/
,'S42249D'  /*4-part fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42249G'  /*4-part fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42249K'  /*4-part fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42249P'  /*4-part fracture of surgical neck of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42249S'  /*4-part fracture of surgical neck of unspecified humerus, sequela*/
,'S42251D'  /*Displaced fracture of greater tuberosity of right humerus, subsequent encounter for fracture with routine healing*/
,'S42251G'  /*Displaced fracture of greater tuberosity of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42251K'  /*Displaced fracture of greater tuberosity of right humerus, subsequent encounter for fracture with nonunion*/
,'S42251P'  /*Displaced fracture of greater tuberosity of right humerus, subsequent encounter for fracture with malunion*/
,'S42251S'  /*Displaced fracture of greater tuberosity of right humerus, sequela*/
,'S42252D'  /*Displaced fracture of greater tuberosity of left humerus, subsequent encounter for fracture with routine healing*/
,'S42252G'  /*Displaced fracture of greater tuberosity of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42252K'  /*Displaced fracture of greater tuberosity of left humerus, subsequent encounter for fracture with nonunion*/
,'S42252P'  /*Displaced fracture of greater tuberosity of left humerus, subsequent encounter for fracture with malunion*/
,'S42252S'  /*Displaced fracture of greater tuberosity of left humerus, sequela*/
,'S42253D'  /*Displaced fracture of greater tuberosity of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42253G'  /*Displaced fracture of greater tuberosity of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42253K'  /*Displaced fracture of greater tuberosity of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42253P'  /*Displaced fracture of greater tuberosity of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42253S'  /*Displaced fracture of greater tuberosity of unspecified humerus, sequela*/
,'S42254D'  /*Nondisplaced fracture of greater tuberosity of right humerus, subsequent encounter for fracture with routine healing*/
,'S42254G'  /*Nondisplaced fracture of greater tuberosity of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42254K'  /*Nondisplaced fracture of greater tuberosity of right humerus, subsequent encounter for fracture with nonunion*/
,'S42254P'  /*Nondisplaced fracture of greater tuberosity of right humerus, subsequent encounter for fracture with malunion*/
,'S42254S'  /*Nondisplaced fracture of greater tuberosity of right humerus, sequela*/
,'S42255D'  /*Nondisplaced fracture of greater tuberosity of left humerus, subsequent encounter for fracture with routine healing*/
,'S42255G'  /*Nondisplaced fracture of greater tuberosity of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42255K'  /*Nondisplaced fracture of greater tuberosity of left humerus, subsequent encounter for fracture with nonunion*/
,'S42255P'  /*Nondisplaced fracture of greater tuberosity of left humerus, subsequent encounter for fracture with malunion*/
,'S42255S'  /*Nondisplaced fracture of greater tuberosity of left humerus, sequela*/
,'S42256D'  /*Nondisplaced fracture of greater tuberosity of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42256G'  /*Nondisplaced fracture of greater tuberosity of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42256K'  /*Nondisplaced fracture of greater tuberosity of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42256P'  /*Nondisplaced fracture of greater tuberosity of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42256S'  /*Nondisplaced fracture of greater tuberosity of unspecified humerus, sequela*/
,'S42261D'  /*Displaced fracture of lesser tuberosity of right humerus, subsequent encounter for fracture with routine healing*/
,'S42261G'  /*Displaced fracture of lesser tuberosity of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42261K'  /*Displaced fracture of lesser tuberosity of right humerus, subsequent encounter for fracture with nonunion*/
,'S42261P'  /*Displaced fracture of lesser tuberosity of right humerus, subsequent encounter for fracture with malunion*/
,'S42261S'  /*Displaced fracture of lesser tuberosity of right humerus, sequela*/
,'S42262D'  /*Displaced fracture of lesser tuberosity of left humerus, subsequent encounter for fracture with routine healing*/
,'S42262G'  /*Displaced fracture of lesser tuberosity of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42262K'  /*Displaced fracture of lesser tuberosity of left humerus, subsequent encounter for fracture with nonunion*/
,'S42262P'  /*Displaced fracture of lesser tuberosity of left humerus, subsequent encounter for fracture with malunion*/
,'S42262S'  /*Displaced fracture of lesser tuberosity of left humerus, sequela*/
,'S42263D'  /*Displaced fracture of lesser tuberosity of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42263G'  /*Displaced fracture of lesser tuberosity of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42263K'  /*Displaced fracture of lesser tuberosity of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42263P'  /*Displaced fracture of lesser tuberosity of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42263S'  /*Displaced fracture of lesser tuberosity of unspecified humerus, sequela*/
,'S42264D'  /*Nondisplaced fracture of lesser tuberosity of right humerus, subsequent encounter for fracture with routine healing*/
,'S42264G'  /*Nondisplaced fracture of lesser tuberosity of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42264K'  /*Nondisplaced fracture of lesser tuberosity of right humerus, subsequent encounter for fracture with nonunion*/
,'S42264P'  /*Nondisplaced fracture of lesser tuberosity of right humerus, subsequent encounter for fracture with malunion*/
,'S42264S'  /*Nondisplaced fracture of lesser tuberosity of right humerus, sequela*/
,'S42265D'  /*Nondisplaced fracture of lesser tuberosity of left humerus, subsequent encounter for fracture with routine healing*/
,'S42265G'  /*Nondisplaced fracture of lesser tuberosity of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42265K'  /*Nondisplaced fracture of lesser tuberosity of left humerus, subsequent encounter for fracture with nonunion*/
,'S42265P'  /*Nondisplaced fracture of lesser tuberosity of left humerus, subsequent encounter for fracture with malunion*/
,'S42265S'  /*Nondisplaced fracture of lesser tuberosity of left humerus, sequela*/
,'S42266D'  /*Nondisplaced fracture of lesser tuberosity of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42266G'  /*Nondisplaced fracture of lesser tuberosity of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42266K'  /*Nondisplaced fracture of lesser tuberosity of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42266P'  /*Nondisplaced fracture of lesser tuberosity of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42266S'  /*Nondisplaced fracture of lesser tuberosity of unspecified humerus, sequela*/
,'S42271D'  /*Torus fracture of upper end of right humerus, subsequent encounter for fracture with routine healing*/
,'S42271G'  /*Torus fracture of upper end of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42271K'  /*Torus fracture of upper end of right humerus, subsequent encounter for fracture with nonunion*/
,'S42271P'  /*Torus fracture of upper end of right humerus, subsequent encounter for fracture with malunion*/
,'S42271S'  /*Torus fracture of upper end of right humerus, sequela*/
,'S42272D'  /*Torus fracture of upper end of left humerus, subsequent encounter for fracture with routine healing*/
,'S42272G'  /*Torus fracture of upper end of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42272K'  /*Torus fracture of upper end of left humerus, subsequent encounter for fracture with nonunion*/
,'S42272P'  /*Torus fracture of upper end of left humerus, subsequent encounter for fracture with malunion*/
,'S42272S'  /*Torus fracture of upper end of left humerus, sequela*/
,'S42279D'  /*Torus fracture of upper end of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42279G'  /*Torus fracture of upper end of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42279K'  /*Torus fracture of upper end of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42279P'  /*Torus fracture of upper end of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42279S'  /*Torus fracture of upper end of unspecified humerus, sequela*/
,'S42291D'  /*Other displaced fracture of upper end of right humerus, subsequent encounter for fracture with routine healing*/
,'S42291G'  /*Other displaced fracture of upper end of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42291K'  /*Other displaced fracture of upper end of right humerus, subsequent encounter for fracture with nonunion*/
,'S42291P'  /*Other displaced fracture of upper end of right humerus, subsequent encounter for fracture with malunion*/
,'S42291S'  /*Other displaced fracture of upper end of right humerus, sequela*/
,'S42292D'  /*Other displaced fracture of upper end of left humerus, subsequent encounter for fracture with routine healing*/
,'S42292G'  /*Other displaced fracture of upper end of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42292K'  /*Other displaced fracture of upper end of left humerus, subsequent encounter for fracture with nonunion*/
,'S42292P'  /*Other displaced fracture of upper end of left humerus, subsequent encounter for fracture with malunion*/
,'S42292S'  /*Other displaced fracture of upper end of left humerus, sequela*/
,'S42293D'  /*Other displaced fracture of upper end of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42293G'  /*Other displaced fracture of upper end of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42293K'  /*Other displaced fracture of upper end of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42293P'  /*Other displaced fracture of upper end of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42293S'  /*Other displaced fracture of upper end of unspecified humerus, sequela*/
,'S42294D'  /*Other nondisplaced fracture of upper end of right humerus, subsequent encounter for fracture with routine healing*/
,'S42294G'  /*Other nondisplaced fracture of upper end of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42294K'  /*Other nondisplaced fracture of upper end of right humerus, subsequent encounter for fracture with nonunion*/
,'S42294P'  /*Other nondisplaced fracture of upper end of right humerus, subsequent encounter for fracture with malunion*/
,'S42294S'  /*Other nondisplaced fracture of upper end of right humerus, sequela*/
,'S42295D'  /*Other nondisplaced fracture of upper end of left humerus, subsequent encounter for fracture with routine healing*/
,'S42295G'  /*Other nondisplaced fracture of upper end of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42295K'  /*Other nondisplaced fracture of upper end of left humerus, subsequent encounter for fracture with nonunion*/
,'S42295P'  /*Other nondisplaced fracture of upper end of left humerus, subsequent encounter for fracture with malunion*/
,'S42295S'  /*Other nondisplaced fracture of upper end of left humerus, sequela*/
,'S42296D'  /*Other nondisplaced fracture of upper end of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42296G'  /*Other nondisplaced fracture of upper end of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42296K'  /*Other nondisplaced fracture of upper end of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42296P'  /*Other nondisplaced fracture of upper end of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42296S'  /*Other nondisplaced fracture of upper end of unspecified humerus, sequela*/
,'S42301D'  /*Unspecified fracture of shaft of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S42301G'  /*Unspecified fracture of shaft of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S42301K'  /*Unspecified fracture of shaft of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S42301P'  /*Unspecified fracture of shaft of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S42301S'  /*Unspecified fracture of shaft of humerus, right arm, sequela*/
,'S42302D'  /*Unspecified fracture of shaft of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S42302G'  /*Unspecified fracture of shaft of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S42302K'  /*Unspecified fracture of shaft of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S42302P'  /*Unspecified fracture of shaft of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S42302S'  /*Unspecified fracture of shaft of humerus, left arm, sequela*/
,'S42309D'  /*Unspecified fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S42309G'  /*Unspecified fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S42309K'  /*Unspecified fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S42309P'  /*Unspecified fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S42309S'  /*Unspecified fracture of shaft of humerus, unspecified arm, sequela*/
,'S42311D'  /*Greenstick fracture of shaft of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S42311G'  /*Greenstick fracture of shaft of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S42311K'  /*Greenstick fracture of shaft of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S42311P'  /*Greenstick fracture of shaft of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S42311S'  /*Greenstick fracture of shaft of humerus, right arm, sequela*/
,'S42312D'  /*Greenstick fracture of shaft of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S42312G'  /*Greenstick fracture of shaft of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S42312K'  /*Greenstick fracture of shaft of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S42312P'  /*Greenstick fracture of shaft of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S42312S'  /*Greenstick fracture of shaft of humerus, left arm, sequela*/
,'S42319D'  /*Greenstick fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S42319G'  /*Greenstick fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S42319K'  /*Greenstick fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S42319P'  /*Greenstick fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S42319S'  /*Greenstick fracture of shaft of humerus, unspecified arm, sequela*/
,'S42321D'  /*Displaced transverse fracture of shaft of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S42321G'  /*Displaced transverse fracture of shaft of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S42321K'  /*Displaced transverse fracture of shaft of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S42321P'  /*Displaced transverse fracture of shaft of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S42321S'  /*Displaced transverse fracture of shaft of humerus, right arm, sequela*/
,'S42322D'  /*Displaced transverse fracture of shaft of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S42322G'  /*Displaced transverse fracture of shaft of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S42322K'  /*Displaced transverse fracture of shaft of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S42322P'  /*Displaced transverse fracture of shaft of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S42322S'  /*Displaced transverse fracture of shaft of humerus, left arm, sequela*/
,'S42323D'  /*Displaced transverse fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S42323G'  /*Displaced transverse fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S42323K'  /*Displaced transverse fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S42323P'  /*Displaced transverse fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S42323S'  /*Displaced transverse fracture of shaft of humerus, unspecified arm, sequela*/
,'S42324D'  /*Nondisplaced transverse fracture of shaft of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S42324G'  /*Nondisplaced transverse fracture of shaft of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S42324K'  /*Nondisplaced transverse fracture of shaft of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S42324P'  /*Nondisplaced transverse fracture of shaft of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S42324S'  /*Nondisplaced transverse fracture of shaft of humerus, right arm, sequela*/
,'S42325D'  /*Nondisplaced transverse fracture of shaft of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S42325G'  /*Nondisplaced transverse fracture of shaft of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S42325K'  /*Nondisplaced transverse fracture of shaft of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S42325P'  /*Nondisplaced transverse fracture of shaft of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S42325S'  /*Nondisplaced transverse fracture of shaft of humerus, left arm, sequela*/
,'S42326D'  /*Nondisplaced transverse fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S42326G'  /*Nondisplaced transverse fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S42326K'  /*Nondisplaced transverse fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S42326P'  /*Nondisplaced transverse fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S42326S'  /*Nondisplaced transverse fracture of shaft of humerus, unspecified arm, sequela*/
,'S42331D'  /*Displaced oblique fracture of shaft of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S42331G'  /*Displaced oblique fracture of shaft of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S42331K'  /*Displaced oblique fracture of shaft of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S42331P'  /*Displaced oblique fracture of shaft of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S42331S'  /*Displaced oblique fracture of shaft of humerus, right arm, sequela*/
,'S42332D'  /*Displaced oblique fracture of shaft of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S42332G'  /*Displaced oblique fracture of shaft of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S42332K'  /*Displaced oblique fracture of shaft of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S42332P'  /*Displaced oblique fracture of shaft of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S42332S'  /*Displaced oblique fracture of shaft of humerus, left arm, sequela*/
,'S42333D'  /*Displaced oblique fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S42333G'  /*Displaced oblique fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S42333K'  /*Displaced oblique fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S42333P'  /*Displaced oblique fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S42333S'  /*Displaced oblique fracture of shaft of humerus, unspecified arm, sequela*/
,'S42334D'  /*Nondisplaced oblique fracture of shaft of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S42334G'  /*Nondisplaced oblique fracture of shaft of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S42334K'  /*Nondisplaced oblique fracture of shaft of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S42334P'  /*Nondisplaced oblique fracture of shaft of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S42334S'  /*Nondisplaced oblique fracture of shaft of humerus, right arm, sequela*/
,'S42335D'  /*Nondisplaced oblique fracture of shaft of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S42335G'  /*Nondisplaced oblique fracture of shaft of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S42335K'  /*Nondisplaced oblique fracture of shaft of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S42335P'  /*Nondisplaced oblique fracture of shaft of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S42335S'  /*Nondisplaced oblique fracture of shaft of humerus, left arm, sequela*/
,'S42336D'  /*Nondisplaced oblique fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S42336G'  /*Nondisplaced oblique fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S42336K'  /*Nondisplaced oblique fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S42336P'  /*Nondisplaced oblique fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S42336S'  /*Nondisplaced oblique fracture of shaft of humerus, unspecified arm, sequela*/
,'S42341D'  /*Displaced spiral fracture of shaft of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S42341G'  /*Displaced spiral fracture of shaft of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S42341K'  /*Displaced spiral fracture of shaft of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S42341P'  /*Displaced spiral fracture of shaft of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S42341S'  /*Displaced spiral fracture of shaft of humerus, right arm, sequela*/
,'S42342D'  /*Displaced spiral fracture of shaft of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S42342G'  /*Displaced spiral fracture of shaft of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S42342K'  /*Displaced spiral fracture of shaft of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S42342P'  /*Displaced spiral fracture of shaft of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S42342S'  /*Displaced spiral fracture of shaft of humerus, left arm, sequela*/
,'S42343D'  /*Displaced spiral fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S42343G'  /*Displaced spiral fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S42343K'  /*Displaced spiral fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S42343P'  /*Displaced spiral fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S42343S'  /*Displaced spiral fracture of shaft of humerus, unspecified arm, sequela*/
,'S42344D'  /*Nondisplaced spiral fracture of shaft of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S42344G'  /*Nondisplaced spiral fracture of shaft of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S42344K'  /*Nondisplaced spiral fracture of shaft of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S42344P'  /*Nondisplaced spiral fracture of shaft of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S42344S'  /*Nondisplaced spiral fracture of shaft of humerus, right arm, sequela*/
,'S42345D'  /*Nondisplaced spiral fracture of shaft of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S42345G'  /*Nondisplaced spiral fracture of shaft of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S42345K'  /*Nondisplaced spiral fracture of shaft of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S42345P'  /*Nondisplaced spiral fracture of shaft of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S42345S'  /*Nondisplaced spiral fracture of shaft of humerus, left arm, sequela*/
,'S42346D'  /*Nondisplaced spiral fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S42346G'  /*Nondisplaced spiral fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S42346K'  /*Nondisplaced spiral fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S42346P'  /*Nondisplaced spiral fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S42346S'  /*Nondisplaced spiral fracture of shaft of humerus, unspecified arm, sequela*/
,'S42351D'  /*Displaced comminuted fracture of shaft of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S42351G'  /*Displaced comminuted fracture of shaft of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S42351K'  /*Displaced comminuted fracture of shaft of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S42351P'  /*Displaced comminuted fracture of shaft of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S42351S'  /*Displaced comminuted fracture of shaft of humerus, right arm, sequela*/
,'S42352D'  /*Displaced comminuted fracture of shaft of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S42352G'  /*Displaced comminuted fracture of shaft of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S42352K'  /*Displaced comminuted fracture of shaft of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S42352P'  /*Displaced comminuted fracture of shaft of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S42352S'  /*Displaced comminuted fracture of shaft of humerus, left arm, sequela*/
,'S42353D'  /*Displaced comminuted fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S42353G'  /*Displaced comminuted fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S42353K'  /*Displaced comminuted fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S42353P'  /*Displaced comminuted fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S42353S'  /*Displaced comminuted fracture of shaft of humerus, unspecified arm, sequela*/
,'S42354D'  /*Nondisplaced comminuted fracture of shaft of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S42354G'  /*Nondisplaced comminuted fracture of shaft of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S42354K'  /*Nondisplaced comminuted fracture of shaft of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S42354P'  /*Nondisplaced comminuted fracture of shaft of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S42354S'  /*Nondisplaced comminuted fracture of shaft of humerus, right arm, sequela*/
,'S42355D'  /*Nondisplaced comminuted fracture of shaft of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S42355G'  /*Nondisplaced comminuted fracture of shaft of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S42355K'  /*Nondisplaced comminuted fracture of shaft of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S42355P'  /*Nondisplaced comminuted fracture of shaft of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S42355S'  /*Nondisplaced comminuted fracture of shaft of humerus, left arm, sequela*/
,'S42356D'  /*Nondisplaced comminuted fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S42356G'  /*Nondisplaced comminuted fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S42356K'  /*Nondisplaced comminuted fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S42356P'  /*Nondisplaced comminuted fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S42356S'  /*Nondisplaced comminuted fracture of shaft of humerus, unspecified arm, sequela*/
,'S42361D'  /*Displaced segmental fracture of shaft of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S42361G'  /*Displaced segmental fracture of shaft of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S42361K'  /*Displaced segmental fracture of shaft of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S42361P'  /*Displaced segmental fracture of shaft of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S42361S'  /*Displaced segmental fracture of shaft of humerus, right arm, sequela*/
,'S42362D'  /*Displaced segmental fracture of shaft of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S42362G'  /*Displaced segmental fracture of shaft of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S42362K'  /*Displaced segmental fracture of shaft of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S42362P'  /*Displaced segmental fracture of shaft of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S42362S'  /*Displaced segmental fracture of shaft of humerus, left arm, sequela*/
,'S42363D'  /*Displaced segmental fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S42363G'  /*Displaced segmental fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S42363K'  /*Displaced segmental fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S42363P'  /*Displaced segmental fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S42363S'  /*Displaced segmental fracture of shaft of humerus, unspecified arm, sequela*/
,'S42364D'  /*Nondisplaced segmental fracture of shaft of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S42364G'  /*Nondisplaced segmental fracture of shaft of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S42364K'  /*Nondisplaced segmental fracture of shaft of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S42364P'  /*Nondisplaced segmental fracture of shaft of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S42364S'  /*Nondisplaced segmental fracture of shaft of humerus, right arm, sequela*/
,'S42365D'  /*Nondisplaced segmental fracture of shaft of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S42365G'  /*Nondisplaced segmental fracture of shaft of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S42365K'  /*Nondisplaced segmental fracture of shaft of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S42365P'  /*Nondisplaced segmental fracture of shaft of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S42365S'  /*Nondisplaced segmental fracture of shaft of humerus, left arm, sequela*/
,'S42366D'  /*Nondisplaced segmental fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S42366G'  /*Nondisplaced segmental fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S42366K'  /*Nondisplaced segmental fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S42366P'  /*Nondisplaced segmental fracture of shaft of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S42366S'  /*Nondisplaced segmental fracture of shaft of humerus, unspecified arm, sequela*/
,'S42391D'  /*Other fracture of shaft of right humerus, subsequent encounter for fracture with routine healing*/
,'S42391G'  /*Other fracture of shaft of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42391K'  /*Other fracture of shaft of right humerus, subsequent encounter for fracture with nonunion*/
,'S42391P'  /*Other fracture of shaft of right humerus, subsequent encounter for fracture with malunion*/
,'S42391S'  /*Other fracture of shaft of right humerus, sequela*/
,'S42392D'  /*Other fracture of shaft of left humerus, subsequent encounter for fracture with routine healing*/
,'S42392G'  /*Other fracture of shaft of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42392K'  /*Other fracture of shaft of left humerus, subsequent encounter for fracture with nonunion*/
,'S42392P'  /*Other fracture of shaft of left humerus, subsequent encounter for fracture with malunion*/
,'S42392S'  /*Other fracture of shaft of left humerus, sequela*/
,'S42399D'  /*Other fracture of shaft of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42399G'  /*Other fracture of shaft of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42399K'  /*Other fracture of shaft of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42399P'  /*Other fracture of shaft of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42399S'  /*Other fracture of shaft of unspecified humerus, sequela*/
,'S42401D'  /*Unspecified fracture of lower end of right humerus, subsequent encounter for fracture with routine healing*/
,'S42401G'  /*Unspecified fracture of lower end of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42401K'  /*Unspecified fracture of lower end of right humerus, subsequent encounter for fracture with nonunion*/
,'S42401P'  /*Unspecified fracture of lower end of right humerus, subsequent encounter for fracture with malunion*/
,'S42401S'  /*Unspecified fracture of lower end of right humerus, sequela*/
,'S42402D'  /*Unspecified fracture of lower end of left humerus, subsequent encounter for fracture with routine healing*/
,'S42402G'  /*Unspecified fracture of lower end of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42402K'  /*Unspecified fracture of lower end of left humerus, subsequent encounter for fracture with nonunion*/
,'S42402P'  /*Unspecified fracture of lower end of left humerus, subsequent encounter for fracture with malunion*/
,'S42402S'  /*Unspecified fracture of lower end of left humerus, sequela*/
,'S42409D'  /*Unspecified fracture of lower end of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42409G'  /*Unspecified fracture of lower end of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42409K'  /*Unspecified fracture of lower end of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42409P'  /*Unspecified fracture of lower end of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42409S'  /*Unspecified fracture of lower end of unspecified humerus, sequela*/
,'S42411D'  /*Displaced simple supracondylar fracture without intercondylar fracture of right humerus, subsequent encounter for fracture with routine healing*/
,'S42411G'  /*Displaced simple supracondylar fracture without intercondylar fracture of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42411K'  /*Displaced simple supracondylar fracture without intercondylar fracture of right humerus, subsequent encounter for fracture with nonunion*/
,'S42411P'  /*Displaced simple supracondylar fracture without intercondylar fracture of right humerus, subsequent encounter for fracture with malunion*/
,'S42411S'  /*Displaced simple supracondylar fracture without intercondylar fracture of right humerus, sequela*/
,'S42412D'  /*Displaced simple supracondylar fracture without intercondylar fracture of left humerus, subsequent encounter for fracture with routine healing*/
,'S42412G'  /*Displaced simple supracondylar fracture without intercondylar fracture of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42412K'  /*Displaced simple supracondylar fracture without intercondylar fracture of left humerus, subsequent encounter for fracture with nonunion*/
,'S42412P'  /*Displaced simple supracondylar fracture without intercondylar fracture of left humerus, subsequent encounter for fracture with malunion*/
,'S42412S'  /*Displaced simple supracondylar fracture without intercondylar fracture of left humerus, sequela*/
,'S42413D'  /*Displaced simple supracondylar fracture without intercondylar fracture of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42413G'  /*Displaced simple supracondylar fracture without intercondylar fracture of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42413K'  /*Displaced simple supracondylar fracture without intercondylar fracture of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42413P'  /*Displaced simple supracondylar fracture without intercondylar fracture of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42413S'  /*Displaced simple supracondylar fracture without intercondylar fracture of unspecified humerus, sequela*/
,'S42414D'  /*Nondisplaced simple supracondylar fracture without intercondylar fracture of right humerus, subsequent encounter for fracture with routine healing*/
,'S42414G'  /*Nondisplaced simple supracondylar fracture without intercondylar fracture of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42414K'  /*Nondisplaced simple supracondylar fracture without intercondylar fracture of right humerus, subsequent encounter for fracture with nonunion*/
,'S42414P'  /*Nondisplaced simple supracondylar fracture without intercondylar fracture of right humerus, subsequent encounter for fracture with malunion*/
,'S42414S'  /*Nondisplaced simple supracondylar fracture without intercondylar fracture of right humerus, sequela*/
,'S42415D'  /*Nondisplaced simple supracondylar fracture without intercondylar fracture of left humerus, subsequent encounter for fracture with routine healing*/
,'S42415G'  /*Nondisplaced simple supracondylar fracture without intercondylar fracture of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42415K'  /*Nondisplaced simple supracondylar fracture without intercondylar fracture of left humerus, subsequent encounter for fracture with nonunion*/
,'S42415P'  /*Nondisplaced simple supracondylar fracture without intercondylar fracture of left humerus, subsequent encounter for fracture with malunion*/
,'S42415S'  /*Nondisplaced simple supracondylar fracture without intercondylar fracture of left humerus, sequela*/
,'S42416D'  /*Nondisplaced simple supracondylar fracture without intercondylar fracture of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42416G'  /*Nondisplaced simple supracondylar fracture without intercondylar fracture of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42416K'  /*Nondisplaced simple supracondylar fracture without intercondylar fracture of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42416P'  /*Nondisplaced simple supracondylar fracture without intercondylar fracture of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42416S'  /*Nondisplaced simple supracondylar fracture without intercondylar fracture of unspecified humerus, sequela*/
,'S42421D'  /*Displaced comminuted supracondylar fracture without intercondylar fracture of right humerus, subsequent encounter for fracture with routine healing*/
,'S42421G'  /*Displaced comminuted supracondylar fracture without intercondylar fracture of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42421K'  /*Displaced comminuted supracondylar fracture without intercondylar fracture of right humerus, subsequent encounter for fracture with nonunion*/
,'S42421P'  /*Displaced comminuted supracondylar fracture without intercondylar fracture of right humerus, subsequent encounter for fracture with malunion*/
,'S42421S'  /*Displaced comminuted supracondylar fracture without intercondylar fracture of right humerus, sequela*/
,'S42422D'  /*Displaced comminuted supracondylar fracture without intercondylar fracture of left humerus, subsequent encounter for fracture with routine healing*/
,'S42422G'  /*Displaced comminuted supracondylar fracture without intercondylar fracture of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42422K'  /*Displaced comminuted supracondylar fracture without intercondylar fracture of left humerus, subsequent encounter for fracture with nonunion*/
,'S42422P'  /*Displaced comminuted supracondylar fracture without intercondylar fracture of left humerus, subsequent encounter for fracture with malunion*/
,'S42422S'  /*Displaced comminuted supracondylar fracture without intercondylar fracture of left humerus, sequela*/
,'S42423D'  /*Displaced comminuted supracondylar fracture without intercondylar fracture of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42423G'  /*Displaced comminuted supracondylar fracture without intercondylar fracture of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42423K'  /*Displaced comminuted supracondylar fracture without intercondylar fracture of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42423P'  /*Displaced comminuted supracondylar fracture without intercondylar fracture of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42423S'  /*Displaced comminuted supracondylar fracture without intercondylar fracture of unspecified humerus, sequela*/
,'S42424D'  /*Nondisplaced comminuted supracondylar fracture without intercondylar fracture of right humerus, subsequent encounter for fracture with routine healing*/
,'S42424G'  /*Nondisplaced comminuted supracondylar fracture without intercondylar fracture of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42424K'  /*Nondisplaced comminuted supracondylar fracture without intercondylar fracture of right humerus, subsequent encounter for fracture with nonunion*/
,'S42424P'  /*Nondisplaced comminuted supracondylar fracture without intercondylar fracture of right humerus, subsequent encounter for fracture with malunion*/
,'S42424S'  /*Nondisplaced comminuted supracondylar fracture without intercondylar fracture of right humerus, sequela*/
,'S42425D'  /*Nondisplaced comminuted supracondylar fracture without intercondylar fracture of left humerus, subsequent encounter for fracture with routine healing*/
,'S42425G'  /*Nondisplaced comminuted supracondylar fracture without intercondylar fracture of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42425K'  /*Nondisplaced comminuted supracondylar fracture without intercondylar fracture of left humerus, subsequent encounter for fracture with nonunion*/
,'S42425P'  /*Nondisplaced comminuted supracondylar fracture without intercondylar fracture of left humerus, subsequent encounter for fracture with malunion*/
,'S42425S'  /*Nondisplaced comminuted supracondylar fracture without intercondylar fracture of left humerus, sequela*/
,'S42426D'  /*Nondisplaced comminuted supracondylar fracture without intercondylar fracture of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42426G'  /*Nondisplaced comminuted supracondylar fracture without intercondylar fracture of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42426K'  /*Nondisplaced comminuted supracondylar fracture without intercondylar fracture of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42426P'  /*Nondisplaced comminuted supracondylar fracture without intercondylar fracture of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42426S'  /*Nondisplaced comminuted supracondylar fracture without intercondylar fracture of unspecified humerus, sequela*/
,'S42431D'  /*Displaced fracture (avulsion) of lateral epicondyle of right humerus, subsequent encounter for fracture with routine healing*/
,'S42431G'  /*Displaced fracture (avulsion) of lateral epicondyle of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42431K'  /*Displaced fracture (avulsion) of lateral epicondyle of right humerus, subsequent encounter for fracture with nonunion*/
,'S42431P'  /*Displaced fracture (avulsion) of lateral epicondyle of right humerus, subsequent encounter for fracture with malunion*/
,'S42431S'  /*Displaced fracture (avulsion) of lateral epicondyle of right humerus, sequela*/
,'S42432D'  /*Displaced fracture (avulsion) of lateral epicondyle of left humerus, subsequent encounter for fracture with routine healing*/
,'S42432G'  /*Displaced fracture (avulsion) of lateral epicondyle of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42432K'  /*Displaced fracture (avulsion) of lateral epicondyle of left humerus, subsequent encounter for fracture with nonunion*/
,'S42432P'  /*Displaced fracture (avulsion) of lateral epicondyle of left humerus, subsequent encounter for fracture with malunion*/
,'S42432S'  /*Displaced fracture (avulsion) of lateral epicondyle of left humerus, sequela*/
,'S42433D'  /*Displaced fracture (avulsion) of lateral epicondyle of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42433G'  /*Displaced fracture (avulsion) of lateral epicondyle of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42433K'  /*Displaced fracture (avulsion) of lateral epicondyle of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42433P'  /*Displaced fracture (avulsion) of lateral epicondyle of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42433S'  /*Displaced fracture (avulsion) of lateral epicondyle of unspecified humerus, sequela*/
,'S42434D'  /*Nondisplaced fracture (avulsion) of lateral epicondyle of right humerus, subsequent encounter for fracture with routine healing*/
,'S42434G'  /*Nondisplaced fracture (avulsion) of lateral epicondyle of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42434K'  /*Nondisplaced fracture (avulsion) of lateral epicondyle of right humerus, subsequent encounter for fracture with nonunion*/
,'S42434P'  /*Nondisplaced fracture (avulsion) of lateral epicondyle of right humerus, subsequent encounter for fracture with malunion*/
,'S42434S'  /*Nondisplaced fracture (avulsion) of lateral epicondyle of right humerus, sequela*/
,'S42435D'  /*Nondisplaced fracture (avulsion) of lateral epicondyle of left humerus, subsequent encounter for fracture with routine healing*/
,'S42435G'  /*Nondisplaced fracture (avulsion) of lateral epicondyle of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42435K'  /*Nondisplaced fracture (avulsion) of lateral epicondyle of left humerus, subsequent encounter for fracture with nonunion*/
,'S42435P'  /*Nondisplaced fracture (avulsion) of lateral epicondyle of left humerus, subsequent encounter for fracture with malunion*/
,'S42435S'  /*Nondisplaced fracture (avulsion) of lateral epicondyle of left humerus, sequela*/
,'S42436D'  /*Nondisplaced fracture (avulsion) of lateral epicondyle of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42436G'  /*Nondisplaced fracture (avulsion) of lateral epicondyle of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42436K'  /*Nondisplaced fracture (avulsion) of lateral epicondyle of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42436P'  /*Nondisplaced fracture (avulsion) of lateral epicondyle of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42436S'  /*Nondisplaced fracture (avulsion) of lateral epicondyle of unspecified humerus, sequela*/
,'S42441D'  /*Displaced fracture (avulsion) of medial epicondyle of right humerus, subsequent encounter for fracture with routine healing*/
,'S42441G'  /*Displaced fracture (avulsion) of medial epicondyle of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42441K'  /*Displaced fracture (avulsion) of medial epicondyle of right humerus, subsequent encounter for fracture with nonunion*/
,'S42441P'  /*Displaced fracture (avulsion) of medial epicondyle of right humerus, subsequent encounter for fracture with malunion*/
,'S42441S'  /*Displaced fracture (avulsion) of medial epicondyle of right humerus, sequela*/
,'S42442D'  /*Displaced fracture (avulsion) of medial epicondyle of left humerus, subsequent encounter for fracture with routine healing*/
,'S42442G'  /*Displaced fracture (avulsion) of medial epicondyle of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42442K'  /*Displaced fracture (avulsion) of medial epicondyle of left humerus, subsequent encounter for fracture with nonunion*/
,'S42442P'  /*Displaced fracture (avulsion) of medial epicondyle of left humerus, subsequent encounter for fracture with malunion*/
,'S42442S'  /*Displaced fracture (avulsion) of medial epicondyle of left humerus, sequela*/
,'S42443D'  /*Displaced fracture (avulsion) of medial epicondyle of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42443G'  /*Displaced fracture (avulsion) of medial epicondyle of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42443K'  /*Displaced fracture (avulsion) of medial epicondyle of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42443P'  /*Displaced fracture (avulsion) of medial epicondyle of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42443S'  /*Displaced fracture (avulsion) of medial epicondyle of unspecified humerus, sequela*/
,'S42444D'  /*Nondisplaced fracture (avulsion) of medial epicondyle of right humerus, subsequent encounter for fracture with routine healing*/
,'S42444G'  /*Nondisplaced fracture (avulsion) of medial epicondyle of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42444K'  /*Nondisplaced fracture (avulsion) of medial epicondyle of right humerus, subsequent encounter for fracture with nonunion*/
,'S42444P'  /*Nondisplaced fracture (avulsion) of medial epicondyle of right humerus, subsequent encounter for fracture with malunion*/
,'S42444S'  /*Nondisplaced fracture (avulsion) of medial epicondyle of right humerus, sequela*/
,'S42445D'  /*Nondisplaced fracture (avulsion) of medial epicondyle of left humerus, subsequent encounter for fracture with routine healing*/
,'S42445G'  /*Nondisplaced fracture (avulsion) of medial epicondyle of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42445K'  /*Nondisplaced fracture (avulsion) of medial epicondyle of left humerus, subsequent encounter for fracture with nonunion*/
,'S42445P'  /*Nondisplaced fracture (avulsion) of medial epicondyle of left humerus, subsequent encounter for fracture with malunion*/
,'S42445S'  /*Nondisplaced fracture (avulsion) of medial epicondyle of left humerus, sequela*/
,'S42446D'  /*Nondisplaced fracture (avulsion) of medial epicondyle of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42446G'  /*Nondisplaced fracture (avulsion) of medial epicondyle of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42446K'  /*Nondisplaced fracture (avulsion) of medial epicondyle of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42446P'  /*Nondisplaced fracture (avulsion) of medial epicondyle of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42446S'  /*Nondisplaced fracture (avulsion) of medial epicondyle of unspecified humerus, sequela*/
,'S42447D'  /*Incarcerated fracture (avulsion) of medial epicondyle of right humerus, subsequent encounter for fracture with routine healing*/
,'S42447G'  /*Incarcerated fracture (avulsion) of medial epicondyle of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42447K'  /*Incarcerated fracture (avulsion) of medial epicondyle of right humerus, subsequent encounter for fracture with nonunion*/
,'S42447P'  /*Incarcerated fracture (avulsion) of medial epicondyle of right humerus, subsequent encounter for fracture with malunion*/
,'S42447S'  /*Incarcerated fracture (avulsion) of medial epicondyle of right humerus, sequela*/
,'S42448D'  /*Incarcerated fracture (avulsion) of medial epicondyle of left humerus, subsequent encounter for fracture with routine healing*/
,'S42448G'  /*Incarcerated fracture (avulsion) of medial epicondyle of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42448K'  /*Incarcerated fracture (avulsion) of medial epicondyle of left humerus, subsequent encounter for fracture with nonunion*/
,'S42448P'  /*Incarcerated fracture (avulsion) of medial epicondyle of left humerus, subsequent encounter for fracture with malunion*/
,'S42448S'  /*Incarcerated fracture (avulsion) of medial epicondyle of left humerus, sequela*/
,'S42449D'  /*Incarcerated fracture (avulsion) of medial epicondyle of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42449G'  /*Incarcerated fracture (avulsion) of medial epicondyle of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42449K'  /*Incarcerated fracture (avulsion) of medial epicondyle of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42449P'  /*Incarcerated fracture (avulsion) of medial epicondyle of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42449S'  /*Incarcerated fracture (avulsion) of medial epicondyle of unspecified humerus, sequela*/
,'S42451D'  /*Displaced fracture of lateral condyle of right humerus, subsequent encounter for fracture with routine healing*/
,'S42451G'  /*Displaced fracture of lateral condyle of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42451K'  /*Displaced fracture of lateral condyle of right humerus, subsequent encounter for fracture with nonunion*/
,'S42451P'  /*Displaced fracture of lateral condyle of right humerus, subsequent encounter for fracture with malunion*/
,'S42451S'  /*Displaced fracture of lateral condyle of right humerus, sequela*/
,'S42452D'  /*Displaced fracture of lateral condyle of left humerus, subsequent encounter for fracture with routine healing*/
,'S42452G'  /*Displaced fracture of lateral condyle of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42452K'  /*Displaced fracture of lateral condyle of left humerus, subsequent encounter for fracture with nonunion*/
,'S42452P'  /*Displaced fracture of lateral condyle of left humerus, subsequent encounter for fracture with malunion*/
,'S42452S'  /*Displaced fracture of lateral condyle of left humerus, sequela*/
,'S42453D'  /*Displaced fracture of lateral condyle of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42453G'  /*Displaced fracture of lateral condyle of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42453K'  /*Displaced fracture of lateral condyle of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42453P'  /*Displaced fracture of lateral condyle of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42453S'  /*Displaced fracture of lateral condyle of unspecified humerus, sequela*/
,'S42454D'  /*Nondisplaced fracture of lateral condyle of right humerus, subsequent encounter for fracture with routine healing*/
,'S42454G'  /*Nondisplaced fracture of lateral condyle of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42454K'  /*Nondisplaced fracture of lateral condyle of right humerus, subsequent encounter for fracture with nonunion*/
,'S42454P'  /*Nondisplaced fracture of lateral condyle of right humerus, subsequent encounter for fracture with malunion*/
,'S42454S'  /*Nondisplaced fracture of lateral condyle of right humerus, sequela*/
,'S42455D'  /*Nondisplaced fracture of lateral condyle of left humerus, subsequent encounter for fracture with routine healing*/
,'S42455G'  /*Nondisplaced fracture of lateral condyle of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42455K'  /*Nondisplaced fracture of lateral condyle of left humerus, subsequent encounter for fracture with nonunion*/
,'S42455P'  /*Nondisplaced fracture of lateral condyle of left humerus, subsequent encounter for fracture with malunion*/
,'S42455S'  /*Nondisplaced fracture of lateral condyle of left humerus, sequela*/
,'S42456D'  /*Nondisplaced fracture of lateral condyle of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42456G'  /*Nondisplaced fracture of lateral condyle of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42456K'  /*Nondisplaced fracture of lateral condyle of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42456P'  /*Nondisplaced fracture of lateral condyle of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42456S'  /*Nondisplaced fracture of lateral condyle of unspecified humerus, sequela*/
,'S42461D'  /*Displaced fracture of medial condyle of right humerus, subsequent encounter for fracture with routine healing*/
,'S42461G'  /*Displaced fracture of medial condyle of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42461K'  /*Displaced fracture of medial condyle of right humerus, subsequent encounter for fracture with nonunion*/
,'S42461P'  /*Displaced fracture of medial condyle of right humerus, subsequent encounter for fracture with malunion*/
,'S42461S'  /*Displaced fracture of medial condyle of right humerus, sequela*/
,'S42462D'  /*Displaced fracture of medial condyle of left humerus, subsequent encounter for fracture with routine healing*/
,'S42462G'  /*Displaced fracture of medial condyle of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42462K'  /*Displaced fracture of medial condyle of left humerus, subsequent encounter for fracture with nonunion*/
,'S42462P'  /*Displaced fracture of medial condyle of left humerus, subsequent encounter for fracture with malunion*/
,'S42462S'  /*Displaced fracture of medial condyle of left humerus, sequela*/
,'S42463D'  /*Displaced fracture of medial condyle of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42463G'  /*Displaced fracture of medial condyle of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42463K'  /*Displaced fracture of medial condyle of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42463P'  /*Displaced fracture of medial condyle of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42463S'  /*Displaced fracture of medial condyle of unspecified humerus, sequela*/
,'S42464D'  /*Nondisplaced fracture of medial condyle of right humerus, subsequent encounter for fracture with routine healing*/
,'S42464G'  /*Nondisplaced fracture of medial condyle of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42464K'  /*Nondisplaced fracture of medial condyle of right humerus, subsequent encounter for fracture with nonunion*/
,'S42464P'  /*Nondisplaced fracture of medial condyle of right humerus, subsequent encounter for fracture with malunion*/
,'S42464S'  /*Nondisplaced fracture of medial condyle of right humerus, sequela*/
,'S42465D'  /*Nondisplaced fracture of medial condyle of left humerus, subsequent encounter for fracture with routine healing*/
,'S42465G'  /*Nondisplaced fracture of medial condyle of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42465K'  /*Nondisplaced fracture of medial condyle of left humerus, subsequent encounter for fracture with nonunion*/
,'S42465P'  /*Nondisplaced fracture of medial condyle of left humerus, subsequent encounter for fracture with malunion*/
,'S42465S'  /*Nondisplaced fracture of medial condyle of left humerus, sequela*/
,'S42466D'  /*Nondisplaced fracture of medial condyle of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42466G'  /*Nondisplaced fracture of medial condyle of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42466K'  /*Nondisplaced fracture of medial condyle of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42466P'  /*Nondisplaced fracture of medial condyle of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42466S'  /*Nondisplaced fracture of medial condyle of unspecified humerus, sequela*/
,'S42471D'  /*Displaced transcondylar fracture of right humerus, subsequent encounter for fracture with routine healing*/
,'S42471G'  /*Displaced transcondylar fracture of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42471K'  /*Displaced transcondylar fracture of right humerus, subsequent encounter for fracture with nonunion*/
,'S42471P'  /*Displaced transcondylar fracture of right humerus, subsequent encounter for fracture with malunion*/
,'S42471S'  /*Displaced transcondylar fracture of right humerus, sequela*/
,'S42472D'  /*Displaced transcondylar fracture of left humerus, subsequent encounter for fracture with routine healing*/
,'S42472G'  /*Displaced transcondylar fracture of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42472K'  /*Displaced transcondylar fracture of left humerus, subsequent encounter for fracture with nonunion*/
,'S42472P'  /*Displaced transcondylar fracture of left humerus, subsequent encounter for fracture with malunion*/
,'S42472S'  /*Displaced transcondylar fracture of left humerus, sequela*/
,'S42473D'  /*Displaced transcondylar fracture of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42473G'  /*Displaced transcondylar fracture of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42473K'  /*Displaced transcondylar fracture of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42473P'  /*Displaced transcondylar fracture of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42473S'  /*Displaced transcondylar fracture of unspecified humerus, sequela*/
,'S42474D'  /*Nondisplaced transcondylar fracture of right humerus, subsequent encounter for fracture with routine healing*/
,'S42474G'  /*Nondisplaced transcondylar fracture of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42474K'  /*Nondisplaced transcondylar fracture of right humerus, subsequent encounter for fracture with nonunion*/
,'S42474P'  /*Nondisplaced transcondylar fracture of right humerus, subsequent encounter for fracture with malunion*/
,'S42474S'  /*Nondisplaced transcondylar fracture of right humerus, sequela*/
,'S42475D'  /*Nondisplaced transcondylar fracture of left humerus, subsequent encounter for fracture with routine healing*/
,'S42475G'  /*Nondisplaced transcondylar fracture of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42475K'  /*Nondisplaced transcondylar fracture of left humerus, subsequent encounter for fracture with nonunion*/
,'S42475P'  /*Nondisplaced transcondylar fracture of left humerus, subsequent encounter for fracture with malunion*/
,'S42475S'  /*Nondisplaced transcondylar fracture of left humerus, sequela*/
,'S42476D'  /*Nondisplaced transcondylar fracture of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42476G'  /*Nondisplaced transcondylar fracture of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42476K'  /*Nondisplaced transcondylar fracture of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42476P'  /*Nondisplaced transcondylar fracture of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42476S'  /*Nondisplaced transcondylar fracture of unspecified humerus, sequela*/
,'S42481D'  /*Torus fracture of lower end of right humerus, subsequent encounter for fracture with routine healing*/
,'S42481G'  /*Torus fracture of lower end of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42481K'  /*Torus fracture of lower end of right humerus, subsequent encounter for fracture with nonunion*/
,'S42481P'  /*Torus fracture of lower end of right humerus, subsequent encounter for fracture with malunion*/
,'S42481S'  /*Torus fracture of lower end of right humerus, sequela*/
,'S42482D'  /*Torus fracture of lower end of left humerus, subsequent encounter for fracture with routine healing*/
,'S42482G'  /*Torus fracture of lower end of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42482K'  /*Torus fracture of lower end of left humerus, subsequent encounter for fracture with nonunion*/
,'S42482P'  /*Torus fracture of lower end of left humerus, subsequent encounter for fracture with malunion*/
,'S42482S'  /*Torus fracture of lower end of left humerus, sequela*/
,'S42489D'  /*Torus fracture of lower end of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42489G'  /*Torus fracture of lower end of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42489K'  /*Torus fracture of lower end of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42489P'  /*Torus fracture of lower end of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42489S'  /*Torus fracture of lower end of unspecified humerus, sequela*/
,'S42491D'  /*Other displaced fracture of lower end of right humerus, subsequent encounter for fracture with routine healing*/
,'S42491G'  /*Other displaced fracture of lower end of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42491K'  /*Other displaced fracture of lower end of right humerus, subsequent encounter for fracture with nonunion*/
,'S42491P'  /*Other displaced fracture of lower end of right humerus, subsequent encounter for fracture with malunion*/
,'S42491S'  /*Other displaced fracture of lower end of right humerus, sequela*/
,'S42492D'  /*Other displaced fracture of lower end of left humerus, subsequent encounter for fracture with routine healing*/
,'S42492G'  /*Other displaced fracture of lower end of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42492K'  /*Other displaced fracture of lower end of left humerus, subsequent encounter for fracture with nonunion*/
,'S42492P'  /*Other displaced fracture of lower end of left humerus, subsequent encounter for fracture with malunion*/
,'S42492S'  /*Other displaced fracture of lower end of left humerus, sequela*/
,'S42493D'  /*Other displaced fracture of lower end of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42493G'  /*Other displaced fracture of lower end of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42493K'  /*Other displaced fracture of lower end of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42493P'  /*Other displaced fracture of lower end of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42493S'  /*Other displaced fracture of lower end of unspecified humerus, sequela*/
,'S42494D'  /*Other nondisplaced fracture of lower end of right humerus, subsequent encounter for fracture with routine healing*/
,'S42494G'  /*Other nondisplaced fracture of lower end of right humerus, subsequent encounter for fracture with delayed healing*/
,'S42494K'  /*Other nondisplaced fracture of lower end of right humerus, subsequent encounter for fracture with nonunion*/
,'S42494P'  /*Other nondisplaced fracture of lower end of right humerus, subsequent encounter for fracture with malunion*/
,'S42494S'  /*Other nondisplaced fracture of lower end of right humerus, sequela*/
,'S42495D'  /*Other nondisplaced fracture of lower end of left humerus, subsequent encounter for fracture with routine healing*/
,'S42495G'  /*Other nondisplaced fracture of lower end of left humerus, subsequent encounter for fracture with delayed healing*/
,'S42495K'  /*Other nondisplaced fracture of lower end of left humerus, subsequent encounter for fracture with nonunion*/
,'S42495P'  /*Other nondisplaced fracture of lower end of left humerus, subsequent encounter for fracture with malunion*/
,'S42495S'  /*Other nondisplaced fracture of lower end of left humerus, sequela*/
,'S42496D'  /*Other nondisplaced fracture of lower end of unspecified humerus, subsequent encounter for fracture with routine healing*/
,'S42496G'  /*Other nondisplaced fracture of lower end of unspecified humerus, subsequent encounter for fracture with delayed healing*/
,'S42496K'  /*Other nondisplaced fracture of lower end of unspecified humerus, subsequent encounter for fracture with nonunion*/
,'S42496P'  /*Other nondisplaced fracture of lower end of unspecified humerus, subsequent encounter for fracture with malunion*/
,'S42496S'  /*Other nondisplaced fracture of lower end of unspecified humerus, sequela*/
,'S4290XD'  /*Fracture of unspecified shoulder girdle, part unspecified, subsequent encounter for fracture with routine healing*/
,'S4290XG'  /*Fracture of unspecified shoulder girdle, part unspecified, subsequent encounter for fracture with delayed healing*/
,'S4290XK'  /*Fracture of unspecified shoulder girdle, part unspecified, subsequent encounter for fracture with nonunion*/
,'S4290XP'  /*Fracture of unspecified shoulder girdle, part unspecified, subsequent encounter for fracture with malunion*/
,'S4290XS'  /*Fracture of unspecified shoulder girdle, part unspecified, sequela*/
,'S4291XD'  /*Fracture of right shoulder girdle, part unspecified, subsequent encounter for fracture with routine healing*/
,'S4291XG'  /*Fracture of right shoulder girdle, part unspecified, subsequent encounter for fracture with delayed healing*/
,'S4291XK'  /*Fracture of right shoulder girdle, part unspecified, subsequent encounter for fracture with nonunion*/
,'S4291XP'  /*Fracture of right shoulder girdle, part unspecified, subsequent encounter for fracture with malunion*/
,'S4291XS'  /*Fracture of right shoulder girdle, part unspecified, sequela*/
,'S4292XD'  /*Fracture of left shoulder girdle, part unspecified, subsequent encounter for fracture with routine healing*/
,'S4292XG'  /*Fracture of left shoulder girdle, part unspecified, subsequent encounter for fracture with delayed healing*/
,'S4292XK'  /*Fracture of left shoulder girdle, part unspecified, subsequent encounter for fracture with nonunion*/
,'S4292XP'  /*Fracture of left shoulder girdle, part unspecified, subsequent encounter for fracture with malunion*/
,'S4292XS'  /*Fracture of left shoulder girdle, part unspecified, sequela*/
,'S43001D'  /*Unspecified subluxation of right shoulder joint, subsequent encounter*/
,'S43001S'  /*Unspecified subluxation of right shoulder joint, sequela*/
,'S43002D'  /*Unspecified subluxation of left shoulder joint, subsequent encounter*/
,'S43002S'  /*Unspecified subluxation of left shoulder joint, sequela*/
,'S43003D'  /*Unspecified subluxation of unspecified shoulder joint, subsequent encounter*/
,'S43003S'  /*Unspecified subluxation of unspecified shoulder joint, sequela*/
,'S43004D'  /*Unspecified dislocation of right shoulder joint, subsequent encounter*/
,'S43004S'  /*Unspecified dislocation of right shoulder joint, sequela*/
,'S43005D'  /*Unspecified dislocation of left shoulder joint, subsequent encounter*/
,'S43005S'  /*Unspecified dislocation of left shoulder joint, sequela*/
,'S43006D'  /*Unspecified dislocation of unspecified shoulder joint, subsequent encounter*/
,'S43006S'  /*Unspecified dislocation of unspecified shoulder joint, sequela*/
,'S43011D'  /*Anterior subluxation of right humerus, subsequent encounter*/
,'S43011S'  /*Anterior subluxation of right humerus, sequela*/
,'S43012D'  /*Anterior subluxation of left humerus, subsequent encounter*/
,'S43012S'  /*Anterior subluxation of left humerus, sequela*/
,'S43013D'  /*Anterior subluxation of unspecified humerus, subsequent encounter*/
,'S43013S'  /*Anterior subluxation of unspecified humerus, sequela*/
,'S43014D'  /*Anterior dislocation of right humerus, subsequent encounter*/
,'S43014S'  /*Anterior dislocation of right humerus, sequela*/
,'S43015D'  /*Anterior dislocation of left humerus, subsequent encounter*/
,'S43015S'  /*Anterior dislocation of left humerus, sequela*/
,'S43016D'  /*Anterior dislocation of unspecified humerus, subsequent encounter*/
,'S43016S'  /*Anterior dislocation of unspecified humerus, sequela*/
,'S43021D'  /*Posterior subluxation of right humerus, subsequent encounter*/
,'S43021S'  /*Posterior subluxation of right humerus, sequela*/
,'S43022D'  /*Posterior subluxation of left humerus, subsequent encounter*/
,'S43022S'  /*Posterior subluxation of left humerus, sequela*/
,'S43023D'  /*Posterior subluxation of unspecified humerus, subsequent encounter*/
,'S43023S'  /*Posterior subluxation of unspecified humerus, sequela*/
,'S43024D'  /*Posterior dislocation of right humerus, subsequent encounter*/
,'S43024S'  /*Posterior dislocation of right humerus, sequela*/
,'S43025D'  /*Posterior dislocation of left humerus, subsequent encounter*/
,'S43025S'  /*Posterior dislocation of left humerus, sequela*/
,'S43026D'  /*Posterior dislocation of unspecified humerus, subsequent encounter*/
,'S43026S'  /*Posterior dislocation of unspecified humerus, sequela*/
,'S43031D'  /*Inferior subluxation of right humerus, subsequent encounter*/
,'S43031S'  /*Inferior subluxation of right humerus, sequela*/
,'S43032D'  /*Inferior subluxation of left humerus, subsequent encounter*/
,'S43032S'  /*Inferior subluxation of left humerus, sequela*/
,'S43033D'  /*Inferior subluxation of unspecified humerus, subsequent encounter*/
,'S43033S'  /*Inferior subluxation of unspecified humerus, sequela*/
,'S43034D'  /*Inferior dislocation of right humerus, subsequent encounter*/
,'S43034S'  /*Inferior dislocation of right humerus, sequela*/
,'S43035D'  /*Inferior dislocation of left humerus, subsequent encounter*/
,'S43035S'  /*Inferior dislocation of left humerus, sequela*/
,'S43036D'  /*Inferior dislocation of unspecified humerus, subsequent encounter*/
,'S43036S'  /*Inferior dislocation of unspecified humerus, sequela*/
,'S43081D'  /*Other subluxation of right shoulder joint, subsequent encounter*/
,'S43081S'  /*Other subluxation of right shoulder joint, sequela*/
,'S43082D'  /*Other subluxation of left shoulder joint, subsequent encounter*/
,'S43082S'  /*Other subluxation of left shoulder joint, sequela*/
,'S43083D'  /*Other subluxation of unspecified shoulder joint, subsequent encounter*/
,'S43083S'  /*Other subluxation of unspecified shoulder joint, sequela*/
,'S43084D'  /*Other dislocation of right shoulder joint, subsequent encounter*/
,'S43084S'  /*Other dislocation of right shoulder joint, sequela*/
,'S43085D'  /*Other dislocation of left shoulder joint, subsequent encounter*/
,'S43085S'  /*Other dislocation of left shoulder joint, sequela*/
,'S43086D'  /*Other dislocation of unspecified shoulder joint, subsequent encounter*/
,'S43086S'  /*Other dislocation of unspecified shoulder joint, sequela*/
,'S43101D'  /*Unspecified dislocation of right acromioclavicular joint, subsequent encounter*/
,'S43101S'  /*Unspecified dislocation of right acromioclavicular joint, sequela*/
,'S43102D'  /*Unspecified dislocation of left acromioclavicular joint, subsequent encounter*/
,'S43102S'  /*Unspecified dislocation of left acromioclavicular joint, sequela*/
,'S43109D'  /*Unspecified dislocation of unspecified acromioclavicular joint, subsequent encounter*/
,'S43109S'  /*Unspecified dislocation of unspecified acromioclavicular joint, sequela*/
,'S43111D'  /*Subluxation of right acromioclavicular joint, subsequent encounter*/
,'S43111S'  /*Subluxation of right acromioclavicular joint, sequela*/
,'S43112D'  /*Subluxation of left acromioclavicular joint, subsequent encounter*/
,'S43112S'  /*Subluxation of left acromioclavicular joint, sequela*/
,'S43119D'  /*Subluxation of unspecified acromioclavicular joint, subsequent encounter*/
,'S43119S'  /*Subluxation of unspecified acromioclavicular joint, sequela*/
,'S43121D'  /*Dislocation of right acromioclavicular joint, 100%-200% displacement, subsequent encounter*/
,'S43121S'  /*Dislocation of right acromioclavicular joint, 100%-200% displacement, sequela*/
,'S43122D'  /*Dislocation of left acromioclavicular joint, 100%-200% displacement, subsequent encounter*/
,'S43122S'  /*Dislocation of left acromioclavicular joint, 100%-200% displacement, sequela*/
,'S43129D'  /*Dislocation of unspecified acromioclavicular joint, 100%-200% displacement, subsequent encounter*/
,'S43129S'  /*Dislocation of unspecified acromioclavicular joint, 100%-200% displacement, sequela*/
,'S43131D'  /*Dislocation of right acromioclavicular joint, greater than 200% displacement, subsequent encounter*/
,'S43131S'  /*Dislocation of right acromioclavicular joint, greater than 200% displacement, sequela*/
,'S43132D'  /*Dislocation of left acromioclavicular joint, greater than 200% displacement, subsequent encounter*/
,'S43132S'  /*Dislocation of left acromioclavicular joint, greater than 200% displacement, sequela*/
,'S43139D'  /*Dislocation of unspecified acromioclavicular joint, greater than 200% displacement, subsequent encounter*/
,'S43139S'  /*Dislocation of unspecified acromioclavicular joint, greater than 200% displacement, sequela*/
,'S43141D'  /*Inferior dislocation of right acromioclavicular joint, subsequent encounter*/
,'S43141S'  /*Inferior dislocation of right acromioclavicular joint, sequela*/
,'S43142D'  /*Inferior dislocation of left acromioclavicular joint, subsequent encounter*/
,'S43142S'  /*Inferior dislocation of left acromioclavicular joint, sequela*/
,'S43149D'  /*Inferior dislocation of unspecified acromioclavicular joint, subsequent encounter*/
,'S43149S'  /*Inferior dislocation of unspecified acromioclavicular joint, sequela*/
,'S43151D'  /*Posterior dislocation of right acromioclavicular joint, subsequent encounter*/
,'S43151S'  /*Posterior dislocation of right acromioclavicular joint, sequela*/
,'S43152D'  /*Posterior dislocation of left acromioclavicular joint, subsequent encounter*/
,'S43152S'  /*Posterior dislocation of left acromioclavicular joint, sequela*/
,'S43159D'  /*Posterior dislocation of unspecified acromioclavicular joint, subsequent encounter*/
,'S43159S'  /*Posterior dislocation of unspecified acromioclavicular joint, sequela*/
,'S43201D'  /*Unspecified subluxation of right sternoclavicular joint, subsequent encounter*/
,'S43201S'  /*Unspecified subluxation of right sternoclavicular joint, sequela*/
,'S43202D'  /*Unspecified subluxation of left sternoclavicular joint, subsequent encounter*/
,'S43202S'  /*Unspecified subluxation of left sternoclavicular joint, sequela*/
,'S43203D'  /*Unspecified subluxation of unspecified sternoclavicular joint, subsequent encounter*/
,'S43203S'  /*Unspecified subluxation of unspecified sternoclavicular joint, sequela*/
,'S43204D'  /*Unspecified dislocation of right sternoclavicular joint, subsequent encounter*/
,'S43204S'  /*Unspecified dislocation of right sternoclavicular joint, sequela*/
,'S43205D'  /*Unspecified dislocation of left sternoclavicular joint, subsequent encounter*/
,'S43205S'  /*Unspecified dislocation of left sternoclavicular joint, sequela*/
,'S43206D'  /*Unspecified dislocation of unspecified sternoclavicular joint, subsequent encounter*/
,'S43206S'  /*Unspecified dislocation of unspecified sternoclavicular joint, sequela*/
,'S43211D'  /*Anterior subluxation of right sternoclavicular joint, subsequent encounter*/
,'S43211S'  /*Anterior subluxation of right sternoclavicular joint, sequela*/
,'S43212D'  /*Anterior subluxation of left sternoclavicular joint, subsequent encounter*/
,'S43212S'  /*Anterior subluxation of left sternoclavicular joint, sequela*/
,'S43213D'  /*Anterior subluxation of unspecified sternoclavicular joint, subsequent encounter*/
,'S43213S'  /*Anterior subluxation of unspecified sternoclavicular joint, sequela*/
,'S43214D'  /*Anterior dislocation of right sternoclavicular joint, subsequent encounter*/
,'S43214S'  /*Anterior dislocation of right sternoclavicular joint, sequela*/
,'S43215D'  /*Anterior dislocation of left sternoclavicular joint, subsequent encounter*/
,'S43215S'  /*Anterior dislocation of left sternoclavicular joint, sequela*/
,'S43216D'  /*Anterior dislocation of unspecified sternoclavicular joint, subsequent encounter*/
,'S43216S'  /*Anterior dislocation of unspecified sternoclavicular joint, sequela*/
,'S43221D'  /*Posterior subluxation of right sternoclavicular joint, subsequent encounter*/
,'S43221S'  /*Posterior subluxation of right sternoclavicular joint, sequela*/
,'S43222D'  /*Posterior subluxation of left sternoclavicular joint, subsequent encounter*/
,'S43222S'  /*Posterior subluxation of left sternoclavicular joint, sequela*/
,'S43223D'  /*Posterior subluxation of unspecified sternoclavicular joint, subsequent encounter*/
,'S43223S'  /*Posterior subluxation of unspecified sternoclavicular joint, sequela*/
,'S43224D'  /*Posterior dislocation of right sternoclavicular joint, subsequent encounter*/
,'S43224S'  /*Posterior dislocation of right sternoclavicular joint, sequela*/
,'S43225D'  /*Posterior dislocation of left sternoclavicular joint, subsequent encounter*/
,'S43225S'  /*Posterior dislocation of left sternoclavicular joint, sequela*/
,'S43226D'  /*Posterior dislocation of unspecified sternoclavicular joint, subsequent encounter*/
,'S43226S'  /*Posterior dislocation of unspecified sternoclavicular joint, sequela*/
,'S43301D'  /*Subluxation of unspecified parts of right shoulder girdle, subsequent encounter*/
,'S43301S'  /*Subluxation of unspecified parts of right shoulder girdle, sequela*/
,'S43302D'  /*Subluxation of unspecified parts of left shoulder girdle, subsequent encounter*/
,'S43302S'  /*Subluxation of unspecified parts of left shoulder girdle, sequela*/
,'S43303D'  /*Subluxation of unspecified parts of unspecified shoulder girdle, subsequent encounter*/
,'S43303S'  /*Subluxation of unspecified parts of unspecified shoulder girdle, sequela*/
,'S43304D'  /*Dislocation of unspecified parts of right shoulder girdle, subsequent encounter*/
,'S43304S'  /*Dislocation of unspecified parts of right shoulder girdle, sequela*/
,'S43305D'  /*Dislocation of unspecified parts of left shoulder girdle, subsequent encounter*/
,'S43305S'  /*Dislocation of unspecified parts of left shoulder girdle, sequela*/
,'S43306D'  /*Dislocation of unspecified parts of unspecified shoulder girdle, subsequent encounter*/
,'S43306S'  /*Dislocation of unspecified parts of unspecified shoulder girdle, sequela*/
,'S43311D'  /*Subluxation of right scapula, subsequent encounter*/
,'S43311S'  /*Subluxation of right scapula, sequela*/
,'S43312D'  /*Subluxation of left scapula, subsequent encounter*/
,'S43312S'  /*Subluxation of left scapula, sequela*/
,'S43313D'  /*Subluxation of unspecified scapula, subsequent encounter*/
,'S43313S'  /*Subluxation of unspecified scapula, sequela*/
,'S43314D'  /*Dislocation of right scapula, subsequent encounter*/
,'S43314S'  /*Dislocation of right scapula, sequela*/
,'S43315D'  /*Dislocation of left scapula, subsequent encounter*/
,'S43315S'  /*Dislocation of left scapula, sequela*/
,'S43316D'  /*Dislocation of unspecified scapula, subsequent encounter*/
,'S43316S'  /*Dislocation of unspecified scapula, sequela*/
,'S43391D'  /*Subluxation of other parts of right shoulder girdle, subsequent encounter*/
,'S43391S'  /*Subluxation of other parts of right shoulder girdle, sequela*/
,'S43392D'  /*Subluxation of other parts of left shoulder girdle, subsequent encounter*/
,'S43392S'  /*Subluxation of other parts of left shoulder girdle, sequela*/
,'S43393D'  /*Subluxation of other parts of unspecified shoulder girdle, subsequent encounter*/
,'S43393S'  /*Subluxation of other parts of unspecified shoulder girdle, sequela*/
,'S43394D'  /*Dislocation of other parts of right shoulder girdle, subsequent encounter*/
,'S43394S'  /*Dislocation of other parts of right shoulder girdle, sequela*/
,'S43395D'  /*Dislocation of other parts of left shoulder girdle, subsequent encounter*/
,'S43395S'  /*Dislocation of other parts of left shoulder girdle, sequela*/
,'S43396D'  /*Dislocation of other parts of unspecified shoulder girdle, subsequent encounter*/
,'S43396S'  /*Dislocation of other parts of unspecified shoulder girdle, sequela*/
,'S43401D'  /*Unspecified sprain of right shoulder joint, subsequent encounter*/
,'S43401S'  /*Unspecified sprain of right shoulder joint, sequela*/
,'S43402D'  /*Unspecified sprain of left shoulder joint, subsequent encounter*/
,'S43402S'  /*Unspecified sprain of left shoulder joint, sequela*/
,'S43409D'  /*Unspecified sprain of unspecified shoulder joint, subsequent encounter*/
,'S43409S'  /*Unspecified sprain of unspecified shoulder joint, sequela*/
,'S43411D'  /*Sprain of right coracohumeral (ligament), subsequent encounter*/
,'S43411S'  /*Sprain of right coracohumeral (ligament), sequela*/
,'S43412D'  /*Sprain of left coracohumeral (ligament), subsequent encounter*/
,'S43412S'  /*Sprain of left coracohumeral (ligament), sequela*/
,'S43419D'  /*Sprain of unspecified coracohumeral (ligament), subsequent encounter*/
,'S43419S'  /*Sprain of unspecified coracohumeral (ligament), sequela*/
,'S43421D'  /*Sprain of right rotator cuff capsule, subsequent encounter*/
,'S43421S'  /*Sprain of right rotator cuff capsule, sequela*/
,'S43422D'  /*Sprain of left rotator cuff capsule, subsequent encounter*/
,'S43422S'  /*Sprain of left rotator cuff capsule, sequela*/
,'S43429D'  /*Sprain of unspecified rotator cuff capsule, subsequent encounter*/
,'S43429S'  /*Sprain of unspecified rotator cuff capsule, sequela*/
,'S43431D'  /*Superior glenoid labrum lesion of right shoulder, subsequent encounter*/
,'S43431S'  /*Superior glenoid labrum lesion of right shoulder, sequela*/
,'S43432D'  /*Superior glenoid labrum lesion of left shoulder, subsequent encounter*/
,'S43432S'  /*Superior glenoid labrum lesion of left shoulder, sequela*/
,'S43439D'  /*Superior glenoid labrum lesion of unspecified shoulder, subsequent encounter*/
,'S43439S'  /*Superior glenoid labrum lesion of unspecified shoulder, sequela*/
,'S43491D'  /*Other sprain of right shoulder joint, subsequent encounter*/
,'S43491S'  /*Other sprain of right shoulder joint, sequela*/
,'S43492D'  /*Other sprain of left shoulder joint, subsequent encounter*/
,'S43492S'  /*Other sprain of left shoulder joint, sequela*/
,'S43499D'  /*Other sprain of unspecified shoulder joint, subsequent encounter*/
,'S43499S'  /*Other sprain of unspecified shoulder joint, sequela*/
,'S4350XD'  /*Sprain of unspecified acromioclavicular joint, subsequent encounter*/
,'S4350XS'  /*Sprain of unspecified acromioclavicular joint, sequela*/
,'S4351XD'  /*Sprain of right acromioclavicular joint, subsequent encounter*/
,'S4351XS'  /*Sprain of right acromioclavicular joint, sequela*/
,'S4352XD'  /*Sprain of left acromioclavicular joint, subsequent encounter*/
,'S4352XS'  /*Sprain of left acromioclavicular joint, sequela*/
,'S4360XD'  /*Sprain of unspecified sternoclavicular joint, subsequent encounter*/
,'S4360XS'  /*Sprain of unspecified sternoclavicular joint, sequela*/
,'S4361XD'  /*Sprain of right sternoclavicular joint, subsequent encounter*/
,'S4361XS'  /*Sprain of right sternoclavicular joint, sequela*/
,'S4362XD'  /*Sprain of left sternoclavicular joint, subsequent encounter*/
,'S4362XS'  /*Sprain of left sternoclavicular joint, sequela*/
,'S4380XD'  /*Sprain of other specified parts of unspecified shoulder girdle, subsequent encounter*/
,'S4380XS'  /*Sprain of other specified parts of unspecified shoulder girdle, sequela*/
,'S4381XD'  /*Sprain of other specified parts of right shoulder girdle, subsequent encounter*/
,'S4381XS'  /*Sprain of other specified parts of right shoulder girdle, sequela*/
,'S4382XD'  /*Sprain of other specified parts of left shoulder girdle, subsequent encounter*/
,'S4382XS'  /*Sprain of other specified parts of left shoulder girdle, sequela*/
,'S4390XD'  /*Sprain of unspecified parts of unspecified shoulder girdle, subsequent encounter*/
,'S4390XS'  /*Sprain of unspecified parts of unspecified shoulder girdle, sequela*/
,'S4391XD'  /*Sprain of unspecified parts of right shoulder girdle, subsequent encounter*/
,'S4391XS'  /*Sprain of unspecified parts of right shoulder girdle, sequela*/
,'S4392XD'  /*Sprain of unspecified parts of left shoulder girdle, subsequent encounter*/
,'S4392XS'  /*Sprain of unspecified parts of left shoulder girdle, sequela*/
,'S4400XD'  /*Injury of ulnar nerve at upper arm level, unspecified arm, subsequent encounter*/
,'S4400XS'  /*Injury of ulnar nerve at upper arm level, unspecified arm, sequela*/
,'S4401XD'  /*Injury of ulnar nerve at upper arm level, right arm, subsequent encounter*/
,'S4401XS'  /*Injury of ulnar nerve at upper arm level, right arm, sequela*/
,'S4402XD'  /*Injury of ulnar nerve at upper arm level, left arm, subsequent encounter*/
,'S4402XS'  /*Injury of ulnar nerve at upper arm level, left arm, sequela*/
,'S4410XD'  /*Injury of median nerve at upper arm level, unspecified arm, subsequent encounter*/
,'S4410XS'  /*Injury of median nerve at upper arm level, unspecified arm, sequela*/
,'S4411XD'  /*Injury of median nerve at upper arm level, right arm, subsequent encounter*/
,'S4411XS'  /*Injury of median nerve at upper arm level, right arm, sequela*/
,'S4412XD'  /*Injury of median nerve at upper arm level, left arm, subsequent encounter*/
,'S4412XS'  /*Injury of median nerve at upper arm level, left arm, sequela*/
,'S4420XD'  /*Injury of radial nerve at upper arm level, unspecified arm, subsequent encounter*/
,'S4420XS'  /*Injury of radial nerve at upper arm level, unspecified arm, sequela*/
,'S4421XD'  /*Injury of radial nerve at upper arm level, right arm, subsequent encounter*/
,'S4421XS'  /*Injury of radial nerve at upper arm level, right arm, sequela*/
,'S4422XD'  /*Injury of radial nerve at upper arm level, left arm, subsequent encounter*/
,'S4422XS'  /*Injury of radial nerve at upper arm level, left arm, sequela*/
,'S4430XD'  /*Injury of axillary nerve, unspecified arm, subsequent encounter*/
,'S4430XS'  /*Injury of axillary nerve, unspecified arm, sequela*/
,'S4431XD'  /*Injury of axillary nerve, right arm, subsequent encounter*/
,'S4431XS'  /*Injury of axillary nerve, right arm, sequela*/
,'S4432XD'  /*Injury of axillary nerve, left arm, subsequent encounter*/
,'S4432XS'  /*Injury of axillary nerve, left arm, sequela*/
,'S4440XD'  /*Injury of musculocutaneous nerve, unspecified arm, subsequent encounter*/
,'S4440XS'  /*Injury of musculocutaneous nerve, unspecified arm, sequela*/
,'S4441XD'  /*Injury of musculocutaneous nerve, right arm, subsequent encounter*/
,'S4441XS'  /*Injury of musculocutaneous nerve, right arm, sequela*/
,'S4442XD'  /*Injury of musculocutaneous nerve, left arm, subsequent encounter*/
,'S4442XS'  /*Injury of musculocutaneous nerve, left arm, sequela*/
,'S4450XD'  /*Injury of cutaneous sensory nerve at shoulder and upper arm level, unspecified arm, subsequent encounter*/
,'S4450XS'  /*Injury of cutaneous sensory nerve at shoulder and upper arm level, unspecified arm, sequela*/
,'S4451XD'  /*Injury of cutaneous sensory nerve at shoulder and upper arm level, right arm, subsequent encounter*/
,'S4451XS'  /*Injury of cutaneous sensory nerve at shoulder and upper arm level, right arm, sequela*/
,'S4452XD'  /*Injury of cutaneous sensory nerve at shoulder and upper arm level, left arm, subsequent encounter*/
,'S4452XS'  /*Injury of cutaneous sensory nerve at shoulder and upper arm level, left arm, sequela*/
,'S448X1D'  /*Injury of other nerves at shoulder and upper arm level, right arm, subsequent encounter*/
,'S448X1S'  /*Injury of other nerves at shoulder and upper arm level, right arm, sequela*/
,'S448X2D'  /*Injury of other nerves at shoulder and upper arm level, left arm, subsequent encounter*/
,'S448X2S'  /*Injury of other nerves at shoulder and upper arm level, left arm, sequela*/
,'S448X9D'  /*Injury of other nerves at shoulder and upper arm level, unspecified arm, subsequent encounter*/
,'S448X9S'  /*Injury of other nerves at shoulder and upper arm level, unspecified arm, sequela*/
,'S4490XD'  /*Injury of unspecified nerve at shoulder and upper arm level, unspecified arm, subsequent encounter*/
,'S4490XS'  /*Injury of unspecified nerve at shoulder and upper arm level, unspecified arm, sequela*/
,'S4491XD'  /*Injury of unspecified nerve at shoulder and upper arm level, right arm, subsequent encounter*/
,'S4491XS'  /*Injury of unspecified nerve at shoulder and upper arm level, right arm, sequela*/
,'S4492XD'  /*Injury of unspecified nerve at shoulder and upper arm level, left arm, subsequent encounter*/
,'S4492XS'  /*Injury of unspecified nerve at shoulder and upper arm level, left arm, sequela*/
,'S45001D'  /*Unspecified injury of axillary artery, right side, subsequent encounter*/
,'S45001S'  /*Unspecified injury of axillary artery, right side, sequela*/
,'S45002D'  /*Unspecified injury of axillary artery, left side, subsequent encounter*/
,'S45002S'  /*Unspecified injury of axillary artery, left side, sequela*/
,'S45009D'  /*Unspecified injury of axillary artery, unspecified side, subsequent encounter*/
,'S45009S'  /*Unspecified injury of axillary artery, unspecified side, sequela*/
,'S45011D'  /*Laceration of axillary artery, right side, subsequent encounter*/
,'S45011S'  /*Laceration of axillary artery, right side, sequela*/
,'S45012D'  /*Laceration of axillary artery, left side, subsequent encounter*/
,'S45012S'  /*Laceration of axillary artery, left side, sequela*/
,'S45019D'  /*Laceration of axillary artery, unspecified side, subsequent encounter*/
,'S45019S'  /*Laceration of axillary artery, unspecified side, sequela*/
,'S45091D'  /*Other specified injury of axillary artery, right side, subsequent encounter*/
,'S45091S'  /*Other specified injury of axillary artery, right side, sequela*/
,'S45092D'  /*Other specified injury of axillary artery, left side, subsequent encounter*/
,'S45092S'  /*Other specified injury of axillary artery, left side, sequela*/
,'S45099D'  /*Other specified injury of axillary artery, unspecified side, subsequent encounter*/
,'S45099S'  /*Other specified injury of axillary artery, unspecified side, sequela*/
,'S45101D'  /*Unspecified injury of brachial artery, right side, subsequent encounter*/
,'S45101S'  /*Unspecified injury of brachial artery, right side, sequela*/
,'S45102D'  /*Unspecified injury of brachial artery, left side, subsequent encounter*/
,'S45102S'  /*Unspecified injury of brachial artery, left side, sequela*/
,'S45109D'  /*Unspecified injury of brachial artery, unspecified side, subsequent encounter*/
,'S45109S'  /*Unspecified injury of brachial artery, unspecified side, sequela*/
,'S45111D'  /*Laceration of brachial artery, right side, subsequent encounter*/
,'S45111S'  /*Laceration of brachial artery, right side, sequela*/
,'S45112D'  /*Laceration of brachial artery, left side, subsequent encounter*/
,'S45112S'  /*Laceration of brachial artery, left side, sequela*/
,'S45119D'  /*Laceration of brachial artery, unspecified side, subsequent encounter*/
,'S45119S'  /*Laceration of brachial artery, unspecified side, sequela*/
,'S45191D'  /*Other specified injury of brachial artery, right side, subsequent encounter*/
,'S45191S'  /*Other specified injury of brachial artery, right side, sequela*/
,'S45192D'  /*Other specified injury of brachial artery, left side, subsequent encounter*/
,'S45192S'  /*Other specified injury of brachial artery, left side, sequela*/
,'S45199D'  /*Other specified injury of brachial artery, unspecified side, subsequent encounter*/
,'S45199S'  /*Other specified injury of brachial artery, unspecified side, sequela*/
,'S45201D'  /*Unspecified injury of axillary or brachial vein, right side, subsequent encounter*/
,'S45201S'  /*Unspecified injury of axillary or brachial vein, right side, sequela*/
,'S45202D'  /*Unspecified injury of axillary or brachial vein, left side, subsequent encounter*/
,'S45202S'  /*Unspecified injury of axillary or brachial vein, left side, sequela*/
,'S45209D'  /*Unspecified injury of axillary or brachial vein, unspecified side, subsequent encounter*/
,'S45209S'  /*Unspecified injury of axillary or brachial vein, unspecified side, sequela*/
,'S45211D'  /*Laceration of axillary or brachial vein, right side, subsequent encounter*/
,'S45211S'  /*Laceration of axillary or brachial vein, right side, sequela*/
,'S45212D'  /*Laceration of axillary or brachial vein, left side, subsequent encounter*/
,'S45212S'  /*Laceration of axillary or brachial vein, left side, sequela*/
,'S45219D'  /*Laceration of axillary or brachial vein, unspecified side, subsequent encounter*/
,'S45219S'  /*Laceration of axillary or brachial vein, unspecified side, sequela*/
,'S45291D'  /*Other specified injury of axillary or brachial vein, right side, subsequent encounter*/
,'S45291S'  /*Other specified injury of axillary or brachial vein, right side, sequela*/
,'S45292D'  /*Other specified injury of axillary or brachial vein, left side, subsequent encounter*/
,'S45292S'  /*Other specified injury of axillary or brachial vein, left side, sequela*/
,'S45299D'  /*Other specified injury of axillary or brachial vein, unspecified side, subsequent encounter*/
,'S45299S'  /*Other specified injury of axillary or brachial vein, unspecified side, sequela*/
,'S45301D'  /*Unspecified injury of superficial vein at shoulder and upper arm level, right arm, subsequent encounter*/
,'S45301S'  /*Unspecified injury of superficial vein at shoulder and upper arm level, right arm, sequela*/
,'S45302D'  /*Unspecified injury of superficial vein at shoulder and upper arm level, left arm, subsequent encounter*/
,'S45302S'  /*Unspecified injury of superficial vein at shoulder and upper arm level, left arm, sequela*/
,'S45309D'  /*Unspecified injury of superficial vein at shoulder and upper arm level, unspecified arm, subsequent encounter*/
,'S45309S'  /*Unspecified injury of superficial vein at shoulder and upper arm level, unspecified arm, sequela*/
,'S45311D'  /*Laceration of superficial vein at shoulder and upper arm level, right arm, subsequent encounter*/
,'S45311S'  /*Laceration of superficial vein at shoulder and upper arm level, right arm, sequela*/
,'S45312D'  /*Laceration of superficial vein at shoulder and upper arm level, left arm, subsequent encounter*/
,'S45312S'  /*Laceration of superficial vein at shoulder and upper arm level, left arm, sequela*/
,'S45319D'  /*Laceration of superficial vein at shoulder and upper arm level, unspecified arm, subsequent encounter*/
,'S45319S'  /*Laceration of superficial vein at shoulder and upper arm level, unspecified arm, sequela*/
,'S45391D'  /*Other specified injury of superficial vein at shoulder and upper arm level, right arm, subsequent encounter*/
,'S45391S'  /*Other specified injury of superficial vein at shoulder and upper arm level, right arm, sequela*/
,'S45392D'  /*Other specified injury of superficial vein at shoulder and upper arm level, left arm, subsequent encounter*/
,'S45392S'  /*Other specified injury of superficial vein at shoulder and upper arm level, left arm, sequela*/
,'S45399D'  /*Other specified injury of superficial vein at shoulder and upper arm level, unspecified arm, subsequent encounter*/
,'S45399S'  /*Other specified injury of superficial vein at shoulder and upper arm level, unspecified arm, sequela*/
,'S45801D'  /*Unspecified injury of other specified blood vessels at shoulder and upper arm level, right arm, subsequent encounter*/
,'S45801S'  /*Unspecified injury of other specified blood vessels at shoulder and upper arm level, right arm, sequela*/
,'S45802D'  /*Unspecified injury of other specified blood vessels at shoulder and upper arm level, left arm, subsequent encounter*/
,'S45802S'  /*Unspecified injury of other specified blood vessels at shoulder and upper arm level, left arm, sequela*/
,'S45809D'  /*Unspecified injury of other specified blood vessels at shoulder and upper arm level, unspecified arm, subsequent encounter*/
,'S45809S'  /*Unspecified injury of other specified blood vessels at shoulder and upper arm level, unspecified arm, sequela*/
,'S45811D'  /*Laceration of other specified blood vessels at shoulder and upper arm level, right arm, subsequent encounter*/
,'S45811S'  /*Laceration of other specified blood vessels at shoulder and upper arm level, right arm, sequela*/
,'S45812D'  /*Laceration of other specified blood vessels at shoulder and upper arm level, left arm, subsequent encounter*/
,'S45812S'  /*Laceration of other specified blood vessels at shoulder and upper arm level, left arm, sequela*/
,'S45819D'  /*Laceration of other specified blood vessels at shoulder and upper arm level, unspecified arm, subsequent encounter*/
,'S45819S'  /*Laceration of other specified blood vessels at shoulder and upper arm level, unspecified arm, sequela*/
,'S45891D'  /*Other specified injury of other specified blood vessels at shoulder and upper arm level, right arm, subsequent encounter*/
,'S45891S'  /*Other specified injury of other specified blood vessels at shoulder and upper arm level, right arm, sequela*/
,'S45892D'  /*Other specified injury of other specified blood vessels at shoulder and upper arm level, left arm, subsequent encounter*/
,'S45892S'  /*Other specified injury of other specified blood vessels at shoulder and upper arm level, left arm, sequela*/
,'S45899D'  /*Other specified injury of other specified blood vessels at shoulder and upper arm level, unspecified arm, subsequent encounter*/
,'S45899S'  /*Other specified injury of other specified blood vessels at shoulder and upper arm level, unspecified arm, sequela*/
,'S45901D'  /*Unspecified injury of unspecified blood vessel at shoulder and upper arm level, right arm, subsequent encounter*/
,'S45901S'  /*Unspecified injury of unspecified blood vessel at shoulder and upper arm level, right arm, sequela*/
,'S45902D'  /*Unspecified injury of unspecified blood vessel at shoulder and upper arm level, left arm, subsequent encounter*/
,'S45902S'  /*Unspecified injury of unspecified blood vessel at shoulder and upper arm level, left arm, sequela*/
,'S45909D'  /*Unspecified injury of unspecified blood vessel at shoulder and upper arm level, unspecified arm, subsequent encounter*/
,'S45909S'  /*Unspecified injury of unspecified blood vessel at shoulder and upper arm level, unspecified arm, sequela*/
,'S45911D'  /*Laceration of unspecified blood vessel at shoulder and upper arm level, right arm, subsequent encounter*/
,'S45911S'  /*Laceration of unspecified blood vessel at shoulder and upper arm level, right arm, sequela*/
,'S45912D'  /*Laceration of unspecified blood vessel at shoulder and upper arm level, left arm, subsequent encounter*/
,'S45912S'  /*Laceration of unspecified blood vessel at shoulder and upper arm level, left arm, sequela*/
,'S45919D'  /*Laceration of unspecified blood vessel at shoulder and upper arm level, unspecified arm, subsequent encounter*/
,'S45919S'  /*Laceration of unspecified blood vessel at shoulder and upper arm level, unspecified arm, sequela*/
,'S45991D'  /*Other specified injury of unspecified blood vessel at shoulder and upper arm level, right arm, subsequent encounter*/
,'S45991S'  /*Other specified injury of unspecified blood vessel at shoulder and upper arm level, right arm, sequela*/
,'S45992D'  /*Other specified injury of unspecified blood vessel at shoulder and upper arm level, left arm, subsequent encounter*/
,'S45992S'  /*Other specified injury of unspecified blood vessel at shoulder and upper arm level, left arm, sequela*/
,'S45999D'  /*Other specified injury of unspecified blood vessel at shoulder and upper arm level, unspecified arm, subsequent encounter*/
,'S45999S'  /*Other specified injury of unspecified blood vessel at shoulder and upper arm level, unspecified arm, sequela*/
,'S46001D'  /*Unspecified injury of muscle(s) and tendon(s) of the rotator cuff of right shoulder, subsequent encounter*/
,'S46001S'  /*Unspecified injury of muscle(s) and tendon(s) of the rotator cuff of right shoulder, sequela*/
,'S46002D'  /*Unspecified injury of muscle(s) and tendon(s) of the rotator cuff of left shoulder, subsequent encounter*/
,'S46002S'  /*Unspecified injury of muscle(s) and tendon(s) of the rotator cuff of left shoulder, sequela*/
,'S46009D'  /*Unspecified injury of muscle(s) and tendon(s) of the rotator cuff of unspecified shoulder, subsequent encounter*/
,'S46009S'  /*Unspecified injury of muscle(s) and tendon(s) of the rotator cuff of unspecified shoulder, sequela*/
,'S46011D'  /*Strain of muscle(s) and tendon(s) of the rotator cuff of right shoulder, subsequent encounter*/
,'S46011S'  /*Strain of muscle(s) and tendon(s) of the rotator cuff of right shoulder, sequela*/
,'S46012D'  /*Strain of muscle(s) and tendon(s) of the rotator cuff of left shoulder, subsequent encounter*/
,'S46012S'  /*Strain of muscle(s) and tendon(s) of the rotator cuff of left shoulder, sequela*/
,'S46019D'  /*Strain of muscle(s) and tendon(s) of the rotator cuff of unspecified shoulder, subsequent encounter*/
,'S46019S'  /*Strain of muscle(s) and tendon(s) of the rotator cuff of unspecified shoulder, sequela*/
,'S46021D'  /*Laceration of muscle(s) and tendon(s) of the rotator cuff of right shoulder, subsequent encounter*/
,'S46021S'  /*Laceration of muscle(s) and tendon(s) of the rotator cuff of right shoulder, sequela*/
,'S46022D'  /*Laceration of muscle(s) and tendon(s) of the rotator cuff of left shoulder, subsequent encounter*/
,'S46022S'  /*Laceration of muscle(s) and tendon(s) of the rotator cuff of left shoulder, sequela*/
,'S46029D'  /*Laceration of muscle(s) and tendon(s) of the rotator cuff of unspecified shoulder, subsequent encounter*/
,'S46029S'  /*Laceration of muscle(s) and tendon(s) of the rotator cuff of unspecified shoulder, sequela*/
,'S46091D'  /*Other injury of muscle(s) and tendon(s) of the rotator cuff of right shoulder, subsequent encounter*/
,'S46091S'  /*Other injury of muscle(s) and tendon(s) of the rotator cuff of right shoulder, sequela*/
,'S46092D'  /*Other injury of muscle(s) and tendon(s) of the rotator cuff of left shoulder, subsequent encounter*/
,'S46092S'  /*Other injury of muscle(s) and tendon(s) of the rotator cuff of left shoulder, sequela*/
,'S46099D'  /*Other injury of muscle(s) and tendon(s) of the rotator cuff of unspecified shoulder, subsequent encounter*/
,'S46099S'  /*Other injury of muscle(s) and tendon(s) of the rotator cuff of unspecified shoulder, sequela*/
,'S46101D'  /*Unspecified injury of muscle, fascia and tendon of long head of biceps, right arm, subsequent encounter*/
,'S46101S'  /*Unspecified injury of muscle, fascia and tendon of long head of biceps, right arm, sequela*/
,'S46102D'  /*Unspecified injury of muscle, fascia and tendon of long head of biceps, left arm, subsequent encounter*/
,'S46102S'  /*Unspecified injury of muscle, fascia and tendon of long head of biceps, left arm, sequela*/
,'S46109D'  /*Unspecified injury of muscle, fascia and tendon of long head of biceps, unspecified arm, subsequent encounter*/
,'S46109S'  /*Unspecified injury of muscle, fascia and tendon of long head of biceps, unspecified arm, sequela*/
,'S46111D'  /*Strain of muscle, fascia and tendon of long head of biceps, right arm, subsequent encounter*/
,'S46111S'  /*Strain of muscle, fascia and tendon of long head of biceps, right arm, sequela*/
,'S46112D'  /*Strain of muscle, fascia and tendon of long head of biceps, left arm, subsequent encounter*/
,'S46112S'  /*Strain of muscle, fascia and tendon of long head of biceps, left arm, sequela*/
,'S46119D'  /*Strain of muscle, fascia and tendon of long head of biceps, unspecified arm, subsequent encounter*/
,'S46119S'  /*Strain of muscle, fascia and tendon of long head of biceps, unspecified arm, sequela*/
,'S46121D'  /*Laceration of muscle, fascia and tendon of long head of biceps, right arm, subsequent encounter*/
,'S46121S'  /*Laceration of muscle, fascia and tendon of long head of biceps, right arm, sequela*/
,'S46122D'  /*Laceration of muscle, fascia and tendon of long head of biceps, left arm, subsequent encounter*/
,'S46122S'  /*Laceration of muscle, fascia and tendon of long head of biceps, left arm, sequela*/
,'S46129D'  /*Laceration of muscle, fascia and tendon of long head of biceps, unspecified arm, subsequent encounter*/
,'S46129S'  /*Laceration of muscle, fascia and tendon of long head of biceps, unspecified arm, sequela*/
,'S46191D'  /*Other injury of muscle, fascia and tendon of long head of biceps, right arm, subsequent encounter*/
,'S46191S'  /*Other injury of muscle, fascia and tendon of long head of biceps, right arm, sequela*/
,'S46192D'  /*Other injury of muscle, fascia and tendon of long head of biceps, left arm, subsequent encounter*/
,'S46192S'  /*Other injury of muscle, fascia and tendon of long head of biceps, left arm, sequela*/
,'S46199D'  /*Other injury of muscle, fascia and tendon of long head of biceps, unspecified arm, subsequent encounter*/
,'S46199S'  /*Other injury of muscle, fascia and tendon of long head of biceps, unspecified arm, sequela*/
,'S46201D'  /*Unspecified injury of muscle, fascia and tendon of other parts of biceps, right arm, subsequent encounter*/
,'S46201S'  /*Unspecified injury of muscle, fascia and tendon of other parts of biceps, right arm, sequela*/
,'S46202D'  /*Unspecified injury of muscle, fascia and tendon of other parts of biceps, left arm, subsequent encounter*/
,'S46202S'  /*Unspecified injury of muscle, fascia and tendon of other parts of biceps, left arm, sequela*/
,'S46209D'  /*Unspecified injury of muscle, fascia and tendon of other parts of biceps, unspecified arm, subsequent encounter*/
,'S46209S'  /*Unspecified injury of muscle, fascia and tendon of other parts of biceps, unspecified arm, sequela*/
,'S46211D'  /*Strain of muscle, fascia and tendon of other parts of biceps, right arm, subsequent encounter*/
,'S46211S'  /*Strain of muscle, fascia and tendon of other parts of biceps, right arm, sequela*/
,'S46212D'  /*Strain of muscle, fascia and tendon of other parts of biceps, left arm, subsequent encounter*/
,'S46212S'  /*Strain of muscle, fascia and tendon of other parts of biceps, left arm, sequela*/
,'S46219D'  /*Strain of muscle, fascia and tendon of other parts of biceps, unspecified arm, subsequent encounter*/
,'S46219S'  /*Strain of muscle, fascia and tendon of other parts of biceps, unspecified arm, sequela*/
,'S46221D'  /*Laceration of muscle, fascia and tendon of other parts of biceps, right arm, subsequent encounter*/
,'S46221S'  /*Laceration of muscle, fascia and tendon of other parts of biceps, right arm, sequela*/
,'S46222D'  /*Laceration of muscle, fascia and tendon of other parts of biceps, left arm, subsequent encounter*/
,'S46222S'  /*Laceration of muscle, fascia and tendon of other parts of biceps, left arm, sequela*/
,'S46229D'  /*Laceration of muscle, fascia and tendon of other parts of biceps, unspecified arm, subsequent encounter*/
,'S46229S'  /*Laceration of muscle, fascia and tendon of other parts of biceps, unspecified arm, sequela*/
,'S46291D'  /*Other injury of muscle, fascia and tendon of other parts of biceps, right arm, subsequent encounter*/
,'S46291S'  /*Other injury of muscle, fascia and tendon of other parts of biceps, right arm, sequela*/
,'S46292D'  /*Other injury of muscle, fascia and tendon of other parts of biceps, left arm, subsequent encounter*/
,'S46292S'  /*Other injury of muscle, fascia and tendon of other parts of biceps, left arm, sequela*/
,'S46299D'  /*Other injury of muscle, fascia and tendon of other parts of biceps, unspecified arm, subsequent encounter*/
,'S46299S'  /*Other injury of muscle, fascia and tendon of other parts of biceps, unspecified arm, sequela*/
,'S46301D'  /*Unspecified injury of muscle, fascia and tendon of triceps, right arm, subsequent encounter*/
,'S46301S'  /*Unspecified injury of muscle, fascia and tendon of triceps, right arm, sequela*/
,'S46302D'  /*Unspecified injury of muscle, fascia and tendon of triceps, left arm, subsequent encounter*/
,'S46302S'  /*Unspecified injury of muscle, fascia and tendon of triceps, left arm, sequela*/
,'S46309D'  /*Unspecified injury of muscle, fascia and tendon of triceps, unspecified arm, subsequent encounter*/
,'S46309S'  /*Unspecified injury of muscle, fascia and tendon of triceps, unspecified arm, sequela*/
,'S46311D'  /*Strain of muscle, fascia and tendon of triceps, right arm, subsequent encounter*/
,'S46311S'  /*Strain of muscle, fascia and tendon of triceps, right arm, sequela*/
,'S46312D'  /*Strain of muscle, fascia and tendon of triceps, left arm, subsequent encounter*/
,'S46312S'  /*Strain of muscle, fascia and tendon of triceps, left arm, sequela*/
,'S46319D'  /*Strain of muscle, fascia and tendon of triceps, unspecified arm, subsequent encounter*/
,'S46319S'  /*Strain of muscle, fascia and tendon of triceps, unspecified arm, sequela*/
,'S46321D'  /*Laceration of muscle, fascia and tendon of triceps, right arm, subsequent encounter*/
,'S46321S'  /*Laceration of muscle, fascia and tendon of triceps, right arm, sequela*/
,'S46322D'  /*Laceration of muscle, fascia and tendon of triceps, left arm, subsequent encounter*/
,'S46322S'  /*Laceration of muscle, fascia and tendon of triceps, left arm, sequela*/
,'S46329D'  /*Laceration of muscle, fascia and tendon of triceps, unspecified arm, subsequent encounter*/
,'S46329S'  /*Laceration of muscle, fascia and tendon of triceps, unspecified arm, sequela*/
,'S46391D'  /*Other injury of muscle, fascia and tendon of triceps, right arm, subsequent encounter*/
,'S46391S'  /*Other injury of muscle, fascia and tendon of triceps, right arm, sequela*/
,'S46392D'  /*Other injury of muscle, fascia and tendon of triceps, left arm, subsequent encounter*/
,'S46392S'  /*Other injury of muscle, fascia and tendon of triceps, left arm, sequela*/
,'S46399D'  /*Other injury of muscle, fascia and tendon of triceps, unspecified arm, subsequent encounter*/
,'S46399S'  /*Other injury of muscle, fascia and tendon of triceps, unspecified arm, sequela*/
,'S46801D'  /*Unspecified injury of other muscles, fascia and tendons at shoulder and upper arm level, right arm, subsequent encounter*/
,'S46801S'  /*Unspecified injury of other muscles, fascia and tendons at shoulder and upper arm level, right arm, sequela*/
,'S46802D'  /*Unspecified injury of other muscles, fascia and tendons at shoulder and upper arm level, left arm, subsequent encounter*/
,'S46802S'  /*Unspecified injury of other muscles, fascia and tendons at shoulder and upper arm level, left arm, sequela*/
,'S46809D'  /*Unspecified injury of other muscles, fascia and tendons at shoulder and upper arm level, unspecified arm, subsequent encounter*/
,'S46809S'  /*Unspecified injury of other muscles, fascia and tendons at shoulder and upper arm level, unspecified arm, sequela*/
,'S46811D'  /*Strain of other muscles, fascia and tendons at shoulder and upper arm level, right arm, subsequent encounter*/
,'S46811S'  /*Strain of other muscles, fascia and tendons at shoulder and upper arm level, right arm, sequela*/
,'S46812D'  /*Strain of other muscles, fascia and tendons at shoulder and upper arm level, left arm, subsequent encounter*/
,'S46812S'  /*Strain of other muscles, fascia and tendons at shoulder and upper arm level, left arm, sequela*/
,'S46819D'  /*Strain of other muscles, fascia and tendons at shoulder and upper arm level, unspecified arm, subsequent encounter*/
,'S46819S'  /*Strain of other muscles, fascia and tendons at shoulder and upper arm level, unspecified arm, sequela*/
,'S46821D'  /*Laceration of other muscles, fascia and tendons at shoulder and upper arm level, right arm, subsequent encounter*/
,'S46821S'  /*Laceration of other muscles, fascia and tendons at shoulder and upper arm level, right arm, sequela*/
,'S46822D'  /*Laceration of other muscles, fascia and tendons at shoulder and upper arm level, left arm, subsequent encounter*/
,'S46822S'  /*Laceration of other muscles, fascia and tendons at shoulder and upper arm level, left arm, sequela*/
,'S46829D'  /*Laceration of other muscles, fascia and tendons at shoulder and upper arm level, unspecified arm, subsequent encounter*/
,'S46829S'  /*Laceration of other muscles, fascia and tendons at shoulder and upper arm level, unspecified arm, sequela*/
,'S46891D'  /*Other injury of other muscles, fascia and tendons at shoulder and upper arm level, right arm, subsequent encounter*/
,'S46891S'  /*Other injury of other muscles, fascia and tendons at shoulder and upper arm level, right arm, sequela*/
,'S46892D'  /*Other injury of other muscles, fascia and tendons at shoulder and upper arm level, left arm, subsequent encounter*/
,'S46892S'  /*Other injury of other muscles, fascia and tendons at shoulder and upper arm level, left arm, sequela*/
,'S46899D'  /*Other injury of other muscles, fascia and tendons at shoulder and upper arm level, unspecified arm, subsequent encounter*/
,'S46899S'  /*Other injury of other muscles, fascia and tendons at shoulder and upper arm level, unspecified arm, sequela*/
,'S46901D'  /*Unspecified injury of unspecified muscle, fascia and tendon at shoulder and upper arm level, right arm, subsequent encounter*/
,'S46901S'  /*Unspecified injury of unspecified muscle, fascia and tendon at shoulder and upper arm level, right arm, sequela*/
,'S46902D'  /*Unspecified injury of unspecified muscle, fascia and tendon at shoulder and upper arm level, left arm, subsequent encounter*/
,'S46902S'  /*Unspecified injury of unspecified muscle, fascia and tendon at shoulder and upper arm level, left arm, sequela*/
,'S46909D'  /*Unspecified injury of unspecified muscle, fascia and tendon at shoulder and upper arm level, unspecified arm, subsequent encounter*/
,'S46909S'  /*Unspecified injury of unspecified muscle, fascia and tendon at shoulder and upper arm level, unspecified arm, sequela*/
,'S46911D'  /*Strain of unspecified muscle, fascia and tendon at shoulder and upper arm level, right arm, subsequent encounter*/
,'S46911S'  /*Strain of unspecified muscle, fascia and tendon at shoulder and upper arm level, right arm, sequela*/
,'S46912D'  /*Strain of unspecified muscle, fascia and tendon at shoulder and upper arm level, left arm, subsequent encounter*/
,'S46912S'  /*Strain of unspecified muscle, fascia and tendon at shoulder and upper arm level, left arm, sequela*/
,'S46919D'  /*Strain of unspecified muscle, fascia and tendon at shoulder and upper arm level, unspecified arm, subsequent encounter*/
,'S46919S'  /*Strain of unspecified muscle, fascia and tendon at shoulder and upper arm level, unspecified arm, sequela*/
,'S46921D'  /*Laceration of unspecified muscle, fascia and tendon at shoulder and upper arm level, right arm, subsequent encounter*/
,'S46921S'  /*Laceration of unspecified muscle, fascia and tendon at shoulder and upper arm level, right arm, sequela*/
,'S46922D'  /*Laceration of unspecified muscle, fascia and tendon at shoulder and upper arm level, left arm, subsequent encounter*/
,'S46922S'  /*Laceration of unspecified muscle, fascia and tendon at shoulder and upper arm level, left arm, sequela*/
,'S46929D'  /*Laceration of unspecified muscle, fascia and tendon at shoulder and upper arm level, unspecified arm, subsequent encounter*/
,'S46929S'  /*Laceration of unspecified muscle, fascia and tendon at shoulder and upper arm level, unspecified arm, sequela*/
,'S46991D'  /*Other injury of unspecified muscle, fascia and tendon at shoulder and upper arm level, right arm, subsequent encounter*/
,'S46991S'  /*Other injury of unspecified muscle, fascia and tendon at shoulder and upper arm level, right arm, sequela*/
,'S46992D'  /*Other injury of unspecified muscle, fascia and tendon at shoulder and upper arm level, left arm, subsequent encounter*/
,'S46992S'  /*Other injury of unspecified muscle, fascia and tendon at shoulder and upper arm level, left arm, sequela*/
,'S46999D'  /*Other injury of unspecified muscle, fascia and tendon at shoulder and upper arm level, unspecified arm, subsequent encounter*/
,'S46999S'  /*Other injury of unspecified muscle, fascia and tendon at shoulder and upper arm level, unspecified arm, sequela*/
,'S471XXD'  /*Crushing injury of right shoulder and upper arm, subsequent encounter*/
,'S471XXS'  /*Crushing injury of right shoulder and upper arm, sequela*/
,'S472XXD'  /*Crushing injury of left shoulder and upper arm, subsequent encounter*/
,'S472XXS'  /*Crushing injury of left shoulder and upper arm, sequela*/
,'S479XXD'  /*Crushing injury of shoulder and upper arm, unspecified arm, subsequent encounter*/
,'S479XXS'  /*Crushing injury of shoulder and upper arm, unspecified arm, sequela*/
,'S48011D'  /*Complete traumatic amputation at right shoulder joint, subsequent encounter*/
,'S48011S'  /*Complete traumatic amputation at right shoulder joint, sequela*/
,'S48012D'  /*Complete traumatic amputation at left shoulder joint, subsequent encounter*/
,'S48012S'  /*Complete traumatic amputation at left shoulder joint, sequela*/
,'S48019D'  /*Complete traumatic amputation at unspecified shoulder joint, subsequent encounter*/
,'S48019S'  /*Complete traumatic amputation at unspecified shoulder joint, sequela*/
,'S48021D'  /*Partial traumatic amputation at right shoulder joint, subsequent encounter*/
,'S48021S'  /*Partial traumatic amputation at right shoulder joint, sequela*/
,'S48022D'  /*Partial traumatic amputation at left shoulder joint, subsequent encounter*/
,'S48022S'  /*Partial traumatic amputation at left shoulder joint, sequela*/
,'S48029D'  /*Partial traumatic amputation at unspecified shoulder joint, subsequent encounter*/
,'S48029S'  /*Partial traumatic amputation at unspecified shoulder joint, sequela*/
,'S48111D'  /*Complete traumatic amputation at level between right shoulder and elbow, subsequent encounter*/
,'S48111S'  /*Complete traumatic amputation at level between right shoulder and elbow, sequela*/
,'S48112D'  /*Complete traumatic amputation at level between left shoulder and elbow, subsequent encounter*/
,'S48112S'  /*Complete traumatic amputation at level between left shoulder and elbow, sequela*/
,'S48119D'  /*Complete traumatic amputation at level between unspecified shoulder and elbow, subsequent encounter*/
,'S48119S'  /*Complete traumatic amputation at level between unspecified shoulder and elbow, sequela*/
,'S48121D'  /*Partial traumatic amputation at level between right shoulder and elbow, subsequent encounter*/
,'S48121S'  /*Partial traumatic amputation at level between right shoulder and elbow, sequela*/
,'S48122D'  /*Partial traumatic amputation at level between left shoulder and elbow, subsequent encounter*/
,'S48122S'  /*Partial traumatic amputation at level between left shoulder and elbow, sequela*/
,'S48129D'  /*Partial traumatic amputation at level between unspecified shoulder and elbow, subsequent encounter*/
,'S48129S'  /*Partial traumatic amputation at level between unspecified shoulder and elbow, sequela*/
,'S48911D'  /*Complete traumatic amputation of right shoulder and upper arm, level unspecified, subsequent encounter*/
,'S48911S'  /*Complete traumatic amputation of right shoulder and upper arm, level unspecified, sequela*/
,'S48912D'  /*Complete traumatic amputation of left shoulder and upper arm, level unspecified, subsequent encounter*/
,'S48912S'  /*Complete traumatic amputation of left shoulder and upper arm, level unspecified, sequela*/
,'S48919D'  /*Complete traumatic amputation of unspecified shoulder and upper arm, level unspecified, subsequent encounter*/
,'S48919S'  /*Complete traumatic amputation of unspecified shoulder and upper arm, level unspecified, sequela*/
,'S48921D'  /*Partial traumatic amputation of right shoulder and upper arm, level unspecified, subsequent encounter*/
,'S48921S'  /*Partial traumatic amputation of right shoulder and upper arm, level unspecified, sequela*/
,'S48922D'  /*Partial traumatic amputation of left shoulder and upper arm, level unspecified, subsequent encounter*/
,'S48922S'  /*Partial traumatic amputation of left shoulder and upper arm, level unspecified, sequela*/
,'S48929D'  /*Partial traumatic amputation of unspecified shoulder and upper arm, level unspecified, subsequent encounter*/
,'S48929S'  /*Partial traumatic amputation of unspecified shoulder and upper arm, level unspecified, sequela*/
,'S49001D'  /*Unspecified physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S49001G'  /*Unspecified physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S49001K'  /*Unspecified physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S49001P'  /*Unspecified physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S49001S'  /*Unspecified physeal fracture of upper end of humerus, right arm, sequela*/
,'S49002D'  /*Unspecified physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S49002G'  /*Unspecified physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S49002K'  /*Unspecified physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S49002P'  /*Unspecified physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S49002S'  /*Unspecified physeal fracture of upper end of humerus, left arm, sequela*/
,'S49009D'  /*Unspecified physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S49009G'  /*Unspecified physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S49009K'  /*Unspecified physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S49009P'  /*Unspecified physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S49009S'  /*Unspecified physeal fracture of upper end of humerus, unspecified arm, sequela*/
,'S49011D'  /*Salter-Harris Type I physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S49011G'  /*Salter-Harris Type I physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S49011K'  /*Salter-Harris Type I physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S49011P'  /*Salter-Harris Type I physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S49011S'  /*Salter-Harris Type I physeal fracture of upper end of humerus, right arm, sequela*/
,'S49012D'  /*Salter-Harris Type I physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S49012G'  /*Salter-Harris Type I physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S49012K'  /*Salter-Harris Type I physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S49012P'  /*Salter-Harris Type I physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S49012S'  /*Salter-Harris Type I physeal fracture of upper end of humerus, left arm, sequela*/
,'S49019D'  /*Salter-Harris Type I physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S49019G'  /*Salter-Harris Type I physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S49019K'  /*Salter-Harris Type I physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S49019P'  /*Salter-Harris Type I physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S49019S'  /*Salter-Harris Type I physeal fracture of upper end of humerus, unspecified arm, sequela*/
,'S49021D'  /*Salter-Harris Type II physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S49021G'  /*Salter-Harris Type II physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S49021K'  /*Salter-Harris Type II physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S49021P'  /*Salter-Harris Type II physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S49021S'  /*Salter-Harris Type II physeal fracture of upper end of humerus, right arm, sequela*/
,'S49022D'  /*Salter-Harris Type II physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S49022G'  /*Salter-Harris Type II physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S49022K'  /*Salter-Harris Type II physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S49022P'  /*Salter-Harris Type II physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S49022S'  /*Salter-Harris Type II physeal fracture of upper end of humerus, left arm, sequela*/
,'S49029D'  /*Salter-Harris Type II physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S49029G'  /*Salter-Harris Type II physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S49029K'  /*Salter-Harris Type II physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S49029P'  /*Salter-Harris Type II physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S49029S'  /*Salter-Harris Type II physeal fracture of upper end of humerus, unspecified arm, sequela*/
,'S49031D'  /*Salter-Harris Type III physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S49031G'  /*Salter-Harris Type III physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S49031K'  /*Salter-Harris Type III physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S49031P'  /*Salter-Harris Type III physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S49031S'  /*Salter-Harris Type III physeal fracture of upper end of humerus, right arm, sequela*/
,'S49032D'  /*Salter-Harris Type III physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S49032G'  /*Salter-Harris Type III physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S49032K'  /*Salter-Harris Type III physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S49032P'  /*Salter-Harris Type III physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S49032S'  /*Salter-Harris Type III physeal fracture of upper end of humerus, left arm, sequela*/
,'S49039D'  /*Salter-Harris Type III physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S49039G'  /*Salter-Harris Type III physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S49039K'  /*Salter-Harris Type III physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S49039P'  /*Salter-Harris Type III physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S49039S'  /*Salter-Harris Type III physeal fracture of upper end of humerus, unspecified arm, sequela*/
,'S49041D'  /*Salter-Harris Type IV physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S49041G'  /*Salter-Harris Type IV physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S49041K'  /*Salter-Harris Type IV physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S49041P'  /*Salter-Harris Type IV physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S49041S'  /*Salter-Harris Type IV physeal fracture of upper end of humerus, right arm, sequela*/
,'S49042D'  /*Salter-Harris Type IV physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S49042G'  /*Salter-Harris Type IV physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S49042K'  /*Salter-Harris Type IV physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S49042P'  /*Salter-Harris Type IV physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S49042S'  /*Salter-Harris Type IV physeal fracture of upper end of humerus, left arm, sequela*/
,'S49049D'  /*Salter-Harris Type IV physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S49049G'  /*Salter-Harris Type IV physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S49049K'  /*Salter-Harris Type IV physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S49049P'  /*Salter-Harris Type IV physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S49049S'  /*Salter-Harris Type IV physeal fracture of upper end of humerus, unspecified arm, sequela*/
,'S49091D'  /*Other physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S49091G'  /*Other physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S49091K'  /*Other physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S49091P'  /*Other physeal fracture of upper end of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S49091S'  /*Other physeal fracture of upper end of humerus, right arm, sequela*/
,'S49092D'  /*Other physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S49092G'  /*Other physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S49092K'  /*Other physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S49092P'  /*Other physeal fracture of upper end of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S49092S'  /*Other physeal fracture of upper end of humerus, left arm, sequela*/
,'S49099D'  /*Other physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S49099G'  /*Other physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S49099K'  /*Other physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S49099P'  /*Other physeal fracture of upper end of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S49099S'  /*Other physeal fracture of upper end of humerus, unspecified arm, sequela*/
,'S49101D'  /*Unspecified physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S49101G'  /*Unspecified physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S49101K'  /*Unspecified physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S49101P'  /*Unspecified physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S49101S'  /*Unspecified physeal fracture of lower end of humerus, right arm, sequela*/
,'S49102D'  /*Unspecified physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S49102G'  /*Unspecified physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S49102K'  /*Unspecified physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S49102P'  /*Unspecified physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S49102S'  /*Unspecified physeal fracture of lower end of humerus, left arm, sequela*/
,'S49109D'  /*Unspecified physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S49109G'  /*Unspecified physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S49109K'  /*Unspecified physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S49109P'  /*Unspecified physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S49109S'  /*Unspecified physeal fracture of lower end of humerus, unspecified arm, sequela*/
,'S49111D'  /*Salter-Harris Type I physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S49111G'  /*Salter-Harris Type I physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S49111K'  /*Salter-Harris Type I physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S49111P'  /*Salter-Harris Type I physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S49111S'  /*Salter-Harris Type I physeal fracture of lower end of humerus, right arm, sequela*/
,'S49112D'  /*Salter-Harris Type I physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S49112G'  /*Salter-Harris Type I physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S49112K'  /*Salter-Harris Type I physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S49112P'  /*Salter-Harris Type I physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S49112S'  /*Salter-Harris Type I physeal fracture of lower end of humerus, left arm, sequela*/
,'S49119D'  /*Salter-Harris Type I physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S49119G'  /*Salter-Harris Type I physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S49119K'  /*Salter-Harris Type I physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S49119P'  /*Salter-Harris Type I physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S49119S'  /*Salter-Harris Type I physeal fracture of lower end of humerus, unspecified arm, sequela*/
,'S49121D'  /*Salter-Harris Type II physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S49121G'  /*Salter-Harris Type II physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S49121K'  /*Salter-Harris Type II physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S49121P'  /*Salter-Harris Type II physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S49121S'  /*Salter-Harris Type II physeal fracture of lower end of humerus, right arm, sequela*/
,'S49122D'  /*Salter-Harris Type II physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S49122G'  /*Salter-Harris Type II physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S49122K'  /*Salter-Harris Type II physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S49122P'  /*Salter-Harris Type II physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S49122S'  /*Salter-Harris Type II physeal fracture of lower end of humerus, left arm, sequela*/
,'S49129D'  /*Salter-Harris Type II physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S49129G'  /*Salter-Harris Type II physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S49129K'  /*Salter-Harris Type II physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S49129P'  /*Salter-Harris Type II physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S49129S'  /*Salter-Harris Type II physeal fracture of lower end of humerus, unspecified arm, sequela*/
,'S49131D'  /*Salter-Harris Type III physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S49131G'  /*Salter-Harris Type III physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S49131K'  /*Salter-Harris Type III physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S49131P'  /*Salter-Harris Type III physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S49131S'  /*Salter-Harris Type III physeal fracture of lower end of humerus, right arm, sequela*/
,'S49132D'  /*Salter-Harris Type III physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S49132G'  /*Salter-Harris Type III physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S49132K'  /*Salter-Harris Type III physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S49132P'  /*Salter-Harris Type III physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S49132S'  /*Salter-Harris Type III physeal fracture of lower end of humerus, left arm, sequela*/
,'S49139D'  /*Salter-Harris Type III physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S49139G'  /*Salter-Harris Type III physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S49139K'  /*Salter-Harris Type III physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S49139P'  /*Salter-Harris Type III physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S49139S'  /*Salter-Harris Type III physeal fracture of lower end of humerus, unspecified arm, sequela*/
,'S49141D'  /*Salter-Harris Type IV physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S49141G'  /*Salter-Harris Type IV physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S49141K'  /*Salter-Harris Type IV physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S49141P'  /*Salter-Harris Type IV physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S49141S'  /*Salter-Harris Type IV physeal fracture of lower end of humerus, right arm, sequela*/
,'S49142D'  /*Salter-Harris Type IV physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S49142G'  /*Salter-Harris Type IV physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S49142K'  /*Salter-Harris Type IV physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S49142P'  /*Salter-Harris Type IV physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S49142S'  /*Salter-Harris Type IV physeal fracture of lower end of humerus, left arm, sequela*/
,'S49149D'  /*Salter-Harris Type IV physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S49149G'  /*Salter-Harris Type IV physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S49149K'  /*Salter-Harris Type IV physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S49149P'  /*Salter-Harris Type IV physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S49149S'  /*Salter-Harris Type IV physeal fracture of lower end of humerus, unspecified arm, sequela*/
,'S49191D'  /*Other physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with routine healing*/
,'S49191G'  /*Other physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with delayed healing*/
,'S49191K'  /*Other physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with nonunion*/
,'S49191P'  /*Other physeal fracture of lower end of humerus, right arm, subsequent encounter for fracture with malunion*/
,'S49191S'  /*Other physeal fracture of lower end of humerus, right arm, sequela*/
,'S49192D'  /*Other physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with routine healing*/
,'S49192G'  /*Other physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with delayed healing*/
,'S49192K'  /*Other physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with nonunion*/
,'S49192P'  /*Other physeal fracture of lower end of humerus, left arm, subsequent encounter for fracture with malunion*/
,'S49192S'  /*Other physeal fracture of lower end of humerus, left arm, sequela*/
,'S49199D'  /*Other physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S49199G'  /*Other physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S49199K'  /*Other physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S49199P'  /*Other physeal fracture of lower end of humerus, unspecified arm, subsequent encounter for fracture with malunion*/
,'S49199S'  /*Other physeal fracture of lower end of humerus, unspecified arm, sequela*/
,'S4980XD'  /*Other specified injuries of shoulder and upper arm, unspecified arm, subsequent encounter*/
,'S4980XS'  /*Other specified injuries of shoulder and upper arm, unspecified arm, sequela*/
,'S4981XD'  /*Other specified injuries of right shoulder and upper arm, subsequent encounter*/
,'S4981XS'  /*Other specified injuries of right shoulder and upper arm, sequela*/
,'S4982XD'  /*Other specified injuries of left shoulder and upper arm, subsequent encounter*/
,'S4982XS'  /*Other specified injuries of left shoulder and upper arm, sequela*/
,'S4990XD'  /*Unspecified injury of shoulder and upper arm, unspecified arm, subsequent encounter*/
,'S4990XS'  /*Unspecified injury of shoulder and upper arm, unspecified arm, sequela*/
,'S4991XD'  /*Unspecified injury of right shoulder and upper arm, subsequent encounter*/
,'S4991XS'  /*Unspecified injury of right shoulder and upper arm, sequela*/
,'S4992XD'  /*Unspecified injury of left shoulder and upper arm, subsequent encounter*/
,'S4992XS'  /*Unspecified injury of left shoulder and upper arm, sequela*/
,'S5000XD'  /*Contusion of unspecified elbow, subsequent encounter*/
,'S5000XS'  /*Contusion of unspecified elbow, sequela*/
,'S5001XD'  /*Contusion of right elbow, subsequent encounter*/
,'S5001XS'  /*Contusion of right elbow, sequela*/
,'S5002XD'  /*Contusion of left elbow, subsequent encounter*/
,'S5002XS'  /*Contusion of left elbow, sequela*/
,'S5010XD'  /*Contusion of unspecified forearm, subsequent encounter*/
,'S5010XS'  /*Contusion of unspecified forearm, sequela*/
,'S5011XD'  /*Contusion of right forearm, subsequent encounter*/
,'S5011XS'  /*Contusion of right forearm, sequela*/
,'S5012XD'  /*Contusion of left forearm, subsequent encounter*/
,'S5012XS'  /*Contusion of left forearm, sequela*/
,'S50311D'  /*Abrasion of right elbow, subsequent encounter*/
,'S50311S'  /*Abrasion of right elbow, sequela*/
,'S50312D'  /*Abrasion of left elbow, subsequent encounter*/
,'S50312S'  /*Abrasion of left elbow, sequela*/
,'S50319D'  /*Abrasion of unspecified elbow, subsequent encounter*/
,'S50319S'  /*Abrasion of unspecified elbow, sequela*/
,'S50321D'  /*Blister (nonthermal) of right elbow, subsequent encounter*/
,'S50321S'  /*Blister (nonthermal) of right elbow, sequela*/
,'S50322D'  /*Blister (nonthermal) of left elbow, subsequent encounter*/
,'S50322S'  /*Blister (nonthermal) of left elbow, sequela*/
,'S50329D'  /*Blister (nonthermal) of unspecified elbow, subsequent encounter*/
,'S50329S'  /*Blister (nonthermal) of unspecified elbow, sequela*/
,'S50341D'  /*External constriction of right elbow, subsequent encounter*/
,'S50341S'  /*External constriction of right elbow, sequela*/
,'S50342D'  /*External constriction of left elbow, subsequent encounter*/
,'S50342S'  /*External constriction of left elbow, sequela*/
,'S50349D'  /*External constriction of unspecified elbow, subsequent encounter*/
,'S50349S'  /*External constriction of unspecified elbow, sequela*/
,'S50351D'  /*Superficial foreign body of right elbow, subsequent encounter*/
,'S50351S'  /*Superficial foreign body of right elbow, sequela*/
,'S50352D'  /*Superficial foreign body of left elbow, subsequent encounter*/
,'S50352S'  /*Superficial foreign body of left elbow, sequela*/
,'S50359D'  /*Superficial foreign body of unspecified elbow, subsequent encounter*/
,'S50359S'  /*Superficial foreign body of unspecified elbow, sequela*/
,'S50361D'  /*Insect bite (nonvenomous) of right elbow, subsequent encounter*/
,'S50361S'  /*Insect bite (nonvenomous) of right elbow, sequela*/
,'S50362D'  /*Insect bite (nonvenomous) of left elbow, subsequent encounter*/
,'S50362S'  /*Insect bite (nonvenomous) of left elbow, sequela*/
,'S50369D'  /*Insect bite (nonvenomous) of unspecified elbow, subsequent encounter*/
,'S50369S'  /*Insect bite (nonvenomous) of unspecified elbow, sequela*/
,'S50371D'  /*Other superficial bite of right elbow, subsequent encounter*/
,'S50371S'  /*Other superficial bite of right elbow, sequela*/
,'S50372D'  /*Other superficial bite of left elbow, subsequent encounter*/
,'S50372S'  /*Other superficial bite of left elbow, sequela*/
,'S50379D'  /*Other superficial bite of unspecified elbow, subsequent encounter*/
,'S50379S'  /*Other superficial bite of unspecified elbow, sequela*/
,'S50811D'  /*Abrasion of right forearm, subsequent encounter*/
,'S50811S'  /*Abrasion of right forearm, sequela*/
,'S50812D'  /*Abrasion of left forearm, subsequent encounter*/
,'S50812S'  /*Abrasion of left forearm, sequela*/
,'S50819D'  /*Abrasion of unspecified forearm, subsequent encounter*/
,'S50819S'  /*Abrasion of unspecified forearm, sequela*/
,'S50821D'  /*Blister (nonthermal) of right forearm, subsequent encounter*/
,'S50821S'  /*Blister (nonthermal) of right forearm, sequela*/
,'S50822D'  /*Blister (nonthermal) of left forearm, subsequent encounter*/
,'S50822S'  /*Blister (nonthermal) of left forearm, sequela*/
,'S50829D'  /*Blister (nonthermal) of unspecified forearm, subsequent encounter*/
,'S50829S'  /*Blister (nonthermal) of unspecified forearm, sequela*/
,'S50841D'  /*External constriction of right forearm, subsequent encounter*/
,'S50841S'  /*External constriction of right forearm, sequela*/
,'S50842D'  /*External constriction of left forearm, subsequent encounter*/
,'S50842S'  /*External constriction of left forearm, sequela*/
,'S50849D'  /*External constriction of unspecified forearm, subsequent encounter*/
,'S50849S'  /*External constriction of unspecified forearm, sequela*/
,'S50851D'  /*Superficial foreign body of right forearm, subsequent encounter*/
,'S50851S'  /*Superficial foreign body of right forearm, sequela*/
,'S50852D'  /*Superficial foreign body of left forearm, subsequent encounter*/
,'S50852S'  /*Superficial foreign body of left forearm, sequela*/
,'S50859D'  /*Superficial foreign body of unspecified forearm, subsequent encounter*/
,'S50859S'  /*Superficial foreign body of unspecified forearm, sequela*/
,'S50861D'  /*Insect bite (nonvenomous) of right forearm, subsequent encounter*/
,'S50861S'  /*Insect bite (nonvenomous) of right forearm, sequela*/
,'S50862D'  /*Insect bite (nonvenomous) of left forearm, subsequent encounter*/
,'S50862S'  /*Insect bite (nonvenomous) of left forearm, sequela*/
,'S50869D'  /*Insect bite (nonvenomous) of unspecified forearm, subsequent encounter*/
,'S50869S'  /*Insect bite (nonvenomous) of unspecified forearm, sequela*/
,'S50871D'  /*Other superficial bite of right forearm, subsequent encounter*/
,'S50871S'  /*Other superficial bite of right forearm, sequela*/
,'S50872D'  /*Other superficial bite of left forearm, subsequent encounter*/
,'S50872S'  /*Other superficial bite of left forearm, sequela*/
,'S50879D'  /*Other superficial bite of unspecified forearm, subsequent encounter*/
,'S50879S'  /*Other superficial bite of unspecified forearm, sequela*/
,'S50901D'  /*Unspecified superficial injury of right elbow, subsequent encounter*/
,'S50901S'  /*Unspecified superficial injury of right elbow, sequela*/
,'S50902D'  /*Unspecified superficial injury of left elbow, subsequent encounter*/
,'S50902S'  /*Unspecified superficial injury of left elbow, sequela*/
,'S50909D'  /*Unspecified superficial injury of unspecified elbow, subsequent encounter*/
,'S50909S'  /*Unspecified superficial injury of unspecified elbow, sequela*/
,'S50911D'  /*Unspecified superficial injury of right forearm, subsequent encounter*/
,'S50911S'  /*Unspecified superficial injury of right forearm, sequela*/
,'S50912D'  /*Unspecified superficial injury of left forearm, subsequent encounter*/
,'S50912S'  /*Unspecified superficial injury of left forearm, sequela*/
,'S50919D'  /*Unspecified superficial injury of unspecified forearm, subsequent encounter*/
,'S50919S'  /*Unspecified superficial injury of unspecified forearm, sequela*/
,'S51001D'  /*Unspecified open wound of right elbow, subsequent encounter*/
,'S51001S'  /*Unspecified open wound of right elbow, sequela*/
,'S51002D'  /*Unspecified open wound of left elbow, subsequent encounter*/
,'S51002S'  /*Unspecified open wound of left elbow, sequela*/
,'S51009D'  /*Unspecified open wound of unspecified elbow, subsequent encounter*/
,'S51009S'  /*Unspecified open wound of unspecified elbow, sequela*/
,'S51011D'  /*Laceration without foreign body of right elbow, subsequent encounter*/
,'S51011S'  /*Laceration without foreign body of right elbow, sequela*/
,'S51012D'  /*Laceration without foreign body of left elbow, subsequent encounter*/
,'S51012S'  /*Laceration without foreign body of left elbow, sequela*/
,'S51019D'  /*Laceration without foreign body of unspecified elbow, subsequent encounter*/
,'S51019S'  /*Laceration without foreign body of unspecified elbow, sequela*/
,'S51021D'  /*Laceration with foreign body of right elbow, subsequent encounter*/
,'S51021S'  /*Laceration with foreign body of right elbow, sequela*/
,'S51022D'  /*Laceration with foreign body of left elbow, subsequent encounter*/
,'S51022S'  /*Laceration with foreign body of left elbow, sequela*/
,'S51029D'  /*Laceration with foreign body of unspecified elbow, subsequent encounter*/
,'S51029S'  /*Laceration with foreign body of unspecified elbow, sequela*/
,'S51031D'  /*Puncture wound without foreign body of right elbow, subsequent encounter*/
,'S51031S'  /*Puncture wound without foreign body of right elbow, sequela*/
,'S51032D'  /*Puncture wound without foreign body of left elbow, subsequent encounter*/
,'S51032S'  /*Puncture wound without foreign body of left elbow, sequela*/
,'S51039D'  /*Puncture wound without foreign body of unspecified elbow, subsequent encounter*/
,'S51039S'  /*Puncture wound without foreign body of unspecified elbow, sequela*/
,'S51041D'  /*Puncture wound with foreign body of right elbow, subsequent encounter*/
,'S51041S'  /*Puncture wound with foreign body of right elbow, sequela*/
,'S51042D'  /*Puncture wound with foreign body of left elbow, subsequent encounter*/
,'S51042S'  /*Puncture wound with foreign body of left elbow, sequela*/
,'S51049D'  /*Puncture wound with foreign body of unspecified elbow, subsequent encounter*/
,'S51049S'  /*Puncture wound with foreign body of unspecified elbow, sequela*/
,'S51051D'  /*Open bite, right elbow, subsequent encounter*/
,'S51051S'  /*Open bite, right elbow, sequela*/
,'S51052D'  /*Open bite, left elbow, subsequent encounter*/
,'S51052S'  /*Open bite, left elbow, sequela*/
,'S51059D'  /*Open bite, unspecified elbow, subsequent encounter*/
,'S51059S'  /*Open bite, unspecified elbow, sequela*/
,'S51801D'  /*Unspecified open wound of right forearm, subsequent encounter*/
,'S51801S'  /*Unspecified open wound of right forearm, sequela*/
,'S51802D'  /*Unspecified open wound of left forearm, subsequent encounter*/
,'S51802S'  /*Unspecified open wound of left forearm, sequela*/
,'S51809D'  /*Unspecified open wound of unspecified forearm, subsequent encounter*/
,'S51809S'  /*Unspecified open wound of unspecified forearm, sequela*/
,'S51811D'  /*Laceration without foreign body of right forearm, subsequent encounter*/
,'S51811S'  /*Laceration without foreign body of right forearm, sequela*/
,'S51812D'  /*Laceration without foreign body of left forearm, subsequent encounter*/
,'S51812S'  /*Laceration without foreign body of left forearm, sequela*/
,'S51819D'  /*Laceration without foreign body of unspecified forearm, subsequent encounter*/
,'S51819S'  /*Laceration without foreign body of unspecified forearm, sequela*/
,'S51821D'  /*Laceration with foreign body of right forearm, subsequent encounter*/
,'S51821S'  /*Laceration with foreign body of right forearm, sequela*/
,'S51822D'  /*Laceration with foreign body of left forearm, subsequent encounter*/
,'S51822S'  /*Laceration with foreign body of left forearm, sequela*/
,'S51829D'  /*Laceration with foreign body of unspecified forearm, subsequent encounter*/
,'S51829S'  /*Laceration with foreign body of unspecified forearm, sequela*/
,'S51831D'  /*Puncture wound without foreign body of right forearm, subsequent encounter*/
,'S51831S'  /*Puncture wound without foreign body of right forearm, sequela*/
,'S51832D'  /*Puncture wound without foreign body of left forearm, subsequent encounter*/
,'S51832S'  /*Puncture wound without foreign body of left forearm, sequela*/
,'S51839D'  /*Puncture wound without foreign body of unspecified forearm, subsequent encounter*/
,'S51839S'  /*Puncture wound without foreign body of unspecified forearm, sequela*/
,'S51841D'  /*Puncture wound with foreign body of right forearm, subsequent encounter*/
,'S51841S'  /*Puncture wound with foreign body of right forearm, sequela*/
,'S51842D'  /*Puncture wound with foreign body of left forearm, subsequent encounter*/
,'S51842S'  /*Puncture wound with foreign body of left forearm, sequela*/
,'S51849D'  /*Puncture wound with foreign body of unspecified forearm, subsequent encounter*/
,'S51849S'  /*Puncture wound with foreign body of unspecified forearm, sequela*/
,'S51851D'  /*Open bite of right forearm, subsequent encounter*/
,'S51851S'  /*Open bite of right forearm, sequela*/
,'S51852D'  /*Open bite of left forearm, subsequent encounter*/
,'S51852S'  /*Open bite of left forearm, sequela*/
,'S51859D'  /*Open bite of unspecified forearm, subsequent encounter*/
,'S51859S'  /*Open bite of unspecified forearm, sequela*/
,'S52001D'  /*Unspecified fracture of upper end of right ulna, subsequent encounter for closed fracture with routine healing*/
,'S52001E'  /*Unspecified fracture of upper end of right ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52001F'  /*Unspecified fracture of upper end of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52001G'  /*Unspecified fracture of upper end of right ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52001H'  /*Unspecified fracture of upper end of right ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52001J'  /*Unspecified fracture of upper end of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52001K'  /*Unspecified fracture of upper end of right ulna, subsequent encounter for closed fracture with nonunion*/
,'S52001M'  /*Unspecified fracture of upper end of right ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52001N'  /*Unspecified fracture of upper end of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52001P'  /*Unspecified fracture of upper end of right ulna, subsequent encounter for closed fracture with malunion*/
,'S52001Q'  /*Unspecified fracture of upper end of right ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52001R'  /*Unspecified fracture of upper end of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52001S'  /*Unspecified fracture of upper end of right ulna, sequela*/
,'S52002D'  /*Unspecified fracture of upper end of left ulna, subsequent encounter for closed fracture with routine healing*/
,'S52002E'  /*Unspecified fracture of upper end of left ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52002F'  /*Unspecified fracture of upper end of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52002G'  /*Unspecified fracture of upper end of left ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52002H'  /*Unspecified fracture of upper end of left ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52002J'  /*Unspecified fracture of upper end of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52002K'  /*Unspecified fracture of upper end of left ulna, subsequent encounter for closed fracture with nonunion*/
,'S52002M'  /*Unspecified fracture of upper end of left ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52002N'  /*Unspecified fracture of upper end of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52002P'  /*Unspecified fracture of upper end of left ulna, subsequent encounter for closed fracture with malunion*/
,'S52002Q'  /*Unspecified fracture of upper end of left ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52002R'  /*Unspecified fracture of upper end of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52002S'  /*Unspecified fracture of upper end of left ulna, sequela*/
,'S52009D'  /*Unspecified fracture of upper end of unspecified ulna, subsequent encounter for closed fracture with routine healing*/
,'S52009E'  /*Unspecified fracture of upper end of unspecified ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52009F'  /*Unspecified fracture of upper end of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52009G'  /*Unspecified fracture of upper end of unspecified ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52009H'  /*Unspecified fracture of upper end of unspecified ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52009J'  /*Unspecified fracture of upper end of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52009K'  /*Unspecified fracture of upper end of unspecified ulna, subsequent encounter for closed fracture with nonunion*/
,'S52009M'  /*Unspecified fracture of upper end of unspecified ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52009N'  /*Unspecified fracture of upper end of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52009P'  /*Unspecified fracture of upper end of unspecified ulna, subsequent encounter for closed fracture with malunion*/
,'S52009Q'  /*Unspecified fracture of upper end of unspecified ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52009R'  /*Unspecified fracture of upper end of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52009S'  /*Unspecified fracture of upper end of unspecified ulna, sequela*/
,'S52011D'  /*Torus fracture of upper end of right ulna, subsequent encounter for fracture with routine healing*/
,'S52011G'  /*Torus fracture of upper end of right ulna, subsequent encounter for fracture with delayed healing*/
,'S52011K'  /*Torus fracture of upper end of right ulna, subsequent encounter for fracture with nonunion*/
,'S52011P'  /*Torus fracture of upper end of right ulna, subsequent encounter for fracture with malunion*/
,'S52011S'  /*Torus fracture of upper end of right ulna, sequela*/
,'S52012D'  /*Torus fracture of upper end of left ulna, subsequent encounter for fracture with routine healing*/
,'S52012G'  /*Torus fracture of upper end of left ulna, subsequent encounter for fracture with delayed healing*/
,'S52012K'  /*Torus fracture of upper end of left ulna, subsequent encounter for fracture with nonunion*/
,'S52012P'  /*Torus fracture of upper end of left ulna, subsequent encounter for fracture with malunion*/
,'S52012S'  /*Torus fracture of upper end of left ulna, sequela*/
,'S52019D'  /*Torus fracture of upper end of unspecified ulna, subsequent encounter for fracture with routine healing*/
,'S52019G'  /*Torus fracture of upper end of unspecified ulna, subsequent encounter for fracture with delayed healing*/
,'S52019K'  /*Torus fracture of upper end of unspecified ulna, subsequent encounter for fracture with nonunion*/
,'S52019P'  /*Torus fracture of upper end of unspecified ulna, subsequent encounter for fracture with malunion*/
,'S52019S'  /*Torus fracture of upper end of unspecified ulna, sequela*/
,'S52021D'  /*Displaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for closed fracture with routine healing*/
,'S52021E'  /*Displaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52021F'  /*Displaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52021G'  /*Displaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52021H'  /*Displaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52021J'  /*Displaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52021K'  /*Displaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for closed fracture with nonunion*/
,'S52021M'  /*Displaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52021N'  /*Displaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52021P'  /*Displaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for closed fracture with malunion*/
,'S52021Q'  /*Displaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52021R'  /*Displaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52021S'  /*Displaced fracture of olecranon process without intraarticular extension of right ulna, sequela*/
,'S52022D'  /*Displaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for closed fracture with routine healing*/
,'S52022E'  /*Displaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52022F'  /*Displaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52022G'  /*Displaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52022H'  /*Displaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52022J'  /*Displaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52022K'  /*Displaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for closed fracture with nonunion*/
,'S52022M'  /*Displaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52022N'  /*Displaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52022P'  /*Displaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for closed fracture with malunion*/
,'S52022Q'  /*Displaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52022R'  /*Displaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52022S'  /*Displaced fracture of olecranon process without intraarticular extension of left ulna, sequela*/
,'S52023D'  /*Displaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for closed fracture with routine healing*/
,'S52023E'  /*Displaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52023F'  /*Displaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52023G'  /*Displaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52023H'  /*Displaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52023J'  /*Displaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52023K'  /*Displaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for closed fracture with nonunion*/
,'S52023M'  /*Displaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52023N'  /*Displaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52023P'  /*Displaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for closed fracture with malunion*/
,'S52023Q'  /*Displaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52023R'  /*Displaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52023S'  /*Displaced fracture of olecranon process without intraarticular extension of unspecified ulna, sequela*/
,'S52024D'  /*Nondisplaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for closed fracture with routine healing*/
,'S52024E'  /*Nondisplaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52024F'  /*Nondisplaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52024G'  /*Nondisplaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52024H'  /*Nondisplaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52024J'  /*Nondisplaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52024K'  /*Nondisplaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for closed fracture with nonunion*/
,'S52024M'  /*Nondisplaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52024N'  /*Nondisplaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52024P'  /*Nondisplaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for closed fracture with malunion*/
,'S52024Q'  /*Nondisplaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52024R'  /*Nondisplaced fracture of olecranon process without intraarticular extension of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52024S'  /*Nondisplaced fracture of olecranon process without intraarticular extension of right ulna, sequela*/
,'S52025D'  /*Nondisplaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for closed fracture with routine healing*/
,'S52025E'  /*Nondisplaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52025F'  /*Nondisplaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52025G'  /*Nondisplaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52025H'  /*Nondisplaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52025J'  /*Nondisplaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52025K'  /*Nondisplaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for closed fracture with nonunion*/
,'S52025M'  /*Nondisplaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52025N'  /*Nondisplaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52025P'  /*Nondisplaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for closed fracture with malunion*/
,'S52025Q'  /*Nondisplaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52025R'  /*Nondisplaced fracture of olecranon process without intraarticular extension of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52025S'  /*Nondisplaced fracture of olecranon process without intraarticular extension of left ulna, sequela*/
,'S52026D'  /*Nondisplaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for closed fracture with routine healing*/
,'S52026E'  /*Nondisplaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52026F'  /*Nondisplaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52026G'  /*Nondisplaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52026H'  /*Nondisplaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52026J'  /*Nondisplaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52026K'  /*Nondisplaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for closed fracture with nonunion*/
,'S52026M'  /*Nondisplaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52026N'  /*Nondisplaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52026P'  /*Nondisplaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for closed fracture with malunion*/
,'S52026Q'  /*Nondisplaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52026R'  /*Nondisplaced fracture of olecranon process without intraarticular extension of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52026S'  /*Nondisplaced fracture of olecranon process without intraarticular extension of unspecified ulna, sequela*/
,'S52031D'  /*Displaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for closed fracture with routine healing*/
,'S52031E'  /*Displaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52031F'  /*Displaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52031G'  /*Displaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52031H'  /*Displaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52031J'  /*Displaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52031K'  /*Displaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for closed fracture with nonunion*/
,'S52031M'  /*Displaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52031N'  /*Displaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52031P'  /*Displaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for closed fracture with malunion*/
,'S52031Q'  /*Displaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52031R'  /*Displaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52031S'  /*Displaced fracture of olecranon process with intraarticular extension of right ulna, sequela*/
,'S52032D'  /*Displaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for closed fracture with routine healing*/
,'S52032E'  /*Displaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52032F'  /*Displaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52032G'  /*Displaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52032H'  /*Displaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52032J'  /*Displaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52032K'  /*Displaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for closed fracture with nonunion*/
,'S52032M'  /*Displaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52032N'  /*Displaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52032P'  /*Displaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for closed fracture with malunion*/
,'S52032Q'  /*Displaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52032R'  /*Displaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52032S'  /*Displaced fracture of olecranon process with intraarticular extension of left ulna, sequela*/
,'S52033D'  /*Displaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for closed fracture with routine healing*/
,'S52033E'  /*Displaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52033F'  /*Displaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52033G'  /*Displaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52033H'  /*Displaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52033J'  /*Displaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52033K'  /*Displaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for closed fracture with nonunion*/
,'S52033M'  /*Displaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52033N'  /*Displaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52033P'  /*Displaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for closed fracture with malunion*/
,'S52033Q'  /*Displaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52033R'  /*Displaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52033S'  /*Displaced fracture of olecranon process with intraarticular extension of unspecified ulna, sequela*/
,'S52034D'  /*Nondisplaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for closed fracture with routine healing*/
,'S52034E'  /*Nondisplaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52034F'  /*Nondisplaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52034G'  /*Nondisplaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52034H'  /*Nondisplaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52034J'  /*Nondisplaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52034K'  /*Nondisplaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for closed fracture with nonunion*/
,'S52034M'  /*Nondisplaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52034N'  /*Nondisplaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52034P'  /*Nondisplaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for closed fracture with malunion*/
,'S52034Q'  /*Nondisplaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52034R'  /*Nondisplaced fracture of olecranon process with intraarticular extension of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52034S'  /*Nondisplaced fracture of olecranon process with intraarticular extension of right ulna, sequela*/
,'S52035D'  /*Nondisplaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for closed fracture with routine healing*/
,'S52035E'  /*Nondisplaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52035F'  /*Nondisplaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52035G'  /*Nondisplaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52035H'  /*Nondisplaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52035J'  /*Nondisplaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52035K'  /*Nondisplaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for closed fracture with nonunion*/
,'S52035M'  /*Nondisplaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52035N'  /*Nondisplaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52035P'  /*Nondisplaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for closed fracture with malunion*/
,'S52035Q'  /*Nondisplaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52035R'  /*Nondisplaced fracture of olecranon process with intraarticular extension of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52035S'  /*Nondisplaced fracture of olecranon process with intraarticular extension of left ulna, sequela*/
,'S52036D'  /*Nondisplaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for closed fracture with routine healing*/
,'S52036E'  /*Nondisplaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52036F'  /*Nondisplaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52036G'  /*Nondisplaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52036H'  /*Nondisplaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52036J'  /*Nondisplaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52036K'  /*Nondisplaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for closed fracture with nonunion*/
,'S52036M'  /*Nondisplaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52036N'  /*Nondisplaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52036P'  /*Nondisplaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for closed fracture with malunion*/
,'S52036Q'  /*Nondisplaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52036R'  /*Nondisplaced fracture of olecranon process with intraarticular extension of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52036S'  /*Nondisplaced fracture of olecranon process with intraarticular extension of unspecified ulna, sequela*/
,'S52041D'  /*Displaced fracture of coronoid process of right ulna, subsequent encounter for closed fracture with routine healing*/
,'S52041E'  /*Displaced fracture of coronoid process of right ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52041F'  /*Displaced fracture of coronoid process of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52041G'  /*Displaced fracture of coronoid process of right ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52041H'  /*Displaced fracture of coronoid process of right ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52041J'  /*Displaced fracture of coronoid process of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52041K'  /*Displaced fracture of coronoid process of right ulna, subsequent encounter for closed fracture with nonunion*/
,'S52041M'  /*Displaced fracture of coronoid process of right ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52041N'  /*Displaced fracture of coronoid process of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52041P'  /*Displaced fracture of coronoid process of right ulna, subsequent encounter for closed fracture with malunion*/
,'S52041Q'  /*Displaced fracture of coronoid process of right ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52041R'  /*Displaced fracture of coronoid process of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52041S'  /*Displaced fracture of coronoid process of right ulna, sequela*/
,'S52042D'  /*Displaced fracture of coronoid process of left ulna, subsequent encounter for closed fracture with routine healing*/
,'S52042E'  /*Displaced fracture of coronoid process of left ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52042F'  /*Displaced fracture of coronoid process of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52042G'  /*Displaced fracture of coronoid process of left ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52042H'  /*Displaced fracture of coronoid process of left ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52042J'  /*Displaced fracture of coronoid process of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52042K'  /*Displaced fracture of coronoid process of left ulna, subsequent encounter for closed fracture with nonunion*/
,'S52042M'  /*Displaced fracture of coronoid process of left ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52042N'  /*Displaced fracture of coronoid process of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52042P'  /*Displaced fracture of coronoid process of left ulna, subsequent encounter for closed fracture with malunion*/
,'S52042Q'  /*Displaced fracture of coronoid process of left ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52042R'  /*Displaced fracture of coronoid process of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52042S'  /*Displaced fracture of coronoid process of left ulna, sequela*/
,'S52043D'  /*Displaced fracture of coronoid process of unspecified ulna, subsequent encounter for closed fracture with routine healing*/
,'S52043E'  /*Displaced fracture of coronoid process of unspecified ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52043F'  /*Displaced fracture of coronoid process of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52043G'  /*Displaced fracture of coronoid process of unspecified ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52043H'  /*Displaced fracture of coronoid process of unspecified ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52043J'  /*Displaced fracture of coronoid process of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52043K'  /*Displaced fracture of coronoid process of unspecified ulna, subsequent encounter for closed fracture with nonunion*/
,'S52043M'  /*Displaced fracture of coronoid process of unspecified ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52043N'  /*Displaced fracture of coronoid process of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52043P'  /*Displaced fracture of coronoid process of unspecified ulna, subsequent encounter for closed fracture with malunion*/
,'S52043Q'  /*Displaced fracture of coronoid process of unspecified ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52043R'  /*Displaced fracture of coronoid process of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52043S'  /*Displaced fracture of coronoid process of unspecified ulna, sequela*/
,'S52044D'  /*Nondisplaced fracture of coronoid process of right ulna, subsequent encounter for closed fracture with routine healing*/
,'S52044E'  /*Nondisplaced fracture of coronoid process of right ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52044F'  /*Nondisplaced fracture of coronoid process of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52044G'  /*Nondisplaced fracture of coronoid process of right ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52044H'  /*Nondisplaced fracture of coronoid process of right ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52044J'  /*Nondisplaced fracture of coronoid process of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52044K'  /*Nondisplaced fracture of coronoid process of right ulna, subsequent encounter for closed fracture with nonunion*/
,'S52044M'  /*Nondisplaced fracture of coronoid process of right ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52044N'  /*Nondisplaced fracture of coronoid process of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52044P'  /*Nondisplaced fracture of coronoid process of right ulna, subsequent encounter for closed fracture with malunion*/
,'S52044Q'  /*Nondisplaced fracture of coronoid process of right ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52044R'  /*Nondisplaced fracture of coronoid process of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52044S'  /*Nondisplaced fracture of coronoid process of right ulna, sequela*/
,'S52045D'  /*Nondisplaced fracture of coronoid process of left ulna, subsequent encounter for closed fracture with routine healing*/
,'S52045E'  /*Nondisplaced fracture of coronoid process of left ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52045F'  /*Nondisplaced fracture of coronoid process of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52045G'  /*Nondisplaced fracture of coronoid process of left ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52045H'  /*Nondisplaced fracture of coronoid process of left ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52045J'  /*Nondisplaced fracture of coronoid process of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52045K'  /*Nondisplaced fracture of coronoid process of left ulna, subsequent encounter for closed fracture with nonunion*/
,'S52045M'  /*Nondisplaced fracture of coronoid process of left ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52045N'  /*Nondisplaced fracture of coronoid process of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52045P'  /*Nondisplaced fracture of coronoid process of left ulna, subsequent encounter for closed fracture with malunion*/
,'S52045Q'  /*Nondisplaced fracture of coronoid process of left ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52045R'  /*Nondisplaced fracture of coronoid process of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52045S'  /*Nondisplaced fracture of coronoid process of left ulna, sequela*/
,'S52046D'  /*Nondisplaced fracture of coronoid process of unspecified ulna, subsequent encounter for closed fracture with routine healing*/
,'S52046E'  /*Nondisplaced fracture of coronoid process of unspecified ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52046F'  /*Nondisplaced fracture of coronoid process of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52046G'  /*Nondisplaced fracture of coronoid process of unspecified ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52046H'  /*Nondisplaced fracture of coronoid process of unspecified ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52046J'  /*Nondisplaced fracture of coronoid process of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52046K'  /*Nondisplaced fracture of coronoid process of unspecified ulna, subsequent encounter for closed fracture with nonunion*/
,'S52046M'  /*Nondisplaced fracture of coronoid process of unspecified ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52046N'  /*Nondisplaced fracture of coronoid process of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52046P'  /*Nondisplaced fracture of coronoid process of unspecified ulna, subsequent encounter for closed fracture with malunion*/
,'S52046Q'  /*Nondisplaced fracture of coronoid process of unspecified ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52046R'  /*Nondisplaced fracture of coronoid process of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52046S'  /*Nondisplaced fracture of coronoid process of unspecified ulna, sequela*/
,'S52091D'  /*Other fracture of upper end of right ulna, subsequent encounter for closed fracture with routine healing*/
,'S52091E'  /*Other fracture of upper end of right ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52091F'  /*Other fracture of upper end of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52091G'  /*Other fracture of upper end of right ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52091H'  /*Other fracture of upper end of right ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52091J'  /*Other fracture of upper end of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52091K'  /*Other fracture of upper end of right ulna, subsequent encounter for closed fracture with nonunion*/
,'S52091M'  /*Other fracture of upper end of right ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52091N'  /*Other fracture of upper end of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52091P'  /*Other fracture of upper end of right ulna, subsequent encounter for closed fracture with malunion*/
,'S52091Q'  /*Other fracture of upper end of right ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52091R'  /*Other fracture of upper end of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52091S'  /*Other fracture of upper end of right ulna, sequela*/
,'S52092D'  /*Other fracture of upper end of left ulna, subsequent encounter for closed fracture with routine healing*/
,'S52092E'  /*Other fracture of upper end of left ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52092F'  /*Other fracture of upper end of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52092G'  /*Other fracture of upper end of left ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52092H'  /*Other fracture of upper end of left ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52092J'  /*Other fracture of upper end of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52092K'  /*Other fracture of upper end of left ulna, subsequent encounter for closed fracture with nonunion*/
,'S52092M'  /*Other fracture of upper end of left ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52092N'  /*Other fracture of upper end of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52092P'  /*Other fracture of upper end of left ulna, subsequent encounter for closed fracture with malunion*/
,'S52092Q'  /*Other fracture of upper end of left ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52092R'  /*Other fracture of upper end of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52092S'  /*Other fracture of upper end of left ulna, sequela*/
,'S52099D'  /*Other fracture of upper end of unspecified ulna, subsequent encounter for closed fracture with routine healing*/
,'S52099E'  /*Other fracture of upper end of unspecified ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52099F'  /*Other fracture of upper end of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52099G'  /*Other fracture of upper end of unspecified ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52099H'  /*Other fracture of upper end of unspecified ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52099J'  /*Other fracture of upper end of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52099K'  /*Other fracture of upper end of unspecified ulna, subsequent encounter for closed fracture with nonunion*/
,'S52099M'  /*Other fracture of upper end of unspecified ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52099N'  /*Other fracture of upper end of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52099P'  /*Other fracture of upper end of unspecified ulna, subsequent encounter for closed fracture with malunion*/
,'S52099Q'  /*Other fracture of upper end of unspecified ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52099R'  /*Other fracture of upper end of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52099S'  /*Other fracture of upper end of unspecified ulna, sequela*/
,'S52101D'  /*Unspecified fracture of upper end of right radius, subsequent encounter for closed fracture with routine healing*/
,'S52101E'  /*Unspecified fracture of upper end of right radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52101F'  /*Unspecified fracture of upper end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52101G'  /*Unspecified fracture of upper end of right radius, subsequent encounter for closed fracture with delayed healing*/
,'S52101H'  /*Unspecified fracture of upper end of right radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52101J'  /*Unspecified fracture of upper end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52101K'  /*Unspecified fracture of upper end of right radius, subsequent encounter for closed fracture with nonunion*/
,'S52101M'  /*Unspecified fracture of upper end of right radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52101N'  /*Unspecified fracture of upper end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52101P'  /*Unspecified fracture of upper end of right radius, subsequent encounter for closed fracture with malunion*/
,'S52101Q'  /*Unspecified fracture of upper end of right radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52101R'  /*Unspecified fracture of upper end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52101S'  /*Unspecified fracture of upper end of right radius, sequela*/
,'S52102D'  /*Unspecified fracture of upper end of left radius, subsequent encounter for closed fracture with routine healing*/
,'S52102E'  /*Unspecified fracture of upper end of left radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52102F'  /*Unspecified fracture of upper end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52102G'  /*Unspecified fracture of upper end of left radius, subsequent encounter for closed fracture with delayed healing*/
,'S52102H'  /*Unspecified fracture of upper end of left radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52102J'  /*Unspecified fracture of upper end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52102K'  /*Unspecified fracture of upper end of left radius, subsequent encounter for closed fracture with nonunion*/
,'S52102M'  /*Unspecified fracture of upper end of left radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52102N'  /*Unspecified fracture of upper end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52102P'  /*Unspecified fracture of upper end of left radius, subsequent encounter for closed fracture with malunion*/
,'S52102Q'  /*Unspecified fracture of upper end of left radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52102R'  /*Unspecified fracture of upper end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52102S'  /*Unspecified fracture of upper end of left radius, sequela*/
,'S52109D'  /*Unspecified fracture of upper end of unspecified radius, subsequent encounter for closed fracture with routine healing*/
,'S52109E'  /*Unspecified fracture of upper end of unspecified radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52109F'  /*Unspecified fracture of upper end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52109G'  /*Unspecified fracture of upper end of unspecified radius, subsequent encounter for closed fracture with delayed healing*/
,'S52109H'  /*Unspecified fracture of upper end of unspecified radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52109J'  /*Unspecified fracture of upper end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52109K'  /*Unspecified fracture of upper end of unspecified radius, subsequent encounter for closed fracture with nonunion*/
,'S52109M'  /*Unspecified fracture of upper end of unspecified radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52109N'  /*Unspecified fracture of upper end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52109P'  /*Unspecified fracture of upper end of unspecified radius, subsequent encounter for closed fracture with malunion*/
,'S52109Q'  /*Unspecified fracture of upper end of unspecified radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52109R'  /*Unspecified fracture of upper end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52109S'  /*Unspecified fracture of upper end of unspecified radius, sequela*/
,'S52111D'  /*Torus fracture of upper end of right radius, subsequent encounter for fracture with routine healing*/
,'S52111G'  /*Torus fracture of upper end of right radius, subsequent encounter for fracture with delayed healing*/
,'S52111K'  /*Torus fracture of upper end of right radius, subsequent encounter for fracture with nonunion*/
,'S52111P'  /*Torus fracture of upper end of right radius, subsequent encounter for fracture with malunion*/
,'S52111S'  /*Torus fracture of upper end of right radius, sequela*/
,'S52112D'  /*Torus fracture of upper end of left radius, subsequent encounter for fracture with routine healing*/
,'S52112G'  /*Torus fracture of upper end of left radius, subsequent encounter for fracture with delayed healing*/
,'S52112K'  /*Torus fracture of upper end of left radius, subsequent encounter for fracture with nonunion*/
,'S52112P'  /*Torus fracture of upper end of left radius, subsequent encounter for fracture with malunion*/
,'S52112S'  /*Torus fracture of upper end of left radius, sequela*/
,'S52119D'  /*Torus fracture of upper end of unspecified radius, subsequent encounter for fracture with routine healing*/
,'S52119G'  /*Torus fracture of upper end of unspecified radius, subsequent encounter for fracture with delayed healing*/
,'S52119K'  /*Torus fracture of upper end of unspecified radius, subsequent encounter for fracture with nonunion*/
,'S52119P'  /*Torus fracture of upper end of unspecified radius, subsequent encounter for fracture with malunion*/
,'S52119S'  /*Torus fracture of upper end of unspecified radius, sequela*/
,'S52121D'  /*Displaced fracture of head of right radius, subsequent encounter for closed fracture with routine healing*/
,'S52121E'  /*Displaced fracture of head of right radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52121F'  /*Displaced fracture of head of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52121G'  /*Displaced fracture of head of right radius, subsequent encounter for closed fracture with delayed healing*/
,'S52121H'  /*Displaced fracture of head of right radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52121J'  /*Displaced fracture of head of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52121K'  /*Displaced fracture of head of right radius, subsequent encounter for closed fracture with nonunion*/
,'S52121M'  /*Displaced fracture of head of right radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52121N'  /*Displaced fracture of head of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52121P'  /*Displaced fracture of head of right radius, subsequent encounter for closed fracture with malunion*/
,'S52121Q'  /*Displaced fracture of head of right radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52121R'  /*Displaced fracture of head of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52121S'  /*Displaced fracture of head of right radius, sequela*/
,'S52122D'  /*Displaced fracture of head of left radius, subsequent encounter for closed fracture with routine healing*/
,'S52122E'  /*Displaced fracture of head of left radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52122F'  /*Displaced fracture of head of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52122G'  /*Displaced fracture of head of left radius, subsequent encounter for closed fracture with delayed healing*/
,'S52122H'  /*Displaced fracture of head of left radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52122J'  /*Displaced fracture of head of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52122K'  /*Displaced fracture of head of left radius, subsequent encounter for closed fracture with nonunion*/
,'S52122M'  /*Displaced fracture of head of left radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52122N'  /*Displaced fracture of head of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52122P'  /*Displaced fracture of head of left radius, subsequent encounter for closed fracture with malunion*/
,'S52122Q'  /*Displaced fracture of head of left radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52122R'  /*Displaced fracture of head of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52122S'  /*Displaced fracture of head of left radius, sequela*/
,'S52123D'  /*Displaced fracture of head of unspecified radius, subsequent encounter for closed fracture with routine healing*/
,'S52123E'  /*Displaced fracture of head of unspecified radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52123F'  /*Displaced fracture of head of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52123G'  /*Displaced fracture of head of unspecified radius, subsequent encounter for closed fracture with delayed healing*/
,'S52123H'  /*Displaced fracture of head of unspecified radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52123J'  /*Displaced fracture of head of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52123K'  /*Displaced fracture of head of unspecified radius, subsequent encounter for closed fracture with nonunion*/
,'S52123M'  /*Displaced fracture of head of unspecified radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52123N'  /*Displaced fracture of head of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52123P'  /*Displaced fracture of head of unspecified radius, subsequent encounter for closed fracture with malunion*/
,'S52123Q'  /*Displaced fracture of head of unspecified radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52123R'  /*Displaced fracture of head of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52123S'  /*Displaced fracture of head of unspecified radius, sequela*/
,'S52124D'  /*Nondisplaced fracture of head of right radius, subsequent encounter for closed fracture with routine healing*/
,'S52124E'  /*Nondisplaced fracture of head of right radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52124F'  /*Nondisplaced fracture of head of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52124G'  /*Nondisplaced fracture of head of right radius, subsequent encounter for closed fracture with delayed healing*/
,'S52124H'  /*Nondisplaced fracture of head of right radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52124J'  /*Nondisplaced fracture of head of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52124K'  /*Nondisplaced fracture of head of right radius, subsequent encounter for closed fracture with nonunion*/
,'S52124M'  /*Nondisplaced fracture of head of right radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52124N'  /*Nondisplaced fracture of head of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52124P'  /*Nondisplaced fracture of head of right radius, subsequent encounter for closed fracture with malunion*/
,'S52124Q'  /*Nondisplaced fracture of head of right radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52124R'  /*Nondisplaced fracture of head of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52124S'  /*Nondisplaced fracture of head of right radius, sequela*/
,'S52125D'  /*Nondisplaced fracture of head of left radius, subsequent encounter for closed fracture with routine healing*/
,'S52125E'  /*Nondisplaced fracture of head of left radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52125F'  /*Nondisplaced fracture of head of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52125G'  /*Nondisplaced fracture of head of left radius, subsequent encounter for closed fracture with delayed healing*/
,'S52125H'  /*Nondisplaced fracture of head of left radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52125J'  /*Nondisplaced fracture of head of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52125K'  /*Nondisplaced fracture of head of left radius, subsequent encounter for closed fracture with nonunion*/
,'S52125M'  /*Nondisplaced fracture of head of left radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52125N'  /*Nondisplaced fracture of head of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52125P'  /*Nondisplaced fracture of head of left radius, subsequent encounter for closed fracture with malunion*/
,'S52125Q'  /*Nondisplaced fracture of head of left radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52125R'  /*Nondisplaced fracture of head of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52125S'  /*Nondisplaced fracture of head of left radius, sequela*/
,'S52126D'  /*Nondisplaced fracture of head of unspecified radius, subsequent encounter for closed fracture with routine healing*/
,'S52126E'  /*Nondisplaced fracture of head of unspecified radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52126F'  /*Nondisplaced fracture of head of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52126G'  /*Nondisplaced fracture of head of unspecified radius, subsequent encounter for closed fracture with delayed healing*/
,'S52126H'  /*Nondisplaced fracture of head of unspecified radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52126J'  /*Nondisplaced fracture of head of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52126K'  /*Nondisplaced fracture of head of unspecified radius, subsequent encounter for closed fracture with nonunion*/
,'S52126M'  /*Nondisplaced fracture of head of unspecified radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52126N'  /*Nondisplaced fracture of head of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52126P'  /*Nondisplaced fracture of head of unspecified radius, subsequent encounter for closed fracture with malunion*/
,'S52126Q'  /*Nondisplaced fracture of head of unspecified radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52126R'  /*Nondisplaced fracture of head of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52126S'  /*Nondisplaced fracture of head of unspecified radius, sequela*/
,'S52131D'  /*Displaced fracture of neck of right radius, subsequent encounter for closed fracture with routine healing*/
,'S52131E'  /*Displaced fracture of neck of right radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52131F'  /*Displaced fracture of neck of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52131G'  /*Displaced fracture of neck of right radius, subsequent encounter for closed fracture with delayed healing*/
,'S52131H'  /*Displaced fracture of neck of right radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52131J'  /*Displaced fracture of neck of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52131K'  /*Displaced fracture of neck of right radius, subsequent encounter for closed fracture with nonunion*/
,'S52131M'  /*Displaced fracture of neck of right radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52131N'  /*Displaced fracture of neck of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52131P'  /*Displaced fracture of neck of right radius, subsequent encounter for closed fracture with malunion*/
,'S52131Q'  /*Displaced fracture of neck of right radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52131R'  /*Displaced fracture of neck of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52131S'  /*Displaced fracture of neck of right radius, sequela*/
,'S52132D'  /*Displaced fracture of neck of left radius, subsequent encounter for closed fracture with routine healing*/
,'S52132E'  /*Displaced fracture of neck of left radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52132F'  /*Displaced fracture of neck of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52132G'  /*Displaced fracture of neck of left radius, subsequent encounter for closed fracture with delayed healing*/
,'S52132H'  /*Displaced fracture of neck of left radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52132J'  /*Displaced fracture of neck of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52132K'  /*Displaced fracture of neck of left radius, subsequent encounter for closed fracture with nonunion*/
,'S52132M'  /*Displaced fracture of neck of left radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52132N'  /*Displaced fracture of neck of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52132P'  /*Displaced fracture of neck of left radius, subsequent encounter for closed fracture with malunion*/
,'S52132Q'  /*Displaced fracture of neck of left radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52132R'  /*Displaced fracture of neck of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52132S'  /*Displaced fracture of neck of left radius, sequela*/
,'S52133D'  /*Displaced fracture of neck of unspecified radius, subsequent encounter for closed fracture with routine healing*/
,'S52133E'  /*Displaced fracture of neck of unspecified radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52133F'  /*Displaced fracture of neck of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52133G'  /*Displaced fracture of neck of unspecified radius, subsequent encounter for closed fracture with delayed healing*/
,'S52133H'  /*Displaced fracture of neck of unspecified radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52133J'  /*Displaced fracture of neck of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52133K'  /*Displaced fracture of neck of unspecified radius, subsequent encounter for closed fracture with nonunion*/
,'S52133M'  /*Displaced fracture of neck of unspecified radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52133N'  /*Displaced fracture of neck of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52133P'  /*Displaced fracture of neck of unspecified radius, subsequent encounter for closed fracture with malunion*/
,'S52133Q'  /*Displaced fracture of neck of unspecified radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52133R'  /*Displaced fracture of neck of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52133S'  /*Displaced fracture of neck of unspecified radius, sequela*/
,'S52134D'  /*Nondisplaced fracture of neck of right radius, subsequent encounter for closed fracture with routine healing*/
,'S52134E'  /*Nondisplaced fracture of neck of right radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52134F'  /*Nondisplaced fracture of neck of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52134G'  /*Nondisplaced fracture of neck of right radius, subsequent encounter for closed fracture with delayed healing*/
,'S52134H'  /*Nondisplaced fracture of neck of right radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52134J'  /*Nondisplaced fracture of neck of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52134K'  /*Nondisplaced fracture of neck of right radius, subsequent encounter for closed fracture with nonunion*/
,'S52134M'  /*Nondisplaced fracture of neck of right radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52134N'  /*Nondisplaced fracture of neck of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52134P'  /*Nondisplaced fracture of neck of right radius, subsequent encounter for closed fracture with malunion*/
,'S52134Q'  /*Nondisplaced fracture of neck of right radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52134R'  /*Nondisplaced fracture of neck of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52134S'  /*Nondisplaced fracture of neck of right radius, sequela*/
,'S52135D'  /*Nondisplaced fracture of neck of left radius, subsequent encounter for closed fracture with routine healing*/
,'S52135E'  /*Nondisplaced fracture of neck of left radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52135F'  /*Nondisplaced fracture of neck of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52135G'  /*Nondisplaced fracture of neck of left radius, subsequent encounter for closed fracture with delayed healing*/
,'S52135H'  /*Nondisplaced fracture of neck of left radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52135J'  /*Nondisplaced fracture of neck of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52135K'  /*Nondisplaced fracture of neck of left radius, subsequent encounter for closed fracture with nonunion*/
,'S52135M'  /*Nondisplaced fracture of neck of left radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52135N'  /*Nondisplaced fracture of neck of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52135P'  /*Nondisplaced fracture of neck of left radius, subsequent encounter for closed fracture with malunion*/
,'S52135Q'  /*Nondisplaced fracture of neck of left radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52135R'  /*Nondisplaced fracture of neck of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52135S'  /*Nondisplaced fracture of neck of left radius, sequela*/
,'S52136D'  /*Nondisplaced fracture of neck of unspecified radius, subsequent encounter for closed fracture with routine healing*/
,'S52136E'  /*Nondisplaced fracture of neck of unspecified radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52136F'  /*Nondisplaced fracture of neck of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52136G'  /*Nondisplaced fracture of neck of unspecified radius, subsequent encounter for closed fracture with delayed healing*/
,'S52136H'  /*Nondisplaced fracture of neck of unspecified radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52136J'  /*Nondisplaced fracture of neck of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52136K'  /*Nondisplaced fracture of neck of unspecified radius, subsequent encounter for closed fracture with nonunion*/
,'S52136M'  /*Nondisplaced fracture of neck of unspecified radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52136N'  /*Nondisplaced fracture of neck of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52136P'  /*Nondisplaced fracture of neck of unspecified radius, subsequent encounter for closed fracture with malunion*/
,'S52136Q'  /*Nondisplaced fracture of neck of unspecified radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52136R'  /*Nondisplaced fracture of neck of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52136S'  /*Nondisplaced fracture of neck of unspecified radius, sequela*/
,'S52181D'  /*Other fracture of upper end of right radius, subsequent encounter for closed fracture with routine healing*/
,'S52181E'  /*Other fracture of upper end of right radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52181F'  /*Other fracture of upper end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52181G'  /*Other fracture of upper end of right radius, subsequent encounter for closed fracture with delayed healing*/
,'S52181H'  /*Other fracture of upper end of right radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52181J'  /*Other fracture of upper end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52181K'  /*Other fracture of upper end of right radius, subsequent encounter for closed fracture with nonunion*/
,'S52181M'  /*Other fracture of upper end of right radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52181N'  /*Other fracture of upper end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52181P'  /*Other fracture of upper end of right radius, subsequent encounter for closed fracture with malunion*/
,'S52181Q'  /*Other fracture of upper end of right radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52181R'  /*Other fracture of upper end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52181S'  /*Other fracture of upper end of right radius, sequela*/
,'S52182D'  /*Other fracture of upper end of left radius, subsequent encounter for closed fracture with routine healing*/
,'S52182E'  /*Other fracture of upper end of left radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52182F'  /*Other fracture of upper end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52182G'  /*Other fracture of upper end of left radius, subsequent encounter for closed fracture with delayed healing*/
,'S52182H'  /*Other fracture of upper end of left radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52182J'  /*Other fracture of upper end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52182K'  /*Other fracture of upper end of left radius, subsequent encounter for closed fracture with nonunion*/
,'S52182M'  /*Other fracture of upper end of left radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52182N'  /*Other fracture of upper end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52182P'  /*Other fracture of upper end of left radius, subsequent encounter for closed fracture with malunion*/
,'S52182Q'  /*Other fracture of upper end of left radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52182R'  /*Other fracture of upper end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52182S'  /*Other fracture of upper end of left radius, sequela*/
,'S52189D'  /*Other fracture of upper end of unspecified radius, subsequent encounter for closed fracture with routine healing*/
,'S52189E'  /*Other fracture of upper end of unspecified radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52189F'  /*Other fracture of upper end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52189G'  /*Other fracture of upper end of unspecified radius, subsequent encounter for closed fracture with delayed healing*/
,'S52189H'  /*Other fracture of upper end of unspecified radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52189J'  /*Other fracture of upper end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52189K'  /*Other fracture of upper end of unspecified radius, subsequent encounter for closed fracture with nonunion*/
,'S52189M'  /*Other fracture of upper end of unspecified radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52189N'  /*Other fracture of upper end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52189P'  /*Other fracture of upper end of unspecified radius, subsequent encounter for closed fracture with malunion*/
,'S52189Q'  /*Other fracture of upper end of unspecified radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52189R'  /*Other fracture of upper end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52189S'  /*Other fracture of upper end of unspecified radius, sequela*/
,'S52201D'  /*Unspecified fracture of shaft of right ulna, subsequent encounter for closed fracture with routine healing*/
,'S52201E'  /*Unspecified fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52201F'  /*Unspecified fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52201G'  /*Unspecified fracture of shaft of right ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52201H'  /*Unspecified fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52201J'  /*Unspecified fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52201K'  /*Unspecified fracture of shaft of right ulna, subsequent encounter for closed fracture with nonunion*/
,'S52201M'  /*Unspecified fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52201N'  /*Unspecified fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52201P'  /*Unspecified fracture of shaft of right ulna, subsequent encounter for closed fracture with malunion*/
,'S52201Q'  /*Unspecified fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52201R'  /*Unspecified fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52201S'  /*Unspecified fracture of shaft of right ulna, sequela*/
,'S52202D'  /*Unspecified fracture of shaft of left ulna, subsequent encounter for closed fracture with routine healing*/
,'S52202E'  /*Unspecified fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52202F'  /*Unspecified fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52202G'  /*Unspecified fracture of shaft of left ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52202H'  /*Unspecified fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52202J'  /*Unspecified fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52202K'  /*Unspecified fracture of shaft of left ulna, subsequent encounter for closed fracture with nonunion*/
,'S52202M'  /*Unspecified fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52202N'  /*Unspecified fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52202P'  /*Unspecified fracture of shaft of left ulna, subsequent encounter for closed fracture with malunion*/
,'S52202Q'  /*Unspecified fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52202R'  /*Unspecified fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52202S'  /*Unspecified fracture of shaft of left ulna, sequela*/
,'S52209D'  /*Unspecified fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with routine healing*/
,'S52209E'  /*Unspecified fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52209F'  /*Unspecified fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52209G'  /*Unspecified fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52209H'  /*Unspecified fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52209J'  /*Unspecified fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52209K'  /*Unspecified fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with nonunion*/
,'S52209M'  /*Unspecified fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52209N'  /*Unspecified fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52209P'  /*Unspecified fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with malunion*/
,'S52209Q'  /*Unspecified fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52209R'  /*Unspecified fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52209S'  /*Unspecified fracture of shaft of unspecified ulna, sequela*/
,'S52211D'  /*Greenstick fracture of shaft of right ulna, subsequent encounter for fracture with routine healing*/
,'S52211G'  /*Greenstick fracture of shaft of right ulna, subsequent encounter for fracture with delayed healing*/
,'S52211K'  /*Greenstick fracture of shaft of right ulna, subsequent encounter for fracture with nonunion*/
,'S52211P'  /*Greenstick fracture of shaft of right ulna, subsequent encounter for fracture with malunion*/
,'S52211S'  /*Greenstick fracture of shaft of right ulna, sequela*/
,'S52212D'  /*Greenstick fracture of shaft of left ulna, subsequent encounter for fracture with routine healing*/
,'S52212G'  /*Greenstick fracture of shaft of left ulna, subsequent encounter for fracture with delayed healing*/
,'S52212K'  /*Greenstick fracture of shaft of left ulna, subsequent encounter for fracture with nonunion*/
,'S52212P'  /*Greenstick fracture of shaft of left ulna, subsequent encounter for fracture with malunion*/
,'S52212S'  /*Greenstick fracture of shaft of left ulna, sequela*/
,'S52219D'  /*Greenstick fracture of shaft of unspecified ulna, subsequent encounter for fracture with routine healing*/
,'S52219G'  /*Greenstick fracture of shaft of unspecified ulna, subsequent encounter for fracture with delayed healing*/
,'S52219K'  /*Greenstick fracture of shaft of unspecified ulna, subsequent encounter for fracture with nonunion*/
,'S52219P'  /*Greenstick fracture of shaft of unspecified ulna, subsequent encounter for fracture with malunion*/
,'S52219S'  /*Greenstick fracture of shaft of unspecified ulna, sequela*/
,'S52221D'  /*Displaced transverse fracture of shaft of right ulna, subsequent encounter for closed fracture with routine healing*/
,'S52221E'  /*Displaced transverse fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52221F'  /*Displaced transverse fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52221G'  /*Displaced transverse fracture of shaft of right ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52221H'  /*Displaced transverse fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52221J'  /*Displaced transverse fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52221K'  /*Displaced transverse fracture of shaft of right ulna, subsequent encounter for closed fracture with nonunion*/
,'S52221M'  /*Displaced transverse fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52221N'  /*Displaced transverse fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52221P'  /*Displaced transverse fracture of shaft of right ulna, subsequent encounter for closed fracture with malunion*/
,'S52221Q'  /*Displaced transverse fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52221R'  /*Displaced transverse fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52221S'  /*Displaced transverse fracture of shaft of right ulna, sequela*/
,'S52222D'  /*Displaced transverse fracture of shaft of left ulna, subsequent encounter for closed fracture with routine healing*/
,'S52222E'  /*Displaced transverse fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52222F'  /*Displaced transverse fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52222G'  /*Displaced transverse fracture of shaft of left ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52222H'  /*Displaced transverse fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52222J'  /*Displaced transverse fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52222K'  /*Displaced transverse fracture of shaft of left ulna, subsequent encounter for closed fracture with nonunion*/
,'S52222M'  /*Displaced transverse fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52222N'  /*Displaced transverse fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52222P'  /*Displaced transverse fracture of shaft of left ulna, subsequent encounter for closed fracture with malunion*/
,'S52222Q'  /*Displaced transverse fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52222R'  /*Displaced transverse fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52222S'  /*Displaced transverse fracture of shaft of left ulna, sequela*/
,'S52223D'  /*Displaced transverse fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with routine healing*/
,'S52223E'  /*Displaced transverse fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52223F'  /*Displaced transverse fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52223G'  /*Displaced transverse fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52223H'  /*Displaced transverse fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52223J'  /*Displaced transverse fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52223K'  /*Displaced transverse fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with nonunion*/
,'S52223M'  /*Displaced transverse fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52223N'  /*Displaced transverse fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52223P'  /*Displaced transverse fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with malunion*/
,'S52223Q'  /*Displaced transverse fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52223R'  /*Displaced transverse fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52223S'  /*Displaced transverse fracture of shaft of unspecified ulna, sequela*/
,'S52224D'  /*Nondisplaced transverse fracture of shaft of right ulna, subsequent encounter for closed fracture with routine healing*/
,'S52224E'  /*Nondisplaced transverse fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52224F'  /*Nondisplaced transverse fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52224G'  /*Nondisplaced transverse fracture of shaft of right ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52224H'  /*Nondisplaced transverse fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52224J'  /*Nondisplaced transverse fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52224K'  /*Nondisplaced transverse fracture of shaft of right ulna, subsequent encounter for closed fracture with nonunion*/
,'S52224M'  /*Nondisplaced transverse fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52224N'  /*Nondisplaced transverse fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52224P'  /*Nondisplaced transverse fracture of shaft of right ulna, subsequent encounter for closed fracture with malunion*/
,'S52224Q'  /*Nondisplaced transverse fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52224R'  /*Nondisplaced transverse fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52224S'  /*Nondisplaced transverse fracture of shaft of right ulna, sequela*/
,'S52225D'  /*Nondisplaced transverse fracture of shaft of left ulna, subsequent encounter for closed fracture with routine healing*/
,'S52225E'  /*Nondisplaced transverse fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52225F'  /*Nondisplaced transverse fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52225G'  /*Nondisplaced transverse fracture of shaft of left ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52225H'  /*Nondisplaced transverse fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52225J'  /*Nondisplaced transverse fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52225K'  /*Nondisplaced transverse fracture of shaft of left ulna, subsequent encounter for closed fracture with nonunion*/
,'S52225M'  /*Nondisplaced transverse fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52225N'  /*Nondisplaced transverse fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52225P'  /*Nondisplaced transverse fracture of shaft of left ulna, subsequent encounter for closed fracture with malunion*/
,'S52225Q'  /*Nondisplaced transverse fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52225R'  /*Nondisplaced transverse fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52225S'  /*Nondisplaced transverse fracture of shaft of left ulna, sequela*/
,'S52226D'  /*Nondisplaced transverse fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with routine healing*/
,'S52226E'  /*Nondisplaced transverse fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52226F'  /*Nondisplaced transverse fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52226G'  /*Nondisplaced transverse fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52226H'  /*Nondisplaced transverse fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52226J'  /*Nondisplaced transverse fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52226K'  /*Nondisplaced transverse fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with nonunion*/
,'S52226M'  /*Nondisplaced transverse fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52226N'  /*Nondisplaced transverse fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52226P'  /*Nondisplaced transverse fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with malunion*/
,'S52226Q'  /*Nondisplaced transverse fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52226R'  /*Nondisplaced transverse fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52226S'  /*Nondisplaced transverse fracture of shaft of unspecified ulna, sequela*/
,'S52231D'  /*Displaced oblique fracture of shaft of right ulna, subsequent encounter for closed fracture with routine healing*/
,'S52231E'  /*Displaced oblique fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52231F'  /*Displaced oblique fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52231G'  /*Displaced oblique fracture of shaft of right ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52231H'  /*Displaced oblique fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52231J'  /*Displaced oblique fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52231K'  /*Displaced oblique fracture of shaft of right ulna, subsequent encounter for closed fracture with nonunion*/
,'S52231M'  /*Displaced oblique fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52231N'  /*Displaced oblique fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52231P'  /*Displaced oblique fracture of shaft of right ulna, subsequent encounter for closed fracture with malunion*/
,'S52231Q'  /*Displaced oblique fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52231R'  /*Displaced oblique fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52231S'  /*Displaced oblique fracture of shaft of right ulna, sequela*/
,'S52232D'  /*Displaced oblique fracture of shaft of left ulna, subsequent encounter for closed fracture with routine healing*/
,'S52232E'  /*Displaced oblique fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52232F'  /*Displaced oblique fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52232G'  /*Displaced oblique fracture of shaft of left ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52232H'  /*Displaced oblique fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52232J'  /*Displaced oblique fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52232K'  /*Displaced oblique fracture of shaft of left ulna, subsequent encounter for closed fracture with nonunion*/
,'S52232M'  /*Displaced oblique fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52232N'  /*Displaced oblique fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52232P'  /*Displaced oblique fracture of shaft of left ulna, subsequent encounter for closed fracture with malunion*/
,'S52232Q'  /*Displaced oblique fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52232R'  /*Displaced oblique fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52232S'  /*Displaced oblique fracture of shaft of left ulna, sequela*/
,'S52233D'  /*Displaced oblique fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with routine healing*/
,'S52233E'  /*Displaced oblique fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52233F'  /*Displaced oblique fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52233G'  /*Displaced oblique fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52233H'  /*Displaced oblique fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52233J'  /*Displaced oblique fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52233K'  /*Displaced oblique fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with nonunion*/
,'S52233M'  /*Displaced oblique fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52233N'  /*Displaced oblique fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52233P'  /*Displaced oblique fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with malunion*/
,'S52233Q'  /*Displaced oblique fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52233R'  /*Displaced oblique fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52233S'  /*Displaced oblique fracture of shaft of unspecified ulna, sequela*/
,'S52234D'  /*Nondisplaced oblique fracture of shaft of right ulna, subsequent encounter for closed fracture with routine healing*/
,'S52234E'  /*Nondisplaced oblique fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52234F'  /*Nondisplaced oblique fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52234G'  /*Nondisplaced oblique fracture of shaft of right ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52234H'  /*Nondisplaced oblique fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52234J'  /*Nondisplaced oblique fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52234K'  /*Nondisplaced oblique fracture of shaft of right ulna, subsequent encounter for closed fracture with nonunion*/
,'S52234M'  /*Nondisplaced oblique fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52234N'  /*Nondisplaced oblique fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52234P'  /*Nondisplaced oblique fracture of shaft of right ulna, subsequent encounter for closed fracture with malunion*/
,'S52234Q'  /*Nondisplaced oblique fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52234R'  /*Nondisplaced oblique fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52234S'  /*Nondisplaced oblique fracture of shaft of right ulna, sequela*/
,'S52235D'  /*Nondisplaced oblique fracture of shaft of left ulna, subsequent encounter for closed fracture with routine healing*/
,'S52235E'  /*Nondisplaced oblique fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52235F'  /*Nondisplaced oblique fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52235G'  /*Nondisplaced oblique fracture of shaft of left ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52235H'  /*Nondisplaced oblique fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52235J'  /*Nondisplaced oblique fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52235K'  /*Nondisplaced oblique fracture of shaft of left ulna, subsequent encounter for closed fracture with nonunion*/
,'S52235M'  /*Nondisplaced oblique fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52235N'  /*Nondisplaced oblique fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52235P'  /*Nondisplaced oblique fracture of shaft of left ulna, subsequent encounter for closed fracture with malunion*/
,'S52235Q'  /*Nondisplaced oblique fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52235R'  /*Nondisplaced oblique fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52235S'  /*Nondisplaced oblique fracture of shaft of left ulna, sequela*/
,'S52236D'  /*Nondisplaced oblique fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with routine healing*/
,'S52236E'  /*Nondisplaced oblique fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52236F'  /*Nondisplaced oblique fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52236G'  /*Nondisplaced oblique fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52236H'  /*Nondisplaced oblique fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52236J'  /*Nondisplaced oblique fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52236K'  /*Nondisplaced oblique fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with nonunion*/
,'S52236M'  /*Nondisplaced oblique fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52236N'  /*Nondisplaced oblique fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52236P'  /*Nondisplaced oblique fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with malunion*/
,'S52236Q'  /*Nondisplaced oblique fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52236R'  /*Nondisplaced oblique fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52236S'  /*Nondisplaced oblique fracture of shaft of unspecified ulna, sequela*/
,'S52241D'  /*Displaced spiral fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with routine healing*/
,'S52241E'  /*Displaced spiral fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52241F'  /*Displaced spiral fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52241G'  /*Displaced spiral fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with delayed healing*/
,'S52241H'  /*Displaced spiral fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52241J'  /*Displaced spiral fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52241K'  /*Displaced spiral fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with nonunion*/
,'S52241M'  /*Displaced spiral fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52241N'  /*Displaced spiral fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52241P'  /*Displaced spiral fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with malunion*/
,'S52241Q'  /*Displaced spiral fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52241R'  /*Displaced spiral fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52241S'  /*Displaced spiral fracture of shaft of ulna, right arm, sequela*/
,'S52242D'  /*Displaced spiral fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with routine healing*/
,'S52242E'  /*Displaced spiral fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52242F'  /*Displaced spiral fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52242G'  /*Displaced spiral fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with delayed healing*/
,'S52242H'  /*Displaced spiral fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52242J'  /*Displaced spiral fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52242K'  /*Displaced spiral fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with nonunion*/
,'S52242M'  /*Displaced spiral fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52242N'  /*Displaced spiral fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52242P'  /*Displaced spiral fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with malunion*/
,'S52242Q'  /*Displaced spiral fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52242R'  /*Displaced spiral fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52242S'  /*Displaced spiral fracture of shaft of ulna, left arm, sequela*/
,'S52243D'  /*Displaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with routine healing*/
,'S52243E'  /*Displaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52243F'  /*Displaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52243G'  /*Displaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with delayed healing*/
,'S52243H'  /*Displaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52243J'  /*Displaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52243K'  /*Displaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with nonunion*/
,'S52243M'  /*Displaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52243N'  /*Displaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52243P'  /*Displaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with malunion*/
,'S52243Q'  /*Displaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52243R'  /*Displaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52243S'  /*Displaced spiral fracture of shaft of ulna, unspecified arm, sequela*/
,'S52244D'  /*Nondisplaced spiral fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with routine healing*/
,'S52244E'  /*Nondisplaced spiral fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52244F'  /*Nondisplaced spiral fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52244G'  /*Nondisplaced spiral fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with delayed healing*/
,'S52244H'  /*Nondisplaced spiral fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52244J'  /*Nondisplaced spiral fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52244K'  /*Nondisplaced spiral fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with nonunion*/
,'S52244M'  /*Nondisplaced spiral fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52244N'  /*Nondisplaced spiral fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52244P'  /*Nondisplaced spiral fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with malunion*/
,'S52244Q'  /*Nondisplaced spiral fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52244R'  /*Nondisplaced spiral fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52244S'  /*Nondisplaced spiral fracture of shaft of ulna, right arm, sequela*/
,'S52245D'  /*Nondisplaced spiral fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with routine healing*/
,'S52245E'  /*Nondisplaced spiral fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52245F'  /*Nondisplaced spiral fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52245G'  /*Nondisplaced spiral fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with delayed healing*/
,'S52245H'  /*Nondisplaced spiral fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52245J'  /*Nondisplaced spiral fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52245K'  /*Nondisplaced spiral fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with nonunion*/
,'S52245M'  /*Nondisplaced spiral fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52245N'  /*Nondisplaced spiral fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52245P'  /*Nondisplaced spiral fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with malunion*/
,'S52245Q'  /*Nondisplaced spiral fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52245R'  /*Nondisplaced spiral fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52245S'  /*Nondisplaced spiral fracture of shaft of ulna, left arm, sequela*/
,'S52246D'  /*Nondisplaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with routine healing*/
,'S52246E'  /*Nondisplaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52246F'  /*Nondisplaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52246G'  /*Nondisplaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with delayed healing*/
,'S52246H'  /*Nondisplaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52246J'  /*Nondisplaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52246K'  /*Nondisplaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with nonunion*/
,'S52246M'  /*Nondisplaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52246N'  /*Nondisplaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52246P'  /*Nondisplaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with malunion*/
,'S52246Q'  /*Nondisplaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52246R'  /*Nondisplaced spiral fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52246S'  /*Nondisplaced spiral fracture of shaft of ulna, unspecified arm, sequela*/
,'S52251D'  /*Displaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with routine healing*/
,'S52251E'  /*Displaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52251F'  /*Displaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52251G'  /*Displaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with delayed healing*/
,'S52251H'  /*Displaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52251J'  /*Displaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52251K'  /*Displaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with nonunion*/
,'S52251M'  /*Displaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52251N'  /*Displaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52251P'  /*Displaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with malunion*/
,'S52251Q'  /*Displaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52251R'  /*Displaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52251S'  /*Displaced comminuted fracture of shaft of ulna, right arm, sequela*/
,'S52252D'  /*Displaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with routine healing*/
,'S52252E'  /*Displaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52252F'  /*Displaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52252G'  /*Displaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with delayed healing*/
,'S52252H'  /*Displaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52252J'  /*Displaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52252K'  /*Displaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with nonunion*/
,'S52252M'  /*Displaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52252N'  /*Displaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52252P'  /*Displaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with malunion*/
,'S52252Q'  /*Displaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52252R'  /*Displaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52252S'  /*Displaced comminuted fracture of shaft of ulna, left arm, sequela*/
,'S52253D'  /*Displaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with routine healing*/
,'S52253E'  /*Displaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52253F'  /*Displaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52253G'  /*Displaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with delayed healing*/
,'S52253H'  /*Displaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52253J'  /*Displaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52253K'  /*Displaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with nonunion*/
,'S52253M'  /*Displaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52253N'  /*Displaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52253P'  /*Displaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with malunion*/
,'S52253Q'  /*Displaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52253R'  /*Displaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52253S'  /*Displaced comminuted fracture of shaft of ulna, unspecified arm, sequela*/
,'S52254D'  /*Nondisplaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with routine healing*/
,'S52254E'  /*Nondisplaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52254F'  /*Nondisplaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52254G'  /*Nondisplaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with delayed healing*/
,'S52254H'  /*Nondisplaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52254J'  /*Nondisplaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52254K'  /*Nondisplaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with nonunion*/
,'S52254M'  /*Nondisplaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52254N'  /*Nondisplaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52254P'  /*Nondisplaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with malunion*/
,'S52254Q'  /*Nondisplaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52254R'  /*Nondisplaced comminuted fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52254S'  /*Nondisplaced comminuted fracture of shaft of ulna, right arm, sequela*/
,'S52255D'  /*Nondisplaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with routine healing*/
,'S52255E'  /*Nondisplaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52255F'  /*Nondisplaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52255G'  /*Nondisplaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with delayed healing*/
,'S52255H'  /*Nondisplaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52255J'  /*Nondisplaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52255K'  /*Nondisplaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with nonunion*/
,'S52255M'  /*Nondisplaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52255N'  /*Nondisplaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52255P'  /*Nondisplaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with malunion*/
,'S52255Q'  /*Nondisplaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52255R'  /*Nondisplaced comminuted fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52255S'  /*Nondisplaced comminuted fracture of shaft of ulna, left arm, sequela*/
,'S52256D'  /*Nondisplaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with routine healing*/
,'S52256E'  /*Nondisplaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52256F'  /*Nondisplaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52256G'  /*Nondisplaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with delayed healing*/
,'S52256H'  /*Nondisplaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52256J'  /*Nondisplaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52256K'  /*Nondisplaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with nonunion*/
,'S52256M'  /*Nondisplaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52256N'  /*Nondisplaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52256P'  /*Nondisplaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with malunion*/
,'S52256Q'  /*Nondisplaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52256R'  /*Nondisplaced comminuted fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52256S'  /*Nondisplaced comminuted fracture of shaft of ulna, unspecified arm, sequela*/
,'S52261D'  /*Displaced segmental fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with routine healing*/
,'S52261E'  /*Displaced segmental fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52261F'  /*Displaced segmental fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52261G'  /*Displaced segmental fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with delayed healing*/
,'S52261H'  /*Displaced segmental fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52261J'  /*Displaced segmental fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52261K'  /*Displaced segmental fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with nonunion*/
,'S52261M'  /*Displaced segmental fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52261N'  /*Displaced segmental fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52261P'  /*Displaced segmental fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with malunion*/
,'S52261Q'  /*Displaced segmental fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52261R'  /*Displaced segmental fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52261S'  /*Displaced segmental fracture of shaft of ulna, right arm, sequela*/
,'S52262D'  /*Displaced segmental fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with routine healing*/
,'S52262E'  /*Displaced segmental fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52262F'  /*Displaced segmental fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52262G'  /*Displaced segmental fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with delayed healing*/
,'S52262H'  /*Displaced segmental fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52262J'  /*Displaced segmental fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52262K'  /*Displaced segmental fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with nonunion*/
,'S52262M'  /*Displaced segmental fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52262N'  /*Displaced segmental fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52262P'  /*Displaced segmental fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with malunion*/
,'S52262Q'  /*Displaced segmental fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52262R'  /*Displaced segmental fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52262S'  /*Displaced segmental fracture of shaft of ulna, left arm, sequela*/
,'S52263D'  /*Displaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with routine healing*/
,'S52263E'  /*Displaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52263F'  /*Displaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52263G'  /*Displaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with delayed healing*/
,'S52263H'  /*Displaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52263J'  /*Displaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52263K'  /*Displaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with nonunion*/
,'S52263M'  /*Displaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52263N'  /*Displaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52263P'  /*Displaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with malunion*/
,'S52263Q'  /*Displaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52263R'  /*Displaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52263S'  /*Displaced segmental fracture of shaft of ulna, unspecified arm, sequela*/
,'S52264D'  /*Nondisplaced segmental fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with routine healing*/
,'S52264E'  /*Nondisplaced segmental fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52264F'  /*Nondisplaced segmental fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52264G'  /*Nondisplaced segmental fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with delayed healing*/
,'S52264H'  /*Nondisplaced segmental fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52264J'  /*Nondisplaced segmental fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52264K'  /*Nondisplaced segmental fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with nonunion*/
,'S52264M'  /*Nondisplaced segmental fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52264N'  /*Nondisplaced segmental fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52264P'  /*Nondisplaced segmental fracture of shaft of ulna, right arm, subsequent encounter for closed fracture with malunion*/
,'S52264Q'  /*Nondisplaced segmental fracture of shaft of ulna, right arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52264R'  /*Nondisplaced segmental fracture of shaft of ulna, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52264S'  /*Nondisplaced segmental fracture of shaft of ulna, right arm, sequela*/
,'S52265D'  /*Nondisplaced segmental fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with routine healing*/
,'S52265E'  /*Nondisplaced segmental fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52265F'  /*Nondisplaced segmental fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52265G'  /*Nondisplaced segmental fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with delayed healing*/
,'S52265H'  /*Nondisplaced segmental fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52265J'  /*Nondisplaced segmental fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52265K'  /*Nondisplaced segmental fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with nonunion*/
,'S52265M'  /*Nondisplaced segmental fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52265N'  /*Nondisplaced segmental fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52265P'  /*Nondisplaced segmental fracture of shaft of ulna, left arm, subsequent encounter for closed fracture with malunion*/
,'S52265Q'  /*Nondisplaced segmental fracture of shaft of ulna, left arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52265R'  /*Nondisplaced segmental fracture of shaft of ulna, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52265S'  /*Nondisplaced segmental fracture of shaft of ulna, left arm, sequela*/
,'S52266D'  /*Nondisplaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with routine healing*/
,'S52266E'  /*Nondisplaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52266F'  /*Nondisplaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52266G'  /*Nondisplaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with delayed healing*/
,'S52266H'  /*Nondisplaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52266J'  /*Nondisplaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52266K'  /*Nondisplaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with nonunion*/
,'S52266M'  /*Nondisplaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52266N'  /*Nondisplaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52266P'  /*Nondisplaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for closed fracture with malunion*/
,'S52266Q'  /*Nondisplaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52266R'  /*Nondisplaced segmental fracture of shaft of ulna, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52266S'  /*Nondisplaced segmental fracture of shaft of ulna, unspecified arm, sequela*/
,'S52271D'  /*Monteggia's fracture of right ulna, subsequent encounter for closed fracture with routine healing*/
,'S52271E'  /*Monteggia's fracture of right ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52271F'  /*Monteggia's fracture of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52271G'  /*Monteggia's fracture of right ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52271H'  /*Monteggia's fracture of right ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52271J'  /*Monteggia's fracture of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52271K'  /*Monteggia's fracture of right ulna, subsequent encounter for closed fracture with nonunion*/
,'S52271M'  /*Monteggia's fracture of right ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52271N'  /*Monteggia's fracture of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52271P'  /*Monteggia's fracture of right ulna, subsequent encounter for closed fracture with malunion*/
,'S52271Q'  /*Monteggia's fracture of right ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52271R'  /*Monteggia's fracture of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52271S'  /*Monteggia's fracture of right ulna, sequela*/
,'S52272D'  /*Monteggia's fracture of left ulna, subsequent encounter for closed fracture with routine healing*/
,'S52272E'  /*Monteggia's fracture of left ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52272F'  /*Monteggia's fracture of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52272G'  /*Monteggia's fracture of left ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52272H'  /*Monteggia's fracture of left ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52272J'  /*Monteggia's fracture of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52272K'  /*Monteggia's fracture of left ulna, subsequent encounter for closed fracture with nonunion*/
,'S52272M'  /*Monteggia's fracture of left ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52272N'  /*Monteggia's fracture of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52272P'  /*Monteggia's fracture of left ulna, subsequent encounter for closed fracture with malunion*/
,'S52272Q'  /*Monteggia's fracture of left ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52272R'  /*Monteggia's fracture of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52272S'  /*Monteggia's fracture of left ulna, sequela*/
,'S52279D'  /*Monteggia's fracture of unspecified ulna, subsequent encounter for closed fracture with routine healing*/
,'S52279E'  /*Monteggia's fracture of unspecified ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52279F'  /*Monteggia's fracture of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52279G'  /*Monteggia's fracture of unspecified ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52279H'  /*Monteggia's fracture of unspecified ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52279J'  /*Monteggia's fracture of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52279K'  /*Monteggia's fracture of unspecified ulna, subsequent encounter for closed fracture with nonunion*/
,'S52279M'  /*Monteggia's fracture of unspecified ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52279N'  /*Monteggia's fracture of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52279P'  /*Monteggia's fracture of unspecified ulna, subsequent encounter for closed fracture with malunion*/
,'S52279Q'  /*Monteggia's fracture of unspecified ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52279R'  /*Monteggia's fracture of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52279S'  /*Monteggia's fracture of unspecified ulna, sequela*/
,'S52281D'  /*Bent bone of right ulna, subsequent encounter for closed fracture with routine healing*/
,'S52281E'  /*Bent bone of right ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52281F'  /*Bent bone of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52281G'  /*Bent bone of right ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52281H'  /*Bent bone of right ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52281J'  /*Bent bone of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52281K'  /*Bent bone of right ulna, subsequent encounter for closed fracture with nonunion*/
,'S52281M'  /*Bent bone of right ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52281N'  /*Bent bone of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52281P'  /*Bent bone of right ulna, subsequent encounter for closed fracture with malunion*/
,'S52281Q'  /*Bent bone of right ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52281R'  /*Bent bone of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52281S'  /*Bent bone of right ulna, sequela*/
,'S52282D'  /*Bent bone of left ulna, subsequent encounter for closed fracture with routine healing*/
,'S52282E'  /*Bent bone of left ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52282F'  /*Bent bone of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52282G'  /*Bent bone of left ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52282H'  /*Bent bone of left ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52282J'  /*Bent bone of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52282K'  /*Bent bone of left ulna, subsequent encounter for closed fracture with nonunion*/
,'S52282M'  /*Bent bone of left ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52282N'  /*Bent bone of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52282P'  /*Bent bone of left ulna, subsequent encounter for closed fracture with malunion*/
,'S52282Q'  /*Bent bone of left ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52282R'  /*Bent bone of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52282S'  /*Bent bone of left ulna, sequela*/
,'S52283D'  /*Bent bone of unspecified ulna, subsequent encounter for closed fracture with routine healing*/
,'S52283E'  /*Bent bone of unspecified ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52283F'  /*Bent bone of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52283G'  /*Bent bone of unspecified ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52283H'  /*Bent bone of unspecified ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52283J'  /*Bent bone of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52283K'  /*Bent bone of unspecified ulna, subsequent encounter for closed fracture with nonunion*/
,'S52283M'  /*Bent bone of unspecified ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52283N'  /*Bent bone of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52283P'  /*Bent bone of unspecified ulna, subsequent encounter for closed fracture with malunion*/
,'S52283Q'  /*Bent bone of unspecified ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52283R'  /*Bent bone of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52283S'  /*Bent bone of unspecified ulna, sequela*/
,'S52291D'  /*Other fracture of shaft of right ulna, subsequent encounter for closed fracture with routine healing*/
,'S52291E'  /*Other fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52291F'  /*Other fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52291G'  /*Other fracture of shaft of right ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52291H'  /*Other fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52291J'  /*Other fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52291K'  /*Other fracture of shaft of right ulna, subsequent encounter for closed fracture with nonunion*/
,'S52291M'  /*Other fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52291N'  /*Other fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52291P'  /*Other fracture of shaft of right ulna, subsequent encounter for closed fracture with malunion*/
,'S52291Q'  /*Other fracture of shaft of right ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52291R'  /*Other fracture of shaft of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52291S'  /*Other fracture of shaft of right ulna, sequela*/
,'S52292D'  /*Other fracture of shaft of left ulna, subsequent encounter for closed fracture with routine healing*/
,'S52292E'  /*Other fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52292F'  /*Other fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52292G'  /*Other fracture of shaft of left ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52292H'  /*Other fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52292J'  /*Other fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52292K'  /*Other fracture of shaft of left ulna, subsequent encounter for closed fracture with nonunion*/
,'S52292M'  /*Other fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52292N'  /*Other fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52292P'  /*Other fracture of shaft of left ulna, subsequent encounter for closed fracture with malunion*/
,'S52292Q'  /*Other fracture of shaft of left ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52292R'  /*Other fracture of shaft of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52292S'  /*Other fracture of shaft of left ulna, sequela*/
,'S52299D'  /*Other fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with routine healing*/
,'S52299E'  /*Other fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52299F'  /*Other fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52299G'  /*Other fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52299H'  /*Other fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52299J'  /*Other fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52299K'  /*Other fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with nonunion*/
,'S52299M'  /*Other fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52299N'  /*Other fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52299P'  /*Other fracture of shaft of unspecified ulna, subsequent encounter for closed fracture with malunion*/
,'S52299Q'  /*Other fracture of shaft of unspecified ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52299R'  /*Other fracture of shaft of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52299S'  /*Other fracture of shaft of unspecified ulna, sequela*/
,'S52301D'  /*Unspecified fracture of shaft of right radius, subsequent encounter for closed fracture with routine healing*/
,'S52301E'  /*Unspecified fracture of shaft of right radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52301F'  /*Unspecified fracture of shaft of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52301G'  /*Unspecified fracture of shaft of right radius, subsequent encounter for closed fracture with delayed healing*/
,'S52301H'  /*Unspecified fracture of shaft of right radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52301J'  /*Unspecified fracture of shaft of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52301K'  /*Unspecified fracture of shaft of right radius, subsequent encounter for closed fracture with nonunion*/
,'S52301M'  /*Unspecified fracture of shaft of right radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52301N'  /*Unspecified fracture of shaft of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52301P'  /*Unspecified fracture of shaft of right radius, subsequent encounter for closed fracture with malunion*/
,'S52301Q'  /*Unspecified fracture of shaft of right radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52301R'  /*Unspecified fracture of shaft of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52301S'  /*Unspecified fracture of shaft of right radius, sequela*/
,'S52302D'  /*Unspecified fracture of shaft of left radius, subsequent encounter for closed fracture with routine healing*/
,'S52302E'  /*Unspecified fracture of shaft of left radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52302F'  /*Unspecified fracture of shaft of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52302G'  /*Unspecified fracture of shaft of left radius, subsequent encounter for closed fracture with delayed healing*/
,'S52302H'  /*Unspecified fracture of shaft of left radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52302J'  /*Unspecified fracture of shaft of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52302K'  /*Unspecified fracture of shaft of left radius, subsequent encounter for closed fracture with nonunion*/
,'S52302M'  /*Unspecified fracture of shaft of left radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52302N'  /*Unspecified fracture of shaft of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52302P'  /*Unspecified fracture of shaft of left radius, subsequent encounter for closed fracture with malunion*/
,'S52302Q'  /*Unspecified fracture of shaft of left radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52302R'  /*Unspecified fracture of shaft of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52302S'  /*Unspecified fracture of shaft of left radius, sequela*/
,'S52309D'  /*Unspecified fracture of shaft of unspecified radius, subsequent encounter for closed fracture with routine healing*/
,'S52309E'  /*Unspecified fracture of shaft of unspecified radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52309F'  /*Unspecified fracture of shaft of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52309G'  /*Unspecified fracture of shaft of unspecified radius, subsequent encounter for closed fracture with delayed healing*/
,'S52309H'  /*Unspecified fracture of shaft of unspecified radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52309J'  /*Unspecified fracture of shaft of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52309K'  /*Unspecified fracture of shaft of unspecified radius, subsequent encounter for closed fracture with nonunion*/
,'S52309M'  /*Unspecified fracture of shaft of unspecified radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52309N'  /*Unspecified fracture of shaft of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52309P'  /*Unspecified fracture of shaft of unspecified radius, subsequent encounter for closed fracture with malunion*/
,'S52309Q'  /*Unspecified fracture of shaft of unspecified radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52309R'  /*Unspecified fracture of shaft of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52309S'  /*Unspecified fracture of shaft of unspecified radius, sequela*/
,'S52311D'  /*Greenstick fracture of shaft of radius, right arm, subsequent encounter for fracture with routine healing*/
,'S52311G'  /*Greenstick fracture of shaft of radius, right arm, subsequent encounter for fracture with delayed healing*/
,'S52311K'  /*Greenstick fracture of shaft of radius, right arm, subsequent encounter for fracture with nonunion*/
,'S52311P'  /*Greenstick fracture of shaft of radius, right arm, subsequent encounter for fracture with malunion*/
,'S52311S'  /*Greenstick fracture of shaft of radius, right arm, sequela*/
,'S52312D'  /*Greenstick fracture of shaft of radius, left arm, subsequent encounter for fracture with routine healing*/
,'S52312G'  /*Greenstick fracture of shaft of radius, left arm, subsequent encounter for fracture with delayed healing*/
,'S52312K'  /*Greenstick fracture of shaft of radius, left arm, subsequent encounter for fracture with nonunion*/
,'S52312P'  /*Greenstick fracture of shaft of radius, left arm, subsequent encounter for fracture with malunion*/
,'S52312S'  /*Greenstick fracture of shaft of radius, left arm, sequela*/
,'S52319D'  /*Greenstick fracture of shaft of radius, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S52319G'  /*Greenstick fracture of shaft of radius, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S52319K'  /*Greenstick fracture of shaft of radius, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S52319P'  /*Greenstick fracture of shaft of radius, unspecified arm, subsequent encounter for fracture with malunion*/
,'S52319S'  /*Greenstick fracture of shaft of radius, unspecified arm, sequela*/
,'S52321D'  /*Displaced transverse fracture of shaft of right radius, subsequent encounter for closed fracture with routine healing*/
,'S52321E'  /*Displaced transverse fracture of shaft of right radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52321F'  /*Displaced transverse fracture of shaft of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52321G'  /*Displaced transverse fracture of shaft of right radius, subsequent encounter for closed fracture with delayed healing*/
,'S52321H'  /*Displaced transverse fracture of shaft of right radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52321J'  /*Displaced transverse fracture of shaft of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52321K'  /*Displaced transverse fracture of shaft of right radius, subsequent encounter for closed fracture with nonunion*/
,'S52321M'  /*Displaced transverse fracture of shaft of right radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52321N'  /*Displaced transverse fracture of shaft of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52321P'  /*Displaced transverse fracture of shaft of right radius, subsequent encounter for closed fracture with malunion*/
,'S52321Q'  /*Displaced transverse fracture of shaft of right radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52321R'  /*Displaced transverse fracture of shaft of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52321S'  /*Displaced transverse fracture of shaft of right radius, sequela*/
,'S52322D'  /*Displaced transverse fracture of shaft of left radius, subsequent encounter for closed fracture with routine healing*/
,'S52322E'  /*Displaced transverse fracture of shaft of left radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52322F'  /*Displaced transverse fracture of shaft of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52322G'  /*Displaced transverse fracture of shaft of left radius, subsequent encounter for closed fracture with delayed healing*/
,'S52322H'  /*Displaced transverse fracture of shaft of left radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52322J'  /*Displaced transverse fracture of shaft of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52322K'  /*Displaced transverse fracture of shaft of left radius, subsequent encounter for closed fracture with nonunion*/
,'S52322M'  /*Displaced transverse fracture of shaft of left radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52322N'  /*Displaced transverse fracture of shaft of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52322P'  /*Displaced transverse fracture of shaft of left radius, subsequent encounter for closed fracture with malunion*/
,'S52322Q'  /*Displaced transverse fracture of shaft of left radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52322R'  /*Displaced transverse fracture of shaft of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52322S'  /*Displaced transverse fracture of shaft of left radius, sequela*/
,'S52323D'  /*Displaced transverse fracture of shaft of unspecified radius, subsequent encounter for closed fracture with routine healing*/
,'S52323E'  /*Displaced transverse fracture of shaft of unspecified radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52323F'  /*Displaced transverse fracture of shaft of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52323G'  /*Displaced transverse fracture of shaft of unspecified radius, subsequent encounter for closed fracture with delayed healing*/
,'S52323H'  /*Displaced transverse fracture of shaft of unspecified radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52323J'  /*Displaced transverse fracture of shaft of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52323K'  /*Displaced transverse fracture of shaft of unspecified radius, subsequent encounter for closed fracture with nonunion*/
,'S52323M'  /*Displaced transverse fracture of shaft of unspecified radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52323N'  /*Displaced transverse fracture of shaft of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52323P'  /*Displaced transverse fracture of shaft of unspecified radius, subsequent encounter for closed fracture with malunion*/
,'S52323Q'  /*Displaced transverse fracture of shaft of unspecified radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52323R'  /*Displaced transverse fracture of shaft of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52323S'  /*Displaced transverse fracture of shaft of unspecified radius, sequela*/
,'S52324D'  /*Nondisplaced transverse fracture of shaft of right radius, subsequent encounter for closed fracture with routine healing*/
,'S52324E'  /*Nondisplaced transverse fracture of shaft of right radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52324F'  /*Nondisplaced transverse fracture of shaft of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52324G'  /*Nondisplaced transverse fracture of shaft of right radius, subsequent encounter for closed fracture with delayed healing*/
,'S52324H'  /*Nondisplaced transverse fracture of shaft of right radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52324J'  /*Nondisplaced transverse fracture of shaft of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52324K'  /*Nondisplaced transverse fracture of shaft of right radius, subsequent encounter for closed fracture with nonunion*/
,'S52324M'  /*Nondisplaced transverse fracture of shaft of right radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52324N'  /*Nondisplaced transverse fracture of shaft of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52324P'  /*Nondisplaced transverse fracture of shaft of right radius, subsequent encounter for closed fracture with malunion*/
,'S52324Q'  /*Nondisplaced transverse fracture of shaft of right radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52324R'  /*Nondisplaced transverse fracture of shaft of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52324S'  /*Nondisplaced transverse fracture of shaft of right radius, sequela*/
,'S52325D'  /*Nondisplaced transverse fracture of shaft of left radius, subsequent encounter for closed fracture with routine healing*/
,'S52325E'  /*Nondisplaced transverse fracture of shaft of left radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52325F'  /*Nondisplaced transverse fracture of shaft of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52325G'  /*Nondisplaced transverse fracture of shaft of left radius, subsequent encounter for closed fracture with delayed healing*/
,'S52325H'  /*Nondisplaced transverse fracture of shaft of left radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52325J'  /*Nondisplaced transverse fracture of shaft of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52325K'  /*Nondisplaced transverse fracture of shaft of left radius, subsequent encounter for closed fracture with nonunion*/
,'S52325M'  /*Nondisplaced transverse fracture of shaft of left radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52325N'  /*Nondisplaced transverse fracture of shaft of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52325P'  /*Nondisplaced transverse fracture of shaft of left radius, subsequent encounter for closed fracture with malunion*/
,'S52325Q'  /*Nondisplaced transverse fracture of shaft of left radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52325R'  /*Nondisplaced transverse fracture of shaft of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52325S'  /*Nondisplaced transverse fracture of shaft of left radius, sequela*/
,'S52326D'  /*Nondisplaced transverse fracture of shaft of unspecified radius, subsequent encounter for closed fracture with routine healing*/
,'S52326E'  /*Nondisplaced transverse fracture of shaft of unspecified radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52326F'  /*Nondisplaced transverse fracture of shaft of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52326G'  /*Nondisplaced transverse fracture of shaft of unspecified radius, subsequent encounter for closed fracture with delayed healing*/
,'S52326H'  /*Nondisplaced transverse fracture of shaft of unspecified radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52326J'  /*Nondisplaced transverse fracture of shaft of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52326K'  /*Nondisplaced transverse fracture of shaft of unspecified radius, subsequent encounter for closed fracture with nonunion*/
,'S52326M'  /*Nondisplaced transverse fracture of shaft of unspecified radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52326N'  /*Nondisplaced transverse fracture of shaft of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52326P'  /*Nondisplaced transverse fracture of shaft of unspecified radius, subsequent encounter for closed fracture with malunion*/
,'S52326Q'  /*Nondisplaced transverse fracture of shaft of unspecified radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52326R'  /*Nondisplaced transverse fracture of shaft of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52326S'  /*Nondisplaced transverse fracture of shaft of unspecified radius, sequela*/
,'S52331D'  /*Displaced oblique fracture of shaft of right radius, subsequent encounter for closed fracture with routine healing*/
,'S52331E'  /*Displaced oblique fracture of shaft of right radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52331F'  /*Displaced oblique fracture of shaft of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52331G'  /*Displaced oblique fracture of shaft of right radius, subsequent encounter for closed fracture with delayed healing*/
,'S52331H'  /*Displaced oblique fracture of shaft of right radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52331J'  /*Displaced oblique fracture of shaft of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52331K'  /*Displaced oblique fracture of shaft of right radius, subsequent encounter for closed fracture with nonunion*/
,'S52331M'  /*Displaced oblique fracture of shaft of right radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52331N'  /*Displaced oblique fracture of shaft of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52331P'  /*Displaced oblique fracture of shaft of right radius, subsequent encounter for closed fracture with malunion*/
,'S52331Q'  /*Displaced oblique fracture of shaft of right radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52331R'  /*Displaced oblique fracture of shaft of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52331S'  /*Displaced oblique fracture of shaft of right radius, sequela*/
,'S52332D'  /*Displaced oblique fracture of shaft of left radius, subsequent encounter for closed fracture with routine healing*/
,'S52332E'  /*Displaced oblique fracture of shaft of left radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52332F'  /*Displaced oblique fracture of shaft of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52332G'  /*Displaced oblique fracture of shaft of left radius, subsequent encounter for closed fracture with delayed healing*/
,'S52332H'  /*Displaced oblique fracture of shaft of left radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52332J'  /*Displaced oblique fracture of shaft of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52332K'  /*Displaced oblique fracture of shaft of left radius, subsequent encounter for closed fracture with nonunion*/
,'S52332M'  /*Displaced oblique fracture of shaft of left radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52332N'  /*Displaced oblique fracture of shaft of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52332P'  /*Displaced oblique fracture of shaft of left radius, subsequent encounter for closed fracture with malunion*/
,'S52332Q'  /*Displaced oblique fracture of shaft of left radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52332R'  /*Displaced oblique fracture of shaft of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52332S'  /*Displaced oblique fracture of shaft of left radius, sequela*/
,'S52333D'  /*Displaced oblique fracture of shaft of unspecified radius, subsequent encounter for closed fracture with routine healing*/
,'S52333E'  /*Displaced oblique fracture of shaft of unspecified radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52333F'  /*Displaced oblique fracture of shaft of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52333G'  /*Displaced oblique fracture of shaft of unspecified radius, subsequent encounter for closed fracture with delayed healing*/
,'S52333H'  /*Displaced oblique fracture of shaft of unspecified radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52333J'  /*Displaced oblique fracture of shaft of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52333K'  /*Displaced oblique fracture of shaft of unspecified radius, subsequent encounter for closed fracture with nonunion*/
,'S52333M'  /*Displaced oblique fracture of shaft of unspecified radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52333N'  /*Displaced oblique fracture of shaft of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52333P'  /*Displaced oblique fracture of shaft of unspecified radius, subsequent encounter for closed fracture with malunion*/
,'S52333Q'  /*Displaced oblique fracture of shaft of unspecified radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52333R'  /*Displaced oblique fracture of shaft of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52333S'  /*Displaced oblique fracture of shaft of unspecified radius, sequela*/
,'S52334D'  /*Nondisplaced oblique fracture of shaft of right radius, subsequent encounter for closed fracture with routine healing*/
,'S52334E'  /*Nondisplaced oblique fracture of shaft of right radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52334F'  /*Nondisplaced oblique fracture of shaft of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52334G'  /*Nondisplaced oblique fracture of shaft of right radius, subsequent encounter for closed fracture with delayed healing*/
,'S52334H'  /*Nondisplaced oblique fracture of shaft of right radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52334J'  /*Nondisplaced oblique fracture of shaft of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52334K'  /*Nondisplaced oblique fracture of shaft of right radius, subsequent encounter for closed fracture with nonunion*/
,'S52334M'  /*Nondisplaced oblique fracture of shaft of right radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52334N'  /*Nondisplaced oblique fracture of shaft of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52334P'  /*Nondisplaced oblique fracture of shaft of right radius, subsequent encounter for closed fracture with malunion*/
,'S52334Q'  /*Nondisplaced oblique fracture of shaft of right radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52334R'  /*Nondisplaced oblique fracture of shaft of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52334S'  /*Nondisplaced oblique fracture of shaft of right radius, sequela*/
,'S52335D'  /*Nondisplaced oblique fracture of shaft of left radius, subsequent encounter for closed fracture with routine healing*/
,'S52335E'  /*Nondisplaced oblique fracture of shaft of left radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52335F'  /*Nondisplaced oblique fracture of shaft of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52335G'  /*Nondisplaced oblique fracture of shaft of left radius, subsequent encounter for closed fracture with delayed healing*/
,'S52335H'  /*Nondisplaced oblique fracture of shaft of left radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52335J'  /*Nondisplaced oblique fracture of shaft of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52335K'  /*Nondisplaced oblique fracture of shaft of left radius, subsequent encounter for closed fracture with nonunion*/
,'S52335M'  /*Nondisplaced oblique fracture of shaft of left radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52335N'  /*Nondisplaced oblique fracture of shaft of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52335P'  /*Nondisplaced oblique fracture of shaft of left radius, subsequent encounter for closed fracture with malunion*/
,'S52335Q'  /*Nondisplaced oblique fracture of shaft of left radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52335R'  /*Nondisplaced oblique fracture of shaft of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52335S'  /*Nondisplaced oblique fracture of shaft of left radius, sequela*/
,'S52336D'  /*Nondisplaced oblique fracture of shaft of unspecified radius, subsequent encounter for closed fracture with routine healing*/
,'S52336E'  /*Nondisplaced oblique fracture of shaft of unspecified radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52336F'  /*Nondisplaced oblique fracture of shaft of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52336G'  /*Nondisplaced oblique fracture of shaft of unspecified radius, subsequent encounter for closed fracture with delayed healing*/
,'S52336H'  /*Nondisplaced oblique fracture of shaft of unspecified radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52336J'  /*Nondisplaced oblique fracture of shaft of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52336K'  /*Nondisplaced oblique fracture of shaft of unspecified radius, subsequent encounter for closed fracture with nonunion*/
,'S52336M'  /*Nondisplaced oblique fracture of shaft of unspecified radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52336N'  /*Nondisplaced oblique fracture of shaft of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52336P'  /*Nondisplaced oblique fracture of shaft of unspecified radius, subsequent encounter for closed fracture with malunion*/
,'S52336Q'  /*Nondisplaced oblique fracture of shaft of unspecified radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52336R'  /*Nondisplaced oblique fracture of shaft of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52336S'  /*Nondisplaced oblique fracture of shaft of unspecified radius, sequela*/
,'S52341D'  /*Displaced spiral fracture of shaft of radius, right arm, subsequent encounter for closed fracture with routine healing*/
,'S52341E'  /*Displaced spiral fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52341F'  /*Displaced spiral fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52341G'  /*Displaced spiral fracture of shaft of radius, right arm, subsequent encounter for closed fracture with delayed healing*/
,'S52341H'  /*Displaced spiral fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52341J'  /*Displaced spiral fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52341K'  /*Displaced spiral fracture of shaft of radius, right arm, subsequent encounter for closed fracture with nonunion*/
,'S52341M'  /*Displaced spiral fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52341N'  /*Displaced spiral fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52341P'  /*Displaced spiral fracture of shaft of radius, right arm, subsequent encounter for closed fracture with malunion*/
,'S52341Q'  /*Displaced spiral fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52341R'  /*Displaced spiral fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52341S'  /*Displaced spiral fracture of shaft of radius, right arm, sequela*/
,'S52342D'  /*Displaced spiral fracture of shaft of radius, left arm, subsequent encounter for closed fracture with routine healing*/
,'S52342E'  /*Displaced spiral fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52342F'  /*Displaced spiral fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52342G'  /*Displaced spiral fracture of shaft of radius, left arm, subsequent encounter for closed fracture with delayed healing*/
,'S52342H'  /*Displaced spiral fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52342J'  /*Displaced spiral fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52342K'  /*Displaced spiral fracture of shaft of radius, left arm, subsequent encounter for closed fracture with nonunion*/
,'S52342M'  /*Displaced spiral fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52342N'  /*Displaced spiral fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52342P'  /*Displaced spiral fracture of shaft of radius, left arm, subsequent encounter for closed fracture with malunion*/
,'S52342Q'  /*Displaced spiral fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52342R'  /*Displaced spiral fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52342S'  /*Displaced spiral fracture of shaft of radius, left arm, sequela*/
,'S52343D'  /*Displaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with routine healing*/
,'S52343E'  /*Displaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52343F'  /*Displaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52343G'  /*Displaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with delayed healing*/
,'S52343H'  /*Displaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52343J'  /*Displaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52343K'  /*Displaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with nonunion*/
,'S52343M'  /*Displaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52343N'  /*Displaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52343P'  /*Displaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with malunion*/
,'S52343Q'  /*Displaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52343R'  /*Displaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52343S'  /*Displaced spiral fracture of shaft of radius, unspecified arm, sequela*/
,'S52344D'  /*Nondisplaced spiral fracture of shaft of radius, right arm, subsequent encounter for closed fracture with routine healing*/
,'S52344E'  /*Nondisplaced spiral fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52344F'  /*Nondisplaced spiral fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52344G'  /*Nondisplaced spiral fracture of shaft of radius, right arm, subsequent encounter for closed fracture with delayed healing*/
,'S52344H'  /*Nondisplaced spiral fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52344J'  /*Nondisplaced spiral fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52344K'  /*Nondisplaced spiral fracture of shaft of radius, right arm, subsequent encounter for closed fracture with nonunion*/
,'S52344M'  /*Nondisplaced spiral fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52344N'  /*Nondisplaced spiral fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52344P'  /*Nondisplaced spiral fracture of shaft of radius, right arm, subsequent encounter for closed fracture with malunion*/
,'S52344Q'  /*Nondisplaced spiral fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52344R'  /*Nondisplaced spiral fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52344S'  /*Nondisplaced spiral fracture of shaft of radius, right arm, sequela*/
,'S52345D'  /*Nondisplaced spiral fracture of shaft of radius, left arm, subsequent encounter for closed fracture with routine healing*/
,'S52345E'  /*Nondisplaced spiral fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52345F'  /*Nondisplaced spiral fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52345G'  /*Nondisplaced spiral fracture of shaft of radius, left arm, subsequent encounter for closed fracture with delayed healing*/
,'S52345H'  /*Nondisplaced spiral fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52345J'  /*Nondisplaced spiral fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52345K'  /*Nondisplaced spiral fracture of shaft of radius, left arm, subsequent encounter for closed fracture with nonunion*/
,'S52345M'  /*Nondisplaced spiral fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52345N'  /*Nondisplaced spiral fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52345P'  /*Nondisplaced spiral fracture of shaft of radius, left arm, subsequent encounter for closed fracture with malunion*/
,'S52345Q'  /*Nondisplaced spiral fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52345R'  /*Nondisplaced spiral fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52345S'  /*Nondisplaced spiral fracture of shaft of radius, left arm, sequela*/
,'S52346D'  /*Nondisplaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with routine healing*/
,'S52346E'  /*Nondisplaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52346F'  /*Nondisplaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52346G'  /*Nondisplaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with delayed healing*/
,'S52346H'  /*Nondisplaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52346J'  /*Nondisplaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52346K'  /*Nondisplaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with nonunion*/
,'S52346M'  /*Nondisplaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52346N'  /*Nondisplaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52346P'  /*Nondisplaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with malunion*/
,'S52346Q'  /*Nondisplaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52346R'  /*Nondisplaced spiral fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52346S'  /*Nondisplaced spiral fracture of shaft of radius, unspecified arm, sequela*/
,'S52351D'  /*Displaced comminuted fracture of shaft of radius, right arm, subsequent encounter for closed fracture with routine healing*/
,'S52351E'  /*Displaced comminuted fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52351F'  /*Displaced comminuted fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52351G'  /*Displaced comminuted fracture of shaft of radius, right arm, subsequent encounter for closed fracture with delayed healing*/
,'S52351H'  /*Displaced comminuted fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52351J'  /*Displaced comminuted fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52351K'  /*Displaced comminuted fracture of shaft of radius, right arm, subsequent encounter for closed fracture with nonunion*/
,'S52351M'  /*Displaced comminuted fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52351N'  /*Displaced comminuted fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52351P'  /*Displaced comminuted fracture of shaft of radius, right arm, subsequent encounter for closed fracture with malunion*/
,'S52351Q'  /*Displaced comminuted fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52351R'  /*Displaced comminuted fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52351S'  /*Displaced comminuted fracture of shaft of radius, right arm, sequela*/
,'S52352D'  /*Displaced comminuted fracture of shaft of radius, left arm, subsequent encounter for closed fracture with routine healing*/
,'S52352E'  /*Displaced comminuted fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52352F'  /*Displaced comminuted fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52352G'  /*Displaced comminuted fracture of shaft of radius, left arm, subsequent encounter for closed fracture with delayed healing*/
,'S52352H'  /*Displaced comminuted fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52352J'  /*Displaced comminuted fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52352K'  /*Displaced comminuted fracture of shaft of radius, left arm, subsequent encounter for closed fracture with nonunion*/
,'S52352M'  /*Displaced comminuted fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52352N'  /*Displaced comminuted fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52352P'  /*Displaced comminuted fracture of shaft of radius, left arm, subsequent encounter for closed fracture with malunion*/
,'S52352Q'  /*Displaced comminuted fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52352R'  /*Displaced comminuted fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52352S'  /*Displaced comminuted fracture of shaft of radius, left arm, sequela*/
,'S52353D'  /*Displaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with routine healing*/
,'S52353E'  /*Displaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52353F'  /*Displaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52353G'  /*Displaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with delayed healing*/
,'S52353H'  /*Displaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52353J'  /*Displaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52353K'  /*Displaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with nonunion*/
,'S52353M'  /*Displaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52353N'  /*Displaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52353P'  /*Displaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with malunion*/
,'S52353Q'  /*Displaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52353R'  /*Displaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52353S'  /*Displaced comminuted fracture of shaft of radius, unspecified arm, sequela*/
,'S52354D'  /*Nondisplaced comminuted fracture of shaft of radius, right arm, subsequent encounter for closed fracture with routine healing*/
,'S52354E'  /*Nondisplaced comminuted fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52354F'  /*Nondisplaced comminuted fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52354G'  /*Nondisplaced comminuted fracture of shaft of radius, right arm, subsequent encounter for closed fracture with delayed healing*/
,'S52354H'  /*Nondisplaced comminuted fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52354J'  /*Nondisplaced comminuted fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52354K'  /*Nondisplaced comminuted fracture of shaft of radius, right arm, subsequent encounter for closed fracture with nonunion*/
,'S52354M'  /*Nondisplaced comminuted fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52354N'  /*Nondisplaced comminuted fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52354P'  /*Nondisplaced comminuted fracture of shaft of radius, right arm, subsequent encounter for closed fracture with malunion*/
,'S52354Q'  /*Nondisplaced comminuted fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52354R'  /*Nondisplaced comminuted fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52354S'  /*Nondisplaced comminuted fracture of shaft of radius, right arm, sequela*/
,'S52355D'  /*Nondisplaced comminuted fracture of shaft of radius, left arm, subsequent encounter for closed fracture with routine healing*/
,'S52355E'  /*Nondisplaced comminuted fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52355F'  /*Nondisplaced comminuted fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52355G'  /*Nondisplaced comminuted fracture of shaft of radius, left arm, subsequent encounter for closed fracture with delayed healing*/
,'S52355H'  /*Nondisplaced comminuted fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52355J'  /*Nondisplaced comminuted fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52355K'  /*Nondisplaced comminuted fracture of shaft of radius, left arm, subsequent encounter for closed fracture with nonunion*/
,'S52355M'  /*Nondisplaced comminuted fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52355N'  /*Nondisplaced comminuted fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52355P'  /*Nondisplaced comminuted fracture of shaft of radius, left arm, subsequent encounter for closed fracture with malunion*/
,'S52355Q'  /*Nondisplaced comminuted fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52355R'  /*Nondisplaced comminuted fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52355S'  /*Nondisplaced comminuted fracture of shaft of radius, left arm, sequela*/
,'S52356D'  /*Nondisplaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with routine healing*/
,'S52356E'  /*Nondisplaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52356F'  /*Nondisplaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52356G'  /*Nondisplaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with delayed healing*/
,'S52356H'  /*Nondisplaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52356J'  /*Nondisplaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52356K'  /*Nondisplaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with nonunion*/
,'S52356M'  /*Nondisplaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52356N'  /*Nondisplaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52356P'  /*Nondisplaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with malunion*/
,'S52356Q'  /*Nondisplaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52356R'  /*Nondisplaced comminuted fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52356S'  /*Nondisplaced comminuted fracture of shaft of radius, unspecified arm, sequela*/
,'S52361D'  /*Displaced segmental fracture of shaft of radius, right arm, subsequent encounter for closed fracture with routine healing*/
,'S52361E'  /*Displaced segmental fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52361F'  /*Displaced segmental fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52361G'  /*Displaced segmental fracture of shaft of radius, right arm, subsequent encounter for closed fracture with delayed healing*/
,'S52361H'  /*Displaced segmental fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52361J'  /*Displaced segmental fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52361K'  /*Displaced segmental fracture of shaft of radius, right arm, subsequent encounter for closed fracture with nonunion*/
,'S52361M'  /*Displaced segmental fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52361N'  /*Displaced segmental fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52361P'  /*Displaced segmental fracture of shaft of radius, right arm, subsequent encounter for closed fracture with malunion*/
,'S52361Q'  /*Displaced segmental fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52361R'  /*Displaced segmental fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52361S'  /*Displaced segmental fracture of shaft of radius, right arm, sequela*/
,'S52362D'  /*Displaced segmental fracture of shaft of radius, left arm, subsequent encounter for closed fracture with routine healing*/
,'S52362E'  /*Displaced segmental fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52362F'  /*Displaced segmental fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52362G'  /*Displaced segmental fracture of shaft of radius, left arm, subsequent encounter for closed fracture with delayed healing*/
,'S52362H'  /*Displaced segmental fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52362J'  /*Displaced segmental fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52362K'  /*Displaced segmental fracture of shaft of radius, left arm, subsequent encounter for closed fracture with nonunion*/
,'S52362M'  /*Displaced segmental fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52362N'  /*Displaced segmental fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52362P'  /*Displaced segmental fracture of shaft of radius, left arm, subsequent encounter for closed fracture with malunion*/
,'S52362Q'  /*Displaced segmental fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52362R'  /*Displaced segmental fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52362S'  /*Displaced segmental fracture of shaft of radius, left arm, sequela*/
,'S52363D'  /*Displaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with routine healing*/
,'S52363E'  /*Displaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52363F'  /*Displaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52363G'  /*Displaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with delayed healing*/
,'S52363H'  /*Displaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52363J'  /*Displaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52363K'  /*Displaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with nonunion*/
,'S52363M'  /*Displaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52363N'  /*Displaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52363P'  /*Displaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with malunion*/
,'S52363Q'  /*Displaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52363R'  /*Displaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52363S'  /*Displaced segmental fracture of shaft of radius, unspecified arm, sequela*/
,'S52364D'  /*Nondisplaced segmental fracture of shaft of radius, right arm, subsequent encounter for closed fracture with routine healing*/
,'S52364E'  /*Nondisplaced segmental fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52364F'  /*Nondisplaced segmental fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52364G'  /*Nondisplaced segmental fracture of shaft of radius, right arm, subsequent encounter for closed fracture with delayed healing*/
,'S52364H'  /*Nondisplaced segmental fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52364J'  /*Nondisplaced segmental fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52364K'  /*Nondisplaced segmental fracture of shaft of radius, right arm, subsequent encounter for closed fracture with nonunion*/
,'S52364M'  /*Nondisplaced segmental fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52364N'  /*Nondisplaced segmental fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52364P'  /*Nondisplaced segmental fracture of shaft of radius, right arm, subsequent encounter for closed fracture with malunion*/
,'S52364Q'  /*Nondisplaced segmental fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52364R'  /*Nondisplaced segmental fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52364S'  /*Nondisplaced segmental fracture of shaft of radius, right arm, sequela*/
,'S52365D'  /*Nondisplaced segmental fracture of shaft of radius, left arm, subsequent encounter for closed fracture with routine healing*/
,'S52365E'  /*Nondisplaced segmental fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52365F'  /*Nondisplaced segmental fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52365G'  /*Nondisplaced segmental fracture of shaft of radius, left arm, subsequent encounter for closed fracture with delayed healing*/
,'S52365H'  /*Nondisplaced segmental fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52365J'  /*Nondisplaced segmental fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52365K'  /*Nondisplaced segmental fracture of shaft of radius, left arm, subsequent encounter for closed fracture with nonunion*/
,'S52365M'  /*Nondisplaced segmental fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52365N'  /*Nondisplaced segmental fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52365P'  /*Nondisplaced segmental fracture of shaft of radius, left arm, subsequent encounter for closed fracture with malunion*/
,'S52365Q'  /*Nondisplaced segmental fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52365R'  /*Nondisplaced segmental fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52365S'  /*Nondisplaced segmental fracture of shaft of radius, left arm, sequela*/
,'S52366D'  /*Nondisplaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with routine healing*/
,'S52366E'  /*Nondisplaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52366F'  /*Nondisplaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52366G'  /*Nondisplaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with delayed healing*/
,'S52366H'  /*Nondisplaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52366J'  /*Nondisplaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52366K'  /*Nondisplaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with nonunion*/
,'S52366M'  /*Nondisplaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52366N'  /*Nondisplaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52366P'  /*Nondisplaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with malunion*/
,'S52366Q'  /*Nondisplaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52366R'  /*Nondisplaced segmental fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52366S'  /*Nondisplaced segmental fracture of shaft of radius, unspecified arm, sequela*/
,'S52371D'  /*Galeazzi's fracture of right radius, subsequent encounter for closed fracture with routine healing*/
,'S52371E'  /*Galeazzi's fracture of right radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52371F'  /*Galeazzi's fracture of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52371G'  /*Galeazzi's fracture of right radius, subsequent encounter for closed fracture with delayed healing*/
,'S52371H'  /*Galeazzi's fracture of right radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52371J'  /*Galeazzi's fracture of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52371K'  /*Galeazzi's fracture of right radius, subsequent encounter for closed fracture with nonunion*/
,'S52371M'  /*Galeazzi's fracture of right radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52371N'  /*Galeazzi's fracture of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52371P'  /*Galeazzi's fracture of right radius, subsequent encounter for closed fracture with malunion*/
,'S52371Q'  /*Galeazzi's fracture of right radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52371R'  /*Galeazzi's fracture of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52371S'  /*Galeazzi's fracture of right radius, sequela*/
,'S52372D'  /*Galeazzi's fracture of left radius, subsequent encounter for closed fracture with routine healing*/
,'S52372E'  /*Galeazzi's fracture of left radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52372F'  /*Galeazzi's fracture of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52372G'  /*Galeazzi's fracture of left radius, subsequent encounter for closed fracture with delayed healing*/
,'S52372H'  /*Galeazzi's fracture of left radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52372J'  /*Galeazzi's fracture of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52372K'  /*Galeazzi's fracture of left radius, subsequent encounter for closed fracture with nonunion*/
,'S52372M'  /*Galeazzi's fracture of left radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52372N'  /*Galeazzi's fracture of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52372P'  /*Galeazzi's fracture of left radius, subsequent encounter for closed fracture with malunion*/
,'S52372Q'  /*Galeazzi's fracture of left radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52372R'  /*Galeazzi's fracture of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52372S'  /*Galeazzi's fracture of left radius, sequela*/
,'S52379D'  /*Galeazzi's fracture of unspecified radius, subsequent encounter for closed fracture with routine healing*/
,'S52379E'  /*Galeazzi's fracture of unspecified radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52379F'  /*Galeazzi's fracture of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52379G'  /*Galeazzi's fracture of unspecified radius, subsequent encounter for closed fracture with delayed healing*/
,'S52379H'  /*Galeazzi's fracture of unspecified radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52379J'  /*Galeazzi's fracture of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52379K'  /*Galeazzi's fracture of unspecified radius, subsequent encounter for closed fracture with nonunion*/
,'S52379M'  /*Galeazzi's fracture of unspecified radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52379N'  /*Galeazzi's fracture of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52379P'  /*Galeazzi's fracture of unspecified radius, subsequent encounter for closed fracture with malunion*/
,'S52379Q'  /*Galeazzi's fracture of unspecified radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52379R'  /*Galeazzi's fracture of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52379S'  /*Galeazzi's fracture of unspecified radius, sequela*/
,'S52381D'  /*Bent bone of right radius, subsequent encounter for closed fracture with routine healing*/
,'S52381E'  /*Bent bone of right radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52381F'  /*Bent bone of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52381G'  /*Bent bone of right radius, subsequent encounter for closed fracture with delayed healing*/
,'S52381H'  /*Bent bone of right radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52381J'  /*Bent bone of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52381K'  /*Bent bone of right radius, subsequent encounter for closed fracture with nonunion*/
,'S52381M'  /*Bent bone of right radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52381N'  /*Bent bone of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52381P'  /*Bent bone of right radius, subsequent encounter for closed fracture with malunion*/
,'S52381Q'  /*Bent bone of right radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52381R'  /*Bent bone of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52381S'  /*Bent bone of right radius, sequela*/
,'S52382D'  /*Bent bone of left radius, subsequent encounter for closed fracture with routine healing*/
,'S52382E'  /*Bent bone of left radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52382F'  /*Bent bone of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52382G'  /*Bent bone of left radius, subsequent encounter for closed fracture with delayed healing*/
,'S52382H'  /*Bent bone of left radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52382J'  /*Bent bone of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52382K'  /*Bent bone of left radius, subsequent encounter for closed fracture with nonunion*/
,'S52382M'  /*Bent bone of left radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52382N'  /*Bent bone of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52382P'  /*Bent bone of left radius, subsequent encounter for closed fracture with malunion*/
,'S52382Q'  /*Bent bone of left radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52382R'  /*Bent bone of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52382S'  /*Bent bone of left radius, sequela*/
,'S52389D'  /*Bent bone of unspecified radius, subsequent encounter for closed fracture with routine healing*/
,'S52389E'  /*Bent bone of unspecified radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52389F'  /*Bent bone of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52389G'  /*Bent bone of unspecified radius, subsequent encounter for closed fracture with delayed healing*/
,'S52389H'  /*Bent bone of unspecified radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52389J'  /*Bent bone of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52389K'  /*Bent bone of unspecified radius, subsequent encounter for closed fracture with nonunion*/
,'S52389M'  /*Bent bone of unspecified radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52389N'  /*Bent bone of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52389P'  /*Bent bone of unspecified radius, subsequent encounter for closed fracture with malunion*/
,'S52389Q'  /*Bent bone of unspecified radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52389R'  /*Bent bone of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52389S'  /*Bent bone of unspecified radius, sequela*/
,'S52391D'  /*Other fracture of shaft of radius, right arm, subsequent encounter for closed fracture with routine healing*/
,'S52391E'  /*Other fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52391F'  /*Other fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52391G'  /*Other fracture of shaft of radius, right arm, subsequent encounter for closed fracture with delayed healing*/
,'S52391H'  /*Other fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52391J'  /*Other fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52391K'  /*Other fracture of shaft of radius, right arm, subsequent encounter for closed fracture with nonunion*/
,'S52391M'  /*Other fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52391N'  /*Other fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52391P'  /*Other fracture of shaft of radius, right arm, subsequent encounter for closed fracture with malunion*/
,'S52391Q'  /*Other fracture of shaft of radius, right arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52391R'  /*Other fracture of shaft of radius, right arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52391S'  /*Other fracture of shaft of radius, right arm, sequela*/
,'S52392D'  /*Other fracture of shaft of radius, left arm, subsequent encounter for closed fracture with routine healing*/
,'S52392E'  /*Other fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52392F'  /*Other fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52392G'  /*Other fracture of shaft of radius, left arm, subsequent encounter for closed fracture with delayed healing*/
,'S52392H'  /*Other fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52392J'  /*Other fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52392K'  /*Other fracture of shaft of radius, left arm, subsequent encounter for closed fracture with nonunion*/
,'S52392M'  /*Other fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52392N'  /*Other fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52392P'  /*Other fracture of shaft of radius, left arm, subsequent encounter for closed fracture with malunion*/
,'S52392Q'  /*Other fracture of shaft of radius, left arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52392R'  /*Other fracture of shaft of radius, left arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52392S'  /*Other fracture of shaft of radius, left arm, sequela*/
,'S52399D'  /*Other fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with routine healing*/
,'S52399E'  /*Other fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with routine healing*/
,'S52399F'  /*Other fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52399G'  /*Other fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with delayed healing*/
,'S52399H'  /*Other fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52399J'  /*Other fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52399K'  /*Other fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with nonunion*/
,'S52399M'  /*Other fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with nonunion*/
,'S52399N'  /*Other fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52399P'  /*Other fracture of shaft of radius, unspecified arm, subsequent encounter for closed fracture with malunion*/
,'S52399Q'  /*Other fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type I or II with malunion*/
,'S52399R'  /*Other fracture of shaft of radius, unspecified arm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52399S'  /*Other fracture of shaft of radius, unspecified arm, sequela*/
,'S52501D'  /*Unspecified fracture of the lower end of right radius, subsequent encounter for closed fracture with routine healing*/
,'S52501E'  /*Unspecified fracture of the lower end of right radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52501F'  /*Unspecified fracture of the lower end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52501G'  /*Unspecified fracture of the lower end of right radius, subsequent encounter for closed fracture with delayed healing*/
,'S52501H'  /*Unspecified fracture of the lower end of right radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52501J'  /*Unspecified fracture of the lower end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52501K'  /*Unspecified fracture of the lower end of right radius, subsequent encounter for closed fracture with nonunion*/
,'S52501M'  /*Unspecified fracture of the lower end of right radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52501N'  /*Unspecified fracture of the lower end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52501P'  /*Unspecified fracture of the lower end of right radius, subsequent encounter for closed fracture with malunion*/
,'S52501Q'  /*Unspecified fracture of the lower end of right radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52501R'  /*Unspecified fracture of the lower end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52501S'  /*Unspecified fracture of the lower end of right radius, sequela*/
,'S52502D'  /*Unspecified fracture of the lower end of left radius, subsequent encounter for closed fracture with routine healing*/
,'S52502E'  /*Unspecified fracture of the lower end of left radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52502F'  /*Unspecified fracture of the lower end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52502G'  /*Unspecified fracture of the lower end of left radius, subsequent encounter for closed fracture with delayed healing*/
,'S52502H'  /*Unspecified fracture of the lower end of left radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52502J'  /*Unspecified fracture of the lower end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52502K'  /*Unspecified fracture of the lower end of left radius, subsequent encounter for closed fracture with nonunion*/
,'S52502M'  /*Unspecified fracture of the lower end of left radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52502N'  /*Unspecified fracture of the lower end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52502P'  /*Unspecified fracture of the lower end of left radius, subsequent encounter for closed fracture with malunion*/
,'S52502Q'  /*Unspecified fracture of the lower end of left radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52502R'  /*Unspecified fracture of the lower end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52502S'  /*Unspecified fracture of the lower end of left radius, sequela*/
,'S52509D'  /*Unspecified fracture of the lower end of unspecified radius, subsequent encounter for closed fracture with routine healing*/
,'S52509E'  /*Unspecified fracture of the lower end of unspecified radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52509F'  /*Unspecified fracture of the lower end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52509G'  /*Unspecified fracture of the lower end of unspecified radius, subsequent encounter for closed fracture with delayed healing*/
,'S52509H'  /*Unspecified fracture of the lower end of unspecified radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52509J'  /*Unspecified fracture of the lower end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52509K'  /*Unspecified fracture of the lower end of unspecified radius, subsequent encounter for closed fracture with nonunion*/
,'S52509M'  /*Unspecified fracture of the lower end of unspecified radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52509N'  /*Unspecified fracture of the lower end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52509P'  /*Unspecified fracture of the lower end of unspecified radius, subsequent encounter for closed fracture with malunion*/
,'S52509Q'  /*Unspecified fracture of the lower end of unspecified radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52509R'  /*Unspecified fracture of the lower end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52509S'  /*Unspecified fracture of the lower end of unspecified radius, sequela*/
,'S52511D'  /*Displaced fracture of right radial styloid process, subsequent encounter for closed fracture with routine healing*/
,'S52511E'  /*Displaced fracture of right radial styloid process, subsequent encounter for open fracture type I or II with routine healing*/
,'S52511F'  /*Displaced fracture of right radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52511G'  /*Displaced fracture of right radial styloid process, subsequent encounter for closed fracture with delayed healing*/
,'S52511H'  /*Displaced fracture of right radial styloid process, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52511J'  /*Displaced fracture of right radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52511K'  /*Displaced fracture of right radial styloid process, subsequent encounter for closed fracture with nonunion*/
,'S52511M'  /*Displaced fracture of right radial styloid process, subsequent encounter for open fracture type I or II with nonunion*/
,'S52511N'  /*Displaced fracture of right radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52511P'  /*Displaced fracture of right radial styloid process, subsequent encounter for closed fracture with malunion*/
,'S52511Q'  /*Displaced fracture of right radial styloid process, subsequent encounter for open fracture type I or II with malunion*/
,'S52511R'  /*Displaced fracture of right radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52511S'  /*Displaced fracture of right radial styloid process, sequela*/
,'S52512D'  /*Displaced fracture of left radial styloid process, subsequent encounter for closed fracture with routine healing*/
,'S52512E'  /*Displaced fracture of left radial styloid process, subsequent encounter for open fracture type I or II with routine healing*/
,'S52512F'  /*Displaced fracture of left radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52512G'  /*Displaced fracture of left radial styloid process, subsequent encounter for closed fracture with delayed healing*/
,'S52512H'  /*Displaced fracture of left radial styloid process, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52512J'  /*Displaced fracture of left radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52512K'  /*Displaced fracture of left radial styloid process, subsequent encounter for closed fracture with nonunion*/
,'S52512M'  /*Displaced fracture of left radial styloid process, subsequent encounter for open fracture type I or II with nonunion*/
,'S52512N'  /*Displaced fracture of left radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52512P'  /*Displaced fracture of left radial styloid process, subsequent encounter for closed fracture with malunion*/
,'S52512Q'  /*Displaced fracture of left radial styloid process, subsequent encounter for open fracture type I or II with malunion*/
,'S52512R'  /*Displaced fracture of left radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52512S'  /*Displaced fracture of left radial styloid process, sequela*/
,'S52513D'  /*Displaced fracture of unspecified radial styloid process, subsequent encounter for closed fracture with routine healing*/
,'S52513E'  /*Displaced fracture of unspecified radial styloid process, subsequent encounter for open fracture type I or II with routine healing*/
,'S52513F'  /*Displaced fracture of unspecified radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52513G'  /*Displaced fracture of unspecified radial styloid process, subsequent encounter for closed fracture with delayed healing*/
,'S52513H'  /*Displaced fracture of unspecified radial styloid process, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52513J'  /*Displaced fracture of unspecified radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52513K'  /*Displaced fracture of unspecified radial styloid process, subsequent encounter for closed fracture with nonunion*/
,'S52513M'  /*Displaced fracture of unspecified radial styloid process, subsequent encounter for open fracture type I or II with nonunion*/
,'S52513N'  /*Displaced fracture of unspecified radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52513P'  /*Displaced fracture of unspecified radial styloid process, subsequent encounter for closed fracture with malunion*/
,'S52513Q'  /*Displaced fracture of unspecified radial styloid process, subsequent encounter for open fracture type I or II with malunion*/
,'S52513R'  /*Displaced fracture of unspecified radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52513S'  /*Displaced fracture of unspecified radial styloid process, sequela*/
,'S52514D'  /*Nondisplaced fracture of right radial styloid process, subsequent encounter for closed fracture with routine healing*/
,'S52514E'  /*Nondisplaced fracture of right radial styloid process, subsequent encounter for open fracture type I or II with routine healing*/
,'S52514F'  /*Nondisplaced fracture of right radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52514G'  /*Nondisplaced fracture of right radial styloid process, subsequent encounter for closed fracture with delayed healing*/
,'S52514H'  /*Nondisplaced fracture of right radial styloid process, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52514J'  /*Nondisplaced fracture of right radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52514K'  /*Nondisplaced fracture of right radial styloid process, subsequent encounter for closed fracture with nonunion*/
,'S52514M'  /*Nondisplaced fracture of right radial styloid process, subsequent encounter for open fracture type I or II with nonunion*/
,'S52514N'  /*Nondisplaced fracture of right radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52514P'  /*Nondisplaced fracture of right radial styloid process, subsequent encounter for closed fracture with malunion*/
,'S52514Q'  /*Nondisplaced fracture of right radial styloid process, subsequent encounter for open fracture type I or II with malunion*/
,'S52514R'  /*Nondisplaced fracture of right radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52514S'  /*Nondisplaced fracture of right radial styloid process, sequela*/
,'S52515D'  /*Nondisplaced fracture of left radial styloid process, subsequent encounter for closed fracture with routine healing*/
,'S52515E'  /*Nondisplaced fracture of left radial styloid process, subsequent encounter for open fracture type I or II with routine healing*/
,'S52515F'  /*Nondisplaced fracture of left radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52515G'  /*Nondisplaced fracture of left radial styloid process, subsequent encounter for closed fracture with delayed healing*/
,'S52515H'  /*Nondisplaced fracture of left radial styloid process, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52515J'  /*Nondisplaced fracture of left radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52515K'  /*Nondisplaced fracture of left radial styloid process, subsequent encounter for closed fracture with nonunion*/
,'S52515M'  /*Nondisplaced fracture of left radial styloid process, subsequent encounter for open fracture type I or II with nonunion*/
,'S52515N'  /*Nondisplaced fracture of left radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52515P'  /*Nondisplaced fracture of left radial styloid process, subsequent encounter for closed fracture with malunion*/
,'S52515Q'  /*Nondisplaced fracture of left radial styloid process, subsequent encounter for open fracture type I or II with malunion*/
,'S52515R'  /*Nondisplaced fracture of left radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52515S'  /*Nondisplaced fracture of left radial styloid process, sequela*/
,'S52516D'  /*Nondisplaced fracture of unspecified radial styloid process, subsequent encounter for closed fracture with routine healing*/
,'S52516E'  /*Nondisplaced fracture of unspecified radial styloid process, subsequent encounter for open fracture type I or II with routine healing*/
,'S52516F'  /*Nondisplaced fracture of unspecified radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52516G'  /*Nondisplaced fracture of unspecified radial styloid process, subsequent encounter for closed fracture with delayed healing*/
,'S52516H'  /*Nondisplaced fracture of unspecified radial styloid process, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52516J'  /*Nondisplaced fracture of unspecified radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52516K'  /*Nondisplaced fracture of unspecified radial styloid process, subsequent encounter for closed fracture with nonunion*/
,'S52516M'  /*Nondisplaced fracture of unspecified radial styloid process, subsequent encounter for open fracture type I or II with nonunion*/
,'S52516N'  /*Nondisplaced fracture of unspecified radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52516P'  /*Nondisplaced fracture of unspecified radial styloid process, subsequent encounter for closed fracture with malunion*/
,'S52516Q'  /*Nondisplaced fracture of unspecified radial styloid process, subsequent encounter for open fracture type I or II with malunion*/
,'S52516R'  /*Nondisplaced fracture of unspecified radial styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52516S'  /*Nondisplaced fracture of unspecified radial styloid process, sequela*/
,'S52521D'  /*Torus fracture of lower end of right radius, subsequent encounter for fracture with routine healing*/
,'S52521G'  /*Torus fracture of lower end of right radius, subsequent encounter for fracture with delayed healing*/
,'S52521K'  /*Torus fracture of lower end of right radius, subsequent encounter for fracture with nonunion*/
,'S52521P'  /*Torus fracture of lower end of right radius, subsequent encounter for fracture with malunion*/
,'S52521S'  /*Torus fracture of lower end of right radius, sequela*/
,'S52522D'  /*Torus fracture of lower end of left radius, subsequent encounter for fracture with routine healing*/
,'S52522G'  /*Torus fracture of lower end of left radius, subsequent encounter for fracture with delayed healing*/
,'S52522K'  /*Torus fracture of lower end of left radius, subsequent encounter for fracture with nonunion*/
,'S52522P'  /*Torus fracture of lower end of left radius, subsequent encounter for fracture with malunion*/
,'S52522S'  /*Torus fracture of lower end of left radius, sequela*/
,'S52529D'  /*Torus fracture of lower end of unspecified radius, subsequent encounter for fracture with routine healing*/
,'S52529G'  /*Torus fracture of lower end of unspecified radius, subsequent encounter for fracture with delayed healing*/
,'S52529K'  /*Torus fracture of lower end of unspecified radius, subsequent encounter for fracture with nonunion*/
,'S52529P'  /*Torus fracture of lower end of unspecified radius, subsequent encounter for fracture with malunion*/
,'S52529S'  /*Torus fracture of lower end of unspecified radius, sequela*/
,'S52531D'  /*Colles' fracture of right radius, subsequent encounter for closed fracture with routine healing*/
,'S52531E'  /*Colles' fracture of right radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52531F'  /*Colles' fracture of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52531G'  /*Colles' fracture of right radius, subsequent encounter for closed fracture with delayed healing*/
,'S52531H'  /*Colles' fracture of right radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52531J'  /*Colles' fracture of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52531K'  /*Colles' fracture of right radius, subsequent encounter for closed fracture with nonunion*/
,'S52531M'  /*Colles' fracture of right radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52531N'  /*Colles' fracture of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52531P'  /*Colles' fracture of right radius, subsequent encounter for closed fracture with malunion*/
,'S52531Q'  /*Colles' fracture of right radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52531R'  /*Colles' fracture of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52531S'  /*Colles' fracture of right radius, sequela*/
,'S52532D'  /*Colles' fracture of left radius, subsequent encounter for closed fracture with routine healing*/
,'S52532E'  /*Colles' fracture of left radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52532F'  /*Colles' fracture of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52532G'  /*Colles' fracture of left radius, subsequent encounter for closed fracture with delayed healing*/
,'S52532H'  /*Colles' fracture of left radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52532J'  /*Colles' fracture of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52532K'  /*Colles' fracture of left radius, subsequent encounter for closed fracture with nonunion*/
,'S52532M'  /*Colles' fracture of left radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52532N'  /*Colles' fracture of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52532P'  /*Colles' fracture of left radius, subsequent encounter for closed fracture with malunion*/
,'S52532Q'  /*Colles' fracture of left radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52532R'  /*Colles' fracture of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52532S'  /*Colles' fracture of left radius, sequela*/
,'S52539D'  /*Colles' fracture of unspecified radius, subsequent encounter for closed fracture with routine healing*/
,'S52539E'  /*Colles' fracture of unspecified radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52539F'  /*Colles' fracture of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52539G'  /*Colles' fracture of unspecified radius, subsequent encounter for closed fracture with delayed healing*/
,'S52539H'  /*Colles' fracture of unspecified radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52539J'  /*Colles' fracture of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52539K'  /*Colles' fracture of unspecified radius, subsequent encounter for closed fracture with nonunion*/
,'S52539M'  /*Colles' fracture of unspecified radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52539N'  /*Colles' fracture of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52539P'  /*Colles' fracture of unspecified radius, subsequent encounter for closed fracture with malunion*/
,'S52539Q'  /*Colles' fracture of unspecified radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52539R'  /*Colles' fracture of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52539S'  /*Colles' fracture of unspecified radius, sequela*/
,'S52541D'  /*Smith's fracture of right radius, subsequent encounter for closed fracture with routine healing*/
,'S52541E'  /*Smith's fracture of right radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52541F'  /*Smith's fracture of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52541G'  /*Smith's fracture of right radius, subsequent encounter for closed fracture with delayed healing*/
,'S52541H'  /*Smith's fracture of right radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52541J'  /*Smith's fracture of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52541K'  /*Smith's fracture of right radius, subsequent encounter for closed fracture with nonunion*/
,'S52541M'  /*Smith's fracture of right radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52541N'  /*Smith's fracture of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52541P'  /*Smith's fracture of right radius, subsequent encounter for closed fracture with malunion*/
,'S52541Q'  /*Smith's fracture of right radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52541R'  /*Smith's fracture of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52541S'  /*Smith's fracture of right radius, sequela*/
,'S52542D'  /*Smith's fracture of left radius, subsequent encounter for closed fracture with routine healing*/
,'S52542E'  /*Smith's fracture of left radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52542F'  /*Smith's fracture of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52542G'  /*Smith's fracture of left radius, subsequent encounter for closed fracture with delayed healing*/
,'S52542H'  /*Smith's fracture of left radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52542J'  /*Smith's fracture of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52542K'  /*Smith's fracture of left radius, subsequent encounter for closed fracture with nonunion*/
,'S52542M'  /*Smith's fracture of left radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52542N'  /*Smith's fracture of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52542P'  /*Smith's fracture of left radius, subsequent encounter for closed fracture with malunion*/
,'S52542Q'  /*Smith's fracture of left radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52542R'  /*Smith's fracture of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52542S'  /*Smith's fracture of left radius, sequela*/
,'S52549D'  /*Smith's fracture of unspecified radius, subsequent encounter for closed fracture with routine healing*/
,'S52549E'  /*Smith's fracture of unspecified radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52549F'  /*Smith's fracture of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52549G'  /*Smith's fracture of unspecified radius, subsequent encounter for closed fracture with delayed healing*/
,'S52549H'  /*Smith's fracture of unspecified radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52549J'  /*Smith's fracture of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52549K'  /*Smith's fracture of unspecified radius, subsequent encounter for closed fracture with nonunion*/
,'S52549M'  /*Smith's fracture of unspecified radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52549N'  /*Smith's fracture of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52549P'  /*Smith's fracture of unspecified radius, subsequent encounter for closed fracture with malunion*/
,'S52549Q'  /*Smith's fracture of unspecified radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52549R'  /*Smith's fracture of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52549S'  /*Smith's fracture of unspecified radius, sequela*/
,'S52551D'  /*Other extraarticular fracture of lower end of right radius, subsequent encounter for closed fracture with routine healing*/
,'S52551E'  /*Other extraarticular fracture of lower end of right radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52551F'  /*Other extraarticular fracture of lower end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52551G'  /*Other extraarticular fracture of lower end of right radius, subsequent encounter for closed fracture with delayed healing*/
,'S52551H'  /*Other extraarticular fracture of lower end of right radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52551J'  /*Other extraarticular fracture of lower end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52551K'  /*Other extraarticular fracture of lower end of right radius, subsequent encounter for closed fracture with nonunion*/
,'S52551M'  /*Other extraarticular fracture of lower end of right radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52551N'  /*Other extraarticular fracture of lower end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52551P'  /*Other extraarticular fracture of lower end of right radius, subsequent encounter for closed fracture with malunion*/
,'S52551Q'  /*Other extraarticular fracture of lower end of right radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52551R'  /*Other extraarticular fracture of lower end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52551S'  /*Other extraarticular fracture of lower end of right radius, sequela*/
,'S52552D'  /*Other extraarticular fracture of lower end of left radius, subsequent encounter for closed fracture with routine healing*/
,'S52552E'  /*Other extraarticular fracture of lower end of left radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52552F'  /*Other extraarticular fracture of lower end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52552G'  /*Other extraarticular fracture of lower end of left radius, subsequent encounter for closed fracture with delayed healing*/
,'S52552H'  /*Other extraarticular fracture of lower end of left radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52552J'  /*Other extraarticular fracture of lower end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52552K'  /*Other extraarticular fracture of lower end of left radius, subsequent encounter for closed fracture with nonunion*/
,'S52552M'  /*Other extraarticular fracture of lower end of left radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52552N'  /*Other extraarticular fracture of lower end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52552P'  /*Other extraarticular fracture of lower end of left radius, subsequent encounter for closed fracture with malunion*/
,'S52552Q'  /*Other extraarticular fracture of lower end of left radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52552R'  /*Other extraarticular fracture of lower end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52552S'  /*Other extraarticular fracture of lower end of left radius, sequela*/
,'S52559D'  /*Other extraarticular fracture of lower end of unspecified radius, subsequent encounter for closed fracture with routine healing*/
,'S52559E'  /*Other extraarticular fracture of lower end of unspecified radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52559F'  /*Other extraarticular fracture of lower end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52559G'  /*Other extraarticular fracture of lower end of unspecified radius, subsequent encounter for closed fracture with delayed healing*/
,'S52559H'  /*Other extraarticular fracture of lower end of unspecified radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52559J'  /*Other extraarticular fracture of lower end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52559K'  /*Other extraarticular fracture of lower end of unspecified radius, subsequent encounter for closed fracture with nonunion*/
,'S52559M'  /*Other extraarticular fracture of lower end of unspecified radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52559N'  /*Other extraarticular fracture of lower end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52559P'  /*Other extraarticular fracture of lower end of unspecified radius, subsequent encounter for closed fracture with malunion*/
,'S52559Q'  /*Other extraarticular fracture of lower end of unspecified radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52559R'  /*Other extraarticular fracture of lower end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52559S'  /*Other extraarticular fracture of lower end of unspecified radius, sequela*/
,'S52561D'  /*Barton's fracture of right radius, subsequent encounter for closed fracture with routine healing*/
,'S52561E'  /*Barton's fracture of right radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52561F'  /*Barton's fracture of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52561G'  /*Barton's fracture of right radius, subsequent encounter for closed fracture with delayed healing*/
,'S52561H'  /*Barton's fracture of right radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52561J'  /*Barton's fracture of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52561K'  /*Barton's fracture of right radius, subsequent encounter for closed fracture with nonunion*/
,'S52561M'  /*Barton's fracture of right radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52561N'  /*Barton's fracture of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52561P'  /*Barton's fracture of right radius, subsequent encounter for closed fracture with malunion*/
,'S52561Q'  /*Barton's fracture of right radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52561R'  /*Barton's fracture of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52561S'  /*Barton's fracture of right radius, sequela*/
,'S52562D'  /*Barton's fracture of left radius, subsequent encounter for closed fracture with routine healing*/
,'S52562E'  /*Barton's fracture of left radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52562F'  /*Barton's fracture of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52562G'  /*Barton's fracture of left radius, subsequent encounter for closed fracture with delayed healing*/
,'S52562H'  /*Barton's fracture of left radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52562J'  /*Barton's fracture of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52562K'  /*Barton's fracture of left radius, subsequent encounter for closed fracture with nonunion*/
,'S52562M'  /*Barton's fracture of left radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52562N'  /*Barton's fracture of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52562P'  /*Barton's fracture of left radius, subsequent encounter for closed fracture with malunion*/
,'S52562Q'  /*Barton's fracture of left radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52562R'  /*Barton's fracture of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52562S'  /*Barton's fracture of left radius, sequela*/
,'S52569D'  /*Barton's fracture of unspecified radius, subsequent encounter for closed fracture with routine healing*/
,'S52569E'  /*Barton's fracture of unspecified radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52569F'  /*Barton's fracture of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52569G'  /*Barton's fracture of unspecified radius, subsequent encounter for closed fracture with delayed healing*/
,'S52569H'  /*Barton's fracture of unspecified radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52569J'  /*Barton's fracture of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52569K'  /*Barton's fracture of unspecified radius, subsequent encounter for closed fracture with nonunion*/
,'S52569M'  /*Barton's fracture of unspecified radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52569N'  /*Barton's fracture of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52569P'  /*Barton's fracture of unspecified radius, subsequent encounter for closed fracture with malunion*/
,'S52569Q'  /*Barton's fracture of unspecified radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52569R'  /*Barton's fracture of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52569S'  /*Barton's fracture of unspecified radius, sequela*/
,'S52571D'  /*Other intraarticular fracture of lower end of right radius, subsequent encounter for closed fracture with routine healing*/
,'S52571E'  /*Other intraarticular fracture of lower end of right radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52571F'  /*Other intraarticular fracture of lower end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52571G'  /*Other intraarticular fracture of lower end of right radius, subsequent encounter for closed fracture with delayed healing*/
,'S52571H'  /*Other intraarticular fracture of lower end of right radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52571J'  /*Other intraarticular fracture of lower end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52571K'  /*Other intraarticular fracture of lower end of right radius, subsequent encounter for closed fracture with nonunion*/
,'S52571M'  /*Other intraarticular fracture of lower end of right radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52571N'  /*Other intraarticular fracture of lower end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52571P'  /*Other intraarticular fracture of lower end of right radius, subsequent encounter for closed fracture with malunion*/
,'S52571Q'  /*Other intraarticular fracture of lower end of right radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52571R'  /*Other intraarticular fracture of lower end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52571S'  /*Other intraarticular fracture of lower end of right radius, sequela*/
,'S52572D'  /*Other intraarticular fracture of lower end of left radius, subsequent encounter for closed fracture with routine healing*/
,'S52572E'  /*Other intraarticular fracture of lower end of left radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52572F'  /*Other intraarticular fracture of lower end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52572G'  /*Other intraarticular fracture of lower end of left radius, subsequent encounter for closed fracture with delayed healing*/
,'S52572H'  /*Other intraarticular fracture of lower end of left radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52572J'  /*Other intraarticular fracture of lower end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52572K'  /*Other intraarticular fracture of lower end of left radius, subsequent encounter for closed fracture with nonunion*/
,'S52572M'  /*Other intraarticular fracture of lower end of left radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52572N'  /*Other intraarticular fracture of lower end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52572P'  /*Other intraarticular fracture of lower end of left radius, subsequent encounter for closed fracture with malunion*/
,'S52572Q'  /*Other intraarticular fracture of lower end of left radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52572R'  /*Other intraarticular fracture of lower end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52572S'  /*Other intraarticular fracture of lower end of left radius, sequela*/
,'S52579D'  /*Other intraarticular fracture of lower end of unspecified radius, subsequent encounter for closed fracture with routine healing*/
,'S52579E'  /*Other intraarticular fracture of lower end of unspecified radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52579F'  /*Other intraarticular fracture of lower end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52579G'  /*Other intraarticular fracture of lower end of unspecified radius, subsequent encounter for closed fracture with delayed healing*/
,'S52579H'  /*Other intraarticular fracture of lower end of unspecified radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52579J'  /*Other intraarticular fracture of lower end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52579K'  /*Other intraarticular fracture of lower end of unspecified radius, subsequent encounter for closed fracture with nonunion*/
,'S52579M'  /*Other intraarticular fracture of lower end of unspecified radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52579N'  /*Other intraarticular fracture of lower end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52579P'  /*Other intraarticular fracture of lower end of unspecified radius, subsequent encounter for closed fracture with malunion*/
,'S52579Q'  /*Other intraarticular fracture of lower end of unspecified radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52579R'  /*Other intraarticular fracture of lower end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52579S'  /*Other intraarticular fracture of lower end of unspecified radius, sequela*/
,'S52591D'  /*Other fractures of lower end of right radius, subsequent encounter for closed fracture with routine healing*/
,'S52591E'  /*Other fractures of lower end of right radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52591F'  /*Other fractures of lower end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52591G'  /*Other fractures of lower end of right radius, subsequent encounter for closed fracture with delayed healing*/
,'S52591H'  /*Other fractures of lower end of right radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52591J'  /*Other fractures of lower end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52591K'  /*Other fractures of lower end of right radius, subsequent encounter for closed fracture with nonunion*/
,'S52591M'  /*Other fractures of lower end of right radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52591N'  /*Other fractures of lower end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52591P'  /*Other fractures of lower end of right radius, subsequent encounter for closed fracture with malunion*/
,'S52591Q'  /*Other fractures of lower end of right radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52591R'  /*Other fractures of lower end of right radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52591S'  /*Other fractures of lower end of right radius, sequela*/
,'S52592D'  /*Other fractures of lower end of left radius, subsequent encounter for closed fracture with routine healing*/
,'S52592E'  /*Other fractures of lower end of left radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52592F'  /*Other fractures of lower end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52592G'  /*Other fractures of lower end of left radius, subsequent encounter for closed fracture with delayed healing*/
,'S52592H'  /*Other fractures of lower end of left radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52592J'  /*Other fractures of lower end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52592K'  /*Other fractures of lower end of left radius, subsequent encounter for closed fracture with nonunion*/
,'S52592M'  /*Other fractures of lower end of left radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52592N'  /*Other fractures of lower end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52592P'  /*Other fractures of lower end of left radius, subsequent encounter for closed fracture with malunion*/
,'S52592Q'  /*Other fractures of lower end of left radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52592R'  /*Other fractures of lower end of left radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52592S'  /*Other fractures of lower end of left radius, sequela*/
,'S52599D'  /*Other fractures of lower end of unspecified radius, subsequent encounter for closed fracture with routine healing*/
,'S52599E'  /*Other fractures of lower end of unspecified radius, subsequent encounter for open fracture type I or II with routine healing*/
,'S52599F'  /*Other fractures of lower end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52599G'  /*Other fractures of lower end of unspecified radius, subsequent encounter for closed fracture with delayed healing*/
,'S52599H'  /*Other fractures of lower end of unspecified radius, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52599J'  /*Other fractures of lower end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52599K'  /*Other fractures of lower end of unspecified radius, subsequent encounter for closed fracture with nonunion*/
,'S52599M'  /*Other fractures of lower end of unspecified radius, subsequent encounter for open fracture type I or II with nonunion*/
,'S52599N'  /*Other fractures of lower end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52599P'  /*Other fractures of lower end of unspecified radius, subsequent encounter for closed fracture with malunion*/
,'S52599Q'  /*Other fractures of lower end of unspecified radius, subsequent encounter for open fracture type I or II with malunion*/
,'S52599R'  /*Other fractures of lower end of unspecified radius, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52599S'  /*Other fractures of lower end of unspecified radius, sequela*/
,'S52601D'  /*Unspecified fracture of lower end of right ulna, subsequent encounter for closed fracture with routine healing*/
,'S52601E'  /*Unspecified fracture of lower end of right ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52601F'  /*Unspecified fracture of lower end of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52601G'  /*Unspecified fracture of lower end of right ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52601H'  /*Unspecified fracture of lower end of right ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52601J'  /*Unspecified fracture of lower end of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52601K'  /*Unspecified fracture of lower end of right ulna, subsequent encounter for closed fracture with nonunion*/
,'S52601M'  /*Unspecified fracture of lower end of right ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52601N'  /*Unspecified fracture of lower end of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52601P'  /*Unspecified fracture of lower end of right ulna, subsequent encounter for closed fracture with malunion*/
,'S52601Q'  /*Unspecified fracture of lower end of right ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52601R'  /*Unspecified fracture of lower end of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52601S'  /*Unspecified fracture of lower end of right ulna, sequela*/
,'S52602D'  /*Unspecified fracture of lower end of left ulna, subsequent encounter for closed fracture with routine healing*/
,'S52602E'  /*Unspecified fracture of lower end of left ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52602F'  /*Unspecified fracture of lower end of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52602G'  /*Unspecified fracture of lower end of left ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52602H'  /*Unspecified fracture of lower end of left ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52602J'  /*Unspecified fracture of lower end of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52602K'  /*Unspecified fracture of lower end of left ulna, subsequent encounter for closed fracture with nonunion*/
,'S52602M'  /*Unspecified fracture of lower end of left ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52602N'  /*Unspecified fracture of lower end of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52602P'  /*Unspecified fracture of lower end of left ulna, subsequent encounter for closed fracture with malunion*/
,'S52602Q'  /*Unspecified fracture of lower end of left ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52602R'  /*Unspecified fracture of lower end of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52602S'  /*Unspecified fracture of lower end of left ulna, sequela*/
,'S52609D'  /*Unspecified fracture of lower end of unspecified ulna, subsequent encounter for closed fracture with routine healing*/
,'S52609E'  /*Unspecified fracture of lower end of unspecified ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52609F'  /*Unspecified fracture of lower end of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52609G'  /*Unspecified fracture of lower end of unspecified ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52609H'  /*Unspecified fracture of lower end of unspecified ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52609J'  /*Unspecified fracture of lower end of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52609K'  /*Unspecified fracture of lower end of unspecified ulna, subsequent encounter for closed fracture with nonunion*/
,'S52609M'  /*Unspecified fracture of lower end of unspecified ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52609N'  /*Unspecified fracture of lower end of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52609P'  /*Unspecified fracture of lower end of unspecified ulna, subsequent encounter for closed fracture with malunion*/
,'S52609Q'  /*Unspecified fracture of lower end of unspecified ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52609R'  /*Unspecified fracture of lower end of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52609S'  /*Unspecified fracture of lower end of unspecified ulna, sequela*/
,'S52611D'  /*Displaced fracture of right ulna styloid process, subsequent encounter for closed fracture with routine healing*/
,'S52611E'  /*Displaced fracture of right ulna styloid process, subsequent encounter for open fracture type I or II with routine healing*/
,'S52611F'  /*Displaced fracture of right ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52611G'  /*Displaced fracture of right ulna styloid process, subsequent encounter for closed fracture with delayed healing*/
,'S52611H'  /*Displaced fracture of right ulna styloid process, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52611J'  /*Displaced fracture of right ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52611K'  /*Displaced fracture of right ulna styloid process, subsequent encounter for closed fracture with nonunion*/
,'S52611M'  /*Displaced fracture of right ulna styloid process, subsequent encounter for open fracture type I or II with nonunion*/
,'S52611N'  /*Displaced fracture of right ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52611P'  /*Displaced fracture of right ulna styloid process, subsequent encounter for closed fracture with malunion*/
,'S52611Q'  /*Displaced fracture of right ulna styloid process, subsequent encounter for open fracture type I or II with malunion*/
,'S52611R'  /*Displaced fracture of right ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52611S'  /*Displaced fracture of right ulna styloid process, sequela*/
,'S52612D'  /*Displaced fracture of left ulna styloid process, subsequent encounter for closed fracture with routine healing*/
,'S52612E'  /*Displaced fracture of left ulna styloid process, subsequent encounter for open fracture type I or II with routine healing*/
,'S52612F'  /*Displaced fracture of left ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52612G'  /*Displaced fracture of left ulna styloid process, subsequent encounter for closed fracture with delayed healing*/
,'S52612H'  /*Displaced fracture of left ulna styloid process, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52612J'  /*Displaced fracture of left ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52612K'  /*Displaced fracture of left ulna styloid process, subsequent encounter for closed fracture with nonunion*/
,'S52612M'  /*Displaced fracture of left ulna styloid process, subsequent encounter for open fracture type I or II with nonunion*/
,'S52612N'  /*Displaced fracture of left ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52612P'  /*Displaced fracture of left ulna styloid process, subsequent encounter for closed fracture with malunion*/
,'S52612Q'  /*Displaced fracture of left ulna styloid process, subsequent encounter for open fracture type I or II with malunion*/
,'S52612R'  /*Displaced fracture of left ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52612S'  /*Displaced fracture of left ulna styloid process, sequela*/
,'S52613D'  /*Displaced fracture of unspecified ulna styloid process, subsequent encounter for closed fracture with routine healing*/
,'S52613E'  /*Displaced fracture of unspecified ulna styloid process, subsequent encounter for open fracture type I or II with routine healing*/
,'S52613F'  /*Displaced fracture of unspecified ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52613G'  /*Displaced fracture of unspecified ulna styloid process, subsequent encounter for closed fracture with delayed healing*/
,'S52613H'  /*Displaced fracture of unspecified ulna styloid process, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52613J'  /*Displaced fracture of unspecified ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52613K'  /*Displaced fracture of unspecified ulna styloid process, subsequent encounter for closed fracture with nonunion*/
,'S52613M'  /*Displaced fracture of unspecified ulna styloid process, subsequent encounter for open fracture type I or II with nonunion*/
,'S52613N'  /*Displaced fracture of unspecified ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52613P'  /*Displaced fracture of unspecified ulna styloid process, subsequent encounter for closed fracture with malunion*/
,'S52613Q'  /*Displaced fracture of unspecified ulna styloid process, subsequent encounter for open fracture type I or II with malunion*/
,'S52613R'  /*Displaced fracture of unspecified ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52613S'  /*Displaced fracture of unspecified ulna styloid process, sequela*/
,'S52614D'  /*Nondisplaced fracture of right ulna styloid process, subsequent encounter for closed fracture with routine healing*/
,'S52614E'  /*Nondisplaced fracture of right ulna styloid process, subsequent encounter for open fracture type I or II with routine healing*/
,'S52614F'  /*Nondisplaced fracture of right ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52614G'  /*Nondisplaced fracture of right ulna styloid process, subsequent encounter for closed fracture with delayed healing*/
,'S52614H'  /*Nondisplaced fracture of right ulna styloid process, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52614J'  /*Nondisplaced fracture of right ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52614K'  /*Nondisplaced fracture of right ulna styloid process, subsequent encounter for closed fracture with nonunion*/
,'S52614M'  /*Nondisplaced fracture of right ulna styloid process, subsequent encounter for open fracture type I or II with nonunion*/
,'S52614N'  /*Nondisplaced fracture of right ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52614P'  /*Nondisplaced fracture of right ulna styloid process, subsequent encounter for closed fracture with malunion*/
,'S52614Q'  /*Nondisplaced fracture of right ulna styloid process, subsequent encounter for open fracture type I or II with malunion*/
,'S52614R'  /*Nondisplaced fracture of right ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52614S'  /*Nondisplaced fracture of right ulna styloid process, sequela*/
,'S52615D'  /*Nondisplaced fracture of left ulna styloid process, subsequent encounter for closed fracture with routine healing*/
,'S52615E'  /*Nondisplaced fracture of left ulna styloid process, subsequent encounter for open fracture type I or II with routine healing*/
,'S52615F'  /*Nondisplaced fracture of left ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52615G'  /*Nondisplaced fracture of left ulna styloid process, subsequent encounter for closed fracture with delayed healing*/
,'S52615H'  /*Nondisplaced fracture of left ulna styloid process, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52615J'  /*Nondisplaced fracture of left ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52615K'  /*Nondisplaced fracture of left ulna styloid process, subsequent encounter for closed fracture with nonunion*/
,'S52615M'  /*Nondisplaced fracture of left ulna styloid process, subsequent encounter for open fracture type I or II with nonunion*/
,'S52615N'  /*Nondisplaced fracture of left ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52615P'  /*Nondisplaced fracture of left ulna styloid process, subsequent encounter for closed fracture with malunion*/
,'S52615Q'  /*Nondisplaced fracture of left ulna styloid process, subsequent encounter for open fracture type I or II with malunion*/
,'S52615R'  /*Nondisplaced fracture of left ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52615S'  /*Nondisplaced fracture of left ulna styloid process, sequela*/
,'S52616D'  /*Nondisplaced fracture of unspecified ulna styloid process, subsequent encounter for closed fracture with routine healing*/
,'S52616E'  /*Nondisplaced fracture of unspecified ulna styloid process, subsequent encounter for open fracture type I or II with routine healing*/
,'S52616F'  /*Nondisplaced fracture of unspecified ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52616G'  /*Nondisplaced fracture of unspecified ulna styloid process, subsequent encounter for closed fracture with delayed healing*/
,'S52616H'  /*Nondisplaced fracture of unspecified ulna styloid process, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52616J'  /*Nondisplaced fracture of unspecified ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52616K'  /*Nondisplaced fracture of unspecified ulna styloid process, subsequent encounter for closed fracture with nonunion*/
,'S52616M'  /*Nondisplaced fracture of unspecified ulna styloid process, subsequent encounter for open fracture type I or II with nonunion*/
,'S52616N'  /*Nondisplaced fracture of unspecified ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52616P'  /*Nondisplaced fracture of unspecified ulna styloid process, subsequent encounter for closed fracture with malunion*/
,'S52616Q'  /*Nondisplaced fracture of unspecified ulna styloid process, subsequent encounter for open fracture type I or II with malunion*/
,'S52616R'  /*Nondisplaced fracture of unspecified ulna styloid process, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52616S'  /*Nondisplaced fracture of unspecified ulna styloid process, sequela*/
,'S52621D'  /*Torus fracture of lower end of right ulna, subsequent encounter for fracture with routine healing*/
,'S52621G'  /*Torus fracture of lower end of right ulna, subsequent encounter for fracture with delayed healing*/
,'S52621K'  /*Torus fracture of lower end of right ulna, subsequent encounter for fracture with nonunion*/
,'S52621P'  /*Torus fracture of lower end of right ulna, subsequent encounter for fracture with malunion*/
,'S52621S'  /*Torus fracture of lower end of right ulna, sequela*/
,'S52622D'  /*Torus fracture of lower end of left ulna, subsequent encounter for fracture with routine healing*/
,'S52622G'  /*Torus fracture of lower end of left ulna, subsequent encounter for fracture with delayed healing*/
,'S52622K'  /*Torus fracture of lower end of left ulna, subsequent encounter for fracture with nonunion*/
,'S52622P'  /*Torus fracture of lower end of left ulna, subsequent encounter for fracture with malunion*/
,'S52622S'  /*Torus fracture of lower end of left ulna, sequela*/
,'S52629D'  /*Torus fracture of lower end of unspecified ulna, subsequent encounter for fracture with routine healing*/
,'S52629G'  /*Torus fracture of lower end of unspecified ulna, subsequent encounter for fracture with delayed healing*/
,'S52629K'  /*Torus fracture of lower end of unspecified ulna, subsequent encounter for fracture with nonunion*/
,'S52629P'  /*Torus fracture of lower end of unspecified ulna, subsequent encounter for fracture with malunion*/
,'S52629S'  /*Torus fracture of lower end of unspecified ulna, sequela*/
,'S52691D'  /*Other fracture of lower end of right ulna, subsequent encounter for closed fracture with routine healing*/
,'S52691E'  /*Other fracture of lower end of right ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52691F'  /*Other fracture of lower end of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52691G'  /*Other fracture of lower end of right ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52691H'  /*Other fracture of lower end of right ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52691J'  /*Other fracture of lower end of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52691K'  /*Other fracture of lower end of right ulna, subsequent encounter for closed fracture with nonunion*/
,'S52691M'  /*Other fracture of lower end of right ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52691N'  /*Other fracture of lower end of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52691P'  /*Other fracture of lower end of right ulna, subsequent encounter for closed fracture with malunion*/
,'S52691Q'  /*Other fracture of lower end of right ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52691R'  /*Other fracture of lower end of right ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52691S'  /*Other fracture of lower end of right ulna, sequela*/
,'S52692D'  /*Other fracture of lower end of left ulna, subsequent encounter for closed fracture with routine healing*/
,'S52692E'  /*Other fracture of lower end of left ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52692F'  /*Other fracture of lower end of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52692G'  /*Other fracture of lower end of left ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52692H'  /*Other fracture of lower end of left ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52692J'  /*Other fracture of lower end of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52692K'  /*Other fracture of lower end of left ulna, subsequent encounter for closed fracture with nonunion*/
,'S52692M'  /*Other fracture of lower end of left ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52692N'  /*Other fracture of lower end of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52692P'  /*Other fracture of lower end of left ulna, subsequent encounter for closed fracture with malunion*/
,'S52692Q'  /*Other fracture of lower end of left ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52692R'  /*Other fracture of lower end of left ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52692S'  /*Other fracture of lower end of left ulna, sequela*/
,'S52699D'  /*Other fracture of lower end of unspecified ulna, subsequent encounter for closed fracture with routine healing*/
,'S52699E'  /*Other fracture of lower end of unspecified ulna, subsequent encounter for open fracture type I or II with routine healing*/
,'S52699F'  /*Other fracture of lower end of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S52699G'  /*Other fracture of lower end of unspecified ulna, subsequent encounter for closed fracture with delayed healing*/
,'S52699H'  /*Other fracture of lower end of unspecified ulna, subsequent encounter for open fracture type I or II with delayed healing*/
,'S52699J'  /*Other fracture of lower end of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S52699K'  /*Other fracture of lower end of unspecified ulna, subsequent encounter for closed fracture with nonunion*/
,'S52699M'  /*Other fracture of lower end of unspecified ulna, subsequent encounter for open fracture type I or II with nonunion*/
,'S52699N'  /*Other fracture of lower end of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S52699P'  /*Other fracture of lower end of unspecified ulna, subsequent encounter for closed fracture with malunion*/
,'S52699Q'  /*Other fracture of lower end of unspecified ulna, subsequent encounter for open fracture type I or II with malunion*/
,'S52699R'  /*Other fracture of lower end of unspecified ulna, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S52699S'  /*Other fracture of lower end of unspecified ulna, sequela*/
,'S5290XD'  /*Unspecified fracture of unspecified forearm, subsequent encounter for closed fracture with routine healing*/
,'S5290XE'  /*Unspecified fracture of unspecified forearm, subsequent encounter for open fracture type I or II with routine healing*/
,'S5290XF'  /*Unspecified fracture of unspecified forearm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S5290XG'  /*Unspecified fracture of unspecified forearm, subsequent encounter for closed fracture with delayed healing*/
,'S5290XH'  /*Unspecified fracture of unspecified forearm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S5290XJ'  /*Unspecified fracture of unspecified forearm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S5290XK'  /*Unspecified fracture of unspecified forearm, subsequent encounter for closed fracture with nonunion*/
,'S5290XM'  /*Unspecified fracture of unspecified forearm, subsequent encounter for open fracture type I or II with nonunion*/
,'S5290XN'  /*Unspecified fracture of unspecified forearm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S5290XP'  /*Unspecified fracture of unspecified forearm, subsequent encounter for closed fracture with malunion*/
,'S5290XQ'  /*Unspecified fracture of unspecified forearm, subsequent encounter for open fracture type I or II with malunion*/
,'S5290XR'  /*Unspecified fracture of unspecified forearm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S5290XS'  /*Unspecified fracture of unspecified forearm, sequela*/
,'S5291XD'  /*Unspecified fracture of right forearm, subsequent encounter for closed fracture with routine healing*/
,'S5291XE'  /*Unspecified fracture of right forearm, subsequent encounter for open fracture type I or II with routine healing*/
,'S5291XF'  /*Unspecified fracture of right forearm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S5291XG'  /*Unspecified fracture of right forearm, subsequent encounter for closed fracture with delayed healing*/
,'S5291XH'  /*Unspecified fracture of right forearm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S5291XJ'  /*Unspecified fracture of right forearm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S5291XK'  /*Unspecified fracture of right forearm, subsequent encounter for closed fracture with nonunion*/
,'S5291XM'  /*Unspecified fracture of right forearm, subsequent encounter for open fracture type I or II with nonunion*/
,'S5291XN'  /*Unspecified fracture of right forearm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S5291XP'  /*Unspecified fracture of right forearm, subsequent encounter for closed fracture with malunion*/
,'S5291XQ'  /*Unspecified fracture of right forearm, subsequent encounter for open fracture type I or II with malunion*/
,'S5291XR'  /*Unspecified fracture of right forearm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S5291XS'  /*Unspecified fracture of right forearm, sequela*/
,'S5292XD'  /*Unspecified fracture of left forearm, subsequent encounter for closed fracture with routine healing*/
,'S5292XE'  /*Unspecified fracture of left forearm, subsequent encounter for open fracture type I or II with routine healing*/
,'S5292XF'  /*Unspecified fracture of left forearm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S5292XG'  /*Unspecified fracture of left forearm, subsequent encounter for closed fracture with delayed healing*/
,'S5292XH'  /*Unspecified fracture of left forearm, subsequent encounter for open fracture type I or II with delayed healing*/
,'S5292XJ'  /*Unspecified fracture of left forearm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S5292XK'  /*Unspecified fracture of left forearm, subsequent encounter for closed fracture with nonunion*/
,'S5292XM'  /*Unspecified fracture of left forearm, subsequent encounter for open fracture type I or II with nonunion*/
,'S5292XN'  /*Unspecified fracture of left forearm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S5292XP'  /*Unspecified fracture of left forearm, subsequent encounter for closed fracture with malunion*/
,'S5292XQ'  /*Unspecified fracture of left forearm, subsequent encounter for open fracture type I or II with malunion*/
,'S5292XR'  /*Unspecified fracture of left forearm, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S5292XS'  /*Unspecified fracture of left forearm, sequela*/
,'S53001D'  /*Unspecified subluxation of right radial head, subsequent encounter*/
,'S53001S'  /*Unspecified subluxation of right radial head, sequela*/
,'S53002D'  /*Unspecified subluxation of left radial head, subsequent encounter*/
,'S53002S'  /*Unspecified subluxation of left radial head, sequela*/
,'S53003D'  /*Unspecified subluxation of unspecified radial head, subsequent encounter*/
,'S53003S'  /*Unspecified subluxation of unspecified radial head, sequela*/
,'S53004D'  /*Unspecified dislocation of right radial head, subsequent encounter*/
,'S53004S'  /*Unspecified dislocation of right radial head, sequela*/
,'S53005D'  /*Unspecified dislocation of left radial head, subsequent encounter*/
,'S53005S'  /*Unspecified dislocation of left radial head, sequela*/
,'S53006D'  /*Unspecified dislocation of unspecified radial head, subsequent encounter*/
,'S53006S'  /*Unspecified dislocation of unspecified radial head, sequela*/
,'S53011D'  /*Anterior subluxation of right radial head, subsequent encounter*/
,'S53011S'  /*Anterior subluxation of right radial head, sequela*/
,'S53012D'  /*Anterior subluxation of left radial head, subsequent encounter*/
,'S53012S'  /*Anterior subluxation of left radial head, sequela*/
,'S53013D'  /*Anterior subluxation of unspecified radial head, subsequent encounter*/
,'S53013S'  /*Anterior subluxation of unspecified radial head, sequela*/
,'S53014D'  /*Anterior dislocation of right radial head, subsequent encounter*/
,'S53014S'  /*Anterior dislocation of right radial head, sequela*/
,'S53015D'  /*Anterior dislocation of left radial head, subsequent encounter*/
,'S53015S'  /*Anterior dislocation of left radial head, sequela*/
,'S53016D'  /*Anterior dislocation of unspecified radial head, subsequent encounter*/
,'S53016S'  /*Anterior dislocation of unspecified radial head, sequela*/
,'S53021D'  /*Posterior subluxation of right radial head, subsequent encounter*/
,'S53021S'  /*Posterior subluxation of right radial head, sequela*/
,'S53022D'  /*Posterior subluxation of left radial head, subsequent encounter*/
,'S53022S'  /*Posterior subluxation of left radial head, sequela*/
,'S53023D'  /*Posterior subluxation of unspecified radial head, subsequent encounter*/
,'S53023S'  /*Posterior subluxation of unspecified radial head, sequela*/
,'S53024D'  /*Posterior dislocation of right radial head, subsequent encounter*/
,'S53024S'  /*Posterior dislocation of right radial head, sequela*/
,'S53025D'  /*Posterior dislocation of left radial head, subsequent encounter*/
,'S53025S'  /*Posterior dislocation of left radial head, sequela*/
,'S53026D'  /*Posterior dislocation of unspecified radial head, subsequent encounter*/
,'S53026S'  /*Posterior dislocation of unspecified radial head, sequela*/
,'S53031D'  /*Nursemaid's elbow, right elbow, subsequent encounter*/
,'S53031S'  /*Nursemaid's elbow, right elbow, sequela*/
,'S53032D'  /*Nursemaid's elbow, left elbow, subsequent encounter*/
,'S53032S'  /*Nursemaid's elbow, left elbow, sequela*/
,'S53033D'  /*Nursemaid's elbow, unspecified elbow, subsequent encounter*/
,'S53033S'  /*Nursemaid's elbow, unspecified elbow, sequela*/
,'S53091D'  /*Other subluxation of right radial head, subsequent encounter*/
,'S53091S'  /*Other subluxation of right radial head, sequela*/
,'S53092D'  /*Other subluxation of left radial head, subsequent encounter*/
,'S53092S'  /*Other subluxation of left radial head, sequela*/
,'S53093D'  /*Other subluxation of unspecified radial head, subsequent encounter*/
,'S53093S'  /*Other subluxation of unspecified radial head, sequela*/
,'S53094D'  /*Other dislocation of right radial head, subsequent encounter*/
,'S53094S'  /*Other dislocation of right radial head, sequela*/
,'S53095D'  /*Other dislocation of left radial head, subsequent encounter*/
,'S53095S'  /*Other dislocation of left radial head, sequela*/
,'S53096D'  /*Other dislocation of unspecified radial head, subsequent encounter*/
,'S53096S'  /*Other dislocation of unspecified radial head, sequela*/
,'S53101D'  /*Unspecified subluxation of right ulnohumeral joint, subsequent encounter*/
,'S53101S'  /*Unspecified subluxation of right ulnohumeral joint, sequela*/
,'S53102D'  /*Unspecified subluxation of left ulnohumeral joint, subsequent encounter*/
,'S53102S'  /*Unspecified subluxation of left ulnohumeral joint, sequela*/
,'S53103D'  /*Unspecified subluxation of unspecified ulnohumeral joint, subsequent encounter*/
,'S53103S'  /*Unspecified subluxation of unspecified ulnohumeral joint, sequela*/
,'S53104D'  /*Unspecified dislocation of right ulnohumeral joint, subsequent encounter*/
,'S53104S'  /*Unspecified dislocation of right ulnohumeral joint, sequela*/
,'S53105D'  /*Unspecified dislocation of left ulnohumeral joint, subsequent encounter*/
,'S53105S'  /*Unspecified dislocation of left ulnohumeral joint, sequela*/
,'S53106D'  /*Unspecified dislocation of unspecified ulnohumeral joint, subsequent encounter*/
,'S53106S'  /*Unspecified dislocation of unspecified ulnohumeral joint, sequela*/
,'S53111D'  /*Anterior subluxation of right ulnohumeral joint, subsequent encounter*/
,'S53111S'  /*Anterior subluxation of right ulnohumeral joint, sequela*/
,'S53112D'  /*Anterior subluxation of left ulnohumeral joint, subsequent encounter*/
,'S53112S'  /*Anterior subluxation of left ulnohumeral joint, sequela*/
,'S53113D'  /*Anterior subluxation of unspecified ulnohumeral joint, subsequent encounter*/
,'S53113S'  /*Anterior subluxation of unspecified ulnohumeral joint, sequela*/
,'S53114D'  /*Anterior dislocation of right ulnohumeral joint, subsequent encounter*/
,'S53114S'  /*Anterior dislocation of right ulnohumeral joint, sequela*/
,'S53115D'  /*Anterior dislocation of left ulnohumeral joint, subsequent encounter*/
,'S53115S'  /*Anterior dislocation of left ulnohumeral joint, sequela*/
,'S53116D'  /*Anterior dislocation of unspecified ulnohumeral joint, subsequent encounter*/
,'S53116S'  /*Anterior dislocation of unspecified ulnohumeral joint, sequela*/
,'S53121D'  /*Posterior subluxation of right ulnohumeral joint, subsequent encounter*/
,'S53121S'  /*Posterior subluxation of right ulnohumeral joint, sequela*/
,'S53122D'  /*Posterior subluxation of left ulnohumeral joint, subsequent encounter*/
,'S53122S'  /*Posterior subluxation of left ulnohumeral joint, sequela*/
,'S53123D'  /*Posterior subluxation of unspecified ulnohumeral joint, subsequent encounter*/
,'S53123S'  /*Posterior subluxation of unspecified ulnohumeral joint, sequela*/
,'S53124D'  /*Posterior dislocation of right ulnohumeral joint, subsequent encounter*/
,'S53124S'  /*Posterior dislocation of right ulnohumeral joint, sequela*/
,'S53125D'  /*Posterior dislocation of left ulnohumeral joint, subsequent encounter*/
,'S53125S'  /*Posterior dislocation of left ulnohumeral joint, sequela*/
,'S53126D'  /*Posterior dislocation of unspecified ulnohumeral joint, subsequent encounter*/
,'S53126S'  /*Posterior dislocation of unspecified ulnohumeral joint, sequela*/
,'S53131D'  /*Medial subluxation of right ulnohumeral joint, subsequent encounter*/
,'S53131S'  /*Medial subluxation of right ulnohumeral joint, sequela*/
,'S53132D'  /*Medial subluxation of left ulnohumeral joint, subsequent encounter*/
,'S53132S'  /*Medial subluxation of left ulnohumeral joint, sequela*/
,'S53133D'  /*Medial subluxation of unspecified ulnohumeral joint, subsequent encounter*/
,'S53133S'  /*Medial subluxation of unspecified ulnohumeral joint, sequela*/
,'S53134D'  /*Medial dislocation of right ulnohumeral joint, subsequent encounter*/
,'S53134S'  /*Medial dislocation of right ulnohumeral joint, sequela*/
,'S53135D'  /*Medial dislocation of left ulnohumeral joint, subsequent encounter*/
,'S53135S'  /*Medial dislocation of left ulnohumeral joint, sequela*/
,'S53136D'  /*Medial dislocation of unspecified ulnohumeral joint, subsequent encounter*/
,'S53136S'  /*Medial dislocation of unspecified ulnohumeral joint, sequela*/
,'S53141D'  /*Lateral subluxation of right ulnohumeral joint, subsequent encounter*/
,'S53141S'  /*Lateral subluxation of right ulnohumeral joint, sequela*/
,'S53142D'  /*Lateral subluxation of left ulnohumeral joint, subsequent encounter*/
,'S53142S'  /*Lateral subluxation of left ulnohumeral joint, sequela*/
,'S53143D'  /*Lateral subluxation of unspecified ulnohumeral joint, subsequent encounter*/
,'S53143S'  /*Lateral subluxation of unspecified ulnohumeral joint, sequela*/
,'S53144D'  /*Lateral dislocation of right ulnohumeral joint, subsequent encounter*/
,'S53144S'  /*Lateral dislocation of right ulnohumeral joint, sequela*/
,'S53145D'  /*Lateral dislocation of left ulnohumeral joint, subsequent encounter*/
,'S53145S'  /*Lateral dislocation of left ulnohumeral joint, sequela*/
,'S53146D'  /*Lateral dislocation of unspecified ulnohumeral joint, subsequent encounter*/
,'S53146S'  /*Lateral dislocation of unspecified ulnohumeral joint, sequela*/
,'S53191D'  /*Other subluxation of right ulnohumeral joint, subsequent encounter*/
,'S53191S'  /*Other subluxation of right ulnohumeral joint, sequela*/
,'S53192D'  /*Other subluxation of left ulnohumeral joint, subsequent encounter*/
,'S53192S'  /*Other subluxation of left ulnohumeral joint, sequela*/
,'S53193D'  /*Other subluxation of unspecified ulnohumeral joint, subsequent encounter*/
,'S53193S'  /*Other subluxation of unspecified ulnohumeral joint, sequela*/
,'S53194D'  /*Other dislocation of right ulnohumeral joint, subsequent encounter*/
,'S53194S'  /*Other dislocation of right ulnohumeral joint, sequela*/
,'S53195D'  /*Other dislocation of left ulnohumeral joint, subsequent encounter*/
,'S53195S'  /*Other dislocation of left ulnohumeral joint, sequela*/
,'S53196D'  /*Other dislocation of unspecified ulnohumeral joint, subsequent encounter*/
,'S53196S'  /*Other dislocation of unspecified ulnohumeral joint, sequela*/
,'S5320XD'  /*Traumatic rupture of unspecified radial collateral ligament, subsequent encounter*/
,'S5320XS'  /*Traumatic rupture of unspecified radial collateral ligament, sequela*/
,'S5321XD'  /*Traumatic rupture of right radial collateral ligament, subsequent encounter*/
,'S5321XS'  /*Traumatic rupture of right radial collateral ligament, sequela*/
,'S5322XD'  /*Traumatic rupture of left radial collateral ligament, subsequent encounter*/
,'S5322XS'  /*Traumatic rupture of left radial collateral ligament, sequela*/
,'S5330XD'  /*Traumatic rupture of unspecified ulnar collateral ligament, subsequent encounter*/
,'S5330XS'  /*Traumatic rupture of unspecified ulnar collateral ligament, sequela*/
,'S5331XD'  /*Traumatic rupture of right ulnar collateral ligament, subsequent encounter*/
,'S5331XS'  /*Traumatic rupture of right ulnar collateral ligament, sequela*/
,'S5332XD'  /*Traumatic rupture of left ulnar collateral ligament, subsequent encounter*/
,'S5332XS'  /*Traumatic rupture of left ulnar collateral ligament, sequela*/
,'S53401D'  /*Unspecified sprain of right elbow, subsequent encounter*/
,'S53401S'  /*Unspecified sprain of right elbow, sequela*/
,'S53402D'  /*Unspecified sprain of left elbow, subsequent encounter*/
,'S53402S'  /*Unspecified sprain of left elbow, sequela*/
,'S53409D'  /*Unspecified sprain of unspecified elbow, subsequent encounter*/
,'S53409S'  /*Unspecified sprain of unspecified elbow, sequela*/
,'S53411D'  /*Radiohumeral (joint) sprain of right elbow, subsequent encounter*/
,'S53411S'  /*Radiohumeral (joint) sprain of right elbow, sequela*/
,'S53412D'  /*Radiohumeral (joint) sprain of left elbow, subsequent encounter*/
,'S53412S'  /*Radiohumeral (joint) sprain of left elbow, sequela*/
,'S53419D'  /*Radiohumeral (joint) sprain of unspecified elbow, subsequent encounter*/
,'S53419S'  /*Radiohumeral (joint) sprain of unspecified elbow, sequela*/
,'S53421D'  /*Ulnohumeral (joint) sprain of right elbow, subsequent encounter*/
,'S53421S'  /*Ulnohumeral (joint) sprain of right elbow, sequela*/
,'S53422D'  /*Ulnohumeral (joint) sprain of left elbow, subsequent encounter*/
,'S53422S'  /*Ulnohumeral (joint) sprain of left elbow, sequela*/
,'S53429D'  /*Ulnohumeral (joint) sprain of unspecified elbow, subsequent encounter*/
,'S53429S'  /*Ulnohumeral (joint) sprain of unspecified elbow, sequela*/
,'S53431D'  /*Radial collateral ligament sprain of right elbow, subsequent encounter*/
,'S53431S'  /*Radial collateral ligament sprain of right elbow, sequela*/
,'S53432D'  /*Radial collateral ligament sprain of left elbow, subsequent encounter*/
,'S53432S'  /*Radial collateral ligament sprain of left elbow, sequela*/
,'S53439D'  /*Radial collateral ligament sprain of unspecified elbow, subsequent encounter*/
,'S53439S'  /*Radial collateral ligament sprain of unspecified elbow, sequela*/
,'S53441D'  /*Ulnar collateral ligament sprain of right elbow, subsequent encounter*/
,'S53441S'  /*Ulnar collateral ligament sprain of right elbow, sequela*/
,'S53442D'  /*Ulnar collateral ligament sprain of left elbow, subsequent encounter*/
,'S53442S'  /*Ulnar collateral ligament sprain of left elbow, sequela*/
,'S53449D'  /*Ulnar collateral ligament sprain of unspecified elbow, subsequent encounter*/
,'S53449S'  /*Ulnar collateral ligament sprain of unspecified elbow, sequela*/
,'S53491D'  /*Other sprain of right elbow, subsequent encounter*/
,'S53491S'  /*Other sprain of right elbow, sequela*/
,'S53492D'  /*Other sprain of left elbow, subsequent encounter*/
,'S53492S'  /*Other sprain of left elbow, sequela*/
,'S53499D'  /*Other sprain of unspecified elbow, subsequent encounter*/
,'S53499S'  /*Other sprain of unspecified elbow, sequela*/
,'S5400XD'  /*Injury of ulnar nerve at forearm level, unspecified arm, subsequent encounter*/
,'S5400XS'  /*Injury of ulnar nerve at forearm level, unspecified arm, sequela*/
,'S5401XD'  /*Injury of ulnar nerve at forearm level, right arm, subsequent encounter*/
,'S5401XS'  /*Injury of ulnar nerve at forearm level, right arm, sequela*/
,'S5402XD'  /*Injury of ulnar nerve at forearm level, left arm, subsequent encounter*/
,'S5402XS'  /*Injury of ulnar nerve at forearm level, left arm, sequela*/
,'S5410XD'  /*Injury of median nerve at forearm level, unspecified arm, subsequent encounter*/
,'S5410XS'  /*Injury of median nerve at forearm level, unspecified arm, sequela*/
,'S5411XD'  /*Injury of median nerve at forearm level, right arm, subsequent encounter*/
,'S5411XS'  /*Injury of median nerve at forearm level, right arm, sequela*/
,'S5412XD'  /*Injury of median nerve at forearm level, left arm, subsequent encounter*/
,'S5412XS'  /*Injury of median nerve at forearm level, left arm, sequela*/
,'S5420XD'  /*Injury of radial nerve at forearm level, unspecified arm, subsequent encounter*/
,'S5420XS'  /*Injury of radial nerve at forearm level, unspecified arm, sequela*/
,'S5421XD'  /*Injury of radial nerve at forearm level, right arm, subsequent encounter*/
,'S5421XS'  /*Injury of radial nerve at forearm level, right arm, sequela*/
,'S5422XD'  /*Injury of radial nerve at forearm level, left arm, subsequent encounter*/
,'S5422XS'  /*Injury of radial nerve at forearm level, left arm, sequela*/
,'S5430XD'  /*Injury of cutaneous sensory nerve at forearm level, unspecified arm, subsequent encounter*/
,'S5430XS'  /*Injury of cutaneous sensory nerve at forearm level, unspecified arm, sequela*/
,'S5431XD'  /*Injury of cutaneous sensory nerve at forearm level, right arm, subsequent encounter*/
,'S5431XS'  /*Injury of cutaneous sensory nerve at forearm level, right arm, sequela*/
,'S5432XD'  /*Injury of cutaneous sensory nerve at forearm level, left arm, subsequent encounter*/
,'S5432XS'  /*Injury of cutaneous sensory nerve at forearm level, left arm, sequela*/
,'S548X1D'  /*Injury of other nerves at forearm level, right arm, subsequent encounter*/
,'S548X1S'  /*Injury of other nerves at forearm level, right arm, sequela*/
,'S548X2D'  /*Injury of other nerves at forearm level, left arm, subsequent encounter*/
,'S548X2S'  /*Injury of other nerves at forearm level, left arm, sequela*/
,'S548X9D'  /*Injury of other nerves at forearm level, unspecified arm, subsequent encounter*/
,'S548X9S'  /*Injury of other nerves at forearm level, unspecified arm, sequela*/
,'S5490XD'  /*Injury of unspecified nerve at forearm level, unspecified arm, subsequent encounter*/
,'S5490XS'  /*Injury of unspecified nerve at forearm level, unspecified arm, sequela*/
,'S5491XD'  /*Injury of unspecified nerve at forearm level, right arm, subsequent encounter*/
,'S5491XS'  /*Injury of unspecified nerve at forearm level, right arm, sequela*/
,'S5492XD'  /*Injury of unspecified nerve at forearm level, left arm, subsequent encounter*/
,'S5492XS'  /*Injury of unspecified nerve at forearm level, left arm, sequela*/
,'S55001D'  /*Unspecified injury of ulnar artery at forearm level, right arm, subsequent encounter*/
,'S55001S'  /*Unspecified injury of ulnar artery at forearm level, right arm, sequela*/
,'S55002D'  /*Unspecified injury of ulnar artery at forearm level, left arm, subsequent encounter*/
,'S55002S'  /*Unspecified injury of ulnar artery at forearm level, left arm, sequela*/
,'S55009D'  /*Unspecified injury of ulnar artery at forearm level, unspecified arm, subsequent encounter*/
,'S55009S'  /*Unspecified injury of ulnar artery at forearm level, unspecified arm, sequela*/
,'S55011D'  /*Laceration of ulnar artery at forearm level, right arm, subsequent encounter*/
,'S55011S'  /*Laceration of ulnar artery at forearm level, right arm, sequela*/
,'S55012D'  /*Laceration of ulnar artery at forearm level, left arm, subsequent encounter*/
,'S55012S'  /*Laceration of ulnar artery at forearm level, left arm, sequela*/
,'S55019D'  /*Laceration of ulnar artery at forearm level, unspecified arm, subsequent encounter*/
,'S55019S'  /*Laceration of ulnar artery at forearm level, unspecified arm, sequela*/
,'S55091D'  /*Other specified injury of ulnar artery at forearm level, right arm, subsequent encounter*/
,'S55091S'  /*Other specified injury of ulnar artery at forearm level, right arm, sequela*/
,'S55092D'  /*Other specified injury of ulnar artery at forearm level, left arm, subsequent encounter*/
,'S55092S'  /*Other specified injury of ulnar artery at forearm level, left arm, sequela*/
,'S55099D'  /*Other specified injury of ulnar artery at forearm level, unspecified arm, subsequent encounter*/
,'S55099S'  /*Other specified injury of ulnar artery at forearm level, unspecified arm, sequela*/
,'S55101D'  /*Unspecified injury of radial artery at forearm level, right arm, subsequent encounter*/
,'S55101S'  /*Unspecified injury of radial artery at forearm level, right arm, sequela*/
,'S55102D'  /*Unspecified injury of radial artery at forearm level, left arm, subsequent encounter*/
,'S55102S'  /*Unspecified injury of radial artery at forearm level, left arm, sequela*/
,'S55109D'  /*Unspecified injury of radial artery at forearm level, unspecified arm, subsequent encounter*/
,'S55109S'  /*Unspecified injury of radial artery at forearm level, unspecified arm, sequela*/
,'S55111D'  /*Laceration of radial artery at forearm level, right arm, subsequent encounter*/
,'S55111S'  /*Laceration of radial artery at forearm level, right arm, sequela*/
,'S55112D'  /*Laceration of radial artery at forearm level, left arm, subsequent encounter*/
,'S55112S'  /*Laceration of radial artery at forearm level, left arm, sequela*/
,'S55119D'  /*Laceration of radial artery at forearm level, unspecified arm, subsequent encounter*/
,'S55119S'  /*Laceration of radial artery at forearm level, unspecified arm, sequela*/
,'S55191D'  /*Other specified injury of radial artery at forearm level, right arm, subsequent encounter*/
,'S55191S'  /*Other specified injury of radial artery at forearm level, right arm, sequela*/
,'S55192D'  /*Other specified injury of radial artery at forearm level, left arm, subsequent encounter*/
,'S55192S'  /*Other specified injury of radial artery at forearm level, left arm, sequela*/
,'S55199D'  /*Other specified injury of radial artery at forearm level, unspecified arm, subsequent encounter*/
,'S55199S'  /*Other specified injury of radial artery at forearm level, unspecified arm, sequela*/
,'S55201D'  /*Unspecified injury of vein at forearm level, right arm, subsequent encounter*/
,'S55201S'  /*Unspecified injury of vein at forearm level, right arm, sequela*/
,'S55202D'  /*Unspecified injury of vein at forearm level, left arm, subsequent encounter*/
,'S55202S'  /*Unspecified injury of vein at forearm level, left arm, sequela*/
,'S55209D'  /*Unspecified injury of vein at forearm level, unspecified arm, subsequent encounter*/
,'S55209S'  /*Unspecified injury of vein at forearm level, unspecified arm, sequela*/
,'S55211D'  /*Laceration of vein at forearm level, right arm, subsequent encounter*/
,'S55211S'  /*Laceration of vein at forearm level, right arm, sequela*/
,'S55212D'  /*Laceration of vein at forearm level, left arm, subsequent encounter*/
,'S55212S'  /*Laceration of vein at forearm level, left arm, sequela*/
,'S55219D'  /*Laceration of vein at forearm level, unspecified arm, subsequent encounter*/
,'S55219S'  /*Laceration of vein at forearm level, unspecified arm, sequela*/
,'S55291D'  /*Other specified injury of vein at forearm level, right arm, subsequent encounter*/
,'S55291S'  /*Other specified injury of vein at forearm level, right arm, sequela*/
,'S55292D'  /*Other specified injury of vein at forearm level, left arm, subsequent encounter*/
,'S55292S'  /*Other specified injury of vein at forearm level, left arm, sequela*/
,'S55299D'  /*Other specified injury of vein at forearm level, unspecified arm, subsequent encounter*/
,'S55299S'  /*Other specified injury of vein at forearm level, unspecified arm, sequela*/
,'S55801D'  /*Unspecified injury of other blood vessels at forearm level, right arm, subsequent encounter*/
,'S55801S'  /*Unspecified injury of other blood vessels at forearm level, right arm, sequela*/
,'S55802D'  /*Unspecified injury of other blood vessels at forearm level, left arm, subsequent encounter*/
,'S55802S'  /*Unspecified injury of other blood vessels at forearm level, left arm, sequela*/
,'S55809D'  /*Unspecified injury of other blood vessels at forearm level, unspecified arm, subsequent encounter*/
,'S55809S'  /*Unspecified injury of other blood vessels at forearm level, unspecified arm, sequela*/
,'S55811D'  /*Laceration of other blood vessels at forearm level, right arm, subsequent encounter*/
,'S55811S'  /*Laceration of other blood vessels at forearm level, right arm, sequela*/
,'S55812D'  /*Laceration of other blood vessels at forearm level, left arm, subsequent encounter*/
,'S55812S'  /*Laceration of other blood vessels at forearm level, left arm, sequela*/
,'S55819D'  /*Laceration of other blood vessels at forearm level, unspecified arm, subsequent encounter*/
,'S55819S'  /*Laceration of other blood vessels at forearm level, unspecified arm, sequela*/
,'S55891D'  /*Other specified injury of other blood vessels at forearm level, right arm, subsequent encounter*/
,'S55891S'  /*Other specified injury of other blood vessels at forearm level, right arm, sequela*/
,'S55892D'  /*Other specified injury of other blood vessels at forearm level, left arm, subsequent encounter*/
,'S55892S'  /*Other specified injury of other blood vessels at forearm level, left arm, sequela*/
,'S55899D'  /*Other specified injury of other blood vessels at forearm level, unspecified arm, subsequent encounter*/
,'S55899S'  /*Other specified injury of other blood vessels at forearm level, unspecified arm, sequela*/
,'S55901D'  /*Unspecified injury of unspecified blood vessel at forearm level, right arm, subsequent encounter*/
,'S55901S'  /*Unspecified injury of unspecified blood vessel at forearm level, right arm, sequela*/
,'S55902D'  /*Unspecified injury of unspecified blood vessel at forearm level, left arm, subsequent encounter*/
,'S55902S'  /*Unspecified injury of unspecified blood vessel at forearm level, left arm, sequela*/
,'S55909D'  /*Unspecified injury of unspecified blood vessel at forearm level, unspecified arm, subsequent encounter*/
,'S55909S'  /*Unspecified injury of unspecified blood vessel at forearm level, unspecified arm, sequela*/
,'S55911D'  /*Laceration of unspecified blood vessel at forearm level, right arm, subsequent encounter*/
,'S55911S'  /*Laceration of unspecified blood vessel at forearm level, right arm, sequela*/
,'S55912D'  /*Laceration of unspecified blood vessel at forearm level, left arm, subsequent encounter*/
,'S55912S'  /*Laceration of unspecified blood vessel at forearm level, left arm, sequela*/
,'S55919D'  /*Laceration of unspecified blood vessel at forearm level, unspecified arm, subsequent encounter*/
,'S55919S'  /*Laceration of unspecified blood vessel at forearm level, unspecified arm, sequela*/
,'S55991D'  /*Other specified injury of unspecified blood vessel at forearm level, right arm, subsequent encounter*/
,'S55991S'  /*Other specified injury of unspecified blood vessel at forearm level, right arm, sequela*/
,'S55992D'  /*Other specified injury of unspecified blood vessel at forearm level, left arm, subsequent encounter*/
,'S55992S'  /*Other specified injury of unspecified blood vessel at forearm level, left arm, sequela*/
,'S55999D'  /*Other specified injury of unspecified blood vessel at forearm level, unspecified arm, subsequent encounter*/
,'S55999S'  /*Other specified injury of unspecified blood vessel at forearm level, unspecified arm, sequela*/
,'S56001D'  /*Unspecified injury of flexor muscle, fascia and tendon of right thumb at forearm level, subsequent encounter*/
,'S56001S'  /*Unspecified injury of flexor muscle, fascia and tendon of right thumb at forearm level, sequela*/
,'S56002D'  /*Unspecified injury of flexor muscle, fascia and tendon of left thumb at forearm level, subsequent encounter*/
,'S56002S'  /*Unspecified injury of flexor muscle, fascia and tendon of left thumb at forearm level, sequela*/
,'S56009D'  /*Unspecified injury of flexor muscle, fascia and tendon of unspecified thumb at forearm level, subsequent encounter*/
,'S56009S'  /*Unspecified injury of flexor muscle, fascia and tendon of unspecified thumb at forearm level, sequela*/
,'S56011D'  /*Strain of flexor muscle, fascia and tendon of right thumb at forearm level, subsequent encounter*/
,'S56011S'  /*Strain of flexor muscle, fascia and tendon of right thumb at forearm level, sequela*/
,'S56012D'  /*Strain of flexor muscle, fascia and tendon of left thumb at forearm level, subsequent encounter*/
,'S56012S'  /*Strain of flexor muscle, fascia and tendon of left thumb at forearm level, sequela*/
,'S56019D'  /*Strain of flexor muscle, fascia and tendon of unspecified thumb at forearm level, subsequent encounter*/
,'S56019S'  /*Strain of flexor muscle, fascia and tendon of unspecified thumb at forearm level, sequela*/
,'S56021D'  /*Laceration of flexor muscle, fascia and tendon of right thumb at forearm level, subsequent encounter*/
,'S56021S'  /*Laceration of flexor muscle, fascia and tendon of right thumb at forearm level, sequela*/
,'S56022D'  /*Laceration of flexor muscle, fascia and tendon of left thumb at forearm level, subsequent encounter*/
,'S56022S'  /*Laceration of flexor muscle, fascia and tendon of left thumb at forearm level, sequela*/
,'S56029D'  /*Laceration of flexor muscle, fascia and tendon of unspecified thumb at forearm level, subsequent encounter*/
,'S56029S'  /*Laceration of flexor muscle, fascia and tendon of unspecified thumb at forearm level, sequela*/
,'S56091D'  /*Other injury of flexor muscle, fascia and tendon of right thumb at forearm level, subsequent encounter*/
,'S56091S'  /*Other injury of flexor muscle, fascia and tendon of right thumb at forearm level, sequela*/
,'S56092D'  /*Other injury of flexor muscle, fascia and tendon of left thumb at forearm level, subsequent encounter*/
,'S56092S'  /*Other injury of flexor muscle, fascia and tendon of left thumb at forearm level, sequela*/
,'S56099D'  /*Other injury of flexor muscle, fascia and tendon of unspecified thumb at forearm level, subsequent encounter*/
,'S56099S'  /*Other injury of flexor muscle, fascia and tendon of unspecified thumb at forearm level, sequela*/
,'S56101D'  /*Unspecified injury of flexor muscle, fascia and tendon of right index finger at forearm level, subsequent encounter*/
,'S56101S'  /*Unspecified injury of flexor muscle, fascia and tendon of right index finger at forearm level, sequela*/
,'S56102D'  /*Unspecified injury of flexor muscle, fascia and tendon of left index finger at forearm level, subsequent encounter*/
,'S56102S'  /*Unspecified injury of flexor muscle, fascia and tendon of left index finger at forearm level, sequela*/
,'S56103D'  /*Unspecified injury of flexor muscle, fascia and tendon of right middle finger at forearm level, subsequent encounter*/
,'S56103S'  /*Unspecified injury of flexor muscle, fascia and tendon of right middle finger at forearm level, sequela*/
,'S56104D'  /*Unspecified injury of flexor muscle, fascia and tendon of left middle finger at forearm level, subsequent encounter*/
,'S56104S'  /*Unspecified injury of flexor muscle, fascia and tendon of left middle finger at forearm level, sequela*/
,'S56105D'  /*Unspecified injury of flexor muscle, fascia and tendon of right ring finger at forearm level, subsequent encounter*/
,'S56105S'  /*Unspecified injury of flexor muscle, fascia and tendon of right ring finger at forearm level, sequela*/
,'S56106D'  /*Unspecified injury of flexor muscle, fascia and tendon of left ring finger at forearm level, subsequent encounter*/
,'S56106S'  /*Unspecified injury of flexor muscle, fascia and tendon of left ring finger at forearm level, sequela*/
,'S56107D'  /*Unspecified injury of flexor muscle, fascia and tendon of right little finger at forearm level, subsequent encounter*/
,'S56107S'  /*Unspecified injury of flexor muscle, fascia and tendon of right little finger at forearm level, sequela*/
,'S56108D'  /*Unspecified injury of flexor muscle, fascia and tendon of left little finger at forearm level, subsequent encounter*/
,'S56108S'  /*Unspecified injury of flexor muscle, fascia and tendon of left little finger at forearm level, sequela*/
,'S56109D'  /*Unspecified injury of flexor muscle, fascia and tendon of unspecified finger at forearm level, subsequent encounter*/
,'S56109S'  /*Unspecified injury of flexor muscle, fascia and tendon of unspecified finger at forearm level, sequela*/
,'S56111D'  /*Strain of flexor muscle, fascia and tendon of right index finger at forearm level, subsequent encounter*/
,'S56111S'  /*Strain of flexor muscle, fascia and tendon of right index finger at forearm level, sequela*/
,'S56112D'  /*Strain of flexor muscle, fascia and tendon of left index finger at forearm level, subsequent encounter*/
,'S56112S'  /*Strain of flexor muscle, fascia and tendon of left index finger at forearm level, sequela*/
,'S56113D'  /*Strain of flexor muscle, fascia and tendon of right middle finger at forearm level, subsequent encounter*/
,'S56113S'  /*Strain of flexor muscle, fascia and tendon of right middle finger at forearm level, sequela*/
,'S56114D'  /*Strain of flexor muscle, fascia and tendon of left middle finger at forearm level, subsequent encounter*/
,'S56114S'  /*Strain of flexor muscle, fascia and tendon of left middle finger at forearm level, sequela*/
,'S56115D'  /*Strain of flexor muscle, fascia and tendon of right ring finger at forearm level, subsequent encounter*/
,'S56115S'  /*Strain of flexor muscle, fascia and tendon of right ring finger at forearm level, sequela*/
,'S56116D'  /*Strain of flexor muscle, fascia and tendon of left ring finger at forearm level, subsequent encounter*/
,'S56116S'  /*Strain of flexor muscle, fascia and tendon of left ring finger at forearm level, sequela*/
,'S56117D'  /*Strain of flexor muscle, fascia and tendon of right little finger at forearm level, subsequent encounter*/
,'S56117S'  /*Strain of flexor muscle, fascia and tendon of right little finger at forearm level, sequela*/
,'S56118D'  /*Strain of flexor muscle, fascia and tendon of left little finger at forearm level, subsequent encounter*/
,'S56118S'  /*Strain of flexor muscle, fascia and tendon of left little finger at forearm level, sequela*/
,'S56119D'  /*Strain of flexor muscle, fascia and tendon of finger of unspecified finger at forearm level, subsequent encounter*/
,'S56119S'  /*Strain of flexor muscle, fascia and tendon of finger of unspecified finger at forearm level, sequela*/
,'S56121D'  /*Laceration of flexor muscle, fascia and tendon of right index finger at forearm level, subsequent encounter*/
,'S56121S'  /*Laceration of flexor muscle, fascia and tendon of right index finger at forearm level, sequela*/
,'S56122D'  /*Laceration of flexor muscle, fascia and tendon of left index finger at forearm level, subsequent encounter*/
,'S56122S'  /*Laceration of flexor muscle, fascia and tendon of left index finger at forearm level, sequela*/
,'S56123D'  /*Laceration of flexor muscle, fascia and tendon of right middle finger at forearm level, subsequent encounter*/
,'S56123S'  /*Laceration of flexor muscle, fascia and tendon of right middle finger at forearm level, sequela*/
,'S56124D'  /*Laceration of flexor muscle, fascia and tendon of left middle finger at forearm level, subsequent encounter*/
,'S56124S'  /*Laceration of flexor muscle, fascia and tendon of left middle finger at forearm level, sequela*/
,'S56125D'  /*Laceration of flexor muscle, fascia and tendon of right ring finger at forearm level, subsequent encounter*/
,'S56125S'  /*Laceration of flexor muscle, fascia and tendon of right ring finger at forearm level, sequela*/
,'S56126D'  /*Laceration of flexor muscle, fascia and tendon of left ring finger at forearm level, subsequent encounter*/
,'S56126S'  /*Laceration of flexor muscle, fascia and tendon of left ring finger at forearm level, sequela*/
,'S56127D'  /*Laceration of flexor muscle, fascia and tendon of right little finger at forearm level, subsequent encounter*/
,'S56127S'  /*Laceration of flexor muscle, fascia and tendon of right little finger at forearm level, sequela*/
,'S56128D'  /*Laceration of flexor muscle, fascia and tendon of left little finger at forearm level, subsequent encounter*/
,'S56128S'  /*Laceration of flexor muscle, fascia and tendon of left little finger at forearm level, sequela*/
,'S56129D'  /*Laceration of flexor muscle, fascia and tendon of unspecified finger at forearm level, subsequent encounter*/
,'S56129S'  /*Laceration of flexor muscle, fascia and tendon of unspecified finger at forearm level, sequela*/
,'S56191D'  /*Other injury of flexor muscle, fascia and tendon of right index finger at forearm level, subsequent encounter*/
,'S56191S'  /*Other injury of flexor muscle, fascia and tendon of right index finger at forearm level, sequela*/
,'S56192D'  /*Other injury of flexor muscle, fascia and tendon of left index finger at forearm level, subsequent encounter*/
,'S56192S'  /*Other injury of flexor muscle, fascia and tendon of left index finger at forearm level, sequela*/
,'S56193D'  /*Other injury of flexor muscle, fascia and tendon of right middle finger at forearm level, subsequent encounter*/
,'S56193S'  /*Other injury of flexor muscle, fascia and tendon of right middle finger at forearm level, sequela*/
,'S56194D'  /*Other injury of flexor muscle, fascia and tendon of left middle finger at forearm level, subsequent encounter*/
,'S56194S'  /*Other injury of flexor muscle, fascia and tendon of left middle finger at forearm level, sequela*/
,'S56195D'  /*Other injury of flexor muscle, fascia and tendon of right ring finger at forearm level, subsequent encounter*/
,'S56195S'  /*Other injury of flexor muscle, fascia and tendon of right ring finger at forearm level, sequela*/
,'S56196D'  /*Other injury of flexor muscle, fascia and tendon of left ring finger at forearm level, subsequent encounter*/
,'S56196S'  /*Other injury of flexor muscle, fascia and tendon of left ring finger at forearm level, sequela*/
,'S56197D'  /*Other injury of flexor muscle, fascia and tendon of right little finger at forearm level, subsequent encounter*/
,'S56197S'  /*Other injury of flexor muscle, fascia and tendon of right little finger at forearm level, sequela*/
,'S56198D'  /*Other injury of flexor muscle, fascia and tendon of left little finger at forearm level, subsequent encounter*/
,'S56198S'  /*Other injury of flexor muscle, fascia and tendon of left little finger at forearm level, sequela*/
,'S56199D'  /*Other injury of flexor muscle, fascia and tendon of unspecified finger at forearm level, subsequent encounter*/
,'S56199S'  /*Other injury of flexor muscle, fascia and tendon of unspecified finger at forearm level, sequela*/
,'S56201D'  /*Unspecified injury of other flexor muscle, fascia and tendon at forearm level, right arm, subsequent encounter*/
,'S56201S'  /*Unspecified injury of other flexor muscle, fascia and tendon at forearm level, right arm, sequela*/
,'S56202D'  /*Unspecified injury of other flexor muscle, fascia and tendon at forearm level, left arm, subsequent encounter*/
,'S56202S'  /*Unspecified injury of other flexor muscle, fascia and tendon at forearm level, left arm, sequela*/
,'S56209D'  /*Unspecified injury of other flexor muscle, fascia and tendon at forearm level, unspecified arm, subsequent encounter*/
,'S56209S'  /*Unspecified injury of other flexor muscle, fascia and tendon at forearm level, unspecified arm, sequela*/
,'S56211D'  /*Strain of other flexor muscle, fascia and tendon at forearm level, right arm, subsequent encounter*/
,'S56211S'  /*Strain of other flexor muscle, fascia and tendon at forearm level, right arm, sequela*/
,'S56212D'  /*Strain of other flexor muscle, fascia and tendon at forearm level, left arm, subsequent encounter*/
,'S56212S'  /*Strain of other flexor muscle, fascia and tendon at forearm level, left arm, sequela*/
,'S56219D'  /*Strain of other flexor muscle, fascia and tendon at forearm level, unspecified arm, subsequent encounter*/
,'S56219S'  /*Strain of other flexor muscle, fascia and tendon at forearm level, unspecified arm, sequela*/
,'S56221D'  /*Laceration of other flexor muscle, fascia and tendon at forearm level, right arm, subsequent encounter*/
,'S56221S'  /*Laceration of other flexor muscle, fascia and tendon at forearm level, right arm, sequela*/
,'S56222D'  /*Laceration of other flexor muscle, fascia and tendon at forearm level, left arm, subsequent encounter*/
,'S56222S'  /*Laceration of other flexor muscle, fascia and tendon at forearm level, left arm, sequela*/
,'S56229D'  /*Laceration of other flexor muscle, fascia and tendon at forearm level, unspecified arm, subsequent encounter*/
,'S56229S'  /*Laceration of other flexor muscle, fascia and tendon at forearm level, unspecified arm, sequela*/
,'S56291D'  /*Other injury of other flexor muscle, fascia and tendon at forearm level, right arm, subsequent encounter*/
,'S56291S'  /*Other injury of other flexor muscle, fascia and tendon at forearm level, right arm, sequela*/
,'S56292D'  /*Other injury of other flexor muscle, fascia and tendon at forearm level, left arm, subsequent encounter*/
,'S56292S'  /*Other injury of other flexor muscle, fascia and tendon at forearm level, left arm, sequela*/
,'S56299D'  /*Other injury of other flexor muscle, fascia and tendon at forearm level, unspecified arm, subsequent encounter*/
,'S56299S'  /*Other injury of other flexor muscle, fascia and tendon at forearm level, unspecified arm, sequela*/
,'S56301D'  /*Unspecified injury of extensor or abductor muscles, fascia and tendons of right thumb at forearm level, subsequent encounter*/
,'S56301S'  /*Unspecified injury of extensor or abductor muscles, fascia and tendons of right thumb at forearm level, sequela*/
,'S56302D'  /*Unspecified injury of extensor or abductor muscles, fascia and tendons of left thumb at forearm level, subsequent encounter*/
,'S56302S'  /*Unspecified injury of extensor or abductor muscles, fascia and tendons of left thumb at forearm level, sequela*/
,'S56309D'  /*Unspecified injury of extensor or abductor muscles, fascia and tendons of unspecified thumb at forearm level, subsequent encounter*/
,'S56309S'  /*Unspecified injury of extensor or abductor muscles, fascia and tendons of unspecified thumb at forearm level, sequela*/
,'S56311D'  /*Strain of extensor or abductor muscles, fascia and tendons of right thumb at forearm level, subsequent encounter*/
,'S56311S'  /*Strain of extensor or abductor muscles, fascia and tendons of right thumb at forearm level, sequela*/
,'S56312D'  /*Strain of extensor or abductor muscles, fascia and tendons of left thumb at forearm level, subsequent encounter*/
,'S56312S'  /*Strain of extensor or abductor muscles, fascia and tendons of left thumb at forearm level, sequela*/
,'S56319D'  /*Strain of extensor or abductor muscles, fascia and tendons of unspecified thumb at forearm level, subsequent encounter*/
,'S56319S'  /*Strain of extensor or abductor muscles, fascia and tendons of unspecified thumb at forearm level, sequela*/
,'S56321D'  /*Laceration of extensor or abductor muscles, fascia and tendons of right thumb at forearm level, subsequent encounter*/
,'S56321S'  /*Laceration of extensor or abductor muscles, fascia and tendons of right thumb at forearm level, sequela*/
,'S56322D'  /*Laceration of extensor or abductor muscles, fascia and tendons of left thumb at forearm level, subsequent encounter*/
,'S56322S'  /*Laceration of extensor or abductor muscles, fascia and tendons of left thumb at forearm level, sequela*/
,'S56329D'  /*Laceration of extensor or abductor muscles, fascia and tendons of unspecified thumb at forearm level, subsequent encounter*/
,'S56329S'  /*Laceration of extensor or abductor muscles, fascia and tendons of unspecified thumb at forearm level, sequela*/
,'S56391D'  /*Other injury of extensor or abductor muscles, fascia and tendons of right thumb at forearm level, subsequent encounter*/
,'S56391S'  /*Other injury of extensor or abductor muscles, fascia and tendons of right thumb at forearm level, sequela*/
,'S56392D'  /*Other injury of extensor or abductor muscles, fascia and tendons of left thumb at forearm level, subsequent encounter*/
,'S56392S'  /*Other injury of extensor or abductor muscles, fascia and tendons of left thumb at forearm level, sequela*/
,'S56399D'  /*Other injury of extensor or abductor muscles, fascia and tendons of unspecified thumb at forearm level, subsequent encounter*/
,'S56399S'  /*Other injury of extensor or abductor muscles, fascia and tendons of unspecified thumb at forearm level, sequela*/
,'S56401D'  /*Unspecified injury of extensor muscle, fascia and tendon of right index finger at forearm level, subsequent encounter*/
,'S56401S'  /*Unspecified injury of extensor muscle, fascia and tendon of right index finger at forearm level, sequela*/
,'S56402D'  /*Unspecified injury of extensor muscle, fascia and tendon of left index finger at forearm level, subsequent encounter*/
,'S56402S'  /*Unspecified injury of extensor muscle, fascia and tendon of left index finger at forearm level, sequela*/
,'S56403D'  /*Unspecified injury of extensor muscle, fascia and tendon of right middle finger at forearm level, subsequent encounter*/
,'S56403S'  /*Unspecified injury of extensor muscle, fascia and tendon of right middle finger at forearm level, sequela*/
,'S56404D'  /*Unspecified injury of extensor muscle, fascia and tendon of left middle finger at forearm level, subsequent encounter*/
,'S56404S'  /*Unspecified injury of extensor muscle, fascia and tendon of left middle finger at forearm level, sequela*/
,'S56405D'  /*Unspecified injury of extensor muscle, fascia and tendon of right ring finger at forearm level, subsequent encounter*/
,'S56405S'  /*Unspecified injury of extensor muscle, fascia and tendon of right ring finger at forearm level, sequela*/
,'S56406D'  /*Unspecified injury of extensor muscle, fascia and tendon of left ring finger at forearm level, subsequent encounter*/
,'S56406S'  /*Unspecified injury of extensor muscle, fascia and tendon of left ring finger at forearm level, sequela*/
,'S56407D'  /*Unspecified injury of extensor muscle, fascia and tendon of right little finger at forearm level, subsequent encounter*/
,'S56407S'  /*Unspecified injury of extensor muscle, fascia and tendon of right little finger at forearm level, sequela*/
,'S56408D'  /*Unspecified injury of extensor muscle, fascia and tendon of left little finger at forearm level, subsequent encounter*/
,'S56408S'  /*Unspecified injury of extensor muscle, fascia and tendon of left little finger at forearm level, sequela*/
,'S56409D'  /*Unspecified injury of extensor muscle, fascia and tendon of unspecified finger at forearm level, subsequent encounter*/
,'S56409S'  /*Unspecified injury of extensor muscle, fascia and tendon of unspecified finger at forearm level, sequela*/
,'S56411D'  /*Strain of extensor muscle, fascia and tendon of right index finger at forearm level, subsequent encounter*/
,'S56411S'  /*Strain of extensor muscle, fascia and tendon of right index finger at forearm level, sequela*/
,'S56412D'  /*Strain of extensor muscle, fascia and tendon of left index finger at forearm level, subsequent encounter*/
,'S56412S'  /*Strain of extensor muscle, fascia and tendon of left index finger at forearm level, sequela*/
,'S56413D'  /*Strain of extensor muscle, fascia and tendon of right middle finger at forearm level, subsequent encounter*/
,'S56413S'  /*Strain of extensor muscle, fascia and tendon of right middle finger at forearm level, sequela*/
,'S56414D'  /*Strain of extensor muscle, fascia and tendon of left middle finger at forearm level, subsequent encounter*/
,'S56414S'  /*Strain of extensor muscle, fascia and tendon of left middle finger at forearm level, sequela*/
,'S56415D'  /*Strain of extensor muscle, fascia and tendon of right ring finger at forearm level, subsequent encounter*/
,'S56415S'  /*Strain of extensor muscle, fascia and tendon of right ring finger at forearm level, sequela*/
,'S56416D'  /*Strain of extensor muscle, fascia and tendon of left ring finger at forearm level, subsequent encounter*/
,'S56416S'  /*Strain of extensor muscle, fascia and tendon of left ring finger at forearm level, sequela*/
,'S56417D'  /*Strain of extensor muscle, fascia and tendon of right little finger at forearm level, subsequent encounter*/
,'S56417S'  /*Strain of extensor muscle, fascia and tendon of right little finger at forearm level, sequela*/
,'S56418D'  /*Strain of extensor muscle, fascia and tendon of left little finger at forearm level, subsequent encounter*/
,'S56418S'  /*Strain of extensor muscle, fascia and tendon of left little finger at forearm level, sequela*/
,'S56419D'  /*Strain of extensor muscle, fascia and tendon of finger, unspecified finger at forearm level, subsequent encounter*/
,'S56419S'  /*Strain of extensor muscle, fascia and tendon of finger, unspecified finger at forearm level, sequela*/
,'S56421D'  /*Laceration of extensor muscle, fascia and tendon of right index finger at forearm level, subsequent encounter*/
,'S56421S'  /*Laceration of extensor muscle, fascia and tendon of right index finger at forearm level, sequela*/
,'S56422D'  /*Laceration of extensor muscle, fascia and tendon of left index finger at forearm level, subsequent encounter*/
,'S56422S'  /*Laceration of extensor muscle, fascia and tendon of left index finger at forearm level, sequela*/
,'S56423D'  /*Laceration of extensor muscle, fascia and tendon of right middle finger at forearm level, subsequent encounter*/
,'S56423S'  /*Laceration of extensor muscle, fascia and tendon of right middle finger at forearm level, sequela*/
,'S56424D'  /*Laceration of extensor muscle, fascia and tendon of left middle finger at forearm level, subsequent encounter*/
,'S56424S'  /*Laceration of extensor muscle, fascia and tendon of left middle finger at forearm level, sequela*/
,'S56425D'  /*Laceration of extensor muscle, fascia and tendon of right ring finger at forearm level, subsequent encounter*/
,'S56425S'  /*Laceration of extensor muscle, fascia and tendon of right ring finger at forearm level, sequela*/
,'S56426D'  /*Laceration of extensor muscle, fascia and tendon of left ring finger at forearm level, subsequent encounter*/
,'S56426S'  /*Laceration of extensor muscle, fascia and tendon of left ring finger at forearm level, sequela*/
,'S56427D'  /*Laceration of extensor muscle, fascia and tendon of right little finger at forearm level, subsequent encounter*/
,'S56427S'  /*Laceration of extensor muscle, fascia and tendon of right little finger at forearm level, sequela*/
,'S56428D'  /*Laceration of extensor muscle, fascia and tendon of left little finger at forearm level, subsequent encounter*/
,'S56428S'  /*Laceration of extensor muscle, fascia and tendon of left little finger at forearm level, sequela*/
,'S56429D'  /*Laceration of extensor muscle, fascia and tendon of unspecified finger at forearm level, subsequent encounter*/
,'S56429S'  /*Laceration of extensor muscle, fascia and tendon of unspecified finger at forearm level, sequela*/
,'S56491D'  /*Other injury of extensor muscle, fascia and tendon of right index finger at forearm level, subsequent encounter*/
,'S56491S'  /*Other injury of extensor muscle, fascia and tendon of right index finger at forearm level, sequela*/
,'S56492D'  /*Other injury of extensor muscle, fascia and tendon of left index finger at forearm level, subsequent encounter*/
,'S56492S'  /*Other injury of extensor muscle, fascia and tendon of left index finger at forearm level, sequela*/
,'S56493D'  /*Other injury of extensor muscle, fascia and tendon of right middle finger at forearm level, subsequent encounter*/
,'S56493S'  /*Other injury of extensor muscle, fascia and tendon of right middle finger at forearm level, sequela*/
,'S56494D'  /*Other injury of extensor muscle, fascia and tendon of left middle finger at forearm level, subsequent encounter*/
,'S56494S'  /*Other injury of extensor muscle, fascia and tendon of left middle finger at forearm level, sequela*/
,'S56495D'  /*Other injury of extensor muscle, fascia and tendon of right ring finger at forearm level, subsequent encounter*/
,'S56495S'  /*Other injury of extensor muscle, fascia and tendon of right ring finger at forearm level, sequela*/
,'S56496D'  /*Other injury of extensor muscle, fascia and tendon of left ring finger at forearm level, subsequent encounter*/
,'S56496S'  /*Other injury of extensor muscle, fascia and tendon of left ring finger at forearm level, sequela*/
,'S56497D'  /*Other injury of extensor muscle, fascia and tendon of right little finger at forearm level, subsequent encounter*/
,'S56497S'  /*Other injury of extensor muscle, fascia and tendon of right little finger at forearm level, sequela*/
,'S56498D'  /*Other injury of extensor muscle, fascia and tendon of left little finger at forearm level, subsequent encounter*/
,'S56498S'  /*Other injury of extensor muscle, fascia and tendon of left little finger at forearm level, sequela*/
,'S56499D'  /*Other injury of extensor muscle, fascia and tendon of unspecified finger at forearm level, subsequent encounter*/
,'S56499S'  /*Other injury of extensor muscle, fascia and tendon of unspecified finger at forearm level, sequela*/
,'S56501D'  /*Unspecified injury of other extensor muscle, fascia and tendon at forearm level, right arm, subsequent encounter*/
,'S56501S'  /*Unspecified injury of other extensor muscle, fascia and tendon at forearm level, right arm, sequela*/
,'S56502D'  /*Unspecified injury of other extensor muscle, fascia and tendon at forearm level, left arm, subsequent encounter*/
,'S56502S'  /*Unspecified injury of other extensor muscle, fascia and tendon at forearm level, left arm, sequela*/
,'S56509D'  /*Unspecified injury of other extensor muscle, fascia and tendon at forearm level, unspecified arm, subsequent encounter*/
,'S56509S'  /*Unspecified injury of other extensor muscle, fascia and tendon at forearm level, unspecified arm, sequela*/
,'S56511D'  /*Strain of other extensor muscle, fascia and tendon at forearm level, right arm, subsequent encounter*/
,'S56511S'  /*Strain of other extensor muscle, fascia and tendon at forearm level, right arm, sequela*/
,'S56512D'  /*Strain of other extensor muscle, fascia and tendon at forearm level, left arm, subsequent encounter*/
,'S56512S'  /*Strain of other extensor muscle, fascia and tendon at forearm level, left arm, sequela*/
,'S56519D'  /*Strain of other extensor muscle, fascia and tendon at forearm level, unspecified arm, subsequent encounter*/
,'S56519S'  /*Strain of other extensor muscle, fascia and tendon at forearm level, unspecified arm, sequela*/
,'S56521D'  /*Laceration of other extensor muscle, fascia and tendon at forearm level, right arm, subsequent encounter*/
,'S56521S'  /*Laceration of other extensor muscle, fascia and tendon at forearm level, right arm, sequela*/
,'S56522D'  /*Laceration of other extensor muscle, fascia and tendon at forearm level, left arm, subsequent encounter*/
,'S56522S'  /*Laceration of other extensor muscle, fascia and tendon at forearm level, left arm, sequela*/
,'S56529D'  /*Laceration of other extensor muscle, fascia and tendon at forearm level, unspecified arm, subsequent encounter*/
,'S56529S'  /*Laceration of other extensor muscle, fascia and tendon at forearm level, unspecified arm, sequela*/
,'S56591D'  /*Other injury of other extensor muscle, fascia and tendon at forearm level, right arm, subsequent encounter*/
,'S56591S'  /*Other injury of other extensor muscle, fascia and tendon at forearm level, right arm, sequela*/
,'S56592D'  /*Other injury of other extensor muscle, fascia and tendon at forearm level, left arm, subsequent encounter*/
,'S56592S'  /*Other injury of other extensor muscle, fascia and tendon at forearm level, left arm, sequela*/
,'S56599D'  /*Other injury of other extensor muscle, fascia and tendon at forearm level, unspecified arm, subsequent encounter*/
,'S56599S'  /*Other injury of other extensor muscle, fascia and tendon at forearm level, unspecified arm, sequela*/
,'S56801D'  /*Unspecified injury of other muscles, fascia and tendons at forearm level, right arm, subsequent encounter*/
,'S56801S'  /*Unspecified injury of other muscles, fascia and tendons at forearm level, right arm, sequela*/
,'S56802D'  /*Unspecified injury of other muscles, fascia and tendons at forearm level, left arm, subsequent encounter*/
,'S56802S'  /*Unspecified injury of other muscles, fascia and tendons at forearm level, left arm, sequela*/
,'S56809D'  /*Unspecified injury of other muscles, fascia and tendons at forearm level, unspecified arm, subsequent encounter*/
,'S56809S'  /*Unspecified injury of other muscles, fascia and tendons at forearm level, unspecified arm, sequela*/
,'S56811D'  /*Strain of other muscles, fascia and tendons at forearm level, right arm, subsequent encounter*/
,'S56811S'  /*Strain of other muscles, fascia and tendons at forearm level, right arm, sequela*/
,'S56812D'  /*Strain of other muscles, fascia and tendons at forearm level, left arm, subsequent encounter*/
,'S56812S'  /*Strain of other muscles, fascia and tendons at forearm level, left arm, sequela*/
,'S56819D'  /*Strain of other muscles, fascia and tendons at forearm level, unspecified arm, subsequent encounter*/
,'S56819S'  /*Strain of other muscles, fascia and tendons at forearm level, unspecified arm, sequela*/
,'S56821D'  /*Laceration of other muscles, fascia and tendons at forearm level, right arm, subsequent encounter*/
,'S56821S'  /*Laceration of other muscles, fascia and tendons at forearm level, right arm, sequela*/
,'S56822D'  /*Laceration of other muscles, fascia and tendons at forearm level, left arm, subsequent encounter*/
,'S56822S'  /*Laceration of other muscles, fascia and tendons at forearm level, left arm, sequela*/
,'S56829D'  /*Laceration of other muscles, fascia and tendons at forearm level, unspecified arm, subsequent encounter*/
,'S56829S'  /*Laceration of other muscles, fascia and tendons at forearm level, unspecified arm, sequela*/
,'S56891D'  /*Other injury of other muscles, fascia and tendons at forearm level, right arm, subsequent encounter*/
,'S56891S'  /*Other injury of other muscles, fascia and tendons at forearm level, right arm, sequela*/
,'S56892D'  /*Other injury of other muscles, fascia and tendons at forearm level, left arm, subsequent encounter*/
,'S56892S'  /*Other injury of other muscles, fascia and tendons at forearm level, left arm, sequela*/
,'S56899D'  /*Other injury of other muscles, fascia and tendons at forearm level, unspecified arm, subsequent encounter*/
,'S56899S'  /*Other injury of other muscles, fascia and tendons at forearm level, unspecified arm, sequela*/
,'S56901D'  /*Unspecified injury of unspecified muscles, fascia and tendons at forearm level, right arm, subsequent encounter*/
,'S56901S'  /*Unspecified injury of unspecified muscles, fascia and tendons at forearm level, right arm, sequela*/
,'S56902D'  /*Unspecified injury of unspecified muscles, fascia and tendons at forearm level, left arm, subsequent encounter*/
,'S56902S'  /*Unspecified injury of unspecified muscles, fascia and tendons at forearm level, left arm, sequela*/
,'S56909D'  /*Unspecified injury of unspecified muscles, fascia and tendons at forearm level, unspecified arm, subsequent encounter*/
,'S56909S'  /*Unspecified injury of unspecified muscles, fascia and tendons at forearm level, unspecified arm, sequela*/
,'S56911D'  /*Strain of unspecified muscles, fascia and tendons at forearm level, right arm, subsequent encounter*/
,'S56911S'  /*Strain of unspecified muscles, fascia and tendons at forearm level, right arm, sequela*/
,'S56912D'  /*Strain of unspecified muscles, fascia and tendons at forearm level, left arm, subsequent encounter*/
,'S56912S'  /*Strain of unspecified muscles, fascia and tendons at forearm level, left arm, sequela*/
,'S56919D'  /*Strain of unspecified muscles, fascia and tendons at forearm level, unspecified arm, subsequent encounter*/
,'S56919S'  /*Strain of unspecified muscles, fascia and tendons at forearm level, unspecified arm, sequela*/
,'S56921D'  /*Laceration of unspecified muscles, fascia and tendons at forearm level, right arm, subsequent encounter*/
,'S56921S'  /*Laceration of unspecified muscles, fascia and tendons at forearm level, right arm, sequela*/
,'S56922D'  /*Laceration of unspecified muscles, fascia and tendons at forearm level, left arm, subsequent encounter*/
,'S56922S'  /*Laceration of unspecified muscles, fascia and tendons at forearm level, left arm, sequela*/
,'S56929D'  /*Laceration of unspecified muscles, fascia and tendons at forearm level, unspecified arm, subsequent encounter*/
,'S56929S'  /*Laceration of unspecified muscles, fascia and tendons at forearm level, unspecified arm, sequela*/
,'S56991D'  /*Other injury of unspecified muscles, fascia and tendons at forearm level, right arm, subsequent encounter*/
,'S56991S'  /*Other injury of unspecified muscles, fascia and tendons at forearm level, right arm, sequela*/
,'S56992D'  /*Other injury of unspecified muscles, fascia and tendons at forearm level, left arm, subsequent encounter*/
,'S56992S'  /*Other injury of unspecified muscles, fascia and tendons at forearm level, left arm, sequela*/
,'S56999D'  /*Other injury of unspecified muscles, fascia and tendons at forearm level, unspecified arm, subsequent encounter*/
,'S56999S'  /*Other injury of unspecified muscles, fascia and tendons at forearm level, unspecified arm, sequela*/
,'S5700XD'  /*Crushing injury of unspecified elbow, subsequent encounter*/
,'S5700XS'  /*Crushing injury of unspecified elbow, sequela*/
,'S5701XD'  /*Crushing injury of right elbow, subsequent encounter*/
,'S5701XS'  /*Crushing injury of right elbow, sequela*/
,'S5702XD'  /*Crushing injury of left elbow, subsequent encounter*/
,'S5702XS'  /*Crushing injury of left elbow, sequela*/
,'S5780XD'  /*Crushing injury of unspecified forearm, subsequent encounter*/
,'S5780XS'  /*Crushing injury of unspecified forearm, sequela*/
,'S5781XD'  /*Crushing injury of right forearm, subsequent encounter*/
,'S5781XS'  /*Crushing injury of right forearm, sequela*/
,'S5782XD'  /*Crushing injury of left forearm, subsequent encounter*/
,'S5782XS'  /*Crushing injury of left forearm, sequela*/
,'S58011D'  /*Complete traumatic amputation at elbow level, right arm, subsequent encounter*/
,'S58011S'  /*Complete traumatic amputation at elbow level, right arm, sequela*/
,'S58012D'  /*Complete traumatic amputation at elbow level, left arm, subsequent encounter*/
,'S58012S'  /*Complete traumatic amputation at elbow level, left arm, sequela*/
,'S58019D'  /*Complete traumatic amputation at elbow level, unspecified arm, subsequent encounter*/
,'S58019S'  /*Complete traumatic amputation at elbow level, unspecified arm, sequela*/
,'S58021D'  /*Partial traumatic amputation at elbow level, right arm, subsequent encounter*/
,'S58021S'  /*Partial traumatic amputation at elbow level, right arm, sequela*/
,'S58022D'  /*Partial traumatic amputation at elbow level, left arm, subsequent encounter*/
,'S58022S'  /*Partial traumatic amputation at elbow level, left arm, sequela*/
,'S58029D'  /*Partial traumatic amputation at elbow level, unspecified arm, subsequent encounter*/
,'S58029S'  /*Partial traumatic amputation at elbow level, unspecified arm, sequela*/
,'S58111D'  /*Complete traumatic amputation at level between elbow and wrist, right arm, subsequent encounter*/
,'S58111S'  /*Complete traumatic amputation at level between elbow and wrist, right arm, sequela*/
,'S58112D'  /*Complete traumatic amputation at level between elbow and wrist, left arm, subsequent encounter*/
,'S58112S'  /*Complete traumatic amputation at level between elbow and wrist, left arm, sequela*/
,'S58119D'  /*Complete traumatic amputation at level between elbow and wrist, unspecified arm, subsequent encounter*/
,'S58119S'  /*Complete traumatic amputation at level between elbow and wrist, unspecified arm, sequela*/
,'S58121D'  /*Partial traumatic amputation at level between elbow and wrist, right arm, subsequent encounter*/
,'S58121S'  /*Partial traumatic amputation at level between elbow and wrist, right arm, sequela*/
,'S58122D'  /*Partial traumatic amputation at level between elbow and wrist, left arm, subsequent encounter*/
,'S58122S'  /*Partial traumatic amputation at level between elbow and wrist, left arm, sequela*/
,'S58129D'  /*Partial traumatic amputation at level between elbow and wrist, unspecified arm, subsequent encounter*/
,'S58129S'  /*Partial traumatic amputation at level between elbow and wrist, unspecified arm, sequela*/
,'S58911D'  /*Complete traumatic amputation of right forearm, level unspecified, subsequent encounter*/
,'S58911S'  /*Complete traumatic amputation of right forearm, level unspecified, sequela*/
,'S58912D'  /*Complete traumatic amputation of left forearm, level unspecified, subsequent encounter*/
,'S58912S'  /*Complete traumatic amputation of left forearm, level unspecified, sequela*/
,'S58919D'  /*Complete traumatic amputation of unspecified forearm, level unspecified, subsequent encounter*/
,'S58919S'  /*Complete traumatic amputation of unspecified forearm, level unspecified, sequela*/
,'S58921D'  /*Partial traumatic amputation of right forearm, level unspecified, subsequent encounter*/
,'S58921S'  /*Partial traumatic amputation of right forearm, level unspecified, sequela*/
,'S58922D'  /*Partial traumatic amputation of left forearm, level unspecified, subsequent encounter*/
,'S58922S'  /*Partial traumatic amputation of left forearm, level unspecified, sequela*/
,'S58929D'  /*Partial traumatic amputation of unspecified forearm, level unspecified, subsequent encounter*/
,'S58929S'  /*Partial traumatic amputation of unspecified forearm, level unspecified, sequela*/
,'S59001D'  /*Unspecified physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with routine healing*/
,'S59001G'  /*Unspecified physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with delayed healing*/
,'S59001K'  /*Unspecified physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with nonunion*/
,'S59001P'  /*Unspecified physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with malunion*/
,'S59001S'  /*Unspecified physeal fracture of lower end of ulna, right arm, sequela*/
,'S59002D'  /*Unspecified physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with routine healing*/
,'S59002G'  /*Unspecified physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with delayed healing*/
,'S59002K'  /*Unspecified physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with nonunion*/
,'S59002P'  /*Unspecified physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with malunion*/
,'S59002S'  /*Unspecified physeal fracture of lower end of ulna, left arm, sequela*/
,'S59009D'  /*Unspecified physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S59009G'  /*Unspecified physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S59009K'  /*Unspecified physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S59009P'  /*Unspecified physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with malunion*/
,'S59009S'  /*Unspecified physeal fracture of lower end of ulna, unspecified arm, sequela*/
,'S59011D'  /*Salter-Harris Type I physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with routine healing*/
,'S59011G'  /*Salter-Harris Type I physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with delayed healing*/
,'S59011K'  /*Salter-Harris Type I physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with nonunion*/
,'S59011P'  /*Salter-Harris Type I physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with malunion*/
,'S59011S'  /*Salter-Harris Type I physeal fracture of lower end of ulna, right arm, sequela*/
,'S59012D'  /*Salter-Harris Type I physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with routine healing*/
,'S59012G'  /*Salter-Harris Type I physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with delayed healing*/
,'S59012K'  /*Salter-Harris Type I physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with nonunion*/
,'S59012P'  /*Salter-Harris Type I physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with malunion*/
,'S59012S'  /*Salter-Harris Type I physeal fracture of lower end of ulna, left arm, sequela*/
,'S59019D'  /*Salter-Harris Type I physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S59019G'  /*Salter-Harris Type I physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S59019K'  /*Salter-Harris Type I physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S59019P'  /*Salter-Harris Type I physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with malunion*/
,'S59019S'  /*Salter-Harris Type I physeal fracture of lower end of ulna, unspecified arm, sequela*/
,'S59021D'  /*Salter-Harris Type II physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with routine healing*/
,'S59021G'  /*Salter-Harris Type II physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with delayed healing*/
,'S59021K'  /*Salter-Harris Type II physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with nonunion*/
,'S59021P'  /*Salter-Harris Type II physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with malunion*/
,'S59021S'  /*Salter-Harris Type II physeal fracture of lower end of ulna, right arm, sequela*/
,'S59022D'  /*Salter-Harris Type II physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with routine healing*/
,'S59022G'  /*Salter-Harris Type II physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with delayed healing*/
,'S59022K'  /*Salter-Harris Type II physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with nonunion*/
,'S59022P'  /*Salter-Harris Type II physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with malunion*/
,'S59022S'  /*Salter-Harris Type II physeal fracture of lower end of ulna, left arm, sequela*/
,'S59029D'  /*Salter-Harris Type II physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S59029G'  /*Salter-Harris Type II physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S59029K'  /*Salter-Harris Type II physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S59029P'  /*Salter-Harris Type II physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with malunion*/
,'S59029S'  /*Salter-Harris Type II physeal fracture of lower end of ulna, unspecified arm, sequela*/
,'S59031D'  /*Salter-Harris Type III physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with routine healing*/
,'S59031G'  /*Salter-Harris Type III physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with delayed healing*/
,'S59031K'  /*Salter-Harris Type III physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with nonunion*/
,'S59031P'  /*Salter-Harris Type III physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with malunion*/
,'S59031S'  /*Salter-Harris Type III physeal fracture of lower end of ulna, right arm, sequela*/
,'S59032D'  /*Salter-Harris Type III physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with routine healing*/
,'S59032G'  /*Salter-Harris Type III physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with delayed healing*/
,'S59032K'  /*Salter-Harris Type III physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with nonunion*/
,'S59032P'  /*Salter-Harris Type III physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with malunion*/
,'S59032S'  /*Salter-Harris Type III physeal fracture of lower end of ulna, left arm, sequela*/
,'S59039D'  /*Salter-Harris Type III physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S59039G'  /*Salter-Harris Type III physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S59039K'  /*Salter-Harris Type III physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S59039P'  /*Salter-Harris Type III physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with malunion*/
,'S59039S'  /*Salter-Harris Type III physeal fracture of lower end of ulna, unspecified arm, sequela*/
,'S59041D'  /*Salter-Harris Type IV physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with routine healing*/
,'S59041G'  /*Salter-Harris Type IV physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with delayed healing*/
,'S59041K'  /*Salter-Harris Type IV physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with nonunion*/
,'S59041P'  /*Salter-Harris Type IV physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with malunion*/
,'S59041S'  /*Salter-Harris Type IV physeal fracture of lower end of ulna, right arm, sequela*/
,'S59042D'  /*Salter-Harris Type IV physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with routine healing*/
,'S59042G'  /*Salter-Harris Type IV physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with delayed healing*/
,'S59042K'  /*Salter-Harris Type IV physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with nonunion*/
,'S59042P'  /*Salter-Harris Type IV physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with malunion*/
,'S59042S'  /*Salter-Harris Type IV physeal fracture of lower end of ulna, left arm, sequela*/
,'S59049D'  /*Salter-Harris Type IV physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S59049G'  /*Salter-Harris Type IV physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S59049K'  /*Salter-Harris Type IV physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S59049P'  /*Salter-Harris Type IV physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with malunion*/
,'S59049S'  /*Salter-Harris Type IV physeal fracture of lower end of ulna, unspecified arm, sequela*/
,'S59091D'  /*Other physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with routine healing*/
,'S59091G'  /*Other physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with delayed healing*/
,'S59091K'  /*Other physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with nonunion*/
,'S59091P'  /*Other physeal fracture of lower end of ulna, right arm, subsequent encounter for fracture with malunion*/
,'S59091S'  /*Other physeal fracture of lower end of ulna, right arm, sequela*/
,'S59092D'  /*Other physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with routine healing*/
,'S59092G'  /*Other physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with delayed healing*/
,'S59092K'  /*Other physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with nonunion*/
,'S59092P'  /*Other physeal fracture of lower end of ulna, left arm, subsequent encounter for fracture with malunion*/
,'S59092S'  /*Other physeal fracture of lower end of ulna, left arm, sequela*/
,'S59099D'  /*Other physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S59099G'  /*Other physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S59099K'  /*Other physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S59099P'  /*Other physeal fracture of lower end of ulna, unspecified arm, subsequent encounter for fracture with malunion*/
,'S59099S'  /*Other physeal fracture of lower end of ulna, unspecified arm, sequela*/
,'S59101D'  /*Unspecified physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with routine healing*/
,'S59101G'  /*Unspecified physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with delayed healing*/
,'S59101K'  /*Unspecified physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with nonunion*/
,'S59101P'  /*Unspecified physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with malunion*/
,'S59101S'  /*Unspecified physeal fracture of upper end of radius, right arm, sequela*/
,'S59102D'  /*Unspecified physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with routine healing*/
,'S59102G'  /*Unspecified physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with delayed healing*/
,'S59102K'  /*Unspecified physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with nonunion*/
,'S59102P'  /*Unspecified physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with malunion*/
,'S59102S'  /*Unspecified physeal fracture of upper end of radius, left arm, sequela*/
,'S59109D'  /*Unspecified physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S59109G'  /*Unspecified physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S59109K'  /*Unspecified physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S59109P'  /*Unspecified physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with malunion*/
,'S59109S'  /*Unspecified physeal fracture of upper end of radius, unspecified arm, sequela*/
,'S59111D'  /*Salter-Harris Type I physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with routine healing*/
,'S59111G'  /*Salter-Harris Type I physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with delayed healing*/
,'S59111K'  /*Salter-Harris Type I physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with nonunion*/
,'S59111P'  /*Salter-Harris Type I physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with malunion*/
,'S59111S'  /*Salter-Harris Type I physeal fracture of upper end of radius, right arm, sequela*/
,'S59112D'  /*Salter-Harris Type I physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with routine healing*/
,'S59112G'  /*Salter-Harris Type I physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with delayed healing*/
,'S59112K'  /*Salter-Harris Type I physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with nonunion*/
,'S59112P'  /*Salter-Harris Type I physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with malunion*/
,'S59112S'  /*Salter-Harris Type I physeal fracture of upper end of radius, left arm, sequela*/
,'S59119D'  /*Salter-Harris Type I physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S59119G'  /*Salter-Harris Type I physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S59119K'  /*Salter-Harris Type I physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S59119P'  /*Salter-Harris Type I physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with malunion*/
,'S59119S'  /*Salter-Harris Type I physeal fracture of upper end of radius, unspecified arm, sequela*/
,'S59121D'  /*Salter-Harris Type II physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with routine healing*/
,'S59121G'  /*Salter-Harris Type II physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with delayed healing*/
,'S59121K'  /*Salter-Harris Type II physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with nonunion*/
,'S59121P'  /*Salter-Harris Type II physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with malunion*/
,'S59121S'  /*Salter-Harris Type II physeal fracture of upper end of radius, right arm, sequela*/
,'S59122D'  /*Salter-Harris Type II physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with routine healing*/
,'S59122G'  /*Salter-Harris Type II physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with delayed healing*/
,'S59122K'  /*Salter-Harris Type II physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with nonunion*/
,'S59122P'  /*Salter-Harris Type II physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with malunion*/
,'S59122S'  /*Salter-Harris Type II physeal fracture of upper end of radius, left arm, sequela*/
,'S59129D'  /*Salter-Harris Type II physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S59129G'  /*Salter-Harris Type II physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S59129K'  /*Salter-Harris Type II physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S59129P'  /*Salter-Harris Type II physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with malunion*/
,'S59129S'  /*Salter-Harris Type II physeal fracture of upper end of radius, unspecified arm, sequela*/
,'S59131D'  /*Salter-Harris Type III physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with routine healing*/
,'S59131G'  /*Salter-Harris Type III physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with delayed healing*/
,'S59131K'  /*Salter-Harris Type III physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with nonunion*/
,'S59131P'  /*Salter-Harris Type III physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with malunion*/
,'S59131S'  /*Salter-Harris Type III physeal fracture of upper end of radius, right arm, sequela*/
,'S59132D'  /*Salter-Harris Type III physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with routine healing*/
,'S59132G'  /*Salter-Harris Type III physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with delayed healing*/
,'S59132K'  /*Salter-Harris Type III physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with nonunion*/
,'S59132P'  /*Salter-Harris Type III physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with malunion*/
,'S59132S'  /*Salter-Harris Type III physeal fracture of upper end of radius, left arm, sequela*/
,'S59139D'  /*Salter-Harris Type III physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S59139G'  /*Salter-Harris Type III physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S59139K'  /*Salter-Harris Type III physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S59139P'  /*Salter-Harris Type III physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with malunion*/
,'S59139S'  /*Salter-Harris Type III physeal fracture of upper end of radius, unspecified arm, sequela*/
,'S59141D'  /*Salter-Harris Type IV physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with routine healing*/
,'S59141G'  /*Salter-Harris Type IV physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with delayed healing*/
,'S59141K'  /*Salter-Harris Type IV physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with nonunion*/
,'S59141P'  /*Salter-Harris Type IV physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with malunion*/
,'S59141S'  /*Salter-Harris Type IV physeal fracture of upper end of radius, right arm, sequela*/
,'S59142D'  /*Salter-Harris Type IV physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with routine healing*/
,'S59142G'  /*Salter-Harris Type IV physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with delayed healing*/
,'S59142K'  /*Salter-Harris Type IV physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with nonunion*/
,'S59142P'  /*Salter-Harris Type IV physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with malunion*/
,'S59142S'  /*Salter-Harris Type IV physeal fracture of upper end of radius, left arm, sequela*/
,'S59149D'  /*Salter-Harris Type IV physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S59149G'  /*Salter-Harris Type IV physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S59149K'  /*Salter-Harris Type IV physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S59149P'  /*Salter-Harris Type IV physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with malunion*/
,'S59149S'  /*Salter-Harris Type IV physeal fracture of upper end of radius, unspecified arm, sequela*/
,'S59191D'  /*Other physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with routine healing*/
,'S59191G'  /*Other physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with delayed healing*/
,'S59191K'  /*Other physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with nonunion*/
,'S59191P'  /*Other physeal fracture of upper end of radius, right arm, subsequent encounter for fracture with malunion*/
,'S59191S'  /*Other physeal fracture of upper end of radius, right arm, sequela*/
,'S59192D'  /*Other physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with routine healing*/
,'S59192G'  /*Other physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with delayed healing*/
,'S59192K'  /*Other physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with nonunion*/
,'S59192P'  /*Other physeal fracture of upper end of radius, left arm, subsequent encounter for fracture with malunion*/
,'S59192S'  /*Other physeal fracture of upper end of radius, left arm, sequela*/
,'S59199D'  /*Other physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S59199G'  /*Other physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S59199K'  /*Other physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S59199P'  /*Other physeal fracture of upper end of radius, unspecified arm, subsequent encounter for fracture with malunion*/
,'S59199S'  /*Other physeal fracture of upper end of radius, unspecified arm, sequela*/
,'S59201D'  /*Unspecified physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with routine healing*/
,'S59201G'  /*Unspecified physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with delayed healing*/
,'S59201K'  /*Unspecified physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with nonunion*/
,'S59201P'  /*Unspecified physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with malunion*/
,'S59201S'  /*Unspecified physeal fracture of lower end of radius, right arm, sequela*/
,'S59202D'  /*Unspecified physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with routine healing*/
,'S59202G'  /*Unspecified physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with delayed healing*/
,'S59202K'  /*Unspecified physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with nonunion*/
,'S59202P'  /*Unspecified physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with malunion*/
,'S59202S'  /*Unspecified physeal fracture of lower end of radius, left arm, sequela*/
,'S59209D'  /*Unspecified physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S59209G'  /*Unspecified physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S59209K'  /*Unspecified physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S59209P'  /*Unspecified physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with malunion*/
,'S59209S'  /*Unspecified physeal fracture of lower end of radius, unspecified arm, sequela*/
,'S59211D'  /*Salter-Harris Type I physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with routine healing*/
,'S59211G'  /*Salter-Harris Type I physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with delayed healing*/
,'S59211K'  /*Salter-Harris Type I physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with nonunion*/
,'S59211P'  /*Salter-Harris Type I physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with malunion*/
,'S59211S'  /*Salter-Harris Type I physeal fracture of lower end of radius, right arm, sequela*/
,'S59212D'  /*Salter-Harris Type I physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with routine healing*/
,'S59212G'  /*Salter-Harris Type I physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with delayed healing*/
,'S59212K'  /*Salter-Harris Type I physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with nonunion*/
,'S59212P'  /*Salter-Harris Type I physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with malunion*/
,'S59212S'  /*Salter-Harris Type I physeal fracture of lower end of radius, left arm, sequela*/
,'S59219D'  /*Salter-Harris Type I physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S59219G'  /*Salter-Harris Type I physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S59219K'  /*Salter-Harris Type I physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S59219P'  /*Salter-Harris Type I physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with malunion*/
,'S59219S'  /*Salter-Harris Type I physeal fracture of lower end of radius, unspecified arm, sequela*/
,'S59221D'  /*Salter-Harris Type II physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with routine healing*/
,'S59221G'  /*Salter-Harris Type II physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with delayed healing*/
,'S59221K'  /*Salter-Harris Type II physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with nonunion*/
,'S59221P'  /*Salter-Harris Type II physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with malunion*/
,'S59221S'  /*Salter-Harris Type II physeal fracture of lower end of radius, right arm, sequela*/
,'S59222D'  /*Salter-Harris Type II physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with routine healing*/
,'S59222G'  /*Salter-Harris Type II physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with delayed healing*/
,'S59222K'  /*Salter-Harris Type II physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with nonunion*/
,'S59222P'  /*Salter-Harris Type II physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with malunion*/
,'S59222S'  /*Salter-Harris Type II physeal fracture of lower end of radius, left arm, sequela*/
,'S59229D'  /*Salter-Harris Type II physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S59229G'  /*Salter-Harris Type II physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S59229K'  /*Salter-Harris Type II physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S59229P'  /*Salter-Harris Type II physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with malunion*/
,'S59229S'  /*Salter-Harris Type II physeal fracture of lower end of radius, unspecified arm, sequela*/
,'S59231D'  /*Salter-Harris Type III physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with routine healing*/
,'S59231G'  /*Salter-Harris Type III physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with delayed healing*/
,'S59231K'  /*Salter-Harris Type III physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with nonunion*/
,'S59231P'  /*Salter-Harris Type III physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with malunion*/
,'S59231S'  /*Salter-Harris Type III physeal fracture of lower end of radius, right arm, sequela*/
,'S59232D'  /*Salter-Harris Type III physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with routine healing*/
,'S59232G'  /*Salter-Harris Type III physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with delayed healing*/
,'S59232K'  /*Salter-Harris Type III physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with nonunion*/
,'S59232P'  /*Salter-Harris Type III physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with malunion*/
,'S59232S'  /*Salter-Harris Type III physeal fracture of lower end of radius, left arm, sequela*/
,'S59239D'  /*Salter-Harris Type III physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S59239G'  /*Salter-Harris Type III physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S59239K'  /*Salter-Harris Type III physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S59239P'  /*Salter-Harris Type III physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with malunion*/
,'S59239S'  /*Salter-Harris Type III physeal fracture of lower end of radius, unspecified arm, sequela*/
,'S59241D'  /*Salter-Harris Type IV physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with routine healing*/
,'S59241G'  /*Salter-Harris Type IV physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with delayed healing*/
,'S59241K'  /*Salter-Harris Type IV physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with nonunion*/
,'S59241P'  /*Salter-Harris Type IV physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with malunion*/
,'S59241S'  /*Salter-Harris Type IV physeal fracture of lower end of radius, right arm, sequela*/
,'S59242D'  /*Salter-Harris Type IV physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with routine healing*/
,'S59242G'  /*Salter-Harris Type IV physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with delayed healing*/
,'S59242K'  /*Salter-Harris Type IV physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with nonunion*/
,'S59242P'  /*Salter-Harris Type IV physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with malunion*/
,'S59242S'  /*Salter-Harris Type IV physeal fracture of lower end of radius, left arm, sequela*/
,'S59249D'  /*Salter-Harris Type IV physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S59249G'  /*Salter-Harris Type IV physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S59249K'  /*Salter-Harris Type IV physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S59249P'  /*Salter-Harris Type IV physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with malunion*/
,'S59249S'  /*Salter-Harris Type IV physeal fracture of lower end of radius, unspecified arm, sequela*/
,'S59291D'  /*Other physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with routine healing*/
,'S59291G'  /*Other physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with delayed healing*/
,'S59291K'  /*Other physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with nonunion*/
,'S59291P'  /*Other physeal fracture of lower end of radius, right arm, subsequent encounter for fracture with malunion*/
,'S59291S'  /*Other physeal fracture of lower end of radius, right arm, sequela*/
,'S59292D'  /*Other physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with routine healing*/
,'S59292G'  /*Other physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with delayed healing*/
,'S59292K'  /*Other physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with nonunion*/
,'S59292P'  /*Other physeal fracture of lower end of radius, left arm, subsequent encounter for fracture with malunion*/
,'S59292S'  /*Other physeal fracture of lower end of radius, left arm, sequela*/
,'S59299D'  /*Other physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with routine healing*/
,'S59299G'  /*Other physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with delayed healing*/
,'S59299K'  /*Other physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with nonunion*/
,'S59299P'  /*Other physeal fracture of lower end of radius, unspecified arm, subsequent encounter for fracture with malunion*/
,'S59299S'  /*Other physeal fracture of lower end of radius, unspecified arm, sequela*/
,'S59801D'  /*Other specified injuries of right elbow, subsequent encounter*/
,'S59801S'  /*Other specified injuries of right elbow, sequela*/
,'S59802D'  /*Other specified injuries of left elbow, subsequent encounter*/
,'S59802S'  /*Other specified injuries of left elbow, sequela*/
,'S59809D'  /*Other specified injuries of unspecified elbow, subsequent encounter*/
,'S59809S'  /*Other specified injuries of unspecified elbow, sequela*/
,'S59811D'  /*Other specified injuries right forearm, subsequent encounter*/
,'S59811S'  /*Other specified injuries right forearm, sequela*/
,'S59812D'  /*Other specified injuries left forearm, subsequent encounter*/
,'S59812S'  /*Other specified injuries left forearm, sequela*/
,'S59819D'  /*Other specified injuries unspecified forearm, subsequent encounter*/
,'S59819S'  /*Other specified injuries unspecified forearm, sequela*/
,'S59901D'  /*Unspecified injury of right elbow, subsequent encounter*/
,'S59901S'  /*Unspecified injury of right elbow, sequela*/
,'S59902D'  /*Unspecified injury of left elbow, subsequent encounter*/
,'S59902S'  /*Unspecified injury of left elbow, sequela*/
,'S59909D'  /*Unspecified injury of unspecified elbow, subsequent encounter*/
,'S59909S'  /*Unspecified injury of unspecified elbow, sequela*/
,'S59911D'  /*Unspecified injury of right forearm, subsequent encounter*/
,'S59911S'  /*Unspecified injury of right forearm, sequela*/
,'S59912D'  /*Unspecified injury of left forearm, subsequent encounter*/
,'S59912S'  /*Unspecified injury of left forearm, sequela*/
,'S59919D'  /*Unspecified injury of unspecified forearm, subsequent encounter*/
,'S59919S'  /*Unspecified injury of unspecified forearm, sequela*/
,'S6000XD'  /*Contusion of unspecified finger without damage to nail, subsequent encounter*/
,'S6000XS'  /*Contusion of unspecified finger without damage to nail, sequela*/
,'S60011D'  /*Contusion of right thumb without damage to nail, subsequent encounter*/
,'S60011S'  /*Contusion of right thumb without damage to nail, sequela*/
,'S60012D'  /*Contusion of left thumb without damage to nail, subsequent encounter*/
,'S60012S'  /*Contusion of left thumb without damage to nail, sequela*/
,'S60019D'  /*Contusion of unspecified thumb without damage to nail, subsequent encounter*/
,'S60019S'  /*Contusion of unspecified thumb without damage to nail, sequela*/
,'S60021D'  /*Contusion of right index finger without damage to nail, subsequent encounter*/
,'S60021S'  /*Contusion of right index finger without damage to nail, sequela*/
,'S60022D'  /*Contusion of left index finger without damage to nail, subsequent encounter*/
,'S60022S'  /*Contusion of left index finger without damage to nail, sequela*/
,'S60029D'  /*Contusion of unspecified index finger without damage to nail, subsequent encounter*/
,'S60029S'  /*Contusion of unspecified index finger without damage to nail, sequela*/
,'S60031D'  /*Contusion of right middle finger without damage to nail, subsequent encounter*/
,'S60031S'  /*Contusion of right middle finger without damage to nail, sequela*/
,'S60032D'  /*Contusion of left middle finger without damage to nail, subsequent encounter*/
,'S60032S'  /*Contusion of left middle finger without damage to nail, sequela*/
,'S60039D'  /*Contusion of unspecified middle finger without damage to nail, subsequent encounter*/
,'S60039S'  /*Contusion of unspecified middle finger without damage to nail, sequela*/
,'S60041D'  /*Contusion of right ring finger without damage to nail, subsequent encounter*/
,'S60041S'  /*Contusion of right ring finger without damage to nail, sequela*/
,'S60042D'  /*Contusion of left ring finger without damage to nail, subsequent encounter*/
,'S60042S'  /*Contusion of left ring finger without damage to nail, sequela*/
,'S60049D'  /*Contusion of unspecified ring finger without damage to nail, subsequent encounter*/
,'S60049S'  /*Contusion of unspecified ring finger without damage to nail, sequela*/
,'S60051D'  /*Contusion of right little finger without damage to nail, subsequent encounter*/
,'S60051S'  /*Contusion of right little finger without damage to nail, sequela*/
,'S60052D'  /*Contusion of left little finger without damage to nail, subsequent encounter*/
,'S60052S'  /*Contusion of left little finger without damage to nail, sequela*/
,'S60059D'  /*Contusion of unspecified little finger without damage to nail, subsequent encounter*/
,'S60059S'  /*Contusion of unspecified little finger without damage to nail, sequela*/
,'S6010XD'  /*Contusion of unspecified finger with damage to nail, subsequent encounter*/
,'S6010XS'  /*Contusion of unspecified finger with damage to nail, sequela*/
,'S60111D'  /*Contusion of right thumb with damage to nail, subsequent encounter*/
,'S60111S'  /*Contusion of right thumb with damage to nail, sequela*/
,'S60112D'  /*Contusion of left thumb with damage to nail, subsequent encounter*/
,'S60112S'  /*Contusion of left thumb with damage to nail, sequela*/
,'S60119D'  /*Contusion of unspecified thumb with damage to nail, subsequent encounter*/
,'S60119S'  /*Contusion of unspecified thumb with damage to nail, sequela*/
,'S60121D'  /*Contusion of right index finger with damage to nail, subsequent encounter*/
,'S60121S'  /*Contusion of right index finger with damage to nail, sequela*/
,'S60122D'  /*Contusion of left index finger with damage to nail, subsequent encounter*/
,'S60122S'  /*Contusion of left index finger with damage to nail, sequela*/
,'S60129D'  /*Contusion of unspecified index finger with damage to nail, subsequent encounter*/
,'S60129S'  /*Contusion of unspecified index finger with damage to nail, sequela*/
,'S60131D'  /*Contusion of right middle finger with damage to nail, subsequent encounter*/
,'S60131S'  /*Contusion of right middle finger with damage to nail, sequela*/
,'S60132D'  /*Contusion of left middle finger with damage to nail, subsequent encounter*/
,'S60132S'  /*Contusion of left middle finger with damage to nail, sequela*/
,'S60139D'  /*Contusion of unspecified middle finger with damage to nail, subsequent encounter*/
,'S60139S'  /*Contusion of unspecified middle finger with damage to nail, sequela*/
,'S60141D'  /*Contusion of right ring finger with damage to nail, subsequent encounter*/
,'S60141S'  /*Contusion of right ring finger with damage to nail, sequela*/
,'S60142D'  /*Contusion of left ring finger with damage to nail, subsequent encounter*/
,'S60142S'  /*Contusion of left ring finger with damage to nail, sequela*/
,'S60149D'  /*Contusion of unspecified ring finger with damage to nail, subsequent encounter*/
,'S60149S'  /*Contusion of unspecified ring finger with damage to nail, sequela*/
,'S60151D'  /*Contusion of right little finger with damage to nail, subsequent encounter*/
,'S60151S'  /*Contusion of right little finger with damage to nail, sequela*/
,'S60152D'  /*Contusion of left little finger with damage to nail, subsequent encounter*/
,'S60152S'  /*Contusion of left little finger with damage to nail, sequela*/
,'S60159D'  /*Contusion of unspecified little finger with damage to nail, subsequent encounter*/
,'S60159S'  /*Contusion of unspecified little finger with damage to nail, sequela*/
,'S60211D'  /*Contusion of right wrist, subsequent encounter*/
,'S60211S'  /*Contusion of right wrist, sequela*/
,'S60212D'  /*Contusion of left wrist, subsequent encounter*/
,'S60212S'  /*Contusion of left wrist, sequela*/
,'S60219D'  /*Contusion of unspecified wrist, subsequent encounter*/
,'S60219S'  /*Contusion of unspecified wrist, sequela*/
,'S60221D'  /*Contusion of right hand, subsequent encounter*/
,'S60221S'  /*Contusion of right hand, sequela*/
,'S60222D'  /*Contusion of left hand, subsequent encounter*/
,'S60222S'  /*Contusion of left hand, sequela*/
,'S60229D'  /*Contusion of unspecified hand, subsequent encounter*/
,'S60229S'  /*Contusion of unspecified hand, sequela*/
,'S60311D'  /*Abrasion of right thumb, subsequent encounter*/
,'S60311S'  /*Abrasion of right thumb, sequela*/
,'S60312D'  /*Abrasion of left thumb, subsequent encounter*/
,'S60312S'  /*Abrasion of left thumb, sequela*/
,'S60319D'  /*Abrasion of unspecified thumb, subsequent encounter*/
,'S60319S'  /*Abrasion of unspecified thumb, sequela*/
,'S60321D'  /*Blister (nonthermal) of right thumb, subsequent encounter*/
,'S60321S'  /*Blister (nonthermal) of right thumb, sequela*/
,'S60322D'  /*Blister (nonthermal) of left thumb, subsequent encounter*/
,'S60322S'  /*Blister (nonthermal) of left thumb, sequela*/
,'S60329D'  /*Blister (nonthermal) of unspecified thumb, subsequent encounter*/
,'S60329S'  /*Blister (nonthermal) of unspecified thumb, sequela*/
,'S60341D'  /*External constriction of right thumb, subsequent encounter*/
,'S60341S'  /*External constriction of right thumb, sequela*/
,'S60342D'  /*External constriction of left thumb, subsequent encounter*/
,'S60342S'  /*External constriction of left thumb, sequela*/
,'S60349D'  /*External constriction of unspecified thumb, subsequent encounter*/
,'S60349S'  /*External constriction of unspecified thumb, sequela*/
,'S60351D'  /*Superficial foreign body of right thumb, subsequent encounter*/
,'S60351S'  /*Superficial foreign body of right thumb, sequela*/
,'S60352D'  /*Superficial foreign body of left thumb, subsequent encounter*/
,'S60352S'  /*Superficial foreign body of left thumb, sequela*/
,'S60359D'  /*Superficial foreign body of unspecified thumb, subsequent encounter*/
,'S60359S'  /*Superficial foreign body of unspecified thumb, sequela*/
,'S60361D'  /*Insect bite (nonvenomous) of right thumb, subsequent encounter*/
,'S60361S'  /*Insect bite (nonvenomous) of right thumb, sequela*/
,'S60362D'  /*Insect bite (nonvenomous) of left thumb, subsequent encounter*/
,'S60362S'  /*Insect bite (nonvenomous) of left thumb, sequela*/
,'S60369D'  /*Insect bite (nonvenomous) of unspecified thumb, subsequent encounter*/
,'S60369S'  /*Insect bite (nonvenomous) of unspecified thumb, sequela*/
,'S60371D'  /*Other superficial bite of right thumb, subsequent encounter*/
,'S60371S'  /*Other superficial bite of right thumb, sequela*/
,'S60372D'  /*Other superficial bite of left thumb, subsequent encounter*/
,'S60372S'  /*Other superficial bite of left thumb, sequela*/
,'S60379D'  /*Other superficial bite of unspecified thumb, subsequent encounter*/
,'S60379S'  /*Other superficial bite of unspecified thumb, sequela*/
,'S60391D'  /*Other superficial injuries of right thumb, subsequent encounter*/
,'S60391S'  /*Other superficial injuries of right thumb, sequela*/
,'S60392D'  /*Other superficial injuries of left thumb, subsequent encounter*/
,'S60392S'  /*Other superficial injuries of left thumb, sequela*/
,'S60399D'  /*Other superficial injuries of unspecified thumb, subsequent encounter*/
,'S60399S'  /*Other superficial injuries of unspecified thumb, sequela*/
,'S60410D'  /*Abrasion of right index finger, subsequent encounter*/
,'S60410S'  /*Abrasion of right index finger, sequela*/
,'S60411D'  /*Abrasion of left index finger, subsequent encounter*/
,'S60411S'  /*Abrasion of left index finger, sequela*/
,'S60412D'  /*Abrasion of right middle finger, subsequent encounter*/
,'S60412S'  /*Abrasion of right middle finger, sequela*/
,'S60413D'  /*Abrasion of left middle finger, subsequent encounter*/
,'S60413S'  /*Abrasion of left middle finger, sequela*/
,'S60414D'  /*Abrasion of right ring finger, subsequent encounter*/
,'S60414S'  /*Abrasion of right ring finger, sequela*/
,'S60415D'  /*Abrasion of left ring finger, subsequent encounter*/
,'S60415S'  /*Abrasion of left ring finger, sequela*/
,'S60416D'  /*Abrasion of right little finger, subsequent encounter*/
,'S60416S'  /*Abrasion of right little finger, sequela*/
,'S60417D'  /*Abrasion of left little finger, subsequent encounter*/
,'S60417S'  /*Abrasion of left little finger, sequela*/
,'S60418D'  /*Abrasion of other finger, subsequent encounter*/
,'S60418S'  /*Abrasion of other finger, sequela*/
,'S60419D'  /*Abrasion of unspecified finger, subsequent encounter*/
,'S60419S'  /*Abrasion of unspecified finger, sequela*/
,'S60420D'  /*Blister (nonthermal) of right index finger, subsequent encounter*/
,'S60420S'  /*Blister (nonthermal) of right index finger, sequela*/
,'S60421D'  /*Blister (nonthermal) of left index finger, subsequent encounter*/
,'S60421S'  /*Blister (nonthermal) of left index finger, sequela*/
,'S60422D'  /*Blister (nonthermal) of right middle finger, subsequent encounter*/
,'S60422S'  /*Blister (nonthermal) of right middle finger, sequela*/
,'S60423D'  /*Blister (nonthermal) of left middle finger, subsequent encounter*/
,'S60423S'  /*Blister (nonthermal) of left middle finger, sequela*/
,'S60424D'  /*Blister (nonthermal) of right ring finger, subsequent encounter*/
,'S60424S'  /*Blister (nonthermal) of right ring finger, sequela*/
,'S60425D'  /*Blister (nonthermal) of left ring finger, subsequent encounter*/
,'S60425S'  /*Blister (nonthermal) of left ring finger, sequela*/
,'S60426D'  /*Blister (nonthermal) of right little finger, subsequent encounter*/
,'S60426S'  /*Blister (nonthermal) of right little finger, sequela*/
,'S60427D'  /*Blister (nonthermal) of left little finger, subsequent encounter*/
,'S60427S'  /*Blister (nonthermal) of left little finger, sequela*/
,'S60428D'  /*Blister (nonthermal) of other finger, subsequent encounter*/
,'S60428S'  /*Blister (nonthermal) of other finger, sequela*/
,'S60429D'  /*Blister (nonthermal) of unspecified finger, subsequent encounter*/
,'S60429S'  /*Blister (nonthermal) of unspecified finger, sequela*/
,'S60440D'  /*External constriction of right index finger, subsequent encounter*/
,'S60440S'  /*External constriction of right index finger, sequela*/
,'S60441D'  /*External constriction of left index finger, subsequent encounter*/
,'S60441S'  /*External constriction of left index finger, sequela*/
,'S60442D'  /*External constriction of right middle finger, subsequent encounter*/
,'S60442S'  /*External constriction of right middle finger, sequela*/
,'S60443D'  /*External constriction of left middle finger, subsequent encounter*/
,'S60443S'  /*External constriction of left middle finger, sequela*/
,'S60444D'  /*External constriction of right ring finger, subsequent encounter*/
,'S60444S'  /*External constriction of right ring finger, sequela*/
,'S60445D'  /*External constriction of left ring finger, subsequent encounter*/
,'S60445S'  /*External constriction of left ring finger, sequela*/
,'S60446D'  /*External constriction of right little finger, subsequent encounter*/
,'S60446S'  /*External constriction of right little finger, sequela*/
,'S60447D'  /*External constriction of left little finger, subsequent encounter*/
,'S60447S'  /*External constriction of left little finger, sequela*/
,'S60448D'  /*External constriction of other finger, subsequent encounter*/
,'S60448S'  /*External constriction of other finger, sequela*/
,'S60449D'  /*External constriction of unspecified finger, subsequent encounter*/
,'S60449S'  /*External constriction of unspecified finger, sequela*/
,'S60450D'  /*Superficial foreign body of right index finger, subsequent encounter*/
,'S60450S'  /*Superficial foreign body of right index finger, sequela*/
,'S60451D'  /*Superficial foreign body of left index finger, subsequent encounter*/
,'S60451S'  /*Superficial foreign body of left index finger, sequela*/
,'S60452D'  /*Superficial foreign body of right middle finger, subsequent encounter*/
,'S60452S'  /*Superficial foreign body of right middle finger, sequela*/
,'S60453D'  /*Superficial foreign body of left middle finger, subsequent encounter*/
,'S60453S'  /*Superficial foreign body of left middle finger, sequela*/
,'S60454D'  /*Superficial foreign body of right ring finger, subsequent encounter*/
,'S60454S'  /*Superficial foreign body of right ring finger, sequela*/
,'S60455D'  /*Superficial foreign body of left ring finger, subsequent encounter*/
,'S60455S'  /*Superficial foreign body of left ring finger, sequela*/
,'S60456D'  /*Superficial foreign body of right little finger, subsequent encounter*/
,'S60456S'  /*Superficial foreign body of right little finger, sequela*/
,'S60457D'  /*Superficial foreign body of left little finger, subsequent encounter*/
,'S60457S'  /*Superficial foreign body of left little finger, sequela*/
,'S60458D'  /*Superficial foreign body of other finger, subsequent encounter*/
,'S60458S'  /*Superficial foreign body of other finger, sequela*/
,'S60459D'  /*Superficial foreign body of unspecified finger, subsequent encounter*/
,'S60459S'  /*Superficial foreign body of unspecified finger, sequela*/
,'S60460D'  /*Insect bite (nonvenomous) of right index finger, subsequent encounter*/
,'S60460S'  /*Insect bite (nonvenomous) of right index finger, sequela*/
,'S60461D'  /*Insect bite (nonvenomous) of left index finger, subsequent encounter*/
,'S60461S'  /*Insect bite (nonvenomous) of left index finger, sequela*/
,'S60462D'  /*Insect bite (nonvenomous) of right middle finger, subsequent encounter*/
,'S60462S'  /*Insect bite (nonvenomous) of right middle finger, sequela*/
,'S60463D'  /*Insect bite (nonvenomous) of left middle finger, subsequent encounter*/
,'S60463S'  /*Insect bite (nonvenomous) of left middle finger, sequela*/
,'S60464D'  /*Insect bite (nonvenomous) of right ring finger, subsequent encounter*/
,'S60464S'  /*Insect bite (nonvenomous) of right ring finger, sequela*/
,'S60465D'  /*Insect bite (nonvenomous) of left ring finger, subsequent encounter*/
,'S60465S'  /*Insect bite (nonvenomous) of left ring finger, sequela*/
,'S60466D'  /*Insect bite (nonvenomous) of right little finger, subsequent encounter*/
,'S60466S'  /*Insect bite (nonvenomous) of right little finger, sequela*/
,'S60467D'  /*Insect bite (nonvenomous) of left little finger, subsequent encounter*/
,'S60467S'  /*Insect bite (nonvenomous) of left little finger, sequela*/
,'S60468D'  /*Insect bite (nonvenomous) of other finger, subsequent encounter*/
,'S60468S'  /*Insect bite (nonvenomous) of other finger, sequela*/
,'S60469D'  /*Insect bite (nonvenomous) of unspecified finger, subsequent encounter*/
,'S60469S'  /*Insect bite (nonvenomous) of unspecified finger, sequela*/
,'S60470D'  /*Other superficial bite of right index finger, subsequent encounter*/
,'S60470S'  /*Other superficial bite of right index finger, sequela*/
,'S60471D'  /*Other superficial bite of left index finger, subsequent encounter*/
,'S60471S'  /*Other superficial bite of left index finger, sequela*/
,'S60472D'  /*Other superficial bite of right middle finger, subsequent encounter*/
,'S60472S'  /*Other superficial bite of right middle finger, sequela*/
,'S60473D'  /*Other superficial bite of left middle finger, subsequent encounter*/
,'S60473S'  /*Other superficial bite of left middle finger, sequela*/
,'S60474D'  /*Other superficial bite of right ring finger, subsequent encounter*/
,'S60474S'  /*Other superficial bite of right ring finger, sequela*/
,'S60475D'  /*Other superficial bite of left ring finger, subsequent encounter*/
,'S60475S'  /*Other superficial bite of left ring finger, sequela*/
,'S60476D'  /*Other superficial bite of right little finger, subsequent encounter*/
,'S60476S'  /*Other superficial bite of right little finger, sequela*/
,'S60477D'  /*Other superficial bite of left little finger, subsequent encounter*/
,'S60477S'  /*Other superficial bite of left little finger, sequela*/
,'S60478D'  /*Other superficial bite of other finger, subsequent encounter*/
,'S60478S'  /*Other superficial bite of other finger, sequela*/
,'S60479D'  /*Other superficial bite of unspecified finger, subsequent encounter*/
,'S60479S'  /*Other superficial bite of unspecified finger, sequela*/
,'S60511D'  /*Abrasion of right hand, subsequent encounter*/
,'S60511S'  /*Abrasion of right hand, sequela*/
,'S60512D'  /*Abrasion of left hand, subsequent encounter*/
,'S60512S'  /*Abrasion of left hand, sequela*/
,'S60519D'  /*Abrasion of unspecified hand, subsequent encounter*/
,'S60519S'  /*Abrasion of unspecified hand, sequela*/
,'S60521D'  /*Blister (nonthermal) of right hand, subsequent encounter*/
,'S60521S'  /*Blister (nonthermal) of right hand, sequela*/
,'S60522D'  /*Blister (nonthermal) of left hand, subsequent encounter*/
,'S60522S'  /*Blister (nonthermal) of left hand, sequela*/
,'S60529D'  /*Blister (nonthermal) of unspecified hand, subsequent encounter*/
,'S60529S'  /*Blister (nonthermal) of unspecified hand, sequela*/
,'S60541D'  /*External constriction of right hand, subsequent encounter*/
,'S60541S'  /*External constriction of right hand, sequela*/
,'S60542D'  /*External constriction of left hand, subsequent encounter*/
,'S60542S'  /*External constriction of left hand, sequela*/
,'S60549D'  /*External constriction of unspecified hand, subsequent encounter*/
,'S60549S'  /*External constriction of unspecified hand, sequela*/
,'S60551D'  /*Superficial foreign body of right hand, subsequent encounter*/
,'S60551S'  /*Superficial foreign body of right hand, sequela*/
,'S60552D'  /*Superficial foreign body of left hand, subsequent encounter*/
,'S60552S'  /*Superficial foreign body of left hand, sequela*/
,'S60559D'  /*Superficial foreign body of unspecified hand, subsequent encounter*/
,'S60559S'  /*Superficial foreign body of unspecified hand, sequela*/
,'S60561D'  /*Insect bite (nonvenomous) of right hand, subsequent encounter*/
,'S60561S'  /*Insect bite (nonvenomous) of right hand, sequela*/
,'S60562D'  /*Insect bite (nonvenomous) of left hand, subsequent encounter*/
,'S60562S'  /*Insect bite (nonvenomous) of left hand, sequela*/
,'S60569D'  /*Insect bite (nonvenomous) of unspecified hand, subsequent encounter*/
,'S60569S'  /*Insect bite (nonvenomous) of unspecified hand, sequela*/
,'S60571D'  /*Other superficial bite of hand of right hand, subsequent encounter*/
,'S60571S'  /*Other superficial bite of hand of right hand, sequela*/
,'S60572D'  /*Other superficial bite of hand of left hand, subsequent encounter*/
,'S60572S'  /*Other superficial bite of hand of left hand, sequela*/
,'S60579D'  /*Other superficial bite of hand of unspecified hand, subsequent encounter*/
,'S60579S'  /*Other superficial bite of hand of unspecified hand, sequela*/
,'S60811D'  /*Abrasion of right wrist, subsequent encounter*/
,'S60811S'  /*Abrasion of right wrist, sequela*/
,'S60812D'  /*Abrasion of left wrist, subsequent encounter*/
,'S60812S'  /*Abrasion of left wrist, sequela*/
,'S60819D'  /*Abrasion of unspecified wrist, subsequent encounter*/
,'S60819S'  /*Abrasion of unspecified wrist, sequela*/
,'S60821D'  /*Blister (nonthermal) of right wrist, subsequent encounter*/
,'S60821S'  /*Blister (nonthermal) of right wrist, sequela*/
,'S60822D'  /*Blister (nonthermal) of left wrist, subsequent encounter*/
,'S60822S'  /*Blister (nonthermal) of left wrist, sequela*/
,'S60829D'  /*Blister (nonthermal) of unspecified wrist, subsequent encounter*/
,'S60829S'  /*Blister (nonthermal) of unspecified wrist, sequela*/
,'S60841D'  /*External constriction of right wrist, subsequent encounter*/
,'S60841S'  /*External constriction of right wrist, sequela*/
,'S60842D'  /*External constriction of left wrist, subsequent encounter*/
,'S60842S'  /*External constriction of left wrist, sequela*/
,'S60849D'  /*External constriction of unspecified wrist, subsequent encounter*/
,'S60849S'  /*External constriction of unspecified wrist, sequela*/
,'S60851D'  /*Superficial foreign body of right wrist, subsequent encounter*/
,'S60851S'  /*Superficial foreign body of right wrist, sequela*/
,'S60852D'  /*Superficial foreign body of left wrist, subsequent encounter*/
,'S60852S'  /*Superficial foreign body of left wrist, sequela*/
,'S60859D'  /*Superficial foreign body of unspecified wrist, subsequent encounter*/
,'S60859S'  /*Superficial foreign body of unspecified wrist, sequela*/
,'S60861D'  /*Insect bite (nonvenomous) of right wrist, subsequent encounter*/
,'S60861S'  /*Insect bite (nonvenomous) of right wrist, sequela*/
,'S60862D'  /*Insect bite (nonvenomous) of left wrist, subsequent encounter*/
,'S60862S'  /*Insect bite (nonvenomous) of left wrist, sequela*/
,'S60869D'  /*Insect bite (nonvenomous) of unspecified wrist, subsequent encounter*/
,'S60869S'  /*Insect bite (nonvenomous) of unspecified wrist, sequela*/
,'S60871D'  /*Other superficial bite of right wrist, subsequent encounter*/
,'S60871S'  /*Other superficial bite of right wrist, sequela*/
,'S60872D'  /*Other superficial bite of left wrist, subsequent encounter*/
,'S60872S'  /*Other superficial bite of left wrist, sequela*/
,'S60879D'  /*Other superficial bite of unspecified wrist, subsequent encounter*/
,'S60879S'  /*Other superficial bite of unspecified wrist, sequela*/
,'S60911D'  /*Unspecified superficial injury of right wrist, subsequent encounter*/
,'S60911S'  /*Unspecified superficial injury of right wrist, sequela*/
,'S60912D'  /*Unspecified superficial injury of left wrist, subsequent encounter*/
,'S60912S'  /*Unspecified superficial injury of left wrist, sequela*/
,'S60919D'  /*Unspecified superficial injury of unspecified wrist, subsequent encounter*/
,'S60919S'  /*Unspecified superficial injury of unspecified wrist, sequela*/
,'S60921D'  /*Unspecified superficial injury of right hand, subsequent encounter*/
,'S60921S'  /*Unspecified superficial injury of right hand, sequela*/
,'S60922D'  /*Unspecified superficial injury of left hand, subsequent encounter*/
,'S60922S'  /*Unspecified superficial injury of left hand, sequela*/
,'S60929D'  /*Unspecified superficial injury of unspecified hand, subsequent encounter*/
,'S60929S'  /*Unspecified superficial injury of unspecified hand, sequela*/
,'S60931D'  /*Unspecified superficial injury of right thumb, subsequent encounter*/
,'S60931S'  /*Unspecified superficial injury of right thumb, sequela*/
,'S60932D'  /*Unspecified superficial injury of left thumb, subsequent encounter*/
,'S60932S'  /*Unspecified superficial injury of left thumb, sequela*/
,'S60939D'  /*Unspecified superficial injury of unspecified thumb, subsequent encounter*/
,'S60939S'  /*Unspecified superficial injury of unspecified thumb, sequela*/
,'S60940D'  /*Unspecified superficial injury of right index finger, subsequent encounter*/
,'S60940S'  /*Unspecified superficial injury of right index finger, sequela*/
,'S60941D'  /*Unspecified superficial injury of left index finger, subsequent encounter*/
,'S60941S'  /*Unspecified superficial injury of left index finger, sequela*/
,'S60942D'  /*Unspecified superficial injury of right middle finger, subsequent encounter*/
,'S60942S'  /*Unspecified superficial injury of right middle finger, sequela*/
,'S60943D'  /*Unspecified superficial injury of left middle finger, subsequent encounter*/
,'S60943S'  /*Unspecified superficial injury of left middle finger, sequela*/
,'S60944D'  /*Unspecified superficial injury of right ring finger, subsequent encounter*/
,'S60944S'  /*Unspecified superficial injury of right ring finger, sequela*/
,'S60945D'  /*Unspecified superficial injury of left ring finger, subsequent encounter*/
,'S60945S'  /*Unspecified superficial injury of left ring finger, sequela*/
,'S60946D'  /*Unspecified superficial injury of right little finger, subsequent encounter*/
,'S60946S'  /*Unspecified superficial injury of right little finger, sequela*/
,'S60947D'  /*Unspecified superficial injury of left little finger, subsequent encounter*/
,'S60947S'  /*Unspecified superficial injury of left little finger, sequela*/
,'S60948D'  /*Unspecified superficial injury of other finger, subsequent encounter*/
,'S60948S'  /*Unspecified superficial injury of other finger, sequela*/
,'S60949D'  /*Unspecified superficial injury of unspecified finger, subsequent encounter*/
,'S60949S'  /*Unspecified superficial injury of unspecified finger, sequela*/
,'S61001D'  /*Unspecified open wound of right thumb without damage to nail, subsequent encounter*/
,'S61001S'  /*Unspecified open wound of right thumb without damage to nail, sequela*/
,'S61002D'  /*Unspecified open wound of left thumb without damage to nail, subsequent encounter*/
,'S61002S'  /*Unspecified open wound of left thumb without damage to nail, sequela*/
,'S61009D'  /*Unspecified open wound of unspecified thumb without damage to nail, subsequent encounter*/
,'S61009S'  /*Unspecified open wound of unspecified thumb without damage to nail, sequela*/
,'S61011D'  /*Laceration without foreign body of right thumb without damage to nail, subsequent encounter*/
,'S61011S'  /*Laceration without foreign body of right thumb without damage to nail, sequela*/
,'S61012D'  /*Laceration without foreign body of left thumb without damage to nail, subsequent encounter*/
,'S61012S'  /*Laceration without foreign body of left thumb without damage to nail, sequela*/
,'S61019D'  /*Laceration without foreign body of unspecified thumb without damage to nail, subsequent encounter*/
,'S61019S'  /*Laceration without foreign body of unspecified thumb without damage to nail, sequela*/
,'S61021D'  /*Laceration with foreign body of right thumb without damage to nail, subsequent encounter*/
,'S61021S'  /*Laceration with foreign body of right thumb without damage to nail, sequela*/
,'S61022D'  /*Laceration with foreign body of left thumb without damage to nail, subsequent encounter*/
,'S61022S'  /*Laceration with foreign body of left thumb without damage to nail, sequela*/
,'S61029D'  /*Laceration with foreign body of unspecified thumb without damage to nail, subsequent encounter*/
,'S61029S'  /*Laceration with foreign body of unspecified thumb without damage to nail, sequela*/
,'S61031D'  /*Puncture wound without foreign body of right thumb without damage to nail, subsequent encounter*/
,'S61031S'  /*Puncture wound without foreign body of right thumb without damage to nail, sequela*/
,'S61032D'  /*Puncture wound without foreign body of left thumb without damage to nail, subsequent encounter*/
,'S61032S'  /*Puncture wound without foreign body of left thumb without damage to nail, sequela*/
,'S61039D'  /*Puncture wound without foreign body of unspecified thumb without damage to nail, subsequent encounter*/
,'S61039S'  /*Puncture wound without foreign body of unspecified thumb without damage to nail, sequela*/
,'S61041D'  /*Puncture wound with foreign body of right thumb without damage to nail, subsequent encounter*/
,'S61041S'  /*Puncture wound with foreign body of right thumb without damage to nail, sequela*/
,'S61042D'  /*Puncture wound with foreign body of left thumb without damage to nail, subsequent encounter*/
,'S61042S'  /*Puncture wound with foreign body of left thumb without damage to nail, sequela*/
,'S61049D'  /*Puncture wound with foreign body of unspecified thumb without damage to nail, subsequent encounter*/
,'S61049S'  /*Puncture wound with foreign body of unspecified thumb without damage to nail, sequela*/
,'S61051D'  /*Open bite of right thumb without damage to nail, subsequent encounter*/
,'S61051S'  /*Open bite of right thumb without damage to nail, sequela*/
,'S61052D'  /*Open bite of left thumb without damage to nail, subsequent encounter*/
,'S61052S'  /*Open bite of left thumb without damage to nail, sequela*/
,'S61059D'  /*Open bite of unspecified thumb without damage to nail, subsequent encounter*/
,'S61059S'  /*Open bite of unspecified thumb without damage to nail, sequela*/
,'S61101D'  /*Unspecified open wound of right thumb with damage to nail, subsequent encounter*/
,'S61101S'  /*Unspecified open wound of right thumb with damage to nail, sequela*/
,'S61102D'  /*Unspecified open wound of left thumb with damage to nail, subsequent encounter*/
,'S61102S'  /*Unspecified open wound of left thumb with damage to nail, sequela*/
,'S61109D'  /*Unspecified open wound of unspecified thumb with damage to nail, subsequent encounter*/
,'S61109S'  /*Unspecified open wound of unspecified thumb with damage to nail, sequela*/
,'S61111D'  /*Laceration without foreign body of right thumb with damage to nail, subsequent encounter*/
,'S61111S'  /*Laceration without foreign body of right thumb with damage to nail, sequela*/
,'S61112D'  /*Laceration without foreign body of left thumb with damage to nail, subsequent encounter*/
,'S61112S'  /*Laceration without foreign body of left thumb with damage to nail, sequela*/
,'S61119D'  /*Laceration without foreign body of unspecified thumb with damage to nail, subsequent encounter*/
,'S61119S'  /*Laceration without foreign body of unspecified thumb with damage to nail, sequela*/
,'S61121D'  /*Laceration with foreign body of right thumb with damage to nail, subsequent encounter*/
,'S61121S'  /*Laceration with foreign body of right thumb with damage to nail, sequela*/
,'S61122D'  /*Laceration with foreign body of left thumb with damage to nail, subsequent encounter*/
,'S61122S'  /*Laceration with foreign body of left thumb with damage to nail, sequela*/
,'S61129D'  /*Laceration with foreign body of unspecified thumb with damage to nail, subsequent encounter*/
,'S61129S'  /*Laceration with foreign body of unspecified thumb with damage to nail, sequela*/
,'S61131D'  /*Puncture wound without foreign body of right thumb with damage to nail, subsequent encounter*/
,'S61131S'  /*Puncture wound without foreign body of right thumb with damage to nail, sequela*/
,'S61132D'  /*Puncture wound without foreign body of left thumb with damage to nail, subsequent encounter*/
,'S61132S'  /*Puncture wound without foreign body of left thumb with damage to nail, sequela*/
,'S61139D'  /*Puncture wound without foreign body of unspecified thumb with damage to nail, subsequent encounter*/
,'S61139S'  /*Puncture wound without foreign body of unspecified thumb with damage to nail, sequela*/
,'S61141D'  /*Puncture wound with foreign body of right thumb with damage to nail, subsequent encounter*/
,'S61141S'  /*Puncture wound with foreign body of right thumb with damage to nail, sequela*/
,'S61142D'  /*Puncture wound with foreign body of left thumb with damage to nail, subsequent encounter*/
,'S61142S'  /*Puncture wound with foreign body of left thumb with damage to nail, sequela*/
,'S61149D'  /*Puncture wound with foreign body of unspecified thumb with damage to nail, subsequent encounter*/
,'S61149S'  /*Puncture wound with foreign body of unspecified thumb with damage to nail, sequela*/
,'S61151D'  /*Open bite of right thumb with damage to nail, subsequent encounter*/
,'S61151S'  /*Open bite of right thumb with damage to nail, sequela*/
,'S61152D'  /*Open bite of left thumb with damage to nail, subsequent encounter*/
,'S61152S'  /*Open bite of left thumb with damage to nail, sequela*/
,'S61159D'  /*Open bite of unspecified thumb with damage to nail, subsequent encounter*/
,'S61159S'  /*Open bite of unspecified thumb with damage to nail, sequela*/
,'S61200D'  /*Unspecified open wound of right index finger without damage to nail, subsequent encounter*/
,'S61200S'  /*Unspecified open wound of right index finger without damage to nail, sequela*/
,'S61201D'  /*Unspecified open wound of left index finger without damage to nail, subsequent encounter*/
,'S61201S'  /*Unspecified open wound of left index finger without damage to nail, sequela*/
,'S61202D'  /*Unspecified open wound of right middle finger without damage to nail, subsequent encounter*/
,'S61202S'  /*Unspecified open wound of right middle finger without damage to nail, sequela*/
,'S61203D'  /*Unspecified open wound of left middle finger without damage to nail, subsequent encounter*/
,'S61203S'  /*Unspecified open wound of left middle finger without damage to nail, sequela*/
,'S61204D'  /*Unspecified open wound of right ring finger without damage to nail, subsequent encounter*/
,'S61204S'  /*Unspecified open wound of right ring finger without damage to nail, sequela*/
,'S61205D'  /*Unspecified open wound of left ring finger without damage to nail, subsequent encounter*/
,'S61205S'  /*Unspecified open wound of left ring finger without damage to nail, sequela*/
,'S61206D'  /*Unspecified open wound of right little finger without damage to nail, subsequent encounter*/
,'S61206S'  /*Unspecified open wound of right little finger without damage to nail, sequela*/
,'S61207D'  /*Unspecified open wound of left little finger without damage to nail, subsequent encounter*/
,'S61207S'  /*Unspecified open wound of left little finger without damage to nail, sequela*/
,'S61208D'  /*Unspecified open wound of other finger without damage to nail, subsequent encounter*/
,'S61208S'  /*Unspecified open wound of other finger without damage to nail, sequela*/
,'S61209D'  /*Unspecified open wound of unspecified finger without damage to nail, subsequent encounter*/
,'S61209S'  /*Unspecified open wound of unspecified finger without damage to nail, sequela*/
,'S61210D'  /*Laceration without foreign body of right index finger without damage to nail, subsequent encounter*/
,'S61210S'  /*Laceration without foreign body of right index finger without damage to nail, sequela*/
,'S61211D'  /*Laceration without foreign body of left index finger without damage to nail, subsequent encounter*/
,'S61211S'  /*Laceration without foreign body of left index finger without damage to nail, sequela*/
,'S61212D'  /*Laceration without foreign body of right middle finger without damage to nail, subsequent encounter*/
,'S61212S'  /*Laceration without foreign body of right middle finger without damage to nail, sequela*/
,'S61213D'  /*Laceration without foreign body of left middle finger without damage to nail, subsequent encounter*/
,'S61213S'  /*Laceration without foreign body of left middle finger without damage to nail, sequela*/
,'S61214D'  /*Laceration without foreign body of right ring finger without damage to nail, subsequent encounter*/
,'S61214S'  /*Laceration without foreign body of right ring finger without damage to nail, sequela*/
,'S61215D'  /*Laceration without foreign body of left ring finger without damage to nail, subsequent encounter*/
,'S61215S'  /*Laceration without foreign body of left ring finger without damage to nail, sequela*/
,'S61216D'  /*Laceration without foreign body of right little finger without damage to nail, subsequent encounter*/
,'S61216S'  /*Laceration without foreign body of right little finger without damage to nail, sequela*/
,'S61217D'  /*Laceration without foreign body of left little finger without damage to nail, subsequent encounter*/
,'S61217S'  /*Laceration without foreign body of left little finger without damage to nail, sequela*/
,'S61218D'  /*Laceration without foreign body of other finger without damage to nail, subsequent encounter*/
,'S61218S'  /*Laceration without foreign body of other finger without damage to nail, sequela*/
,'S61219D'  /*Laceration without foreign body of unspecified finger without damage to nail, subsequent encounter*/
,'S61219S'  /*Laceration without foreign body of unspecified finger without damage to nail, sequela*/
,'S61220D'  /*Laceration with foreign body of right index finger without damage to nail, subsequent encounter*/
,'S61220S'  /*Laceration with foreign body of right index finger without damage to nail, sequela*/
,'S61221D'  /*Laceration with foreign body of left index finger without damage to nail, subsequent encounter*/
,'S61221S'  /*Laceration with foreign body of left index finger without damage to nail, sequela*/
,'S61222D'  /*Laceration with foreign body of right middle finger without damage to nail, subsequent encounter*/
,'S61222S'  /*Laceration with foreign body of right middle finger without damage to nail, sequela*/
,'S61223D'  /*Laceration with foreign body of left middle finger without damage to nail, subsequent encounter*/
,'S61223S'  /*Laceration with foreign body of left middle finger without damage to nail, sequela*/
,'S61224D'  /*Laceration with foreign body of right ring finger without damage to nail, subsequent encounter*/
,'S61224S'  /*Laceration with foreign body of right ring finger without damage to nail, sequela*/
,'S61225D'  /*Laceration with foreign body of left ring finger without damage to nail, subsequent encounter*/
,'S61225S'  /*Laceration with foreign body of left ring finger without damage to nail, sequela*/
,'S61226D'  /*Laceration with foreign body of right little finger without damage to nail, subsequent encounter*/
,'S61226S'  /*Laceration with foreign body of right little finger without damage to nail, sequela*/
,'S61227D'  /*Laceration with foreign body of left little finger without damage to nail, subsequent encounter*/
,'S61227S'  /*Laceration with foreign body of left little finger without damage to nail, sequela*/
,'S61228D'  /*Laceration with foreign body of other finger without damage to nail, subsequent encounter*/
,'S61228S'  /*Laceration with foreign body of other finger without damage to nail, sequela*/
,'S61229D'  /*Laceration with foreign body of unspecified finger without damage to nail, subsequent encounter*/
,'S61229S'  /*Laceration with foreign body of unspecified finger without damage to nail, sequela*/
,'S61230D'  /*Puncture wound without foreign body of right index finger without damage to nail, subsequent encounter*/
,'S61230S'  /*Puncture wound without foreign body of right index finger without damage to nail, sequela*/
,'S61231D'  /*Puncture wound without foreign body of left index finger without damage to nail, subsequent encounter*/
,'S61231S'  /*Puncture wound without foreign body of left index finger without damage to nail, sequela*/
,'S61232D'  /*Puncture wound without foreign body of right middle finger without damage to nail, subsequent encounter*/
,'S61232S'  /*Puncture wound without foreign body of right middle finger without damage to nail, sequela*/
,'S61233D'  /*Puncture wound without foreign body of left middle finger without damage to nail, subsequent encounter*/
,'S61233S'  /*Puncture wound without foreign body of left middle finger without damage to nail, sequela*/
,'S61234D'  /*Puncture wound without foreign body of right ring finger without damage to nail, subsequent encounter*/
,'S61234S'  /*Puncture wound without foreign body of right ring finger without damage to nail, sequela*/
,'S61235D'  /*Puncture wound without foreign body of left ring finger without damage to nail, subsequent encounter*/
,'S61235S'  /*Puncture wound without foreign body of left ring finger without damage to nail, sequela*/
,'S61236D'  /*Puncture wound without foreign body of right little finger without damage to nail, subsequent encounter*/
,'S61236S'  /*Puncture wound without foreign body of right little finger without damage to nail, sequela*/
,'S61237D'  /*Puncture wound without foreign body of left little finger without damage to nail, subsequent encounter*/
,'S61237S'  /*Puncture wound without foreign body of left little finger without damage to nail, sequela*/
,'S61238D'  /*Puncture wound without foreign body of other finger without damage to nail, subsequent encounter*/
,'S61238S'  /*Puncture wound without foreign body of other finger without damage to nail, sequela*/
,'S61239D'  /*Puncture wound without foreign body of unspecified finger without damage to nail, subsequent encounter*/
,'S61239S'  /*Puncture wound without foreign body of unspecified finger without damage to nail, sequela*/
,'S61240D'  /*Puncture wound with foreign body of right index finger without damage to nail, subsequent encounter*/
,'S61240S'  /*Puncture wound with foreign body of right index finger without damage to nail, sequela*/
,'S61241D'  /*Puncture wound with foreign body of left index finger without damage to nail, subsequent encounter*/
,'S61241S'  /*Puncture wound with foreign body of left index finger without damage to nail, sequela*/
,'S61242D'  /*Puncture wound with foreign body of right middle finger without damage to nail, subsequent encounter*/
,'S61242S'  /*Puncture wound with foreign body of right middle finger without damage to nail, sequela*/
,'S61243D'  /*Puncture wound with foreign body of left middle finger without damage to nail, subsequent encounter*/
,'S61243S'  /*Puncture wound with foreign body of left middle finger without damage to nail, sequela*/
,'S61244D'  /*Puncture wound with foreign body of right ring finger without damage to nail, subsequent encounter*/
,'S61244S'  /*Puncture wound with foreign body of right ring finger without damage to nail, sequela*/
,'S61245D'  /*Puncture wound with foreign body of left ring finger without damage to nail, subsequent encounter*/
,'S61245S'  /*Puncture wound with foreign body of left ring finger without damage to nail, sequela*/
,'S61246D'  /*Puncture wound with foreign body of right little finger without damage to nail, subsequent encounter*/
,'S61246S'  /*Puncture wound with foreign body of right little finger without damage to nail, sequela*/
,'S61247D'  /*Puncture wound with foreign body of left little finger without damage to nail, subsequent encounter*/
,'S61247S'  /*Puncture wound with foreign body of left little finger without damage to nail, sequela*/
,'S61248D'  /*Puncture wound with foreign body of other finger without damage to nail, subsequent encounter*/
,'S61248S'  /*Puncture wound with foreign body of other finger without damage to nail, sequela*/
,'S61249D'  /*Puncture wound with foreign body of unspecified finger without damage to nail, subsequent encounter*/
,'S61249S'  /*Puncture wound with foreign body of unspecified finger without damage to nail, sequela*/
,'S61250D'  /*Open bite of right index finger without damage to nail, subsequent encounter*/
,'S61250S'  /*Open bite of right index finger without damage to nail, sequela*/
,'S61251D'  /*Open bite of left index finger without damage to nail, subsequent encounter*/
,'S61251S'  /*Open bite of left index finger without damage to nail, sequela*/
,'S61252D'  /*Open bite of right middle finger without damage to nail, subsequent encounter*/
,'S61252S'  /*Open bite of right middle finger without damage to nail, sequela*/
,'S61253D'  /*Open bite of left middle finger without damage to nail, subsequent encounter*/
,'S61253S'  /*Open bite of left middle finger without damage to nail, sequela*/
,'S61254D'  /*Open bite of right ring finger without damage to nail, subsequent encounter*/
,'S61254S'  /*Open bite of right ring finger without damage to nail, sequela*/
,'S61255D'  /*Open bite of left ring finger without damage to nail, subsequent encounter*/
,'S61255S'  /*Open bite of left ring finger without damage to nail, sequela*/
,'S61256D'  /*Open bite of right little finger without damage to nail, subsequent encounter*/
,'S61256S'  /*Open bite of right little finger without damage to nail, sequela*/
,'S61257D'  /*Open bite of left little finger without damage to nail, subsequent encounter*/
,'S61257S'  /*Open bite of left little finger without damage to nail, sequela*/
,'S61258D'  /*Open bite of other finger without damage to nail, subsequent encounter*/
,'S61258S'  /*Open bite of other finger without damage to nail, sequela*/
,'S61259D'  /*Open bite of unspecified finger without damage to nail, subsequent encounter*/
,'S61259S'  /*Open bite of unspecified finger without damage to nail, sequela*/
,'S61300D'  /*Unspecified open wound of right index finger with damage to nail, subsequent encounter*/
,'S61300S'  /*Unspecified open wound of right index finger with damage to nail, sequela*/
,'S61301D'  /*Unspecified open wound of left index finger with damage to nail, subsequent encounter*/
,'S61301S'  /*Unspecified open wound of left index finger with damage to nail, sequela*/
,'S61302D'  /*Unspecified open wound of right middle finger with damage to nail, subsequent encounter*/
,'S61302S'  /*Unspecified open wound of right middle finger with damage to nail, sequela*/
,'S61303D'  /*Unspecified open wound of left middle finger with damage to nail, subsequent encounter*/
,'S61303S'  /*Unspecified open wound of left middle finger with damage to nail, sequela*/
,'S61304D'  /*Unspecified open wound of right ring finger with damage to nail, subsequent encounter*/
,'S61304S'  /*Unspecified open wound of right ring finger with damage to nail, sequela*/
,'S61305D'  /*Unspecified open wound of left ring finger with damage to nail, subsequent encounter*/
,'S61305S'  /*Unspecified open wound of left ring finger with damage to nail, sequela*/
,'S61306D'  /*Unspecified open wound of right little finger with damage to nail, subsequent encounter*/
,'S61306S'  /*Unspecified open wound of right little finger with damage to nail, sequela*/
,'S61307D'  /*Unspecified open wound of left little finger with damage to nail, subsequent encounter*/
,'S61307S'  /*Unspecified open wound of left little finger with damage to nail, sequela*/
,'S61308D'  /*Unspecified open wound of other finger with damage to nail, subsequent encounter*/
,'S61308S'  /*Unspecified open wound of other finger with damage to nail, sequela*/
,'S61309D'  /*Unspecified open wound of unspecified finger with damage to nail, subsequent encounter*/
,'S61309S'  /*Unspecified open wound of unspecified finger with damage to nail, sequela*/
,'S61310D'  /*Laceration without foreign body of right index finger with damage to nail, subsequent encounter*/
,'S61310S'  /*Laceration without foreign body of right index finger with damage to nail, sequela*/
,'S61311D'  /*Laceration without foreign body of left index finger with damage to nail, subsequent encounter*/
,'S61311S'  /*Laceration without foreign body of left index finger with damage to nail, sequela*/
,'S61312D'  /*Laceration without foreign body of right middle finger with damage to nail, subsequent encounter*/
,'S61312S'  /*Laceration without foreign body of right middle finger with damage to nail, sequela*/
,'S61313D'  /*Laceration without foreign body of left middle finger with damage to nail, subsequent encounter*/
,'S61313S'  /*Laceration without foreign body of left middle finger with damage to nail, sequela*/
,'S61314D'  /*Laceration without foreign body of right ring finger with damage to nail, subsequent encounter*/
,'S61314S'  /*Laceration without foreign body of right ring finger with damage to nail, sequela*/
,'S61315D'  /*Laceration without foreign body of left ring finger with damage to nail, subsequent encounter*/
,'S61315S'  /*Laceration without foreign body of left ring finger with damage to nail, sequela*/
,'S61316D'  /*Laceration without foreign body of right little finger with damage to nail, subsequent encounter*/
,'S61316S'  /*Laceration without foreign body of right little finger with damage to nail, sequela*/
,'S61317D'  /*Laceration without foreign body of left little finger with damage to nail, subsequent encounter*/
,'S61317S'  /*Laceration without foreign body of left little finger with damage to nail, sequela*/
,'S61318D'  /*Laceration without foreign body of other finger with damage to nail, subsequent encounter*/
,'S61318S'  /*Laceration without foreign body of other finger with damage to nail, sequela*/
,'S61319D'  /*Laceration without foreign body of unspecified finger with damage to nail, subsequent encounter*/
,'S61319S'  /*Laceration without foreign body of unspecified finger with damage to nail, sequela*/
,'S61320D'  /*Laceration with foreign body of right index finger with damage to nail, subsequent encounter*/
,'S61320S'  /*Laceration with foreign body of right index finger with damage to nail, sequela*/
,'S61321D'  /*Laceration with foreign body of left index finger with damage to nail, subsequent encounter*/
,'S61321S'  /*Laceration with foreign body of left index finger with damage to nail, sequela*/
,'S61322D'  /*Laceration with foreign body of right middle finger with damage to nail, subsequent encounter*/
,'S61322S'  /*Laceration with foreign body of right middle finger with damage to nail, sequela*/
,'S61323D'  /*Laceration with foreign body of left middle finger with damage to nail, subsequent encounter*/
,'S61323S'  /*Laceration with foreign body of left middle finger with damage to nail, sequela*/
,'S61324D'  /*Laceration with foreign body of right ring finger with damage to nail, subsequent encounter*/
,'S61324S'  /*Laceration with foreign body of right ring finger with damage to nail, sequela*/
,'S61325D'  /*Laceration with foreign body of left ring finger with damage to nail, subsequent encounter*/
,'S61325S'  /*Laceration with foreign body of left ring finger with damage to nail, sequela*/
,'S61326D'  /*Laceration with foreign body of right little finger with damage to nail, subsequent encounter*/
,'S61326S'  /*Laceration with foreign body of right little finger with damage to nail, sequela*/
,'S61327D'  /*Laceration with foreign body of left little finger with damage to nail, subsequent encounter*/
,'S61327S'  /*Laceration with foreign body of left little finger with damage to nail, sequela*/
,'S61328D'  /*Laceration with foreign body of other finger with damage to nail, subsequent encounter*/
,'S61328S'  /*Laceration with foreign body of other finger with damage to nail, sequela*/
,'S61329D'  /*Laceration with foreign body of unspecified finger with damage to nail, subsequent encounter*/
,'S61329S'  /*Laceration with foreign body of unspecified finger with damage to nail, sequela*/
,'S61330D'  /*Puncture wound without foreign body of right index finger with damage to nail, subsequent encounter*/
,'S61330S'  /*Puncture wound without foreign body of right index finger with damage to nail, sequela*/
,'S61331D'  /*Puncture wound without foreign body of left index finger with damage to nail, subsequent encounter*/
,'S61331S'  /*Puncture wound without foreign body of left index finger with damage to nail, sequela*/
,'S61332D'  /*Puncture wound without foreign body of right middle finger with damage to nail, subsequent encounter*/
,'S61332S'  /*Puncture wound without foreign body of right middle finger with damage to nail, sequela*/
,'S61333D'  /*Puncture wound without foreign body of left middle finger with damage to nail, subsequent encounter*/
,'S61333S'  /*Puncture wound without foreign body of left middle finger with damage to nail, sequela*/
,'S61334D'  /*Puncture wound without foreign body of right ring finger with damage to nail, subsequent encounter*/
,'S61334S'  /*Puncture wound without foreign body of right ring finger with damage to nail, sequela*/
,'S61335D'  /*Puncture wound without foreign body of left ring finger with damage to nail, subsequent encounter*/
,'S61335S'  /*Puncture wound without foreign body of left ring finger with damage to nail, sequela*/
,'S61336D'  /*Puncture wound without foreign body of right little finger with damage to nail, subsequent encounter*/
,'S61336S'  /*Puncture wound without foreign body of right little finger with damage to nail, sequela*/
,'S61337D'  /*Puncture wound without foreign body of left little finger with damage to nail, subsequent encounter*/
,'S61337S'  /*Puncture wound without foreign body of left little finger with damage to nail, sequela*/
,'S61338D'  /*Puncture wound without foreign body of other finger with damage to nail, subsequent encounter*/
,'S61338S'  /*Puncture wound without foreign body of other finger with damage to nail, sequela*/
,'S61339D'  /*Puncture wound without foreign body of unspecified finger with damage to nail, subsequent encounter*/
,'S61339S'  /*Puncture wound without foreign body of unspecified finger with damage to nail, sequela*/
,'S61340D'  /*Puncture wound with foreign body of right index finger with damage to nail, subsequent encounter*/
,'S61340S'  /*Puncture wound with foreign body of right index finger with damage to nail, sequela*/
,'S61341D'  /*Puncture wound with foreign body of left index finger with damage to nail, subsequent encounter*/
,'S61341S'  /*Puncture wound with foreign body of left index finger with damage to nail, sequela*/
,'S61342D'  /*Puncture wound with foreign body of right middle finger with damage to nail, subsequent encounter*/
,'S61342S'  /*Puncture wound with foreign body of right middle finger with damage to nail, sequela*/
,'S61343D'  /*Puncture wound with foreign body of left middle finger with damage to nail, subsequent encounter*/
,'S61343S'  /*Puncture wound with foreign body of left middle finger with damage to nail, sequela*/
,'S61344D'  /*Puncture wound with foreign body of right ring finger with damage to nail, subsequent encounter*/
,'S61344S'  /*Puncture wound with foreign body of right ring finger with damage to nail, sequela*/
,'S61345D'  /*Puncture wound with foreign body of left ring finger with damage to nail, subsequent encounter*/
,'S61345S'  /*Puncture wound with foreign body of left ring finger with damage to nail, sequela*/
,'S61346D'  /*Puncture wound with foreign body of right little finger with damage to nail, subsequent encounter*/
,'S61346S'  /*Puncture wound with foreign body of right little finger with damage to nail, sequela*/
,'S61347D'  /*Puncture wound with foreign body of left little finger with damage to nail, subsequent encounter*/
,'S61347S'  /*Puncture wound with foreign body of left little finger with damage to nail, sequela*/
,'S61348D'  /*Puncture wound with foreign body of other finger with damage to nail, subsequent encounter*/
,'S61348S'  /*Puncture wound with foreign body of other finger with damage to nail, sequela*/
,'S61349D'  /*Puncture wound with foreign body of unspecified finger with damage to nail, subsequent encounter*/
,'S61349S'  /*Puncture wound with foreign body of unspecified finger with damage to nail, sequela*/
,'S61350D'  /*Open bite of right index finger with damage to nail, subsequent encounter*/
,'S61350S'  /*Open bite of right index finger with damage to nail, sequela*/
,'S61351D'  /*Open bite of left index finger with damage to nail, subsequent encounter*/
,'S61351S'  /*Open bite of left index finger with damage to nail, sequela*/
,'S61352D'  /*Open bite of right middle finger with damage to nail, subsequent encounter*/
,'S61352S'  /*Open bite of right middle finger with damage to nail, sequela*/
,'S61353D'  /*Open bite of left middle finger with damage to nail, subsequent encounter*/
,'S61353S'  /*Open bite of left middle finger with damage to nail, sequela*/
,'S61354D'  /*Open bite of right ring finger with damage to nail, subsequent encounter*/
,'S61354S'  /*Open bite of right ring finger with damage to nail, sequela*/
,'S61355D'  /*Open bite of left ring finger with damage to nail, subsequent encounter*/
,'S61355S'  /*Open bite of left ring finger with damage to nail, sequela*/
,'S61356D'  /*Open bite of right little finger with damage to nail, subsequent encounter*/
,'S61356S'  /*Open bite of right little finger with damage to nail, sequela*/
,'S61357D'  /*Open bite of left little finger with damage to nail, subsequent encounter*/
,'S61357S'  /*Open bite of left little finger with damage to nail, sequela*/
,'S61358D'  /*Open bite of other finger with damage to nail, subsequent encounter*/
,'S61358S'  /*Open bite of other finger with damage to nail, sequela*/
,'S61359D'  /*Open bite of unspecified finger with damage to nail, subsequent encounter*/
,'S61359S'  /*Open bite of unspecified finger with damage to nail, sequela*/
,'S61401D'  /*Unspecified open wound of right hand, subsequent encounter*/
,'S61401S'  /*Unspecified open wound of right hand, sequela*/
,'S61402D'  /*Unspecified open wound of left hand, subsequent encounter*/
,'S61402S'  /*Unspecified open wound of left hand, sequela*/
,'S61409D'  /*Unspecified open wound of unspecified hand, subsequent encounter*/
,'S61409S'  /*Unspecified open wound of unspecified hand, sequela*/
,'S61411D'  /*Laceration without foreign body of right hand, subsequent encounter*/
,'S61411S'  /*Laceration without foreign body of right hand, sequela*/
,'S61412D'  /*Laceration without foreign body of left hand, subsequent encounter*/
,'S61412S'  /*Laceration without foreign body of left hand, sequela*/
,'S61419D'  /*Laceration without foreign body of unspecified hand, subsequent encounter*/
,'S61419S'  /*Laceration without foreign body of unspecified hand, sequela*/
,'S61421D'  /*Laceration with foreign body of right hand, subsequent encounter*/
,'S61421S'  /*Laceration with foreign body of right hand, sequela*/
,'S61422D'  /*Laceration with foreign body of left hand, subsequent encounter*/
,'S61422S'  /*Laceration with foreign body of left hand, sequela*/
,'S61429D'  /*Laceration with foreign body of unspecified hand, subsequent encounter*/
,'S61429S'  /*Laceration with foreign body of unspecified hand, sequela*/
,'S61431D'  /*Puncture wound without foreign body of right hand, subsequent encounter*/
,'S61431S'  /*Puncture wound without foreign body of right hand, sequela*/
,'S61432D'  /*Puncture wound without foreign body of left hand, subsequent encounter*/
,'S61432S'  /*Puncture wound without foreign body of left hand, sequela*/
,'S61439D'  /*Puncture wound without foreign body of unspecified hand, subsequent encounter*/
,'S61439S'  /*Puncture wound without foreign body of unspecified hand, sequela*/
,'S61441D'  /*Puncture wound with foreign body of right hand, subsequent encounter*/
,'S61441S'  /*Puncture wound with foreign body of right hand, sequela*/
,'S61442D'  /*Puncture wound with foreign body of left hand, subsequent encounter*/
,'S61442S'  /*Puncture wound with foreign body of left hand, sequela*/
,'S61449D'  /*Puncture wound with foreign body of unspecified hand, subsequent encounter*/
,'S61449S'  /*Puncture wound with foreign body of unspecified hand, sequela*/
,'S61451D'  /*Open bite of right hand, subsequent encounter*/
,'S61451S'  /*Open bite of right hand, sequela*/
,'S61452D'  /*Open bite of left hand, subsequent encounter*/
,'S61452S'  /*Open bite of left hand, sequela*/
,'S61459D'  /*Open bite of unspecified hand, subsequent encounter*/
,'S61459S'  /*Open bite of unspecified hand, sequela*/
,'S61501D'  /*Unspecified open wound of right wrist, subsequent encounter*/
,'S61501S'  /*Unspecified open wound of right wrist, sequela*/
,'S61502D'  /*Unspecified open wound of left wrist, subsequent encounter*/
,'S61502S'  /*Unspecified open wound of left wrist, sequela*/
,'S61509D'  /*Unspecified open wound of unspecified wrist, subsequent encounter*/
,'S61509S'  /*Unspecified open wound of unspecified wrist, sequela*/
,'S61511D'  /*Laceration without foreign body of right wrist, subsequent encounter*/
,'S61511S'  /*Laceration without foreign body of right wrist, sequela*/
,'S61512D'  /*Laceration without foreign body of left wrist, subsequent encounter*/
,'S61512S'  /*Laceration without foreign body of left wrist, sequela*/
,'S61519D'  /*Laceration without foreign body of unspecified wrist, subsequent encounter*/
,'S61519S'  /*Laceration without foreign body of unspecified wrist, sequela*/
,'S61521D'  /*Laceration with foreign body of right wrist, subsequent encounter*/
,'S61521S'  /*Laceration with foreign body of right wrist, sequela*/
,'S61522D'  /*Laceration with foreign body of left wrist, subsequent encounter*/
,'S61522S'  /*Laceration with foreign body of left wrist, sequela*/
,'S61529D'  /*Laceration with foreign body of unspecified wrist, subsequent encounter*/
,'S61529S'  /*Laceration with foreign body of unspecified wrist, sequela*/
,'S61531D'  /*Puncture wound without foreign body of right wrist, subsequent encounter*/
,'S61531S'  /*Puncture wound without foreign body of right wrist, sequela*/
,'S61532D'  /*Puncture wound without foreign body of left wrist, subsequent encounter*/
,'S61532S'  /*Puncture wound without foreign body of left wrist, sequela*/
,'S61539D'  /*Puncture wound without foreign body of unspecified wrist, subsequent encounter*/
,'S61539S'  /*Puncture wound without foreign body of unspecified wrist, sequela*/
,'S61541D'  /*Puncture wound with foreign body of right wrist, subsequent encounter*/
,'S61541S'  /*Puncture wound with foreign body of right wrist, sequela*/
,'S61542D'  /*Puncture wound with foreign body of left wrist, subsequent encounter*/
,'S61542S'  /*Puncture wound with foreign body of left wrist, sequela*/
,'S61549D'  /*Puncture wound with foreign body of unspecified wrist, subsequent encounter*/
,'S61549S'  /*Puncture wound with foreign body of unspecified wrist, sequela*/
,'S61551D'  /*Open bite of right wrist, subsequent encounter*/
,'S61551S'  /*Open bite of right wrist, sequela*/
,'S61552D'  /*Open bite of left wrist, subsequent encounter*/
,'S61552S'  /*Open bite of left wrist, sequela*/
,'S61559D'  /*Open bite of unspecified wrist, subsequent encounter*/
,'S61559S'  /*Open bite of unspecified wrist, sequela*/
,'S62001D'  /*Unspecified fracture of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with routine healing*/
,'S62001G'  /*Unspecified fracture of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with delayed healing*/
,'S62001K'  /*Unspecified fracture of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with nonunion*/
,'S62001P'  /*Unspecified fracture of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with malunion*/
,'S62001S'  /*Unspecified fracture of navicular [scaphoid] bone of right wrist, sequela*/
,'S62002D'  /*Unspecified fracture of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with routine healing*/
,'S62002G'  /*Unspecified fracture of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with delayed healing*/
,'S62002K'  /*Unspecified fracture of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with nonunion*/
,'S62002P'  /*Unspecified fracture of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with malunion*/
,'S62002S'  /*Unspecified fracture of navicular [scaphoid] bone of left wrist, sequela*/
,'S62009D'  /*Unspecified fracture of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62009G'  /*Unspecified fracture of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62009K'  /*Unspecified fracture of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62009P'  /*Unspecified fracture of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62009S'  /*Unspecified fracture of navicular [scaphoid] bone of unspecified wrist, sequela*/
,'S62011D'  /*Displaced fracture of distal pole of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with routine healing*/
,'S62011G'  /*Displaced fracture of distal pole of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with delayed healing*/
,'S62011K'  /*Displaced fracture of distal pole of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with nonunion*/
,'S62011P'  /*Displaced fracture of distal pole of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with malunion*/
,'S62011S'  /*Displaced fracture of distal pole of navicular [scaphoid] bone of right wrist, sequela*/
,'S62012D'  /*Displaced fracture of distal pole of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with routine healing*/
,'S62012G'  /*Displaced fracture of distal pole of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with delayed healing*/
,'S62012K'  /*Displaced fracture of distal pole of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with nonunion*/
,'S62012P'  /*Displaced fracture of distal pole of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with malunion*/
,'S62012S'  /*Displaced fracture of distal pole of navicular [scaphoid] bone of left wrist, sequela*/
,'S62013D'  /*Displaced fracture of distal pole of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62013G'  /*Displaced fracture of distal pole of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62013K'  /*Displaced fracture of distal pole of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62013P'  /*Displaced fracture of distal pole of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62013S'  /*Displaced fracture of distal pole of navicular [scaphoid] bone of unspecified wrist, sequela*/
,'S62014D'  /*Nondisplaced fracture of distal pole of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with routine healing*/
,'S62014G'  /*Nondisplaced fracture of distal pole of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with delayed healing*/
,'S62014K'  /*Nondisplaced fracture of distal pole of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with nonunion*/
,'S62014P'  /*Nondisplaced fracture of distal pole of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with malunion*/
,'S62014S'  /*Nondisplaced fracture of distal pole of navicular [scaphoid] bone of right wrist, sequela*/
,'S62015D'  /*Nondisplaced fracture of distal pole of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with routine healing*/
,'S62015G'  /*Nondisplaced fracture of distal pole of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with delayed healing*/
,'S62015K'  /*Nondisplaced fracture of distal pole of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with nonunion*/
,'S62015P'  /*Nondisplaced fracture of distal pole of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with malunion*/
,'S62015S'  /*Nondisplaced fracture of distal pole of navicular [scaphoid] bone of left wrist, sequela*/
,'S62016D'  /*Nondisplaced fracture of distal pole of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62016G'  /*Nondisplaced fracture of distal pole of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62016K'  /*Nondisplaced fracture of distal pole of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62016P'  /*Nondisplaced fracture of distal pole of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62016S'  /*Nondisplaced fracture of distal pole of navicular [scaphoid] bone of unspecified wrist, sequela*/
,'S62021D'  /*Displaced fracture of middle third of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with routine healing*/
,'S62021G'  /*Displaced fracture of middle third of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with delayed healing*/
,'S62021K'  /*Displaced fracture of middle third of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with nonunion*/
,'S62021P'  /*Displaced fracture of middle third of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with malunion*/
,'S62021S'  /*Displaced fracture of middle third of navicular [scaphoid] bone of right wrist, sequela*/
,'S62022D'  /*Displaced fracture of middle third of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with routine healing*/
,'S62022G'  /*Displaced fracture of middle third of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with delayed healing*/
,'S62022K'  /*Displaced fracture of middle third of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with nonunion*/
,'S62022P'  /*Displaced fracture of middle third of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with malunion*/
,'S62022S'  /*Displaced fracture of middle third of navicular [scaphoid] bone of left wrist, sequela*/
,'S62023D'  /*Displaced fracture of middle third of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62023G'  /*Displaced fracture of middle third of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62023K'  /*Displaced fracture of middle third of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62023P'  /*Displaced fracture of middle third of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62023S'  /*Displaced fracture of middle third of navicular [scaphoid] bone of unspecified wrist, sequela*/
,'S62024D'  /*Nondisplaced fracture of middle third of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with routine healing*/
,'S62024G'  /*Nondisplaced fracture of middle third of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with delayed healing*/
,'S62024K'  /*Nondisplaced fracture of middle third of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with nonunion*/
,'S62024P'  /*Nondisplaced fracture of middle third of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with malunion*/
,'S62024S'  /*Nondisplaced fracture of middle third of navicular [scaphoid] bone of right wrist, sequela*/
,'S62025D'  /*Nondisplaced fracture of middle third of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with routine healing*/
,'S62025G'  /*Nondisplaced fracture of middle third of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with delayed healing*/
,'S62025K'  /*Nondisplaced fracture of middle third of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with nonunion*/
,'S62025P'  /*Nondisplaced fracture of middle third of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with malunion*/
,'S62025S'  /*Nondisplaced fracture of middle third of navicular [scaphoid] bone of left wrist, sequela*/
,'S62026D'  /*Nondisplaced fracture of middle third of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62026G'  /*Nondisplaced fracture of middle third of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62026K'  /*Nondisplaced fracture of middle third of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62026P'  /*Nondisplaced fracture of middle third of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62026S'  /*Nondisplaced fracture of middle third of navicular [scaphoid] bone of unspecified wrist, sequela*/
,'S62031D'  /*Displaced fracture of proximal third of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with routine healing*/
,'S62031G'  /*Displaced fracture of proximal third of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with delayed healing*/
,'S62031K'  /*Displaced fracture of proximal third of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with nonunion*/
,'S62031P'  /*Displaced fracture of proximal third of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with malunion*/
,'S62031S'  /*Displaced fracture of proximal third of navicular [scaphoid] bone of right wrist, sequela*/
,'S62032D'  /*Displaced fracture of proximal third of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with routine healing*/
,'S62032G'  /*Displaced fracture of proximal third of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with delayed healing*/
,'S62032K'  /*Displaced fracture of proximal third of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with nonunion*/
,'S62032P'  /*Displaced fracture of proximal third of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with malunion*/
,'S62032S'  /*Displaced fracture of proximal third of navicular [scaphoid] bone of left wrist, sequela*/
,'S62033D'  /*Displaced fracture of proximal third of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62033G'  /*Displaced fracture of proximal third of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62033K'  /*Displaced fracture of proximal third of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62033P'  /*Displaced fracture of proximal third of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62033S'  /*Displaced fracture of proximal third of navicular [scaphoid] bone of unspecified wrist, sequela*/
,'S62034D'  /*Nondisplaced fracture of proximal third of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with routine healing*/
,'S62034G'  /*Nondisplaced fracture of proximal third of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with delayed healing*/
,'S62034K'  /*Nondisplaced fracture of proximal third of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with nonunion*/
,'S62034P'  /*Nondisplaced fracture of proximal third of navicular [scaphoid] bone of right wrist, subsequent encounter for fracture with malunion*/
,'S62034S'  /*Nondisplaced fracture of proximal third of navicular [scaphoid] bone of right wrist, sequela*/
,'S62035D'  /*Nondisplaced fracture of proximal third of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with routine healing*/
,'S62035G'  /*Nondisplaced fracture of proximal third of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with delayed healing*/
,'S62035K'  /*Nondisplaced fracture of proximal third of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with nonunion*/
,'S62035P'  /*Nondisplaced fracture of proximal third of navicular [scaphoid] bone of left wrist, subsequent encounter for fracture with malunion*/
,'S62035S'  /*Nondisplaced fracture of proximal third of navicular [scaphoid] bone of left wrist, sequela*/
,'S62036D'  /*Nondisplaced fracture of proximal third of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62036G'  /*Nondisplaced fracture of proximal third of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62036K'  /*Nondisplaced fracture of proximal third of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62036P'  /*Nondisplaced fracture of proximal third of navicular [scaphoid] bone of unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62036S'  /*Nondisplaced fracture of proximal third of navicular [scaphoid] bone of unspecified wrist, sequela*/
,'S62101D'  /*Fracture of unspecified carpal bone, right wrist, subsequent encounter for fracture with routine healing*/
,'S62101G'  /*Fracture of unspecified carpal bone, right wrist, subsequent encounter for fracture with delayed healing*/
,'S62101K'  /*Fracture of unspecified carpal bone, right wrist, subsequent encounter for fracture with nonunion*/
,'S62101P'  /*Fracture of unspecified carpal bone, right wrist, subsequent encounter for fracture with malunion*/
,'S62101S'  /*Fracture of unspecified carpal bone, right wrist, sequela*/
,'S62102D'  /*Fracture of unspecified carpal bone, left wrist, subsequent encounter for fracture with routine healing*/
,'S62102G'  /*Fracture of unspecified carpal bone, left wrist, subsequent encounter for fracture with delayed healing*/
,'S62102K'  /*Fracture of unspecified carpal bone, left wrist, subsequent encounter for fracture with nonunion*/
,'S62102P'  /*Fracture of unspecified carpal bone, left wrist, subsequent encounter for fracture with malunion*/
,'S62102S'  /*Fracture of unspecified carpal bone, left wrist, sequela*/
,'S62109D'  /*Fracture of unspecified carpal bone, unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62109G'  /*Fracture of unspecified carpal bone, unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62109K'  /*Fracture of unspecified carpal bone, unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62109P'  /*Fracture of unspecified carpal bone, unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62109S'  /*Fracture of unspecified carpal bone, unspecified wrist, sequela*/
,'S62111D'  /*Displaced fracture of triquetrum [cuneiform] bone, right wrist, subsequent encounter for fracture with routine healing*/
,'S62111G'  /*Displaced fracture of triquetrum [cuneiform] bone, right wrist, subsequent encounter for fracture with delayed healing*/
,'S62111K'  /*Displaced fracture of triquetrum [cuneiform] bone, right wrist, subsequent encounter for fracture with nonunion*/
,'S62111P'  /*Displaced fracture of triquetrum [cuneiform] bone, right wrist, subsequent encounter for fracture with malunion*/
,'S62111S'  /*Displaced fracture of triquetrum [cuneiform] bone, right wrist, sequela*/
,'S62112D'  /*Displaced fracture of triquetrum [cuneiform] bone, left wrist, subsequent encounter for fracture with routine healing*/
,'S62112G'  /*Displaced fracture of triquetrum [cuneiform] bone, left wrist, subsequent encounter for fracture with delayed healing*/
,'S62112K'  /*Displaced fracture of triquetrum [cuneiform] bone, left wrist, subsequent encounter for fracture with nonunion*/
,'S62112P'  /*Displaced fracture of triquetrum [cuneiform] bone, left wrist, subsequent encounter for fracture with malunion*/
,'S62112S'  /*Displaced fracture of triquetrum [cuneiform] bone, left wrist, sequela*/
,'S62113D'  /*Displaced fracture of triquetrum [cuneiform] bone, unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62113G'  /*Displaced fracture of triquetrum [cuneiform] bone, unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62113K'  /*Displaced fracture of triquetrum [cuneiform] bone, unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62113P'  /*Displaced fracture of triquetrum [cuneiform] bone, unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62113S'  /*Displaced fracture of triquetrum [cuneiform] bone, unspecified wrist, sequela*/
,'S62114D'  /*Nondisplaced fracture of triquetrum [cuneiform] bone, right wrist, subsequent encounter for fracture with routine healing*/
,'S62114G'  /*Nondisplaced fracture of triquetrum [cuneiform] bone, right wrist, subsequent encounter for fracture with delayed healing*/
,'S62114K'  /*Nondisplaced fracture of triquetrum [cuneiform] bone, right wrist, subsequent encounter for fracture with nonunion*/
,'S62114P'  /*Nondisplaced fracture of triquetrum [cuneiform] bone, right wrist, subsequent encounter for fracture with malunion*/
,'S62114S'  /*Nondisplaced fracture of triquetrum [cuneiform] bone, right wrist, sequela*/
,'S62115D'  /*Nondisplaced fracture of triquetrum [cuneiform] bone, left wrist, subsequent encounter for fracture with routine healing*/
,'S62115G'  /*Nondisplaced fracture of triquetrum [cuneiform] bone, left wrist, subsequent encounter for fracture with delayed healing*/
,'S62115K'  /*Nondisplaced fracture of triquetrum [cuneiform] bone, left wrist, subsequent encounter for fracture with nonunion*/
,'S62115P'  /*Nondisplaced fracture of triquetrum [cuneiform] bone, left wrist, subsequent encounter for fracture with malunion*/
,'S62115S'  /*Nondisplaced fracture of triquetrum [cuneiform] bone, left wrist, sequela*/
,'S62116D'  /*Nondisplaced fracture of triquetrum [cuneiform] bone, unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62116G'  /*Nondisplaced fracture of triquetrum [cuneiform] bone, unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62116K'  /*Nondisplaced fracture of triquetrum [cuneiform] bone, unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62116P'  /*Nondisplaced fracture of triquetrum [cuneiform] bone, unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62116S'  /*Nondisplaced fracture of triquetrum [cuneiform] bone, unspecified wrist, sequela*/
,'S62121D'  /*Displaced fracture of lunate [semilunar], right wrist, subsequent encounter for fracture with routine healing*/
,'S62121G'  /*Displaced fracture of lunate [semilunar], right wrist, subsequent encounter for fracture with delayed healing*/
,'S62121K'  /*Displaced fracture of lunate [semilunar], right wrist, subsequent encounter for fracture with nonunion*/
,'S62121P'  /*Displaced fracture of lunate [semilunar], right wrist, subsequent encounter for fracture with malunion*/
,'S62121S'  /*Displaced fracture of lunate [semilunar], right wrist, sequela*/
,'S62122D'  /*Displaced fracture of lunate [semilunar], left wrist, subsequent encounter for fracture with routine healing*/
,'S62122G'  /*Displaced fracture of lunate [semilunar], left wrist, subsequent encounter for fracture with delayed healing*/
,'S62122K'  /*Displaced fracture of lunate [semilunar], left wrist, subsequent encounter for fracture with nonunion*/
,'S62122P'  /*Displaced fracture of lunate [semilunar], left wrist, subsequent encounter for fracture with malunion*/
,'S62122S'  /*Displaced fracture of lunate [semilunar], left wrist, sequela*/
,'S62123D'  /*Displaced fracture of lunate [semilunar], unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62123G'  /*Displaced fracture of lunate [semilunar], unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62123K'  /*Displaced fracture of lunate [semilunar], unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62123P'  /*Displaced fracture of lunate [semilunar], unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62123S'  /*Displaced fracture of lunate [semilunar], unspecified wrist, sequela*/
,'S62124D'  /*Nondisplaced fracture of lunate [semilunar], right wrist, subsequent encounter for fracture with routine healing*/
,'S62124G'  /*Nondisplaced fracture of lunate [semilunar], right wrist, subsequent encounter for fracture with delayed healing*/
,'S62124K'  /*Nondisplaced fracture of lunate [semilunar], right wrist, subsequent encounter for fracture with nonunion*/
,'S62124P'  /*Nondisplaced fracture of lunate [semilunar], right wrist, subsequent encounter for fracture with malunion*/
,'S62124S'  /*Nondisplaced fracture of lunate [semilunar], right wrist, sequela*/
,'S62125D'  /*Nondisplaced fracture of lunate [semilunar], left wrist, subsequent encounter for fracture with routine healing*/
,'S62125G'  /*Nondisplaced fracture of lunate [semilunar], left wrist, subsequent encounter for fracture with delayed healing*/
,'S62125K'  /*Nondisplaced fracture of lunate [semilunar], left wrist, subsequent encounter for fracture with nonunion*/
,'S62125P'  /*Nondisplaced fracture of lunate [semilunar], left wrist, subsequent encounter for fracture with malunion*/
,'S62125S'  /*Nondisplaced fracture of lunate [semilunar], left wrist, sequela*/
,'S62126D'  /*Nondisplaced fracture of lunate [semilunar], unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62126G'  /*Nondisplaced fracture of lunate [semilunar], unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62126K'  /*Nondisplaced fracture of lunate [semilunar], unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62126P'  /*Nondisplaced fracture of lunate [semilunar], unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62126S'  /*Nondisplaced fracture of lunate [semilunar], unspecified wrist, sequela*/
,'S62131D'  /*Displaced fracture of capitate [os magnum] bone, right wrist, subsequent encounter for fracture with routine healing*/
,'S62131G'  /*Displaced fracture of capitate [os magnum] bone, right wrist, subsequent encounter for fracture with delayed healing*/
,'S62131K'  /*Displaced fracture of capitate [os magnum] bone, right wrist, subsequent encounter for fracture with nonunion*/
,'S62131P'  /*Displaced fracture of capitate [os magnum] bone, right wrist, subsequent encounter for fracture with malunion*/
,'S62131S'  /*Displaced fracture of capitate [os magnum] bone, right wrist, sequela*/
,'S62132D'  /*Displaced fracture of capitate [os magnum] bone, left wrist, subsequent encounter for fracture with routine healing*/
,'S62132G'  /*Displaced fracture of capitate [os magnum] bone, left wrist, subsequent encounter for fracture with delayed healing*/
,'S62132K'  /*Displaced fracture of capitate [os magnum] bone, left wrist, subsequent encounter for fracture with nonunion*/
,'S62132P'  /*Displaced fracture of capitate [os magnum] bone, left wrist, subsequent encounter for fracture with malunion*/
,'S62132S'  /*Displaced fracture of capitate [os magnum] bone, left wrist, sequela*/
,'S62133D'  /*Displaced fracture of capitate [os magnum] bone, unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62133G'  /*Displaced fracture of capitate [os magnum] bone, unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62133K'  /*Displaced fracture of capitate [os magnum] bone, unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62133P'  /*Displaced fracture of capitate [os magnum] bone, unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62133S'  /*Displaced fracture of capitate [os magnum] bone, unspecified wrist, sequela*/
,'S62134D'  /*Nondisplaced fracture of capitate [os magnum] bone, right wrist, subsequent encounter for fracture with routine healing*/
,'S62134G'  /*Nondisplaced fracture of capitate [os magnum] bone, right wrist, subsequent encounter for fracture with delayed healing*/
,'S62134K'  /*Nondisplaced fracture of capitate [os magnum] bone, right wrist, subsequent encounter for fracture with nonunion*/
,'S62134P'  /*Nondisplaced fracture of capitate [os magnum] bone, right wrist, subsequent encounter for fracture with malunion*/
,'S62134S'  /*Nondisplaced fracture of capitate [os magnum] bone, right wrist, sequela*/
,'S62135D'  /*Nondisplaced fracture of capitate [os magnum] bone, left wrist, subsequent encounter for fracture with routine healing*/
,'S62135G'  /*Nondisplaced fracture of capitate [os magnum] bone, left wrist, subsequent encounter for fracture with delayed healing*/
,'S62135K'  /*Nondisplaced fracture of capitate [os magnum] bone, left wrist, subsequent encounter for fracture with nonunion*/
,'S62135P'  /*Nondisplaced fracture of capitate [os magnum] bone, left wrist, subsequent encounter for fracture with malunion*/
,'S62135S'  /*Nondisplaced fracture of capitate [os magnum] bone, left wrist, sequela*/
,'S62136D'  /*Nondisplaced fracture of capitate [os magnum] bone, unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62136G'  /*Nondisplaced fracture of capitate [os magnum] bone, unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62136K'  /*Nondisplaced fracture of capitate [os magnum] bone, unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62136P'  /*Nondisplaced fracture of capitate [os magnum] bone, unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62136S'  /*Nondisplaced fracture of capitate [os magnum] bone, unspecified wrist, sequela*/
,'S62141D'  /*Displaced fracture of body of hamate [unciform] bone, right wrist, subsequent encounter for fracture with routine healing*/
,'S62141G'  /*Displaced fracture of body of hamate [unciform] bone, right wrist, subsequent encounter for fracture with delayed healing*/
,'S62141K'  /*Displaced fracture of body of hamate [unciform] bone, right wrist, subsequent encounter for fracture with nonunion*/
,'S62141P'  /*Displaced fracture of body of hamate [unciform] bone, right wrist, subsequent encounter for fracture with malunion*/
,'S62141S'  /*Displaced fracture of body of hamate [unciform] bone, right wrist, sequela*/
,'S62142D'  /*Displaced fracture of body of hamate [unciform] bone, left wrist, subsequent encounter for fracture with routine healing*/
,'S62142G'  /*Displaced fracture of body of hamate [unciform] bone, left wrist, subsequent encounter for fracture with delayed healing*/
,'S62142K'  /*Displaced fracture of body of hamate [unciform] bone, left wrist, subsequent encounter for fracture with nonunion*/
,'S62142P'  /*Displaced fracture of body of hamate [unciform] bone, left wrist, subsequent encounter for fracture with malunion*/
,'S62142S'  /*Displaced fracture of body of hamate [unciform] bone, left wrist, sequela*/
,'S62143D'  /*Displaced fracture of body of hamate [unciform] bone, unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62143G'  /*Displaced fracture of body of hamate [unciform] bone, unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62143K'  /*Displaced fracture of body of hamate [unciform] bone, unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62143P'  /*Displaced fracture of body of hamate [unciform] bone, unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62143S'  /*Displaced fracture of body of hamate [unciform] bone, unspecified wrist, sequela*/
,'S62144D'  /*Nondisplaced fracture of body of hamate [unciform] bone, right wrist, subsequent encounter for fracture with routine healing*/
,'S62144G'  /*Nondisplaced fracture of body of hamate [unciform] bone, right wrist, subsequent encounter for fracture with delayed healing*/
,'S62144K'  /*Nondisplaced fracture of body of hamate [unciform] bone, right wrist, subsequent encounter for fracture with nonunion*/
,'S62144P'  /*Nondisplaced fracture of body of hamate [unciform] bone, right wrist, subsequent encounter for fracture with malunion*/
,'S62144S'  /*Nondisplaced fracture of body of hamate [unciform] bone, right wrist, sequela*/
,'S62145D'  /*Nondisplaced fracture of body of hamate [unciform] bone, left wrist, subsequent encounter for fracture with routine healing*/
,'S62145G'  /*Nondisplaced fracture of body of hamate [unciform] bone, left wrist, subsequent encounter for fracture with delayed healing*/
,'S62145K'  /*Nondisplaced fracture of body of hamate [unciform] bone, left wrist, subsequent encounter for fracture with nonunion*/
,'S62145P'  /*Nondisplaced fracture of body of hamate [unciform] bone, left wrist, subsequent encounter for fracture with malunion*/
,'S62145S'  /*Nondisplaced fracture of body of hamate [unciform] bone, left wrist, sequela*/
,'S62146D'  /*Nondisplaced fracture of body of hamate [unciform] bone, unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62146G'  /*Nondisplaced fracture of body of hamate [unciform] bone, unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62146K'  /*Nondisplaced fracture of body of hamate [unciform] bone, unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62146P'  /*Nondisplaced fracture of body of hamate [unciform] bone, unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62146S'  /*Nondisplaced fracture of body of hamate [unciform] bone, unspecified wrist, sequela*/
,'S62151D'  /*Displaced fracture of hook process of hamate [unciform] bone, right wrist, subsequent encounter for fracture with routine healing*/
,'S62151G'  /*Displaced fracture of hook process of hamate [unciform] bone, right wrist, subsequent encounter for fracture with delayed healing*/
,'S62151K'  /*Displaced fracture of hook process of hamate [unciform] bone, right wrist, subsequent encounter for fracture with nonunion*/
,'S62151P'  /*Displaced fracture of hook process of hamate [unciform] bone, right wrist, subsequent encounter for fracture with malunion*/
,'S62151S'  /*Displaced fracture of hook process of hamate [unciform] bone, right wrist, sequela*/
,'S62152D'  /*Displaced fracture of hook process of hamate [unciform] bone, left wrist, subsequent encounter for fracture with routine healing*/
,'S62152G'  /*Displaced fracture of hook process of hamate [unciform] bone, left wrist, subsequent encounter for fracture with delayed healing*/
,'S62152K'  /*Displaced fracture of hook process of hamate [unciform] bone, left wrist, subsequent encounter for fracture with nonunion*/
,'S62152P'  /*Displaced fracture of hook process of hamate [unciform] bone, left wrist, subsequent encounter for fracture with malunion*/
,'S62152S'  /*Displaced fracture of hook process of hamate [unciform] bone, left wrist, sequela*/
,'S62153D'  /*Displaced fracture of hook process of hamate [unciform] bone, unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62153G'  /*Displaced fracture of hook process of hamate [unciform] bone, unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62153K'  /*Displaced fracture of hook process of hamate [unciform] bone, unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62153P'  /*Displaced fracture of hook process of hamate [unciform] bone, unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62153S'  /*Displaced fracture of hook process of hamate [unciform] bone, unspecified wrist, sequela*/
,'S62154D'  /*Nondisplaced fracture of hook process of hamate [unciform] bone, right wrist, subsequent encounter for fracture with routine healing*/
,'S62154G'  /*Nondisplaced fracture of hook process of hamate [unciform] bone, right wrist, subsequent encounter for fracture with delayed healing*/
,'S62154K'  /*Nondisplaced fracture of hook process of hamate [unciform] bone, right wrist, subsequent encounter for fracture with nonunion*/
,'S62154P'  /*Nondisplaced fracture of hook process of hamate [unciform] bone, right wrist, subsequent encounter for fracture with malunion*/
,'S62154S'  /*Nondisplaced fracture of hook process of hamate [unciform] bone, right wrist, sequela*/
,'S62155D'  /*Nondisplaced fracture of hook process of hamate [unciform] bone, left wrist, subsequent encounter for fracture with routine healing*/
,'S62155G'  /*Nondisplaced fracture of hook process of hamate [unciform] bone, left wrist, subsequent encounter for fracture with delayed healing*/
,'S62155K'  /*Nondisplaced fracture of hook process of hamate [unciform] bone, left wrist, subsequent encounter for fracture with nonunion*/
,'S62155P'  /*Nondisplaced fracture of hook process of hamate [unciform] bone, left wrist, subsequent encounter for fracture with malunion*/
,'S62155S'  /*Nondisplaced fracture of hook process of hamate [unciform] bone, left wrist, sequela*/
,'S62156D'  /*Nondisplaced fracture of hook process of hamate [unciform] bone, unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62156G'  /*Nondisplaced fracture of hook process of hamate [unciform] bone, unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62156K'  /*Nondisplaced fracture of hook process of hamate [unciform] bone, unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62156P'  /*Nondisplaced fracture of hook process of hamate [unciform] bone, unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62156S'  /*Nondisplaced fracture of hook process of hamate [unciform] bone, unspecified wrist, sequela*/
,'S62161D'  /*Displaced fracture of pisiform, right wrist, subsequent encounter for fracture with routine healing*/
,'S62161G'  /*Displaced fracture of pisiform, right wrist, subsequent encounter for fracture with delayed healing*/
,'S62161K'  /*Displaced fracture of pisiform, right wrist, subsequent encounter for fracture with nonunion*/
,'S62161P'  /*Displaced fracture of pisiform, right wrist, subsequent encounter for fracture with malunion*/
,'S62161S'  /*Displaced fracture of pisiform, right wrist, sequela*/
,'S62162D'  /*Displaced fracture of pisiform, left wrist, subsequent encounter for fracture with routine healing*/
,'S62162G'  /*Displaced fracture of pisiform, left wrist, subsequent encounter for fracture with delayed healing*/
,'S62162K'  /*Displaced fracture of pisiform, left wrist, subsequent encounter for fracture with nonunion*/
,'S62162P'  /*Displaced fracture of pisiform, left wrist, subsequent encounter for fracture with malunion*/
,'S62162S'  /*Displaced fracture of pisiform, left wrist, sequela*/
,'S62163D'  /*Displaced fracture of pisiform, unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62163G'  /*Displaced fracture of pisiform, unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62163K'  /*Displaced fracture of pisiform, unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62163P'  /*Displaced fracture of pisiform, unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62163S'  /*Displaced fracture of pisiform, unspecified wrist, sequela*/
,'S62164D'  /*Nondisplaced fracture of pisiform, right wrist, subsequent encounter for fracture with routine healing*/
,'S62164G'  /*Nondisplaced fracture of pisiform, right wrist, subsequent encounter for fracture with delayed healing*/
,'S62164K'  /*Nondisplaced fracture of pisiform, right wrist, subsequent encounter for fracture with nonunion*/
,'S62164P'  /*Nondisplaced fracture of pisiform, right wrist, subsequent encounter for fracture with malunion*/
,'S62164S'  /*Nondisplaced fracture of pisiform, right wrist, sequela*/
,'S62165D'  /*Nondisplaced fracture of pisiform, left wrist, subsequent encounter for fracture with routine healing*/
,'S62165G'  /*Nondisplaced fracture of pisiform, left wrist, subsequent encounter for fracture with delayed healing*/
,'S62165K'  /*Nondisplaced fracture of pisiform, left wrist, subsequent encounter for fracture with nonunion*/
,'S62165P'  /*Nondisplaced fracture of pisiform, left wrist, subsequent encounter for fracture with malunion*/
,'S62165S'  /*Nondisplaced fracture of pisiform, left wrist, sequela*/
,'S62166D'  /*Nondisplaced fracture of pisiform, unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62166G'  /*Nondisplaced fracture of pisiform, unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62166K'  /*Nondisplaced fracture of pisiform, unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62166P'  /*Nondisplaced fracture of pisiform, unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62166S'  /*Nondisplaced fracture of pisiform, unspecified wrist, sequela*/
,'S62171D'  /*Displaced fracture of trapezium [larger multangular], right wrist, subsequent encounter for fracture with routine healing*/
,'S62171G'  /*Displaced fracture of trapezium [larger multangular], right wrist, subsequent encounter for fracture with delayed healing*/
,'S62171K'  /*Displaced fracture of trapezium [larger multangular], right wrist, subsequent encounter for fracture with nonunion*/
,'S62171P'  /*Displaced fracture of trapezium [larger multangular], right wrist, subsequent encounter for fracture with malunion*/
,'S62171S'  /*Displaced fracture of trapezium [larger multangular], right wrist, sequela*/
,'S62172D'  /*Displaced fracture of trapezium [larger multangular], left wrist, subsequent encounter for fracture with routine healing*/
,'S62172G'  /*Displaced fracture of trapezium [larger multangular], left wrist, subsequent encounter for fracture with delayed healing*/
,'S62172K'  /*Displaced fracture of trapezium [larger multangular], left wrist, subsequent encounter for fracture with nonunion*/
,'S62172P'  /*Displaced fracture of trapezium [larger multangular], left wrist, subsequent encounter for fracture with malunion*/
,'S62172S'  /*Displaced fracture of trapezium [larger multangular], left wrist, sequela*/
,'S62173D'  /*Displaced fracture of trapezium [larger multangular], unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62173G'  /*Displaced fracture of trapezium [larger multangular], unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62173K'  /*Displaced fracture of trapezium [larger multangular], unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62173P'  /*Displaced fracture of trapezium [larger multangular], unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62173S'  /*Displaced fracture of trapezium [larger multangular], unspecified wrist, sequela*/
,'S62174D'  /*Nondisplaced fracture of trapezium [larger multangular], right wrist, subsequent encounter for fracture with routine healing*/
,'S62174G'  /*Nondisplaced fracture of trapezium [larger multangular], right wrist, subsequent encounter for fracture with delayed healing*/
,'S62174K'  /*Nondisplaced fracture of trapezium [larger multangular], right wrist, subsequent encounter for fracture with nonunion*/
,'S62174P'  /*Nondisplaced fracture of trapezium [larger multangular], right wrist, subsequent encounter for fracture with malunion*/
,'S62174S'  /*Nondisplaced fracture of trapezium [larger multangular], right wrist, sequela*/
,'S62175D'  /*Nondisplaced fracture of trapezium [larger multangular], left wrist, subsequent encounter for fracture with routine healing*/
,'S62175G'  /*Nondisplaced fracture of trapezium [larger multangular], left wrist, subsequent encounter for fracture with delayed healing*/
,'S62175K'  /*Nondisplaced fracture of trapezium [larger multangular], left wrist, subsequent encounter for fracture with nonunion*/
,'S62175P'  /*Nondisplaced fracture of trapezium [larger multangular], left wrist, subsequent encounter for fracture with malunion*/
,'S62175S'  /*Nondisplaced fracture of trapezium [larger multangular], left wrist, sequela*/
,'S62176D'  /*Nondisplaced fracture of trapezium [larger multangular], unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62176G'  /*Nondisplaced fracture of trapezium [larger multangular], unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62176K'  /*Nondisplaced fracture of trapezium [larger multangular], unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62176P'  /*Nondisplaced fracture of trapezium [larger multangular], unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62176S'  /*Nondisplaced fracture of trapezium [larger multangular], unspecified wrist, sequela*/
,'S62181D'  /*Displaced fracture of trapezoid [smaller multangular], right wrist, subsequent encounter for fracture with routine healing*/
,'S62181G'  /*Displaced fracture of trapezoid [smaller multangular], right wrist, subsequent encounter for fracture with delayed healing*/
,'S62181K'  /*Displaced fracture of trapezoid [smaller multangular], right wrist, subsequent encounter for fracture with nonunion*/
,'S62181P'  /*Displaced fracture of trapezoid [smaller multangular], right wrist, subsequent encounter for fracture with malunion*/
,'S62181S'  /*Displaced fracture of trapezoid [smaller multangular], right wrist, sequela*/
,'S62182D'  /*Displaced fracture of trapezoid [smaller multangular], left wrist, subsequent encounter for fracture with routine healing*/
,'S62182G'  /*Displaced fracture of trapezoid [smaller multangular], left wrist, subsequent encounter for fracture with delayed healing*/
,'S62182K'  /*Displaced fracture of trapezoid [smaller multangular], left wrist, subsequent encounter for fracture with nonunion*/
,'S62182P'  /*Displaced fracture of trapezoid [smaller multangular], left wrist, subsequent encounter for fracture with malunion*/
,'S62182S'  /*Displaced fracture of trapezoid [smaller multangular], left wrist, sequela*/
,'S62183D'  /*Displaced fracture of trapezoid [smaller multangular], unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62183G'  /*Displaced fracture of trapezoid [smaller multangular], unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62183K'  /*Displaced fracture of trapezoid [smaller multangular], unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62183P'  /*Displaced fracture of trapezoid [smaller multangular], unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62183S'  /*Displaced fracture of trapezoid [smaller multangular], unspecified wrist, sequela*/
,'S62184D'  /*Nondisplaced fracture of trapezoid [smaller multangular], right wrist, subsequent encounter for fracture with routine healing*/
,'S62184G'  /*Nondisplaced fracture of trapezoid [smaller multangular], right wrist, subsequent encounter for fracture with delayed healing*/
,'S62184K'  /*Nondisplaced fracture of trapezoid [smaller multangular], right wrist, subsequent encounter for fracture with nonunion*/
,'S62184P'  /*Nondisplaced fracture of trapezoid [smaller multangular], right wrist, subsequent encounter for fracture with malunion*/
,'S62184S'  /*Nondisplaced fracture of trapezoid [smaller multangular], right wrist, sequela*/
,'S62185D'  /*Nondisplaced fracture of trapezoid [smaller multangular], left wrist, subsequent encounter for fracture with routine healing*/
,'S62185G'  /*Nondisplaced fracture of trapezoid [smaller multangular], left wrist, subsequent encounter for fracture with delayed healing*/
,'S62185K'  /*Nondisplaced fracture of trapezoid [smaller multangular], left wrist, subsequent encounter for fracture with nonunion*/
,'S62185P'  /*Nondisplaced fracture of trapezoid [smaller multangular], left wrist, subsequent encounter for fracture with malunion*/
,'S62185S'  /*Nondisplaced fracture of trapezoid [smaller multangular], left wrist, sequela*/
,'S62186D'  /*Nondisplaced fracture of trapezoid [smaller multangular], unspecified wrist, subsequent encounter for fracture with routine healing*/
,'S62186G'  /*Nondisplaced fracture of trapezoid [smaller multangular], unspecified wrist, subsequent encounter for fracture with delayed healing*/
,'S62186K'  /*Nondisplaced fracture of trapezoid [smaller multangular], unspecified wrist, subsequent encounter for fracture with nonunion*/
,'S62186P'  /*Nondisplaced fracture of trapezoid [smaller multangular], unspecified wrist, subsequent encounter for fracture with malunion*/
,'S62186S'  /*Nondisplaced fracture of trapezoid [smaller multangular], unspecified wrist, sequela*/
,'S62201D'  /*Unspecified fracture of first metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62201G'  /*Unspecified fracture of first metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62201K'  /*Unspecified fracture of first metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62201P'  /*Unspecified fracture of first metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62201S'  /*Unspecified fracture of first metacarpal bone, right hand, sequela*/
,'S62202D'  /*Unspecified fracture of first metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62202G'  /*Unspecified fracture of first metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62202K'  /*Unspecified fracture of first metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62202P'  /*Unspecified fracture of first metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62202S'  /*Unspecified fracture of first metacarpal bone, left hand, sequela*/
,'S62209D'  /*Unspecified fracture of first metacarpal bone, unspecified hand, subsequent encounter for fracture with routine healing*/
,'S62209G'  /*Unspecified fracture of first metacarpal bone, unspecified hand, subsequent encounter for fracture with delayed healing*/
,'S62209K'  /*Unspecified fracture of first metacarpal bone, unspecified hand, subsequent encounter for fracture with nonunion*/
,'S62209P'  /*Unspecified fracture of first metacarpal bone, unspecified hand, subsequent encounter for fracture with malunion*/
,'S62209S'  /*Unspecified fracture of first metacarpal bone, unspecified hand, sequela*/
,'S62211D'  /*Bennett's fracture, right hand, subsequent encounter for fracture with routine healing*/
,'S62211G'  /*Bennett's fracture, right hand, subsequent encounter for fracture with delayed healing*/
,'S62211K'  /*Bennett's fracture, right hand, subsequent encounter for fracture with nonunion*/
,'S62211P'  /*Bennett's fracture, right hand, subsequent encounter for fracture with malunion*/
,'S62211S'  /*Bennett's fracture, right hand, sequela*/
,'S62212D'  /*Bennett's fracture, left hand, subsequent encounter for fracture with routine healing*/
,'S62212G'  /*Bennett's fracture, left hand, subsequent encounter for fracture with delayed healing*/
,'S62212K'  /*Bennett's fracture, left hand, subsequent encounter for fracture with nonunion*/
,'S62212P'  /*Bennett's fracture, left hand, subsequent encounter for fracture with malunion*/
,'S62212S'  /*Bennett's fracture, left hand, sequela*/
,'S62213D'  /*Bennett's fracture, unspecified hand, subsequent encounter for fracture with routine healing*/
,'S62213G'  /*Bennett's fracture, unspecified hand, subsequent encounter for fracture with delayed healing*/
,'S62213K'  /*Bennett's fracture, unspecified hand, subsequent encounter for fracture with nonunion*/
,'S62213P'  /*Bennett's fracture, unspecified hand, subsequent encounter for fracture with malunion*/
,'S62213S'  /*Bennett's fracture, unspecified hand, sequela*/
,'S62221D'  /*Displaced Rolando's fracture, right hand, subsequent encounter for fracture with routine healing*/
,'S62221G'  /*Displaced Rolando's fracture, right hand, subsequent encounter for fracture with delayed healing*/
,'S62221K'  /*Displaced Rolando's fracture, right hand, subsequent encounter for fracture with nonunion*/
,'S62221P'  /*Displaced Rolando's fracture, right hand, subsequent encounter for fracture with malunion*/
,'S62221S'  /*Displaced Rolando's fracture, right hand, sequela*/
,'S62222D'  /*Displaced Rolando's fracture, left hand, subsequent encounter for fracture with routine healing*/
,'S62222G'  /*Displaced Rolando's fracture, left hand, subsequent encounter for fracture with delayed healing*/
,'S62222K'  /*Displaced Rolando's fracture, left hand, subsequent encounter for fracture with nonunion*/
,'S62222P'  /*Displaced Rolando's fracture, left hand, subsequent encounter for fracture with malunion*/
,'S62222S'  /*Displaced Rolando's fracture, left hand, sequela*/
,'S62223D'  /*Displaced Rolando's fracture, unspecified hand, subsequent encounter for fracture with routine healing*/
,'S62223G'  /*Displaced Rolando's fracture, unspecified hand, subsequent encounter for fracture with delayed healing*/
,'S62223K'  /*Displaced Rolando's fracture, unspecified hand, subsequent encounter for fracture with nonunion*/
,'S62223P'  /*Displaced Rolando's fracture, unspecified hand, subsequent encounter for fracture with malunion*/
,'S62223S'  /*Displaced Rolando's fracture, unspecified hand, sequela*/
,'S62224D'  /*Nondisplaced Rolando's fracture, right hand, subsequent encounter for fracture with routine healing*/
,'S62224G'  /*Nondisplaced Rolando's fracture, right hand, subsequent encounter for fracture with delayed healing*/
,'S62224K'  /*Nondisplaced Rolando's fracture, right hand, subsequent encounter for fracture with nonunion*/
,'S62224P'  /*Nondisplaced Rolando's fracture, right hand, subsequent encounter for fracture with malunion*/
,'S62224S'  /*Nondisplaced Rolando's fracture, right hand, sequela*/
,'S62225D'  /*Nondisplaced Rolando's fracture, left hand, subsequent encounter for fracture with routine healing*/
,'S62225G'  /*Nondisplaced Rolando's fracture, left hand, subsequent encounter for fracture with delayed healing*/
,'S62225K'  /*Nondisplaced Rolando's fracture, left hand, subsequent encounter for fracture with nonunion*/
,'S62225P'  /*Nondisplaced Rolando's fracture, left hand, subsequent encounter for fracture with malunion*/
,'S62225S'  /*Nondisplaced Rolando's fracture, left hand, sequela*/
,'S62226D'  /*Nondisplaced Rolando's fracture, unspecified hand, subsequent encounter for fracture with routine healing*/
,'S62226G'  /*Nondisplaced Rolando's fracture, unspecified hand, subsequent encounter for fracture with delayed healing*/
,'S62226K'  /*Nondisplaced Rolando's fracture, unspecified hand, subsequent encounter for fracture with nonunion*/
,'S62226P'  /*Nondisplaced Rolando's fracture, unspecified hand, subsequent encounter for fracture with malunion*/
,'S62226S'  /*Nondisplaced Rolando's fracture, unspecified hand, sequela*/
,'S62231D'  /*Other displaced fracture of base of first metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62231G'  /*Other displaced fracture of base of first metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62231K'  /*Other displaced fracture of base of first metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62231P'  /*Other displaced fracture of base of first metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62231S'  /*Other displaced fracture of base of first metacarpal bone, right hand, sequela*/
,'S62232D'  /*Other displaced fracture of base of first metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62232G'  /*Other displaced fracture of base of first metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62232K'  /*Other displaced fracture of base of first metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62232P'  /*Other displaced fracture of base of first metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62232S'  /*Other displaced fracture of base of first metacarpal bone, left hand, sequela*/
,'S62233D'  /*Other displaced fracture of base of first metacarpal bone, unspecified hand, subsequent encounter for fracture with routine healing*/
,'S62233G'  /*Other displaced fracture of base of first metacarpal bone, unspecified hand, subsequent encounter for fracture with delayed healing*/
,'S62233K'  /*Other displaced fracture of base of first metacarpal bone, unspecified hand, subsequent encounter for fracture with nonunion*/
,'S62233P'  /*Other displaced fracture of base of first metacarpal bone, unspecified hand, subsequent encounter for fracture with malunion*/
,'S62233S'  /*Other displaced fracture of base of first metacarpal bone, unspecified hand, sequela*/
,'S62234D'  /*Other nondisplaced fracture of base of first metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62234G'  /*Other nondisplaced fracture of base of first metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62234K'  /*Other nondisplaced fracture of base of first metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62234P'  /*Other nondisplaced fracture of base of first metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62234S'  /*Other nondisplaced fracture of base of first metacarpal bone, right hand, sequela*/
,'S62235D'  /*Other nondisplaced fracture of base of first metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62235G'  /*Other nondisplaced fracture of base of first metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62235K'  /*Other nondisplaced fracture of base of first metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62235P'  /*Other nondisplaced fracture of base of first metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62235S'  /*Other nondisplaced fracture of base of first metacarpal bone, left hand, sequela*/
,'S62236D'  /*Other nondisplaced fracture of base of first metacarpal bone, unspecified hand, subsequent encounter for fracture with routine healing*/
,'S62236G'  /*Other nondisplaced fracture of base of first metacarpal bone, unspecified hand, subsequent encounter for fracture with delayed healing*/
,'S62236K'  /*Other nondisplaced fracture of base of first metacarpal bone, unspecified hand, subsequent encounter for fracture with nonunion*/
,'S62236P'  /*Other nondisplaced fracture of base of first metacarpal bone, unspecified hand, subsequent encounter for fracture with malunion*/
,'S62236S'  /*Other nondisplaced fracture of base of first metacarpal bone, unspecified hand, sequela*/
,'S62241D'  /*Displaced fracture of shaft of first metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62241G'  /*Displaced fracture of shaft of first metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62241K'  /*Displaced fracture of shaft of first metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62241P'  /*Displaced fracture of shaft of first metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62241S'  /*Displaced fracture of shaft of first metacarpal bone, right hand, sequela*/
,'S62242D'  /*Displaced fracture of shaft of first metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62242G'  /*Displaced fracture of shaft of first metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62242K'  /*Displaced fracture of shaft of first metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62242P'  /*Displaced fracture of shaft of first metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62242S'  /*Displaced fracture of shaft of first metacarpal bone, left hand, sequela*/
,'S62243D'  /*Displaced fracture of shaft of first metacarpal bone, unspecified hand, subsequent encounter for fracture with routine healing*/
,'S62243G'  /*Displaced fracture of shaft of first metacarpal bone, unspecified hand, subsequent encounter for fracture with delayed healing*/
,'S62243K'  /*Displaced fracture of shaft of first metacarpal bone, unspecified hand, subsequent encounter for fracture with nonunion*/
,'S62243P'  /*Displaced fracture of shaft of first metacarpal bone, unspecified hand, subsequent encounter for fracture with malunion*/
,'S62243S'  /*Displaced fracture of shaft of first metacarpal bone, unspecified hand, sequela*/
,'S62244D'  /*Nondisplaced fracture of shaft of first metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62244G'  /*Nondisplaced fracture of shaft of first metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62244K'  /*Nondisplaced fracture of shaft of first metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62244P'  /*Nondisplaced fracture of shaft of first metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62244S'  /*Nondisplaced fracture of shaft of first metacarpal bone, right hand, sequela*/
,'S62245D'  /*Nondisplaced fracture of shaft of first metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62245G'  /*Nondisplaced fracture of shaft of first metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62245K'  /*Nondisplaced fracture of shaft of first metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62245P'  /*Nondisplaced fracture of shaft of first metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62245S'  /*Nondisplaced fracture of shaft of first metacarpal bone, left hand, sequela*/
,'S62246D'  /*Nondisplaced fracture of shaft of first metacarpal bone, unspecified hand, subsequent encounter for fracture with routine healing*/
,'S62246G'  /*Nondisplaced fracture of shaft of first metacarpal bone, unspecified hand, subsequent encounter for fracture with delayed healing*/
,'S62246K'  /*Nondisplaced fracture of shaft of first metacarpal bone, unspecified hand, subsequent encounter for fracture with nonunion*/
,'S62246P'  /*Nondisplaced fracture of shaft of first metacarpal bone, unspecified hand, subsequent encounter for fracture with malunion*/
,'S62246S'  /*Nondisplaced fracture of shaft of first metacarpal bone, unspecified hand, sequela*/
,'S62251D'  /*Displaced fracture of neck of first metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62251G'  /*Displaced fracture of neck of first metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62251K'  /*Displaced fracture of neck of first metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62251P'  /*Displaced fracture of neck of first metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62251S'  /*Displaced fracture of neck of first metacarpal bone, right hand, sequela*/
,'S62252D'  /*Displaced fracture of neck of first metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62252G'  /*Displaced fracture of neck of first metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62252K'  /*Displaced fracture of neck of first metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62252P'  /*Displaced fracture of neck of first metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62252S'  /*Displaced fracture of neck of first metacarpal bone, left hand, sequela*/
,'S62253D'  /*Displaced fracture of neck of first metacarpal bone, unspecified hand, subsequent encounter for fracture with routine healing*/
,'S62253G'  /*Displaced fracture of neck of first metacarpal bone, unspecified hand, subsequent encounter for fracture with delayed healing*/
,'S62253K'  /*Displaced fracture of neck of first metacarpal bone, unspecified hand, subsequent encounter for fracture with nonunion*/
,'S62253P'  /*Displaced fracture of neck of first metacarpal bone, unspecified hand, subsequent encounter for fracture with malunion*/
,'S62253S'  /*Displaced fracture of neck of first metacarpal bone, unspecified hand, sequela*/
,'S62254D'  /*Nondisplaced fracture of neck of first metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62254G'  /*Nondisplaced fracture of neck of first metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62254K'  /*Nondisplaced fracture of neck of first metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62254P'  /*Nondisplaced fracture of neck of first metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62254S'  /*Nondisplaced fracture of neck of first metacarpal bone, right hand, sequela*/
,'S62255D'  /*Nondisplaced fracture of neck of first metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62255G'  /*Nondisplaced fracture of neck of first metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62255K'  /*Nondisplaced fracture of neck of first metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62255P'  /*Nondisplaced fracture of neck of first metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62255S'  /*Nondisplaced fracture of neck of first metacarpal bone, left hand, sequela*/
,'S62256D'  /*Nondisplaced fracture of neck of first metacarpal bone, unspecified hand, subsequent encounter for fracture with routine healing*/
,'S62256G'  /*Nondisplaced fracture of neck of first metacarpal bone, unspecified hand, subsequent encounter for fracture with delayed healing*/
,'S62256K'  /*Nondisplaced fracture of neck of first metacarpal bone, unspecified hand, subsequent encounter for fracture with nonunion*/
,'S62256P'  /*Nondisplaced fracture of neck of first metacarpal bone, unspecified hand, subsequent encounter for fracture with malunion*/
,'S62256S'  /*Nondisplaced fracture of neck of first metacarpal bone, unspecified hand, sequela*/
,'S62291D'  /*Other fracture of first metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62291G'  /*Other fracture of first metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62291K'  /*Other fracture of first metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62291P'  /*Other fracture of first metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62291S'  /*Other fracture of first metacarpal bone, right hand, sequela*/
,'S62292D'  /*Other fracture of first metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62292G'  /*Other fracture of first metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62292K'  /*Other fracture of first metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62292P'  /*Other fracture of first metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62292S'  /*Other fracture of first metacarpal bone, left hand, sequela*/
,'S62299D'  /*Other fracture of first metacarpal bone, unspecified hand, subsequent encounter for fracture with routine healing*/
,'S62299G'  /*Other fracture of first metacarpal bone, unspecified hand, subsequent encounter for fracture with delayed healing*/
,'S62299K'  /*Other fracture of first metacarpal bone, unspecified hand, subsequent encounter for fracture with nonunion*/
,'S62299P'  /*Other fracture of first metacarpal bone, unspecified hand, subsequent encounter for fracture with malunion*/
,'S62299S'  /*Other fracture of first metacarpal bone, unspecified hand, sequela*/
,'S62300D'  /*Unspecified fracture of second metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62300G'  /*Unspecified fracture of second metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62300K'  /*Unspecified fracture of second metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62300P'  /*Unspecified fracture of second metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62300S'  /*Unspecified fracture of second metacarpal bone, right hand, sequela*/
,'S62301D'  /*Unspecified fracture of second metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62301G'  /*Unspecified fracture of second metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62301K'  /*Unspecified fracture of second metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62301P'  /*Unspecified fracture of second metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62301S'  /*Unspecified fracture of second metacarpal bone, left hand, sequela*/
,'S62302D'  /*Unspecified fracture of third metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62302G'  /*Unspecified fracture of third metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62302K'  /*Unspecified fracture of third metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62302P'  /*Unspecified fracture of third metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62302S'  /*Unspecified fracture of third metacarpal bone, right hand, sequela*/
,'S62303D'  /*Unspecified fracture of third metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62303G'  /*Unspecified fracture of third metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62303K'  /*Unspecified fracture of third metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62303P'  /*Unspecified fracture of third metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62303S'  /*Unspecified fracture of third metacarpal bone, left hand, sequela*/
,'S62304D'  /*Unspecified fracture of fourth metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62304G'  /*Unspecified fracture of fourth metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62304K'  /*Unspecified fracture of fourth metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62304P'  /*Unspecified fracture of fourth metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62304S'  /*Unspecified fracture of fourth metacarpal bone, right hand, sequela*/
,'S62305D'  /*Unspecified fracture of fourth metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62305G'  /*Unspecified fracture of fourth metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62305K'  /*Unspecified fracture of fourth metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62305P'  /*Unspecified fracture of fourth metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62305S'  /*Unspecified fracture of fourth metacarpal bone, left hand, sequela*/
,'S62306D'  /*Unspecified fracture of fifth metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62306G'  /*Unspecified fracture of fifth metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62306K'  /*Unspecified fracture of fifth metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62306P'  /*Unspecified fracture of fifth metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62306S'  /*Unspecified fracture of fifth metacarpal bone, right hand, sequela*/
,'S62307D'  /*Unspecified fracture of fifth metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62307G'  /*Unspecified fracture of fifth metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62307K'  /*Unspecified fracture of fifth metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62307P'  /*Unspecified fracture of fifth metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62307S'  /*Unspecified fracture of fifth metacarpal bone, left hand, sequela*/
,'S62308D'  /*Unspecified fracture of other metacarpal bone, subsequent encounter for fracture with routine healing*/
,'S62308G'  /*Unspecified fracture of other metacarpal bone, subsequent encounter for fracture with delayed healing*/
,'S62308K'  /*Unspecified fracture of other metacarpal bone, subsequent encounter for fracture with nonunion*/
,'S62308P'  /*Unspecified fracture of other metacarpal bone, subsequent encounter for fracture with malunion*/
,'S62308S'  /*Unspecified fracture of other metacarpal bone, sequela*/
,'S62309D'  /*Unspecified fracture of unspecified metacarpal bone, subsequent encounter for fracture with routine healing*/
,'S62309G'  /*Unspecified fracture of unspecified metacarpal bone, subsequent encounter for fracture with delayed healing*/
,'S62309K'  /*Unspecified fracture of unspecified metacarpal bone, subsequent encounter for fracture with nonunion*/
,'S62309P'  /*Unspecified fracture of unspecified metacarpal bone, subsequent encounter for fracture with malunion*/
,'S62309S'  /*Unspecified fracture of unspecified metacarpal bone, sequela*/
,'S62310D'  /*Displaced fracture of base of second metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62310G'  /*Displaced fracture of base of second metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62310K'  /*Displaced fracture of base of second metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62310P'  /*Displaced fracture of base of second metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62310S'  /*Displaced fracture of base of second metacarpal bone, right hand, sequela*/
,'S62311D'  /*Displaced fracture of base of second metacarpal bone left hand, subsequent encounter for fracture with routine healing*/
,'S62311G'  /*Displaced fracture of base of second metacarpal bone left hand, subsequent encounter for fracture with delayed healing*/
,'S62311K'  /*Displaced fracture of base of second metacarpal bone left hand, subsequent encounter for fracture with nonunion*/
,'S62311P'  /*Displaced fracture of base of second metacarpal bone left hand, subsequent encounter for fracture with malunion*/
,'S62311S'  /*Displaced fracture of base of second metacarpal bone left hand, sequela*/
,'S62312D'  /*Displaced fracture of base of third metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62312G'  /*Displaced fracture of base of third metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62312K'  /*Displaced fracture of base of third metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62312P'  /*Displaced fracture of base of third metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62312S'  /*Displaced fracture of base of third metacarpal bone, right hand, sequela*/
,'S62313D'  /*Displaced fracture of base of third metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62313G'  /*Displaced fracture of base of third metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62313K'  /*Displaced fracture of base of third metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62313P'  /*Displaced fracture of base of third metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62313S'  /*Displaced fracture of base of third metacarpal bone, left hand, sequela*/
,'S62314D'  /*Displaced fracture of base of fourth metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62314G'  /*Displaced fracture of base of fourth metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62314K'  /*Displaced fracture of base of fourth metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62314P'  /*Displaced fracture of base of fourth metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62314S'  /*Displaced fracture of base of fourth metacarpal bone, right hand, sequela*/
,'S62315D'  /*Displaced fracture of base of fourth metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62315G'  /*Displaced fracture of base of fourth metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62315K'  /*Displaced fracture of base of fourth metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62315P'  /*Displaced fracture of base of fourth metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62315S'  /*Displaced fracture of base of fourth metacarpal bone, left hand, sequela*/
,'S62316D'  /*Displaced fracture of base of fifth metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62316G'  /*Displaced fracture of base of fifth metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62316K'  /*Displaced fracture of base of fifth metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62316P'  /*Displaced fracture of base of fifth metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62316S'  /*Displaced fracture of base of fifth metacarpal bone, right hand, sequela*/
,'S62317D'  /*Displaced fracture of base of fifth metacarpal bone left hand, subsequent encounter for fracture with routine healing*/
,'S62317G'  /*Displaced fracture of base of fifth metacarpal bone left hand, subsequent encounter for fracture with delayed healing*/
,'S62317K'  /*Displaced fracture of base of fifth metacarpal bone left hand, subsequent encounter for fracture with nonunion*/
,'S62317P'  /*Displaced fracture of base of fifth metacarpal bone left hand, subsequent encounter for fracture with malunion*/
,'S62317S'  /*Displaced fracture of base of fifth metacarpal bone left hand, sequela*/
,'S62318D'  /*Displaced fracture of base of other metacarpal bone, subsequent encounter for fracture with routine healing*/
,'S62318G'  /*Displaced fracture of base of other metacarpal bone, subsequent encounter for fracture with delayed healing*/
,'S62318K'  /*Displaced fracture of base of other metacarpal bone, subsequent encounter for fracture with nonunion*/
,'S62318P'  /*Displaced fracture of base of other metacarpal bone, subsequent encounter for fracture with malunion*/
,'S62318S'  /*Displaced fracture of base of other metacarpal bone, sequela*/
,'S62319D'  /*Displaced fracture of base of unspecified metacarpal bone, subsequent encounter for fracture with routine healing*/
,'S62319G'  /*Displaced fracture of base of unspecified metacarpal bone, subsequent encounter for fracture with delayed healing*/
,'S62319K'  /*Displaced fracture of base of unspecified metacarpal bone, subsequent encounter for fracture with nonunion*/
,'S62319P'  /*Displaced fracture of base of unspecified metacarpal bone, subsequent encounter for fracture with malunion*/
,'S62319S'  /*Displaced fracture of base of unspecified metacarpal bone, sequela*/
,'S62320D'  /*Displaced fracture of shaft of second metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62320G'  /*Displaced fracture of shaft of second metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62320K'  /*Displaced fracture of shaft of second metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62320P'  /*Displaced fracture of shaft of second metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62320S'  /*Displaced fracture of shaft of second metacarpal bone, right hand, sequela*/
,'S62321D'  /*Displaced fracture of shaft of second metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62321G'  /*Displaced fracture of shaft of second metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62321K'  /*Displaced fracture of shaft of second metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62321P'  /*Displaced fracture of shaft of second metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62321S'  /*Displaced fracture of shaft of second metacarpal bone, left hand, sequela*/
,'S62322D'  /*Displaced fracture of shaft of third metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62322G'  /*Displaced fracture of shaft of third metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62322K'  /*Displaced fracture of shaft of third metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62322P'  /*Displaced fracture of shaft of third metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62322S'  /*Displaced fracture of shaft of third metacarpal bone, right hand, sequela*/
,'S62323D'  /*Displaced fracture of shaft of third metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62323G'  /*Displaced fracture of shaft of third metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62323K'  /*Displaced fracture of shaft of third metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62323P'  /*Displaced fracture of shaft of third metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62323S'  /*Displaced fracture of shaft of third metacarpal bone, left hand, sequela*/
,'S62324D'  /*Displaced fracture of shaft of fourth metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62324G'  /*Displaced fracture of shaft of fourth metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62324K'  /*Displaced fracture of shaft of fourth metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62324P'  /*Displaced fracture of shaft of fourth metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62324S'  /*Displaced fracture of shaft of fourth metacarpal bone, right hand, sequela*/
,'S62325D'  /*Displaced fracture of shaft of fourth metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62325G'  /*Displaced fracture of shaft of fourth metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62325K'  /*Displaced fracture of shaft of fourth metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62325P'  /*Displaced fracture of shaft of fourth metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62325S'  /*Displaced fracture of shaft of fourth metacarpal bone, left hand, sequela*/
,'S62326D'  /*Displaced fracture of shaft of fifth metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62326G'  /*Displaced fracture of shaft of fifth metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62326K'  /*Displaced fracture of shaft of fifth metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62326P'  /*Displaced fracture of shaft of fifth metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62326S'  /*Displaced fracture of shaft of fifth metacarpal bone, right hand, sequela*/
,'S62327D'  /*Displaced fracture of shaft of fifth metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62327G'  /*Displaced fracture of shaft of fifth metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62327K'  /*Displaced fracture of shaft of fifth metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62327P'  /*Displaced fracture of shaft of fifth metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62327S'  /*Displaced fracture of shaft of fifth metacarpal bone, left hand, sequela*/
,'S62328D'  /*Displaced fracture of shaft of other metacarpal bone, subsequent encounter for fracture with routine healing*/
,'S62328G'  /*Displaced fracture of shaft of other metacarpal bone, subsequent encounter for fracture with delayed healing*/
,'S62328K'  /*Displaced fracture of shaft of other metacarpal bone, subsequent encounter for fracture with nonunion*/
,'S62328P'  /*Displaced fracture of shaft of other metacarpal bone, subsequent encounter for fracture with malunion*/
,'S62328S'  /*Displaced fracture of shaft of other metacarpal bone, sequela*/
,'S62329D'  /*Displaced fracture of shaft of unspecified metacarpal bone, subsequent encounter for fracture with routine healing*/
,'S62329G'  /*Displaced fracture of shaft of unspecified metacarpal bone, subsequent encounter for fracture with delayed healing*/
,'S62329K'  /*Displaced fracture of shaft of unspecified metacarpal bone, subsequent encounter for fracture with nonunion*/
,'S62329P'  /*Displaced fracture of shaft of unspecified metacarpal bone, subsequent encounter for fracture with malunion*/
,'S62329S'  /*Displaced fracture of shaft of unspecified metacarpal bone, sequela*/
,'S62330D'  /*Displaced fracture of neck of second metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62330G'  /*Displaced fracture of neck of second metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62330K'  /*Displaced fracture of neck of second metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62330P'  /*Displaced fracture of neck of second metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62330S'  /*Displaced fracture of neck of second metacarpal bone, right hand, sequela*/
,'S62331D'  /*Displaced fracture of neck of second metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62331G'  /*Displaced fracture of neck of second metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62331K'  /*Displaced fracture of neck of second metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62331P'  /*Displaced fracture of neck of second metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62331S'  /*Displaced fracture of neck of second metacarpal bone, left hand, sequela*/
,'S62332D'  /*Displaced fracture of neck of third metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62332G'  /*Displaced fracture of neck of third metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62332K'  /*Displaced fracture of neck of third metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62332P'  /*Displaced fracture of neck of third metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62332S'  /*Displaced fracture of neck of third metacarpal bone, right hand, sequela*/
,'S62333D'  /*Displaced fracture of neck of third metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62333G'  /*Displaced fracture of neck of third metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62333K'  /*Displaced fracture of neck of third metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62333P'  /*Displaced fracture of neck of third metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62333S'  /*Displaced fracture of neck of third metacarpal bone, left hand, sequela*/
,'S62334D'  /*Displaced fracture of neck of fourth metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62334G'  /*Displaced fracture of neck of fourth metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62334K'  /*Displaced fracture of neck of fourth metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62334P'  /*Displaced fracture of neck of fourth metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62334S'  /*Displaced fracture of neck of fourth metacarpal bone, right hand, sequela*/
,'S62335D'  /*Displaced fracture of neck of fourth metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62335G'  /*Displaced fracture of neck of fourth metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62335K'  /*Displaced fracture of neck of fourth metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62335P'  /*Displaced fracture of neck of fourth metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62335S'  /*Displaced fracture of neck of fourth metacarpal bone, left hand, sequela*/
,'S62336D'  /*Displaced fracture of neck of fifth metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62336G'  /*Displaced fracture of neck of fifth metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62336K'  /*Displaced fracture of neck of fifth metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62336P'  /*Displaced fracture of neck of fifth metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62336S'  /*Displaced fracture of neck of fifth metacarpal bone, right hand, sequela*/
,'S62337D'  /*Displaced fracture of neck of fifth metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62337G'  /*Displaced fracture of neck of fifth metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62337K'  /*Displaced fracture of neck of fifth metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62337P'  /*Displaced fracture of neck of fifth metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62337S'  /*Displaced fracture of neck of fifth metacarpal bone, left hand, sequela*/
,'S62338D'  /*Displaced fracture of neck of other metacarpal bone, subsequent encounter for fracture with routine healing*/
,'S62338G'  /*Displaced fracture of neck of other metacarpal bone, subsequent encounter for fracture with delayed healing*/
,'S62338K'  /*Displaced fracture of neck of other metacarpal bone, subsequent encounter for fracture with nonunion*/
,'S62338P'  /*Displaced fracture of neck of other metacarpal bone, subsequent encounter for fracture with malunion*/
,'S62338S'  /*Displaced fracture of neck of other metacarpal bone, sequela*/
,'S62339D'  /*Displaced fracture of neck of unspecified metacarpal bone, subsequent encounter for fracture with routine healing*/
,'S62339G'  /*Displaced fracture of neck of unspecified metacarpal bone, subsequent encounter for fracture with delayed healing*/
,'S62339K'  /*Displaced fracture of neck of unspecified metacarpal bone, subsequent encounter for fracture with nonunion*/
,'S62339P'  /*Displaced fracture of neck of unspecified metacarpal bone, subsequent encounter for fracture with malunion*/
,'S62339S'  /*Displaced fracture of neck of unspecified metacarpal bone, sequela*/
,'S62340D'  /*Nondisplaced fracture of base of second metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62340G'  /*Nondisplaced fracture of base of second metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62340K'  /*Nondisplaced fracture of base of second metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62340P'  /*Nondisplaced fracture of base of second metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62340S'  /*Nondisplaced fracture of base of second metacarpal bone, right hand, sequela*/
,'S62341D'  /*Nondisplaced fracture of base of second metacarpal bone left hand, subsequent encounter for fracture with routine healing*/
,'S62341G'  /*Nondisplaced fracture of base of second metacarpal bone left hand, subsequent encounter for fracture with delayed healing*/
,'S62341K'  /*Nondisplaced fracture of base of second metacarpal bone left hand, subsequent encounter for fracture with nonunion*/
,'S62341P'  /*Nondisplaced fracture of base of second metacarpal bone left hand, subsequent encounter for fracture with malunion*/
,'S62341S'  /*Nondisplaced fracture of base of second metacarpal bone left hand, sequela*/
,'S62342D'  /*Nondisplaced fracture of base of third metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62342G'  /*Nondisplaced fracture of base of third metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62342K'  /*Nondisplaced fracture of base of third metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62342P'  /*Nondisplaced fracture of base of third metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62342S'  /*Nondisplaced fracture of base of third metacarpal bone, right hand, sequela*/
,'S62343D'  /*Nondisplaced fracture of base of third metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62343G'  /*Nondisplaced fracture of base of third metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62343K'  /*Nondisplaced fracture of base of third metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62343P'  /*Nondisplaced fracture of base of third metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62343S'  /*Nondisplaced fracture of base of third metacarpal bone, left hand, sequela*/
,'S62344D'  /*Nondisplaced fracture of base of fourth metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62344G'  /*Nondisplaced fracture of base of fourth metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62344K'  /*Nondisplaced fracture of base of fourth metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62344P'  /*Nondisplaced fracture of base of fourth metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62344S'  /*Nondisplaced fracture of base of fourth metacarpal bone, right hand, sequela*/
,'S62345D'  /*Nondisplaced fracture of base of fourth metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62345G'  /*Nondisplaced fracture of base of fourth metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62345K'  /*Nondisplaced fracture of base of fourth metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62345P'  /*Nondisplaced fracture of base of fourth metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62345S'  /*Nondisplaced fracture of base of fourth metacarpal bone, left hand, sequela*/
,'S62346D'  /*Nondisplaced fracture of base of fifth metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62346G'  /*Nondisplaced fracture of base of fifth metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62346K'  /*Nondisplaced fracture of base of fifth metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62346P'  /*Nondisplaced fracture of base of fifth metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62346S'  /*Nondisplaced fracture of base of fifth metacarpal bone, right hand, sequela*/
,'S62347D'  /*Nondisplaced fracture of base of fifth metacarpal bone left hand, subsequent encounter for fracture with routine healing*/
,'S62347G'  /*Nondisplaced fracture of base of fifth metacarpal bone left hand, subsequent encounter for fracture with delayed healing*/
,'S62347K'  /*Nondisplaced fracture of base of fifth metacarpal bone left hand, subsequent encounter for fracture with nonunion*/
,'S62347P'  /*Nondisplaced fracture of base of fifth metacarpal bone left hand, subsequent encounter for fracture with malunion*/
,'S62347S'  /*Nondisplaced fracture of base of fifth metacarpal bone left hand, sequela*/
,'S62348D'  /*Nondisplaced fracture of base of other metacarpal bone, subsequent encounter for fracture with routine healing*/
,'S62348G'  /*Nondisplaced fracture of base of other metacarpal bone, subsequent encounter for fracture with delayed healing*/
,'S62348K'  /*Nondisplaced fracture of base of other metacarpal bone, subsequent encounter for fracture with nonunion*/
,'S62348P'  /*Nondisplaced fracture of base of other metacarpal bone, subsequent encounter for fracture with malunion*/
,'S62348S'  /*Nondisplaced fracture of base of other metacarpal bone, sequela*/
,'S62349D'  /*Nondisplaced fracture of base of unspecified metacarpal bone, subsequent encounter for fracture with routine healing*/
,'S62349G'  /*Nondisplaced fracture of base of unspecified metacarpal bone, subsequent encounter for fracture with delayed healing*/
,'S62349K'  /*Nondisplaced fracture of base of unspecified metacarpal bone, subsequent encounter for fracture with nonunion*/
,'S62349P'  /*Nondisplaced fracture of base of unspecified metacarpal bone, subsequent encounter for fracture with malunion*/
,'S62349S'  /*Nondisplaced fracture of base of unspecified metacarpal bone, sequela*/
,'S62350D'  /*Nondisplaced fracture of shaft of second metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62350G'  /*Nondisplaced fracture of shaft of second metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62350K'  /*Nondisplaced fracture of shaft of second metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62350P'  /*Nondisplaced fracture of shaft of second metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62350S'  /*Nondisplaced fracture of shaft of second metacarpal bone, right hand, sequela*/
,'S62351D'  /*Nondisplaced fracture of shaft of second metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62351G'  /*Nondisplaced fracture of shaft of second metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62351K'  /*Nondisplaced fracture of shaft of second metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62351P'  /*Nondisplaced fracture of shaft of second metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62351S'  /*Nondisplaced fracture of shaft of second metacarpal bone, left hand, sequela*/
,'S62352D'  /*Nondisplaced fracture of shaft of third metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62352G'  /*Nondisplaced fracture of shaft of third metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62352K'  /*Nondisplaced fracture of shaft of third metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62352P'  /*Nondisplaced fracture of shaft of third metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62352S'  /*Nondisplaced fracture of shaft of third metacarpal bone, right hand, sequela*/
,'S62353D'  /*Nondisplaced fracture of shaft of third metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62353G'  /*Nondisplaced fracture of shaft of third metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62353K'  /*Nondisplaced fracture of shaft of third metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62353P'  /*Nondisplaced fracture of shaft of third metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62353S'  /*Nondisplaced fracture of shaft of third metacarpal bone, left hand, sequela*/
,'S62354D'  /*Nondisplaced fracture of shaft of fourth metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62354G'  /*Nondisplaced fracture of shaft of fourth metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62354K'  /*Nondisplaced fracture of shaft of fourth metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62354P'  /*Nondisplaced fracture of shaft of fourth metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62354S'  /*Nondisplaced fracture of shaft of fourth metacarpal bone, right hand, sequela*/
,'S62355D'  /*Nondisplaced fracture of shaft of fourth metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62355G'  /*Nondisplaced fracture of shaft of fourth metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62355K'  /*Nondisplaced fracture of shaft of fourth metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62355P'  /*Nondisplaced fracture of shaft of fourth metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62355S'  /*Nondisplaced fracture of shaft of fourth metacarpal bone, left hand, sequela*/
,'S62356D'  /*Nondisplaced fracture of shaft of fifth metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62356G'  /*Nondisplaced fracture of shaft of fifth metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62356K'  /*Nondisplaced fracture of shaft of fifth metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62356P'  /*Nondisplaced fracture of shaft of fifth metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62356S'  /*Nondisplaced fracture of shaft of fifth metacarpal bone, right hand, sequela*/
,'S62357D'  /*Nondisplaced fracture of shaft of fifth metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62357G'  /*Nondisplaced fracture of shaft of fifth metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62357K'  /*Nondisplaced fracture of shaft of fifth metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62357P'  /*Nondisplaced fracture of shaft of fifth metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62357S'  /*Nondisplaced fracture of shaft of fifth metacarpal bone, left hand, sequela*/
,'S62358D'  /*Nondisplaced fracture of shaft of other metacarpal bone, subsequent encounter for fracture with routine healing*/
,'S62358G'  /*Nondisplaced fracture of shaft of other metacarpal bone, subsequent encounter for fracture with delayed healing*/
,'S62358K'  /*Nondisplaced fracture of shaft of other metacarpal bone, subsequent encounter for fracture with nonunion*/
,'S62358P'  /*Nondisplaced fracture of shaft of other metacarpal bone, subsequent encounter for fracture with malunion*/
,'S62358S'  /*Nondisplaced fracture of shaft of other metacarpal bone, sequela*/
,'S62359D'  /*Nondisplaced fracture of shaft of unspecified metacarpal bone, subsequent encounter for fracture with routine healing*/
,'S62359G'  /*Nondisplaced fracture of shaft of unspecified metacarpal bone, subsequent encounter for fracture with delayed healing*/
,'S62359K'  /*Nondisplaced fracture of shaft of unspecified metacarpal bone, subsequent encounter for fracture with nonunion*/
,'S62359P'  /*Nondisplaced fracture of shaft of unspecified metacarpal bone, subsequent encounter for fracture with malunion*/
,'S62359S'  /*Nondisplaced fracture of shaft of unspecified metacarpal bone, sequela*/
,'S62360D'  /*Nondisplaced fracture of neck of second metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62360G'  /*Nondisplaced fracture of neck of second metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62360K'  /*Nondisplaced fracture of neck of second metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62360P'  /*Nondisplaced fracture of neck of second metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62360S'  /*Nondisplaced fracture of neck of second metacarpal bone, right hand, sequela*/
,'S62361D'  /*Nondisplaced fracture of neck of second metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62361G'  /*Nondisplaced fracture of neck of second metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62361K'  /*Nondisplaced fracture of neck of second metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62361P'  /*Nondisplaced fracture of neck of second metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62361S'  /*Nondisplaced fracture of neck of second metacarpal bone, left hand, sequela*/
,'S62362D'  /*Nondisplaced fracture of neck of third metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62362G'  /*Nondisplaced fracture of neck of third metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62362K'  /*Nondisplaced fracture of neck of third metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62362P'  /*Nondisplaced fracture of neck of third metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62362S'  /*Nondisplaced fracture of neck of third metacarpal bone, right hand, sequela*/
,'S62363D'  /*Nondisplaced fracture of neck of third metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62363G'  /*Nondisplaced fracture of neck of third metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62363K'  /*Nondisplaced fracture of neck of third metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62363P'  /*Nondisplaced fracture of neck of third metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62363S'  /*Nondisplaced fracture of neck of third metacarpal bone, left hand, sequela*/
,'S62364D'  /*Nondisplaced fracture of neck of fourth metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62364G'  /*Nondisplaced fracture of neck of fourth metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62364K'  /*Nondisplaced fracture of neck of fourth metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62364P'  /*Nondisplaced fracture of neck of fourth metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62364S'  /*Nondisplaced fracture of neck of fourth metacarpal bone, right hand, sequela*/
,'S62365D'  /*Nondisplaced fracture of neck of fourth metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62365G'  /*Nondisplaced fracture of neck of fourth metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62365K'  /*Nondisplaced fracture of neck of fourth metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62365P'  /*Nondisplaced fracture of neck of fourth metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62365S'  /*Nondisplaced fracture of neck of fourth metacarpal bone, left hand, sequela*/
,'S62366D'  /*Nondisplaced fracture of neck of fifth metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62366G'  /*Nondisplaced fracture of neck of fifth metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62366K'  /*Nondisplaced fracture of neck of fifth metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62366P'  /*Nondisplaced fracture of neck of fifth metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62366S'  /*Nondisplaced fracture of neck of fifth metacarpal bone, right hand, sequela*/
,'S62367D'  /*Nondisplaced fracture of neck of fifth metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62367G'  /*Nondisplaced fracture of neck of fifth metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62367K'  /*Nondisplaced fracture of neck of fifth metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62367P'  /*Nondisplaced fracture of neck of fifth metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62367S'  /*Nondisplaced fracture of neck of fifth metacarpal bone, left hand, sequela*/
,'S62368D'  /*Nondisplaced fracture of neck of other metacarpal bone, subsequent encounter for fracture with routine healing*/
,'S62368G'  /*Nondisplaced fracture of neck of other metacarpal bone, subsequent encounter for fracture with delayed healing*/
,'S62368K'  /*Nondisplaced fracture of neck of other metacarpal bone, subsequent encounter for fracture with nonunion*/
,'S62368P'  /*Nondisplaced fracture of neck of other metacarpal bone, subsequent encounter for fracture with malunion*/
,'S62368S'  /*Nondisplaced fracture of neck of other metacarpal bone, sequela*/
,'S62369D'  /*Nondisplaced fracture of neck of unspecified metacarpal bone, subsequent encounter for fracture with routine healing*/
,'S62369G'  /*Nondisplaced fracture of neck of unspecified metacarpal bone, subsequent encounter for fracture with delayed healing*/
,'S62369K'  /*Nondisplaced fracture of neck of unspecified metacarpal bone, subsequent encounter for fracture with nonunion*/
,'S62369P'  /*Nondisplaced fracture of neck of unspecified metacarpal bone, subsequent encounter for fracture with malunion*/
,'S62369S'  /*Nondisplaced fracture of neck of unspecified metacarpal bone, sequela*/
,'S62390D'  /*Other fracture of second metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62390G'  /*Other fracture of second metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62390K'  /*Other fracture of second metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62390P'  /*Other fracture of second metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62390S'  /*Other fracture of second metacarpal bone, right hand, sequela*/
,'S62391D'  /*Other fracture of second metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62391G'  /*Other fracture of second metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62391K'  /*Other fracture of second metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62391P'  /*Other fracture of second metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62391S'  /*Other fracture of second metacarpal bone, left hand, sequela*/
,'S62392D'  /*Other fracture of third metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62392G'  /*Other fracture of third metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62392K'  /*Other fracture of third metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62392P'  /*Other fracture of third metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62392S'  /*Other fracture of third metacarpal bone, right hand, sequela*/
,'S62393D'  /*Other fracture of third metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62393G'  /*Other fracture of third metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62393K'  /*Other fracture of third metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62393P'  /*Other fracture of third metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62393S'  /*Other fracture of third metacarpal bone, left hand, sequela*/
,'S62394D'  /*Other fracture of fourth metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62394G'  /*Other fracture of fourth metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62394K'  /*Other fracture of fourth metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62394P'  /*Other fracture of fourth metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62394S'  /*Other fracture of fourth metacarpal bone, right hand, sequela*/
,'S62395D'  /*Other fracture of fourth metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62395G'  /*Other fracture of fourth metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62395K'  /*Other fracture of fourth metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62395P'  /*Other fracture of fourth metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62395S'  /*Other fracture of fourth metacarpal bone, left hand, sequela*/
,'S62396D'  /*Other fracture of fifth metacarpal bone, right hand, subsequent encounter for fracture with routine healing*/
,'S62396G'  /*Other fracture of fifth metacarpal bone, right hand, subsequent encounter for fracture with delayed healing*/
,'S62396K'  /*Other fracture of fifth metacarpal bone, right hand, subsequent encounter for fracture with nonunion*/
,'S62396P'  /*Other fracture of fifth metacarpal bone, right hand, subsequent encounter for fracture with malunion*/
,'S62396S'  /*Other fracture of fifth metacarpal bone, right hand, sequela*/
,'S62397D'  /*Other fracture of fifth metacarpal bone, left hand, subsequent encounter for fracture with routine healing*/
,'S62397G'  /*Other fracture of fifth metacarpal bone, left hand, subsequent encounter for fracture with delayed healing*/
,'S62397K'  /*Other fracture of fifth metacarpal bone, left hand, subsequent encounter for fracture with nonunion*/
,'S62397P'  /*Other fracture of fifth metacarpal bone, left hand, subsequent encounter for fracture with malunion*/
,'S62397S'  /*Other fracture of fifth metacarpal bone, left hand, sequela*/
,'S62398D'  /*Other fracture of other metacarpal bone, subsequent encounter for fracture with routine healing*/
,'S62398G'  /*Other fracture of other metacarpal bone, subsequent encounter for fracture with delayed healing*/
,'S62398K'  /*Other fracture of other metacarpal bone, subsequent encounter for fracture with nonunion*/
,'S62398P'  /*Other fracture of other metacarpal bone, subsequent encounter for fracture with malunion*/
,'S62398S'  /*Other fracture of other metacarpal bone, sequela*/
,'S62399D'  /*Other fracture of unspecified metacarpal bone, subsequent encounter for fracture with routine healing*/
,'S62399G'  /*Other fracture of unspecified metacarpal bone, subsequent encounter for fracture with delayed healing*/
,'S62399K'  /*Other fracture of unspecified metacarpal bone, subsequent encounter for fracture with nonunion*/
,'S62399P'  /*Other fracture of unspecified metacarpal bone, subsequent encounter for fracture with malunion*/
,'S62399S'  /*Other fracture of unspecified metacarpal bone, sequela*/
,'S62501D'  /*Fracture of unspecified phalanx of right thumb, subsequent encounter for fracture with routine healing*/
,'S62501G'  /*Fracture of unspecified phalanx of right thumb, subsequent encounter for fracture with delayed healing*/
,'S62501K'  /*Fracture of unspecified phalanx of right thumb, subsequent encounter for fracture with nonunion*/
,'S62501P'  /*Fracture of unspecified phalanx of right thumb, subsequent encounter for fracture with malunion*/
,'S62501S'  /*Fracture of unspecified phalanx of right thumb, sequela*/
,'S62502D'  /*Fracture of unspecified phalanx of left thumb, subsequent encounter for fracture with routine healing*/
,'S62502G'  /*Fracture of unspecified phalanx of left thumb, subsequent encounter for fracture with delayed healing*/
,'S62502K'  /*Fracture of unspecified phalanx of left thumb, subsequent encounter for fracture with nonunion*/
,'S62502P'  /*Fracture of unspecified phalanx of left thumb, subsequent encounter for fracture with malunion*/
,'S62502S'  /*Fracture of unspecified phalanx of left thumb, sequela*/
,'S62509D'  /*Fracture of unspecified phalanx of unspecified thumb, subsequent encounter for fracture with routine healing*/
,'S62509G'  /*Fracture of unspecified phalanx of unspecified thumb, subsequent encounter for fracture with delayed healing*/
,'S62509K'  /*Fracture of unspecified phalanx of unspecified thumb, subsequent encounter for fracture with nonunion*/
,'S62509P'  /*Fracture of unspecified phalanx of unspecified thumb, subsequent encounter for fracture with malunion*/
,'S62509S'  /*Fracture of unspecified phalanx of unspecified thumb, sequela*/
,'S62511D'  /*Displaced fracture of proximal phalanx of right thumb, subsequent encounter for fracture with routine healing*/
,'S62511G'  /*Displaced fracture of proximal phalanx of right thumb, subsequent encounter for fracture with delayed healing*/
,'S62511K'  /*Displaced fracture of proximal phalanx of right thumb, subsequent encounter for fracture with nonunion*/
,'S62511P'  /*Displaced fracture of proximal phalanx of right thumb, subsequent encounter for fracture with malunion*/
,'S62511S'  /*Displaced fracture of proximal phalanx of right thumb, sequela*/
,'S62512D'  /*Displaced fracture of proximal phalanx of left thumb, subsequent encounter for fracture with routine healing*/
,'S62512G'  /*Displaced fracture of proximal phalanx of left thumb, subsequent encounter for fracture with delayed healing*/
,'S62512K'  /*Displaced fracture of proximal phalanx of left thumb, subsequent encounter for fracture with nonunion*/
,'S62512P'  /*Displaced fracture of proximal phalanx of left thumb, subsequent encounter for fracture with malunion*/
,'S62512S'  /*Displaced fracture of proximal phalanx of left thumb, sequela*/
,'S62513D'  /*Displaced fracture of proximal phalanx of unspecified thumb, subsequent encounter for fracture with routine healing*/
,'S62513G'  /*Displaced fracture of proximal phalanx of unspecified thumb, subsequent encounter for fracture with delayed healing*/
,'S62513K'  /*Displaced fracture of proximal phalanx of unspecified thumb, subsequent encounter for fracture with nonunion*/
,'S62513P'  /*Displaced fracture of proximal phalanx of unspecified thumb, subsequent encounter for fracture with malunion*/
,'S62513S'  /*Displaced fracture of proximal phalanx of unspecified thumb, sequela*/
,'S62514D'  /*Nondisplaced fracture of proximal phalanx of right thumb, subsequent encounter for fracture with routine healing*/
,'S62514G'  /*Nondisplaced fracture of proximal phalanx of right thumb, subsequent encounter for fracture with delayed healing*/
,'S62514K'  /*Nondisplaced fracture of proximal phalanx of right thumb, subsequent encounter for fracture with nonunion*/
,'S62514P'  /*Nondisplaced fracture of proximal phalanx of right thumb, subsequent encounter for fracture with malunion*/
,'S62514S'  /*Nondisplaced fracture of proximal phalanx of right thumb, sequela*/
,'S62515D'  /*Nondisplaced fracture of proximal phalanx of left thumb, subsequent encounter for fracture with routine healing*/
,'S62515G'  /*Nondisplaced fracture of proximal phalanx of left thumb, subsequent encounter for fracture with delayed healing*/
,'S62515K'  /*Nondisplaced fracture of proximal phalanx of left thumb, subsequent encounter for fracture with nonunion*/
,'S62515P'  /*Nondisplaced fracture of proximal phalanx of left thumb, subsequent encounter for fracture with malunion*/
,'S62515S'  /*Nondisplaced fracture of proximal phalanx of left thumb, sequela*/
,'S62516D'  /*Nondisplaced fracture of proximal phalanx of unspecified thumb, subsequent encounter for fracture with routine healing*/
,'S62516G'  /*Nondisplaced fracture of proximal phalanx of unspecified thumb, subsequent encounter for fracture with delayed healing*/
,'S62516K'  /*Nondisplaced fracture of proximal phalanx of unspecified thumb, subsequent encounter for fracture with nonunion*/
,'S62516P'  /*Nondisplaced fracture of proximal phalanx of unspecified thumb, subsequent encounter for fracture with malunion*/
,'S62516S'  /*Nondisplaced fracture of proximal phalanx of unspecified thumb, sequela*/
,'S62521D'  /*Displaced fracture of distal phalanx of right thumb, subsequent encounter for fracture with routine healing*/
,'S62521G'  /*Displaced fracture of distal phalanx of right thumb, subsequent encounter for fracture with delayed healing*/
,'S62521K'  /*Displaced fracture of distal phalanx of right thumb, subsequent encounter for fracture with nonunion*/
,'S62521P'  /*Displaced fracture of distal phalanx of right thumb, subsequent encounter for fracture with malunion*/
,'S62521S'  /*Displaced fracture of distal phalanx of right thumb, sequela*/
,'S62522D'  /*Displaced fracture of distal phalanx of left thumb, subsequent encounter for fracture with routine healing*/
,'S62522G'  /*Displaced fracture of distal phalanx of left thumb, subsequent encounter for fracture with delayed healing*/
,'S62522K'  /*Displaced fracture of distal phalanx of left thumb, subsequent encounter for fracture with nonunion*/
,'S62522P'  /*Displaced fracture of distal phalanx of left thumb, subsequent encounter for fracture with malunion*/
,'S62522S'  /*Displaced fracture of distal phalanx of left thumb, sequela*/
,'S62523D'  /*Displaced fracture of distal phalanx of unspecified thumb, subsequent encounter for fracture with routine healing*/
,'S62523G'  /*Displaced fracture of distal phalanx of unspecified thumb, subsequent encounter for fracture with delayed healing*/
,'S62523K'  /*Displaced fracture of distal phalanx of unspecified thumb, subsequent encounter for fracture with nonunion*/
,'S62523P'  /*Displaced fracture of distal phalanx of unspecified thumb, subsequent encounter for fracture with malunion*/
,'S62523S'  /*Displaced fracture of distal phalanx of unspecified thumb, sequela*/
,'S62524D'  /*Nondisplaced fracture of distal phalanx of right thumb, subsequent encounter for fracture with routine healing*/
,'S62524G'  /*Nondisplaced fracture of distal phalanx of right thumb, subsequent encounter for fracture with delayed healing*/
,'S62524K'  /*Nondisplaced fracture of distal phalanx of right thumb, subsequent encounter for fracture with nonunion*/
,'S62524P'  /*Nondisplaced fracture of distal phalanx of right thumb, subsequent encounter for fracture with malunion*/
,'S62524S'  /*Nondisplaced fracture of distal phalanx of right thumb, sequela*/
,'S62525D'  /*Nondisplaced fracture of distal phalanx of left thumb, subsequent encounter for fracture with routine healing*/
,'S62525G'  /*Nondisplaced fracture of distal phalanx of left thumb, subsequent encounter for fracture with delayed healing*/
,'S62525K'  /*Nondisplaced fracture of distal phalanx of left thumb, subsequent encounter for fracture with nonunion*/
,'S62525P'  /*Nondisplaced fracture of distal phalanx of left thumb, subsequent encounter for fracture with malunion*/
,'S62525S'  /*Nondisplaced fracture of distal phalanx of left thumb, sequela*/
,'S62526D'  /*Nondisplaced fracture of distal phalanx of unspecified thumb, subsequent encounter for fracture with routine healing*/
,'S62526G'  /*Nondisplaced fracture of distal phalanx of unspecified thumb, subsequent encounter for fracture with delayed healing*/
,'S62526K'  /*Nondisplaced fracture of distal phalanx of unspecified thumb, subsequent encounter for fracture with nonunion*/
,'S62526P'  /*Nondisplaced fracture of distal phalanx of unspecified thumb, subsequent encounter for fracture with malunion*/
,'S62526S'  /*Nondisplaced fracture of distal phalanx of unspecified thumb, sequela*/
,'S62600D'  /*Fracture of unspecified phalanx of right index finger, subsequent encounter for fracture with routine healing*/
,'S62600G'  /*Fracture of unspecified phalanx of right index finger, subsequent encounter for fracture with delayed healing*/
,'S62600K'  /*Fracture of unspecified phalanx of right index finger, subsequent encounter for fracture with nonunion*/
,'S62600P'  /*Fracture of unspecified phalanx of right index finger, subsequent encounter for fracture with malunion*/
,'S62600S'  /*Fracture of unspecified phalanx of right index finger, sequela*/
,'S62601D'  /*Fracture of unspecified phalanx of left index finger, subsequent encounter for fracture with routine healing*/
,'S62601G'  /*Fracture of unspecified phalanx of left index finger, subsequent encounter for fracture with delayed healing*/
,'S62601K'  /*Fracture of unspecified phalanx of left index finger, subsequent encounter for fracture with nonunion*/
,'S62601P'  /*Fracture of unspecified phalanx of left index finger, subsequent encounter for fracture with malunion*/
,'S62601S'  /*Fracture of unspecified phalanx of left index finger, sequela*/
,'S62602D'  /*Fracture of unspecified phalanx of right middle finger, subsequent encounter for fracture with routine healing*/
,'S62602G'  /*Fracture of unspecified phalanx of right middle finger, subsequent encounter for fracture with delayed healing*/
,'S62602K'  /*Fracture of unspecified phalanx of right middle finger, subsequent encounter for fracture with nonunion*/
,'S62602P'  /*Fracture of unspecified phalanx of right middle finger, subsequent encounter for fracture with malunion*/
,'S62602S'  /*Fracture of unspecified phalanx of right middle finger, sequela*/
,'S62603D'  /*Fracture of unspecified phalanx of left middle finger, subsequent encounter for fracture with routine healing*/
,'S62603G'  /*Fracture of unspecified phalanx of left middle finger, subsequent encounter for fracture with delayed healing*/
,'S62603K'  /*Fracture of unspecified phalanx of left middle finger, subsequent encounter for fracture with nonunion*/
,'S62603P'  /*Fracture of unspecified phalanx of left middle finger, subsequent encounter for fracture with malunion*/
,'S62603S'  /*Fracture of unspecified phalanx of left middle finger, sequela*/
,'S62604D'  /*Fracture of unspecified phalanx of right ring finger, subsequent encounter for fracture with routine healing*/
,'S62604G'  /*Fracture of unspecified phalanx of right ring finger, subsequent encounter for fracture with delayed healing*/
,'S62604K'  /*Fracture of unspecified phalanx of right ring finger, subsequent encounter for fracture with nonunion*/
,'S62604P'  /*Fracture of unspecified phalanx of right ring finger, subsequent encounter for fracture with malunion*/
,'S62604S'  /*Fracture of unspecified phalanx of right ring finger, sequela*/
,'S62605D'  /*Fracture of unspecified phalanx of left ring finger, subsequent encounter for fracture with routine healing*/
,'S62605G'  /*Fracture of unspecified phalanx of left ring finger, subsequent encounter for fracture with delayed healing*/
,'S62605K'  /*Fracture of unspecified phalanx of left ring finger, subsequent encounter for fracture with nonunion*/
,'S62605P'  /*Fracture of unspecified phalanx of left ring finger, subsequent encounter for fracture with malunion*/
,'S62605S'  /*Fracture of unspecified phalanx of left ring finger, sequela*/
,'S62606D'  /*Fracture of unspecified phalanx of right little finger, subsequent encounter for fracture with routine healing*/
,'S62606G'  /*Fracture of unspecified phalanx of right little finger, subsequent encounter for fracture with delayed healing*/
,'S62606K'  /*Fracture of unspecified phalanx of right little finger, subsequent encounter for fracture with nonunion*/
,'S62606P'  /*Fracture of unspecified phalanx of right little finger, subsequent encounter for fracture with malunion*/
,'S62606S'  /*Fracture of unspecified phalanx of right little finger, sequela*/
,'S62607D'  /*Fracture of unspecified phalanx of left little finger, subsequent encounter for fracture with routine healing*/
,'S62607G'  /*Fracture of unspecified phalanx of left little finger, subsequent encounter for fracture with delayed healing*/
,'S62607K'  /*Fracture of unspecified phalanx of left little finger, subsequent encounter for fracture with nonunion*/
,'S62607P'  /*Fracture of unspecified phalanx of left little finger, subsequent encounter for fracture with malunion*/
,'S62607S'  /*Fracture of unspecified phalanx of left little finger, sequela*/
,'S62608D'  /*Fracture of unspecified phalanx of other finger, subsequent encounter for fracture with routine healing*/
,'S62608G'  /*Fracture of unspecified phalanx of other finger, subsequent encounter for fracture with delayed healing*/
,'S62608K'  /*Fracture of unspecified phalanx of other finger, subsequent encounter for fracture with nonunion*/
,'S62608P'  /*Fracture of unspecified phalanx of other finger, subsequent encounter for fracture with malunion*/
,'S62608S'  /*Fracture of unspecified phalanx of other finger, sequela*/
,'S62609D'  /*Fracture of unspecified phalanx of unspecified finger, subsequent encounter for fracture with routine healing*/
,'S62609G'  /*Fracture of unspecified phalanx of unspecified finger, subsequent encounter for fracture with delayed healing*/
,'S62609K'  /*Fracture of unspecified phalanx of unspecified finger, subsequent encounter for fracture with nonunion*/
,'S62609P'  /*Fracture of unspecified phalanx of unspecified finger, subsequent encounter for fracture with malunion*/
,'S62609S'  /*Fracture of unspecified phalanx of unspecified finger, sequela*/
,'S62610D'  /*Displaced fracture of proximal phalanx of right index finger, subsequent encounter for fracture with routine healing*/
,'S62610G'  /*Displaced fracture of proximal phalanx of right index finger, subsequent encounter for fracture with delayed healing*/
,'S62610K'  /*Displaced fracture of proximal phalanx of right index finger, subsequent encounter for fracture with nonunion*/
,'S62610P'  /*Displaced fracture of proximal phalanx of right index finger, subsequent encounter for fracture with malunion*/
,'S62610S'  /*Displaced fracture of proximal phalanx of right index finger, sequela*/
,'S62611D'  /*Displaced fracture of proximal phalanx of left index finger, subsequent encounter for fracture with routine healing*/
,'S62611G'  /*Displaced fracture of proximal phalanx of left index finger, subsequent encounter for fracture with delayed healing*/
,'S62611K'  /*Displaced fracture of proximal phalanx of left index finger, subsequent encounter for fracture with nonunion*/
,'S62611P'  /*Displaced fracture of proximal phalanx of left index finger, subsequent encounter for fracture with malunion*/
,'S62611S'  /*Displaced fracture of proximal phalanx of left index finger, sequela*/
,'S62612D'  /*Displaced fracture of proximal phalanx of right middle finger, subsequent encounter for fracture with routine healing*/
,'S62612G'  /*Displaced fracture of proximal phalanx of right middle finger, subsequent encounter for fracture with delayed healing*/
,'S62612K'  /*Displaced fracture of proximal phalanx of right middle finger, subsequent encounter for fracture with nonunion*/
,'S62612P'  /*Displaced fracture of proximal phalanx of right middle finger, subsequent encounter for fracture with malunion*/
,'S62612S'  /*Displaced fracture of proximal phalanx of right middle finger, sequela*/
,'S62613D'  /*Displaced fracture of proximal phalanx of left middle finger, subsequent encounter for fracture with routine healing*/
,'S62613G'  /*Displaced fracture of proximal phalanx of left middle finger, subsequent encounter for fracture with delayed healing*/
,'S62613K'  /*Displaced fracture of proximal phalanx of left middle finger, subsequent encounter for fracture with nonunion*/
,'S62613P'  /*Displaced fracture of proximal phalanx of left middle finger, subsequent encounter for fracture with malunion*/
,'S62613S'  /*Displaced fracture of proximal phalanx of left middle finger, sequela*/
,'S62614D'  /*Displaced fracture of proximal phalanx of right ring finger, subsequent encounter for fracture with routine healing*/
,'S62614G'  /*Displaced fracture of proximal phalanx of right ring finger, subsequent encounter for fracture with delayed healing*/
,'S62614K'  /*Displaced fracture of proximal phalanx of right ring finger, subsequent encounter for fracture with nonunion*/
,'S62614P'  /*Displaced fracture of proximal phalanx of right ring finger, subsequent encounter for fracture with malunion*/
,'S62614S'  /*Displaced fracture of proximal phalanx of right ring finger, sequela*/
,'S62615D'  /*Displaced fracture of proximal phalanx of left ring finger, subsequent encounter for fracture with routine healing*/
,'S62615G'  /*Displaced fracture of proximal phalanx of left ring finger, subsequent encounter for fracture with delayed healing*/
,'S62615K'  /*Displaced fracture of proximal phalanx of left ring finger, subsequent encounter for fracture with nonunion*/
,'S62615P'  /*Displaced fracture of proximal phalanx of left ring finger, subsequent encounter for fracture with malunion*/
,'S62615S'  /*Displaced fracture of proximal phalanx of left ring finger, sequela*/
,'S62616D'  /*Displaced fracture of proximal phalanx of right little finger, subsequent encounter for fracture with routine healing*/
,'S62616G'  /*Displaced fracture of proximal phalanx of right little finger, subsequent encounter for fracture with delayed healing*/
,'S62616K'  /*Displaced fracture of proximal phalanx of right little finger, subsequent encounter for fracture with nonunion*/
,'S62616P'  /*Displaced fracture of proximal phalanx of right little finger, subsequent encounter for fracture with malunion*/
,'S62616S'  /*Displaced fracture of proximal phalanx of right little finger, sequela*/
,'S62617D'  /*Displaced fracture of proximal phalanx of left little finger, subsequent encounter for fracture with routine healing*/
,'S62617G'  /*Displaced fracture of proximal phalanx of left little finger, subsequent encounter for fracture with delayed healing*/
,'S62617K'  /*Displaced fracture of proximal phalanx of left little finger, subsequent encounter for fracture with nonunion*/
,'S62617P'  /*Displaced fracture of proximal phalanx of left little finger, subsequent encounter for fracture with malunion*/
,'S62617S'  /*Displaced fracture of proximal phalanx of left little finger, sequela*/
,'S62618D'  /*Displaced fracture of proximal phalanx of other finger, subsequent encounter for fracture with routine healing*/
,'S62618G'  /*Displaced fracture of proximal phalanx of other finger, subsequent encounter for fracture with delayed healing*/
,'S62618K'  /*Displaced fracture of proximal phalanx of other finger, subsequent encounter for fracture with nonunion*/
,'S62618P'  /*Displaced fracture of proximal phalanx of other finger, subsequent encounter for fracture with malunion*/
,'S62618S'  /*Displaced fracture of proximal phalanx of other finger, sequela*/
,'S62619D'  /*Displaced fracture of proximal phalanx of unspecified finger, subsequent encounter for fracture with routine healing*/
,'S62619G'  /*Displaced fracture of proximal phalanx of unspecified finger, subsequent encounter for fracture with delayed healing*/
,'S62619K'  /*Displaced fracture of proximal phalanx of unspecified finger, subsequent encounter for fracture with nonunion*/
,'S62619P'  /*Displaced fracture of proximal phalanx of unspecified finger, subsequent encounter for fracture with malunion*/
,'S62619S'  /*Displaced fracture of proximal phalanx of unspecified finger, sequela*/
,'S62620D'  /*Displaced fracture of medial phalanx of right index finger, subsequent encounter for fracture with routine healing*/
,'S62620G'  /*Displaced fracture of medial phalanx of right index finger, subsequent encounter for fracture with delayed healing*/
,'S62620K'  /*Displaced fracture of medial phalanx of right index finger, subsequent encounter for fracture with nonunion*/
,'S62620P'  /*Displaced fracture of medial phalanx of right index finger, subsequent encounter for fracture with malunion*/
,'S62620S'  /*Displaced fracture of medial phalanx of right index finger, sequela*/
,'S62621D'  /*Displaced fracture of medial phalanx of left index finger, subsequent encounter for fracture with routine healing*/
,'S62621G'  /*Displaced fracture of medial phalanx of left index finger, subsequent encounter for fracture with delayed healing*/
,'S62621K'  /*Displaced fracture of medial phalanx of left index finger, subsequent encounter for fracture with nonunion*/
,'S62621P'  /*Displaced fracture of medial phalanx of left index finger, subsequent encounter for fracture with malunion*/
,'S62621S'  /*Displaced fracture of medial phalanx of left index finger, sequela*/
,'S62622D'  /*Displaced fracture of medial phalanx of right middle finger, subsequent encounter for fracture with routine healing*/
,'S62622G'  /*Displaced fracture of medial phalanx of right middle finger, subsequent encounter for fracture with delayed healing*/
,'S62622K'  /*Displaced fracture of medial phalanx of right middle finger, subsequent encounter for fracture with nonunion*/
,'S62622P'  /*Displaced fracture of medial phalanx of right middle finger, subsequent encounter for fracture with malunion*/
,'S62622S'  /*Displaced fracture of medial phalanx of right middle finger, sequela*/
,'S62623D'  /*Displaced fracture of medial phalanx of left middle finger, subsequent encounter for fracture with routine healing*/
,'S62623G'  /*Displaced fracture of medial phalanx of left middle finger, subsequent encounter for fracture with delayed healing*/
,'S62623K'  /*Displaced fracture of medial phalanx of left middle finger, subsequent encounter for fracture with nonunion*/
,'S62623P'  /*Displaced fracture of medial phalanx of left middle finger, subsequent encounter for fracture with malunion*/
,'S62623S'  /*Displaced fracture of medial phalanx of left middle finger, sequela*/
,'S62624D'  /*Displaced fracture of medial phalanx of right ring finger, subsequent encounter for fracture with routine healing*/
,'S62624G'  /*Displaced fracture of medial phalanx of right ring finger, subsequent encounter for fracture with delayed healing*/
,'S62624K'  /*Displaced fracture of medial phalanx of right ring finger, subsequent encounter for fracture with nonunion*/
,'S62624P'  /*Displaced fracture of medial phalanx of right ring finger, subsequent encounter for fracture with malunion*/
,'S62624S'  /*Displaced fracture of medial phalanx of right ring finger, sequela*/
,'S62625D'  /*Displaced fracture of medial phalanx of left ring finger, subsequent encounter for fracture with routine healing*/
,'S62625G'  /*Displaced fracture of medial phalanx of left ring finger, subsequent encounter for fracture with delayed healing*/
,'S62625K'  /*Displaced fracture of medial phalanx of left ring finger, subsequent encounter for fracture with nonunion*/
,'S62625P'  /*Displaced fracture of medial phalanx of left ring finger, subsequent encounter for fracture with malunion*/
,'S62625S'  /*Displaced fracture of medial phalanx of left ring finger, sequela*/
,'S62626D'  /*Displaced fracture of medial phalanx of right little finger, subsequent encounter for fracture with routine healing*/
,'S62626G'  /*Displaced fracture of medial phalanx of right little finger, subsequent encounter for fracture with delayed healing*/
,'S62626K'  /*Displaced fracture of medial phalanx of right little finger, subsequent encounter for fracture with nonunion*/
,'S62626P'  /*Displaced fracture of medial phalanx of right little finger, subsequent encounter for fracture with malunion*/
,'S62626S'  /*Displaced fracture of medial phalanx of right little finger, sequela*/
,'S62627D'  /*Displaced fracture of medial phalanx of left little finger, subsequent encounter for fracture with routine healing*/
,'S62627G'  /*Displaced fracture of medial phalanx of left little finger, subsequent encounter for fracture with delayed healing*/
,'S62627K'  /*Displaced fracture of medial phalanx of left little finger, subsequent encounter for fracture with nonunion*/
,'S62627P'  /*Displaced fracture of medial phalanx of left little finger, subsequent encounter for fracture with malunion*/
,'S62627S'  /*Displaced fracture of medial phalanx of left little finger, sequela*/
,'S62628D'  /*Displaced fracture of medial phalanx of other finger, subsequent encounter for fracture with routine healing*/
,'S62628G'  /*Displaced fracture of medial phalanx of other finger, subsequent encounter for fracture with delayed healing*/
,'S62628K'  /*Displaced fracture of medial phalanx of other finger, subsequent encounter for fracture with nonunion*/
,'S62628P'  /*Displaced fracture of medial phalanx of other finger, subsequent encounter for fracture with malunion*/
,'S62628S'  /*Displaced fracture of medial phalanx of other finger, sequela*/
,'S62629D'  /*Displaced fracture of medial phalanx of unspecified finger, subsequent encounter for fracture with routine healing*/
,'S62629G'  /*Displaced fracture of medial phalanx of unspecified finger, subsequent encounter for fracture with delayed healing*/
,'S62629K'  /*Displaced fracture of medial phalanx of unspecified finger, subsequent encounter for fracture with nonunion*/
,'S62629P'  /*Displaced fracture of medial phalanx of unspecified finger, subsequent encounter for fracture with malunion*/
,'S62629S'  /*Displaced fracture of medial phalanx of unspecified finger, sequela*/
,'S62630D'  /*Displaced fracture of distal phalanx of right index finger, subsequent encounter for fracture with routine healing*/
,'S62630G'  /*Displaced fracture of distal phalanx of right index finger, subsequent encounter for fracture with delayed healing*/
,'S62630K'  /*Displaced fracture of distal phalanx of right index finger, subsequent encounter for fracture with nonunion*/
,'S62630P'  /*Displaced fracture of distal phalanx of right index finger, subsequent encounter for fracture with malunion*/
,'S62630S'  /*Displaced fracture of distal phalanx of right index finger, sequela*/
,'S62631D'  /*Displaced fracture of distal phalanx of left index finger, subsequent encounter for fracture with routine healing*/
,'S62631G'  /*Displaced fracture of distal phalanx of left index finger, subsequent encounter for fracture with delayed healing*/
,'S62631K'  /*Displaced fracture of distal phalanx of left index finger, subsequent encounter for fracture with nonunion*/
,'S62631P'  /*Displaced fracture of distal phalanx of left index finger, subsequent encounter for fracture with malunion*/
,'S62631S'  /*Displaced fracture of distal phalanx of left index finger, sequela*/
,'S62632D'  /*Displaced fracture of distal phalanx of right middle finger, subsequent encounter for fracture with routine healing*/
,'S62632G'  /*Displaced fracture of distal phalanx of right middle finger, subsequent encounter for fracture with delayed healing*/
,'S62632K'  /*Displaced fracture of distal phalanx of right middle finger, subsequent encounter for fracture with nonunion*/
,'S62632P'  /*Displaced fracture of distal phalanx of right middle finger, subsequent encounter for fracture with malunion*/
,'S62632S'  /*Displaced fracture of distal phalanx of right middle finger, sequela*/
,'S62633D'  /*Displaced fracture of distal phalanx of left middle finger, subsequent encounter for fracture with routine healing*/
,'S62633G'  /*Displaced fracture of distal phalanx of left middle finger, subsequent encounter for fracture with delayed healing*/
,'S62633K'  /*Displaced fracture of distal phalanx of left middle finger, subsequent encounter for fracture with nonunion*/
,'S62633P'  /*Displaced fracture of distal phalanx of left middle finger, subsequent encounter for fracture with malunion*/
,'S62633S'  /*Displaced fracture of distal phalanx of left middle finger, sequela*/
,'S62634D'  /*Displaced fracture of distal phalanx of right ring finger, subsequent encounter for fracture with routine healing*/
,'S62634G'  /*Displaced fracture of distal phalanx of right ring finger, subsequent encounter for fracture with delayed healing*/
,'S62634K'  /*Displaced fracture of distal phalanx of right ring finger, subsequent encounter for fracture with nonunion*/
,'S62634P'  /*Displaced fracture of distal phalanx of right ring finger, subsequent encounter for fracture with malunion*/
,'S62634S'  /*Displaced fracture of distal phalanx of right ring finger, sequela*/
,'S62635D'  /*Displaced fracture of distal phalanx of left ring finger, subsequent encounter for fracture with routine healing*/
,'S62635G'  /*Displaced fracture of distal phalanx of left ring finger, subsequent encounter for fracture with delayed healing*/
,'S62635K'  /*Displaced fracture of distal phalanx of left ring finger, subsequent encounter for fracture with nonunion*/
,'S62635P'  /*Displaced fracture of distal phalanx of left ring finger, subsequent encounter for fracture with malunion*/
,'S62635S'  /*Displaced fracture of distal phalanx of left ring finger, sequela*/
,'S62636D'  /*Displaced fracture of distal phalanx of right little finger, subsequent encounter for fracture with routine healing*/
,'S62636G'  /*Displaced fracture of distal phalanx of right little finger, subsequent encounter for fracture with delayed healing*/
,'S62636K'  /*Displaced fracture of distal phalanx of right little finger, subsequent encounter for fracture with nonunion*/
,'S62636P'  /*Displaced fracture of distal phalanx of right little finger, subsequent encounter for fracture with malunion*/
,'S62636S'  /*Displaced fracture of distal phalanx of right little finger, sequela*/
,'S62637D'  /*Displaced fracture of distal phalanx of left little finger, subsequent encounter for fracture with routine healing*/
,'S62637G'  /*Displaced fracture of distal phalanx of left little finger, subsequent encounter for fracture with delayed healing*/
,'S62637K'  /*Displaced fracture of distal phalanx of left little finger, subsequent encounter for fracture with nonunion*/
,'S62637P'  /*Displaced fracture of distal phalanx of left little finger, subsequent encounter for fracture with malunion*/
,'S62637S'  /*Displaced fracture of distal phalanx of left little finger, sequela*/
,'S62638D'  /*Displaced fracture of distal phalanx of other finger, subsequent encounter for fracture with routine healing*/
,'S62638G'  /*Displaced fracture of distal phalanx of other finger, subsequent encounter for fracture with delayed healing*/
,'S62638K'  /*Displaced fracture of distal phalanx of other finger, subsequent encounter for fracture with nonunion*/
,'S62638P'  /*Displaced fracture of distal phalanx of other finger, subsequent encounter for fracture with malunion*/
,'S62638S'  /*Displaced fracture of distal phalanx of other finger, sequela*/
,'S62639D'  /*Displaced fracture of distal phalanx of unspecified finger, subsequent encounter for fracture with routine healing*/
,'S62639G'  /*Displaced fracture of distal phalanx of unspecified finger, subsequent encounter for fracture with delayed healing*/
,'S62639K'  /*Displaced fracture of distal phalanx of unspecified finger, subsequent encounter for fracture with nonunion*/
,'S62639P'  /*Displaced fracture of distal phalanx of unspecified finger, subsequent encounter for fracture with malunion*/
,'S62639S'  /*Displaced fracture of distal phalanx of unspecified finger, sequela*/
,'S62640D'  /*Nondisplaced fracture of proximal phalanx of right index finger, subsequent encounter for fracture with routine healing*/
,'S62640G'  /*Nondisplaced fracture of proximal phalanx of right index finger, subsequent encounter for fracture with delayed healing*/
,'S62640K'  /*Nondisplaced fracture of proximal phalanx of right index finger, subsequent encounter for fracture with nonunion*/
,'S62640P'  /*Nondisplaced fracture of proximal phalanx of right index finger, subsequent encounter for fracture with malunion*/
,'S62640S'  /*Nondisplaced fracture of proximal phalanx of right index finger, sequela*/
,'S62641D'  /*Nondisplaced fracture of proximal phalanx of left index finger, subsequent encounter for fracture with routine healing*/
,'S62641G'  /*Nondisplaced fracture of proximal phalanx of left index finger, subsequent encounter for fracture with delayed healing*/
,'S62641K'  /*Nondisplaced fracture of proximal phalanx of left index finger, subsequent encounter for fracture with nonunion*/
,'S62641P'  /*Nondisplaced fracture of proximal phalanx of left index finger, subsequent encounter for fracture with malunion*/
,'S62641S'  /*Nondisplaced fracture of proximal phalanx of left index finger, sequela*/
,'S62642D'  /*Nondisplaced fracture of proximal phalanx of right middle finger, subsequent encounter for fracture with routine healing*/
,'S62642G'  /*Nondisplaced fracture of proximal phalanx of right middle finger, subsequent encounter for fracture with delayed healing*/
,'S62642K'  /*Nondisplaced fracture of proximal phalanx of right middle finger, subsequent encounter for fracture with nonunion*/
,'S62642P'  /*Nondisplaced fracture of proximal phalanx of right middle finger, subsequent encounter for fracture with malunion*/
,'S62642S'  /*Nondisplaced fracture of proximal phalanx of right middle finger, sequela*/
,'S62643D'  /*Nondisplaced fracture of proximal phalanx of left middle finger, subsequent encounter for fracture with routine healing*/
,'S62643G'  /*Nondisplaced fracture of proximal phalanx of left middle finger, subsequent encounter for fracture with delayed healing*/
,'S62643K'  /*Nondisplaced fracture of proximal phalanx of left middle finger, subsequent encounter for fracture with nonunion*/
,'S62643P'  /*Nondisplaced fracture of proximal phalanx of left middle finger, subsequent encounter for fracture with malunion*/
,'S62643S'  /*Nondisplaced fracture of proximal phalanx of left middle finger, sequela*/
,'S62644D'  /*Nondisplaced fracture of proximal phalanx of right ring finger, subsequent encounter for fracture with routine healing*/
,'S62644G'  /*Nondisplaced fracture of proximal phalanx of right ring finger, subsequent encounter for fracture with delayed healing*/
,'S62644K'  /*Nondisplaced fracture of proximal phalanx of right ring finger, subsequent encounter for fracture with nonunion*/
,'S62644P'  /*Nondisplaced fracture of proximal phalanx of right ring finger, subsequent encounter for fracture with malunion*/
,'S62644S'  /*Nondisplaced fracture of proximal phalanx of right ring finger, sequela*/
,'S62645D'  /*Nondisplaced fracture of proximal phalanx of left ring finger, subsequent encounter for fracture with routine healing*/
,'S62645G'  /*Nondisplaced fracture of proximal phalanx of left ring finger, subsequent encounter for fracture with delayed healing*/
,'S62645K'  /*Nondisplaced fracture of proximal phalanx of left ring finger, subsequent encounter for fracture with nonunion*/
,'S62645P'  /*Nondisplaced fracture of proximal phalanx of left ring finger, subsequent encounter for fracture with malunion*/
,'S62645S'  /*Nondisplaced fracture of proximal phalanx of left ring finger, sequela*/
,'S62646D'  /*Nondisplaced fracture of proximal phalanx of right little finger, subsequent encounter for fracture with routine healing*/
,'S62646G'  /*Nondisplaced fracture of proximal phalanx of right little finger, subsequent encounter for fracture with delayed healing*/
,'S62646K'  /*Nondisplaced fracture of proximal phalanx of right little finger, subsequent encounter for fracture with nonunion*/
,'S62646P'  /*Nondisplaced fracture of proximal phalanx of right little finger, subsequent encounter for fracture with malunion*/
,'S62646S'  /*Nondisplaced fracture of proximal phalanx of right little finger, sequela*/
,'S62647D'  /*Nondisplaced fracture of proximal phalanx of left little finger, subsequent encounter for fracture with routine healing*/
,'S62647G'  /*Nondisplaced fracture of proximal phalanx of left little finger, subsequent encounter for fracture with delayed healing*/
,'S62647K'  /*Nondisplaced fracture of proximal phalanx of left little finger, subsequent encounter for fracture with nonunion*/
,'S62647P'  /*Nondisplaced fracture of proximal phalanx of left little finger, subsequent encounter for fracture with malunion*/
,'S62647S'  /*Nondisplaced fracture of proximal phalanx of left little finger, sequela*/
,'S62648D'  /*Nondisplaced fracture of proximal phalanx of other finger, subsequent encounter for fracture with routine healing*/
,'S62648G'  /*Nondisplaced fracture of proximal phalanx of other finger, subsequent encounter for fracture with delayed healing*/
,'S62648K'  /*Nondisplaced fracture of proximal phalanx of other finger, subsequent encounter for fracture with nonunion*/
,'S62648P'  /*Nondisplaced fracture of proximal phalanx of other finger, subsequent encounter for fracture with malunion*/
,'S62648S'  /*Nondisplaced fracture of proximal phalanx of other finger, sequela*/
,'S62649D'  /*Nondisplaced fracture of proximal phalanx of unspecified finger, subsequent encounter for fracture with routine healing*/
,'S62649G'  /*Nondisplaced fracture of proximal phalanx of unspecified finger, subsequent encounter for fracture with delayed healing*/
,'S62649K'  /*Nondisplaced fracture of proximal phalanx of unspecified finger, subsequent encounter for fracture with nonunion*/
,'S62649P'  /*Nondisplaced fracture of proximal phalanx of unspecified finger, subsequent encounter for fracture with malunion*/
,'S62649S'  /*Nondisplaced fracture of proximal phalanx of unspecified finger, sequela*/
,'S62650D'  /*Nondisplaced fracture of medial phalanx of right index finger, subsequent encounter for fracture with routine healing*/
,'S62650G'  /*Nondisplaced fracture of medial phalanx of right index finger, subsequent encounter for fracture with delayed healing*/
,'S62650K'  /*Nondisplaced fracture of medial phalanx of right index finger, subsequent encounter for fracture with nonunion*/
,'S62650P'  /*Nondisplaced fracture of medial phalanx of right index finger, subsequent encounter for fracture with malunion*/
,'S62650S'  /*Nondisplaced fracture of medial phalanx of right index finger, sequela*/
,'S62651D'  /*Nondisplaced fracture of medial phalanx of left index finger, subsequent encounter for fracture with routine healing*/
,'S62651G'  /*Nondisplaced fracture of medial phalanx of left index finger, subsequent encounter for fracture with delayed healing*/
,'S62651K'  /*Nondisplaced fracture of medial phalanx of left index finger, subsequent encounter for fracture with nonunion*/
,'S62651P'  /*Nondisplaced fracture of medial phalanx of left index finger, subsequent encounter for fracture with malunion*/
,'S62651S'  /*Nondisplaced fracture of medial phalanx of left index finger, sequela*/
,'S62652D'  /*Nondisplaced fracture of medial phalanx of right middle finger, subsequent encounter for fracture with routine healing*/
,'S62652G'  /*Nondisplaced fracture of medial phalanx of right middle finger, subsequent encounter for fracture with delayed healing*/
,'S62652K'  /*Nondisplaced fracture of medial phalanx of right middle finger, subsequent encounter for fracture with nonunion*/
,'S62652P'  /*Nondisplaced fracture of medial phalanx of right middle finger, subsequent encounter for fracture with malunion*/
,'S62652S'  /*Nondisplaced fracture of medial phalanx of right middle finger, sequela*/
,'S62653D'  /*Nondisplaced fracture of medial phalanx of left middle finger, subsequent encounter for fracture with routine healing*/
,'S62653G'  /*Nondisplaced fracture of medial phalanx of left middle finger, subsequent encounter for fracture with delayed healing*/
,'S62653K'  /*Nondisplaced fracture of medial phalanx of left middle finger, subsequent encounter for fracture with nonunion*/
,'S62653P'  /*Nondisplaced fracture of medial phalanx of left middle finger, subsequent encounter for fracture with malunion*/
,'S62653S'  /*Nondisplaced fracture of medial phalanx of left middle finger, sequela*/
,'S62654D'  /*Nondisplaced fracture of medial phalanx of right ring finger, subsequent encounter for fracture with routine healing*/
,'S62654G'  /*Nondisplaced fracture of medial phalanx of right ring finger, subsequent encounter for fracture with delayed healing*/
,'S62654K'  /*Nondisplaced fracture of medial phalanx of right ring finger, subsequent encounter for fracture with nonunion*/
,'S62654P'  /*Nondisplaced fracture of medial phalanx of right ring finger, subsequent encounter for fracture with malunion*/
,'S62654S'  /*Nondisplaced fracture of medial phalanx of right ring finger, sequela*/
,'S62655D'  /*Nondisplaced fracture of medial phalanx of left ring finger, subsequent encounter for fracture with routine healing*/
,'S62655G'  /*Nondisplaced fracture of medial phalanx of left ring finger, subsequent encounter for fracture with delayed healing*/
,'S62655K'  /*Nondisplaced fracture of medial phalanx of left ring finger, subsequent encounter for fracture with nonunion*/
,'S62655P'  /*Nondisplaced fracture of medial phalanx of left ring finger, subsequent encounter for fracture with malunion*/
,'S62655S'  /*Nondisplaced fracture of medial phalanx of left ring finger, sequela*/
,'S62656D'  /*Nondisplaced fracture of medial phalanx of right little finger, subsequent encounter for fracture with routine healing*/
,'S62656G'  /*Nondisplaced fracture of medial phalanx of right little finger, subsequent encounter for fracture with delayed healing*/
,'S62656K'  /*Nondisplaced fracture of medial phalanx of right little finger, subsequent encounter for fracture with nonunion*/
,'S62656P'  /*Nondisplaced fracture of medial phalanx of right little finger, subsequent encounter for fracture with malunion*/
,'S62656S'  /*Nondisplaced fracture of medial phalanx of right little finger, sequela*/
,'S62657D'  /*Nondisplaced fracture of medial phalanx of left little finger, subsequent encounter for fracture with routine healing*/
,'S62657G'  /*Nondisplaced fracture of medial phalanx of left little finger, subsequent encounter for fracture with delayed healing*/
,'S62657K'  /*Nondisplaced fracture of medial phalanx of left little finger, subsequent encounter for fracture with nonunion*/
,'S62657P'  /*Nondisplaced fracture of medial phalanx of left little finger, subsequent encounter for fracture with malunion*/
,'S62657S'  /*Nondisplaced fracture of medial phalanx of left little finger, sequela*/
,'S62658D'  /*Nondisplaced fracture of medial phalanx of other finger, subsequent encounter for fracture with routine healing*/
,'S62658G'  /*Nondisplaced fracture of medial phalanx of other finger, subsequent encounter for fracture with delayed healing*/
,'S62658K'  /*Nondisplaced fracture of medial phalanx of other finger, subsequent encounter for fracture with nonunion*/
,'S62658P'  /*Nondisplaced fracture of medial phalanx of other finger, subsequent encounter for fracture with malunion*/
,'S62658S'  /*Nondisplaced fracture of medial phalanx of other finger, sequela*/
,'S62659D'  /*Nondisplaced fracture of medial phalanx of unspecified finger, subsequent encounter for fracture with routine healing*/
,'S62659G'  /*Nondisplaced fracture of medial phalanx of unspecified finger, subsequent encounter for fracture with delayed healing*/
,'S62659K'  /*Nondisplaced fracture of medial phalanx of unspecified finger, subsequent encounter for fracture with nonunion*/
,'S62659P'  /*Nondisplaced fracture of medial phalanx of unspecified finger, subsequent encounter for fracture with malunion*/
,'S62659S'  /*Nondisplaced fracture of medial phalanx of unspecified finger, sequela*/
,'S62660D'  /*Nondisplaced fracture of distal phalanx of right index finger, subsequent encounter for fracture with routine healing*/
,'S62660G'  /*Nondisplaced fracture of distal phalanx of right index finger, subsequent encounter for fracture with delayed healing*/
,'S62660K'  /*Nondisplaced fracture of distal phalanx of right index finger, subsequent encounter for fracture with nonunion*/
,'S62660P'  /*Nondisplaced fracture of distal phalanx of right index finger, subsequent encounter for fracture with malunion*/
,'S62660S'  /*Nondisplaced fracture of distal phalanx of right index finger, sequela*/
,'S62661D'  /*Nondisplaced fracture of distal phalanx of left index finger, subsequent encounter for fracture with routine healing*/
,'S62661G'  /*Nondisplaced fracture of distal phalanx of left index finger, subsequent encounter for fracture with delayed healing*/
,'S62661K'  /*Nondisplaced fracture of distal phalanx of left index finger, subsequent encounter for fracture with nonunion*/
,'S62661P'  /*Nondisplaced fracture of distal phalanx of left index finger, subsequent encounter for fracture with malunion*/
,'S62661S'  /*Nondisplaced fracture of distal phalanx of left index finger, sequela*/
,'S62662D'  /*Nondisplaced fracture of distal phalanx of right middle finger, subsequent encounter for fracture with routine healing*/
,'S62662G'  /*Nondisplaced fracture of distal phalanx of right middle finger, subsequent encounter for fracture with delayed healing*/
,'S62662K'  /*Nondisplaced fracture of distal phalanx of right middle finger, subsequent encounter for fracture with nonunion*/
,'S62662P'  /*Nondisplaced fracture of distal phalanx of right middle finger, subsequent encounter for fracture with malunion*/
,'S62662S'  /*Nondisplaced fracture of distal phalanx of right middle finger, sequela*/
,'S62663D'  /*Nondisplaced fracture of distal phalanx of left middle finger, subsequent encounter for fracture with routine healing*/
,'S62663G'  /*Nondisplaced fracture of distal phalanx of left middle finger, subsequent encounter for fracture with delayed healing*/
,'S62663K'  /*Nondisplaced fracture of distal phalanx of left middle finger, subsequent encounter for fracture with nonunion*/
,'S62663P'  /*Nondisplaced fracture of distal phalanx of left middle finger, subsequent encounter for fracture with malunion*/
,'S62663S'  /*Nondisplaced fracture of distal phalanx of left middle finger, sequela*/
,'S62664D'  /*Nondisplaced fracture of distal phalanx of right ring finger, subsequent encounter for fracture with routine healing*/
,'S62664G'  /*Nondisplaced fracture of distal phalanx of right ring finger, subsequent encounter for fracture with delayed healing*/
,'S62664K'  /*Nondisplaced fracture of distal phalanx of right ring finger, subsequent encounter for fracture with nonunion*/
,'S62664P'  /*Nondisplaced fracture of distal phalanx of right ring finger, subsequent encounter for fracture with malunion*/
,'S62664S'  /*Nondisplaced fracture of distal phalanx of right ring finger, sequela*/
,'S62665D'  /*Nondisplaced fracture of distal phalanx of left ring finger, subsequent encounter for fracture with routine healing*/
,'S62665G'  /*Nondisplaced fracture of distal phalanx of left ring finger, subsequent encounter for fracture with delayed healing*/
,'S62665K'  /*Nondisplaced fracture of distal phalanx of left ring finger, subsequent encounter for fracture with nonunion*/
,'S62665P'  /*Nondisplaced fracture of distal phalanx of left ring finger, subsequent encounter for fracture with malunion*/
,'S62665S'  /*Nondisplaced fracture of distal phalanx of left ring finger, sequela*/
,'S62666D'  /*Nondisplaced fracture of distal phalanx of right little finger, subsequent encounter for fracture with routine healing*/
,'S62666G'  /*Nondisplaced fracture of distal phalanx of right little finger, subsequent encounter for fracture with delayed healing*/
,'S62666K'  /*Nondisplaced fracture of distal phalanx of right little finger, subsequent encounter for fracture with nonunion*/
,'S62666P'  /*Nondisplaced fracture of distal phalanx of right little finger, subsequent encounter for fracture with malunion*/
,'S62666S'  /*Nondisplaced fracture of distal phalanx of right little finger, sequela*/
,'S62667D'  /*Nondisplaced fracture of distal phalanx of left little finger, subsequent encounter for fracture with routine healing*/
,'S62667G'  /*Nondisplaced fracture of distal phalanx of left little finger, subsequent encounter for fracture with delayed healing*/
,'S62667K'  /*Nondisplaced fracture of distal phalanx of left little finger, subsequent encounter for fracture with nonunion*/
,'S62667P'  /*Nondisplaced fracture of distal phalanx of left little finger, subsequent encounter for fracture with malunion*/
,'S62667S'  /*Nondisplaced fracture of distal phalanx of left little finger, sequela*/
,'S62668D'  /*Nondisplaced fracture of distal phalanx of other finger, subsequent encounter for fracture with routine healing*/
,'S62668G'  /*Nondisplaced fracture of distal phalanx of other finger, subsequent encounter for fracture with delayed healing*/
,'S62668K'  /*Nondisplaced fracture of distal phalanx of other finger, subsequent encounter for fracture with nonunion*/
,'S62668P'  /*Nondisplaced fracture of distal phalanx of other finger, subsequent encounter for fracture with malunion*/
,'S62668S'  /*Nondisplaced fracture of distal phalanx of other finger, sequela*/
,'S62669D'  /*Nondisplaced fracture of distal phalanx of unspecified finger, subsequent encounter for fracture with routine healing*/
,'S62669G'  /*Nondisplaced fracture of distal phalanx of unspecified finger, subsequent encounter for fracture with delayed healing*/
,'S62669K'  /*Nondisplaced fracture of distal phalanx of unspecified finger, subsequent encounter for fracture with nonunion*/
,'S62669P'  /*Nondisplaced fracture of distal phalanx of unspecified finger, subsequent encounter for fracture with malunion*/
,'S62669S'  /*Nondisplaced fracture of distal phalanx of unspecified finger, sequela*/
,'S6290XD'  /*Unspecified fracture of unspecified wrist and hand, subsequent encounter for fracture with routine healing*/
,'S6290XG'  /*Unspecified fracture of unspecified wrist and hand, subsequent encounter for fracture with delayed healing*/
,'S6290XK'  /*Unspecified fracture of unspecified wrist and hand, subsequent encounter for fracture with nonunion*/
,'S6290XP'  /*Unspecified fracture of unspecified wrist and hand, subsequent encounter for fracture with malunion*/
,'S6290XS'  /*Unspecified fracture of unspecified wrist and hand, sequela*/
,'S6291XD'  /*Unspecified fracture of right wrist and hand, subsequent encounter for fracture with routine healing*/
,'S6291XG'  /*Unspecified fracture of right wrist and hand, subsequent encounter for fracture with delayed healing*/
,'S6291XK'  /*Unspecified fracture of right wrist and hand, subsequent encounter for fracture with nonunion*/
,'S6291XP'  /*Unspecified fracture of right wrist and hand, subsequent encounter for fracture with malunion*/
,'S6291XS'  /*Unspecified fracture of right wrist and hand, sequela*/
,'S6292XD'  /*Unspecified fracture of left wrist and hand, subsequent encounter for fracture with routine healing*/
,'S6292XG'  /*Unspecified fracture of left wrist and hand, subsequent encounter for fracture with delayed healing*/
,'S6292XK'  /*Unspecified fracture of left wrist and hand, subsequent encounter for fracture with nonunion*/
,'S6292XP'  /*Unspecified fracture of left wrist and hand, subsequent encounter for fracture with malunion*/
,'S6292XS'  /*Unspecified fracture of left wrist and hand, sequela*/
,'S63001D'  /*Unspecified subluxation of right wrist and hand, subsequent encounter*/
,'S63001S'  /*Unspecified subluxation of right wrist and hand, sequela*/
,'S63002D'  /*Unspecified subluxation of left wrist and hand, subsequent encounter*/
,'S63002S'  /*Unspecified subluxation of left wrist and hand, sequela*/
,'S63003D'  /*Unspecified subluxation of unspecified wrist and hand, subsequent encounter*/
,'S63003S'  /*Unspecified subluxation of unspecified wrist and hand, sequela*/
,'S63004D'  /*Unspecified dislocation of right wrist and hand, subsequent encounter*/
,'S63004S'  /*Unspecified dislocation of right wrist and hand, sequela*/
,'S63005D'  /*Unspecified dislocation of left wrist and hand, subsequent encounter*/
,'S63005S'  /*Unspecified dislocation of left wrist and hand, sequela*/
,'S63006D'  /*Unspecified dislocation of unspecified wrist and hand, subsequent encounter*/
,'S63006S'  /*Unspecified dislocation of unspecified wrist and hand, sequela*/
,'S63011D'  /*Subluxation of distal radioulnar joint of right wrist, subsequent encounter*/
,'S63011S'  /*Subluxation of distal radioulnar joint of right wrist, sequela*/
,'S63012D'  /*Subluxation of distal radioulnar joint of left wrist, subsequent encounter*/
,'S63012S'  /*Subluxation of distal radioulnar joint of left wrist, sequela*/
,'S63013D'  /*Subluxation of distal radioulnar joint of unspecified wrist, subsequent encounter*/
,'S63013S'  /*Subluxation of distal radioulnar joint of unspecified wrist, sequela*/
,'S63014D'  /*Dislocation of distal radioulnar joint of right wrist, subsequent encounter*/
,'S63014S'  /*Dislocation of distal radioulnar joint of right wrist, sequela*/
,'S63015D'  /*Dislocation of distal radioulnar joint of left wrist, subsequent encounter*/
,'S63015S'  /*Dislocation of distal radioulnar joint of left wrist, sequela*/
,'S63016D'  /*Dislocation of distal radioulnar joint of unspecified wrist, subsequent encounter*/
,'S63016S'  /*Dislocation of distal radioulnar joint of unspecified wrist, sequela*/
,'S63021D'  /*Subluxation of radiocarpal joint of right wrist, subsequent encounter*/
,'S63021S'  /*Subluxation of radiocarpal joint of right wrist, sequela*/
,'S63022D'  /*Subluxation of radiocarpal joint of left wrist, subsequent encounter*/
,'S63022S'  /*Subluxation of radiocarpal joint of left wrist, sequela*/
,'S63023D'  /*Subluxation of radiocarpal joint of unspecified wrist, subsequent encounter*/
,'S63023S'  /*Subluxation of radiocarpal joint of unspecified wrist, sequela*/
,'S63024D'  /*Dislocation of radiocarpal joint of right wrist, subsequent encounter*/
,'S63024S'  /*Dislocation of radiocarpal joint of right wrist, sequela*/
,'S63025D'  /*Dislocation of radiocarpal joint of left wrist, subsequent encounter*/
,'S63025S'  /*Dislocation of radiocarpal joint of left wrist, sequela*/
,'S63026D'  /*Dislocation of radiocarpal joint of unspecified wrist, subsequent encounter*/
,'S63026S'  /*Dislocation of radiocarpal joint of unspecified wrist, sequela*/
,'S63031D'  /*Subluxation of midcarpal joint of right wrist, subsequent encounter*/
,'S63031S'  /*Subluxation of midcarpal joint of right wrist, sequela*/
,'S63032D'  /*Subluxation of midcarpal joint of left wrist, subsequent encounter*/
,'S63032S'  /*Subluxation of midcarpal joint of left wrist, sequela*/
,'S63033D'  /*Subluxation of midcarpal joint of unspecified wrist, subsequent encounter*/
,'S63033S'  /*Subluxation of midcarpal joint of unspecified wrist, sequela*/
,'S63034D'  /*Dislocation of midcarpal joint of right wrist, subsequent encounter*/
,'S63034S'  /*Dislocation of midcarpal joint of right wrist, sequela*/
,'S63035D'  /*Dislocation of midcarpal joint of left wrist, subsequent encounter*/
,'S63035S'  /*Dislocation of midcarpal joint of left wrist, sequela*/
,'S63036D'  /*Dislocation of midcarpal joint of unspecified wrist, subsequent encounter*/
,'S63036S'  /*Dislocation of midcarpal joint of unspecified wrist, sequela*/
,'S63041D'  /*Subluxation of carpometacarpal joint of right thumb, subsequent encounter*/
,'S63041S'  /*Subluxation of carpometacarpal joint of right thumb, sequela*/
,'S63042D'  /*Subluxation of carpometacarpal joint of left thumb, subsequent encounter*/
,'S63042S'  /*Subluxation of carpometacarpal joint of left thumb, sequela*/
,'S63043D'  /*Subluxation of carpometacarpal joint of unspecified thumb, subsequent encounter*/
,'S63043S'  /*Subluxation of carpometacarpal joint of unspecified thumb, sequela*/
,'S63044D'  /*Dislocation of carpometacarpal joint of right thumb, subsequent encounter*/
,'S63044S'  /*Dislocation of carpometacarpal joint of right thumb, sequela*/
,'S63045D'  /*Dislocation of carpometacarpal joint of left thumb, subsequent encounter*/
,'S63045S'  /*Dislocation of carpometacarpal joint of left thumb, sequela*/
,'S63046D'  /*Dislocation of carpometacarpal joint of unspecified thumb, subsequent encounter*/
,'S63046S'  /*Dislocation of carpometacarpal joint of unspecified thumb, sequela*/
,'S63051D'  /*Subluxation of other carpometacarpal joint of right hand, subsequent encounter*/
,'S63051S'  /*Subluxation of other carpometacarpal joint of right hand, sequela*/
,'S63052D'  /*Subluxation of other carpometacarpal joint of left hand, subsequent encounter*/
,'S63052S'  /*Subluxation of other carpometacarpal joint of left hand, sequela*/
,'S63053D'  /*Subluxation of other carpometacarpal joint of unspecified hand, subsequent encounter*/
,'S63053S'  /*Subluxation of other carpometacarpal joint of unspecified hand, sequela*/
,'S63054D'  /*Dislocation of other carpometacarpal joint of right hand, subsequent encounter*/
,'S63054S'  /*Dislocation of other carpometacarpal joint of right hand, sequela*/
,'S63055D'  /*Dislocation of other carpometacarpal joint of left hand, subsequent encounter*/
,'S63055S'  /*Dislocation of other carpometacarpal joint of left hand, sequela*/
,'S63056D'  /*Dislocation of other carpometacarpal joint of unspecified hand, subsequent encounter*/
,'S63056S'  /*Dislocation of other carpometacarpal joint of unspecified hand, sequela*/
,'S63061D'  /*Subluxation of metacarpal (bone), proximal end of right hand, subsequent encounter*/
,'S63061S'  /*Subluxation of metacarpal (bone), proximal end of right hand, sequela*/
,'S63062D'  /*Subluxation of metacarpal (bone), proximal end of left hand, subsequent encounter*/
,'S63062S'  /*Subluxation of metacarpal (bone), proximal end of left hand, sequela*/
,'S63063D'  /*Subluxation of metacarpal (bone), proximal end of unspecified hand, subsequent encounter*/
,'S63063S'  /*Subluxation of metacarpal (bone), proximal end of unspecified hand, sequela*/
,'S63064D'  /*Dislocation of metacarpal (bone), proximal end of right hand, subsequent encounter*/
,'S63064S'  /*Dislocation of metacarpal (bone), proximal end of right hand, sequela*/
,'S63065D'  /*Dislocation of metacarpal (bone), proximal end of left hand, subsequent encounter*/
,'S63065S'  /*Dislocation of metacarpal (bone), proximal end of left hand, sequela*/
,'S63066D'  /*Dislocation of metacarpal (bone), proximal end of unspecified hand, subsequent encounter*/
,'S63066S'  /*Dislocation of metacarpal (bone), proximal end of unspecified hand, sequela*/
,'S63071D'  /*Subluxation of distal end of right ulna, subsequent encounter*/
,'S63071S'  /*Subluxation of distal end of right ulna, sequela*/
,'S63072D'  /*Subluxation of distal end of left ulna, subsequent encounter*/
,'S63072S'  /*Subluxation of distal end of left ulna, sequela*/
,'S63073D'  /*Subluxation of distal end of unspecified ulna, subsequent encounter*/
,'S63073S'  /*Subluxation of distal end of unspecified ulna, sequela*/
,'S63074D'  /*Dislocation of distal end of right ulna, subsequent encounter*/
,'S63074S'  /*Dislocation of distal end of right ulna, sequela*/
,'S63075D'  /*Dislocation of distal end of left ulna, subsequent encounter*/
,'S63075S'  /*Dislocation of distal end of left ulna, sequela*/
,'S63076D'  /*Dislocation of distal end of unspecified ulna, subsequent encounter*/
,'S63076S'  /*Dislocation of distal end of unspecified ulna, sequela*/
,'S63091D'  /*Other subluxation of right wrist and hand, subsequent encounter*/
,'S63091S'  /*Other subluxation of right wrist and hand, sequela*/
,'S63092D'  /*Other subluxation of left wrist and hand, subsequent encounter*/
,'S63092S'  /*Other subluxation of left wrist and hand, sequela*/
,'S63093D'  /*Other subluxation of unspecified wrist and hand, subsequent encounter*/
,'S63093S'  /*Other subluxation of unspecified wrist and hand, sequela*/
,'S63094D'  /*Other dislocation of right wrist and hand, subsequent encounter*/
,'S63094S'  /*Other dislocation of right wrist and hand, sequela*/
,'S63095D'  /*Other dislocation of left wrist and hand, subsequent encounter*/
,'S63095S'  /*Other dislocation of left wrist and hand, sequela*/
,'S63096D'  /*Other dislocation of unspecified wrist and hand, subsequent encounter*/
,'S63096S'  /*Other dislocation of unspecified wrist and hand, sequela*/
,'S63101D'  /*Unspecified subluxation of right thumb, subsequent encounter*/
,'S63101S'  /*Unspecified subluxation of right thumb, sequela*/
,'S63102D'  /*Unspecified subluxation of left thumb, subsequent encounter*/
,'S63102S'  /*Unspecified subluxation of left thumb, sequela*/
,'S63103D'  /*Unspecified subluxation of unspecified thumb, subsequent encounter*/
,'S63103S'  /*Unspecified subluxation of unspecified thumb, sequela*/
,'S63104D'  /*Unspecified dislocation of right thumb, subsequent encounter*/
,'S63104S'  /*Unspecified dislocation of right thumb, sequela*/
,'S63105D'  /*Unspecified dislocation of left thumb, subsequent encounter*/
,'S63105S'  /*Unspecified dislocation of left thumb, sequela*/
,'S63106D'  /*Unspecified dislocation of unspecified thumb, subsequent encounter*/
,'S63106S'  /*Unspecified dislocation of unspecified thumb, sequela*/
,'S63111D'  /*Subluxation of metacarpophalangeal joint of right thumb, subsequent encounter*/
,'S63111S'  /*Subluxation of metacarpophalangeal joint of right thumb, sequela*/
,'S63112D'  /*Subluxation of metacarpophalangeal joint of left thumb, subsequent encounter*/
,'S63112S'  /*Subluxation of metacarpophalangeal joint of left thumb, sequela*/
,'S63113D'  /*Subluxation of metacarpophalangeal joint of unspecified thumb, subsequent encounter*/
,'S63113S'  /*Subluxation of metacarpophalangeal joint of unspecified thumb, sequela*/
,'S63114D'  /*Dislocation of metacarpophalangeal joint of right thumb, subsequent encounter*/
,'S63114S'  /*Dislocation of metacarpophalangeal joint of right thumb, sequela*/
,'S63115D'  /*Dislocation of metacarpophalangeal joint of left thumb, subsequent encounter*/
,'S63115S'  /*Dislocation of metacarpophalangeal joint of left thumb, sequela*/
,'S63116D'  /*Dislocation of metacarpophalangeal joint of unspecified thumb, subsequent encounter*/
,'S63116S'  /*Dislocation of metacarpophalangeal joint of unspecified thumb, sequela*/
,'S63121D'  /*Subluxation of unspecified interphalangeal joint of right thumb, subsequent encounter*/
,'S63121S'  /*Subluxation of unspecified interphalangeal joint of right thumb, sequela*/
,'S63122D'  /*Subluxation of unspecified interphalangeal joint of left thumb, subsequent encounter*/
,'S63122S'  /*Subluxation of unspecified interphalangeal joint of left thumb, sequela*/
,'S63123D'  /*Subluxation of unspecified interphalangeal joint of unspecified thumb, subsequent encounter*/
,'S63123S'  /*Subluxation of unspecified interphalangeal joint of unspecified thumb, sequela*/
,'S63124D'  /*Dislocation of unspecified interphalangeal joint of right thumb, subsequent encounter*/
,'S63124S'  /*Dislocation of unspecified interphalangeal joint of right thumb, sequela*/
,'S63125D'  /*Dislocation of unspecified interphalangeal joint of left thumb, subsequent encounter*/
,'S63125S'  /*Dislocation of unspecified interphalangeal joint of left thumb, sequela*/
,'S63126D'  /*Dislocation of unspecified interphalangeal joint of unspecified thumb, subsequent encounter*/
,'S63126S'  /*Dislocation of unspecified interphalangeal joint of unspecified thumb, sequela*/
,'S63131D'  /*Subluxation of proximal interphalangeal joint of right thumb, subsequent encounter*/
,'S63131S'  /*Subluxation of proximal interphalangeal joint of right thumb, sequela*/
,'S63132D'  /*Subluxation of proximal interphalangeal joint of left thumb, subsequent encounter*/
,'S63132S'  /*Subluxation of proximal interphalangeal joint of left thumb, sequela*/
,'S63133D'  /*Subluxation of proximal interphalangeal joint of unspecified thumb, subsequent encounter*/
,'S63133S'  /*Subluxation of proximal interphalangeal joint of unspecified thumb, sequela*/
,'S63134D'  /*Dislocation of proximal interphalangeal joint of right thumb, subsequent encounter*/
,'S63134S'  /*Dislocation of proximal interphalangeal joint of right thumb, sequela*/
,'S63135D'  /*Dislocation of proximal interphalangeal joint of left thumb, subsequent encounter*/
,'S63135S'  /*Dislocation of proximal interphalangeal joint of left thumb, sequela*/
,'S63136D'  /*Dislocation of proximal interphalangeal joint of unspecified thumb, subsequent encounter*/
,'S63136S'  /*Dislocation of proximal interphalangeal joint of unspecified thumb, sequela*/
,'S63141D'  /*Subluxation of distal interphalangeal joint of right thumb, subsequent encounter*/
,'S63141S'  /*Subluxation of distal interphalangeal joint of right thumb, sequela*/
,'S63142D'  /*Subluxation of distal interphalangeal joint of left thumb, subsequent encounter*/
,'S63142S'  /*Subluxation of distal interphalangeal joint of left thumb, sequela*/
,'S63143D'  /*Subluxation of distal interphalangeal joint of unspecified thumb, subsequent encounter*/
,'S63143S'  /*Subluxation of distal interphalangeal joint of unspecified thumb, sequela*/
,'S63144D'  /*Dislocation of distal interphalangeal joint of right thumb, subsequent encounter*/
,'S63144S'  /*Dislocation of distal interphalangeal joint of right thumb, sequela*/
,'S63145D'  /*Dislocation of distal interphalangeal joint of left thumb, subsequent encounter*/
,'S63145S'  /*Dislocation of distal interphalangeal joint of left thumb, sequela*/
,'S63146D'  /*Dislocation of distal interphalangeal joint of unspecified thumb, subsequent encounter*/
,'S63146S'  /*Dislocation of distal interphalangeal joint of unspecified thumb, sequela*/
,'S63200D'  /*Unspecified subluxation of right index finger, subsequent encounter*/
,'S63200S'  /*Unspecified subluxation of right index finger, sequela*/
,'S63201D'  /*Unspecified subluxation of left index finger, subsequent encounter*/
,'S63201S'  /*Unspecified subluxation of left index finger, sequela*/
,'S63202D'  /*Unspecified subluxation of right middle finger, subsequent encounter*/
,'S63202S'  /*Unspecified subluxation of right middle finger, sequela*/
,'S63203D'  /*Unspecified subluxation of left middle finger, subsequent encounter*/
,'S63203S'  /*Unspecified subluxation of left middle finger, sequela*/
,'S63204D'  /*Unspecified subluxation of right ring finger, subsequent encounter*/
,'S63204S'  /*Unspecified subluxation of right ring finger, sequela*/
,'S63205D'  /*Unspecified subluxation of left ring finger, subsequent encounter*/
,'S63205S'  /*Unspecified subluxation of left ring finger, sequela*/
,'S63206D'  /*Unspecified subluxation of right little finger, subsequent encounter*/
,'S63206S'  /*Unspecified subluxation of right little finger, sequela*/
,'S63207D'  /*Unspecified subluxation of left little finger, subsequent encounter*/
,'S63207S'  /*Unspecified subluxation of left little finger, sequela*/
,'S63208D'  /*Unspecified subluxation of other finger, subsequent encounter*/
,'S63208S'  /*Unspecified subluxation of other finger, sequela*/
,'S63209D'  /*Unspecified subluxation of unspecified finger, subsequent encounter*/
,'S63209S'  /*Unspecified subluxation of unspecified finger, sequela*/
,'S63210D'  /*Subluxation of metacarpophalangeal joint of right index finger, subsequent encounter*/
,'S63210S'  /*Subluxation of metacarpophalangeal joint of right index finger, sequela*/
,'S63211D'  /*Subluxation of metacarpophalangeal joint of left index finger, subsequent encounter*/
,'S63211S'  /*Subluxation of metacarpophalangeal joint of left index finger, sequela*/
,'S63212D'  /*Subluxation of metacarpophalangeal joint of right middle finger, subsequent encounter*/
,'S63212S'  /*Subluxation of metacarpophalangeal joint of right middle finger, sequela*/
,'S63213D'  /*Subluxation of metacarpophalangeal joint of left middle finger, subsequent encounter*/
,'S63213S'  /*Subluxation of metacarpophalangeal joint of left middle finger, sequela*/
,'S63214D'  /*Subluxation of metacarpophalangeal joint of right ring finger, subsequent encounter*/
,'S63214S'  /*Subluxation of metacarpophalangeal joint of right ring finger, sequela*/
,'S63215D'  /*Subluxation of metacarpophalangeal joint of left ring finger, subsequent encounter*/
,'S63215S'  /*Subluxation of metacarpophalangeal joint of left ring finger, sequela*/
,'S63216D'  /*Subluxation of metacarpophalangeal joint of right little finger, subsequent encounter*/
,'S63216S'  /*Subluxation of metacarpophalangeal joint of right little finger, sequela*/
,'S63217D'  /*Subluxation of metacarpophalangeal joint of left little finger, subsequent encounter*/
,'S63217S'  /*Subluxation of metacarpophalangeal joint of left little finger, sequela*/
,'S63218D'  /*Subluxation of metacarpophalangeal joint of other finger, subsequent encounter*/
,'S63218S'  /*Subluxation of metacarpophalangeal joint of other finger, sequela*/
,'S63219D'  /*Subluxation of metacarpophalangeal joint of unspecified finger, subsequent encounter*/
,'S63219S'  /*Subluxation of metacarpophalangeal joint of unspecified finger, sequela*/
,'S63220D'  /*Subluxation of unspecified interphalangeal joint of right index finger, subsequent encounter*/
,'S63220S'  /*Subluxation of unspecified interphalangeal joint of right index finger, sequela*/
,'S63221D'  /*Subluxation of unspecified interphalangeal joint of left index finger, subsequent encounter*/
,'S63221S'  /*Subluxation of unspecified interphalangeal joint of left index finger, sequela*/
,'S63222D'  /*Subluxation of unspecified interphalangeal joint of right middle finger, subsequent encounter*/
,'S63222S'  /*Subluxation of unspecified interphalangeal joint of right middle finger, sequela*/
,'S63223D'  /*Subluxation of unspecified interphalangeal joint of left middle finger, subsequent encounter*/
,'S63223S'  /*Subluxation of unspecified interphalangeal joint of left middle finger, sequela*/
,'S63224D'  /*Subluxation of unspecified interphalangeal joint of right ring finger, subsequent encounter*/
,'S63224S'  /*Subluxation of unspecified interphalangeal joint of right ring finger, sequela*/
,'S63225D'  /*Subluxation of unspecified interphalangeal joint of left ring finger, subsequent encounter*/
,'S63225S'  /*Subluxation of unspecified interphalangeal joint of left ring finger, sequela*/
,'S63226D'  /*Subluxation of unspecified interphalangeal joint of right little finger, subsequent encounter*/
,'S63226S'  /*Subluxation of unspecified interphalangeal joint of right little finger, sequela*/
,'S63227D'  /*Subluxation of unspecified interphalangeal joint of left little finger, subsequent encounter*/
,'S63227S'  /*Subluxation of unspecified interphalangeal joint of left little finger, sequela*/
,'S63228D'  /*Subluxation of unspecified interphalangeal joint of other finger, subsequent encounter*/
,'S63228S'  /*Subluxation of unspecified interphalangeal joint of other finger, sequela*/
,'S63229D'  /*Subluxation of unspecified interphalangeal joint of unspecified finger, subsequent encounter*/
,'S63229S'  /*Subluxation of unspecified interphalangeal joint of unspecified finger, sequela*/
,'S63230D'  /*Subluxation of proximal interphalangeal joint of right index finger, subsequent encounter*/
,'S63230S'  /*Subluxation of proximal interphalangeal joint of right index finger, sequela*/
,'S63231D'  /*Subluxation of proximal interphalangeal joint of left index finger, subsequent encounter*/
,'S63231S'  /*Subluxation of proximal interphalangeal joint of left index finger, sequela*/
,'S63232D'  /*Subluxation of proximal interphalangeal joint of right middle finger, subsequent encounter*/
,'S63232S'  /*Subluxation of proximal interphalangeal joint of right middle finger, sequela*/
,'S63233D'  /*Subluxation of proximal interphalangeal joint of left middle finger, subsequent encounter*/
,'S63233S'  /*Subluxation of proximal interphalangeal joint of left middle finger, sequela*/
,'S63234D'  /*Subluxation of proximal interphalangeal joint of right ring finger, subsequent encounter*/
,'S63234S'  /*Subluxation of proximal interphalangeal joint of right ring finger, sequela*/
,'S63235D'  /*Subluxation of proximal interphalangeal joint of left ring finger, subsequent encounter*/
,'S63235S'  /*Subluxation of proximal interphalangeal joint of left ring finger, sequela*/
,'S63236D'  /*Subluxation of proximal interphalangeal joint of right little finger, subsequent encounter*/
,'S63236S'  /*Subluxation of proximal interphalangeal joint of right little finger, sequela*/
,'S63237D'  /*Subluxation of proximal interphalangeal joint of left little finger, subsequent encounter*/
,'S63237S'  /*Subluxation of proximal interphalangeal joint of left little finger, sequela*/
,'S63238D'  /*Subluxation of proximal interphalangeal joint of other finger, subsequent encounter*/
,'S63238S'  /*Subluxation of proximal interphalangeal joint of other finger, sequela*/
,'S63239D'  /*Subluxation of proximal interphalangeal joint of unspecified finger, subsequent encounter*/
,'S63239S'  /*Subluxation of proximal interphalangeal joint of unspecified finger, sequela*/
,'S63240D'  /*Subluxation of distal interphalangeal joint of right index finger, subsequent encounter*/
,'S63240S'  /*Subluxation of distal interphalangeal joint of right index finger, sequela*/
,'S63241D'  /*Subluxation of distal interphalangeal joint of left index finger, subsequent encounter*/
,'S63241S'  /*Subluxation of distal interphalangeal joint of left index finger, sequela*/
,'S63242D'  /*Subluxation of distal interphalangeal joint of right middle finger, subsequent encounter*/
,'S63242S'  /*Subluxation of distal interphalangeal joint of right middle finger, sequela*/
,'S63243D'  /*Subluxation of distal interphalangeal joint of left middle finger, subsequent encounter*/
,'S63243S'  /*Subluxation of distal interphalangeal joint of left middle finger, sequela*/
,'S63244D'  /*Subluxation of distal interphalangeal joint of right ring finger, subsequent encounter*/
,'S63244S'  /*Subluxation of distal interphalangeal joint of right ring finger, sequela*/
,'S63245D'  /*Subluxation of distal interphalangeal joint of left ring finger, subsequent encounter*/
,'S63245S'  /*Subluxation of distal interphalangeal joint of left ring finger, sequela*/
,'S63246D'  /*Subluxation of distal interphalangeal joint of right little finger, subsequent encounter*/
,'S63246S'  /*Subluxation of distal interphalangeal joint of right little finger, sequela*/
,'S63247D'  /*Subluxation of distal interphalangeal joint of left little finger, subsequent encounter*/
,'S63247S'  /*Subluxation of distal interphalangeal joint of left little finger, sequela*/
,'S63248D'  /*Subluxation of distal interphalangeal joint of other finger, subsequent encounter*/
,'S63248S'  /*Subluxation of distal interphalangeal joint of other finger, sequela*/
,'S63249D'  /*Subluxation of distal interphalangeal joint of unspecified finger, subsequent encounter*/
,'S63249S'  /*Subluxation of distal interphalangeal joint of unspecified finger, sequela*/
,'S63250D'  /*Unspecified dislocation of right index finger, subsequent encounter*/
,'S63250S'  /*Unspecified dislocation of right index finger, sequela*/
,'S63251D'  /*Unspecified dislocation of left index finger, subsequent encounter*/
,'S63251S'  /*Unspecified dislocation of left index finger, sequela*/
,'S63252D'  /*Unspecified dislocation of right middle finger, subsequent encounter*/
,'S63252S'  /*Unspecified dislocation of right middle finger, sequela*/
,'S63253D'  /*Unspecified dislocation of left middle finger, subsequent encounter*/
,'S63253S'  /*Unspecified dislocation of left middle finger, sequela*/
,'S63254D'  /*Unspecified dislocation of right ring finger, subsequent encounter*/
,'S63254S'  /*Unspecified dislocation of right ring finger, sequela*/
,'S63255D'  /*Unspecified dislocation of left ring finger, subsequent encounter*/
,'S63255S'  /*Unspecified dislocation of left ring finger, sequela*/
,'S63256D'  /*Unspecified dislocation of right little finger, subsequent encounter*/
,'S63256S'  /*Unspecified dislocation of right little finger, sequela*/
,'S63257D'  /*Unspecified dislocation of left little finger, subsequent encounter*/
,'S63257S'  /*Unspecified dislocation of left little finger, sequela*/
,'S63258D'  /*Unspecified dislocation of other finger, subsequent encounter*/
,'S63258S'  /*Unspecified dislocation of other finger, sequela*/
,'S63259D'  /*Unspecified dislocation of unspecified finger, subsequent encounter*/
,'S63259S'  /*Unspecified dislocation of unspecified finger, sequela*/
,'S63260D'  /*Dislocation of metacarpophalangeal joint of right index finger, subsequent encounter*/
,'S63260S'  /*Dislocation of metacarpophalangeal joint of right index finger, sequela*/
,'S63261D'  /*Dislocation of metacarpophalangeal joint of left index finger, subsequent encounter*/
,'S63261S'  /*Dislocation of metacarpophalangeal joint of left index finger, sequela*/
,'S63262D'  /*Dislocation of metacarpophalangeal joint of right middle finger, subsequent encounter*/
,'S63262S'  /*Dislocation of metacarpophalangeal joint of right middle finger, sequela*/
,'S63263D'  /*Dislocation of metacarpophalangeal joint of left middle finger, subsequent encounter*/
,'S63263S'  /*Dislocation of metacarpophalangeal joint of left middle finger, sequela*/
,'S63264D'  /*Dislocation of metacarpophalangeal joint of right ring finger, subsequent encounter*/
,'S63264S'  /*Dislocation of metacarpophalangeal joint of right ring finger, sequela*/
,'S63265D'  /*Dislocation of metacarpophalangeal joint of left ring finger, subsequent encounter*/
,'S63265S'  /*Dislocation of metacarpophalangeal joint of left ring finger, sequela*/
,'S63266D'  /*Dislocation of metacarpophalangeal joint of right little finger, subsequent encounter*/
,'S63266S'  /*Dislocation of metacarpophalangeal joint of right little finger, sequela*/
,'S63267D'  /*Dislocation of metacarpophalangeal joint of left little finger, subsequent encounter*/
,'S63267S'  /*Dislocation of metacarpophalangeal joint of left little finger, sequela*/
,'S63268D'  /*Dislocation of metacarpophalangeal joint of other finger, subsequent encounter*/
,'S63268S'  /*Dislocation of metacarpophalangeal joint of other finger, sequela*/
,'S63269D'  /*Dislocation of metacarpophalangeal joint of unspecified finger, subsequent encounter*/
,'S63269S'  /*Dislocation of metacarpophalangeal joint of unspecified finger, sequela*/
,'S63270D'  /*Dislocation of unspecified interphalangeal joint of right index finger, subsequent encounter*/
,'S63270S'  /*Dislocation of unspecified interphalangeal joint of right index finger, sequela*/
,'S63271D'  /*Dislocation of unspecified interphalangeal joint of left index finger, subsequent encounter*/
,'S63271S'  /*Dislocation of unspecified interphalangeal joint of left index finger, sequela*/
,'S63272D'  /*Dislocation of unspecified interphalangeal joint of right middle finger, subsequent encounter*/
,'S63272S'  /*Dislocation of unspecified interphalangeal joint of right middle finger, sequela*/
,'S63273D'  /*Dislocation of unspecified interphalangeal joint of left middle finger, subsequent encounter*/
,'S63273S'  /*Dislocation of unspecified interphalangeal joint of left middle finger, sequela*/
,'S63274D'  /*Dislocation of unspecified interphalangeal joint of right ring finger, subsequent encounter*/
,'S63274S'  /*Dislocation of unspecified interphalangeal joint of right ring finger, sequela*/
,'S63275D'  /*Dislocation of unspecified interphalangeal joint of left ring finger, subsequent encounter*/
,'S63275S'  /*Dislocation of unspecified interphalangeal joint of left ring finger, sequela*/
,'S63276D'  /*Dislocation of unspecified interphalangeal joint of right little finger, subsequent encounter*/
,'S63276S'  /*Dislocation of unspecified interphalangeal joint of right little finger, sequela*/
,'S63277D'  /*Dislocation of unspecified interphalangeal joint of left little finger, subsequent encounter*/
,'S63277S'  /*Dislocation of unspecified interphalangeal joint of left little finger, sequela*/
,'S63278D'  /*Dislocation of unspecified interphalangeal joint of other finger, subsequent encounter*/
,'S63278S'  /*Dislocation of unspecified interphalangeal joint of other finger, sequela*/
,'S63279D'  /*Dislocation of unspecified interphalangeal joint of unspecified finger, subsequent encounter*/
,'S63279S'  /*Dislocation of unspecified interphalangeal joint of unspecified finger, sequela*/
,'S63280D'  /*Dislocation of proximal interphalangeal joint of right index finger, subsequent encounter*/
,'S63280S'  /*Dislocation of proximal interphalangeal joint of right index finger, sequela*/
,'S63281D'  /*Dislocation of proximal interphalangeal joint of left index finger, subsequent encounter*/
,'S63281S'  /*Dislocation of proximal interphalangeal joint of left index finger, sequela*/
,'S63282D'  /*Dislocation of proximal interphalangeal joint of right middle finger, subsequent encounter*/
,'S63282S'  /*Dislocation of proximal interphalangeal joint of right middle finger, sequela*/
,'S63283D'  /*Dislocation of proximal interphalangeal joint of left middle finger, subsequent encounter*/
,'S63283S'  /*Dislocation of proximal interphalangeal joint of left middle finger, sequela*/
,'S63284D'  /*Dislocation of proximal interphalangeal joint of right ring finger, subsequent encounter*/
,'S63284S'  /*Dislocation of proximal interphalangeal joint of right ring finger, sequela*/
,'S63285D'  /*Dislocation of proximal interphalangeal joint of left ring finger, subsequent encounter*/
,'S63285S'  /*Dislocation of proximal interphalangeal joint of left ring finger, sequela*/
,'S63286D'  /*Dislocation of proximal interphalangeal joint of right little finger, subsequent encounter*/
,'S63286S'  /*Dislocation of proximal interphalangeal joint of right little finger, sequela*/
,'S63287D'  /*Dislocation of proximal interphalangeal joint of left little finger, subsequent encounter*/
,'S63287S'  /*Dislocation of proximal interphalangeal joint of left little finger, sequela*/
,'S63288D'  /*Dislocation of proximal interphalangeal joint of other finger, subsequent encounter*/
,'S63288S'  /*Dislocation of proximal interphalangeal joint of other finger, sequela*/
,'S63289D'  /*Dislocation of proximal interphalangeal joint of unspecified finger, subsequent encounter*/
,'S63289S'  /*Dislocation of proximal interphalangeal joint of unspecified finger, sequela*/
,'S63290D'  /*Dislocation of distal interphalangeal joint of right index finger, subsequent encounter*/
,'S63290S'  /*Dislocation of distal interphalangeal joint of right index finger, sequela*/
,'S63291D'  /*Dislocation of distal interphalangeal joint of left index finger, subsequent encounter*/
,'S63291S'  /*Dislocation of distal interphalangeal joint of left index finger, sequela*/
,'S63292D'  /*Dislocation of distal interphalangeal joint of right middle finger, subsequent encounter*/
,'S63292S'  /*Dislocation of distal interphalangeal joint of right middle finger, sequela*/
,'S63293D'  /*Dislocation of distal interphalangeal joint of left middle finger, subsequent encounter*/
,'S63293S'  /*Dislocation of distal interphalangeal joint of left middle finger, sequela*/
,'S63294D'  /*Dislocation of distal interphalangeal joint of right ring finger, subsequent encounter*/
,'S63294S'  /*Dislocation of distal interphalangeal joint of right ring finger, sequela*/
,'S63295D'  /*Dislocation of distal interphalangeal joint of left ring finger, subsequent encounter*/
,'S63295S'  /*Dislocation of distal interphalangeal joint of left ring finger, sequela*/
,'S63296D'  /*Dislocation of distal interphalangeal joint of right little finger, subsequent encounter*/
,'S63296S'  /*Dislocation of distal interphalangeal joint of right little finger, sequela*/
,'S63297D'  /*Dislocation of distal interphalangeal joint of left little finger, subsequent encounter*/
,'S63297S'  /*Dislocation of distal interphalangeal joint of left little finger, sequela*/
,'S63298D'  /*Dislocation of distal interphalangeal joint of other finger, subsequent encounter*/
,'S63298S'  /*Dislocation of distal interphalangeal joint of other finger, sequela*/
,'S63299D'  /*Dislocation of distal interphalangeal joint of unspecified finger, subsequent encounter*/
,'S63299S'  /*Dislocation of distal interphalangeal joint of unspecified finger, sequela*/
,'S63301D'  /*Traumatic rupture of unspecified ligament of right wrist, subsequent encounter*/
,'S63301S'  /*Traumatic rupture of unspecified ligament of right wrist, sequela*/
,'S63302D'  /*Traumatic rupture of unspecified ligament of left wrist, subsequent encounter*/
,'S63302S'  /*Traumatic rupture of unspecified ligament of left wrist, sequela*/
,'S63309D'  /*Traumatic rupture of unspecified ligament of unspecified wrist, subsequent encounter*/
,'S63309S'  /*Traumatic rupture of unspecified ligament of unspecified wrist, sequela*/
,'S63311D'  /*Traumatic rupture of collateral ligament of right wrist, subsequent encounter*/
,'S63311S'  /*Traumatic rupture of collateral ligament of right wrist, sequela*/
,'S63312D'  /*Traumatic rupture of collateral ligament of left wrist, subsequent encounter*/
,'S63312S'  /*Traumatic rupture of collateral ligament of left wrist, sequela*/
,'S63319D'  /*Traumatic rupture of collateral ligament of unspecified wrist, subsequent encounter*/
,'S63319S'  /*Traumatic rupture of collateral ligament of unspecified wrist, sequela*/
,'S63321D'  /*Traumatic rupture of right radiocarpal ligament, subsequent encounter*/
,'S63321S'  /*Traumatic rupture of right radiocarpal ligament, sequela*/
,'S63322D'  /*Traumatic rupture of left radiocarpal ligament, subsequent encounter*/
,'S63322S'  /*Traumatic rupture of left radiocarpal ligament, sequela*/
,'S63329D'  /*Traumatic rupture of unspecified radiocarpal ligament, subsequent encounter*/
,'S63329S'  /*Traumatic rupture of unspecified radiocarpal ligament, sequela*/
,'S63331D'  /*Traumatic rupture of right ulnocarpal (palmar) ligament, subsequent encounter*/
,'S63331S'  /*Traumatic rupture of right ulnocarpal (palmar) ligament, sequela*/
,'S63332D'  /*Traumatic rupture of left ulnocarpal (palmar) ligament, subsequent encounter*/
,'S63332S'  /*Traumatic rupture of left ulnocarpal (palmar) ligament, sequela*/
,'S63339D'  /*Traumatic rupture of unspecified ulnocarpal (palmar) ligament, subsequent encounter*/
,'S63339S'  /*Traumatic rupture of unspecified ulnocarpal (palmar) ligament, sequela*/
,'S63391D'  /*Traumatic rupture of other ligament of right wrist, subsequent encounter*/
,'S63391S'  /*Traumatic rupture of other ligament of right wrist, sequela*/
,'S63392D'  /*Traumatic rupture of other ligament of left wrist, subsequent encounter*/
,'S63392S'  /*Traumatic rupture of other ligament of left wrist, sequela*/
,'S63399D'  /*Traumatic rupture of other ligament of unspecified wrist, subsequent encounter*/
,'S63399S'  /*Traumatic rupture of other ligament of unspecified wrist, sequela*/
,'S63400D'  /*Traumatic rupture of unspecified ligament of right index finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63400S'  /*Traumatic rupture of unspecified ligament of right index finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63401D'  /*Traumatic rupture of unspecified ligament of left index finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63401S'  /*Traumatic rupture of unspecified ligament of left index finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63402D'  /*Traumatic rupture of unspecified ligament of right middle finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63402S'  /*Traumatic rupture of unspecified ligament of right middle finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63403D'  /*Traumatic rupture of unspecified ligament of left middle finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63403S'  /*Traumatic rupture of unspecified ligament of left middle finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63404D'  /*Traumatic rupture of unspecified ligament of right ring finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63404S'  /*Traumatic rupture of unspecified ligament of right ring finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63405D'  /*Traumatic rupture of unspecified ligament of left ring finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63405S'  /*Traumatic rupture of unspecified ligament of left ring finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63406D'  /*Traumatic rupture of unspecified ligament of right little finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63406S'  /*Traumatic rupture of unspecified ligament of right little finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63407D'  /*Traumatic rupture of unspecified ligament of left little finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63407S'  /*Traumatic rupture of unspecified ligament of left little finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63408D'  /*Traumatic rupture of unspecified ligament of other finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63408S'  /*Traumatic rupture of unspecified ligament of other finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63409D'  /*Traumatic rupture of unspecified ligament of unspecified finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63409S'  /*Traumatic rupture of unspecified ligament of unspecified finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63410D'  /*Traumatic rupture of collateral ligament of right index finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63410S'  /*Traumatic rupture of collateral ligament of right index finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63411D'  /*Traumatic rupture of collateral ligament of left index finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63411S'  /*Traumatic rupture of collateral ligament of left index finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63412D'  /*Traumatic rupture of collateral ligament of right middle finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63412S'  /*Traumatic rupture of collateral ligament of right middle finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63413D'  /*Traumatic rupture of collateral ligament of left middle finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63413S'  /*Traumatic rupture of collateral ligament of left middle finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63414D'  /*Traumatic rupture of collateral ligament of right ring finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63414S'  /*Traumatic rupture of collateral ligament of right ring finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63415D'  /*Traumatic rupture of collateral ligament of left ring finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63415S'  /*Traumatic rupture of collateral ligament of left ring finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63416D'  /*Traumatic rupture of collateral ligament of right little finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63416S'  /*Traumatic rupture of collateral ligament of right little finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63417D'  /*Traumatic rupture of collateral ligament of left little finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63417S'  /*Traumatic rupture of collateral ligament of left little finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63418D'  /*Traumatic rupture of collateral ligament of other finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63418S'  /*Traumatic rupture of collateral ligament of other finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63419D'  /*Traumatic rupture of collateral ligament of unspecified finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63419S'  /*Traumatic rupture of collateral ligament of unspecified finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63420D'  /*Traumatic rupture of palmar ligament of right index finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63420S'  /*Traumatic rupture of palmar ligament of right index finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63421D'  /*Traumatic rupture of palmar ligament of left index finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63421S'  /*Traumatic rupture of palmar ligament of left index finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63422D'  /*Traumatic rupture of palmar ligament of right middle finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63422S'  /*Traumatic rupture of palmar ligament of right middle finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63423D'  /*Traumatic rupture of palmar ligament of left middle finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63423S'  /*Traumatic rupture of palmar ligament of left middle finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63424D'  /*Traumatic rupture of palmar ligament of right ring finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63424S'  /*Traumatic rupture of palmar ligament of right ring finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63425D'  /*Traumatic rupture of palmar ligament of left ring finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63425S'  /*Traumatic rupture of palmar ligament of left ring finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63426D'  /*Traumatic rupture of palmar ligament of right little finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63426S'  /*Traumatic rupture of palmar ligament of right little finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63427D'  /*Traumatic rupture of palmar ligament of left little finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63427S'  /*Traumatic rupture of palmar ligament of left little finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63428D'  /*Traumatic rupture of palmar ligament of other finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63428S'  /*Traumatic rupture of palmar ligament of other finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63429D'  /*Traumatic rupture of palmar ligament of unspecified finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63429S'  /*Traumatic rupture of palmar ligament of unspecified finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63430D'  /*Traumatic rupture of volar plate of right index finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63430S'  /*Traumatic rupture of volar plate of right index finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63431D'  /*Traumatic rupture of volar plate of left index finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63431S'  /*Traumatic rupture of volar plate of left index finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63432D'  /*Traumatic rupture of volar plate of right middle finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63432S'  /*Traumatic rupture of volar plate of right middle finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63433D'  /*Traumatic rupture of volar plate of left middle finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63433S'  /*Traumatic rupture of volar plate of left middle finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63434D'  /*Traumatic rupture of volar plate of right ring finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63434S'  /*Traumatic rupture of volar plate of right ring finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63435D'  /*Traumatic rupture of volar plate of left ring finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63435S'  /*Traumatic rupture of volar plate of left ring finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63436D'  /*Traumatic rupture of volar plate of right little finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63436S'  /*Traumatic rupture of volar plate of right little finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63437D'  /*Traumatic rupture of volar plate of left little finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63437S'  /*Traumatic rupture of volar plate of left little finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63438D'  /*Traumatic rupture of volar plate of other finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63438S'  /*Traumatic rupture of volar plate of other finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63439D'  /*Traumatic rupture of volar plate of unspecified finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63439S'  /*Traumatic rupture of volar plate of unspecified finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63490D'  /*Traumatic rupture of other ligament of right index finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63490S'  /*Traumatic rupture of other ligament of right index finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63491D'  /*Traumatic rupture of other ligament of left index finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63491S'  /*Traumatic rupture of other ligament of left index finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63492D'  /*Traumatic rupture of other ligament of right middle finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63492S'  /*Traumatic rupture of other ligament of right middle finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63493D'  /*Traumatic rupture of other ligament of left middle finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63493S'  /*Traumatic rupture of other ligament of left middle finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63494D'  /*Traumatic rupture of other ligament of right ring finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63494S'  /*Traumatic rupture of other ligament of right ring finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63495D'  /*Traumatic rupture of other ligament of left ring finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63495S'  /*Traumatic rupture of other ligament of left ring finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63496D'  /*Traumatic rupture of other ligament of right little finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63496S'  /*Traumatic rupture of other ligament of right little finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63497D'  /*Traumatic rupture of other ligament of left little finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63497S'  /*Traumatic rupture of other ligament of left little finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63498D'  /*Traumatic rupture of other ligament of other finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63498S'  /*Traumatic rupture of other ligament of other finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63499D'  /*Traumatic rupture of other ligament of unspecified finger at metacarpophalangeal and interphalangeal joint, subsequent encounter*/
,'S63499S'  /*Traumatic rupture of other ligament of unspecified finger at metacarpophalangeal and interphalangeal joint, sequela*/
,'S63501D'  /*Unspecified sprain of right wrist, subsequent encounter*/
,'S63501S'  /*Unspecified sprain of right wrist, sequela*/
,'S63502D'  /*Unspecified sprain of left wrist, subsequent encounter*/
,'S63502S'  /*Unspecified sprain of left wrist, sequela*/
,'S63509D'  /*Unspecified sprain of unspecified wrist, subsequent encounter*/
,'S63509S'  /*Unspecified sprain of unspecified wrist, sequela*/
,'S63511D'  /*Sprain of carpal joint of right wrist, subsequent encounter*/
,'S63511S'  /*Sprain of carpal joint of right wrist, sequela*/
,'S63512D'  /*Sprain of carpal joint of left wrist, subsequent encounter*/
,'S63512S'  /*Sprain of carpal joint of left wrist, sequela*/
,'S63519D'  /*Sprain of carpal joint of unspecified wrist, subsequent encounter*/
,'S63519S'  /*Sprain of carpal joint of unspecified wrist, sequela*/
,'S63521D'  /*Sprain of radiocarpal joint of right wrist, subsequent encounter*/
,'S63521S'  /*Sprain of radiocarpal joint of right wrist, sequela*/
,'S63522D'  /*Sprain of radiocarpal joint of left wrist, subsequent encounter*/
,'S63522S'  /*Sprain of radiocarpal joint of left wrist, sequela*/
,'S63529D'  /*Sprain of radiocarpal joint of unspecified wrist, subsequent encounter*/
,'S63529S'  /*Sprain of radiocarpal joint of unspecified wrist, sequela*/
,'S63591D'  /*Other specified sprain of right wrist, subsequent encounter*/
,'S63591S'  /*Other specified sprain of right wrist, sequela*/
,'S63592D'  /*Other specified sprain of left wrist, subsequent encounter*/
,'S63592S'  /*Other specified sprain of left wrist, sequela*/
,'S63599D'  /*Other specified sprain of unspecified wrist, subsequent encounter*/
,'S63599S'  /*Other specified sprain of unspecified wrist, sequela*/
,'S63601D'  /*Unspecified sprain of right thumb, subsequent encounter*/
,'S63601S'  /*Unspecified sprain of right thumb, sequela*/
,'S63602D'  /*Unspecified sprain of left thumb, subsequent encounter*/
,'S63602S'  /*Unspecified sprain of left thumb, sequela*/
,'S63609D'  /*Unspecified sprain of unspecified thumb, subsequent encounter*/
,'S63609S'  /*Unspecified sprain of unspecified thumb, sequela*/
,'S63610D'  /*Unspecified sprain of right index finger, subsequent encounter*/
,'S63610S'  /*Unspecified sprain of right index finger, sequela*/
,'S63611D'  /*Unspecified sprain of left index finger, subsequent encounter*/
,'S63611S'  /*Unspecified sprain of left index finger, sequela*/
,'S63612D'  /*Unspecified sprain of right middle finger, subsequent encounter*/
,'S63612S'  /*Unspecified sprain of right middle finger, sequela*/
,'S63613D'  /*Unspecified sprain of left middle finger, subsequent encounter*/
,'S63613S'  /*Unspecified sprain of left middle finger, sequela*/
,'S63614D'  /*Unspecified sprain of right ring finger, subsequent encounter*/
,'S63614S'  /*Unspecified sprain of right ring finger, sequela*/
,'S63615D'  /*Unspecified sprain of left ring finger, subsequent encounter*/
,'S63615S'  /*Unspecified sprain of left ring finger, sequela*/
,'S63616D'  /*Unspecified sprain of right little finger, subsequent encounter*/
,'S63616S'  /*Unspecified sprain of right little finger, sequela*/
,'S63617D'  /*Unspecified sprain of left little finger, subsequent encounter*/
,'S63617S'  /*Unspecified sprain of left little finger, sequela*/
,'S63618D'  /*Unspecified sprain of other finger, subsequent encounter*/
,'S63618S'  /*Unspecified sprain of other finger, sequela*/
,'S63619D'  /*Unspecified sprain of unspecified finger, subsequent encounter*/
,'S63619S'  /*Unspecified sprain of unspecified finger, sequela*/
,'S63621D'  /*Sprain of interphalangeal joint of right thumb, subsequent encounter*/
,'S63621S'  /*Sprain of interphalangeal joint of right thumb, sequela*/
,'S63622D'  /*Sprain of interphalangeal joint of left thumb, subsequent encounter*/
,'S63622S'  /*Sprain of interphalangeal joint of left thumb, sequela*/
,'S63629D'  /*Sprain of interphalangeal joint of unspecified thumb, subsequent encounter*/
,'S63629S'  /*Sprain of interphalangeal joint of unspecified thumb, sequela*/
,'S63630D'  /*Sprain of interphalangeal joint of right index finger, subsequent encounter*/
,'S63630S'  /*Sprain of interphalangeal joint of right index finger, sequela*/
,'S63631D'  /*Sprain of interphalangeal joint of left index finger, subsequent encounter*/
,'S63631S'  /*Sprain of interphalangeal joint of left index finger, sequela*/
,'S63632D'  /*Sprain of interphalangeal joint of right middle finger, subsequent encounter*/
,'S63632S'  /*Sprain of interphalangeal joint of right middle finger, sequela*/
,'S63633D'  /*Sprain of interphalangeal joint of left middle finger, subsequent encounter*/
,'S63633S'  /*Sprain of interphalangeal joint of left middle finger, sequela*/
,'S63634D'  /*Sprain of interphalangeal joint of right ring finger, subsequent encounter*/
,'S63634S'  /*Sprain of interphalangeal joint of right ring finger, sequela*/
,'S63635D'  /*Sprain of interphalangeal joint of left ring finger, subsequent encounter*/
,'S63635S'  /*Sprain of interphalangeal joint of left ring finger, sequela*/
,'S63636D'  /*Sprain of interphalangeal joint of right little finger, subsequent encounter*/
,'S63636S'  /*Sprain of interphalangeal joint of right little finger, sequela*/
,'S63637D'  /*Sprain of interphalangeal joint of left little finger, subsequent encounter*/
,'S63637S'  /*Sprain of interphalangeal joint of left little finger, sequela*/
,'S63638D'  /*Sprain of interphalangeal joint of other finger, subsequent encounter*/
,'S63638S'  /*Sprain of interphalangeal joint of other finger, sequela*/
,'S63639D'  /*Sprain of interphalangeal joint of unspecified finger, subsequent encounter*/
,'S63639S'  /*Sprain of interphalangeal joint of unspecified finger, sequela*/
,'S63641D'  /*Sprain of metacarpophalangeal joint of right thumb, subsequent encounter*/
,'S63641S'  /*Sprain of metacarpophalangeal joint of right thumb, sequela*/
,'S63642D'  /*Sprain of metacarpophalangeal joint of left thumb, subsequent encounter*/
,'S63642S'  /*Sprain of metacarpophalangeal joint of left thumb, sequela*/
,'S63649D'  /*Sprain of metacarpophalangeal joint of unspecified thumb, subsequent encounter*/
,'S63649S'  /*Sprain of metacarpophalangeal joint of unspecified thumb, sequela*/
,'S63650D'  /*Sprain of metacarpophalangeal joint of right index finger, subsequent encounter*/
,'S63650S'  /*Sprain of metacarpophalangeal joint of right index finger, sequela*/
,'S63651D'  /*Sprain of metacarpophalangeal joint of left index finger, subsequent encounter*/
,'S63651S'  /*Sprain of metacarpophalangeal joint of left index finger, sequela*/
,'S63652D'  /*Sprain of metacarpophalangeal joint of right middle finger, subsequent encounter*/
,'S63652S'  /*Sprain of metacarpophalangeal joint of right middle finger, sequela*/
,'S63653D'  /*Sprain of metacarpophalangeal joint of left middle finger, subsequent encounter*/
,'S63653S'  /*Sprain of metacarpophalangeal joint of left middle finger, sequela*/
,'S63654D'  /*Sprain of metacarpophalangeal joint of right ring finger, subsequent encounter*/
,'S63654S'  /*Sprain of metacarpophalangeal joint of right ring finger, sequela*/
,'S63655D'  /*Sprain of metacarpophalangeal joint of left ring finger, subsequent encounter*/
,'S63655S'  /*Sprain of metacarpophalangeal joint of left ring finger, sequela*/
,'S63656D'  /*Sprain of metacarpophalangeal joint of right little finger, subsequent encounter*/
,'S63656S'  /*Sprain of metacarpophalangeal joint of right little finger, sequela*/
,'S63657D'  /*Sprain of metacarpophalangeal joint of left little finger, subsequent encounter*/
,'S63657S'  /*Sprain of metacarpophalangeal joint of left little finger, sequela*/
,'S63658D'  /*Sprain of metacarpophalangeal joint of other finger, subsequent encounter*/
,'S63658S'  /*Sprain of metacarpophalangeal joint of other finger, sequela*/
,'S63659D'  /*Sprain of metacarpophalangeal joint of unspecified finger, subsequent encounter*/
,'S63659S'  /*Sprain of metacarpophalangeal joint of unspecified finger, sequela*/
,'S63681D'  /*Other sprain of right thumb, subsequent encounter*/
,'S63681S'  /*Other sprain of right thumb, sequela*/
,'S63682D'  /*Other sprain of left thumb, subsequent encounter*/
,'S63682S'  /*Other sprain of left thumb, sequela*/
,'S63689D'  /*Other sprain of unspecified thumb, subsequent encounter*/
,'S63689S'  /*Other sprain of unspecified thumb, sequela*/
,'S63690D'  /*Other sprain of right index finger, subsequent encounter*/
,'S63690S'  /*Other sprain of right index finger, sequela*/
,'S63691D'  /*Other sprain of left index finger, subsequent encounter*/
,'S63691S'  /*Other sprain of left index finger, sequela*/
,'S63692D'  /*Other sprain of right middle finger, subsequent encounter*/
,'S63692S'  /*Other sprain of right middle finger, sequela*/
,'S63693D'  /*Other sprain of left middle finger, subsequent encounter*/
,'S63693S'  /*Other sprain of left middle finger, sequela*/
,'S63694D'  /*Other sprain of right ring finger, subsequent encounter*/
,'S63694S'  /*Other sprain of right ring finger, sequela*/
,'S63695D'  /*Other sprain of left ring finger, subsequent encounter*/
,'S63695S'  /*Other sprain of left ring finger, sequela*/
,'S63696D'  /*Other sprain of right little finger, subsequent encounter*/
,'S63696S'  /*Other sprain of right little finger, sequela*/
,'S63697D'  /*Other sprain of left little finger, subsequent encounter*/
,'S63697S'  /*Other sprain of left little finger, sequela*/
,'S63698D'  /*Other sprain of other finger, subsequent encounter*/
,'S63698S'  /*Other sprain of other finger, sequela*/
,'S63699D'  /*Other sprain of unspecified finger, subsequent encounter*/
,'S63699S'  /*Other sprain of unspecified finger, sequela*/
,'S638X1D'  /*Sprain of other part of right wrist and hand, subsequent encounter*/
,'S638X1S'  /*Sprain of other part of right wrist and hand, sequela*/
,'S638X2D'  /*Sprain of other part of left wrist and hand, subsequent encounter*/
,'S638X2S'  /*Sprain of other part of left wrist and hand, sequela*/
,'S638X9D'  /*Sprain of other part of unspecified wrist and hand, subsequent encounter*/
,'S638X9S'  /*Sprain of other part of unspecified wrist and hand, sequela*/
,'S6390XD'  /*Sprain of unspecified part of unspecified wrist and hand, subsequent encounter*/
,'S6390XS'  /*Sprain of unspecified part of unspecified wrist and hand, sequela*/
,'S6391XD'  /*Sprain of unspecified part of right wrist and hand, subsequent encounter*/
,'S6391XS'  /*Sprain of unspecified part of right wrist and hand, sequela*/
,'S6392XD'  /*Sprain of unspecified part of left wrist and hand, subsequent encounter*/
,'S6392XS'  /*Sprain of unspecified part of left wrist and hand, sequela*/
,'S6400XD'  /*Injury of ulnar nerve at wrist and hand level of unspecified arm, subsequent encounter*/
,'S6400XS'  /*Injury of ulnar nerve at wrist and hand level of unspecified arm, sequela*/
,'S6401XD'  /*Injury of ulnar nerve at wrist and hand level of right arm, subsequent encounter*/
,'S6401XS'  /*Injury of ulnar nerve at wrist and hand level of right arm, sequela*/
,'S6402XD'  /*Injury of ulnar nerve at wrist and hand level of left arm, subsequent encounter*/
,'S6402XS'  /*Injury of ulnar nerve at wrist and hand level of left arm, sequela*/
,'S6410XD'  /*Injury of median nerve at wrist and hand level of unspecified arm, subsequent encounter*/
,'S6410XS'  /*Injury of median nerve at wrist and hand level of unspecified arm, sequela*/
,'S6411XD'  /*Injury of median nerve at wrist and hand level of right arm, subsequent encounter*/
,'S6411XS'  /*Injury of median nerve at wrist and hand level of right arm, sequela*/
,'S6412XD'  /*Injury of median nerve at wrist and hand level of left arm, subsequent encounter*/
,'S6412XS'  /*Injury of median nerve at wrist and hand level of left arm, sequela*/
,'S6420XD'  /*Injury of radial nerve at wrist and hand level of unspecified arm, subsequent encounter*/
,'S6420XS'  /*Injury of radial nerve at wrist and hand level of unspecified arm, sequela*/
,'S6421XD'  /*Injury of radial nerve at wrist and hand level of right arm, subsequent encounter*/
,'S6421XS'  /*Injury of radial nerve at wrist and hand level of right arm, sequela*/
,'S6422XD'  /*Injury of radial nerve at wrist and hand level of left arm, subsequent encounter*/
,'S6422XS'  /*Injury of radial nerve at wrist and hand level of left arm, sequela*/
,'S6430XD'  /*Injury of digital nerve of unspecified thumb, subsequent encounter*/
,'S6430XS'  /*Injury of digital nerve of unspecified thumb, sequela*/
,'S6431XD'  /*Injury of digital nerve of right thumb, subsequent encounter*/
,'S6431XS'  /*Injury of digital nerve of right thumb, sequela*/
,'S6432XD'  /*Injury of digital nerve of left thumb, subsequent encounter*/
,'S6432XS'  /*Injury of digital nerve of left thumb, sequela*/
,'S6440XD'  /*Injury of digital nerve of unspecified finger, subsequent encounter*/
,'S6440XS'  /*Injury of digital nerve of unspecified finger, sequela*/
,'S64490D'  /*Injury of digital nerve of right index finger, subsequent encounter*/
,'S64490S'  /*Injury of digital nerve of right index finger, sequela*/
,'S64491D'  /*Injury of digital nerve of left index finger, subsequent encounter*/
,'S64491S'  /*Injury of digital nerve of left index finger, sequela*/
,'S64492D'  /*Injury of digital nerve of right middle finger, subsequent encounter*/
,'S64492S'  /*Injury of digital nerve of right middle finger, sequela*/
,'S64493D'  /*Injury of digital nerve of left middle finger, subsequent encounter*/
,'S64493S'  /*Injury of digital nerve of left middle finger, sequela*/
,'S64494D'  /*Injury of digital nerve of right ring finger, subsequent encounter*/
,'S64494S'  /*Injury of digital nerve of right ring finger, sequela*/
,'S64495D'  /*Injury of digital nerve of left ring finger, subsequent encounter*/
,'S64495S'  /*Injury of digital nerve of left ring finger, sequela*/
,'S64496D'  /*Injury of digital nerve of right little finger, subsequent encounter*/
,'S64496S'  /*Injury of digital nerve of right little finger, sequela*/
,'S64497D'  /*Injury of digital nerve of left little finger, subsequent encounter*/
,'S64497S'  /*Injury of digital nerve of left little finger, sequela*/
,'S64498D'  /*Injury of digital nerve of other finger, subsequent encounter*/
,'S64498S'  /*Injury of digital nerve of other finger, sequela*/
,'S648X1D'  /*Injury of other nerves at wrist and hand level of right arm, subsequent encounter*/
,'S648X1S'  /*Injury of other nerves at wrist and hand level of right arm, sequela*/
,'S648X2D'  /*Injury of other nerves at wrist and hand level of left arm, subsequent encounter*/
,'S648X2S'  /*Injury of other nerves at wrist and hand level of left arm, sequela*/
,'S648X9D'  /*Injury of other nerves at wrist and hand level of unspecified arm, subsequent encounter*/
,'S648X9S'  /*Injury of other nerves at wrist and hand level of unspecified arm, sequela*/
,'S6490XD'  /*Injury of unspecified nerve at wrist and hand level of unspecified arm, subsequent encounter*/
,'S6490XS'  /*Injury of unspecified nerve at wrist and hand level of unspecified arm, sequela*/
,'S6491XD'  /*Injury of unspecified nerve at wrist and hand level of right arm, subsequent encounter*/
,'S6491XS'  /*Injury of unspecified nerve at wrist and hand level of right arm, sequela*/
,'S6492XD'  /*Injury of unspecified nerve at wrist and hand level of left arm, subsequent encounter*/
,'S6492XS'  /*Injury of unspecified nerve at wrist and hand level of left arm, sequela*/
,'S65001D'  /*Unspecified injury of ulnar artery at wrist and hand level of right arm, subsequent encounter*/
,'S65001S'  /*Unspecified injury of ulnar artery at wrist and hand level of right arm, sequela*/
,'S65002D'  /*Unspecified injury of ulnar artery at wrist and hand level of left arm, subsequent encounter*/
,'S65002S'  /*Unspecified injury of ulnar artery at wrist and hand level of left arm, sequela*/
,'S65009D'  /*Unspecified injury of ulnar artery at wrist and hand level of unspecified arm, subsequent encounter*/
,'S65009S'  /*Unspecified injury of ulnar artery at wrist and hand level of unspecified arm, sequela*/
,'S65011D'  /*Laceration of ulnar artery at wrist and hand level of right arm, subsequent encounter*/
,'S65011S'  /*Laceration of ulnar artery at wrist and hand level of right arm, sequela*/
,'S65012D'  /*Laceration of ulnar artery at wrist and hand level of left arm, subsequent encounter*/
,'S65012S'  /*Laceration of ulnar artery at wrist and hand level of left arm, sequela*/
,'S65019D'  /*Laceration of ulnar artery at wrist and hand level of unspecified arm, subsequent encounter*/
,'S65019S'  /*Laceration of ulnar artery at wrist and hand level of unspecified arm, sequela*/
,'S65091D'  /*Other specified injury of ulnar artery at wrist and hand level of right arm, subsequent encounter*/
,'S65091S'  /*Other specified injury of ulnar artery at wrist and hand level of right arm, sequela*/
,'S65092D'  /*Other specified injury of ulnar artery at wrist and hand level of left arm, subsequent encounter*/
,'S65092S'  /*Other specified injury of ulnar artery at wrist and hand level of left arm, sequela*/
,'S65099D'  /*Other specified injury of ulnar artery at wrist and hand level of unspecified arm, subsequent encounter*/
,'S65099S'  /*Other specified injury of ulnar artery at wrist and hand level of unspecified arm, sequela*/
,'S65101D'  /*Unspecified injury of radial artery at wrist and hand level of right arm, subsequent encounter*/
,'S65101S'  /*Unspecified injury of radial artery at wrist and hand level of right arm, sequela*/
,'S65102D'  /*Unspecified injury of radial artery at wrist and hand level of left arm, subsequent encounter*/
,'S65102S'  /*Unspecified injury of radial artery at wrist and hand level of left arm, sequela*/
,'S65109D'  /*Unspecified injury of radial artery at wrist and hand level of unspecified arm, subsequent encounter*/
,'S65109S'  /*Unspecified injury of radial artery at wrist and hand level of unspecified arm, sequela*/
,'S65111D'  /*Laceration of radial artery at wrist and hand level of right arm, subsequent encounter*/
,'S65111S'  /*Laceration of radial artery at wrist and hand level of right arm, sequela*/
,'S65112D'  /*Laceration of radial artery at wrist and hand level of left arm, subsequent encounter*/
,'S65112S'  /*Laceration of radial artery at wrist and hand level of left arm, sequela*/
,'S65119D'  /*Laceration of radial artery at wrist and hand level of unspecified arm, subsequent encounter*/
,'S65119S'  /*Laceration of radial artery at wrist and hand level of unspecified arm, sequela*/
,'S65191D'  /*Other specified injury of radial artery at wrist and hand level of right arm, subsequent encounter*/
,'S65191S'  /*Other specified injury of radial artery at wrist and hand level of right arm, sequela*/
,'S65192D'  /*Other specified injury of radial artery at wrist and hand level of left arm, subsequent encounter*/
,'S65192S'  /*Other specified injury of radial artery at wrist and hand level of left arm, sequela*/
,'S65199D'  /*Other specified injury of radial artery at wrist and hand level of unspecified arm, subsequent encounter*/
,'S65199S'  /*Other specified injury of radial artery at wrist and hand level of unspecified arm, sequela*/
,'S65201D'  /*Unspecified injury of superficial palmar arch of right hand, subsequent encounter*/
,'S65201S'  /*Unspecified injury of superficial palmar arch of right hand, sequela*/
,'S65202D'  /*Unspecified injury of superficial palmar arch of left hand, subsequent encounter*/
,'S65202S'  /*Unspecified injury of superficial palmar arch of left hand, sequela*/
,'S65209D'  /*Unspecified injury of superficial palmar arch of unspecified hand, subsequent encounter*/
,'S65209S'  /*Unspecified injury of superficial palmar arch of unspecified hand, sequela*/
,'S65211D'  /*Laceration of superficial palmar arch of right hand, subsequent encounter*/
,'S65211S'  /*Laceration of superficial palmar arch of right hand, sequela*/
,'S65212D'  /*Laceration of superficial palmar arch of left hand, subsequent encounter*/
,'S65212S'  /*Laceration of superficial palmar arch of left hand, sequela*/
,'S65219D'  /*Laceration of superficial palmar arch of unspecified hand, subsequent encounter*/
,'S65219S'  /*Laceration of superficial palmar arch of unspecified hand, sequela*/
,'S65291D'  /*Other specified injury of superficial palmar arch of right hand, subsequent encounter*/
,'S65291S'  /*Other specified injury of superficial palmar arch of right hand, sequela*/
,'S65292D'  /*Other specified injury of superficial palmar arch of left hand, subsequent encounter*/
,'S65292S'  /*Other specified injury of superficial palmar arch of left hand, sequela*/
,'S65299D'  /*Other specified injury of superficial palmar arch of unspecified hand, subsequent encounter*/
,'S65299S'  /*Other specified injury of superficial palmar arch of unspecified hand, sequela*/
,'S65301D'  /*Unspecified injury of deep palmar arch of right hand, subsequent encounter*/
,'S65301S'  /*Unspecified injury of deep palmar arch of right hand, sequela*/
,'S65302D'  /*Unspecified injury of deep palmar arch of left hand, subsequent encounter*/
,'S65302S'  /*Unspecified injury of deep palmar arch of left hand, sequela*/
,'S65309D'  /*Unspecified injury of deep palmar arch of unspecified hand, subsequent encounter*/
,'S65309S'  /*Unspecified injury of deep palmar arch of unspecified hand, sequela*/
,'S65311D'  /*Laceration of deep palmar arch of right hand, subsequent encounter*/
,'S65311S'  /*Laceration of deep palmar arch of right hand, sequela*/
,'S65312D'  /*Laceration of deep palmar arch of left hand, subsequent encounter*/
,'S65312S'  /*Laceration of deep palmar arch of left hand, sequela*/
,'S65319D'  /*Laceration of deep palmar arch of unspecified hand, subsequent encounter*/
,'S65319S'  /*Laceration of deep palmar arch of unspecified hand, sequela*/
,'S65391D'  /*Other specified injury of deep palmar arch of right hand, subsequent encounter*/
,'S65391S'  /*Other specified injury of deep palmar arch of right hand, sequela*/
,'S65392D'  /*Other specified injury of deep palmar arch of left hand, subsequent encounter*/
,'S65392S'  /*Other specified injury of deep palmar arch of left hand, sequela*/
,'S65399D'  /*Other specified injury of deep palmar arch of unspecified hand, subsequent encounter*/
,'S65399S'  /*Other specified injury of deep palmar arch of unspecified hand, sequela*/
,'S65401D'  /*Unspecified injury of blood vessel of right thumb, subsequent encounter*/
,'S65401S'  /*Unspecified injury of blood vessel of right thumb, sequela*/
,'S65402D'  /*Unspecified injury of blood vessel of left thumb, subsequent encounter*/
,'S65402S'  /*Unspecified injury of blood vessel of left thumb, sequela*/
,'S65409D'  /*Unspecified injury of blood vessel of unspecified thumb, subsequent encounter*/
,'S65409S'  /*Unspecified injury of blood vessel of unspecified thumb, sequela*/
,'S65411D'  /*Laceration of blood vessel of right thumb, subsequent encounter*/
,'S65411S'  /*Laceration of blood vessel of right thumb, sequela*/
,'S65412D'  /*Laceration of blood vessel of left thumb, subsequent encounter*/
,'S65412S'  /*Laceration of blood vessel of left thumb, sequela*/
,'S65419D'  /*Laceration of blood vessel of unspecified thumb, subsequent encounter*/
,'S65419S'  /*Laceration of blood vessel of unspecified thumb, sequela*/
,'S65491D'  /*Other specified injury of blood vessel of right thumb, subsequent encounter*/
,'S65491S'  /*Other specified injury of blood vessel of right thumb, sequela*/
,'S65492D'  /*Other specified injury of blood vessel of left thumb, subsequent encounter*/
,'S65492S'  /*Other specified injury of blood vessel of left thumb, sequela*/
,'S65499D'  /*Other specified injury of blood vessel of unspecified thumb, subsequent encounter*/
,'S65499S'  /*Other specified injury of blood vessel of unspecified thumb, sequela*/
,'S65500D'  /*Unspecified injury of blood vessel of right index finger, subsequent encounter*/
,'S65500S'  /*Unspecified injury of blood vessel of right index finger, sequela*/
,'S65501D'  /*Unspecified injury of blood vessel of left index finger, subsequent encounter*/
,'S65501S'  /*Unspecified injury of blood vessel of left index finger, sequela*/
,'S65502D'  /*Unspecified injury of blood vessel of right middle finger, subsequent encounter*/
,'S65502S'  /*Unspecified injury of blood vessel of right middle finger, sequela*/
,'S65503D'  /*Unspecified injury of blood vessel of left middle finger, subsequent encounter*/
,'S65503S'  /*Unspecified injury of blood vessel of left middle finger, sequela*/
,'S65504D'  /*Unspecified injury of blood vessel of right ring finger, subsequent encounter*/
,'S65504S'  /*Unspecified injury of blood vessel of right ring finger, sequela*/
,'S65505D'  /*Unspecified injury of blood vessel of left ring finger, subsequent encounter*/
,'S65505S'  /*Unspecified injury of blood vessel of left ring finger, sequela*/
,'S65506D'  /*Unspecified injury of blood vessel of right little finger, subsequent encounter*/
,'S65506S'  /*Unspecified injury of blood vessel of right little finger, sequela*/
,'S65507D'  /*Unspecified injury of blood vessel of left little finger, subsequent encounter*/
,'S65507S'  /*Unspecified injury of blood vessel of left little finger, sequela*/
,'S65508D'  /*Unspecified injury of blood vessel of other finger, subsequent encounter*/
,'S65508S'  /*Unspecified injury of blood vessel of other finger, sequela*/
,'S65509D'  /*Unspecified injury of blood vessel of unspecified finger, subsequent encounter*/
,'S65509S'  /*Unspecified injury of blood vessel of unspecified finger, sequela*/
,'S65510D'  /*Laceration of blood vessel of right index finger, subsequent encounter*/
,'S65510S'  /*Laceration of blood vessel of right index finger, sequela*/
,'S65511D'  /*Laceration of blood vessel of left index finger, subsequent encounter*/
,'S65511S'  /*Laceration of blood vessel of left index finger, sequela*/
,'S65512D'  /*Laceration of blood vessel of right middle finger, subsequent encounter*/
,'S65512S'  /*Laceration of blood vessel of right middle finger, sequela*/
,'S65513D'  /*Laceration of blood vessel of left middle finger, subsequent encounter*/
,'S65513S'  /*Laceration of blood vessel of left middle finger, sequela*/
,'S65514D'  /*Laceration of blood vessel of right ring finger, subsequent encounter*/
,'S65514S'  /*Laceration of blood vessel of right ring finger, sequela*/
,'S65515D'  /*Laceration of blood vessel of left ring finger, subsequent encounter*/
,'S65515S'  /*Laceration of blood vessel of left ring finger, sequela*/
,'S65516D'  /*Laceration of blood vessel of right little finger, subsequent encounter*/
,'S65516S'  /*Laceration of blood vessel of right little finger, sequela*/
,'S65517D'  /*Laceration of blood vessel of left little finger, subsequent encounter*/
,'S65517S'  /*Laceration of blood vessel of left little finger, sequela*/
,'S65518D'  /*Laceration of blood vessel of other finger, subsequent encounter*/
,'S65518S'  /*Laceration of blood vessel of other finger, sequela*/
,'S65519D'  /*Laceration of blood vessel of unspecified finger, subsequent encounter*/
,'S65519S'  /*Laceration of blood vessel of unspecified finger, sequela*/
,'S65590D'  /*Other specified injury of blood vessel of right index finger, subsequent encounter*/
,'S65590S'  /*Other specified injury of blood vessel of right index finger, sequela*/
,'S65591D'  /*Other specified injury of blood vessel of left index finger, subsequent encounter*/
,'S65591S'  /*Other specified injury of blood vessel of left index finger, sequela*/
,'S65592D'  /*Other specified injury of blood vessel of right middle finger, subsequent encounter*/
,'S65592S'  /*Other specified injury of blood vessel of right middle finger, sequela*/
,'S65593D'  /*Other specified injury of blood vessel of left middle finger, subsequent encounter*/
,'S65593S'  /*Other specified injury of blood vessel of left middle finger, sequela*/
,'S65594D'  /*Other specified injury of blood vessel of right ring finger, subsequent encounter*/
,'S65594S'  /*Other specified injury of blood vessel of right ring finger, sequela*/
,'S65595D'  /*Other specified injury of blood vessel of left ring finger, subsequent encounter*/
,'S65595S'  /*Other specified injury of blood vessel of left ring finger, sequela*/
,'S65596D'  /*Other specified injury of blood vessel of right little finger, subsequent encounter*/
,'S65596S'  /*Other specified injury of blood vessel of right little finger, sequela*/
,'S65597D'  /*Other specified injury of blood vessel of left little finger, subsequent encounter*/
,'S65597S'  /*Other specified injury of blood vessel of left little finger, sequela*/
,'S65598D'  /*Other specified injury of blood vessel of other finger, subsequent encounter*/
,'S65598S'  /*Other specified injury of blood vessel of other finger, sequela*/
,'S65599D'  /*Other specified injury of blood vessel of unspecified finger, subsequent encounter*/
,'S65599S'  /*Other specified injury of blood vessel of unspecified finger, sequela*/
,'S65801D'  /*Unspecified injury of other blood vessels at wrist and hand level of right arm, subsequent encounter*/
,'S65801S'  /*Unspecified injury of other blood vessels at wrist and hand level of right arm, sequela*/
,'S65802D'  /*Unspecified injury of other blood vessels at wrist and hand level of left arm, subsequent encounter*/
,'S65802S'  /*Unspecified injury of other blood vessels at wrist and hand level of left arm, sequela*/
,'S65809D'  /*Unspecified injury of other blood vessels at wrist and hand level of unspecified arm, subsequent encounter*/
,'S65809S'  /*Unspecified injury of other blood vessels at wrist and hand level of unspecified arm, sequela*/
,'S65811D'  /*Laceration of other blood vessels at wrist and hand level of right arm, subsequent encounter*/
,'S65811S'  /*Laceration of other blood vessels at wrist and hand level of right arm, sequela*/
,'S65812D'  /*Laceration of other blood vessels at wrist and hand level of left arm, subsequent encounter*/
,'S65812S'  /*Laceration of other blood vessels at wrist and hand level of left arm, sequela*/
,'S65819D'  /*Laceration of other blood vessels at wrist and hand level of unspecified arm, subsequent encounter*/
,'S65819S'  /*Laceration of other blood vessels at wrist and hand level of unspecified arm, sequela*/
,'S65891D'  /*Other specified injury of other blood vessels at wrist and hand level of right arm, subsequent encounter*/
,'S65891S'  /*Other specified injury of other blood vessels at wrist and hand level of right arm, sequela*/
,'S65892D'  /*Other specified injury of other blood vessels at wrist and hand level of left arm, subsequent encounter*/
,'S65892S'  /*Other specified injury of other blood vessels at wrist and hand level of left arm, sequela*/
,'S65899D'  /*Other specified injury of other blood vessels at wrist and hand level of unspecified arm, subsequent encounter*/
,'S65899S'  /*Other specified injury of other blood vessels at wrist and hand level of unspecified arm, sequela*/
,'S65901D'  /*Unspecified injury of unspecified blood vessel at wrist and hand level of right arm, subsequent encounter*/
,'S65901S'  /*Unspecified injury of unspecified blood vessel at wrist and hand level of right arm, sequela*/
,'S65902D'  /*Unspecified injury of unspecified blood vessel at wrist and hand level of left arm, subsequent encounter*/
,'S65902S'  /*Unspecified injury of unspecified blood vessel at wrist and hand level of left arm, sequela*/
,'S65909D'  /*Unspecified injury of unspecified blood vessel at wrist and hand level of unspecified arm, subsequent encounter*/
,'S65909S'  /*Unspecified injury of unspecified blood vessel at wrist and hand level of unspecified arm, sequela*/
,'S65911D'  /*Laceration of unspecified blood vessel at wrist and hand level of right arm, subsequent encounter*/
,'S65911S'  /*Laceration of unspecified blood vessel at wrist and hand level of right arm, sequela*/
,'S65912D'  /*Laceration of unspecified blood vessel at wrist and hand level of left arm, subsequent encounter*/
,'S65912S'  /*Laceration of unspecified blood vessel at wrist and hand level of left arm, sequela*/
,'S65919D'  /*Laceration of unspecified blood vessel at wrist and hand level of unspecified arm, subsequent encounter*/
,'S65919S'  /*Laceration of unspecified blood vessel at wrist and hand level of unspecified arm, sequela*/
,'S65991D'  /*Other specified injury of unspecified blood vessel at wrist and hand of right arm, subsequent encounter*/
,'S65991S'  /*Other specified injury of unspecified blood vessel at wrist and hand of right arm, sequela*/
,'S65992D'  /*Other specified injury of unspecified blood vessel at wrist and hand of left arm, subsequent encounter*/
,'S65992S'  /*Other specified injury of unspecified blood vessel at wrist and hand of left arm, sequela*/
,'S65999D'  /*Other specified injury of unspecified blood vessel at wrist and hand of unspecified arm, subsequent encounter*/
,'S65999S'  /*Other specified injury of unspecified blood vessel at wrist and hand of unspecified arm, sequela*/
,'S66001D'  /*Unspecified injury of long flexor muscle, fascia and tendon of right thumb at wrist and hand level, subsequent encounter*/
,'S66001S'  /*Unspecified injury of long flexor muscle, fascia and tendon of right thumb at wrist and hand level, sequela*/
,'S66002D'  /*Unspecified injury of long flexor muscle, fascia and tendon of left thumb at wrist and hand level, subsequent encounter*/
,'S66002S'  /*Unspecified injury of long flexor muscle, fascia and tendon of left thumb at wrist and hand level, sequela*/
,'S66009D'  /*Unspecified injury of long flexor muscle, fascia and tendon of unspecified thumb at wrist and hand level, subsequent encounter*/
,'S66009S'  /*Unspecified injury of long flexor muscle, fascia and tendon of unspecified thumb at wrist and hand level, sequela*/
,'S66011D'  /*Strain of long flexor muscle, fascia and tendon of right thumb at wrist and hand level, subsequent encounter*/
,'S66011S'  /*Strain of long flexor muscle, fascia and tendon of right thumb at wrist and hand level, sequela*/
,'S66012D'  /*Strain of long flexor muscle, fascia and tendon of left thumb at wrist and hand level, subsequent encounter*/
,'S66012S'  /*Strain of long flexor muscle, fascia and tendon of left thumb at wrist and hand level, sequela*/
,'S66019D'  /*Strain of long flexor muscle, fascia and tendon of unspecified thumb at wrist and hand level, subsequent encounter*/
,'S66019S'  /*Strain of long flexor muscle, fascia and tendon of unspecified thumb at wrist and hand level, sequela*/
,'S66021D'  /*Laceration of long flexor muscle, fascia and tendon of right thumb at wrist and hand level, subsequent encounter*/
,'S66021S'  /*Laceration of long flexor muscle, fascia and tendon of right thumb at wrist and hand level, sequela*/
,'S66022D'  /*Laceration of long flexor muscle, fascia and tendon of left thumb at wrist and hand level, subsequent encounter*/
,'S66022S'  /*Laceration of long flexor muscle, fascia and tendon of left thumb at wrist and hand level, sequela*/
,'S66029D'  /*Laceration of long flexor muscle, fascia and tendon of unspecified thumb at wrist and hand level, subsequent encounter*/
,'S66029S'  /*Laceration of long flexor muscle, fascia and tendon of unspecified thumb at wrist and hand level, sequela*/
,'S66091D'  /*Other specified injury of long flexor muscle, fascia and tendon of right thumb at wrist and hand level, subsequent encounter*/
,'S66091S'  /*Other specified injury of long flexor muscle, fascia and tendon of right thumb at wrist and hand level, sequela*/
,'S66092D'  /*Other specified injury of long flexor muscle, fascia and tendon of left thumb at wrist and hand level, subsequent encounter*/
,'S66092S'  /*Other specified injury of long flexor muscle, fascia and tendon of left thumb at wrist and hand level, sequela*/
,'S66099D'  /*Other specified injury of long flexor muscle, fascia and tendon of unspecified thumb at wrist and hand level, subsequent encounter*/
,'S66099S'  /*Other specified injury of long flexor muscle, fascia and tendon of unspecified thumb at wrist and hand level, sequela*/
,'S66100D'  /*Unspecified injury of flexor muscle, fascia and tendon of right index finger at wrist and hand level, subsequent encounter*/
,'S66100S'  /*Unspecified injury of flexor muscle, fascia and tendon of right index finger at wrist and hand level, sequela*/
,'S66101D'  /*Unspecified injury of flexor muscle, fascia and tendon of left index finger at wrist and hand level, subsequent encounter*/
,'S66101S'  /*Unspecified injury of flexor muscle, fascia and tendon of left index finger at wrist and hand level, sequela*/
,'S66102D'  /*Unspecified injury of flexor muscle, fascia and tendon of right middle finger at wrist and hand level, subsequent encounter*/
,'S66102S'  /*Unspecified injury of flexor muscle, fascia and tendon of right middle finger at wrist and hand level, sequela*/
,'S66103D'  /*Unspecified injury of flexor muscle, fascia and tendon of left middle finger at wrist and hand level, subsequent encounter*/
,'S66103S'  /*Unspecified injury of flexor muscle, fascia and tendon of left middle finger at wrist and hand level, sequela*/
,'S66104D'  /*Unspecified injury of flexor muscle, fascia and tendon of right ring finger at wrist and hand level, subsequent encounter*/
,'S66104S'  /*Unspecified injury of flexor muscle, fascia and tendon of right ring finger at wrist and hand level, sequela*/
,'S66105D'  /*Unspecified injury of flexor muscle, fascia and tendon of left ring finger at wrist and hand level, subsequent encounter*/
,'S66105S'  /*Unspecified injury of flexor muscle, fascia and tendon of left ring finger at wrist and hand level, sequela*/
,'S66106D'  /*Unspecified injury of flexor muscle, fascia and tendon of right little finger at wrist and hand level, subsequent encounter*/
,'S66106S'  /*Unspecified injury of flexor muscle, fascia and tendon of right little finger at wrist and hand level, sequela*/
,'S66107D'  /*Unspecified injury of flexor muscle, fascia and tendon of left little finger at wrist and hand level, subsequent encounter*/
,'S66107S'  /*Unspecified injury of flexor muscle, fascia and tendon of left little finger at wrist and hand level, sequela*/
,'S66108D'  /*Unspecified injury of flexor muscle, fascia and tendon of other finger at wrist and hand level, subsequent encounter*/
,'S66108S'  /*Unspecified injury of flexor muscle, fascia and tendon of other finger at wrist and hand level, sequela*/
,'S66109D'  /*Unspecified injury of flexor muscle, fascia and tendon of unspecified finger at wrist and hand level, subsequent encounter*/
,'S66109S'  /*Unspecified injury of flexor muscle, fascia and tendon of unspecified finger at wrist and hand level, sequela*/
,'S66110D'  /*Strain of flexor muscle, fascia and tendon of right index finger at wrist and hand level, subsequent encounter*/
,'S66110S'  /*Strain of flexor muscle, fascia and tendon of right index finger at wrist and hand level, sequela*/
,'S66111D'  /*Strain of flexor muscle, fascia and tendon of left index finger at wrist and hand level, subsequent encounter*/
,'S66111S'  /*Strain of flexor muscle, fascia and tendon of left index finger at wrist and hand level, sequela*/
,'S66112D'  /*Strain of flexor muscle, fascia and tendon of right middle finger at wrist and hand level, subsequent encounter*/
,'S66112S'  /*Strain of flexor muscle, fascia and tendon of right middle finger at wrist and hand level, sequela*/
,'S66113D'  /*Strain of flexor muscle, fascia and tendon of left middle finger at wrist and hand level, subsequent encounter*/
,'S66113S'  /*Strain of flexor muscle, fascia and tendon of left middle finger at wrist and hand level, sequela*/
,'S66114D'  /*Strain of flexor muscle, fascia and tendon of right ring finger at wrist and hand level, subsequent encounter*/
,'S66114S'  /*Strain of flexor muscle, fascia and tendon of right ring finger at wrist and hand level, sequela*/
,'S66115D'  /*Strain of flexor muscle, fascia and tendon of left ring finger at wrist and hand level, subsequent encounter*/
,'S66115S'  /*Strain of flexor muscle, fascia and tendon of left ring finger at wrist and hand level, sequela*/
,'S66116D'  /*Strain of flexor muscle, fascia and tendon of right little finger at wrist and hand level, subsequent encounter*/
,'S66116S'  /*Strain of flexor muscle, fascia and tendon of right little finger at wrist and hand level, sequela*/
,'S66117D'  /*Strain of flexor muscle, fascia and tendon of left little finger at wrist and hand level, subsequent encounter*/
,'S66117S'  /*Strain of flexor muscle, fascia and tendon of left little finger at wrist and hand level, sequela*/
,'S66118D'  /*Strain of flexor muscle, fascia and tendon of other finger at wrist and hand level, subsequent encounter*/
,'S66118S'  /*Strain of flexor muscle, fascia and tendon of other finger at wrist and hand level, sequela*/
,'S66119D'  /*Strain of flexor muscle, fascia and tendon of unspecified finger at wrist and hand level, subsequent encounter*/
,'S66119S'  /*Strain of flexor muscle, fascia and tendon of unspecified finger at wrist and hand level, sequela*/
,'S66120D'  /*Laceration of flexor muscle, fascia and tendon of right index finger at wrist and hand level, subsequent encounter*/
,'S66120S'  /*Laceration of flexor muscle, fascia and tendon of right index finger at wrist and hand level, sequela*/
,'S66121D'  /*Laceration of flexor muscle, fascia and tendon of left index finger at wrist and hand level, subsequent encounter*/
,'S66121S'  /*Laceration of flexor muscle, fascia and tendon of left index finger at wrist and hand level, sequela*/
,'S66122D'  /*Laceration of flexor muscle, fascia and tendon of right middle finger at wrist and hand level, subsequent encounter*/
,'S66122S'  /*Laceration of flexor muscle, fascia and tendon of right middle finger at wrist and hand level, sequela*/
,'S66123D'  /*Laceration of flexor muscle, fascia and tendon of left middle finger at wrist and hand level, subsequent encounter*/
,'S66123S'  /*Laceration of flexor muscle, fascia and tendon of left middle finger at wrist and hand level, sequela*/
,'S66124D'  /*Laceration of flexor muscle, fascia and tendon of right ring finger at wrist and hand level, subsequent encounter*/
,'S66124S'  /*Laceration of flexor muscle, fascia and tendon of right ring finger at wrist and hand level, sequela*/
,'S66125D'  /*Laceration of flexor muscle, fascia and tendon of left ring finger at wrist and hand level, subsequent encounter*/
,'S66125S'  /*Laceration of flexor muscle, fascia and tendon of left ring finger at wrist and hand level, sequela*/
,'S66126D'  /*Laceration of flexor muscle, fascia and tendon of right little finger at wrist and hand level, subsequent encounter*/
,'S66126S'  /*Laceration of flexor muscle, fascia and tendon of right little finger at wrist and hand level, sequela*/
,'S66127D'  /*Laceration of flexor muscle, fascia and tendon of left little finger at wrist and hand level, subsequent encounter*/
,'S66127S'  /*Laceration of flexor muscle, fascia and tendon of left little finger at wrist and hand level, sequela*/
,'S66128D'  /*Laceration of flexor muscle, fascia and tendon of other finger at wrist and hand level, subsequent encounter*/
,'S66128S'  /*Laceration of flexor muscle, fascia and tendon of other finger at wrist and hand level, sequela*/
,'S66129D'  /*Laceration of flexor muscle, fascia and tendon of unspecified finger at wrist and hand level, subsequent encounter*/
,'S66129S'  /*Laceration of flexor muscle, fascia and tendon of unspecified finger at wrist and hand level, sequela*/
,'S66190D'  /*Other injury of flexor muscle, fascia and tendon of right index finger at wrist and hand level, subsequent encounter*/
,'S66190S'  /*Other injury of flexor muscle, fascia and tendon of right index finger at wrist and hand level, sequela*/
,'S66191D'  /*Other injury of flexor muscle, fascia and tendon of left index finger at wrist and hand level, subsequent encounter*/
,'S66191S'  /*Other injury of flexor muscle, fascia and tendon of left index finger at wrist and hand level, sequela*/
,'S66192D'  /*Other injury of flexor muscle, fascia and tendon of right middle finger at wrist and hand level, subsequent encounter*/
,'S66192S'  /*Other injury of flexor muscle, fascia and tendon of right middle finger at wrist and hand level, sequela*/
,'S66193D'  /*Other injury of flexor muscle, fascia and tendon of left middle finger at wrist and hand level, subsequent encounter*/
,'S66193S'  /*Other injury of flexor muscle, fascia and tendon of left middle finger at wrist and hand level, sequela*/
,'S66194D'  /*Other injury of flexor muscle, fascia and tendon of right ring finger at wrist and hand level, subsequent encounter*/
,'S66194S'  /*Other injury of flexor muscle, fascia and tendon of right ring finger at wrist and hand level, sequela*/
,'S66195D'  /*Other injury of flexor muscle, fascia and tendon of left ring finger at wrist and hand level, subsequent encounter*/
,'S66195S'  /*Other injury of flexor muscle, fascia and tendon of left ring finger at wrist and hand level, sequela*/
,'S66196D'  /*Other injury of flexor muscle, fascia and tendon of right little finger at wrist and hand level, subsequent encounter*/
,'S66196S'  /*Other injury of flexor muscle, fascia and tendon of right little finger at wrist and hand level, sequela*/
,'S66197D'  /*Other injury of flexor muscle, fascia and tendon of left little finger at wrist and hand level, subsequent encounter*/
,'S66197S'  /*Other injury of flexor muscle, fascia and tendon of left little finger at wrist and hand level, sequela*/
,'S66198D'  /*Other injury of flexor muscle, fascia and tendon of other finger at wrist and hand level, subsequent encounter*/
,'S66198S'  /*Other injury of flexor muscle, fascia and tendon of other finger at wrist and hand level, sequela*/
,'S66199D'  /*Other injury of flexor muscle, fascia and tendon of unspecified finger at wrist and hand level, subsequent encounter*/
,'S66199S'  /*Other injury of flexor muscle, fascia and tendon of unspecified finger at wrist and hand level, sequela*/
,'S66201D'  /*Unspecified injury of extensor muscle, fascia and tendon of right thumb at wrist and hand level, subsequent encounter*/
,'S66201S'  /*Unspecified injury of extensor muscle, fascia and tendon of right thumb at wrist and hand level, sequela*/
,'S66202D'  /*Unspecified injury of extensor muscle, fascia and tendon of left thumb at wrist and hand level, subsequent encounter*/
,'S66202S'  /*Unspecified injury of extensor muscle, fascia and tendon of left thumb at wrist and hand level, sequela*/
,'S66209D'  /*Unspecified injury of extensor muscle, fascia and tendon of unspecified thumb at wrist and hand level, subsequent encounter*/
,'S66209S'  /*Unspecified injury of extensor muscle, fascia and tendon of unspecified thumb at wrist and hand level, sequela*/
,'S66211D'  /*Strain of extensor muscle, fascia and tendon of right thumb at wrist and hand level, subsequent encounter*/
,'S66211S'  /*Strain of extensor muscle, fascia and tendon of right thumb at wrist and hand level, sequela*/
,'S66212D'  /*Strain of extensor muscle, fascia and tendon of left thumb at wrist and hand level, subsequent encounter*/
,'S66212S'  /*Strain of extensor muscle, fascia and tendon of left thumb at wrist and hand level, sequela*/
,'S66219D'  /*Strain of extensor muscle, fascia and tendon of unspecified thumb at wrist and hand level, subsequent encounter*/
,'S66219S'  /*Strain of extensor muscle, fascia and tendon of unspecified thumb at wrist and hand level, sequela*/
,'S66221D'  /*Laceration of extensor muscle, fascia and tendon of right thumb at wrist and hand level, subsequent encounter*/
,'S66221S'  /*Laceration of extensor muscle, fascia and tendon of right thumb at wrist and hand level, sequela*/
,'S66222D'  /*Laceration of extensor muscle, fascia and tendon of left thumb at wrist and hand level, subsequent encounter*/
,'S66222S'  /*Laceration of extensor muscle, fascia and tendon of left thumb at wrist and hand level, sequela*/
,'S66229D'  /*Laceration of extensor muscle, fascia and tendon of unspecified thumb at wrist and hand level, subsequent encounter*/
,'S66229S'  /*Laceration of extensor muscle, fascia and tendon of unspecified thumb at wrist and hand level, sequela*/
,'S66291D'  /*Other specified injury of extensor muscle, fascia and tendon of right thumb at wrist and hand level, subsequent encounter*/
,'S66291S'  /*Other specified injury of extensor muscle, fascia and tendon of right thumb at wrist and hand level, sequela*/
,'S66292D'  /*Other specified injury of extensor muscle, fascia and tendon of left thumb at wrist and hand level, subsequent encounter*/
,'S66292S'  /*Other specified injury of extensor muscle, fascia and tendon of left thumb at wrist and hand level, sequela*/
,'S66299D'  /*Other specified injury of extensor muscle, fascia and tendon of unspecified thumb at wrist and hand level, subsequent encounter*/
,'S66299S'  /*Other specified injury of extensor muscle, fascia and tendon of unspecified thumb at wrist and hand level, sequela*/
,'S66300D'  /*Unspecified injury of extensor muscle, fascia and tendon of right index finger at wrist and hand level, subsequent encounter*/
,'S66300S'  /*Unspecified injury of extensor muscle, fascia and tendon of right index finger at wrist and hand level, sequela*/
,'S66301D'  /*Unspecified injury of extensor muscle, fascia and tendon of left index finger at wrist and hand level, subsequent encounter*/
,'S66301S'  /*Unspecified injury of extensor muscle, fascia and tendon of left index finger at wrist and hand level, sequela*/
,'S66302D'  /*Unspecified injury of extensor muscle, fascia and tendon of right middle finger at wrist and hand level, subsequent encounter*/
,'S66302S'  /*Unspecified injury of extensor muscle, fascia and tendon of right middle finger at wrist and hand level, sequela*/
,'S66303D'  /*Unspecified injury of extensor muscle, fascia and tendon of left middle finger at wrist and hand level, subsequent encounter*/
,'S66303S'  /*Unspecified injury of extensor muscle, fascia and tendon of left middle finger at wrist and hand level, sequela*/
,'S66304D'  /*Unspecified injury of extensor muscle, fascia and tendon of right ring finger at wrist and hand level, subsequent encounter*/
,'S66304S'  /*Unspecified injury of extensor muscle, fascia and tendon of right ring finger at wrist and hand level, sequela*/
,'S66305D'  /*Unspecified injury of extensor muscle, fascia and tendon of left ring finger at wrist and hand level, subsequent encounter*/
,'S66305S'  /*Unspecified injury of extensor muscle, fascia and tendon of left ring finger at wrist and hand level, sequela*/
,'S66306D'  /*Unspecified injury of extensor muscle, fascia and tendon of right little finger at wrist and hand level, subsequent encounter*/
,'S66306S'  /*Unspecified injury of extensor muscle, fascia and tendon of right little finger at wrist and hand level, sequela*/
,'S66307D'  /*Unspecified injury of extensor muscle, fascia and tendon of left little finger at wrist and hand level, subsequent encounter*/
,'S66307S'  /*Unspecified injury of extensor muscle, fascia and tendon of left little finger at wrist and hand level, sequela*/
,'S66308D'  /*Unspecified injury of extensor muscle, fascia and tendon of other finger at wrist and hand level, subsequent encounter*/
,'S66308S'  /*Unspecified injury of extensor muscle, fascia and tendon of other finger at wrist and hand level, sequela*/
,'S66309D'  /*Unspecified injury of extensor muscle, fascia and tendon of unspecified finger at wrist and hand level, subsequent encounter*/
,'S66309S'  /*Unspecified injury of extensor muscle, fascia and tendon of unspecified finger at wrist and hand level, sequela*/
,'S66310D'  /*Strain of extensor muscle, fascia and tendon of right index finger at wrist and hand level, subsequent encounter*/
,'S66310S'  /*Strain of extensor muscle, fascia and tendon of right index finger at wrist and hand level, sequela*/
,'S66311D'  /*Strain of extensor muscle, fascia and tendon of left index finger at wrist and hand level, subsequent encounter*/
,'S66311S'  /*Strain of extensor muscle, fascia and tendon of left index finger at wrist and hand level, sequela*/
,'S66312D'  /*Strain of extensor muscle, fascia and tendon of right middle finger at wrist and hand level, subsequent encounter*/
,'S66312S'  /*Strain of extensor muscle, fascia and tendon of right middle finger at wrist and hand level, sequela*/
,'S66313D'  /*Strain of extensor muscle, fascia and tendon of left middle finger at wrist and hand level, subsequent encounter*/
,'S66313S'  /*Strain of extensor muscle, fascia and tendon of left middle finger at wrist and hand level, sequela*/
,'S66314D'  /*Strain of extensor muscle, fascia and tendon of right ring finger at wrist and hand level, subsequent encounter*/
,'S66314S'  /*Strain of extensor muscle, fascia and tendon of right ring finger at wrist and hand level, sequela*/
,'S66315D'  /*Strain of extensor muscle, fascia and tendon of left ring finger at wrist and hand level, subsequent encounter*/
,'S66315S'  /*Strain of extensor muscle, fascia and tendon of left ring finger at wrist and hand level, sequela*/
,'S66316D'  /*Strain of extensor muscle, fascia and tendon of right little finger at wrist and hand level, subsequent encounter*/
,'S66316S'  /*Strain of extensor muscle, fascia and tendon of right little finger at wrist and hand level, sequela*/
,'S66317D'  /*Strain of extensor muscle, fascia and tendon of left little finger at wrist and hand level, subsequent encounter*/
,'S66317S'  /*Strain of extensor muscle, fascia and tendon of left little finger at wrist and hand level, sequela*/
,'S66318D'  /*Strain of extensor muscle, fascia and tendon of other finger at wrist and hand level, subsequent encounter*/
,'S66318S'  /*Strain of extensor muscle, fascia and tendon of other finger at wrist and hand level, sequela*/
,'S66319D'  /*Strain of extensor muscle, fascia and tendon of unspecified finger at wrist and hand level, subsequent encounter*/
,'S66319S'  /*Strain of extensor muscle, fascia and tendon of unspecified finger at wrist and hand level, sequela*/
,'S66320D'  /*Laceration of extensor muscle, fascia and tendon of right index finger at wrist and hand level, subsequent encounter*/
,'S66320S'  /*Laceration of extensor muscle, fascia and tendon of right index finger at wrist and hand level, sequela*/
,'S66321D'  /*Laceration of extensor muscle, fascia and tendon of left index finger at wrist and hand level, subsequent encounter*/
,'S66321S'  /*Laceration of extensor muscle, fascia and tendon of left index finger at wrist and hand level, sequela*/
,'S66322D'  /*Laceration of extensor muscle, fascia and tendon of right middle finger at wrist and hand level, subsequent encounter*/
,'S66322S'  /*Laceration of extensor muscle, fascia and tendon of right middle finger at wrist and hand level, sequela*/
,'S66323D'  /*Laceration of extensor muscle, fascia and tendon of left middle finger at wrist and hand level, subsequent encounter*/
,'S66323S'  /*Laceration of extensor muscle, fascia and tendon of left middle finger at wrist and hand level, sequela*/
,'S66324D'  /*Laceration of extensor muscle, fascia and tendon of right ring finger at wrist and hand level, subsequent encounter*/
,'S66324S'  /*Laceration of extensor muscle, fascia and tendon of right ring finger at wrist and hand level, sequela*/
,'S66325D'  /*Laceration of extensor muscle, fascia and tendon of left ring finger at wrist and hand level, subsequent encounter*/
,'S66325S'  /*Laceration of extensor muscle, fascia and tendon of left ring finger at wrist and hand level, sequela*/
,'S66326D'  /*Laceration of extensor muscle, fascia and tendon of right little finger at wrist and hand level, subsequent encounter*/
,'S66326S'  /*Laceration of extensor muscle, fascia and tendon of right little finger at wrist and hand level, sequela*/
,'S66327D'  /*Laceration of extensor muscle, fascia and tendon of left little finger at wrist and hand level, subsequent encounter*/
,'S66327S'  /*Laceration of extensor muscle, fascia and tendon of left little finger at wrist and hand level, sequela*/
,'S66328D'  /*Laceration of extensor muscle, fascia and tendon of other finger at wrist and hand level, subsequent encounter*/
,'S66328S'  /*Laceration of extensor muscle, fascia and tendon of other finger at wrist and hand level, sequela*/
,'S66329D'  /*Laceration of extensor muscle, fascia and tendon of unspecified finger at wrist and hand level, subsequent encounter*/
,'S66329S'  /*Laceration of extensor muscle, fascia and tendon of unspecified finger at wrist and hand level, sequela*/
,'S66390D'  /*Other injury of extensor muscle, fascia and tendon of right index finger at wrist and hand level, subsequent encounter*/
,'S66390S'  /*Other injury of extensor muscle, fascia and tendon of right index finger at wrist and hand level, sequela*/
,'S66391D'  /*Other injury of extensor muscle, fascia and tendon of left index finger at wrist and hand level, subsequent encounter*/
,'S66391S'  /*Other injury of extensor muscle, fascia and tendon of left index finger at wrist and hand level, sequela*/
,'S66392D'  /*Other injury of extensor muscle, fascia and tendon of right middle finger at wrist and hand level, subsequent encounter*/
,'S66392S'  /*Other injury of extensor muscle, fascia and tendon of right middle finger at wrist and hand level, sequela*/
,'S66393D'  /*Other injury of extensor muscle, fascia and tendon of left middle finger at wrist and hand level, subsequent encounter*/
,'S66393S'  /*Other injury of extensor muscle, fascia and tendon of left middle finger at wrist and hand level, sequela*/
,'S66394D'  /*Other injury of extensor muscle, fascia and tendon of right ring finger at wrist and hand level, subsequent encounter*/
,'S66394S'  /*Other injury of extensor muscle, fascia and tendon of right ring finger at wrist and hand level, sequela*/
,'S66395D'  /*Other injury of extensor muscle, fascia and tendon of left ring finger at wrist and hand level, subsequent encounter*/
,'S66395S'  /*Other injury of extensor muscle, fascia and tendon of left ring finger at wrist and hand level, sequela*/
,'S66396D'  /*Other injury of extensor muscle, fascia and tendon of right little finger at wrist and hand level, subsequent encounter*/
,'S66396S'  /*Other injury of extensor muscle, fascia and tendon of right little finger at wrist and hand level, sequela*/
,'S66397D'  /*Other injury of extensor muscle, fascia and tendon of left little finger at wrist and hand level, subsequent encounter*/
,'S66397S'  /*Other injury of extensor muscle, fascia and tendon of left little finger at wrist and hand level, sequela*/
,'S66398D'  /*Other injury of extensor muscle, fascia and tendon of other finger at wrist and hand level, subsequent encounter*/
,'S66398S'  /*Other injury of extensor muscle, fascia and tendon of other finger at wrist and hand level, sequela*/
,'S66399D'  /*Other injury of extensor muscle, fascia and tendon of unspecified finger at wrist and hand level, subsequent encounter*/
,'S66399S'  /*Other injury of extensor muscle, fascia and tendon of unspecified finger at wrist and hand level, sequela*/
,'S66401D'  /*Unspecified injury of intrinsic muscle, fascia and tendon of right thumb at wrist and hand level, subsequent encounter*/
,'S66401S'  /*Unspecified injury of intrinsic muscle, fascia and tendon of right thumb at wrist and hand level, sequela*/
,'S66402D'  /*Unspecified injury of intrinsic muscle, fascia and tendon of left thumb at wrist and hand level, subsequent encounter*/
,'S66402S'  /*Unspecified injury of intrinsic muscle, fascia and tendon of left thumb at wrist and hand level, sequela*/
,'S66409D'  /*Unspecified injury of intrinsic muscle, fascia and tendon of unspecified thumb at wrist and hand level, subsequent encounter*/
,'S66409S'  /*Unspecified injury of intrinsic muscle, fascia and tendon of unspecified thumb at wrist and hand level, sequela*/
,'S66411D'  /*Strain of intrinsic muscle, fascia and tendon of right thumb at wrist and hand level, subsequent encounter*/
,'S66411S'  /*Strain of intrinsic muscle, fascia and tendon of right thumb at wrist and hand level, sequela*/
,'S66412D'  /*Strain of intrinsic muscle, fascia and tendon of left thumb at wrist and hand level, subsequent encounter*/
,'S66412S'  /*Strain of intrinsic muscle, fascia and tendon of left thumb at wrist and hand level, sequela*/
,'S66419D'  /*Strain of intrinsic muscle, fascia and tendon of unspecified thumb at wrist and hand level, subsequent encounter*/
,'S66419S'  /*Strain of intrinsic muscle, fascia and tendon of unspecified thumb at wrist and hand level, sequela*/
,'S66421D'  /*Laceration of intrinsic muscle, fascia and tendon of right thumb at wrist and hand level, subsequent encounter*/
,'S66421S'  /*Laceration of intrinsic muscle, fascia and tendon of right thumb at wrist and hand level, sequela*/
,'S66422D'  /*Laceration of intrinsic muscle, fascia and tendon of left thumb at wrist and hand level, subsequent encounter*/
,'S66422S'  /*Laceration of intrinsic muscle, fascia and tendon of left thumb at wrist and hand level, sequela*/
,'S66429D'  /*Laceration of intrinsic muscle, fascia and tendon of unspecified thumb at wrist and hand level, subsequent encounter*/
,'S66429S'  /*Laceration of intrinsic muscle, fascia and tendon of unspecified thumb at wrist and hand level, sequela*/
,'S66491D'  /*Other specified injury of intrinsic muscle, fascia and tendon of right thumb at wrist and hand level, subsequent encounter*/
,'S66491S'  /*Other specified injury of intrinsic muscle, fascia and tendon of right thumb at wrist and hand level, sequela*/
,'S66492D'  /*Other specified injury of intrinsic muscle, fascia and tendon of left thumb at wrist and hand level, subsequent encounter*/
,'S66492S'  /*Other specified injury of intrinsic muscle, fascia and tendon of left thumb at wrist and hand level, sequela*/
,'S66499D'  /*Other specified injury of intrinsic muscle, fascia and tendon of unspecified thumb at wrist and hand level, subsequent encounter*/
,'S66499S'  /*Other specified injury of intrinsic muscle, fascia and tendon of unspecified thumb at wrist and hand level, sequela*/
,'S66500D'  /*Unspecified injury of intrinsic muscle, fascia and tendon of right index finger at wrist and hand level, subsequent encounter*/
,'S66500S'  /*Unspecified injury of intrinsic muscle, fascia and tendon of right index finger at wrist and hand level, sequela*/
,'S66501D'  /*Unspecified injury of intrinsic muscle, fascia and tendon of left index finger at wrist and hand level, subsequent encounter*/
,'S66501S'  /*Unspecified injury of intrinsic muscle, fascia and tendon of left index finger at wrist and hand level, sequela*/
,'S66502D'  /*Unspecified injury of intrinsic muscle, fascia and tendon of right middle finger at wrist and hand level, subsequent encounter*/
,'S66502S'  /*Unspecified injury of intrinsic muscle, fascia and tendon of right middle finger at wrist and hand level, sequela*/
,'S66503D'  /*Unspecified injury of intrinsic muscle, fascia and tendon of left middle finger at wrist and hand level, subsequent encounter*/
,'S66503S'  /*Unspecified injury of intrinsic muscle, fascia and tendon of left middle finger at wrist and hand level, sequela*/
,'S66504D'  /*Unspecified injury of intrinsic muscle, fascia and tendon of right ring finger at wrist and hand level, subsequent encounter*/
,'S66504S'  /*Unspecified injury of intrinsic muscle, fascia and tendon of right ring finger at wrist and hand level, sequela*/
,'S66505D'  /*Unspecified injury of intrinsic muscle, fascia and tendon of left ring finger at wrist and hand level, subsequent encounter*/
,'S66505S'  /*Unspecified injury of intrinsic muscle, fascia and tendon of left ring finger at wrist and hand level, sequela*/
,'S66506D'  /*Unspecified injury of intrinsic muscle, fascia and tendon of right little finger at wrist and hand level, subsequent encounter*/
,'S66506S'  /*Unspecified injury of intrinsic muscle, fascia and tendon of right little finger at wrist and hand level, sequela*/
,'S66507D'  /*Unspecified injury of intrinsic muscle, fascia and tendon of left little finger at wrist and hand level, subsequent encounter*/
,'S66507S'  /*Unspecified injury of intrinsic muscle, fascia and tendon of left little finger at wrist and hand level, sequela*/
,'S66508D'  /*Unspecified injury of intrinsic muscle, fascia and tendon of other finger at wrist and hand level, subsequent encounter*/
,'S66508S'  /*Unspecified injury of intrinsic muscle, fascia and tendon of other finger at wrist and hand level, sequela*/
,'S66509D'  /*Unspecified injury of intrinsic muscle, fascia and tendon of unspecified finger at wrist and hand level, subsequent encounter*/
,'S66509S'  /*Unspecified injury of intrinsic muscle, fascia and tendon of unspecified finger at wrist and hand level, sequela*/
,'S66510D'  /*Strain of intrinsic muscle, fascia and tendon of right index finger at wrist and hand level, subsequent encounter*/
,'S66510S'  /*Strain of intrinsic muscle, fascia and tendon of right index finger at wrist and hand level, sequela*/
,'S66511D'  /*Strain of intrinsic muscle, fascia and tendon of left index finger at wrist and hand level, subsequent encounter*/
,'S66511S'  /*Strain of intrinsic muscle, fascia and tendon of left index finger at wrist and hand level, sequela*/
,'S66512D'  /*Strain of intrinsic muscle, fascia and tendon of right middle finger at wrist and hand level, subsequent encounter*/
,'S66512S'  /*Strain of intrinsic muscle, fascia and tendon of right middle finger at wrist and hand level, sequela*/
,'S66513D'  /*Strain of intrinsic muscle, fascia and tendon of left middle finger at wrist and hand level, subsequent encounter*/
,'S66513S'  /*Strain of intrinsic muscle, fascia and tendon of left middle finger at wrist and hand level, sequela*/
,'S66514D'  /*Strain of intrinsic muscle, fascia and tendon of right ring finger at wrist and hand level, subsequent encounter*/
,'S66514S'  /*Strain of intrinsic muscle, fascia and tendon of right ring finger at wrist and hand level, sequela*/
,'S66515D'  /*Strain of intrinsic muscle, fascia and tendon of left ring finger at wrist and hand level, subsequent encounter*/
,'S66515S'  /*Strain of intrinsic muscle, fascia and tendon of left ring finger at wrist and hand level, sequela*/
,'S66516D'  /*Strain of intrinsic muscle, fascia and tendon of right little finger at wrist and hand level, subsequent encounter*/
,'S66516S'  /*Strain of intrinsic muscle, fascia and tendon of right little finger at wrist and hand level, sequela*/
,'S66517D'  /*Strain of intrinsic muscle, fascia and tendon of left little finger at wrist and hand level, subsequent encounter*/
,'S66517S'  /*Strain of intrinsic muscle, fascia and tendon of left little finger at wrist and hand level, sequela*/
,'S66518D'  /*Strain of intrinsic muscle, fascia and tendon of other finger at wrist and hand level, subsequent encounter*/
,'S66518S'  /*Strain of intrinsic muscle, fascia and tendon of other finger at wrist and hand level, sequela*/
,'S66519D'  /*Strain of intrinsic muscle, fascia and tendon of unspecified finger at wrist and hand level, subsequent encounter*/
,'S66519S'  /*Strain of intrinsic muscle, fascia and tendon of unspecified finger at wrist and hand level, sequela*/
,'S66520D'  /*Laceration of intrinsic muscle, fascia and tendon of right index finger at wrist and hand level, subsequent encounter*/
,'S66520S'  /*Laceration of intrinsic muscle, fascia and tendon of right index finger at wrist and hand level, sequela*/
,'S66521D'  /*Laceration of intrinsic muscle, fascia and tendon of left index finger at wrist and hand level, subsequent encounter*/
,'S66521S'  /*Laceration of intrinsic muscle, fascia and tendon of left index finger at wrist and hand level, sequela*/
,'S66522D'  /*Laceration of intrinsic muscle, fascia and tendon of right middle finger at wrist and hand level, subsequent encounter*/
,'S66522S'  /*Laceration of intrinsic muscle, fascia and tendon of right middle finger at wrist and hand level, sequela*/
,'S66523D'  /*Laceration of intrinsic muscle, fascia and tendon of left middle finger at wrist and hand level, subsequent encounter*/
,'S66523S'  /*Laceration of intrinsic muscle, fascia and tendon of left middle finger at wrist and hand level, sequela*/
,'S66524D'  /*Laceration of intrinsic muscle, fascia and tendon of right ring finger at wrist and hand level, subsequent encounter*/
,'S66524S'  /*Laceration of intrinsic muscle, fascia and tendon of right ring finger at wrist and hand level, sequela*/
,'S66525D'  /*Laceration of intrinsic muscle, fascia and tendon of left ring finger at wrist and hand level, subsequent encounter*/
,'S66525S'  /*Laceration of intrinsic muscle, fascia and tendon of left ring finger at wrist and hand level, sequela*/
,'S66526D'  /*Laceration of intrinsic muscle, fascia and tendon of right little finger at wrist and hand level, subsequent encounter*/
,'S66526S'  /*Laceration of intrinsic muscle, fascia and tendon of right little finger at wrist and hand level, sequela*/
,'S66527D'  /*Laceration of intrinsic muscle, fascia and tendon of left little finger at wrist and hand level, subsequent encounter*/
,'S66527S'  /*Laceration of intrinsic muscle, fascia and tendon of left little finger at wrist and hand level, sequela*/
,'S66528D'  /*Laceration of intrinsic muscle, fascia and tendon of other finger at wrist and hand level, subsequent encounter*/
,'S66528S'  /*Laceration of intrinsic muscle, fascia and tendon of other finger at wrist and hand level, sequela*/
,'S66529D'  /*Laceration of intrinsic muscle, fascia and tendon of unspecified finger at wrist and hand level, subsequent encounter*/
,'S66529S'  /*Laceration of intrinsic muscle, fascia and tendon of unspecified finger at wrist and hand level, sequela*/
,'S66590D'  /*Other injury of intrinsic muscle, fascia and tendon of right index finger at wrist and hand level, subsequent encounter*/
,'S66590S'  /*Other injury of intrinsic muscle, fascia and tendon of right index finger at wrist and hand level, sequela*/
,'S66591D'  /*Other injury of intrinsic muscle, fascia and tendon of left index finger at wrist and hand level, subsequent encounter*/
,'S66591S'  /*Other injury of intrinsic muscle, fascia and tendon of left index finger at wrist and hand level, sequela*/
,'S66592D'  /*Other injury of intrinsic muscle, fascia and tendon of right middle finger at wrist and hand level, subsequent encounter*/
,'S66592S'  /*Other injury of intrinsic muscle, fascia and tendon of right middle finger at wrist and hand level, sequela*/
,'S66593D'  /*Other injury of intrinsic muscle, fascia and tendon of left middle finger at wrist and hand level, subsequent encounter*/
,'S66593S'  /*Other injury of intrinsic muscle, fascia and tendon of left middle finger at wrist and hand level, sequela*/
,'S66594D'  /*Other injury of intrinsic muscle, fascia and tendon of right ring finger at wrist and hand level, subsequent encounter*/
,'S66594S'  /*Other injury of intrinsic muscle, fascia and tendon of right ring finger at wrist and hand level, sequela*/
,'S66595D'  /*Other injury of intrinsic muscle, fascia and tendon of left ring finger at wrist and hand level, subsequent encounter*/
,'S66595S'  /*Other injury of intrinsic muscle, fascia and tendon of left ring finger at wrist and hand level, sequela*/
,'S66596D'  /*Other injury of intrinsic muscle, fascia and tendon of right little finger at wrist and hand level, subsequent encounter*/
,'S66596S'  /*Other injury of intrinsic muscle, fascia and tendon of right little finger at wrist and hand level, sequela*/
,'S66597D'  /*Other injury of intrinsic muscle, fascia and tendon of left little finger at wrist and hand level, subsequent encounter*/
,'S66597S'  /*Other injury of intrinsic muscle, fascia and tendon of left little finger at wrist and hand level, sequela*/
,'S66598D'  /*Other injury of intrinsic muscle, fascia and tendon of other finger at wrist and hand level, subsequent encounter*/
,'S66598S'  /*Other injury of intrinsic muscle, fascia and tendon of other finger at wrist and hand level, sequela*/
,'S66599D'  /*Other injury of intrinsic muscle, fascia and tendon of unspecified finger at wrist and hand level, subsequent encounter*/
,'S66599S'  /*Other injury of intrinsic muscle, fascia and tendon of unspecified finger at wrist and hand level, sequela*/
,'S66801D'  /*Unspecified injury of other specified muscles, fascia and tendons at wrist and hand level, right hand, subsequent encounter*/
,'S66801S'  /*Unspecified injury of other specified muscles, fascia and tendons at wrist and hand level, right hand, sequela*/
,'S66802D'  /*Unspecified injury of other specified muscles, fascia and tendons at wrist and hand level, left hand, subsequent encounter*/
,'S66802S'  /*Unspecified injury of other specified muscles, fascia and tendons at wrist and hand level, left hand, sequela*/
,'S66809D'  /*Unspecified injury of other specified muscles, fascia and tendons at wrist and hand level, unspecified hand, subsequent encounter*/
,'S66809S'  /*Unspecified injury of other specified muscles, fascia and tendons at wrist and hand level, unspecified hand, sequela*/
,'S66811D'  /*Strain of other specified muscles, fascia and tendons at wrist and hand level, right hand, subsequent encounter*/
,'S66811S'  /*Strain of other specified muscles, fascia and tendons at wrist and hand level, right hand, sequela*/
,'S66812D'  /*Strain of other specified muscles, fascia and tendons at wrist and hand level, left hand, subsequent encounter*/
,'S66812S'  /*Strain of other specified muscles, fascia and tendons at wrist and hand level, left hand, sequela*/
,'S66819D'  /*Strain of other specified muscles, fascia and tendons at wrist and hand level, unspecified hand, subsequent encounter*/
,'S66819S'  /*Strain of other specified muscles, fascia and tendons at wrist and hand level, unspecified hand, sequela*/
,'S66821D'  /*Laceration of other specified muscles, fascia and tendons at wrist and hand level, right hand, subsequent encounter*/
,'S66821S'  /*Laceration of other specified muscles, fascia and tendons at wrist and hand level, right hand, sequela*/
,'S66822D'  /*Laceration of other specified muscles, fascia and tendons at wrist and hand level, left hand, subsequent encounter*/
,'S66822S'  /*Laceration of other specified muscles, fascia and tendons at wrist and hand level, left hand, sequela*/
,'S66829D'  /*Laceration of other specified muscles, fascia and tendons at wrist and hand level, unspecified hand, subsequent encounter*/
,'S66829S'  /*Laceration of other specified muscles, fascia and tendons at wrist and hand level, unspecified hand, sequela*/
,'S66891D'  /*Other injury of other specified muscles, fascia and tendons at wrist and hand level, right hand, subsequent encounter*/
,'S66891S'  /*Other injury of other specified muscles, fascia and tendons at wrist and hand level, right hand, sequela*/
,'S66892D'  /*Other injury of other specified muscles, fascia and tendons at wrist and hand level, left hand, subsequent encounter*/
,'S66892S'  /*Other injury of other specified muscles, fascia and tendons at wrist and hand level, left hand, sequela*/
,'S66899D'  /*Other injury of other specified muscles, fascia and tendons at wrist and hand level, unspecified hand, subsequent encounter*/
,'S66899S'  /*Other injury of other specified muscles, fascia and tendons at wrist and hand level, unspecified hand, sequela*/
,'S66901D'  /*Unspecified injury of unspecified muscle, fascia and tendon at wrist and hand level, right hand, subsequent encounter*/
,'S66901S'  /*Unspecified injury of unspecified muscle, fascia and tendon at wrist and hand level, right hand, sequela*/
,'S66902D'  /*Unspecified injury of unspecified muscle, fascia and tendon at wrist and hand level, left hand, subsequent encounter*/
,'S66902S'  /*Unspecified injury of unspecified muscle, fascia and tendon at wrist and hand level, left hand, sequela*/
,'S66909D'  /*Unspecified injury of unspecified muscle, fascia and tendon at wrist and hand level, unspecified hand, subsequent encounter*/
,'S66909S'  /*Unspecified injury of unspecified muscle, fascia and tendon at wrist and hand level, unspecified hand, sequela*/
,'S66911D'  /*Strain of unspecified muscle, fascia and tendon at wrist and hand level, right hand, subsequent encounter*/
,'S66911S'  /*Strain of unspecified muscle, fascia and tendon at wrist and hand level, right hand, sequela*/
,'S66912D'  /*Strain of unspecified muscle, fascia and tendon at wrist and hand level, left hand, subsequent encounter*/
,'S66912S'  /*Strain of unspecified muscle, fascia and tendon at wrist and hand level, left hand, sequela*/
,'S66919D'  /*Strain of unspecified muscle, fascia and tendon at wrist and hand level, unspecified hand, subsequent encounter*/
,'S66919S'  /*Strain of unspecified muscle, fascia and tendon at wrist and hand level, unspecified hand, sequela*/
,'S66921D'  /*Laceration of unspecified muscle, fascia and tendon at wrist and hand level, right hand, subsequent encounter*/
,'S66921S'  /*Laceration of unspecified muscle, fascia and tendon at wrist and hand level, right hand, sequela*/
,'S66922D'  /*Laceration of unspecified muscle, fascia and tendon at wrist and hand level, left hand, subsequent encounter*/
,'S66922S'  /*Laceration of unspecified muscle, fascia and tendon at wrist and hand level, left hand, sequela*/
,'S66929D'  /*Laceration of unspecified muscle, fascia and tendon at wrist and hand level, unspecified hand, subsequent encounter*/
,'S66929S'  /*Laceration of unspecified muscle, fascia and tendon at wrist and hand level, unspecified hand, sequela*/
,'S66991D'  /*Other injury of unspecified muscle, fascia and tendon at wrist and hand level, right hand, subsequent encounter*/
,'S66991S'  /*Other injury of unspecified muscle, fascia and tendon at wrist and hand level, right hand, sequela*/
,'S66992D'  /*Other injury of unspecified muscle, fascia and tendon at wrist and hand level, left hand, subsequent encounter*/
,'S66992S'  /*Other injury of unspecified muscle, fascia and tendon at wrist and hand level, left hand, sequela*/
,'S66999D'  /*Other injury of unspecified muscle, fascia and tendon at wrist and hand level, unspecified hand, subsequent encounter*/
,'S66999S'  /*Other injury of unspecified muscle, fascia and tendon at wrist and hand level, unspecified hand, sequela*/
,'S6700XD'  /*Crushing injury of unspecified thumb, subsequent encounter*/
,'S6700XS'  /*Crushing injury of unspecified thumb, sequela*/
,'S6701XD'  /*Crushing injury of right thumb, subsequent encounter*/
,'S6701XS'  /*Crushing injury of right thumb, sequela*/
,'S6702XD'  /*Crushing injury of left thumb, subsequent encounter*/
,'S6702XS'  /*Crushing injury of left thumb, sequela*/
,'S6710XD'  /*Crushing injury of unspecified finger(s), subsequent encounter*/
,'S6710XS'  /*Crushing injury of unspecified finger(s), sequela*/
,'S67190D'  /*Crushing injury of right index finger, subsequent encounter*/
,'S67190S'  /*Crushing injury of right index finger, sequela*/
,'S67191D'  /*Crushing injury of left index finger, subsequent encounter*/
,'S67191S'  /*Crushing injury of left index finger, sequela*/
,'S67192D'  /*Crushing injury of right middle finger, subsequent encounter*/
,'S67192S'  /*Crushing injury of right middle finger, sequela*/
,'S67193D'  /*Crushing injury of left middle finger, subsequent encounter*/
,'S67193S'  /*Crushing injury of left middle finger, sequela*/
,'S67194D'  /*Crushing injury of right ring finger, subsequent encounter*/
,'S67194S'  /*Crushing injury of right ring finger, sequela*/
,'S67195D'  /*Crushing injury of left ring finger, subsequent encounter*/
,'S67195S'  /*Crushing injury of left ring finger, sequela*/
,'S67196D'  /*Crushing injury of right little finger, subsequent encounter*/
,'S67196S'  /*Crushing injury of right little finger, sequela*/
,'S67197D'  /*Crushing injury of left little finger, subsequent encounter*/
,'S67197S'  /*Crushing injury of left little finger, sequela*/
,'S67198D'  /*Crushing injury of other finger, subsequent encounter*/
,'S67198S'  /*Crushing injury of other finger, sequela*/
,'S6720XD'  /*Crushing injury of unspecified hand, subsequent encounter*/
,'S6720XS'  /*Crushing injury of unspecified hand, sequela*/
,'S6721XD'  /*Crushing injury of right hand, subsequent encounter*/
,'S6721XS'  /*Crushing injury of right hand, sequela*/
,'S6722XD'  /*Crushing injury of left hand, subsequent encounter*/
,'S6722XS'  /*Crushing injury of left hand, sequela*/
,'S6730XD'  /*Crushing injury of unspecified wrist, subsequent encounter*/
,'S6730XS'  /*Crushing injury of unspecified wrist, sequela*/
,'S6731XD'  /*Crushing injury of right wrist, subsequent encounter*/
,'S6731XS'  /*Crushing injury of right wrist, sequela*/
,'S6732XD'  /*Crushing injury of left wrist, subsequent encounter*/
,'S6732XS'  /*Crushing injury of left wrist, sequela*/
,'S6740XD'  /*Crushing injury of unspecified wrist and hand, subsequent encounter*/
,'S6740XS'  /*Crushing injury of unspecified wrist and hand, sequela*/
,'S6741XD'  /*Crushing injury of right wrist and hand, subsequent encounter*/
,'S6741XS'  /*Crushing injury of right wrist and hand, sequela*/
,'S6742XD'  /*Crushing injury of left wrist and hand, subsequent encounter*/
,'S6742XS'  /*Crushing injury of left wrist and hand, sequela*/
,'S6790XD'  /*Crushing injury of unspecified part(s) of unspecified wrist, hand and fingers, subsequent encounter*/
,'S6790XS'  /*Crushing injury of unspecified part(s) of unspecified wrist, hand and fingers, sequela*/
,'S6791XD'  /*Crushing injury of unspecified part(s) of right wrist, hand and fingers, subsequent encounter*/
,'S6791XS'  /*Crushing injury of unspecified part(s) of right wrist, hand and fingers, sequela*/
,'S6792XD'  /*Crushing injury of unspecified part(s) of left wrist, hand and fingers, subsequent encounter*/
,'S6792XS'  /*Crushing injury of unspecified part(s) of left wrist, hand and fingers, sequela*/
,'S68011D'  /*Complete traumatic metacarpophalangeal amputation of right thumb, subsequent encounter*/
,'S68011S'  /*Complete traumatic metacarpophalangeal amputation of right thumb, sequela*/
,'S68012D'  /*Complete traumatic metacarpophalangeal amputation of left thumb, subsequent encounter*/
,'S68012S'  /*Complete traumatic metacarpophalangeal amputation of left thumb, sequela*/
,'S68019D'  /*Complete traumatic metacarpophalangeal amputation of unspecified thumb, subsequent encounter*/
,'S68019S'  /*Complete traumatic metacarpophalangeal amputation of unspecified thumb, sequela*/
,'S68021D'  /*Partial traumatic metacarpophalangeal amputation of right thumb, subsequent encounter*/
,'S68021S'  /*Partial traumatic metacarpophalangeal amputation of right thumb, sequela*/
,'S68022D'  /*Partial traumatic metacarpophalangeal amputation of left thumb, subsequent encounter*/
,'S68022S'  /*Partial traumatic metacarpophalangeal amputation of left thumb, sequela*/
,'S68029D'  /*Partial traumatic metacarpophalangeal amputation of unspecified thumb, subsequent encounter*/
,'S68029S'  /*Partial traumatic metacarpophalangeal amputation of unspecified thumb, sequela*/
,'S68110D'  /*Complete traumatic metacarpophalangeal amputation of right index finger, subsequent encounter*/
,'S68110S'  /*Complete traumatic metacarpophalangeal amputation of right index finger, sequela*/
,'S68111D'  /*Complete traumatic metacarpophalangeal amputation of left index finger, subsequent encounter*/
,'S68111S'  /*Complete traumatic metacarpophalangeal amputation of left index finger, sequela*/
,'S68112D'  /*Complete traumatic metacarpophalangeal amputation of right middle finger, subsequent encounter*/
,'S68112S'  /*Complete traumatic metacarpophalangeal amputation of right middle finger, sequela*/
,'S68113D'  /*Complete traumatic metacarpophalangeal amputation of left middle finger, subsequent encounter*/
,'S68113S'  /*Complete traumatic metacarpophalangeal amputation of left middle finger, sequela*/
,'S68114D'  /*Complete traumatic metacarpophalangeal amputation of right ring finger, subsequent encounter*/
,'S68114S'  /*Complete traumatic metacarpophalangeal amputation of right ring finger, sequela*/
,'S68115D'  /*Complete traumatic metacarpophalangeal amputation of left ring finger, subsequent encounter*/
,'S68115S'  /*Complete traumatic metacarpophalangeal amputation of left ring finger, sequela*/
,'S68116D'  /*Complete traumatic metacarpophalangeal amputation of right little finger, subsequent encounter*/
,'S68116S'  /*Complete traumatic metacarpophalangeal amputation of right little finger, sequela*/
,'S68117D'  /*Complete traumatic metacarpophalangeal amputation of left little finger, subsequent encounter*/
,'S68117S'  /*Complete traumatic metacarpophalangeal amputation of left little finger, sequela*/
,'S68118D'  /*Complete traumatic metacarpophalangeal amputation of other finger, subsequent encounter*/
,'S68118S'  /*Complete traumatic metacarpophalangeal amputation of other finger, sequela*/
,'S68119D'  /*Complete traumatic metacarpophalangeal amputation of unspecified finger, subsequent encounter*/
,'S68119S'  /*Complete traumatic metacarpophalangeal amputation of unspecified finger, sequela*/
,'S68120D'  /*Partial traumatic metacarpophalangeal amputation of right index finger, subsequent encounter*/
,'S68120S'  /*Partial traumatic metacarpophalangeal amputation of right index finger, sequela*/
,'S68121D'  /*Partial traumatic metacarpophalangeal amputation of left index finger, subsequent encounter*/
,'S68121S'  /*Partial traumatic metacarpophalangeal amputation of left index finger, sequela*/
,'S68122D'  /*Partial traumatic metacarpophalangeal amputation of right middle finger, subsequent encounter*/
,'S68122S'  /*Partial traumatic metacarpophalangeal amputation of right middle finger, sequela*/
,'S68123D'  /*Partial traumatic metacarpophalangeal amputation of left middle finger, subsequent encounter*/
,'S68123S'  /*Partial traumatic metacarpophalangeal amputation of left middle finger, sequela*/
,'S68124D'  /*Partial traumatic metacarpophalangeal amputation of right ring finger, subsequent encounter*/
,'S68124S'  /*Partial traumatic metacarpophalangeal amputation of right ring finger, sequela*/
,'S68125D'  /*Partial traumatic metacarpophalangeal amputation of left ring finger, subsequent encounter*/
,'S68125S'  /*Partial traumatic metacarpophalangeal amputation of left ring finger, sequela*/
,'S68126D'  /*Partial traumatic metacarpophalangeal amputation of right little finger, subsequent encounter*/
,'S68126S'  /*Partial traumatic metacarpophalangeal amputation of right little finger, sequela*/
,'S68127D'  /*Partial traumatic metacarpophalangeal amputation of left little finger, subsequent encounter*/
,'S68127S'  /*Partial traumatic metacarpophalangeal amputation of left little finger, sequela*/
,'S68128D'  /*Partial traumatic metacarpophalangeal amputation of other finger, subsequent encounter*/
,'S68128S'  /*Partial traumatic metacarpophalangeal amputation of other finger, sequela*/
,'S68129D'  /*Partial traumatic metacarpophalangeal amputation of unspecified finger, subsequent encounter*/
,'S68129S'  /*Partial traumatic metacarpophalangeal amputation of unspecified finger, sequela*/
,'S68411D'  /*Complete traumatic amputation of right hand at wrist level, subsequent encounter*/
,'S68411S'  /*Complete traumatic amputation of right hand at wrist level, sequela*/
,'S68412D'  /*Complete traumatic amputation of left hand at wrist level, subsequent encounter*/
,'S68412S'  /*Complete traumatic amputation of left hand at wrist level, sequela*/
,'S68419D'  /*Complete traumatic amputation of unspecified hand at wrist level, subsequent encounter*/
,'S68419S'  /*Complete traumatic amputation of unspecified hand at wrist level, sequela*/
,'S68421D'  /*Partial traumatic amputation of right hand at wrist level, subsequent encounter*/
,'S68421S'  /*Partial traumatic amputation of right hand at wrist level, sequela*/
,'S68422D'  /*Partial traumatic amputation of left hand at wrist level, subsequent encounter*/
,'S68422S'  /*Partial traumatic amputation of left hand at wrist level, sequela*/
,'S68429D'  /*Partial traumatic amputation of unspecified hand at wrist level, subsequent encounter*/
,'S68429S'  /*Partial traumatic amputation of unspecified hand at wrist level, sequela*/
,'S68511D'  /*Complete traumatic transphalangeal amputation of right thumb, subsequent encounter*/
,'S68511S'  /*Complete traumatic transphalangeal amputation of right thumb, sequela*/
,'S68512D'  /*Complete traumatic transphalangeal amputation of left thumb, subsequent encounter*/
,'S68512S'  /*Complete traumatic transphalangeal amputation of left thumb, sequela*/
,'S68519D'  /*Complete traumatic transphalangeal amputation of unspecified thumb, subsequent encounter*/
,'S68519S'  /*Complete traumatic transphalangeal amputation of unspecified thumb, sequela*/
,'S68521D'  /*Partial traumatic transphalangeal amputation of right thumb, subsequent encounter*/
,'S68521S'  /*Partial traumatic transphalangeal amputation of right thumb, sequela*/
,'S68522D'  /*Partial traumatic transphalangeal amputation of left thumb, subsequent encounter*/
,'S68522S'  /*Partial traumatic transphalangeal amputation of left thumb, sequela*/
,'S68529D'  /*Partial traumatic transphalangeal amputation of unspecified thumb, subsequent encounter*/
,'S68529S'  /*Partial traumatic transphalangeal amputation of unspecified thumb, sequela*/
,'S68610D'  /*Complete traumatic transphalangeal amputation of right index finger, subsequent encounter*/
,'S68610S'  /*Complete traumatic transphalangeal amputation of right index finger, sequela*/
,'S68611D'  /*Complete traumatic transphalangeal amputation of left index finger, subsequent encounter*/
,'S68611S'  /*Complete traumatic transphalangeal amputation of left index finger, sequela*/
,'S68612D'  /*Complete traumatic transphalangeal amputation of right middle finger, subsequent encounter*/
,'S68612S'  /*Complete traumatic transphalangeal amputation of right middle finger, sequela*/
,'S68613D'  /*Complete traumatic transphalangeal amputation of left middle finger, subsequent encounter*/
,'S68613S'  /*Complete traumatic transphalangeal amputation of left middle finger, sequela*/
,'S68614D'  /*Complete traumatic transphalangeal amputation of right ring finger, subsequent encounter*/
,'S68614S'  /*Complete traumatic transphalangeal amputation of right ring finger, sequela*/
,'S68615D'  /*Complete traumatic transphalangeal amputation of left ring finger, subsequent encounter*/
,'S68615S'  /*Complete traumatic transphalangeal amputation of left ring finger, sequela*/
,'S68616D'  /*Complete traumatic transphalangeal amputation of right little finger, subsequent encounter*/
,'S68616S'  /*Complete traumatic transphalangeal amputation of right little finger, sequela*/
,'S68617D'  /*Complete traumatic transphalangeal amputation of left little finger, subsequent encounter*/
,'S68617S'  /*Complete traumatic transphalangeal amputation of left little finger, sequela*/
,'S68618D'  /*Complete traumatic transphalangeal amputation of other finger, subsequent encounter*/
,'S68618S'  /*Complete traumatic transphalangeal amputation of other finger, sequela*/
,'S68619D'  /*Complete traumatic transphalangeal amputation of unspecified finger, subsequent encounter*/
,'S68619S'  /*Complete traumatic transphalangeal amputation of unspecified finger, sequela*/
,'S68620D'  /*Partial traumatic transphalangeal amputation of right index finger, subsequent encounter*/
,'S68620S'  /*Partial traumatic transphalangeal amputation of right index finger, sequela*/
,'S68621D'  /*Partial traumatic transphalangeal amputation of left index finger, subsequent encounter*/
,'S68621S'  /*Partial traumatic transphalangeal amputation of left index finger, sequela*/
,'S68622D'  /*Partial traumatic transphalangeal amputation of right middle finger, subsequent encounter*/
,'S68622S'  /*Partial traumatic transphalangeal amputation of right middle finger, sequela*/
,'S68623D'  /*Partial traumatic transphalangeal amputation of left middle finger, subsequent encounter*/
,'S68623S'  /*Partial traumatic transphalangeal amputation of left middle finger, sequela*/
,'S68624D'  /*Partial traumatic transphalangeal amputation of right ring finger, subsequent encounter*/
,'S68624S'  /*Partial traumatic transphalangeal amputation of right ring finger, sequela*/
,'S68625D'  /*Partial traumatic transphalangeal amputation of left ring finger, subsequent encounter*/
,'S68625S'  /*Partial traumatic transphalangeal amputation of left ring finger, sequela*/
,'S68626D'  /*Partial traumatic transphalangeal amputation of right little finger, subsequent encounter*/
,'S68626S'  /*Partial traumatic transphalangeal amputation of right little finger, sequela*/
,'S68627D'  /*Partial traumatic transphalangeal amputation of left little finger, subsequent encounter*/
,'S68627S'  /*Partial traumatic transphalangeal amputation of left little finger, sequela*/
,'S68628D'  /*Partial traumatic transphalangeal amputation of other finger, subsequent encounter*/
,'S68628S'  /*Partial traumatic transphalangeal amputation of other finger, sequela*/
,'S68629D'  /*Partial traumatic transphalangeal amputation of unspecified finger, subsequent encounter*/
,'S68629S'  /*Partial traumatic transphalangeal amputation of unspecified finger, sequela*/
,'S68711D'  /*Complete traumatic transmetacarpal amputation of right hand, subsequent encounter*/
,'S68711S'  /*Complete traumatic transmetacarpal amputation of right hand, sequela*/
,'S68712D'  /*Complete traumatic transmetacarpal amputation of left hand, subsequent encounter*/
,'S68712S'  /*Complete traumatic transmetacarpal amputation of left hand, sequela*/
,'S68719D'  /*Complete traumatic transmetacarpal amputation of unspecified hand, subsequent encounter*/
,'S68719S'  /*Complete traumatic transmetacarpal amputation of unspecified hand, sequela*/
,'S68721D'  /*Partial traumatic transmetacarpal amputation of right hand, subsequent encounter*/
,'S68721S'  /*Partial traumatic transmetacarpal amputation of right hand, sequela*/
,'S68722D'  /*Partial traumatic transmetacarpal amputation of left hand, subsequent encounter*/
,'S68722S'  /*Partial traumatic transmetacarpal amputation of left hand, sequela*/
,'S68729D'  /*Partial traumatic transmetacarpal amputation of unspecified hand, subsequent encounter*/
,'S68729S'  /*Partial traumatic transmetacarpal amputation of unspecified hand, sequela*/
,'S6980XD'  /*Other specified injuries of unspecified wrist, hand and finger(s), subsequent encounter*/
,'S6980XS'  /*Other specified injuries of unspecified wrist, hand and finger(s), sequela*/
,'S6981XD'  /*Other specified injuries of right wrist, hand and finger(s), subsequent encounter*/
,'S6981XS'  /*Other specified injuries of right wrist, hand and finger(s), sequela*/
,'S6982XD'  /*Other specified injuries of left wrist, hand and finger(s), subsequent encounter*/
,'S6982XS'  /*Other specified injuries of left wrist, hand and finger(s), sequela*/
,'S6990XD'  /*Unspecified injury of unspecified wrist, hand and finger(s), subsequent encounter*/
,'S6990XS'  /*Unspecified injury of unspecified wrist, hand and finger(s), sequela*/
,'S6991XD'  /*Unspecified injury of right wrist, hand and finger(s), subsequent encounter*/
,'S6991XS'  /*Unspecified injury of right wrist, hand and finger(s), sequela*/
,'S6992XD'  /*Unspecified injury of left wrist, hand and finger(s), subsequent encounter*/
,'S6992XS'  /*Unspecified injury of left wrist, hand and finger(s), sequela*/
,'S7000XD'  /*Contusion of unspecified hip, subsequent encounter*/
,'S7000XS'  /*Contusion of unspecified hip, sequela*/
,'S7001XD'  /*Contusion of right hip, subsequent encounter*/
,'S7001XS'  /*Contusion of right hip, sequela*/
,'S7002XD'  /*Contusion of left hip, subsequent encounter*/
,'S7002XS'  /*Contusion of left hip, sequela*/
,'S7010XD'  /*Contusion of unspecified thigh, subsequent encounter*/
,'S7010XS'  /*Contusion of unspecified thigh, sequela*/
,'S7011XD'  /*Contusion of right thigh, subsequent encounter*/
,'S7011XS'  /*Contusion of right thigh, sequela*/
,'S7012XD'  /*Contusion of left thigh, subsequent encounter*/
,'S7012XS'  /*Contusion of left thigh, sequela*/
,'S70211D'  /*Abrasion, right hip, subsequent encounter*/
,'S70211S'  /*Abrasion, right hip, sequela*/
,'S70212D'  /*Abrasion, left hip, subsequent encounter*/
,'S70212S'  /*Abrasion, left hip, sequela*/
,'S70219D'  /*Abrasion, unspecified hip, subsequent encounter*/
,'S70219S'  /*Abrasion, unspecified hip, sequela*/
,'S70221D'  /*Blister (nonthermal), right hip, subsequent encounter*/
,'S70221S'  /*Blister (nonthermal), right hip, sequela*/
,'S70222D'  /*Blister (nonthermal), left hip, subsequent encounter*/
,'S70222S'  /*Blister (nonthermal), left hip, sequela*/
,'S70229D'  /*Blister (nonthermal), unspecified hip, subsequent encounter*/
,'S70229S'  /*Blister (nonthermal), unspecified hip, sequela*/
,'S70241D'  /*External constriction, right hip, subsequent encounter*/
,'S70241S'  /*External constriction, right hip, sequela*/
,'S70242D'  /*External constriction, left hip, subsequent encounter*/
,'S70242S'  /*External constriction, left hip, sequela*/
,'S70249D'  /*External constriction, unspecified hip, subsequent encounter*/
,'S70249S'  /*External constriction, unspecified hip, sequela*/
,'S70251D'  /*Superficial foreign body, right hip, subsequent encounter*/
,'S70251S'  /*Superficial foreign body, right hip, sequela*/
,'S70252D'  /*Superficial foreign body, left hip, subsequent encounter*/
,'S70252S'  /*Superficial foreign body, left hip, sequela*/
,'S70259D'  /*Superficial foreign body, unspecified hip, subsequent encounter*/
,'S70259S'  /*Superficial foreign body, unspecified hip, sequela*/
,'S70261D'  /*Insect bite (nonvenomous), right hip, subsequent encounter*/
,'S70261S'  /*Insect bite (nonvenomous), right hip, sequela*/
,'S70262D'  /*Insect bite (nonvenomous), left hip, subsequent encounter*/
,'S70262S'  /*Insect bite (nonvenomous), left hip, sequela*/
,'S70269D'  /*Insect bite (nonvenomous), unspecified hip, subsequent encounter*/
,'S70269S'  /*Insect bite (nonvenomous), unspecified hip, sequela*/
,'S70271D'  /*Other superficial bite of hip, right hip, subsequent encounter*/
,'S70271S'  /*Other superficial bite of hip, right hip, sequela*/
,'S70272D'  /*Other superficial bite of hip, left hip, subsequent encounter*/
,'S70272S'  /*Other superficial bite of hip, left hip, sequela*/
,'S70279D'  /*Other superficial bite of hip, unspecified hip, subsequent encounter*/
,'S70279S'  /*Other superficial bite of hip, unspecified hip, sequela*/
,'S70311D'  /*Abrasion, right thigh, subsequent encounter*/
,'S70311S'  /*Abrasion, right thigh, sequela*/
,'S70312D'  /*Abrasion, left thigh, subsequent encounter*/
,'S70312S'  /*Abrasion, left thigh, sequela*/
,'S70319D'  /*Abrasion, unspecified thigh, subsequent encounter*/
,'S70319S'  /*Abrasion, unspecified thigh, sequela*/
,'S70321D'  /*Blister (nonthermal), right thigh, subsequent encounter*/
,'S70321S'  /*Blister (nonthermal), right thigh, sequela*/
,'S70322D'  /*Blister (nonthermal), left thigh, subsequent encounter*/
,'S70322S'  /*Blister (nonthermal), left thigh, sequela*/
,'S70329D'  /*Blister (nonthermal), unspecified thigh, subsequent encounter*/
,'S70329S'  /*Blister (nonthermal), unspecified thigh, sequela*/
,'S70341D'  /*External constriction, right thigh, subsequent encounter*/
,'S70341S'  /*External constriction, right thigh, sequela*/
,'S70342D'  /*External constriction, left thigh, subsequent encounter*/
,'S70342S'  /*External constriction, left thigh, sequela*/
,'S70349D'  /*External constriction, unspecified thigh, subsequent encounter*/
,'S70349S'  /*External constriction, unspecified thigh, sequela*/
,'S70351D'  /*Superficial foreign body, right thigh, subsequent encounter*/
,'S70351S'  /*Superficial foreign body, right thigh, sequela*/
,'S70352D'  /*Superficial foreign body, left thigh, subsequent encounter*/
,'S70352S'  /*Superficial foreign body, left thigh, sequela*/
,'S70359D'  /*Superficial foreign body, unspecified thigh, subsequent encounter*/
,'S70359S'  /*Superficial foreign body, unspecified thigh, sequela*/
,'S70361D'  /*Insect bite (nonvenomous), right thigh, subsequent encounter*/
,'S70361S'  /*Insect bite (nonvenomous), right thigh, sequela*/
,'S70362D'  /*Insect bite (nonvenomous), left thigh, subsequent encounter*/
,'S70362S'  /*Insect bite (nonvenomous), left thigh, sequela*/
,'S70369D'  /*Insect bite (nonvenomous), unspecified thigh, subsequent encounter*/
,'S70369S'  /*Insect bite (nonvenomous), unspecified thigh, sequela*/
,'S70371D'  /*Other superficial bite of right thigh, subsequent encounter*/
,'S70371S'  /*Other superficial bite of right thigh, sequela*/
,'S70372D'  /*Other superficial bite of left thigh, subsequent encounter*/
,'S70372S'  /*Other superficial bite of left thigh, sequela*/
,'S70379D'  /*Other superficial bite of unspecified thigh, subsequent encounter*/
,'S70379S'  /*Other superficial bite of unspecified thigh, sequela*/
,'S70911D'  /*Unspecified superficial injury of right hip, subsequent encounter*/
,'S70911S'  /*Unspecified superficial injury of right hip, sequela*/
,'S70912D'  /*Unspecified superficial injury of left hip, subsequent encounter*/
,'S70912S'  /*Unspecified superficial injury of left hip, sequela*/
,'S70919D'  /*Unspecified superficial injury of unspecified hip, subsequent encounter*/
,'S70919S'  /*Unspecified superficial injury of unspecified hip, sequela*/
,'S70921D'  /*Unspecified superficial injury of right thigh, subsequent encounter*/
,'S70921S'  /*Unspecified superficial injury of right thigh, sequela*/
,'S70922D'  /*Unspecified superficial injury of left thigh, subsequent encounter*/
,'S70922S'  /*Unspecified superficial injury of left thigh, sequela*/
,'S70929D'  /*Unspecified superficial injury of unspecified thigh, subsequent encounter*/
,'S70929S'  /*Unspecified superficial injury of unspecified thigh, sequela*/
,'S71001D'  /*Unspecified open wound, right hip, subsequent encounter*/
,'S71001S'  /*Unspecified open wound, right hip, sequela*/
,'S71002D'  /*Unspecified open wound, left hip, subsequent encounter*/
,'S71002S'  /*Unspecified open wound, left hip, sequela*/
,'S71009D'  /*Unspecified open wound, unspecified hip, subsequent encounter*/
,'S71009S'  /*Unspecified open wound, unspecified hip, sequela*/
,'S71011D'  /*Laceration without foreign body, right hip, subsequent encounter*/
,'S71011S'  /*Laceration without foreign body, right hip, sequela*/
,'S71012D'  /*Laceration without foreign body, left hip, subsequent encounter*/
,'S71012S'  /*Laceration without foreign body, left hip, sequela*/
,'S71019D'  /*Laceration without foreign body, unspecified hip, subsequent encounter*/
,'S71019S'  /*Laceration without foreign body, unspecified hip, sequela*/
,'S71021D'  /*Laceration with foreign body, right hip, subsequent encounter*/
,'S71021S'  /*Laceration with foreign body, right hip, sequela*/
,'S71022D'  /*Laceration with foreign body, left hip, subsequent encounter*/
,'S71022S'  /*Laceration with foreign body, left hip, sequela*/
,'S71029D'  /*Laceration with foreign body, unspecified hip, subsequent encounter*/
,'S71029S'  /*Laceration with foreign body, unspecified hip, sequela*/
,'S71031D'  /*Puncture wound without foreign body, right hip, subsequent encounter*/
,'S71031S'  /*Puncture wound without foreign body, right hip, sequela*/
,'S71032D'  /*Puncture wound without foreign body, left hip, subsequent encounter*/
,'S71032S'  /*Puncture wound without foreign body, left hip, sequela*/
,'S71039D'  /*Puncture wound without foreign body, unspecified hip, subsequent encounter*/
,'S71039S'  /*Puncture wound without foreign body, unspecified hip, sequela*/
,'S71041D'  /*Puncture wound with foreign body, right hip, subsequent encounter*/
,'S71041S'  /*Puncture wound with foreign body, right hip, sequela*/
,'S71042D'  /*Puncture wound with foreign body, left hip, subsequent encounter*/
,'S71042S'  /*Puncture wound with foreign body, left hip, sequela*/
,'S71049D'  /*Puncture wound with foreign body, unspecified hip, subsequent encounter*/
,'S71049S'  /*Puncture wound with foreign body, unspecified hip, sequela*/
,'S71051D'  /*Open bite, right hip, subsequent encounter*/
,'S71051S'  /*Open bite, right hip, sequela*/
,'S71052D'  /*Open bite, left hip, subsequent encounter*/
,'S71052S'  /*Open bite, left hip, sequela*/
,'S71059D'  /*Open bite, unspecified hip, subsequent encounter*/
,'S71059S'  /*Open bite, unspecified hip, sequela*/
,'S71101D'  /*Unspecified open wound, right thigh, subsequent encounter*/
,'S71101S'  /*Unspecified open wound, right thigh, sequela*/
,'S71102D'  /*Unspecified open wound, left thigh, subsequent encounter*/
,'S71102S'  /*Unspecified open wound, left thigh, sequela*/
,'S71109D'  /*Unspecified open wound, unspecified thigh, subsequent encounter*/
,'S71109S'  /*Unspecified open wound, unspecified thigh, sequela*/
,'S71111D'  /*Laceration without foreign body, right thigh, subsequent encounter*/
,'S71111S'  /*Laceration without foreign body, right thigh, sequela*/
,'S71112D'  /*Laceration without foreign body, left thigh, subsequent encounter*/
,'S71112S'  /*Laceration without foreign body, left thigh, sequela*/
,'S71119D'  /*Laceration without foreign body, unspecified thigh, subsequent encounter*/
,'S71119S'  /*Laceration without foreign body, unspecified thigh, sequela*/
,'S71121D'  /*Laceration with foreign body, right thigh, subsequent encounter*/
,'S71121S'  /*Laceration with foreign body, right thigh, sequela*/
,'S71122D'  /*Laceration with foreign body, left thigh, subsequent encounter*/
,'S71122S'  /*Laceration with foreign body, left thigh, sequela*/
,'S71129D'  /*Laceration with foreign body, unspecified thigh, subsequent encounter*/
,'S71129S'  /*Laceration with foreign body, unspecified thigh, sequela*/
,'S71131D'  /*Puncture wound without foreign body, right thigh, subsequent encounter*/
,'S71131S'  /*Puncture wound without foreign body, right thigh, sequela*/
,'S71132D'  /*Puncture wound without foreign body, left thigh, subsequent encounter*/
,'S71132S'  /*Puncture wound without foreign body, left thigh, sequela*/
,'S71139D'  /*Puncture wound without foreign body, unspecified thigh, subsequent encounter*/
,'S71139S'  /*Puncture wound without foreign body, unspecified thigh, sequela*/
,'S71141D'  /*Puncture wound with foreign body, right thigh, subsequent encounter*/
,'S71141S'  /*Puncture wound with foreign body, right thigh, sequela*/
,'S71142D'  /*Puncture wound with foreign body, left thigh, subsequent encounter*/
,'S71142S'  /*Puncture wound with foreign body, left thigh, sequela*/
,'S71149D'  /*Puncture wound with foreign body, unspecified thigh, subsequent encounter*/
,'S71149S'  /*Puncture wound with foreign body, unspecified thigh, sequela*/
,'S71151D'  /*Open bite, right thigh, subsequent encounter*/
,'S71151S'  /*Open bite, right thigh, sequela*/
,'S71152D'  /*Open bite, left thigh, subsequent encounter*/
,'S71152S'  /*Open bite, left thigh, sequela*/
,'S71159D'  /*Open bite, unspecified thigh, subsequent encounter*/
,'S71159S'  /*Open bite, unspecified thigh, sequela*/
,'S72001D'  /*Fracture of unspecified part of neck of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72001E'  /*Fracture of unspecified part of neck of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72001F'  /*Fracture of unspecified part of neck of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72001G'  /*Fracture of unspecified part of neck of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72001H'  /*Fracture of unspecified part of neck of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72001J'  /*Fracture of unspecified part of neck of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72001K'  /*Fracture of unspecified part of neck of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72001M'  /*Fracture of unspecified part of neck of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72001N'  /*Fracture of unspecified part of neck of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72001P'  /*Fracture of unspecified part of neck of right femur, subsequent encounter for closed fracture with malunion*/
,'S72001Q'  /*Fracture of unspecified part of neck of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72001R'  /*Fracture of unspecified part of neck of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72001S'  /*Fracture of unspecified part of neck of right femur, sequela*/
,'S72002D'  /*Fracture of unspecified part of neck of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72002E'  /*Fracture of unspecified part of neck of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72002F'  /*Fracture of unspecified part of neck of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72002G'  /*Fracture of unspecified part of neck of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72002H'  /*Fracture of unspecified part of neck of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72002J'  /*Fracture of unspecified part of neck of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72002K'  /*Fracture of unspecified part of neck of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72002M'  /*Fracture of unspecified part of neck of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72002N'  /*Fracture of unspecified part of neck of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72002P'  /*Fracture of unspecified part of neck of left femur, subsequent encounter for closed fracture with malunion*/
,'S72002Q'  /*Fracture of unspecified part of neck of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72002R'  /*Fracture of unspecified part of neck of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72002S'  /*Fracture of unspecified part of neck of left femur, sequela*/
,'S72009D'  /*Fracture of unspecified part of neck of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72009E'  /*Fracture of unspecified part of neck of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72009F'  /*Fracture of unspecified part of neck of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72009G'  /*Fracture of unspecified part of neck of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72009H'  /*Fracture of unspecified part of neck of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72009J'  /*Fracture of unspecified part of neck of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72009K'  /*Fracture of unspecified part of neck of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72009M'  /*Fracture of unspecified part of neck of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72009N'  /*Fracture of unspecified part of neck of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72009P'  /*Fracture of unspecified part of neck of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72009Q'  /*Fracture of unspecified part of neck of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72009R'  /*Fracture of unspecified part of neck of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72009S'  /*Fracture of unspecified part of neck of unspecified femur, sequela*/
,'S72011D'  /*Unspecified intracapsular fracture of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72011E'  /*Unspecified intracapsular fracture of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72011F'  /*Unspecified intracapsular fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72011G'  /*Unspecified intracapsular fracture of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72011H'  /*Unspecified intracapsular fracture of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72011J'  /*Unspecified intracapsular fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72011K'  /*Unspecified intracapsular fracture of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72011M'  /*Unspecified intracapsular fracture of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72011N'  /*Unspecified intracapsular fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72011P'  /*Unspecified intracapsular fracture of right femur, subsequent encounter for closed fracture with malunion*/
,'S72011Q'  /*Unspecified intracapsular fracture of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72011R'  /*Unspecified intracapsular fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72011S'  /*Unspecified intracapsular fracture of right femur, sequela*/
,'S72012D'  /*Unspecified intracapsular fracture of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72012E'  /*Unspecified intracapsular fracture of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72012F'  /*Unspecified intracapsular fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72012G'  /*Unspecified intracapsular fracture of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72012H'  /*Unspecified intracapsular fracture of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72012J'  /*Unspecified intracapsular fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72012K'  /*Unspecified intracapsular fracture of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72012M'  /*Unspecified intracapsular fracture of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72012N'  /*Unspecified intracapsular fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72012P'  /*Unspecified intracapsular fracture of left femur, subsequent encounter for closed fracture with malunion*/
,'S72012Q'  /*Unspecified intracapsular fracture of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72012R'  /*Unspecified intracapsular fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72012S'  /*Unspecified intracapsular fracture of left femur, sequela*/
,'S72019D'  /*Unspecified intracapsular fracture of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72019E'  /*Unspecified intracapsular fracture of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72019F'  /*Unspecified intracapsular fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72019G'  /*Unspecified intracapsular fracture of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72019H'  /*Unspecified intracapsular fracture of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72019J'  /*Unspecified intracapsular fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72019K'  /*Unspecified intracapsular fracture of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72019M'  /*Unspecified intracapsular fracture of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72019N'  /*Unspecified intracapsular fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72019P'  /*Unspecified intracapsular fracture of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72019Q'  /*Unspecified intracapsular fracture of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72019R'  /*Unspecified intracapsular fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72019S'  /*Unspecified intracapsular fracture of unspecified femur, sequela*/
,'S72021D'  /*Displaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72021E'  /*Displaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72021F'  /*Displaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72021G'  /*Displaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72021H'  /*Displaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72021J'  /*Displaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72021K'  /*Displaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72021M'  /*Displaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72021N'  /*Displaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72021P'  /*Displaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for closed fracture with malunion*/
,'S72021Q'  /*Displaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72021R'  /*Displaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72021S'  /*Displaced fracture of epiphysis (separation) (upper) of right femur, sequela*/
,'S72022D'  /*Displaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72022E'  /*Displaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72022F'  /*Displaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72022G'  /*Displaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72022H'  /*Displaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72022J'  /*Displaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72022K'  /*Displaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72022M'  /*Displaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72022N'  /*Displaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72022P'  /*Displaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for closed fracture with malunion*/
,'S72022Q'  /*Displaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72022R'  /*Displaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72022S'  /*Displaced fracture of epiphysis (separation) (upper) of left femur, sequela*/
,'S72023D'  /*Displaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72023E'  /*Displaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72023F'  /*Displaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72023G'  /*Displaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72023H'  /*Displaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72023J'  /*Displaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72023K'  /*Displaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72023M'  /*Displaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72023N'  /*Displaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72023P'  /*Displaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72023Q'  /*Displaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72023R'  /*Displaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72023S'  /*Displaced fracture of epiphysis (separation) (upper) of unspecified femur, sequela*/
,'S72024D'  /*Nondisplaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72024E'  /*Nondisplaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72024F'  /*Nondisplaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72024G'  /*Nondisplaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72024H'  /*Nondisplaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72024J'  /*Nondisplaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72024K'  /*Nondisplaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72024M'  /*Nondisplaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72024N'  /*Nondisplaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72024P'  /*Nondisplaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for closed fracture with malunion*/
,'S72024Q'  /*Nondisplaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72024R'  /*Nondisplaced fracture of epiphysis (separation) (upper) of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72024S'  /*Nondisplaced fracture of epiphysis (separation) (upper) of right femur, sequela*/
,'S72025D'  /*Nondisplaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72025E'  /*Nondisplaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72025F'  /*Nondisplaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72025G'  /*Nondisplaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72025H'  /*Nondisplaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72025J'  /*Nondisplaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72025K'  /*Nondisplaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72025M'  /*Nondisplaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72025N'  /*Nondisplaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72025P'  /*Nondisplaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for closed fracture with malunion*/
,'S72025Q'  /*Nondisplaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72025R'  /*Nondisplaced fracture of epiphysis (separation) (upper) of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72025S'  /*Nondisplaced fracture of epiphysis (separation) (upper) of left femur, sequela*/
,'S72026D'  /*Nondisplaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72026E'  /*Nondisplaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72026F'  /*Nondisplaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72026G'  /*Nondisplaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72026H'  /*Nondisplaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72026J'  /*Nondisplaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72026K'  /*Nondisplaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72026M'  /*Nondisplaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72026N'  /*Nondisplaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72026P'  /*Nondisplaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72026Q'  /*Nondisplaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72026R'  /*Nondisplaced fracture of epiphysis (separation) (upper) of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72026S'  /*Nondisplaced fracture of epiphysis (separation) (upper) of unspecified femur, sequela*/
,'S72031D'  /*Displaced midcervical fracture of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72031E'  /*Displaced midcervical fracture of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72031F'  /*Displaced midcervical fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72031G'  /*Displaced midcervical fracture of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72031H'  /*Displaced midcervical fracture of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72031J'  /*Displaced midcervical fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72031K'  /*Displaced midcervical fracture of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72031M'  /*Displaced midcervical fracture of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72031N'  /*Displaced midcervical fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72031P'  /*Displaced midcervical fracture of right femur, subsequent encounter for closed fracture with malunion*/
,'S72031Q'  /*Displaced midcervical fracture of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72031R'  /*Displaced midcervical fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72031S'  /*Displaced midcervical fracture of right femur, sequela*/
,'S72032D'  /*Displaced midcervical fracture of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72032E'  /*Displaced midcervical fracture of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72032F'  /*Displaced midcervical fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72032G'  /*Displaced midcervical fracture of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72032H'  /*Displaced midcervical fracture of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72032J'  /*Displaced midcervical fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72032K'  /*Displaced midcervical fracture of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72032M'  /*Displaced midcervical fracture of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72032N'  /*Displaced midcervical fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72032P'  /*Displaced midcervical fracture of left femur, subsequent encounter for closed fracture with malunion*/
,'S72032Q'  /*Displaced midcervical fracture of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72032R'  /*Displaced midcervical fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72032S'  /*Displaced midcervical fracture of left femur, sequela*/
,'S72033D'  /*Displaced midcervical fracture of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72033E'  /*Displaced midcervical fracture of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72033F'  /*Displaced midcervical fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72033G'  /*Displaced midcervical fracture of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72033H'  /*Displaced midcervical fracture of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72033J'  /*Displaced midcervical fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72033K'  /*Displaced midcervical fracture of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72033M'  /*Displaced midcervical fracture of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72033N'  /*Displaced midcervical fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72033P'  /*Displaced midcervical fracture of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72033Q'  /*Displaced midcervical fracture of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72033R'  /*Displaced midcervical fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72033S'  /*Displaced midcervical fracture of unspecified femur, sequela*/
,'S72034D'  /*Nondisplaced midcervical fracture of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72034E'  /*Nondisplaced midcervical fracture of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72034F'  /*Nondisplaced midcervical fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72034G'  /*Nondisplaced midcervical fracture of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72034H'  /*Nondisplaced midcervical fracture of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72034J'  /*Nondisplaced midcervical fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72034K'  /*Nondisplaced midcervical fracture of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72034M'  /*Nondisplaced midcervical fracture of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72034N'  /*Nondisplaced midcervical fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72034P'  /*Nondisplaced midcervical fracture of right femur, subsequent encounter for closed fracture with malunion*/
,'S72034Q'  /*Nondisplaced midcervical fracture of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72034R'  /*Nondisplaced midcervical fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72034S'  /*Nondisplaced midcervical fracture of right femur, sequela*/
,'S72035D'  /*Nondisplaced midcervical fracture of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72035E'  /*Nondisplaced midcervical fracture of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72035F'  /*Nondisplaced midcervical fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72035G'  /*Nondisplaced midcervical fracture of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72035H'  /*Nondisplaced midcervical fracture of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72035J'  /*Nondisplaced midcervical fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72035K'  /*Nondisplaced midcervical fracture of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72035M'  /*Nondisplaced midcervical fracture of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72035N'  /*Nondisplaced midcervical fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72035P'  /*Nondisplaced midcervical fracture of left femur, subsequent encounter for closed fracture with malunion*/
,'S72035Q'  /*Nondisplaced midcervical fracture of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72035R'  /*Nondisplaced midcervical fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72035S'  /*Nondisplaced midcervical fracture of left femur, sequela*/
,'S72036D'  /*Nondisplaced midcervical fracture of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72036E'  /*Nondisplaced midcervical fracture of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72036F'  /*Nondisplaced midcervical fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72036G'  /*Nondisplaced midcervical fracture of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72036H'  /*Nondisplaced midcervical fracture of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72036J'  /*Nondisplaced midcervical fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72036K'  /*Nondisplaced midcervical fracture of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72036M'  /*Nondisplaced midcervical fracture of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72036N'  /*Nondisplaced midcervical fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72036P'  /*Nondisplaced midcervical fracture of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72036Q'  /*Nondisplaced midcervical fracture of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72036R'  /*Nondisplaced midcervical fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72036S'  /*Nondisplaced midcervical fracture of unspecified femur, sequela*/
,'S72041D'  /*Displaced fracture of base of neck of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72041E'  /*Displaced fracture of base of neck of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72041F'  /*Displaced fracture of base of neck of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72041G'  /*Displaced fracture of base of neck of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72041H'  /*Displaced fracture of base of neck of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72041J'  /*Displaced fracture of base of neck of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72041K'  /*Displaced fracture of base of neck of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72041M'  /*Displaced fracture of base of neck of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72041N'  /*Displaced fracture of base of neck of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72041P'  /*Displaced fracture of base of neck of right femur, subsequent encounter for closed fracture with malunion*/
,'S72041Q'  /*Displaced fracture of base of neck of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72041R'  /*Displaced fracture of base of neck of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72041S'  /*Displaced fracture of base of neck of right femur, sequela*/
,'S72042D'  /*Displaced fracture of base of neck of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72042E'  /*Displaced fracture of base of neck of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72042F'  /*Displaced fracture of base of neck of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72042G'  /*Displaced fracture of base of neck of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72042H'  /*Displaced fracture of base of neck of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72042J'  /*Displaced fracture of base of neck of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72042K'  /*Displaced fracture of base of neck of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72042M'  /*Displaced fracture of base of neck of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72042N'  /*Displaced fracture of base of neck of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72042P'  /*Displaced fracture of base of neck of left femur, subsequent encounter for closed fracture with malunion*/
,'S72042Q'  /*Displaced fracture of base of neck of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72042R'  /*Displaced fracture of base of neck of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72042S'  /*Displaced fracture of base of neck of left femur, sequela*/
,'S72043D'  /*Displaced fracture of base of neck of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72043E'  /*Displaced fracture of base of neck of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72043F'  /*Displaced fracture of base of neck of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72043G'  /*Displaced fracture of base of neck of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72043H'  /*Displaced fracture of base of neck of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72043J'  /*Displaced fracture of base of neck of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72043K'  /*Displaced fracture of base of neck of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72043M'  /*Displaced fracture of base of neck of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72043N'  /*Displaced fracture of base of neck of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72043P'  /*Displaced fracture of base of neck of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72043Q'  /*Displaced fracture of base of neck of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72043R'  /*Displaced fracture of base of neck of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72043S'  /*Displaced fracture of base of neck of unspecified femur, sequela*/
,'S72044D'  /*Nondisplaced fracture of base of neck of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72044E'  /*Nondisplaced fracture of base of neck of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72044F'  /*Nondisplaced fracture of base of neck of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72044G'  /*Nondisplaced fracture of base of neck of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72044H'  /*Nondisplaced fracture of base of neck of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72044J'  /*Nondisplaced fracture of base of neck of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72044K'  /*Nondisplaced fracture of base of neck of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72044M'  /*Nondisplaced fracture of base of neck of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72044N'  /*Nondisplaced fracture of base of neck of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72044P'  /*Nondisplaced fracture of base of neck of right femur, subsequent encounter for closed fracture with malunion*/
,'S72044Q'  /*Nondisplaced fracture of base of neck of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72044R'  /*Nondisplaced fracture of base of neck of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72044S'  /*Nondisplaced fracture of base of neck of right femur, sequela*/
,'S72045D'  /*Nondisplaced fracture of base of neck of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72045E'  /*Nondisplaced fracture of base of neck of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72045F'  /*Nondisplaced fracture of base of neck of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72045G'  /*Nondisplaced fracture of base of neck of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72045H'  /*Nondisplaced fracture of base of neck of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72045J'  /*Nondisplaced fracture of base of neck of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72045K'  /*Nondisplaced fracture of base of neck of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72045M'  /*Nondisplaced fracture of base of neck of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72045N'  /*Nondisplaced fracture of base of neck of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72045P'  /*Nondisplaced fracture of base of neck of left femur, subsequent encounter for closed fracture with malunion*/
,'S72045Q'  /*Nondisplaced fracture of base of neck of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72045R'  /*Nondisplaced fracture of base of neck of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72045S'  /*Nondisplaced fracture of base of neck of left femur, sequela*/
,'S72046D'  /*Nondisplaced fracture of base of neck of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72046E'  /*Nondisplaced fracture of base of neck of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72046F'  /*Nondisplaced fracture of base of neck of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72046G'  /*Nondisplaced fracture of base of neck of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72046H'  /*Nondisplaced fracture of base of neck of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72046J'  /*Nondisplaced fracture of base of neck of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72046K'  /*Nondisplaced fracture of base of neck of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72046M'  /*Nondisplaced fracture of base of neck of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72046N'  /*Nondisplaced fracture of base of neck of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72046P'  /*Nondisplaced fracture of base of neck of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72046Q'  /*Nondisplaced fracture of base of neck of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72046R'  /*Nondisplaced fracture of base of neck of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72046S'  /*Nondisplaced fracture of base of neck of unspecified femur, sequela*/
,'S72051D'  /*Unspecified fracture of head of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72051E'  /*Unspecified fracture of head of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72051F'  /*Unspecified fracture of head of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72051G'  /*Unspecified fracture of head of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72051H'  /*Unspecified fracture of head of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72051J'  /*Unspecified fracture of head of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72051K'  /*Unspecified fracture of head of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72051M'  /*Unspecified fracture of head of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72051N'  /*Unspecified fracture of head of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72051P'  /*Unspecified fracture of head of right femur, subsequent encounter for closed fracture with malunion*/
,'S72051Q'  /*Unspecified fracture of head of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72051R'  /*Unspecified fracture of head of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72051S'  /*Unspecified fracture of head of right femur, sequela*/
,'S72052D'  /*Unspecified fracture of head of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72052E'  /*Unspecified fracture of head of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72052F'  /*Unspecified fracture of head of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72052G'  /*Unspecified fracture of head of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72052H'  /*Unspecified fracture of head of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72052J'  /*Unspecified fracture of head of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72052K'  /*Unspecified fracture of head of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72052M'  /*Unspecified fracture of head of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72052N'  /*Unspecified fracture of head of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72052P'  /*Unspecified fracture of head of left femur, subsequent encounter for closed fracture with malunion*/
,'S72052Q'  /*Unspecified fracture of head of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72052R'  /*Unspecified fracture of head of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72052S'  /*Unspecified fracture of head of left femur, sequela*/
,'S72059D'  /*Unspecified fracture of head of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72059E'  /*Unspecified fracture of head of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72059F'  /*Unspecified fracture of head of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72059G'  /*Unspecified fracture of head of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72059H'  /*Unspecified fracture of head of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72059J'  /*Unspecified fracture of head of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72059K'  /*Unspecified fracture of head of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72059M'  /*Unspecified fracture of head of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72059N'  /*Unspecified fracture of head of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72059P'  /*Unspecified fracture of head of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72059Q'  /*Unspecified fracture of head of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72059R'  /*Unspecified fracture of head of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72059S'  /*Unspecified fracture of head of unspecified femur, sequela*/
,'S72061D'  /*Displaced articular fracture of head of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72061E'  /*Displaced articular fracture of head of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72061F'  /*Displaced articular fracture of head of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72061G'  /*Displaced articular fracture of head of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72061H'  /*Displaced articular fracture of head of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72061J'  /*Displaced articular fracture of head of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72061K'  /*Displaced articular fracture of head of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72061M'  /*Displaced articular fracture of head of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72061N'  /*Displaced articular fracture of head of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72061P'  /*Displaced articular fracture of head of right femur, subsequent encounter for closed fracture with malunion*/
,'S72061Q'  /*Displaced articular fracture of head of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72061R'  /*Displaced articular fracture of head of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72061S'  /*Displaced articular fracture of head of right femur, sequela*/
,'S72062D'  /*Displaced articular fracture of head of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72062E'  /*Displaced articular fracture of head of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72062F'  /*Displaced articular fracture of head of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72062G'  /*Displaced articular fracture of head of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72062H'  /*Displaced articular fracture of head of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72062J'  /*Displaced articular fracture of head of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72062K'  /*Displaced articular fracture of head of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72062M'  /*Displaced articular fracture of head of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72062N'  /*Displaced articular fracture of head of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72062P'  /*Displaced articular fracture of head of left femur, subsequent encounter for closed fracture with malunion*/
,'S72062Q'  /*Displaced articular fracture of head of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72062R'  /*Displaced articular fracture of head of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72062S'  /*Displaced articular fracture of head of left femur, sequela*/
,'S72063D'  /*Displaced articular fracture of head of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72063E'  /*Displaced articular fracture of head of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72063F'  /*Displaced articular fracture of head of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72063G'  /*Displaced articular fracture of head of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72063H'  /*Displaced articular fracture of head of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72063J'  /*Displaced articular fracture of head of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72063K'  /*Displaced articular fracture of head of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72063M'  /*Displaced articular fracture of head of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72063N'  /*Displaced articular fracture of head of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72063P'  /*Displaced articular fracture of head of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72063Q'  /*Displaced articular fracture of head of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72063R'  /*Displaced articular fracture of head of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72063S'  /*Displaced articular fracture of head of unspecified femur, sequela*/
,'S72064D'  /*Nondisplaced articular fracture of head of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72064E'  /*Nondisplaced articular fracture of head of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72064F'  /*Nondisplaced articular fracture of head of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72064G'  /*Nondisplaced articular fracture of head of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72064H'  /*Nondisplaced articular fracture of head of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72064J'  /*Nondisplaced articular fracture of head of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72064K'  /*Nondisplaced articular fracture of head of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72064M'  /*Nondisplaced articular fracture of head of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72064N'  /*Nondisplaced articular fracture of head of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72064P'  /*Nondisplaced articular fracture of head of right femur, subsequent encounter for closed fracture with malunion*/
,'S72064Q'  /*Nondisplaced articular fracture of head of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72064R'  /*Nondisplaced articular fracture of head of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72064S'  /*Nondisplaced articular fracture of head of right femur, sequela*/
,'S72065D'  /*Nondisplaced articular fracture of head of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72065E'  /*Nondisplaced articular fracture of head of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72065F'  /*Nondisplaced articular fracture of head of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72065G'  /*Nondisplaced articular fracture of head of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72065H'  /*Nondisplaced articular fracture of head of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72065J'  /*Nondisplaced articular fracture of head of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72065K'  /*Nondisplaced articular fracture of head of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72065M'  /*Nondisplaced articular fracture of head of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72065N'  /*Nondisplaced articular fracture of head of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72065P'  /*Nondisplaced articular fracture of head of left femur, subsequent encounter for closed fracture with malunion*/
,'S72065Q'  /*Nondisplaced articular fracture of head of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72065R'  /*Nondisplaced articular fracture of head of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72065S'  /*Nondisplaced articular fracture of head of left femur, sequela*/
,'S72066D'  /*Nondisplaced articular fracture of head of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72066E'  /*Nondisplaced articular fracture of head of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72066F'  /*Nondisplaced articular fracture of head of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72066G'  /*Nondisplaced articular fracture of head of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72066H'  /*Nondisplaced articular fracture of head of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72066J'  /*Nondisplaced articular fracture of head of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72066K'  /*Nondisplaced articular fracture of head of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72066M'  /*Nondisplaced articular fracture of head of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72066N'  /*Nondisplaced articular fracture of head of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72066P'  /*Nondisplaced articular fracture of head of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72066Q'  /*Nondisplaced articular fracture of head of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72066R'  /*Nondisplaced articular fracture of head of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72066S'  /*Nondisplaced articular fracture of head of unspecified femur, sequela*/
,'S72091D'  /*Other fracture of head and neck of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72091E'  /*Other fracture of head and neck of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72091F'  /*Other fracture of head and neck of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72091G'  /*Other fracture of head and neck of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72091H'  /*Other fracture of head and neck of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72091J'  /*Other fracture of head and neck of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72091K'  /*Other fracture of head and neck of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72091M'  /*Other fracture of head and neck of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72091N'  /*Other fracture of head and neck of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72091P'  /*Other fracture of head and neck of right femur, subsequent encounter for closed fracture with malunion*/
,'S72091Q'  /*Other fracture of head and neck of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72091R'  /*Other fracture of head and neck of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72091S'  /*Other fracture of head and neck of right femur, sequela*/
,'S72092D'  /*Other fracture of head and neck of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72092E'  /*Other fracture of head and neck of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72092F'  /*Other fracture of head and neck of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72092G'  /*Other fracture of head and neck of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72092H'  /*Other fracture of head and neck of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72092J'  /*Other fracture of head and neck of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72092K'  /*Other fracture of head and neck of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72092M'  /*Other fracture of head and neck of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72092N'  /*Other fracture of head and neck of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72092P'  /*Other fracture of head and neck of left femur, subsequent encounter for closed fracture with malunion*/
,'S72092Q'  /*Other fracture of head and neck of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72092R'  /*Other fracture of head and neck of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72092S'  /*Other fracture of head and neck of left femur, sequela*/
,'S72099D'  /*Other fracture of head and neck of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72099E'  /*Other fracture of head and neck of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72099F'  /*Other fracture of head and neck of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72099G'  /*Other fracture of head and neck of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72099H'  /*Other fracture of head and neck of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72099J'  /*Other fracture of head and neck of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72099K'  /*Other fracture of head and neck of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72099M'  /*Other fracture of head and neck of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72099N'  /*Other fracture of head and neck of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72099P'  /*Other fracture of head and neck of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72099Q'  /*Other fracture of head and neck of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72099R'  /*Other fracture of head and neck of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72099S'  /*Other fracture of head and neck of unspecified femur, sequela*/
,'S72101D'  /*Unspecified trochanteric fracture of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72101E'  /*Unspecified trochanteric fracture of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72101F'  /*Unspecified trochanteric fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72101G'  /*Unspecified trochanteric fracture of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72101H'  /*Unspecified trochanteric fracture of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72101J'  /*Unspecified trochanteric fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72101K'  /*Unspecified trochanteric fracture of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72101M'  /*Unspecified trochanteric fracture of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72101N'  /*Unspecified trochanteric fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72101P'  /*Unspecified trochanteric fracture of right femur, subsequent encounter for closed fracture with malunion*/
,'S72101Q'  /*Unspecified trochanteric fracture of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72101R'  /*Unspecified trochanteric fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72101S'  /*Unspecified trochanteric fracture of right femur, sequela*/
,'S72102D'  /*Unspecified trochanteric fracture of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72102E'  /*Unspecified trochanteric fracture of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72102F'  /*Unspecified trochanteric fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72102G'  /*Unspecified trochanteric fracture of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72102H'  /*Unspecified trochanteric fracture of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72102J'  /*Unspecified trochanteric fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72102K'  /*Unspecified trochanteric fracture of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72102M'  /*Unspecified trochanteric fracture of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72102N'  /*Unspecified trochanteric fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72102P'  /*Unspecified trochanteric fracture of left femur, subsequent encounter for closed fracture with malunion*/
,'S72102Q'  /*Unspecified trochanteric fracture of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72102R'  /*Unspecified trochanteric fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72102S'  /*Unspecified trochanteric fracture of left femur, sequela*/
,'S72109D'  /*Unspecified trochanteric fracture of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72109E'  /*Unspecified trochanteric fracture of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72109F'  /*Unspecified trochanteric fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72109G'  /*Unspecified trochanteric fracture of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72109H'  /*Unspecified trochanteric fracture of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72109J'  /*Unspecified trochanteric fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72109K'  /*Unspecified trochanteric fracture of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72109M'  /*Unspecified trochanteric fracture of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72109N'  /*Unspecified trochanteric fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72109P'  /*Unspecified trochanteric fracture of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72109Q'  /*Unspecified trochanteric fracture of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72109R'  /*Unspecified trochanteric fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72109S'  /*Unspecified trochanteric fracture of unspecified femur, sequela*/
,'S72111D'  /*Displaced fracture of greater trochanter of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72111E'  /*Displaced fracture of greater trochanter of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72111F'  /*Displaced fracture of greater trochanter of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72111G'  /*Displaced fracture of greater trochanter of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72111H'  /*Displaced fracture of greater trochanter of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72111J'  /*Displaced fracture of greater trochanter of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72111K'  /*Displaced fracture of greater trochanter of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72111M'  /*Displaced fracture of greater trochanter of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72111N'  /*Displaced fracture of greater trochanter of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72111P'  /*Displaced fracture of greater trochanter of right femur, subsequent encounter for closed fracture with malunion*/
,'S72111Q'  /*Displaced fracture of greater trochanter of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72111R'  /*Displaced fracture of greater trochanter of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72111S'  /*Displaced fracture of greater trochanter of right femur, sequela*/
,'S72112D'  /*Displaced fracture of greater trochanter of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72112E'  /*Displaced fracture of greater trochanter of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72112F'  /*Displaced fracture of greater trochanter of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72112G'  /*Displaced fracture of greater trochanter of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72112H'  /*Displaced fracture of greater trochanter of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72112J'  /*Displaced fracture of greater trochanter of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72112K'  /*Displaced fracture of greater trochanter of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72112M'  /*Displaced fracture of greater trochanter of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72112N'  /*Displaced fracture of greater trochanter of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72112P'  /*Displaced fracture of greater trochanter of left femur, subsequent encounter for closed fracture with malunion*/
,'S72112Q'  /*Displaced fracture of greater trochanter of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72112R'  /*Displaced fracture of greater trochanter of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72112S'  /*Displaced fracture of greater trochanter of left femur, sequela*/
,'S72113D'  /*Displaced fracture of greater trochanter of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72113E'  /*Displaced fracture of greater trochanter of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72113F'  /*Displaced fracture of greater trochanter of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72113G'  /*Displaced fracture of greater trochanter of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72113H'  /*Displaced fracture of greater trochanter of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72113J'  /*Displaced fracture of greater trochanter of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72113K'  /*Displaced fracture of greater trochanter of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72113M'  /*Displaced fracture of greater trochanter of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72113N'  /*Displaced fracture of greater trochanter of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72113P'  /*Displaced fracture of greater trochanter of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72113Q'  /*Displaced fracture of greater trochanter of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72113R'  /*Displaced fracture of greater trochanter of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72113S'  /*Displaced fracture of greater trochanter of unspecified femur, sequela*/
,'S72114D'  /*Nondisplaced fracture of greater trochanter of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72114E'  /*Nondisplaced fracture of greater trochanter of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72114F'  /*Nondisplaced fracture of greater trochanter of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72114G'  /*Nondisplaced fracture of greater trochanter of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72114H'  /*Nondisplaced fracture of greater trochanter of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72114J'  /*Nondisplaced fracture of greater trochanter of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72114K'  /*Nondisplaced fracture of greater trochanter of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72114M'  /*Nondisplaced fracture of greater trochanter of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72114N'  /*Nondisplaced fracture of greater trochanter of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72114P'  /*Nondisplaced fracture of greater trochanter of right femur, subsequent encounter for closed fracture with malunion*/
,'S72114Q'  /*Nondisplaced fracture of greater trochanter of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72114R'  /*Nondisplaced fracture of greater trochanter of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72114S'  /*Nondisplaced fracture of greater trochanter of right femur, sequela*/
,'S72115D'  /*Nondisplaced fracture of greater trochanter of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72115E'  /*Nondisplaced fracture of greater trochanter of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72115F'  /*Nondisplaced fracture of greater trochanter of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72115G'  /*Nondisplaced fracture of greater trochanter of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72115H'  /*Nondisplaced fracture of greater trochanter of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72115J'  /*Nondisplaced fracture of greater trochanter of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72115K'  /*Nondisplaced fracture of greater trochanter of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72115M'  /*Nondisplaced fracture of greater trochanter of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72115N'  /*Nondisplaced fracture of greater trochanter of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72115P'  /*Nondisplaced fracture of greater trochanter of left femur, subsequent encounter for closed fracture with malunion*/
,'S72115Q'  /*Nondisplaced fracture of greater trochanter of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72115R'  /*Nondisplaced fracture of greater trochanter of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72115S'  /*Nondisplaced fracture of greater trochanter of left femur, sequela*/
,'S72116D'  /*Nondisplaced fracture of greater trochanter of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72116E'  /*Nondisplaced fracture of greater trochanter of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72116F'  /*Nondisplaced fracture of greater trochanter of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72116G'  /*Nondisplaced fracture of greater trochanter of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72116H'  /*Nondisplaced fracture of greater trochanter of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72116J'  /*Nondisplaced fracture of greater trochanter of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72116K'  /*Nondisplaced fracture of greater trochanter of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72116M'  /*Nondisplaced fracture of greater trochanter of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72116N'  /*Nondisplaced fracture of greater trochanter of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72116P'  /*Nondisplaced fracture of greater trochanter of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72116Q'  /*Nondisplaced fracture of greater trochanter of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72116R'  /*Nondisplaced fracture of greater trochanter of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72116S'  /*Nondisplaced fracture of greater trochanter of unspecified femur, sequela*/
,'S72121D'  /*Displaced fracture of lesser trochanter of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72121E'  /*Displaced fracture of lesser trochanter of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72121F'  /*Displaced fracture of lesser trochanter of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72121G'  /*Displaced fracture of lesser trochanter of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72121H'  /*Displaced fracture of lesser trochanter of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72121J'  /*Displaced fracture of lesser trochanter of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72121K'  /*Displaced fracture of lesser trochanter of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72121M'  /*Displaced fracture of lesser trochanter of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72121N'  /*Displaced fracture of lesser trochanter of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72121P'  /*Displaced fracture of lesser trochanter of right femur, subsequent encounter for closed fracture with malunion*/
,'S72121Q'  /*Displaced fracture of lesser trochanter of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72121R'  /*Displaced fracture of lesser trochanter of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72121S'  /*Displaced fracture of lesser trochanter of right femur, sequela*/
,'S72122D'  /*Displaced fracture of lesser trochanter of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72122E'  /*Displaced fracture of lesser trochanter of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72122F'  /*Displaced fracture of lesser trochanter of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72122G'  /*Displaced fracture of lesser trochanter of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72122H'  /*Displaced fracture of lesser trochanter of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72122J'  /*Displaced fracture of lesser trochanter of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72122K'  /*Displaced fracture of lesser trochanter of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72122M'  /*Displaced fracture of lesser trochanter of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72122N'  /*Displaced fracture of lesser trochanter of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72122P'  /*Displaced fracture of lesser trochanter of left femur, subsequent encounter for closed fracture with malunion*/
,'S72122Q'  /*Displaced fracture of lesser trochanter of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72122R'  /*Displaced fracture of lesser trochanter of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72122S'  /*Displaced fracture of lesser trochanter of left femur, sequela*/
,'S72123D'  /*Displaced fracture of lesser trochanter of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72123E'  /*Displaced fracture of lesser trochanter of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72123F'  /*Displaced fracture of lesser trochanter of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72123G'  /*Displaced fracture of lesser trochanter of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72123H'  /*Displaced fracture of lesser trochanter of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72123J'  /*Displaced fracture of lesser trochanter of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72123K'  /*Displaced fracture of lesser trochanter of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72123M'  /*Displaced fracture of lesser trochanter of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72123N'  /*Displaced fracture of lesser trochanter of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72123P'  /*Displaced fracture of lesser trochanter of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72123Q'  /*Displaced fracture of lesser trochanter of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72123R'  /*Displaced fracture of lesser trochanter of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72123S'  /*Displaced fracture of lesser trochanter of unspecified femur, sequela*/
,'S72124D'  /*Nondisplaced fracture of lesser trochanter of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72124E'  /*Nondisplaced fracture of lesser trochanter of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72124F'  /*Nondisplaced fracture of lesser trochanter of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72124G'  /*Nondisplaced fracture of lesser trochanter of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72124H'  /*Nondisplaced fracture of lesser trochanter of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72124J'  /*Nondisplaced fracture of lesser trochanter of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72124K'  /*Nondisplaced fracture of lesser trochanter of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72124M'  /*Nondisplaced fracture of lesser trochanter of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72124N'  /*Nondisplaced fracture of lesser trochanter of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72124P'  /*Nondisplaced fracture of lesser trochanter of right femur, subsequent encounter for closed fracture with malunion*/
,'S72124Q'  /*Nondisplaced fracture of lesser trochanter of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72124R'  /*Nondisplaced fracture of lesser trochanter of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72124S'  /*Nondisplaced fracture of lesser trochanter of right femur, sequela*/
,'S72125D'  /*Nondisplaced fracture of lesser trochanter of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72125E'  /*Nondisplaced fracture of lesser trochanter of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72125F'  /*Nondisplaced fracture of lesser trochanter of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72125G'  /*Nondisplaced fracture of lesser trochanter of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72125H'  /*Nondisplaced fracture of lesser trochanter of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72125J'  /*Nondisplaced fracture of lesser trochanter of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72125K'  /*Nondisplaced fracture of lesser trochanter of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72125M'  /*Nondisplaced fracture of lesser trochanter of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72125N'  /*Nondisplaced fracture of lesser trochanter of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72125P'  /*Nondisplaced fracture of lesser trochanter of left femur, subsequent encounter for closed fracture with malunion*/
,'S72125Q'  /*Nondisplaced fracture of lesser trochanter of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72125R'  /*Nondisplaced fracture of lesser trochanter of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72125S'  /*Nondisplaced fracture of lesser trochanter of left femur, sequela*/
,'S72126D'  /*Nondisplaced fracture of lesser trochanter of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72126E'  /*Nondisplaced fracture of lesser trochanter of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72126F'  /*Nondisplaced fracture of lesser trochanter of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72126G'  /*Nondisplaced fracture of lesser trochanter of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72126H'  /*Nondisplaced fracture of lesser trochanter of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72126J'  /*Nondisplaced fracture of lesser trochanter of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72126K'  /*Nondisplaced fracture of lesser trochanter of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72126M'  /*Nondisplaced fracture of lesser trochanter of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72126N'  /*Nondisplaced fracture of lesser trochanter of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72126P'  /*Nondisplaced fracture of lesser trochanter of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72126Q'  /*Nondisplaced fracture of lesser trochanter of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72126R'  /*Nondisplaced fracture of lesser trochanter of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72126S'  /*Nondisplaced fracture of lesser trochanter of unspecified femur, sequela*/
,'S72131D'  /*Displaced apophyseal fracture of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72131E'  /*Displaced apophyseal fracture of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72131F'  /*Displaced apophyseal fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72131G'  /*Displaced apophyseal fracture of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72131H'  /*Displaced apophyseal fracture of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72131J'  /*Displaced apophyseal fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72131K'  /*Displaced apophyseal fracture of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72131M'  /*Displaced apophyseal fracture of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72131N'  /*Displaced apophyseal fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72131P'  /*Displaced apophyseal fracture of right femur, subsequent encounter for closed fracture with malunion*/
,'S72131Q'  /*Displaced apophyseal fracture of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72131R'  /*Displaced apophyseal fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72131S'  /*Displaced apophyseal fracture of right femur, sequela*/
,'S72132D'  /*Displaced apophyseal fracture of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72132E'  /*Displaced apophyseal fracture of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72132F'  /*Displaced apophyseal fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72132G'  /*Displaced apophyseal fracture of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72132H'  /*Displaced apophyseal fracture of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72132J'  /*Displaced apophyseal fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72132K'  /*Displaced apophyseal fracture of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72132M'  /*Displaced apophyseal fracture of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72132N'  /*Displaced apophyseal fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72132P'  /*Displaced apophyseal fracture of left femur, subsequent encounter for closed fracture with malunion*/
,'S72132Q'  /*Displaced apophyseal fracture of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72132R'  /*Displaced apophyseal fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72132S'  /*Displaced apophyseal fracture of left femur, sequela*/
,'S72133D'  /*Displaced apophyseal fracture of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72133E'  /*Displaced apophyseal fracture of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72133F'  /*Displaced apophyseal fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72133G'  /*Displaced apophyseal fracture of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72133H'  /*Displaced apophyseal fracture of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72133J'  /*Displaced apophyseal fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72133K'  /*Displaced apophyseal fracture of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72133M'  /*Displaced apophyseal fracture of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72133N'  /*Displaced apophyseal fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72133P'  /*Displaced apophyseal fracture of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72133Q'  /*Displaced apophyseal fracture of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72133R'  /*Displaced apophyseal fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72133S'  /*Displaced apophyseal fracture of unspecified femur, sequela*/
,'S72134D'  /*Nondisplaced apophyseal fracture of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72134E'  /*Nondisplaced apophyseal fracture of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72134F'  /*Nondisplaced apophyseal fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72134G'  /*Nondisplaced apophyseal fracture of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72134H'  /*Nondisplaced apophyseal fracture of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72134J'  /*Nondisplaced apophyseal fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72134K'  /*Nondisplaced apophyseal fracture of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72134M'  /*Nondisplaced apophyseal fracture of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72134N'  /*Nondisplaced apophyseal fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72134P'  /*Nondisplaced apophyseal fracture of right femur, subsequent encounter for closed fracture with malunion*/
,'S72134Q'  /*Nondisplaced apophyseal fracture of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72134R'  /*Nondisplaced apophyseal fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72134S'  /*Nondisplaced apophyseal fracture of right femur, sequela*/
,'S72135D'  /*Nondisplaced apophyseal fracture of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72135E'  /*Nondisplaced apophyseal fracture of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72135F'  /*Nondisplaced apophyseal fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72135G'  /*Nondisplaced apophyseal fracture of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72135H'  /*Nondisplaced apophyseal fracture of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72135J'  /*Nondisplaced apophyseal fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72135K'  /*Nondisplaced apophyseal fracture of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72135M'  /*Nondisplaced apophyseal fracture of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72135N'  /*Nondisplaced apophyseal fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72135P'  /*Nondisplaced apophyseal fracture of left femur, subsequent encounter for closed fracture with malunion*/
,'S72135Q'  /*Nondisplaced apophyseal fracture of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72135R'  /*Nondisplaced apophyseal fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72135S'  /*Nondisplaced apophyseal fracture of left femur, sequela*/
,'S72136D'  /*Nondisplaced apophyseal fracture of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72136E'  /*Nondisplaced apophyseal fracture of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72136F'  /*Nondisplaced apophyseal fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72136G'  /*Nondisplaced apophyseal fracture of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72136H'  /*Nondisplaced apophyseal fracture of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72136J'  /*Nondisplaced apophyseal fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72136K'  /*Nondisplaced apophyseal fracture of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72136M'  /*Nondisplaced apophyseal fracture of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72136N'  /*Nondisplaced apophyseal fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72136P'  /*Nondisplaced apophyseal fracture of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72136Q'  /*Nondisplaced apophyseal fracture of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72136R'  /*Nondisplaced apophyseal fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72136S'  /*Nondisplaced apophyseal fracture of unspecified femur, sequela*/
,'S72141D'  /*Displaced intertrochanteric fracture of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72141E'  /*Displaced intertrochanteric fracture of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72141F'  /*Displaced intertrochanteric fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72141G'  /*Displaced intertrochanteric fracture of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72141H'  /*Displaced intertrochanteric fracture of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72141J'  /*Displaced intertrochanteric fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72141K'  /*Displaced intertrochanteric fracture of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72141M'  /*Displaced intertrochanteric fracture of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72141N'  /*Displaced intertrochanteric fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72141P'  /*Displaced intertrochanteric fracture of right femur, subsequent encounter for closed fracture with malunion*/
,'S72141Q'  /*Displaced intertrochanteric fracture of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72141R'  /*Displaced intertrochanteric fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72141S'  /*Displaced intertrochanteric fracture of right femur, sequela*/
,'S72142D'  /*Displaced intertrochanteric fracture of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72142E'  /*Displaced intertrochanteric fracture of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72142F'  /*Displaced intertrochanteric fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72142G'  /*Displaced intertrochanteric fracture of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72142H'  /*Displaced intertrochanteric fracture of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72142J'  /*Displaced intertrochanteric fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72142K'  /*Displaced intertrochanteric fracture of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72142M'  /*Displaced intertrochanteric fracture of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72142N'  /*Displaced intertrochanteric fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72142P'  /*Displaced intertrochanteric fracture of left femur, subsequent encounter for closed fracture with malunion*/
,'S72142Q'  /*Displaced intertrochanteric fracture of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72142R'  /*Displaced intertrochanteric fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72142S'  /*Displaced intertrochanteric fracture of left femur, sequela*/
,'S72143D'  /*Displaced intertrochanteric fracture of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72143E'  /*Displaced intertrochanteric fracture of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72143F'  /*Displaced intertrochanteric fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72143G'  /*Displaced intertrochanteric fracture of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72143H'  /*Displaced intertrochanteric fracture of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72143J'  /*Displaced intertrochanteric fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72143K'  /*Displaced intertrochanteric fracture of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72143M'  /*Displaced intertrochanteric fracture of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72143N'  /*Displaced intertrochanteric fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72143P'  /*Displaced intertrochanteric fracture of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72143Q'  /*Displaced intertrochanteric fracture of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72143R'  /*Displaced intertrochanteric fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72143S'  /*Displaced intertrochanteric fracture of unspecified femur, sequela*/
,'S72144D'  /*Nondisplaced intertrochanteric fracture of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72144E'  /*Nondisplaced intertrochanteric fracture of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72144F'  /*Nondisplaced intertrochanteric fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72144G'  /*Nondisplaced intertrochanteric fracture of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72144H'  /*Nondisplaced intertrochanteric fracture of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72144J'  /*Nondisplaced intertrochanteric fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72144K'  /*Nondisplaced intertrochanteric fracture of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72144M'  /*Nondisplaced intertrochanteric fracture of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72144N'  /*Nondisplaced intertrochanteric fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72144P'  /*Nondisplaced intertrochanteric fracture of right femur, subsequent encounter for closed fracture with malunion*/
,'S72144Q'  /*Nondisplaced intertrochanteric fracture of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72144R'  /*Nondisplaced intertrochanteric fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72144S'  /*Nondisplaced intertrochanteric fracture of right femur, sequela*/
,'S72145D'  /*Nondisplaced intertrochanteric fracture of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72145E'  /*Nondisplaced intertrochanteric fracture of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72145F'  /*Nondisplaced intertrochanteric fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72145G'  /*Nondisplaced intertrochanteric fracture of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72145H'  /*Nondisplaced intertrochanteric fracture of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72145J'  /*Nondisplaced intertrochanteric fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72145K'  /*Nondisplaced intertrochanteric fracture of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72145M'  /*Nondisplaced intertrochanteric fracture of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72145N'  /*Nondisplaced intertrochanteric fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72145P'  /*Nondisplaced intertrochanteric fracture of left femur, subsequent encounter for closed fracture with malunion*/
,'S72145Q'  /*Nondisplaced intertrochanteric fracture of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72145R'  /*Nondisplaced intertrochanteric fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72145S'  /*Nondisplaced intertrochanteric fracture of left femur, sequela*/
,'S72146D'  /*Nondisplaced intertrochanteric fracture of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72146E'  /*Nondisplaced intertrochanteric fracture of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72146F'  /*Nondisplaced intertrochanteric fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72146G'  /*Nondisplaced intertrochanteric fracture of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72146H'  /*Nondisplaced intertrochanteric fracture of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72146J'  /*Nondisplaced intertrochanteric fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72146K'  /*Nondisplaced intertrochanteric fracture of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72146M'  /*Nondisplaced intertrochanteric fracture of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72146N'  /*Nondisplaced intertrochanteric fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72146P'  /*Nondisplaced intertrochanteric fracture of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72146Q'  /*Nondisplaced intertrochanteric fracture of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72146R'  /*Nondisplaced intertrochanteric fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72146S'  /*Nondisplaced intertrochanteric fracture of unspecified femur, sequela*/
,'S7221XD'  /*Displaced subtrochanteric fracture of right femur, subsequent encounter for closed fracture with routine healing*/
,'S7221XE'  /*Displaced subtrochanteric fracture of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S7221XF'  /*Displaced subtrochanteric fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S7221XG'  /*Displaced subtrochanteric fracture of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S7221XH'  /*Displaced subtrochanteric fracture of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S7221XJ'  /*Displaced subtrochanteric fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S7221XK'  /*Displaced subtrochanteric fracture of right femur, subsequent encounter for closed fracture with nonunion*/
,'S7221XM'  /*Displaced subtrochanteric fracture of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S7221XN'  /*Displaced subtrochanteric fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S7221XP'  /*Displaced subtrochanteric fracture of right femur, subsequent encounter for closed fracture with malunion*/
,'S7221XQ'  /*Displaced subtrochanteric fracture of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S7221XR'  /*Displaced subtrochanteric fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S7221XS'  /*Displaced subtrochanteric fracture of right femur, sequela*/
,'S7222XD'  /*Displaced subtrochanteric fracture of left femur, subsequent encounter for closed fracture with routine healing*/
,'S7222XE'  /*Displaced subtrochanteric fracture of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S7222XF'  /*Displaced subtrochanteric fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S7222XG'  /*Displaced subtrochanteric fracture of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S7222XH'  /*Displaced subtrochanteric fracture of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S7222XJ'  /*Displaced subtrochanteric fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S7222XK'  /*Displaced subtrochanteric fracture of left femur, subsequent encounter for closed fracture with nonunion*/
,'S7222XM'  /*Displaced subtrochanteric fracture of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S7222XN'  /*Displaced subtrochanteric fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S7222XP'  /*Displaced subtrochanteric fracture of left femur, subsequent encounter for closed fracture with malunion*/
,'S7222XQ'  /*Displaced subtrochanteric fracture of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S7222XR'  /*Displaced subtrochanteric fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S7222XS'  /*Displaced subtrochanteric fracture of left femur, sequela*/
,'S7223XD'  /*Displaced subtrochanteric fracture of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S7223XE'  /*Displaced subtrochanteric fracture of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S7223XF'  /*Displaced subtrochanteric fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S7223XG'  /*Displaced subtrochanteric fracture of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S7223XH'  /*Displaced subtrochanteric fracture of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S7223XJ'  /*Displaced subtrochanteric fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S7223XK'  /*Displaced subtrochanteric fracture of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S7223XM'  /*Displaced subtrochanteric fracture of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S7223XN'  /*Displaced subtrochanteric fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S7223XP'  /*Displaced subtrochanteric fracture of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S7223XQ'  /*Displaced subtrochanteric fracture of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S7223XR'  /*Displaced subtrochanteric fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S7223XS'  /*Displaced subtrochanteric fracture of unspecified femur, sequela*/
,'S7224XD'  /*Nondisplaced subtrochanteric fracture of right femur, subsequent encounter for closed fracture with routine healing*/
,'S7224XE'  /*Nondisplaced subtrochanteric fracture of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S7224XF'  /*Nondisplaced subtrochanteric fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S7224XG'  /*Nondisplaced subtrochanteric fracture of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S7224XH'  /*Nondisplaced subtrochanteric fracture of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S7224XJ'  /*Nondisplaced subtrochanteric fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S7224XK'  /*Nondisplaced subtrochanteric fracture of right femur, subsequent encounter for closed fracture with nonunion*/
,'S7224XM'  /*Nondisplaced subtrochanteric fracture of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S7224XN'  /*Nondisplaced subtrochanteric fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S7224XP'  /*Nondisplaced subtrochanteric fracture of right femur, subsequent encounter for closed fracture with malunion*/
,'S7224XQ'  /*Nondisplaced subtrochanteric fracture of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S7224XR'  /*Nondisplaced subtrochanteric fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S7224XS'  /*Nondisplaced subtrochanteric fracture of right femur, sequela*/
,'S7225XD'  /*Nondisplaced subtrochanteric fracture of left femur, subsequent encounter for closed fracture with routine healing*/
,'S7225XE'  /*Nondisplaced subtrochanteric fracture of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S7225XF'  /*Nondisplaced subtrochanteric fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S7225XG'  /*Nondisplaced subtrochanteric fracture of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S7225XH'  /*Nondisplaced subtrochanteric fracture of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S7225XJ'  /*Nondisplaced subtrochanteric fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S7225XK'  /*Nondisplaced subtrochanteric fracture of left femur, subsequent encounter for closed fracture with nonunion*/
,'S7225XM'  /*Nondisplaced subtrochanteric fracture of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S7225XN'  /*Nondisplaced subtrochanteric fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S7225XP'  /*Nondisplaced subtrochanteric fracture of left femur, subsequent encounter for closed fracture with malunion*/
,'S7225XQ'  /*Nondisplaced subtrochanteric fracture of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S7225XR'  /*Nondisplaced subtrochanteric fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S7225XS'  /*Nondisplaced subtrochanteric fracture of left femur, sequela*/
,'S7226XD'  /*Nondisplaced subtrochanteric fracture of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S7226XE'  /*Nondisplaced subtrochanteric fracture of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S7226XF'  /*Nondisplaced subtrochanteric fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S7226XG'  /*Nondisplaced subtrochanteric fracture of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S7226XH'  /*Nondisplaced subtrochanteric fracture of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S7226XJ'  /*Nondisplaced subtrochanteric fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S7226XK'  /*Nondisplaced subtrochanteric fracture of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S7226XM'  /*Nondisplaced subtrochanteric fracture of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S7226XN'  /*Nondisplaced subtrochanteric fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S7226XP'  /*Nondisplaced subtrochanteric fracture of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S7226XQ'  /*Nondisplaced subtrochanteric fracture of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S7226XR'  /*Nondisplaced subtrochanteric fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S7226XS'  /*Nondisplaced subtrochanteric fracture of unspecified femur, sequela*/
,'S72301D'  /*Unspecified fracture of shaft of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72301E'  /*Unspecified fracture of shaft of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72301F'  /*Unspecified fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72301G'  /*Unspecified fracture of shaft of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72301H'  /*Unspecified fracture of shaft of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72301J'  /*Unspecified fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72301K'  /*Unspecified fracture of shaft of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72301M'  /*Unspecified fracture of shaft of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72301N'  /*Unspecified fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72301P'  /*Unspecified fracture of shaft of right femur, subsequent encounter for closed fracture with malunion*/
,'S72301Q'  /*Unspecified fracture of shaft of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72301R'  /*Unspecified fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72301S'  /*Unspecified fracture of shaft of right femur, sequela*/
,'S72302D'  /*Unspecified fracture of shaft of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72302E'  /*Unspecified fracture of shaft of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72302F'  /*Unspecified fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72302G'  /*Unspecified fracture of shaft of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72302H'  /*Unspecified fracture of shaft of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72302J'  /*Unspecified fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72302K'  /*Unspecified fracture of shaft of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72302M'  /*Unspecified fracture of shaft of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72302N'  /*Unspecified fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72302P'  /*Unspecified fracture of shaft of left femur, subsequent encounter for closed fracture with malunion*/
,'S72302Q'  /*Unspecified fracture of shaft of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72302R'  /*Unspecified fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72302S'  /*Unspecified fracture of shaft of left femur, sequela*/
,'S72309D'  /*Unspecified fracture of shaft of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72309E'  /*Unspecified fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72309F'  /*Unspecified fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72309G'  /*Unspecified fracture of shaft of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72309H'  /*Unspecified fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72309J'  /*Unspecified fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72309K'  /*Unspecified fracture of shaft of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72309M'  /*Unspecified fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72309N'  /*Unspecified fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72309P'  /*Unspecified fracture of shaft of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72309Q'  /*Unspecified fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72309R'  /*Unspecified fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72309S'  /*Unspecified fracture of shaft of unspecified femur, sequela*/
,'S72321D'  /*Displaced transverse fracture of shaft of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72321E'  /*Displaced transverse fracture of shaft of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72321F'  /*Displaced transverse fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72321G'  /*Displaced transverse fracture of shaft of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72321H'  /*Displaced transverse fracture of shaft of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72321J'  /*Displaced transverse fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72321K'  /*Displaced transverse fracture of shaft of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72321M'  /*Displaced transverse fracture of shaft of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72321N'  /*Displaced transverse fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72321P'  /*Displaced transverse fracture of shaft of right femur, subsequent encounter for closed fracture with malunion*/
,'S72321Q'  /*Displaced transverse fracture of shaft of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72321R'  /*Displaced transverse fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72321S'  /*Displaced transverse fracture of shaft of right femur, sequela*/
,'S72322D'  /*Displaced transverse fracture of shaft of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72322E'  /*Displaced transverse fracture of shaft of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72322F'  /*Displaced transverse fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72322G'  /*Displaced transverse fracture of shaft of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72322H'  /*Displaced transverse fracture of shaft of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72322J'  /*Displaced transverse fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72322K'  /*Displaced transverse fracture of shaft of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72322M'  /*Displaced transverse fracture of shaft of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72322N'  /*Displaced transverse fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72322P'  /*Displaced transverse fracture of shaft of left femur, subsequent encounter for closed fracture with malunion*/
,'S72322Q'  /*Displaced transverse fracture of shaft of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72322R'  /*Displaced transverse fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72322S'  /*Displaced transverse fracture of shaft of left femur, sequela*/
,'S72323D'  /*Displaced transverse fracture of shaft of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72323E'  /*Displaced transverse fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72323F'  /*Displaced transverse fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72323G'  /*Displaced transverse fracture of shaft of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72323H'  /*Displaced transverse fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72323J'  /*Displaced transverse fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72323K'  /*Displaced transverse fracture of shaft of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72323M'  /*Displaced transverse fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72323N'  /*Displaced transverse fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72323P'  /*Displaced transverse fracture of shaft of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72323Q'  /*Displaced transverse fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72323R'  /*Displaced transverse fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72323S'  /*Displaced transverse fracture of shaft of unspecified femur, sequela*/
,'S72324D'  /*Nondisplaced transverse fracture of shaft of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72324E'  /*Nondisplaced transverse fracture of shaft of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72324F'  /*Nondisplaced transverse fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72324G'  /*Nondisplaced transverse fracture of shaft of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72324H'  /*Nondisplaced transverse fracture of shaft of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72324J'  /*Nondisplaced transverse fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72324K'  /*Nondisplaced transverse fracture of shaft of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72324M'  /*Nondisplaced transverse fracture of shaft of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72324N'  /*Nondisplaced transverse fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72324P'  /*Nondisplaced transverse fracture of shaft of right femur, subsequent encounter for closed fracture with malunion*/
,'S72324Q'  /*Nondisplaced transverse fracture of shaft of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72324R'  /*Nondisplaced transverse fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72324S'  /*Nondisplaced transverse fracture of shaft of right femur, sequela*/
,'S72325D'  /*Nondisplaced transverse fracture of shaft of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72325E'  /*Nondisplaced transverse fracture of shaft of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72325F'  /*Nondisplaced transverse fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72325G'  /*Nondisplaced transverse fracture of shaft of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72325H'  /*Nondisplaced transverse fracture of shaft of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72325J'  /*Nondisplaced transverse fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72325K'  /*Nondisplaced transverse fracture of shaft of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72325M'  /*Nondisplaced transverse fracture of shaft of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72325N'  /*Nondisplaced transverse fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72325P'  /*Nondisplaced transverse fracture of shaft of left femur, subsequent encounter for closed fracture with malunion*/
,'S72325Q'  /*Nondisplaced transverse fracture of shaft of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72325R'  /*Nondisplaced transverse fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72325S'  /*Nondisplaced transverse fracture of shaft of left femur, sequela*/
,'S72326D'  /*Nondisplaced transverse fracture of shaft of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72326E'  /*Nondisplaced transverse fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72326F'  /*Nondisplaced transverse fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72326G'  /*Nondisplaced transverse fracture of shaft of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72326H'  /*Nondisplaced transverse fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72326J'  /*Nondisplaced transverse fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72326K'  /*Nondisplaced transverse fracture of shaft of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72326M'  /*Nondisplaced transverse fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72326N'  /*Nondisplaced transverse fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72326P'  /*Nondisplaced transverse fracture of shaft of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72326Q'  /*Nondisplaced transverse fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72326R'  /*Nondisplaced transverse fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72326S'  /*Nondisplaced transverse fracture of shaft of unspecified femur, sequela*/
,'S72331D'  /*Displaced oblique fracture of shaft of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72331E'  /*Displaced oblique fracture of shaft of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72331F'  /*Displaced oblique fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72331G'  /*Displaced oblique fracture of shaft of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72331H'  /*Displaced oblique fracture of shaft of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72331J'  /*Displaced oblique fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72331K'  /*Displaced oblique fracture of shaft of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72331M'  /*Displaced oblique fracture of shaft of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72331N'  /*Displaced oblique fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72331P'  /*Displaced oblique fracture of shaft of right femur, subsequent encounter for closed fracture with malunion*/
,'S72331Q'  /*Displaced oblique fracture of shaft of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72331R'  /*Displaced oblique fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72331S'  /*Displaced oblique fracture of shaft of right femur, sequela*/
,'S72332D'  /*Displaced oblique fracture of shaft of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72332E'  /*Displaced oblique fracture of shaft of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72332F'  /*Displaced oblique fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72332G'  /*Displaced oblique fracture of shaft of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72332H'  /*Displaced oblique fracture of shaft of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72332J'  /*Displaced oblique fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72332K'  /*Displaced oblique fracture of shaft of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72332M'  /*Displaced oblique fracture of shaft of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72332N'  /*Displaced oblique fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72332P'  /*Displaced oblique fracture of shaft of left femur, subsequent encounter for closed fracture with malunion*/
,'S72332Q'  /*Displaced oblique fracture of shaft of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72332R'  /*Displaced oblique fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72332S'  /*Displaced oblique fracture of shaft of left femur, sequela*/
,'S72333D'  /*Displaced oblique fracture of shaft of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72333E'  /*Displaced oblique fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72333F'  /*Displaced oblique fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72333G'  /*Displaced oblique fracture of shaft of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72333H'  /*Displaced oblique fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72333J'  /*Displaced oblique fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72333K'  /*Displaced oblique fracture of shaft of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72333M'  /*Displaced oblique fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72333N'  /*Displaced oblique fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72333P'  /*Displaced oblique fracture of shaft of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72333Q'  /*Displaced oblique fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72333R'  /*Displaced oblique fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72333S'  /*Displaced oblique fracture of shaft of unspecified femur, sequela*/
,'S72334D'  /*Nondisplaced oblique fracture of shaft of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72334E'  /*Nondisplaced oblique fracture of shaft of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72334F'  /*Nondisplaced oblique fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72334G'  /*Nondisplaced oblique fracture of shaft of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72334H'  /*Nondisplaced oblique fracture of shaft of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72334J'  /*Nondisplaced oblique fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72334K'  /*Nondisplaced oblique fracture of shaft of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72334M'  /*Nondisplaced oblique fracture of shaft of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72334N'  /*Nondisplaced oblique fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72334P'  /*Nondisplaced oblique fracture of shaft of right femur, subsequent encounter for closed fracture with malunion*/
,'S72334Q'  /*Nondisplaced oblique fracture of shaft of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72334R'  /*Nondisplaced oblique fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72334S'  /*Nondisplaced oblique fracture of shaft of right femur, sequela*/
,'S72335D'  /*Nondisplaced oblique fracture of shaft of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72335E'  /*Nondisplaced oblique fracture of shaft of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72335F'  /*Nondisplaced oblique fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72335G'  /*Nondisplaced oblique fracture of shaft of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72335H'  /*Nondisplaced oblique fracture of shaft of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72335J'  /*Nondisplaced oblique fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72335K'  /*Nondisplaced oblique fracture of shaft of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72335M'  /*Nondisplaced oblique fracture of shaft of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72335N'  /*Nondisplaced oblique fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72335P'  /*Nondisplaced oblique fracture of shaft of left femur, subsequent encounter for closed fracture with malunion*/
,'S72335Q'  /*Nondisplaced oblique fracture of shaft of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72335R'  /*Nondisplaced oblique fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72335S'  /*Nondisplaced oblique fracture of shaft of left femur, sequela*/
,'S72336D'  /*Nondisplaced oblique fracture of shaft of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72336E'  /*Nondisplaced oblique fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72336F'  /*Nondisplaced oblique fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72336G'  /*Nondisplaced oblique fracture of shaft of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72336H'  /*Nondisplaced oblique fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72336J'  /*Nondisplaced oblique fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72336K'  /*Nondisplaced oblique fracture of shaft of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72336M'  /*Nondisplaced oblique fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72336N'  /*Nondisplaced oblique fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72336P'  /*Nondisplaced oblique fracture of shaft of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72336Q'  /*Nondisplaced oblique fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72336R'  /*Nondisplaced oblique fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72336S'  /*Nondisplaced oblique fracture of shaft of unspecified femur, sequela*/
,'S72341D'  /*Displaced spiral fracture of shaft of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72341E'  /*Displaced spiral fracture of shaft of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72341F'  /*Displaced spiral fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72341G'  /*Displaced spiral fracture of shaft of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72341H'  /*Displaced spiral fracture of shaft of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72341J'  /*Displaced spiral fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72341K'  /*Displaced spiral fracture of shaft of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72341M'  /*Displaced spiral fracture of shaft of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72341N'  /*Displaced spiral fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72341P'  /*Displaced spiral fracture of shaft of right femur, subsequent encounter for closed fracture with malunion*/
,'S72341Q'  /*Displaced spiral fracture of shaft of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72341R'  /*Displaced spiral fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72341S'  /*Displaced spiral fracture of shaft of right femur, sequela*/
,'S72342D'  /*Displaced spiral fracture of shaft of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72342E'  /*Displaced spiral fracture of shaft of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72342F'  /*Displaced spiral fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72342G'  /*Displaced spiral fracture of shaft of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72342H'  /*Displaced spiral fracture of shaft of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72342J'  /*Displaced spiral fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72342K'  /*Displaced spiral fracture of shaft of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72342M'  /*Displaced spiral fracture of shaft of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72342N'  /*Displaced spiral fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72342P'  /*Displaced spiral fracture of shaft of left femur, subsequent encounter for closed fracture with malunion*/
,'S72342Q'  /*Displaced spiral fracture of shaft of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72342R'  /*Displaced spiral fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72342S'  /*Displaced spiral fracture of shaft of left femur, sequela*/
,'S72343D'  /*Displaced spiral fracture of shaft of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72343E'  /*Displaced spiral fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72343F'  /*Displaced spiral fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72343G'  /*Displaced spiral fracture of shaft of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72343H'  /*Displaced spiral fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72343J'  /*Displaced spiral fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72343K'  /*Displaced spiral fracture of shaft of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72343M'  /*Displaced spiral fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72343N'  /*Displaced spiral fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72343P'  /*Displaced spiral fracture of shaft of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72343Q'  /*Displaced spiral fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72343R'  /*Displaced spiral fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72343S'  /*Displaced spiral fracture of shaft of unspecified femur, sequela*/
,'S72344D'  /*Nondisplaced spiral fracture of shaft of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72344E'  /*Nondisplaced spiral fracture of shaft of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72344F'  /*Nondisplaced spiral fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72344G'  /*Nondisplaced spiral fracture of shaft of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72344H'  /*Nondisplaced spiral fracture of shaft of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72344J'  /*Nondisplaced spiral fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72344K'  /*Nondisplaced spiral fracture of shaft of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72344M'  /*Nondisplaced spiral fracture of shaft of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72344N'  /*Nondisplaced spiral fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72344P'  /*Nondisplaced spiral fracture of shaft of right femur, subsequent encounter for closed fracture with malunion*/
,'S72344Q'  /*Nondisplaced spiral fracture of shaft of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72344R'  /*Nondisplaced spiral fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72344S'  /*Nondisplaced spiral fracture of shaft of right femur, sequela*/
,'S72345D'  /*Nondisplaced spiral fracture of shaft of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72345E'  /*Nondisplaced spiral fracture of shaft of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72345F'  /*Nondisplaced spiral fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72345G'  /*Nondisplaced spiral fracture of shaft of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72345H'  /*Nondisplaced spiral fracture of shaft of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72345J'  /*Nondisplaced spiral fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72345K'  /*Nondisplaced spiral fracture of shaft of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72345M'  /*Nondisplaced spiral fracture of shaft of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72345N'  /*Nondisplaced spiral fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72345P'  /*Nondisplaced spiral fracture of shaft of left femur, subsequent encounter for closed fracture with malunion*/
,'S72345Q'  /*Nondisplaced spiral fracture of shaft of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72345R'  /*Nondisplaced spiral fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72345S'  /*Nondisplaced spiral fracture of shaft of left femur, sequela*/
,'S72346D'  /*Nondisplaced spiral fracture of shaft of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72346E'  /*Nondisplaced spiral fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72346F'  /*Nondisplaced spiral fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72346G'  /*Nondisplaced spiral fracture of shaft of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72346H'  /*Nondisplaced spiral fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72346J'  /*Nondisplaced spiral fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72346K'  /*Nondisplaced spiral fracture of shaft of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72346M'  /*Nondisplaced spiral fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72346N'  /*Nondisplaced spiral fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72346P'  /*Nondisplaced spiral fracture of shaft of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72346Q'  /*Nondisplaced spiral fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72346R'  /*Nondisplaced spiral fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72346S'  /*Nondisplaced spiral fracture of shaft of unspecified femur, sequela*/
,'S72351D'  /*Displaced comminuted fracture of shaft of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72351E'  /*Displaced comminuted fracture of shaft of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72351F'  /*Displaced comminuted fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72351G'  /*Displaced comminuted fracture of shaft of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72351H'  /*Displaced comminuted fracture of shaft of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72351J'  /*Displaced comminuted fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72351K'  /*Displaced comminuted fracture of shaft of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72351M'  /*Displaced comminuted fracture of shaft of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72351N'  /*Displaced comminuted fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72351P'  /*Displaced comminuted fracture of shaft of right femur, subsequent encounter for closed fracture with malunion*/
,'S72351Q'  /*Displaced comminuted fracture of shaft of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72351R'  /*Displaced comminuted fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72351S'  /*Displaced comminuted fracture of shaft of right femur, sequela*/
,'S72352D'  /*Displaced comminuted fracture of shaft of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72352E'  /*Displaced comminuted fracture of shaft of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72352F'  /*Displaced comminuted fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72352G'  /*Displaced comminuted fracture of shaft of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72352H'  /*Displaced comminuted fracture of shaft of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72352J'  /*Displaced comminuted fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72352K'  /*Displaced comminuted fracture of shaft of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72352M'  /*Displaced comminuted fracture of shaft of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72352N'  /*Displaced comminuted fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72352P'  /*Displaced comminuted fracture of shaft of left femur, subsequent encounter for closed fracture with malunion*/
,'S72352Q'  /*Displaced comminuted fracture of shaft of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72352R'  /*Displaced comminuted fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72352S'  /*Displaced comminuted fracture of shaft of left femur, sequela*/
,'S72353D'  /*Displaced comminuted fracture of shaft of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72353E'  /*Displaced comminuted fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72353F'  /*Displaced comminuted fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72353G'  /*Displaced comminuted fracture of shaft of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72353H'  /*Displaced comminuted fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72353J'  /*Displaced comminuted fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72353K'  /*Displaced comminuted fracture of shaft of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72353M'  /*Displaced comminuted fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72353N'  /*Displaced comminuted fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72353P'  /*Displaced comminuted fracture of shaft of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72353Q'  /*Displaced comminuted fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72353R'  /*Displaced comminuted fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72353S'  /*Displaced comminuted fracture of shaft of unspecified femur, sequela*/
,'S72354D'  /*Nondisplaced comminuted fracture of shaft of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72354E'  /*Nondisplaced comminuted fracture of shaft of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72354F'  /*Nondisplaced comminuted fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72354G'  /*Nondisplaced comminuted fracture of shaft of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72354H'  /*Nondisplaced comminuted fracture of shaft of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72354J'  /*Nondisplaced comminuted fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72354K'  /*Nondisplaced comminuted fracture of shaft of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72354M'  /*Nondisplaced comminuted fracture of shaft of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72354N'  /*Nondisplaced comminuted fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72354P'  /*Nondisplaced comminuted fracture of shaft of right femur, subsequent encounter for closed fracture with malunion*/
,'S72354Q'  /*Nondisplaced comminuted fracture of shaft of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72354R'  /*Nondisplaced comminuted fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72354S'  /*Nondisplaced comminuted fracture of shaft of right femur, sequela*/
,'S72355D'  /*Nondisplaced comminuted fracture of shaft of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72355E'  /*Nondisplaced comminuted fracture of shaft of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72355F'  /*Nondisplaced comminuted fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72355G'  /*Nondisplaced comminuted fracture of shaft of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72355H'  /*Nondisplaced comminuted fracture of shaft of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72355J'  /*Nondisplaced comminuted fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72355K'  /*Nondisplaced comminuted fracture of shaft of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72355M'  /*Nondisplaced comminuted fracture of shaft of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72355N'  /*Nondisplaced comminuted fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72355P'  /*Nondisplaced comminuted fracture of shaft of left femur, subsequent encounter for closed fracture with malunion*/
,'S72355Q'  /*Nondisplaced comminuted fracture of shaft of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72355R'  /*Nondisplaced comminuted fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72355S'  /*Nondisplaced comminuted fracture of shaft of left femur, sequela*/
,'S72356D'  /*Nondisplaced comminuted fracture of shaft of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72356E'  /*Nondisplaced comminuted fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72356F'  /*Nondisplaced comminuted fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72356G'  /*Nondisplaced comminuted fracture of shaft of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72356H'  /*Nondisplaced comminuted fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72356J'  /*Nondisplaced comminuted fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72356K'  /*Nondisplaced comminuted fracture of shaft of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72356M'  /*Nondisplaced comminuted fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72356N'  /*Nondisplaced comminuted fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72356P'  /*Nondisplaced comminuted fracture of shaft of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72356Q'  /*Nondisplaced comminuted fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72356R'  /*Nondisplaced comminuted fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72356S'  /*Nondisplaced comminuted fracture of shaft of unspecified femur, sequela*/
,'S72361D'  /*Displaced segmental fracture of shaft of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72361E'  /*Displaced segmental fracture of shaft of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72361F'  /*Displaced segmental fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72361G'  /*Displaced segmental fracture of shaft of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72361H'  /*Displaced segmental fracture of shaft of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72361J'  /*Displaced segmental fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72361K'  /*Displaced segmental fracture of shaft of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72361M'  /*Displaced segmental fracture of shaft of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72361N'  /*Displaced segmental fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72361P'  /*Displaced segmental fracture of shaft of right femur, subsequent encounter for closed fracture with malunion*/
,'S72361Q'  /*Displaced segmental fracture of shaft of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72361R'  /*Displaced segmental fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72361S'  /*Displaced segmental fracture of shaft of right femur, sequela*/
,'S72362D'  /*Displaced segmental fracture of shaft of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72362E'  /*Displaced segmental fracture of shaft of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72362F'  /*Displaced segmental fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72362G'  /*Displaced segmental fracture of shaft of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72362H'  /*Displaced segmental fracture of shaft of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72362J'  /*Displaced segmental fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72362K'  /*Displaced segmental fracture of shaft of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72362M'  /*Displaced segmental fracture of shaft of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72362N'  /*Displaced segmental fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72362P'  /*Displaced segmental fracture of shaft of left femur, subsequent encounter for closed fracture with malunion*/
,'S72362Q'  /*Displaced segmental fracture of shaft of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72362R'  /*Displaced segmental fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72362S'  /*Displaced segmental fracture of shaft of left femur, sequela*/
,'S72363D'  /*Displaced segmental fracture of shaft of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72363E'  /*Displaced segmental fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72363F'  /*Displaced segmental fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72363G'  /*Displaced segmental fracture of shaft of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72363H'  /*Displaced segmental fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72363J'  /*Displaced segmental fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72363K'  /*Displaced segmental fracture of shaft of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72363M'  /*Displaced segmental fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72363N'  /*Displaced segmental fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72363P'  /*Displaced segmental fracture of shaft of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72363Q'  /*Displaced segmental fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72363R'  /*Displaced segmental fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72363S'  /*Displaced segmental fracture of shaft of unspecified femur, sequela*/
,'S72364D'  /*Nondisplaced segmental fracture of shaft of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72364E'  /*Nondisplaced segmental fracture of shaft of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72364F'  /*Nondisplaced segmental fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72364G'  /*Nondisplaced segmental fracture of shaft of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72364H'  /*Nondisplaced segmental fracture of shaft of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72364J'  /*Nondisplaced segmental fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72364K'  /*Nondisplaced segmental fracture of shaft of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72364M'  /*Nondisplaced segmental fracture of shaft of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72364N'  /*Nondisplaced segmental fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72364P'  /*Nondisplaced segmental fracture of shaft of right femur, subsequent encounter for closed fracture with malunion*/
,'S72364Q'  /*Nondisplaced segmental fracture of shaft of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72364R'  /*Nondisplaced segmental fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72364S'  /*Nondisplaced segmental fracture of shaft of right femur, sequela*/
,'S72365D'  /*Nondisplaced segmental fracture of shaft of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72365E'  /*Nondisplaced segmental fracture of shaft of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72365F'  /*Nondisplaced segmental fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72365G'  /*Nondisplaced segmental fracture of shaft of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72365H'  /*Nondisplaced segmental fracture of shaft of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72365J'  /*Nondisplaced segmental fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72365K'  /*Nondisplaced segmental fracture of shaft of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72365M'  /*Nondisplaced segmental fracture of shaft of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72365N'  /*Nondisplaced segmental fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72365P'  /*Nondisplaced segmental fracture of shaft of left femur, subsequent encounter for closed fracture with malunion*/
,'S72365Q'  /*Nondisplaced segmental fracture of shaft of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72365R'  /*Nondisplaced segmental fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72365S'  /*Nondisplaced segmental fracture of shaft of left femur, sequela*/
,'S72366D'  /*Nondisplaced segmental fracture of shaft of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72366E'  /*Nondisplaced segmental fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72366F'  /*Nondisplaced segmental fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72366G'  /*Nondisplaced segmental fracture of shaft of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72366H'  /*Nondisplaced segmental fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72366J'  /*Nondisplaced segmental fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72366K'  /*Nondisplaced segmental fracture of shaft of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72366M'  /*Nondisplaced segmental fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72366N'  /*Nondisplaced segmental fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72366P'  /*Nondisplaced segmental fracture of shaft of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72366Q'  /*Nondisplaced segmental fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72366R'  /*Nondisplaced segmental fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72366S'  /*Nondisplaced segmental fracture of shaft of unspecified femur, sequela*/
,'S72391D'  /*Other fracture of shaft of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72391E'  /*Other fracture of shaft of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72391F'  /*Other fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72391G'  /*Other fracture of shaft of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72391H'  /*Other fracture of shaft of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72391J'  /*Other fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72391K'  /*Other fracture of shaft of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72391M'  /*Other fracture of shaft of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72391N'  /*Other fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72391P'  /*Other fracture of shaft of right femur, subsequent encounter for closed fracture with malunion*/
,'S72391Q'  /*Other fracture of shaft of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72391R'  /*Other fracture of shaft of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72391S'  /*Other fracture of shaft of right femur, sequela*/
,'S72392D'  /*Other fracture of shaft of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72392E'  /*Other fracture of shaft of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72392F'  /*Other fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72392G'  /*Other fracture of shaft of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72392H'  /*Other fracture of shaft of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72392J'  /*Other fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72392K'  /*Other fracture of shaft of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72392M'  /*Other fracture of shaft of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72392N'  /*Other fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72392P'  /*Other fracture of shaft of left femur, subsequent encounter for closed fracture with malunion*/
,'S72392Q'  /*Other fracture of shaft of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72392R'  /*Other fracture of shaft of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72392S'  /*Other fracture of shaft of left femur, sequela*/
,'S72399D'  /*Other fracture of shaft of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72399E'  /*Other fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72399F'  /*Other fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72399G'  /*Other fracture of shaft of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72399H'  /*Other fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72399J'  /*Other fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72399K'  /*Other fracture of shaft of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72399M'  /*Other fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72399N'  /*Other fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72399P'  /*Other fracture of shaft of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72399Q'  /*Other fracture of shaft of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72399R'  /*Other fracture of shaft of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72399S'  /*Other fracture of shaft of unspecified femur, sequela*/
,'S72401D'  /*Unspecified fracture of lower end of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72401E'  /*Unspecified fracture of lower end of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72401F'  /*Unspecified fracture of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72401G'  /*Unspecified fracture of lower end of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72401H'  /*Unspecified fracture of lower end of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72401J'  /*Unspecified fracture of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72401K'  /*Unspecified fracture of lower end of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72401M'  /*Unspecified fracture of lower end of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72401N'  /*Unspecified fracture of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72401P'  /*Unspecified fracture of lower end of right femur, subsequent encounter for closed fracture with malunion*/
,'S72401Q'  /*Unspecified fracture of lower end of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72401R'  /*Unspecified fracture of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72401S'  /*Unspecified fracture of lower end of right femur, sequela*/
,'S72402D'  /*Unspecified fracture of lower end of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72402E'  /*Unspecified fracture of lower end of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72402F'  /*Unspecified fracture of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72402G'  /*Unspecified fracture of lower end of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72402H'  /*Unspecified fracture of lower end of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72402J'  /*Unspecified fracture of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72402K'  /*Unspecified fracture of lower end of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72402M'  /*Unspecified fracture of lower end of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72402N'  /*Unspecified fracture of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72402P'  /*Unspecified fracture of lower end of left femur, subsequent encounter for closed fracture with malunion*/
,'S72402Q'  /*Unspecified fracture of lower end of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72402R'  /*Unspecified fracture of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72402S'  /*Unspecified fracture of lower end of left femur, sequela*/
,'S72409D'  /*Unspecified fracture of lower end of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72409E'  /*Unspecified fracture of lower end of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72409F'  /*Unspecified fracture of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72409G'  /*Unspecified fracture of lower end of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72409H'  /*Unspecified fracture of lower end of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72409J'  /*Unspecified fracture of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72409K'  /*Unspecified fracture of lower end of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72409M'  /*Unspecified fracture of lower end of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72409N'  /*Unspecified fracture of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72409P'  /*Unspecified fracture of lower end of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72409Q'  /*Unspecified fracture of lower end of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72409R'  /*Unspecified fracture of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72409S'  /*Unspecified fracture of lower end of unspecified femur, sequela*/
,'S72411D'  /*Displaced unspecified condyle fracture of lower end of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72411E'  /*Displaced unspecified condyle fracture of lower end of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72411F'  /*Displaced unspecified condyle fracture of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72411G'  /*Displaced unspecified condyle fracture of lower end of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72411H'  /*Displaced unspecified condyle fracture of lower end of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72411J'  /*Displaced unspecified condyle fracture of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72411K'  /*Displaced unspecified condyle fracture of lower end of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72411M'  /*Displaced unspecified condyle fracture of lower end of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72411N'  /*Displaced unspecified condyle fracture of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72411P'  /*Displaced unspecified condyle fracture of lower end of right femur, subsequent encounter for closed fracture with malunion*/
,'S72411Q'  /*Displaced unspecified condyle fracture of lower end of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72411R'  /*Displaced unspecified condyle fracture of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72411S'  /*Displaced unspecified condyle fracture of lower end of right femur, sequela*/
,'S72412D'  /*Displaced unspecified condyle fracture of lower end of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72412E'  /*Displaced unspecified condyle fracture of lower end of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72412F'  /*Displaced unspecified condyle fracture of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72412G'  /*Displaced unspecified condyle fracture of lower end of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72412H'  /*Displaced unspecified condyle fracture of lower end of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72412J'  /*Displaced unspecified condyle fracture of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72412K'  /*Displaced unspecified condyle fracture of lower end of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72412M'  /*Displaced unspecified condyle fracture of lower end of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72412N'  /*Displaced unspecified condyle fracture of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72412P'  /*Displaced unspecified condyle fracture of lower end of left femur, subsequent encounter for closed fracture with malunion*/
,'S72412Q'  /*Displaced unspecified condyle fracture of lower end of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72412R'  /*Displaced unspecified condyle fracture of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72412S'  /*Displaced unspecified condyle fracture of lower end of left femur, sequela*/
,'S72413D'  /*Displaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72413E'  /*Displaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72413F'  /*Displaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72413G'  /*Displaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72413H'  /*Displaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72413J'  /*Displaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72413K'  /*Displaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72413M'  /*Displaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72413N'  /*Displaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72413P'  /*Displaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72413Q'  /*Displaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72413R'  /*Displaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72413S'  /*Displaced unspecified condyle fracture of lower end of unspecified femur, sequela*/
,'S72414D'  /*Nondisplaced unspecified condyle fracture of lower end of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72414E'  /*Nondisplaced unspecified condyle fracture of lower end of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72414F'  /*Nondisplaced unspecified condyle fracture of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72414G'  /*Nondisplaced unspecified condyle fracture of lower end of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72414H'  /*Nondisplaced unspecified condyle fracture of lower end of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72414J'  /*Nondisplaced unspecified condyle fracture of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72414K'  /*Nondisplaced unspecified condyle fracture of lower end of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72414M'  /*Nondisplaced unspecified condyle fracture of lower end of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72414N'  /*Nondisplaced unspecified condyle fracture of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72414P'  /*Nondisplaced unspecified condyle fracture of lower end of right femur, subsequent encounter for closed fracture with malunion*/
,'S72414Q'  /*Nondisplaced unspecified condyle fracture of lower end of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72414R'  /*Nondisplaced unspecified condyle fracture of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72414S'  /*Nondisplaced unspecified condyle fracture of lower end of right femur, sequela*/
,'S72415D'  /*Nondisplaced unspecified condyle fracture of lower end of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72415E'  /*Nondisplaced unspecified condyle fracture of lower end of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72415F'  /*Nondisplaced unspecified condyle fracture of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72415G'  /*Nondisplaced unspecified condyle fracture of lower end of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72415H'  /*Nondisplaced unspecified condyle fracture of lower end of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72415J'  /*Nondisplaced unspecified condyle fracture of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72415K'  /*Nondisplaced unspecified condyle fracture of lower end of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72415M'  /*Nondisplaced unspecified condyle fracture of lower end of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72415N'  /*Nondisplaced unspecified condyle fracture of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72415P'  /*Nondisplaced unspecified condyle fracture of lower end of left femur, subsequent encounter for closed fracture with malunion*/
,'S72415Q'  /*Nondisplaced unspecified condyle fracture of lower end of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72415R'  /*Nondisplaced unspecified condyle fracture of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72415S'  /*Nondisplaced unspecified condyle fracture of lower end of left femur, sequela*/
,'S72416D'  /*Nondisplaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72416E'  /*Nondisplaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72416F'  /*Nondisplaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72416G'  /*Nondisplaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72416H'  /*Nondisplaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72416J'  /*Nondisplaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72416K'  /*Nondisplaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72416M'  /*Nondisplaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72416N'  /*Nondisplaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72416P'  /*Nondisplaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72416Q'  /*Nondisplaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72416R'  /*Nondisplaced unspecified condyle fracture of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72416S'  /*Nondisplaced unspecified condyle fracture of lower end of unspecified femur, sequela*/
,'S72421D'  /*Displaced fracture of lateral condyle of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72421E'  /*Displaced fracture of lateral condyle of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72421F'  /*Displaced fracture of lateral condyle of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72421G'  /*Displaced fracture of lateral condyle of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72421H'  /*Displaced fracture of lateral condyle of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72421J'  /*Displaced fracture of lateral condyle of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72421K'  /*Displaced fracture of lateral condyle of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72421M'  /*Displaced fracture of lateral condyle of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72421N'  /*Displaced fracture of lateral condyle of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72421P'  /*Displaced fracture of lateral condyle of right femur, subsequent encounter for closed fracture with malunion*/
,'S72421Q'  /*Displaced fracture of lateral condyle of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72421R'  /*Displaced fracture of lateral condyle of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72421S'  /*Displaced fracture of lateral condyle of right femur, sequela*/
,'S72422D'  /*Displaced fracture of lateral condyle of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72422E'  /*Displaced fracture of lateral condyle of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72422F'  /*Displaced fracture of lateral condyle of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72422G'  /*Displaced fracture of lateral condyle of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72422H'  /*Displaced fracture of lateral condyle of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72422J'  /*Displaced fracture of lateral condyle of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72422K'  /*Displaced fracture of lateral condyle of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72422M'  /*Displaced fracture of lateral condyle of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72422N'  /*Displaced fracture of lateral condyle of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72422P'  /*Displaced fracture of lateral condyle of left femur, subsequent encounter for closed fracture with malunion*/
,'S72422Q'  /*Displaced fracture of lateral condyle of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72422R'  /*Displaced fracture of lateral condyle of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72422S'  /*Displaced fracture of lateral condyle of left femur, sequela*/
,'S72423D'  /*Displaced fracture of lateral condyle of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72423E'  /*Displaced fracture of lateral condyle of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72423F'  /*Displaced fracture of lateral condyle of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72423G'  /*Displaced fracture of lateral condyle of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72423H'  /*Displaced fracture of lateral condyle of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72423J'  /*Displaced fracture of lateral condyle of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72423K'  /*Displaced fracture of lateral condyle of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72423M'  /*Displaced fracture of lateral condyle of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72423N'  /*Displaced fracture of lateral condyle of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72423P'  /*Displaced fracture of lateral condyle of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72423Q'  /*Displaced fracture of lateral condyle of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72423R'  /*Displaced fracture of lateral condyle of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72423S'  /*Displaced fracture of lateral condyle of unspecified femur, sequela*/
,'S72424D'  /*Nondisplaced fracture of lateral condyle of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72424E'  /*Nondisplaced fracture of lateral condyle of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72424F'  /*Nondisplaced fracture of lateral condyle of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72424G'  /*Nondisplaced fracture of lateral condyle of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72424H'  /*Nondisplaced fracture of lateral condyle of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72424J'  /*Nondisplaced fracture of lateral condyle of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72424K'  /*Nondisplaced fracture of lateral condyle of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72424M'  /*Nondisplaced fracture of lateral condyle of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72424N'  /*Nondisplaced fracture of lateral condyle of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72424P'  /*Nondisplaced fracture of lateral condyle of right femur, subsequent encounter for closed fracture with malunion*/
,'S72424Q'  /*Nondisplaced fracture of lateral condyle of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72424R'  /*Nondisplaced fracture of lateral condyle of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72424S'  /*Nondisplaced fracture of lateral condyle of right femur, sequela*/
,'S72425D'  /*Nondisplaced fracture of lateral condyle of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72425E'  /*Nondisplaced fracture of lateral condyle of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72425F'  /*Nondisplaced fracture of lateral condyle of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72425G'  /*Nondisplaced fracture of lateral condyle of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72425H'  /*Nondisplaced fracture of lateral condyle of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72425J'  /*Nondisplaced fracture of lateral condyle of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72425K'  /*Nondisplaced fracture of lateral condyle of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72425M'  /*Nondisplaced fracture of lateral condyle of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72425N'  /*Nondisplaced fracture of lateral condyle of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72425P'  /*Nondisplaced fracture of lateral condyle of left femur, subsequent encounter for closed fracture with malunion*/
,'S72425Q'  /*Nondisplaced fracture of lateral condyle of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72425R'  /*Nondisplaced fracture of lateral condyle of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72425S'  /*Nondisplaced fracture of lateral condyle of left femur, sequela*/
,'S72426D'  /*Nondisplaced fracture of lateral condyle of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72426E'  /*Nondisplaced fracture of lateral condyle of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72426F'  /*Nondisplaced fracture of lateral condyle of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72426G'  /*Nondisplaced fracture of lateral condyle of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72426H'  /*Nondisplaced fracture of lateral condyle of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72426J'  /*Nondisplaced fracture of lateral condyle of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72426K'  /*Nondisplaced fracture of lateral condyle of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72426M'  /*Nondisplaced fracture of lateral condyle of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72426N'  /*Nondisplaced fracture of lateral condyle of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72426P'  /*Nondisplaced fracture of lateral condyle of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72426Q'  /*Nondisplaced fracture of lateral condyle of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72426R'  /*Nondisplaced fracture of lateral condyle of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72426S'  /*Nondisplaced fracture of lateral condyle of unspecified femur, sequela*/
,'S72431D'  /*Displaced fracture of medial condyle of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72431E'  /*Displaced fracture of medial condyle of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72431F'  /*Displaced fracture of medial condyle of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72431G'  /*Displaced fracture of medial condyle of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72431H'  /*Displaced fracture of medial condyle of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72431J'  /*Displaced fracture of medial condyle of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72431K'  /*Displaced fracture of medial condyle of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72431M'  /*Displaced fracture of medial condyle of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72431N'  /*Displaced fracture of medial condyle of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72431P'  /*Displaced fracture of medial condyle of right femur, subsequent encounter for closed fracture with malunion*/
,'S72431Q'  /*Displaced fracture of medial condyle of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72431R'  /*Displaced fracture of medial condyle of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72431S'  /*Displaced fracture of medial condyle of right femur, sequela*/
,'S72432D'  /*Displaced fracture of medial condyle of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72432E'  /*Displaced fracture of medial condyle of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72432F'  /*Displaced fracture of medial condyle of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72432G'  /*Displaced fracture of medial condyle of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72432H'  /*Displaced fracture of medial condyle of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72432J'  /*Displaced fracture of medial condyle of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72432K'  /*Displaced fracture of medial condyle of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72432M'  /*Displaced fracture of medial condyle of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72432N'  /*Displaced fracture of medial condyle of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72432P'  /*Displaced fracture of medial condyle of left femur, subsequent encounter for closed fracture with malunion*/
,'S72432Q'  /*Displaced fracture of medial condyle of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72432R'  /*Displaced fracture of medial condyle of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72432S'  /*Displaced fracture of medial condyle of left femur, sequela*/
,'S72433D'  /*Displaced fracture of medial condyle of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72433E'  /*Displaced fracture of medial condyle of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72433F'  /*Displaced fracture of medial condyle of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72433G'  /*Displaced fracture of medial condyle of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72433H'  /*Displaced fracture of medial condyle of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72433J'  /*Displaced fracture of medial condyle of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72433K'  /*Displaced fracture of medial condyle of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72433M'  /*Displaced fracture of medial condyle of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72433N'  /*Displaced fracture of medial condyle of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72433P'  /*Displaced fracture of medial condyle of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72433Q'  /*Displaced fracture of medial condyle of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72433R'  /*Displaced fracture of medial condyle of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72433S'  /*Displaced fracture of medial condyle of unspecified femur, sequela*/
,'S72434D'  /*Nondisplaced fracture of medial condyle of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72434E'  /*Nondisplaced fracture of medial condyle of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72434F'  /*Nondisplaced fracture of medial condyle of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72434G'  /*Nondisplaced fracture of medial condyle of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72434H'  /*Nondisplaced fracture of medial condyle of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72434J'  /*Nondisplaced fracture of medial condyle of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72434K'  /*Nondisplaced fracture of medial condyle of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72434M'  /*Nondisplaced fracture of medial condyle of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72434N'  /*Nondisplaced fracture of medial condyle of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72434P'  /*Nondisplaced fracture of medial condyle of right femur, subsequent encounter for closed fracture with malunion*/
,'S72434Q'  /*Nondisplaced fracture of medial condyle of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72434R'  /*Nondisplaced fracture of medial condyle of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72434S'  /*Nondisplaced fracture of medial condyle of right femur, sequela*/
,'S72435D'  /*Nondisplaced fracture of medial condyle of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72435E'  /*Nondisplaced fracture of medial condyle of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72435F'  /*Nondisplaced fracture of medial condyle of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72435G'  /*Nondisplaced fracture of medial condyle of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72435H'  /*Nondisplaced fracture of medial condyle of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72435J'  /*Nondisplaced fracture of medial condyle of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72435K'  /*Nondisplaced fracture of medial condyle of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72435M'  /*Nondisplaced fracture of medial condyle of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72435N'  /*Nondisplaced fracture of medial condyle of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72435P'  /*Nondisplaced fracture of medial condyle of left femur, subsequent encounter for closed fracture with malunion*/
,'S72435Q'  /*Nondisplaced fracture of medial condyle of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72435R'  /*Nondisplaced fracture of medial condyle of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72435S'  /*Nondisplaced fracture of medial condyle of left femur, sequela*/
,'S72436D'  /*Nondisplaced fracture of medial condyle of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72436E'  /*Nondisplaced fracture of medial condyle of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72436F'  /*Nondisplaced fracture of medial condyle of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72436G'  /*Nondisplaced fracture of medial condyle of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72436H'  /*Nondisplaced fracture of medial condyle of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72436J'  /*Nondisplaced fracture of medial condyle of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72436K'  /*Nondisplaced fracture of medial condyle of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72436M'  /*Nondisplaced fracture of medial condyle of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72436N'  /*Nondisplaced fracture of medial condyle of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72436P'  /*Nondisplaced fracture of medial condyle of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72436Q'  /*Nondisplaced fracture of medial condyle of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72436R'  /*Nondisplaced fracture of medial condyle of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72436S'  /*Nondisplaced fracture of medial condyle of unspecified femur, sequela*/
,'S72441D'  /*Displaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72441E'  /*Displaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72441F'  /*Displaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72441G'  /*Displaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72441H'  /*Displaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72441J'  /*Displaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72441K'  /*Displaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72441M'  /*Displaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72441N'  /*Displaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72441P'  /*Displaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for closed fracture with malunion*/
,'S72441Q'  /*Displaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72441R'  /*Displaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72441S'  /*Displaced fracture of lower epiphysis (separation) of right femur, sequela*/
,'S72442D'  /*Displaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72442E'  /*Displaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72442F'  /*Displaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72442G'  /*Displaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72442H'  /*Displaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72442J'  /*Displaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72442K'  /*Displaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72442M'  /*Displaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72442N'  /*Displaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72442P'  /*Displaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for closed fracture with malunion*/
,'S72442Q'  /*Displaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72442R'  /*Displaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72442S'  /*Displaced fracture of lower epiphysis (separation) of left femur, sequela*/
,'S72443D'  /*Displaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72443E'  /*Displaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72443F'  /*Displaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72443G'  /*Displaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72443H'  /*Displaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72443J'  /*Displaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72443K'  /*Displaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72443M'  /*Displaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72443N'  /*Displaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72443P'  /*Displaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72443Q'  /*Displaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72443R'  /*Displaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72443S'  /*Displaced fracture of lower epiphysis (separation) of unspecified femur, sequela*/
,'S72444D'  /*Nondisplaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72444E'  /*Nondisplaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72444F'  /*Nondisplaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72444G'  /*Nondisplaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72444H'  /*Nondisplaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72444J'  /*Nondisplaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72444K'  /*Nondisplaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72444M'  /*Nondisplaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72444N'  /*Nondisplaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72444P'  /*Nondisplaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for closed fracture with malunion*/
,'S72444Q'  /*Nondisplaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72444R'  /*Nondisplaced fracture of lower epiphysis (separation) of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72444S'  /*Nondisplaced fracture of lower epiphysis (separation) of right femur, sequela*/
,'S72445D'  /*Nondisplaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72445E'  /*Nondisplaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72445F'  /*Nondisplaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72445G'  /*Nondisplaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72445H'  /*Nondisplaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72445J'  /*Nondisplaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72445K'  /*Nondisplaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72445M'  /*Nondisplaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72445N'  /*Nondisplaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72445P'  /*Nondisplaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for closed fracture with malunion*/
,'S72445Q'  /*Nondisplaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72445R'  /*Nondisplaced fracture of lower epiphysis (separation) of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72445S'  /*Nondisplaced fracture of lower epiphysis (separation) of left femur, sequela*/
,'S72446D'  /*Nondisplaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72446E'  /*Nondisplaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72446F'  /*Nondisplaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72446G'  /*Nondisplaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72446H'  /*Nondisplaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72446J'  /*Nondisplaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72446K'  /*Nondisplaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72446M'  /*Nondisplaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72446N'  /*Nondisplaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72446P'  /*Nondisplaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72446Q'  /*Nondisplaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72446R'  /*Nondisplaced fracture of lower epiphysis (separation) of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72446S'  /*Nondisplaced fracture of lower epiphysis (separation) of unspecified femur, sequela*/
,'S72451D'  /*Displaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72451E'  /*Displaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72451F'  /*Displaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72451G'  /*Displaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72451H'  /*Displaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72451J'  /*Displaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72451K'  /*Displaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72451M'  /*Displaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72451N'  /*Displaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72451P'  /*Displaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for closed fracture with malunion*/
,'S72451Q'  /*Displaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72451R'  /*Displaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72451S'  /*Displaced supracondylar fracture without intracondylar extension of lower end of right femur, sequela*/
,'S72452D'  /*Displaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72452E'  /*Displaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72452F'  /*Displaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72452G'  /*Displaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72452H'  /*Displaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72452J'  /*Displaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72452K'  /*Displaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72452M'  /*Displaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72452N'  /*Displaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72452P'  /*Displaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for closed fracture with malunion*/
,'S72452Q'  /*Displaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72452R'  /*Displaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72452S'  /*Displaced supracondylar fracture without intracondylar extension of lower end of left femur, sequela*/
,'S72453D'  /*Displaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72453E'  /*Displaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72453F'  /*Displaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72453G'  /*Displaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72453H'  /*Displaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72453J'  /*Displaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72453K'  /*Displaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72453M'  /*Displaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72453N'  /*Displaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72453P'  /*Displaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72453Q'  /*Displaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72453R'  /*Displaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72453S'  /*Displaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, sequela*/
,'S72454D'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72454E'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72454F'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72454G'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72454H'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72454J'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72454K'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72454M'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72454N'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72454P'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for closed fracture with malunion*/
,'S72454Q'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72454R'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72454S'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of right femur, sequela*/
,'S72455D'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72455E'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72455F'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72455G'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72455H'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72455J'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72455K'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72455M'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72455N'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72455P'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for closed fracture with malunion*/
,'S72455Q'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72455R'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72455S'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of left femur, sequela*/
,'S72456D'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72456E'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72456F'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72456G'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72456H'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72456J'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72456K'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72456M'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72456N'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72456P'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72456Q'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72456R'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72456S'  /*Nondisplaced supracondylar fracture without intracondylar extension of lower end of unspecified femur, sequela*/
,'S72461D'  /*Displaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72461E'  /*Displaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72461F'  /*Displaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72461G'  /*Displaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72461H'  /*Displaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72461J'  /*Displaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72461K'  /*Displaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72461M'  /*Displaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72461N'  /*Displaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72461P'  /*Displaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for closed fracture with malunion*/
,'S72461Q'  /*Displaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72461R'  /*Displaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72461S'  /*Displaced supracondylar fracture with intracondylar extension of lower end of right femur, sequela*/
,'S72462D'  /*Displaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72462E'  /*Displaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72462F'  /*Displaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72462G'  /*Displaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72462H'  /*Displaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72462J'  /*Displaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72462K'  /*Displaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72462M'  /*Displaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72462N'  /*Displaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72462P'  /*Displaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for closed fracture with malunion*/
,'S72462Q'  /*Displaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72462R'  /*Displaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72462S'  /*Displaced supracondylar fracture with intracondylar extension of lower end of left femur, sequela*/
,'S72463D'  /*Displaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72463E'  /*Displaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72463F'  /*Displaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72463G'  /*Displaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72463H'  /*Displaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72463J'  /*Displaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72463K'  /*Displaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72463M'  /*Displaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72463N'  /*Displaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72463P'  /*Displaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72463Q'  /*Displaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72463R'  /*Displaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72463S'  /*Displaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, sequela*/
,'S72464D'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72464E'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72464F'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72464G'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72464H'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72464J'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72464K'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72464M'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72464N'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72464P'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for closed fracture with malunion*/
,'S72464Q'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72464R'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72464S'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of right femur, sequela*/
,'S72465D'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72465E'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72465F'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72465G'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72465H'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72465J'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72465K'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72465M'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72465N'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72465P'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for closed fracture with malunion*/
,'S72465Q'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72465R'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72465S'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of left femur, sequela*/
,'S72466D'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72466E'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72466F'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72466G'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72466H'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72466J'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72466K'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72466M'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72466N'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72466P'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72466Q'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72466R'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72466S'  /*Nondisplaced supracondylar fracture with intracondylar extension of lower end of unspecified femur, sequela*/
,'S72471D'  /*Torus fracture of lower end of right femur, subsequent encounter for fracture with routine healing*/
,'S72471G'  /*Torus fracture of lower end of right femur, subsequent encounter for fracture with delayed healing*/
,'S72471K'  /*Torus fracture of lower end of right femur, subsequent encounter for fracture with nonunion*/
,'S72471P'  /*Torus fracture of lower end of right femur, subsequent encounter for fracture with malunion*/
,'S72471S'  /*Torus fracture of lower end of right femur, sequela*/
,'S72472D'  /*Torus fracture of lower end of left femur, subsequent encounter for fracture with routine healing*/
,'S72472G'  /*Torus fracture of lower end of left femur, subsequent encounter for fracture with delayed healing*/
,'S72472K'  /*Torus fracture of lower end of left femur, subsequent encounter for fracture with nonunion*/
,'S72472P'  /*Torus fracture of lower end of left femur, subsequent encounter for fracture with malunion*/
,'S72472S'  /*Torus fracture of lower end of left femur, sequela*/
,'S72479D'  /*Torus fracture of lower end of unspecified femur, subsequent encounter for fracture with routine healing*/
,'S72479G'  /*Torus fracture of lower end of unspecified femur, subsequent encounter for fracture with delayed healing*/
,'S72479K'  /*Torus fracture of lower end of unspecified femur, subsequent encounter for fracture with nonunion*/
,'S72479P'  /*Torus fracture of lower end of unspecified femur, subsequent encounter for fracture with malunion*/
,'S72479S'  /*Torus fracture of lower end of unspecified femur, sequela*/
,'S72491D'  /*Other fracture of lower end of right femur, subsequent encounter for closed fracture with routine healing*/
,'S72491E'  /*Other fracture of lower end of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72491F'  /*Other fracture of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72491G'  /*Other fracture of lower end of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S72491H'  /*Other fracture of lower end of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72491J'  /*Other fracture of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72491K'  /*Other fracture of lower end of right femur, subsequent encounter for closed fracture with nonunion*/
,'S72491M'  /*Other fracture of lower end of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72491N'  /*Other fracture of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72491P'  /*Other fracture of lower end of right femur, subsequent encounter for closed fracture with malunion*/
,'S72491Q'  /*Other fracture of lower end of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72491R'  /*Other fracture of lower end of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72491S'  /*Other fracture of lower end of right femur, sequela*/
,'S72492D'  /*Other fracture of lower end of left femur, subsequent encounter for closed fracture with routine healing*/
,'S72492E'  /*Other fracture of lower end of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72492F'  /*Other fracture of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72492G'  /*Other fracture of lower end of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S72492H'  /*Other fracture of lower end of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72492J'  /*Other fracture of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72492K'  /*Other fracture of lower end of left femur, subsequent encounter for closed fracture with nonunion*/
,'S72492M'  /*Other fracture of lower end of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72492N'  /*Other fracture of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72492P'  /*Other fracture of lower end of left femur, subsequent encounter for closed fracture with malunion*/
,'S72492Q'  /*Other fracture of lower end of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72492R'  /*Other fracture of lower end of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72492S'  /*Other fracture of lower end of left femur, sequela*/
,'S72499D'  /*Other fracture of lower end of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S72499E'  /*Other fracture of lower end of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S72499F'  /*Other fracture of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S72499G'  /*Other fracture of lower end of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S72499H'  /*Other fracture of lower end of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S72499J'  /*Other fracture of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S72499K'  /*Other fracture of lower end of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S72499M'  /*Other fracture of lower end of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S72499N'  /*Other fracture of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S72499P'  /*Other fracture of lower end of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S72499Q'  /*Other fracture of lower end of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S72499R'  /*Other fracture of lower end of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S72499S'  /*Other fracture of lower end of unspecified femur, sequela*/
,'S728X1D'  /*Other fracture of right femur, subsequent encounter for closed fracture with routine healing*/
,'S728X1E'  /*Other fracture of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S728X1F'  /*Other fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S728X1G'  /*Other fracture of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S728X1H'  /*Other fracture of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S728X1J'  /*Other fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S728X1K'  /*Other fracture of right femur, subsequent encounter for closed fracture with nonunion*/
,'S728X1M'  /*Other fracture of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S728X1N'  /*Other fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S728X1P'  /*Other fracture of right femur, subsequent encounter for closed fracture with malunion*/
,'S728X1Q'  /*Other fracture of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S728X1R'  /*Other fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S728X1S'  /*Other fracture of right femur, sequela*/
,'S728X2D'  /*Other fracture of left femur, subsequent encounter for closed fracture with routine healing*/
,'S728X2E'  /*Other fracture of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S728X2F'  /*Other fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S728X2G'  /*Other fracture of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S728X2H'  /*Other fracture of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S728X2J'  /*Other fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S728X2K'  /*Other fracture of left femur, subsequent encounter for closed fracture with nonunion*/
,'S728X2M'  /*Other fracture of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S728X2N'  /*Other fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S728X2P'  /*Other fracture of left femur, subsequent encounter for closed fracture with malunion*/
,'S728X2Q'  /*Other fracture of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S728X2R'  /*Other fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S728X2S'  /*Other fracture of left femur, sequela*/
,'S728X9D'  /*Other fracture of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S728X9E'  /*Other fracture of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S728X9F'  /*Other fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S728X9G'  /*Other fracture of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S728X9H'  /*Other fracture of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S728X9J'  /*Other fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S728X9K'  /*Other fracture of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S728X9M'  /*Other fracture of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S728X9N'  /*Other fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S728X9P'  /*Other fracture of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S728X9Q'  /*Other fracture of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S728X9R'  /*Other fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S728X9S'  /*Other fracture of unspecified femur, sequela*/
,'S7290XD'  /*Unspecified fracture of unspecified femur, subsequent encounter for closed fracture with routine healing*/
,'S7290XE'  /*Unspecified fracture of unspecified femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S7290XF'  /*Unspecified fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S7290XG'  /*Unspecified fracture of unspecified femur, subsequent encounter for closed fracture with delayed healing*/
,'S7290XH'  /*Unspecified fracture of unspecified femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S7290XJ'  /*Unspecified fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S7290XK'  /*Unspecified fracture of unspecified femur, subsequent encounter for closed fracture with nonunion*/
,'S7290XM'  /*Unspecified fracture of unspecified femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S7290XN'  /*Unspecified fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S7290XP'  /*Unspecified fracture of unspecified femur, subsequent encounter for closed fracture with malunion*/
,'S7290XQ'  /*Unspecified fracture of unspecified femur, subsequent encounter for open fracture type I or II with malunion*/
,'S7290XR'  /*Unspecified fracture of unspecified femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S7290XS'  /*Unspecified fracture of unspecified femur, sequela*/
,'S7291XD'  /*Unspecified fracture of right femur, subsequent encounter for closed fracture with routine healing*/
,'S7291XE'  /*Unspecified fracture of right femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S7291XF'  /*Unspecified fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S7291XG'  /*Unspecified fracture of right femur, subsequent encounter for closed fracture with delayed healing*/
,'S7291XH'  /*Unspecified fracture of right femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S7291XJ'  /*Unspecified fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S7291XK'  /*Unspecified fracture of right femur, subsequent encounter for closed fracture with nonunion*/
,'S7291XM'  /*Unspecified fracture of right femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S7291XN'  /*Unspecified fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S7291XP'  /*Unspecified fracture of right femur, subsequent encounter for closed fracture with malunion*/
,'S7291XQ'  /*Unspecified fracture of right femur, subsequent encounter for open fracture type I or II with malunion*/
,'S7291XR'  /*Unspecified fracture of right femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S7291XS'  /*Unspecified fracture of right femur, sequela*/
,'S7292XD'  /*Unspecified fracture of left femur, subsequent encounter for closed fracture with routine healing*/
,'S7292XE'  /*Unspecified fracture of left femur, subsequent encounter for open fracture type I or II with routine healing*/
,'S7292XF'  /*Unspecified fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S7292XG'  /*Unspecified fracture of left femur, subsequent encounter for closed fracture with delayed healing*/
,'S7292XH'  /*Unspecified fracture of left femur, subsequent encounter for open fracture type I or II with delayed healing*/
,'S7292XJ'  /*Unspecified fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S7292XK'  /*Unspecified fracture of left femur, subsequent encounter for closed fracture with nonunion*/
,'S7292XM'  /*Unspecified fracture of left femur, subsequent encounter for open fracture type I or II with nonunion*/
,'S7292XN'  /*Unspecified fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S7292XP'  /*Unspecified fracture of left femur, subsequent encounter for closed fracture with malunion*/
,'S7292XQ'  /*Unspecified fracture of left femur, subsequent encounter for open fracture type I or II with malunion*/
,'S7292XR'  /*Unspecified fracture of left femur, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S7292XS'  /*Unspecified fracture of left femur, sequela*/
,'S73001D'  /*Unspecified subluxation of right hip, subsequent encounter*/
,'S73001S'  /*Unspecified subluxation of right hip, sequela*/
,'S73002D'  /*Unspecified subluxation of left hip, subsequent encounter*/
,'S73002S'  /*Unspecified subluxation of left hip, sequela*/
,'S73003D'  /*Unspecified subluxation of unspecified hip, subsequent encounter*/
,'S73003S'  /*Unspecified subluxation of unspecified hip, sequela*/
,'S73004D'  /*Unspecified dislocation of right hip, subsequent encounter*/
,'S73004S'  /*Unspecified dislocation of right hip, sequela*/
,'S73005D'  /*Unspecified dislocation of left hip, subsequent encounter*/
,'S73005S'  /*Unspecified dislocation of left hip, sequela*/
,'S73006D'  /*Unspecified dislocation of unspecified hip, subsequent encounter*/
,'S73006S'  /*Unspecified dislocation of unspecified hip, sequela*/
,'S73011D'  /*Posterior subluxation of right hip, subsequent encounter*/
,'S73011S'  /*Posterior subluxation of right hip, sequela*/
,'S73012D'  /*Posterior subluxation of left hip, subsequent encounter*/
,'S73012S'  /*Posterior subluxation of left hip, sequela*/
,'S73013D'  /*Posterior subluxation of unspecified hip, subsequent encounter*/
,'S73013S'  /*Posterior subluxation of unspecified hip, sequela*/
,'S73014D'  /*Posterior dislocation of right hip, subsequent encounter*/
,'S73014S'  /*Posterior dislocation of right hip, sequela*/
,'S73015D'  /*Posterior dislocation of left hip, subsequent encounter*/
,'S73015S'  /*Posterior dislocation of left hip, sequela*/
,'S73016D'  /*Posterior dislocation of unspecified hip, subsequent encounter*/
,'S73016S'  /*Posterior dislocation of unspecified hip, sequela*/
,'S73021D'  /*Obturator subluxation of right hip, subsequent encounter*/
,'S73021S'  /*Obturator subluxation of right hip, sequela*/
,'S73022D'  /*Obturator subluxation of left hip, subsequent encounter*/
,'S73022S'  /*Obturator subluxation of left hip, sequela*/
,'S73023D'  /*Obturator subluxation of unspecified hip, subsequent encounter*/
,'S73023S'  /*Obturator subluxation of unspecified hip, sequela*/
,'S73024D'  /*Obturator dislocation of right hip, subsequent encounter*/
,'S73024S'  /*Obturator dislocation of right hip, sequela*/
,'S73025D'  /*Obturator dislocation of left hip, subsequent encounter*/
,'S73025S'  /*Obturator dislocation of left hip, sequela*/
,'S73026D'  /*Obturator dislocation of unspecified hip, subsequent encounter*/
,'S73026S'  /*Obturator dislocation of unspecified hip, sequela*/
,'S73031D'  /*Other anterior subluxation of right hip, subsequent encounter*/
,'S73031S'  /*Other anterior subluxation of right hip, sequela*/
,'S73032D'  /*Other anterior subluxation of left hip, subsequent encounter*/
,'S73032S'  /*Other anterior subluxation of left hip, sequela*/
,'S73033D'  /*Other anterior subluxation of unspecified hip, subsequent encounter*/
,'S73033S'  /*Other anterior subluxation of unspecified hip, sequela*/
,'S73034D'  /*Other anterior dislocation of right hip, subsequent encounter*/
,'S73034S'  /*Other anterior dislocation of right hip, sequela*/
,'S73035D'  /*Other anterior dislocation of left hip, subsequent encounter*/
,'S73035S'  /*Other anterior dislocation of left hip, sequela*/
,'S73036D'  /*Other anterior dislocation of unspecified hip, subsequent encounter*/
,'S73036S'  /*Other anterior dislocation of unspecified hip, sequela*/
,'S73041D'  /*Central subluxation of right hip, subsequent encounter*/
,'S73041S'  /*Central subluxation of right hip, sequela*/
,'S73042D'  /*Central subluxation of left hip, subsequent encounter*/
,'S73042S'  /*Central subluxation of left hip, sequela*/
,'S73043D'  /*Central subluxation of unspecified hip, subsequent encounter*/
,'S73043S'  /*Central subluxation of unspecified hip, sequela*/
,'S73044D'  /*Central dislocation of right hip, subsequent encounter*/
,'S73044S'  /*Central dislocation of right hip, sequela*/
,'S73045D'  /*Central dislocation of left hip, subsequent encounter*/
,'S73045S'  /*Central dislocation of left hip, sequela*/
,'S73046D'  /*Central dislocation of unspecified hip, subsequent encounter*/
,'S73046S'  /*Central dislocation of unspecified hip, sequela*/
,'S73101D'  /*Unspecified sprain of right hip, subsequent encounter*/
,'S73101S'  /*Unspecified sprain of right hip, sequela*/
,'S73102D'  /*Unspecified sprain of left hip, subsequent encounter*/
,'S73102S'  /*Unspecified sprain of left hip, sequela*/
,'S73109D'  /*Unspecified sprain of unspecified hip, subsequent encounter*/
,'S73109S'  /*Unspecified sprain of unspecified hip, sequela*/
,'S73111D'  /*Iliofemoral ligament sprain of right hip, subsequent encounter*/
,'S73111S'  /*Iliofemoral ligament sprain of right hip, sequela*/
,'S73112D'  /*Iliofemoral ligament sprain of left hip, subsequent encounter*/
,'S73112S'  /*Iliofemoral ligament sprain of left hip, sequela*/
,'S73119D'  /*Iliofemoral ligament sprain of unspecified hip, subsequent encounter*/
,'S73119S'  /*Iliofemoral ligament sprain of unspecified hip, sequela*/
,'S73121D'  /*Ischiocapsular ligament sprain of right hip, subsequent encounter*/
,'S73121S'  /*Ischiocapsular ligament sprain of right hip, sequela*/
,'S73122D'  /*Ischiocapsular ligament sprain of left hip, subsequent encounter*/
,'S73122S'  /*Ischiocapsular ligament sprain of left hip, sequela*/
,'S73129D'  /*Ischiocapsular ligament sprain of unspecified hip, subsequent encounter*/
,'S73129S'  /*Ischiocapsular ligament sprain of unspecified hip, sequela*/
,'S73191D'  /*Other sprain of right hip, subsequent encounter*/
,'S73191S'  /*Other sprain of right hip, sequela*/
,'S73192D'  /*Other sprain of left hip, subsequent encounter*/
,'S73192S'  /*Other sprain of left hip, sequela*/
,'S73199D'  /*Other sprain of unspecified hip, subsequent encounter*/
,'S73199S'  /*Other sprain of unspecified hip, sequela*/
,'S7400XD'  /*Injury of sciatic nerve at hip and thigh level, unspecified leg, subsequent encounter*/
,'S7400XS'  /*Injury of sciatic nerve at hip and thigh level, unspecified leg, sequela*/
,'S7401XD'  /*Injury of sciatic nerve at hip and thigh level, right leg, subsequent encounter*/
,'S7401XS'  /*Injury of sciatic nerve at hip and thigh level, right leg, sequela*/
,'S7402XD'  /*Injury of sciatic nerve at hip and thigh level, left leg, subsequent encounter*/
,'S7402XS'  /*Injury of sciatic nerve at hip and thigh level, left leg, sequela*/
,'S7410XD'  /*Injury of femoral nerve at hip and thigh level, unspecified leg, subsequent encounter*/
,'S7410XS'  /*Injury of femoral nerve at hip and thigh level, unspecified leg, sequela*/
,'S7411XD'  /*Injury of femoral nerve at hip and thigh level, right leg, subsequent encounter*/
,'S7411XS'  /*Injury of femoral nerve at hip and thigh level, right leg, sequela*/
,'S7412XD'  /*Injury of femoral nerve at hip and thigh level, left leg, subsequent encounter*/
,'S7412XS'  /*Injury of femoral nerve at hip and thigh level, left leg, sequela*/
,'S7420XD'  /*Injury of cutaneous sensory nerve at hip and thigh level, unspecified leg, subsequent encounter*/
,'S7420XS'  /*Injury of cutaneous sensory nerve at hip and thigh level, unspecified leg, sequela*/
,'S7421XD'  /*Injury of cutaneous sensory nerve at hip and high level, right leg, subsequent encounter*/
,'S7421XS'  /*Injury of cutaneous sensory nerve at hip and high level, right leg, sequela*/
,'S7422XD'  /*Injury of cutaneous sensory nerve at hip and thigh level, left leg, subsequent encounter*/
,'S7422XS'  /*Injury of cutaneous sensory nerve at hip and thigh level, left leg, sequela*/
,'S748X1D'  /*Injury of other nerves at hip and thigh level, right leg, subsequent encounter*/
,'S748X1S'  /*Injury of other nerves at hip and thigh level, right leg, sequela*/
,'S748X2D'  /*Injury of other nerves at hip and thigh level, left leg, subsequent encounter*/
,'S748X2S'  /*Injury of other nerves at hip and thigh level, left leg, sequela*/
,'S748X9D'  /*Injury of other nerves at hip and thigh level, unspecified leg, subsequent encounter*/
,'S748X9S'  /*Injury of other nerves at hip and thigh level, unspecified leg, sequela*/
,'S7490XD'  /*Injury of unspecified nerve at hip and thigh level, unspecified leg, subsequent encounter*/
,'S7490XS'  /*Injury of unspecified nerve at hip and thigh level, unspecified leg, sequela*/
,'S7491XD'  /*Injury of unspecified nerve at hip and thigh level, right leg, subsequent encounter*/
,'S7491XS'  /*Injury of unspecified nerve at hip and thigh level, right leg, sequela*/
,'S7492XD'  /*Injury of unspecified nerve at hip and thigh level, left leg, subsequent encounter*/
,'S7492XS'  /*Injury of unspecified nerve at hip and thigh level, left leg, sequela*/
,'S75001D'  /*Unspecified injury of femoral artery, right leg, subsequent encounter*/
,'S75001S'  /*Unspecified injury of femoral artery, right leg, sequela*/
,'S75002D'  /*Unspecified injury of femoral artery, left leg, subsequent encounter*/
,'S75002S'  /*Unspecified injury of femoral artery, left leg, sequela*/
,'S75009D'  /*Unspecified injury of femoral artery, unspecified leg, subsequent encounter*/
,'S75009S'  /*Unspecified injury of femoral artery, unspecified leg, sequela*/
,'S75011D'  /*Minor laceration of femoral artery, right leg, subsequent encounter*/
,'S75011S'  /*Minor laceration of femoral artery, right leg, sequela*/
,'S75012D'  /*Minor laceration of femoral artery, left leg, subsequent encounter*/
,'S75012S'  /*Minor laceration of femoral artery, left leg, sequela*/
,'S75019D'  /*Minor laceration of femoral artery, unspecified leg, subsequent encounter*/
,'S75019S'  /*Minor laceration of femoral artery, unspecified leg, sequela*/
,'S75021D'  /*Major laceration of femoral artery, right leg, subsequent encounter*/
,'S75021S'  /*Major laceration of femoral artery, right leg, sequela*/
,'S75022D'  /*Major laceration of femoral artery, left leg, subsequent encounter*/
,'S75022S'  /*Major laceration of femoral artery, left leg, sequela*/
,'S75029D'  /*Major laceration of femoral artery, unspecified leg, subsequent encounter*/
,'S75029S'  /*Major laceration of femoral artery, unspecified leg, sequela*/
,'S75091D'  /*Other specified injury of femoral artery, right leg, subsequent encounter*/
,'S75091S'  /*Other specified injury of femoral artery, right leg, sequela*/
,'S75092D'  /*Other specified injury of femoral artery, left leg, subsequent encounter*/
,'S75092S'  /*Other specified injury of femoral artery, left leg, sequela*/
,'S75099D'  /*Other specified injury of femoral artery, unspecified leg, subsequent encounter*/
,'S75099S'  /*Other specified injury of femoral artery, unspecified leg, sequela*/
,'S75101D'  /*Unspecified injury of femoral vein at hip and thigh level, right leg, subsequent encounter*/
,'S75101S'  /*Unspecified injury of femoral vein at hip and thigh level, right leg, sequela*/
,'S75102D'  /*Unspecified injury of femoral vein at hip and thigh level, left leg, subsequent encounter*/
,'S75102S'  /*Unspecified injury of femoral vein at hip and thigh level, left leg, sequela*/
,'S75109D'  /*Unspecified injury of femoral vein at hip and thigh level, unspecified leg, subsequent encounter*/
,'S75109S'  /*Unspecified injury of femoral vein at hip and thigh level, unspecified leg, sequela*/
,'S75111D'  /*Minor laceration of femoral vein at hip and thigh level, right leg, subsequent encounter*/
,'S75111S'  /*Minor laceration of femoral vein at hip and thigh level, right leg, sequela*/
,'S75112D'  /*Minor laceration of femoral vein at hip and thigh level, left leg, subsequent encounter*/
,'S75112S'  /*Minor laceration of femoral vein at hip and thigh level, left leg, sequela*/
,'S75119D'  /*Minor laceration of femoral vein at hip and thigh level, unspecified leg, subsequent encounter*/
,'S75119S'  /*Minor laceration of femoral vein at hip and thigh level, unspecified leg, sequela*/
,'S75121D'  /*Major laceration of femoral vein at hip and thigh level, right leg, subsequent encounter*/
,'S75121S'  /*Major laceration of femoral vein at hip and thigh level, right leg, sequela*/
,'S75122D'  /*Major laceration of femoral vein at hip and thigh level, left leg, subsequent encounter*/
,'S75122S'  /*Major laceration of femoral vein at hip and thigh level, left leg, sequela*/
,'S75129D'  /*Major laceration of femoral vein at hip and thigh level, unspecified leg, subsequent encounter*/
,'S75129S'  /*Major laceration of femoral vein at hip and thigh level, unspecified leg, sequela*/
,'S75191D'  /*Other specified injury of femoral vein at hip and thigh level, right leg, subsequent encounter*/
,'S75191S'  /*Other specified injury of femoral vein at hip and thigh level, right leg, sequela*/
,'S75192D'  /*Other specified injury of femoral vein at hip and thigh level, left leg, subsequent encounter*/
,'S75192S'  /*Other specified injury of femoral vein at hip and thigh level, left leg, sequela*/
,'S75199D'  /*Other specified injury of femoral vein at hip and thigh level, unspecified leg, subsequent encounter*/
,'S75199S'  /*Other specified injury of femoral vein at hip and thigh level, unspecified leg, sequela*/
,'S75201D'  /*Unspecified injury of greater saphenous vein at hip and thigh level, right leg, subsequent encounter*/
,'S75201S'  /*Unspecified injury of greater saphenous vein at hip and thigh level, right leg, sequela*/
,'S75202D'  /*Unspecified injury of greater saphenous vein at hip and thigh level, left leg, subsequent encounter*/
,'S75202S'  /*Unspecified injury of greater saphenous vein at hip and thigh level, left leg, sequela*/
,'S75209D'  /*Unspecified injury of greater saphenous vein at hip and thigh level, unspecified leg, subsequent encounter*/
,'S75209S'  /*Unspecified injury of greater saphenous vein at hip and thigh level, unspecified leg, sequela*/
,'S75211D'  /*Minor laceration of greater saphenous vein at hip and thigh level, right leg, subsequent encounter*/
,'S75211S'  /*Minor laceration of greater saphenous vein at hip and thigh level, right leg, sequela*/
,'S75212D'  /*Minor laceration of greater saphenous vein at hip and thigh level, left leg, subsequent encounter*/
,'S75212S'  /*Minor laceration of greater saphenous vein at hip and thigh level, left leg, sequela*/
,'S75219D'  /*Minor laceration of greater saphenous vein at hip and thigh level, unspecified leg, subsequent encounter*/
,'S75219S'  /*Minor laceration of greater saphenous vein at hip and thigh level, unspecified leg, sequela*/
,'S75221D'  /*Major laceration of greater saphenous vein at hip and thigh level, right leg, subsequent encounter*/
,'S75221S'  /*Major laceration of greater saphenous vein at hip and thigh level, right leg, sequela*/
,'S75222D'  /*Major laceration of greater saphenous vein at hip and thigh level, left leg, subsequent encounter*/
,'S75222S'  /*Major laceration of greater saphenous vein at hip and thigh level, left leg, sequela*/
,'S75229D'  /*Major laceration of greater saphenous vein at hip and thigh level, unspecified leg, subsequent encounter*/
,'S75229S'  /*Major laceration of greater saphenous vein at hip and thigh level, unspecified leg, sequela*/
,'S75291D'  /*Other specified injury of greater saphenous vein at hip and thigh level, right leg, subsequent encounter*/
,'S75291S'  /*Other specified injury of greater saphenous vein at hip and thigh level, right leg, sequela*/
,'S75292D'  /*Other specified injury of greater saphenous vein at hip and thigh level, left leg, subsequent encounter*/
,'S75292S'  /*Other specified injury of greater saphenous vein at hip and thigh level, left leg, sequela*/
,'S75299D'  /*Other specified injury of greater saphenous vein at hip and thigh level, unspecified leg, subsequent encounter*/
,'S75299S'  /*Other specified injury of greater saphenous vein at hip and thigh level, unspecified leg, sequela*/
,'S75801D'  /*Unspecified injury of other blood vessels at hip and thigh level, right leg, subsequent encounter*/
,'S75801S'  /*Unspecified injury of other blood vessels at hip and thigh level, right leg, sequela*/
,'S75802D'  /*Unspecified injury of other blood vessels at hip and thigh level, left leg, subsequent encounter*/
,'S75802S'  /*Unspecified injury of other blood vessels at hip and thigh level, left leg, sequela*/
,'S75809D'  /*Unspecified injury of other blood vessels at hip and thigh level, unspecified leg, subsequent encounter*/
,'S75809S'  /*Unspecified injury of other blood vessels at hip and thigh level, unspecified leg, sequela*/
,'S75811D'  /*Laceration of other blood vessels at hip and thigh level, right leg, subsequent encounter*/
,'S75811S'  /*Laceration of other blood vessels at hip and thigh level, right leg, sequela*/
,'S75812D'  /*Laceration of other blood vessels at hip and thigh level, left leg, subsequent encounter*/
,'S75812S'  /*Laceration of other blood vessels at hip and thigh level, left leg, sequela*/
,'S75819D'  /*Laceration of other blood vessels at hip and thigh level, unspecified leg, subsequent encounter*/
,'S75819S'  /*Laceration of other blood vessels at hip and thigh level, unspecified leg, sequela*/
,'S75891D'  /*Other specified injury of other blood vessels at hip and thigh level, right leg, subsequent encounter*/
,'S75891S'  /*Other specified injury of other blood vessels at hip and thigh level, right leg, sequela*/
,'S75892D'  /*Other specified injury of other blood vessels at hip and thigh level, left leg, subsequent encounter*/
,'S75892S'  /*Other specified injury of other blood vessels at hip and thigh level, left leg, sequela*/
,'S75899D'  /*Other specified injury of other blood vessels at hip and thigh level, unspecified leg, subsequent encounter*/
,'S75899S'  /*Other specified injury of other blood vessels at hip and thigh level, unspecified leg, sequela*/
,'S75901D'  /*Unspecified injury of unspecified blood vessel at hip and thigh level, right leg, subsequent encounter*/
,'S75901S'  /*Unspecified injury of unspecified blood vessel at hip and thigh level, right leg, sequela*/
,'S75902D'  /*Unspecified injury of unspecified blood vessel at hip and thigh level, left leg, subsequent encounter*/
,'S75902S'  /*Unspecified injury of unspecified blood vessel at hip and thigh level, left leg, sequela*/
,'S75909D'  /*Unspecified injury of unspecified blood vessel at hip and thigh level, unspecified leg, subsequent encounter*/
,'S75909S'  /*Unspecified injury of unspecified blood vessel at hip and thigh level, unspecified leg, sequela*/
,'S75911D'  /*Laceration of unspecified blood vessel at hip and thigh level, right leg, subsequent encounter*/
,'S75911S'  /*Laceration of unspecified blood vessel at hip and thigh level, right leg, sequela*/
,'S75912D'  /*Laceration of unspecified blood vessel at hip and thigh level, left leg, subsequent encounter*/
,'S75912S'  /*Laceration of unspecified blood vessel at hip and thigh level, left leg, sequela*/
,'S75919D'  /*Laceration of unspecified blood vessel at hip and thigh level, unspecified leg, subsequent encounter*/
,'S75919S'  /*Laceration of unspecified blood vessel at hip and thigh level, unspecified leg, sequela*/
,'S75991D'  /*Other specified injury of unspecified blood vessel at hip and thigh level, right leg, subsequent encounter*/
,'S75991S'  /*Other specified injury of unspecified blood vessel at hip and thigh level, right leg, sequela*/
,'S75992D'  /*Other specified injury of unspecified blood vessel at hip and thigh level, left leg, subsequent encounter*/
,'S75992S'  /*Other specified injury of unspecified blood vessel at hip and thigh level, left leg, sequela*/
,'S75999D'  /*Other specified injury of unspecified blood vessel at hip and thigh level, unspecified leg, subsequent encounter*/
,'S75999S'  /*Other specified injury of unspecified blood vessel at hip and thigh level, unspecified leg, sequela*/
,'S76001D'  /*Unspecified injury of muscle, fascia and tendon of right hip, subsequent encounter*/
,'S76001S'  /*Unspecified injury of muscle, fascia and tendon of right hip, sequela*/
,'S76002D'  /*Unspecified injury of muscle, fascia and tendon of left hip, subsequent encounter*/
,'S76002S'  /*Unspecified injury of muscle, fascia and tendon of left hip, sequela*/
,'S76009D'  /*Unspecified injury of muscle, fascia and tendon of unspecified hip, subsequent encounter*/
,'S76009S'  /*Unspecified injury of muscle, fascia and tendon of unspecified hip, sequela*/
,'S76011D'  /*Strain of muscle, fascia and tendon of right hip, subsequent encounter*/
,'S76011S'  /*Strain of muscle, fascia and tendon of right hip, sequela*/
,'S76012D'  /*Strain of muscle, fascia and tendon of left hip, subsequent encounter*/
,'S76012S'  /*Strain of muscle, fascia and tendon of left hip, sequela*/
,'S76019D'  /*Strain of muscle, fascia and tendon of unspecified hip, subsequent encounter*/
,'S76019S'  /*Strain of muscle, fascia and tendon of unspecified hip, sequela*/
,'S76021D'  /*Laceration of muscle, fascia and tendon of right hip, subsequent encounter*/
,'S76021S'  /*Laceration of muscle, fascia and tendon of right hip, sequela*/
,'S76022D'  /*Laceration of muscle, fascia and tendon of left hip, subsequent encounter*/
,'S76022S'  /*Laceration of muscle, fascia and tendon of left hip, sequela*/
,'S76029D'  /*Laceration of muscle, fascia and tendon of unspecified hip, subsequent encounter*/
,'S76029S'  /*Laceration of muscle, fascia and tendon of unspecified hip, sequela*/
,'S76091D'  /*Other specified injury of muscle, fascia and tendon of right hip, subsequent encounter*/
,'S76091S'  /*Other specified injury of muscle, fascia and tendon of right hip, sequela*/
,'S76092D'  /*Other specified injury of muscle, fascia and tendon of left hip, subsequent encounter*/
,'S76092S'  /*Other specified injury of muscle, fascia and tendon of left hip, sequela*/
,'S76099D'  /*Other specified injury of muscle, fascia and tendon of unspecified hip, subsequent encounter*/
,'S76099S'  /*Other specified injury of muscle, fascia and tendon of unspecified hip, sequela*/
,'S76101D'  /*Unspecified injury of right quadriceps muscle, fascia and tendon, subsequent encounter*/
,'S76101S'  /*Unspecified injury of right quadriceps muscle, fascia and tendon, sequela*/
,'S76102D'  /*Unspecified injury of left quadriceps muscle, fascia and tendon, subsequent encounter*/
,'S76102S'  /*Unspecified injury of left quadriceps muscle, fascia and tendon, sequela*/
,'S76109D'  /*Unspecified injury of unspecified quadriceps muscle, fascia and tendon, subsequent encounter*/
,'S76109S'  /*Unspecified injury of unspecified quadriceps muscle, fascia and tendon, sequela*/
,'S76111D'  /*Strain of right quadriceps muscle, fascia and tendon, subsequent encounter*/
,'S76111S'  /*Strain of right quadriceps muscle, fascia and tendon, sequela*/
,'S76112D'  /*Strain of left quadriceps muscle, fascia and tendon, subsequent encounter*/
,'S76112S'  /*Strain of left quadriceps muscle, fascia and tendon, sequela*/
,'S76119D'  /*Strain of unspecified quadriceps muscle, fascia and tendon, subsequent encounter*/
,'S76119S'  /*Strain of unspecified quadriceps muscle, fascia and tendon, sequela*/
,'S76121D'  /*Laceration of right quadriceps muscle, fascia and tendon, subsequent encounter*/
,'S76121S'  /*Laceration of right quadriceps muscle, fascia and tendon, sequela*/
,'S76122D'  /*Laceration of left quadriceps muscle, fascia and tendon, subsequent encounter*/
,'S76122S'  /*Laceration of left quadriceps muscle, fascia and tendon, sequela*/
,'S76129D'  /*Laceration of unspecified quadriceps muscle, fascia and tendon, subsequent encounter*/
,'S76129S'  /*Laceration of unspecified quadriceps muscle, fascia and tendon, sequela*/
,'S76191D'  /*Other specified injury of right quadriceps muscle, fascia and tendon, subsequent encounter*/
,'S76191S'  /*Other specified injury of right quadriceps muscle, fascia and tendon, sequela*/
,'S76192D'  /*Other specified injury of left quadriceps muscle, fascia and tendon, subsequent encounter*/
,'S76192S'  /*Other specified injury of left quadriceps muscle, fascia and tendon, sequela*/
,'S76199D'  /*Other specified injury of unspecified quadriceps muscle, fascia and tendon, subsequent encounter*/
,'S76199S'  /*Other specified injury of unspecified quadriceps muscle, fascia and tendon, sequela*/
,'S76201D'  /*Unspecified injury of adductor muscle, fascia and tendon of right thigh, subsequent encounter*/
,'S76201S'  /*Unspecified injury of adductor muscle, fascia and tendon of right thigh, sequela*/
,'S76202D'  /*Unspecified injury of adductor muscle, fascia and tendon of left thigh, subsequent encounter*/
,'S76202S'  /*Unspecified injury of adductor muscle, fascia and tendon of left thigh, sequela*/
,'S76209D'  /*Unspecified injury of adductor muscle, fascia and tendon of unspecified thigh, subsequent encounter*/
,'S76209S'  /*Unspecified injury of adductor muscle, fascia and tendon of unspecified thigh, sequela*/
,'S76211D'  /*Strain of adductor muscle, fascia and tendon of right thigh, subsequent encounter*/
,'S76211S'  /*Strain of adductor muscle, fascia and tendon of right thigh, sequela*/
,'S76212D'  /*Strain of adductor muscle, fascia and tendon of left thigh, subsequent encounter*/
,'S76212S'  /*Strain of adductor muscle, fascia and tendon of left thigh, sequela*/
,'S76219D'  /*Strain of adductor muscle, fascia and tendon of unspecified thigh, subsequent encounter*/
,'S76219S'  /*Strain of adductor muscle, fascia and tendon of unspecified thigh, sequela*/
,'S76221D'  /*Laceration of adductor muscle, fascia and tendon of right thigh, subsequent encounter*/
,'S76221S'  /*Laceration of adductor muscle, fascia and tendon of right thigh, sequela*/
,'S76222D'  /*Laceration of adductor muscle, fascia and tendon of left thigh, subsequent encounter*/
,'S76222S'  /*Laceration of adductor muscle, fascia and tendon of left thigh, sequela*/
,'S76229D'  /*Laceration of adductor muscle, fascia and tendon of unspecified thigh, subsequent encounter*/
,'S76229S'  /*Laceration of adductor muscle, fascia and tendon of unspecified thigh, sequela*/
,'S76291D'  /*Other injury of adductor muscle, fascia and tendon of right thigh, subsequent encounter*/
,'S76291S'  /*Other injury of adductor muscle, fascia and tendon of right thigh, sequela*/
,'S76292D'  /*Other injury of adductor muscle, fascia and tendon of left thigh, subsequent encounter*/
,'S76292S'  /*Other injury of adductor muscle, fascia and tendon of left thigh, sequela*/
,'S76299D'  /*Other injury of adductor muscle, fascia and tendon of unspecified thigh, subsequent encounter*/
,'S76299S'  /*Other injury of adductor muscle, fascia and tendon of unspecified thigh, sequela*/
,'S76301D'  /*Unspecified injury of muscle, fascia and tendon of the posterior muscle group at thigh level, right thigh, subsequent encounter*/
,'S76301S'  /*Unspecified injury of muscle, fascia and tendon of the posterior muscle group at thigh level, right thigh, sequela*/
,'S76302D'  /*Unspecified injury of muscle, fascia and tendon of the posterior muscle group at thigh level, left thigh, subsequent encounter*/
,'S76302S'  /*Unspecified injury of muscle, fascia and tendon of the posterior muscle group at thigh level, left thigh, sequela*/
,'S76309D'  /*Unspecified injury of muscle, fascia and tendon of the posterior muscle group at thigh level, unspecified thigh, subsequent encounter*/
,'S76309S'  /*Unspecified injury of muscle, fascia and tendon of the posterior muscle group at thigh level, unspecified thigh, sequela*/
,'S76311D'  /*Strain of muscle, fascia and tendon of the posterior muscle group at thigh level, right thigh, subsequent encounter*/
,'S76311S'  /*Strain of muscle, fascia and tendon of the posterior muscle group at thigh level, right thigh, sequela*/
,'S76312D'  /*Strain of muscle, fascia and tendon of the posterior muscle group at thigh level, left thigh, subsequent encounter*/
,'S76312S'  /*Strain of muscle, fascia and tendon of the posterior muscle group at thigh level, left thigh, sequela*/
,'S76319D'  /*Strain of muscle, fascia and tendon of the posterior muscle group at thigh level, unspecified thigh, subsequent encounter*/
,'S76319S'  /*Strain of muscle, fascia and tendon of the posterior muscle group at thigh level, unspecified thigh, sequela*/
,'S76321D'  /*Laceration of muscle, fascia and tendon of the posterior muscle group at thigh level, right thigh, subsequent encounter*/
,'S76321S'  /*Laceration of muscle, fascia and tendon of the posterior muscle group at thigh level, right thigh, sequela*/
,'S76322D'  /*Laceration of muscle, fascia and tendon of the posterior muscle group at thigh level, left thigh, subsequent encounter*/
,'S76322S'  /*Laceration of muscle, fascia and tendon of the posterior muscle group at thigh level, left thigh, sequela*/
,'S76329D'  /*Laceration of muscle, fascia and tendon of the posterior muscle group at thigh level, unspecified thigh, subsequent encounter*/
,'S76329S'  /*Laceration of muscle, fascia and tendon of the posterior muscle group at thigh level, unspecified thigh, sequela*/
,'S76391D'  /*Other specified injury of muscle, fascia and tendon of the posterior muscle group at thigh level, right thigh, subsequent encounter*/
,'S76391S'  /*Other specified injury of muscle, fascia and tendon of the posterior muscle group at thigh level, right thigh, sequela*/
,'S76392D'  /*Other specified injury of muscle, fascia and tendon of the posterior muscle group at thigh level, left thigh, subsequent encounter*/
,'S76392S'  /*Other specified injury of muscle, fascia and tendon of the posterior muscle group at thigh level, left thigh, sequela*/
,'S76399D'  /*Other specified injury of muscle, fascia and tendon of the posterior muscle group at thigh level, unspecified thigh, subsequent encounter*/
,'S76399S'  /*Other specified injury of muscle, fascia and tendon of the posterior muscle group at thigh level, unspecified thigh, sequela*/
,'S76801D'  /*Unspecified injury of other specified muscles, fascia and tendons at thigh level, right thigh, subsequent encounter*/
,'S76801S'  /*Unspecified injury of other specified muscles, fascia and tendons at thigh level, right thigh, sequela*/
,'S76802D'  /*Unspecified injury of other specified muscles, fascia and tendons at thigh level, left thigh, subsequent encounter*/
,'S76802S'  /*Unspecified injury of other specified muscles, fascia and tendons at thigh level, left thigh, sequela*/
,'S76809D'  /*Unspecified injury of other specified muscles, fascia and tendons at thigh level, unspecified thigh, subsequent encounter*/
,'S76809S'  /*Unspecified injury of other specified muscles, fascia and tendons at thigh level, unspecified thigh, sequela*/
,'S76811D'  /*Strain of other specified muscles, fascia and tendons at thigh level, right thigh, subsequent encounter*/
,'S76811S'  /*Strain of other specified muscles, fascia and tendons at thigh level, right thigh, sequela*/
,'S76812D'  /*Strain of other specified muscles, fascia and tendons at thigh level, left thigh, subsequent encounter*/
,'S76812S'  /*Strain of other specified muscles, fascia and tendons at thigh level, left thigh, sequela*/
,'S76819D'  /*Strain of other specified muscles, fascia and tendons at thigh level, unspecified thigh, subsequent encounter*/
,'S76819S'  /*Strain of other specified muscles, fascia and tendons at thigh level, unspecified thigh, sequela*/
,'S76821D'  /*Laceration of other specified muscles, fascia and tendons at thigh level, right thigh, subsequent encounter*/
,'S76821S'  /*Laceration of other specified muscles, fascia and tendons at thigh level, right thigh, sequela*/
,'S76822D'  /*Laceration of other specified muscles, fascia and tendons at thigh level, left thigh, subsequent encounter*/
,'S76822S'  /*Laceration of other specified muscles, fascia and tendons at thigh level, left thigh, sequela*/
,'S76829D'  /*Laceration of other specified muscles, fascia and tendons at thigh level, unspecified thigh, subsequent encounter*/
,'S76829S'  /*Laceration of other specified muscles, fascia and tendons at thigh level, unspecified thigh, sequela*/
,'S76891D'  /*Other injury of other specified muscles, fascia and tendons at thigh level, right thigh, subsequent encounter*/
,'S76891S'  /*Other injury of other specified muscles, fascia and tendons at thigh level, right thigh, sequela*/
,'S76892D'  /*Other injury of other specified muscles, fascia and tendons at thigh level, left thigh, subsequent encounter*/
,'S76892S'  /*Other injury of other specified muscles, fascia and tendons at thigh level, left thigh, sequela*/
,'S76899D'  /*Other injury of other specified muscles, fascia and tendons at thigh level, unspecified thigh, subsequent encounter*/
,'S76899S'  /*Other injury of other specified muscles, fascia and tendons at thigh level, unspecified thigh, sequela*/
,'S76901D'  /*Unspecified injury of unspecified muscles, fascia and tendons at thigh level, right thigh, subsequent encounter*/
,'S76901S'  /*Unspecified injury of unspecified muscles, fascia and tendons at thigh level, right thigh, sequela*/
,'S76902D'  /*Unspecified injury of unspecified muscles, fascia and tendons at thigh level, left thigh, subsequent encounter*/
,'S76902S'  /*Unspecified injury of unspecified muscles, fascia and tendons at thigh level, left thigh, sequela*/
,'S76909D'  /*Unspecified injury of unspecified muscles, fascia and tendons at thigh level, unspecified thigh, subsequent encounter*/
,'S76909S'  /*Unspecified injury of unspecified muscles, fascia and tendons at thigh level, unspecified thigh, sequela*/
,'S76911D'  /*Strain of unspecified muscles, fascia and tendons at thigh level, right thigh, subsequent encounter*/
,'S76911S'  /*Strain of unspecified muscles, fascia and tendons at thigh level, right thigh, sequela*/
,'S76912D'  /*Strain of unspecified muscles, fascia and tendons at thigh level, left thigh, subsequent encounter*/
,'S76912S'  /*Strain of unspecified muscles, fascia and tendons at thigh level, left thigh, sequela*/
,'S76919D'  /*Strain of unspecified muscles, fascia and tendons at thigh level, unspecified thigh, subsequent encounter*/
,'S76919S'  /*Strain of unspecified muscles, fascia and tendons at thigh level, unspecified thigh, sequela*/
,'S76921D'  /*Laceration of unspecified muscles, fascia and tendons at thigh level, right thigh, subsequent encounter*/
,'S76921S'  /*Laceration of unspecified muscles, fascia and tendons at thigh level, right thigh, sequela*/
,'S76922D'  /*Laceration of unspecified muscles, fascia and tendons at thigh level, left thigh, subsequent encounter*/
,'S76922S'  /*Laceration of unspecified muscles, fascia and tendons at thigh level, left thigh, sequela*/
,'S76929D'  /*Laceration of unspecified muscles, fascia and tendons at thigh level, unspecified thigh, subsequent encounter*/
,'S76929S'  /*Laceration of unspecified muscles, fascia and tendons at thigh level, unspecified thigh, sequela*/
,'S76991D'  /*Other specified injury of unspecified muscles, fascia and tendons at thigh level, right thigh, subsequent encounter*/
,'S76991S'  /*Other specified injury of unspecified muscles, fascia and tendons at thigh level, right thigh, sequela*/
,'S76992D'  /*Other specified injury of unspecified muscles, fascia and tendons at thigh level, left thigh, subsequent encounter*/
,'S76992S'  /*Other specified injury of unspecified muscles, fascia and tendons at thigh level, left thigh, sequela*/
,'S76999D'  /*Other specified injury of unspecified muscles, fascia and tendons at thigh level, unspecified thigh, subsequent encounter*/
,'S76999S'  /*Other specified injury of unspecified muscles, fascia and tendons at thigh level, unspecified thigh, sequela*/
,'S7700XD'  /*Crushing injury of unspecified hip, subsequent encounter*/
,'S7700XS'  /*Crushing injury of unspecified hip, sequela*/
,'S7701XD'  /*Crushing injury of right hip, subsequent encounter*/
,'S7701XS'  /*Crushing injury of right hip, sequela*/
,'S7702XD'  /*Crushing injury of left hip, subsequent encounter*/
,'S7702XS'  /*Crushing injury of left hip, sequela*/
,'S7710XD'  /*Crushing injury of unspecified thigh, subsequent encounter*/
,'S7710XS'  /*Crushing injury of unspecified thigh, sequela*/
,'S7711XD'  /*Crushing injury of right thigh, subsequent encounter*/
,'S7711XS'  /*Crushing injury of right thigh, sequela*/
,'S7712XD'  /*Crushing injury of left thigh, subsequent encounter*/
,'S7712XS'  /*Crushing injury of left thigh, sequela*/
,'S7720XD'  /*Crushing injury of unspecified hip with thigh, subsequent encounter*/
,'S7720XS'  /*Crushing injury of unspecified hip with thigh, sequela*/
,'S7721XD'  /*Crushing injury of right hip with thigh, subsequent encounter*/
,'S7721XS'  /*Crushing injury of right hip with thigh, sequela*/
,'S7722XD'  /*Crushing injury of left hip with thigh, subsequent encounter*/
,'S7722XS'  /*Crushing injury of left hip with thigh, sequela*/
,'S78011D'  /*Complete traumatic amputation at right hip joint, subsequent encounter*/
,'S78011S'  /*Complete traumatic amputation at right hip joint, sequela*/
,'S78012D'  /*Complete traumatic amputation at left hip joint, subsequent encounter*/
,'S78012S'  /*Complete traumatic amputation at left hip joint, sequela*/
,'S78019D'  /*Complete traumatic amputation at unspecified hip joint, subsequent encounter*/
,'S78019S'  /*Complete traumatic amputation at unspecified hip joint, sequela*/
,'S78021D'  /*Partial traumatic amputation at right hip joint, subsequent encounter*/
,'S78021S'  /*Partial traumatic amputation at right hip joint, sequela*/
,'S78022D'  /*Partial traumatic amputation at left hip joint, subsequent encounter*/
,'S78022S'  /*Partial traumatic amputation at left hip joint, sequela*/
,'S78029D'  /*Partial traumatic amputation at unspecified hip joint, subsequent encounter*/
,'S78029S'  /*Partial traumatic amputation at unspecified hip joint, sequela*/
,'S78111D'  /*Complete traumatic amputation at level between right hip and knee, subsequent encounter*/
,'S78111S'  /*Complete traumatic amputation at level between right hip and knee, sequela*/
,'S78112D'  /*Complete traumatic amputation at level between left hip and knee, subsequent encounter*/
,'S78112S'  /*Complete traumatic amputation at level between left hip and knee, sequela*/
,'S78119D'  /*Complete traumatic amputation at level between unspecified hip and knee, subsequent encounter*/
,'S78119S'  /*Complete traumatic amputation at level between unspecified hip and knee, sequela*/
,'S78121D'  /*Partial traumatic amputation at level between right hip and knee, subsequent encounter*/
,'S78121S'  /*Partial traumatic amputation at level between right hip and knee, sequela*/
,'S78122D'  /*Partial traumatic amputation at level between left hip and knee, subsequent encounter*/
,'S78122S'  /*Partial traumatic amputation at level between left hip and knee, sequela*/
,'S78129D'  /*Partial traumatic amputation at level between unspecified hip and knee, subsequent encounter*/
,'S78129S'  /*Partial traumatic amputation at level between unspecified hip and knee, sequela*/
,'S78911D'  /*Complete traumatic amputation of right hip and thigh, level unspecified, subsequent encounter*/
,'S78911S'  /*Complete traumatic amputation of right hip and thigh, level unspecified, sequela*/
,'S78912D'  /*Complete traumatic amputation of left hip and thigh, level unspecified, subsequent encounter*/
,'S78912S'  /*Complete traumatic amputation of left hip and thigh, level unspecified, sequela*/
,'S78919D'  /*Complete traumatic amputation of unspecified hip and thigh, level unspecified, subsequent encounter*/
,'S78919S'  /*Complete traumatic amputation of unspecified hip and thigh, level unspecified, sequela*/
,'S78921D'  /*Partial traumatic amputation of right hip and thigh, level unspecified, subsequent encounter*/
,'S78921S'  /*Partial traumatic amputation of right hip and thigh, level unspecified, sequela*/
,'S78922D'  /*Partial traumatic amputation of left hip and thigh, level unspecified, subsequent encounter*/
,'S78922S'  /*Partial traumatic amputation of left hip and thigh, level unspecified, sequela*/
,'S78929D'  /*Partial traumatic amputation of unspecified hip and thigh, level unspecified, subsequent encounter*/
,'S78929S'  /*Partial traumatic amputation of unspecified hip and thigh, level unspecified, sequela*/
,'S79001D'  /*Unspecified physeal fracture of upper end of right femur, subsequent encounter for fracture with routine healing*/
,'S79001G'  /*Unspecified physeal fracture of upper end of right femur, subsequent encounter for fracture with delayed healing*/
,'S79001K'  /*Unspecified physeal fracture of upper end of right femur, subsequent encounter for fracture with nonunion*/
,'S79001P'  /*Unspecified physeal fracture of upper end of right femur, subsequent encounter for fracture with malunion*/
,'S79001S'  /*Unspecified physeal fracture of upper end of right femur, sequela*/
,'S79002D'  /*Unspecified physeal fracture of upper end of left femur, subsequent encounter for fracture with routine healing*/
,'S79002G'  /*Unspecified physeal fracture of upper end of left femur, subsequent encounter for fracture with delayed healing*/
,'S79002K'  /*Unspecified physeal fracture of upper end of left femur, subsequent encounter for fracture with nonunion*/
,'S79002P'  /*Unspecified physeal fracture of upper end of left femur, subsequent encounter for fracture with malunion*/
,'S79002S'  /*Unspecified physeal fracture of upper end of left femur, sequela*/
,'S79009D'  /*Unspecified physeal fracture of upper end of unspecified femur, subsequent encounter for fracture with routine healing*/
,'S79009G'  /*Unspecified physeal fracture of upper end of unspecified femur, subsequent encounter for fracture with delayed healing*/
,'S79009K'  /*Unspecified physeal fracture of upper end of unspecified femur, subsequent encounter for fracture with nonunion*/
,'S79009P'  /*Unspecified physeal fracture of upper end of unspecified femur, subsequent encounter for fracture with malunion*/
,'S79009S'  /*Unspecified physeal fracture of upper end of unspecified femur, sequela*/
,'S79011D'  /*Salter-Harris Type I physeal fracture of upper end of right femur, subsequent encounter for fracture with routine healing*/
,'S79011G'  /*Salter-Harris Type I physeal fracture of upper end of right femur, subsequent encounter for fracture with delayed healing*/
,'S79011K'  /*Salter-Harris Type I physeal fracture of upper end of right femur, subsequent encounter for fracture with nonunion*/
,'S79011P'  /*Salter-Harris Type I physeal fracture of upper end of right femur, subsequent encounter for fracture with malunion*/
,'S79011S'  /*Salter-Harris Type I physeal fracture of upper end of right femur, sequela*/
,'S79012D'  /*Salter-Harris Type I physeal fracture of upper end of left femur, subsequent encounter for fracture with routine healing*/
,'S79012G'  /*Salter-Harris Type I physeal fracture of upper end of left femur, subsequent encounter for fracture with delayed healing*/
,'S79012K'  /*Salter-Harris Type I physeal fracture of upper end of left femur, subsequent encounter for fracture with nonunion*/
,'S79012P'  /*Salter-Harris Type I physeal fracture of upper end of left femur, subsequent encounter for fracture with malunion*/
,'S79012S'  /*Salter-Harris Type I physeal fracture of upper end of left femur, sequela*/
,'S79019D'  /*Salter-Harris Type I physeal fracture of upper end of unspecified femur, subsequent encounter for fracture with routine healing*/
,'S79019G'  /*Salter-Harris Type I physeal fracture of upper end of unspecified femur, subsequent encounter for fracture with delayed healing*/
,'S79019K'  /*Salter-Harris Type I physeal fracture of upper end of unspecified femur, subsequent encounter for fracture with nonunion*/
,'S79019P'  /*Salter-Harris Type I physeal fracture of upper end of unspecified femur, subsequent encounter for fracture with malunion*/
,'S79019S'  /*Salter-Harris Type I physeal fracture of upper end of unspecified femur, sequela*/
,'S79091D'  /*Other physeal fracture of upper end of right femur, subsequent encounter for fracture with routine healing*/
,'S79091G'  /*Other physeal fracture of upper end of right femur, subsequent encounter for fracture with delayed healing*/
,'S79091K'  /*Other physeal fracture of upper end of right femur, subsequent encounter for fracture with nonunion*/
,'S79091P'  /*Other physeal fracture of upper end of right femur, subsequent encounter for fracture with malunion*/
,'S79091S'  /*Other physeal fracture of upper end of right femur, sequela*/
,'S79092D'  /*Other physeal fracture of upper end of left femur, subsequent encounter for fracture with routine healing*/
,'S79092G'  /*Other physeal fracture of upper end of left femur, subsequent encounter for fracture with delayed healing*/
,'S79092K'  /*Other physeal fracture of upper end of left femur, subsequent encounter for fracture with nonunion*/
,'S79092P'  /*Other physeal fracture of upper end of left femur, subsequent encounter for fracture with malunion*/
,'S79092S'  /*Other physeal fracture of upper end of left femur, sequela*/
,'S79099D'  /*Other physeal fracture of upper end of unspecified femur, subsequent encounter for fracture with routine healing*/
,'S79099G'  /*Other physeal fracture of upper end of unspecified femur, subsequent encounter for fracture with delayed healing*/
,'S79099K'  /*Other physeal fracture of upper end of unspecified femur, subsequent encounter for fracture with nonunion*/
,'S79099P'  /*Other physeal fracture of upper end of unspecified femur, subsequent encounter for fracture with malunion*/
,'S79099S'  /*Other physeal fracture of upper end of unspecified femur, sequela*/
,'S79101D'  /*Unspecified physeal fracture of lower end of right femur, subsequent encounter for fracture with routine healing*/
,'S79101G'  /*Unspecified physeal fracture of lower end of right femur, subsequent encounter for fracture with delayed healing*/
,'S79101K'  /*Unspecified physeal fracture of lower end of right femur, subsequent encounter for fracture with nonunion*/
,'S79101P'  /*Unspecified physeal fracture of lower end of right femur, subsequent encounter for fracture with malunion*/
,'S79101S'  /*Unspecified physeal fracture of lower end of right femur, sequela*/
,'S79102D'  /*Unspecified physeal fracture of lower end of left femur, subsequent encounter for fracture with routine healing*/
,'S79102G'  /*Unspecified physeal fracture of lower end of left femur, subsequent encounter for fracture with delayed healing*/
,'S79102K'  /*Unspecified physeal fracture of lower end of left femur, subsequent encounter for fracture with nonunion*/
,'S79102P'  /*Unspecified physeal fracture of lower end of left femur, subsequent encounter for fracture with malunion*/
,'S79102S'  /*Unspecified physeal fracture of lower end of left femur, sequela*/
,'S79109D'  /*Unspecified physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with routine healing*/
,'S79109G'  /*Unspecified physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with delayed healing*/
,'S79109K'  /*Unspecified physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with nonunion*/
,'S79109P'  /*Unspecified physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with malunion*/
,'S79109S'  /*Unspecified physeal fracture of lower end of unspecified femur, sequela*/
,'S79111D'  /*Salter-Harris Type I physeal fracture of lower end of right femur, subsequent encounter for fracture with routine healing*/
,'S79111G'  /*Salter-Harris Type I physeal fracture of lower end of right femur, subsequent encounter for fracture with delayed healing*/
,'S79111K'  /*Salter-Harris Type I physeal fracture of lower end of right femur, subsequent encounter for fracture with nonunion*/
,'S79111P'  /*Salter-Harris Type I physeal fracture of lower end of right femur, subsequent encounter for fracture with malunion*/
,'S79111S'  /*Salter-Harris Type I physeal fracture of lower end of right femur, sequela*/
,'S79112D'  /*Salter-Harris Type I physeal fracture of lower end of left femur, subsequent encounter for fracture with routine healing*/
,'S79112G'  /*Salter-Harris Type I physeal fracture of lower end of left femur, subsequent encounter for fracture with delayed healing*/
,'S79112K'  /*Salter-Harris Type I physeal fracture of lower end of left femur, subsequent encounter for fracture with nonunion*/
,'S79112P'  /*Salter-Harris Type I physeal fracture of lower end of left femur, subsequent encounter for fracture with malunion*/
,'S79112S'  /*Salter-Harris Type I physeal fracture of lower end of left femur, sequela*/
,'S79119D'  /*Salter-Harris Type I physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with routine healing*/
,'S79119G'  /*Salter-Harris Type I physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with delayed healing*/
,'S79119K'  /*Salter-Harris Type I physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with nonunion*/
,'S79119P'  /*Salter-Harris Type I physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with malunion*/
,'S79119S'  /*Salter-Harris Type I physeal fracture of lower end of unspecified femur, sequela*/
,'S79121D'  /*Salter-Harris Type II physeal fracture of lower end of right femur, subsequent encounter for fracture with routine healing*/
,'S79121G'  /*Salter-Harris Type II physeal fracture of lower end of right femur, subsequent encounter for fracture with delayed healing*/
,'S79121K'  /*Salter-Harris Type II physeal fracture of lower end of right femur, subsequent encounter for fracture with nonunion*/
,'S79121P'  /*Salter-Harris Type II physeal fracture of lower end of right femur, subsequent encounter for fracture with malunion*/
,'S79121S'  /*Salter-Harris Type II physeal fracture of lower end of right femur, sequela*/
,'S79122D'  /*Salter-Harris Type II physeal fracture of lower end of left femur, subsequent encounter for fracture with routine healing*/
,'S79122G'  /*Salter-Harris Type II physeal fracture of lower end of left femur, subsequent encounter for fracture with delayed healing*/
,'S79122K'  /*Salter-Harris Type II physeal fracture of lower end of left femur, subsequent encounter for fracture with nonunion*/
,'S79122P'  /*Salter-Harris Type II physeal fracture of lower end of left femur, subsequent encounter for fracture with malunion*/
,'S79122S'  /*Salter-Harris Type II physeal fracture of lower end of left femur, sequela*/
,'S79129D'  /*Salter-Harris Type II physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with routine healing*/
,'S79129G'  /*Salter-Harris Type II physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with delayed healing*/
,'S79129K'  /*Salter-Harris Type II physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with nonunion*/
,'S79129P'  /*Salter-Harris Type II physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with malunion*/
,'S79129S'  /*Salter-Harris Type II physeal fracture of lower end of unspecified femur, sequela*/
,'S79131D'  /*Salter-Harris Type III physeal fracture of lower end of right femur, subsequent encounter for fracture with routine healing*/
,'S79131G'  /*Salter-Harris Type III physeal fracture of lower end of right femur, subsequent encounter for fracture with delayed healing*/
,'S79131K'  /*Salter-Harris Type III physeal fracture of lower end of right femur, subsequent encounter for fracture with nonunion*/
,'S79131P'  /*Salter-Harris Type III physeal fracture of lower end of right femur, subsequent encounter for fracture with malunion*/
,'S79131S'  /*Salter-Harris Type III physeal fracture of lower end of right femur, sequela*/
,'S79132D'  /*Salter-Harris Type III physeal fracture of lower end of left femur, subsequent encounter for fracture with routine healing*/
,'S79132G'  /*Salter-Harris Type III physeal fracture of lower end of left femur, subsequent encounter for fracture with delayed healing*/
,'S79132K'  /*Salter-Harris Type III physeal fracture of lower end of left femur, subsequent encounter for fracture with nonunion*/
,'S79132P'  /*Salter-Harris Type III physeal fracture of lower end of left femur, subsequent encounter for fracture with malunion*/
,'S79132S'  /*Salter-Harris Type III physeal fracture of lower end of left femur, sequela*/
,'S79139D'  /*Salter-Harris Type III physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with routine healing*/
,'S79139G'  /*Salter-Harris Type III physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with delayed healing*/
,'S79139K'  /*Salter-Harris Type III physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with nonunion*/
,'S79139P'  /*Salter-Harris Type III physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with malunion*/
,'S79139S'  /*Salter-Harris Type III physeal fracture of lower end of unspecified femur, sequela*/
,'S79141D'  /*Salter-Harris Type IV physeal fracture of lower end of right femur, subsequent encounter for fracture with routine healing*/
,'S79141G'  /*Salter-Harris Type IV physeal fracture of lower end of right femur, subsequent encounter for fracture with delayed healing*/
,'S79141K'  /*Salter-Harris Type IV physeal fracture of lower end of right femur, subsequent encounter for fracture with nonunion*/
,'S79141P'  /*Salter-Harris Type IV physeal fracture of lower end of right femur, subsequent encounter for fracture with malunion*/
,'S79141S'  /*Salter-Harris Type IV physeal fracture of lower end of right femur, sequela*/
,'S79142D'  /*Salter-Harris Type IV physeal fracture of lower end of left femur, subsequent encounter for fracture with routine healing*/
,'S79142G'  /*Salter-Harris Type IV physeal fracture of lower end of left femur, subsequent encounter for fracture with delayed healing*/
,'S79142K'  /*Salter-Harris Type IV physeal fracture of lower end of left femur, subsequent encounter for fracture with nonunion*/
,'S79142P'  /*Salter-Harris Type IV physeal fracture of lower end of left femur, subsequent encounter for fracture with malunion*/
,'S79142S'  /*Salter-Harris Type IV physeal fracture of lower end of left femur, sequela*/
,'S79149D'  /*Salter-Harris Type IV physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with routine healing*/
,'S79149G'  /*Salter-Harris Type IV physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with delayed healing*/
,'S79149K'  /*Salter-Harris Type IV physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with nonunion*/
,'S79149P'  /*Salter-Harris Type IV physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with malunion*/
,'S79149S'  /*Salter-Harris Type IV physeal fracture of lower end of unspecified femur, sequela*/
,'S79191D'  /*Other physeal fracture of lower end of right femur, subsequent encounter for fracture with routine healing*/
,'S79191G'  /*Other physeal fracture of lower end of right femur, subsequent encounter for fracture with delayed healing*/
,'S79191K'  /*Other physeal fracture of lower end of right femur, subsequent encounter for fracture with nonunion*/
,'S79191P'  /*Other physeal fracture of lower end of right femur, subsequent encounter for fracture with malunion*/
,'S79191S'  /*Other physeal fracture of lower end of right femur, sequela*/
,'S79192D'  /*Other physeal fracture of lower end of left femur, subsequent encounter for fracture with routine healing*/
,'S79192G'  /*Other physeal fracture of lower end of left femur, subsequent encounter for fracture with delayed healing*/
,'S79192K'  /*Other physeal fracture of lower end of left femur, subsequent encounter for fracture with nonunion*/
,'S79192P'  /*Other physeal fracture of lower end of left femur, subsequent encounter for fracture with malunion*/
,'S79192S'  /*Other physeal fracture of lower end of left femur, sequela*/
,'S79199D'  /*Other physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with routine healing*/
,'S79199G'  /*Other physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with delayed healing*/
,'S79199K'  /*Other physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with nonunion*/
,'S79199P'  /*Other physeal fracture of lower end of unspecified femur, subsequent encounter for fracture with malunion*/
,'S79199S'  /*Other physeal fracture of lower end of unspecified femur, sequela*/
,'S79811D'  /*Other specified injuries of right hip, subsequent encounter*/
,'S79811S'  /*Other specified injuries of right hip, sequela*/
,'S79812D'  /*Other specified injuries of left hip, subsequent encounter*/
,'S79812S'  /*Other specified injuries of left hip, sequela*/
,'S79819D'  /*Other specified injuries of unspecified hip, subsequent encounter*/
,'S79819S'  /*Other specified injuries of unspecified hip, sequela*/
,'S79821D'  /*Other specified injuries of right thigh, subsequent encounter*/
,'S79821S'  /*Other specified injuries of right thigh, sequela*/
,'S79822D'  /*Other specified injuries of left thigh, subsequent encounter*/
,'S79822S'  /*Other specified injuries of left thigh, sequela*/
,'S79829D'  /*Other specified injuries of unspecified thigh, subsequent encounter*/
,'S79829S'  /*Other specified injuries of unspecified thigh, sequela*/
,'S79911D'  /*Unspecified injury of right hip, subsequent encounter*/
,'S79911S'  /*Unspecified injury of right hip, sequela*/
,'S79912D'  /*Unspecified injury of left hip, subsequent encounter*/
,'S79912S'  /*Unspecified injury of left hip, sequela*/
,'S79919D'  /*Unspecified injury of unspecified hip, subsequent encounter*/
,'S79919S'  /*Unspecified injury of unspecified hip, sequela*/
,'S79921D'  /*Unspecified injury of right thigh, subsequent encounter*/
,'S79921S'  /*Unspecified injury of right thigh, sequela*/
,'S79922D'  /*Unspecified injury of left thigh, subsequent encounter*/
,'S79922S'  /*Unspecified injury of left thigh, sequela*/
,'S79929D'  /*Unspecified injury of unspecified thigh, subsequent encounter*/
,'S79929S'  /*Unspecified injury of unspecified thigh, sequela*/
,'S8000XD'  /*Contusion of unspecified knee, subsequent encounter*/
,'S8000XS'  /*Contusion of unspecified knee, sequela*/
,'S8001XD'  /*Contusion of right knee, subsequent encounter*/
,'S8001XS'  /*Contusion of right knee, sequela*/
,'S8002XD'  /*Contusion of left knee, subsequent encounter*/
,'S8002XS'  /*Contusion of left knee, sequela*/
,'S8010XD'  /*Contusion of unspecified lower leg, subsequent encounter*/
,'S8010XS'  /*Contusion of unspecified lower leg, sequela*/
,'S8011XD'  /*Contusion of right lower leg, subsequent encounter*/
,'S8011XS'  /*Contusion of right lower leg, sequela*/
,'S8012XD'  /*Contusion of left lower leg, subsequent encounter*/
,'S8012XS'  /*Contusion of left lower leg, sequela*/
,'S80211D'  /*Abrasion, right knee, subsequent encounter*/
,'S80211S'  /*Abrasion, right knee, sequela*/
,'S80212D'  /*Abrasion, left knee, subsequent encounter*/
,'S80212S'  /*Abrasion, left knee, sequela*/
,'S80219D'  /*Abrasion, unspecified knee, subsequent encounter*/
,'S80219S'  /*Abrasion, unspecified knee, sequela*/
,'S80221D'  /*Blister (nonthermal), right knee, subsequent encounter*/
,'S80221S'  /*Blister (nonthermal), right knee, sequela*/
,'S80222D'  /*Blister (nonthermal), left knee, subsequent encounter*/
,'S80222S'  /*Blister (nonthermal), left knee, sequela*/
,'S80229D'  /*Blister (nonthermal), unspecified knee, subsequent encounter*/
,'S80229S'  /*Blister (nonthermal), unspecified knee, sequela*/
,'S80241D'  /*External constriction, right knee, subsequent encounter*/
,'S80241S'  /*External constriction, right knee, sequela*/
,'S80242D'  /*External constriction, left knee, subsequent encounter*/
,'S80242S'  /*External constriction, left knee, sequela*/
,'S80249D'  /*External constriction, unspecified knee, subsequent encounter*/
,'S80249S'  /*External constriction, unspecified knee, sequela*/
,'S80251D'  /*Superficial foreign body, right knee, subsequent encounter*/
,'S80251S'  /*Superficial foreign body, right knee, sequela*/
,'S80252D'  /*Superficial foreign body, left knee, subsequent encounter*/
,'S80252S'  /*Superficial foreign body, left knee, sequela*/
,'S80259D'  /*Superficial foreign body, unspecified knee, subsequent encounter*/
,'S80259S'  /*Superficial foreign body, unspecified knee, sequela*/
,'S80261D'  /*Insect bite (nonvenomous), right knee, subsequent encounter*/
,'S80261S'  /*Insect bite (nonvenomous), right knee, sequela*/
,'S80262D'  /*Insect bite (nonvenomous), left knee, subsequent encounter*/
,'S80262S'  /*Insect bite (nonvenomous), left knee, sequela*/
,'S80269D'  /*Insect bite (nonvenomous), unspecified knee, subsequent encounter*/
,'S80269S'  /*Insect bite (nonvenomous), unspecified knee, sequela*/
,'S80271D'  /*Other superficial bite of right knee, subsequent encounter*/
,'S80271S'  /*Other superficial bite of right knee, sequela*/
,'S80272D'  /*Other superficial bite of left knee, subsequent encounter*/
,'S80272S'  /*Other superficial bite of left knee, sequela*/
,'S80279D'  /*Other superficial bite of unspecified knee, subsequent encounter*/
,'S80279S'  /*Other superficial bite of unspecified knee, sequela*/
,'S80811D'  /*Abrasion, right lower leg, subsequent encounter*/
,'S80811S'  /*Abrasion, right lower leg, sequela*/
,'S80812D'  /*Abrasion, left lower leg, subsequent encounter*/
,'S80812S'  /*Abrasion, left lower leg, sequela*/
,'S80819D'  /*Abrasion, unspecified lower leg, subsequent encounter*/
,'S80819S'  /*Abrasion, unspecified lower leg, sequela*/
,'S80821D'  /*Blister (nonthermal), right lower leg, subsequent encounter*/
,'S80821S'  /*Blister (nonthermal), right lower leg, sequela*/
,'S80822D'  /*Blister (nonthermal), left lower leg, subsequent encounter*/
,'S80822S'  /*Blister (nonthermal), left lower leg, sequela*/
,'S80829D'  /*Blister (nonthermal), unspecified lower leg, subsequent encounter*/
,'S80829S'  /*Blister (nonthermal), unspecified lower leg, sequela*/
,'S80841D'  /*External constriction, right lower leg, subsequent encounter*/
,'S80841S'  /*External constriction, right lower leg, sequela*/
,'S80842D'  /*External constriction, left lower leg, subsequent encounter*/
,'S80842S'  /*External constriction, left lower leg, sequela*/
,'S80849D'  /*External constriction, unspecified lower leg, subsequent encounter*/
,'S80849S'  /*External constriction, unspecified lower leg, sequela*/
,'S80851D'  /*Superficial foreign body, right lower leg, subsequent encounter*/
,'S80851S'  /*Superficial foreign body, right lower leg, sequela*/
,'S80852D'  /*Superficial foreign body, left lower leg, subsequent encounter*/
,'S80852S'  /*Superficial foreign body, left lower leg, sequela*/
,'S80859D'  /*Superficial foreign body, unspecified lower leg, subsequent encounter*/
,'S80859S'  /*Superficial foreign body, unspecified lower leg, sequela*/
,'S80861D'  /*Insect bite (nonvenomous), right lower leg, subsequent encounter*/
,'S80861S'  /*Insect bite (nonvenomous), right lower leg, sequela*/
,'S80862D'  /*Insect bite (nonvenomous), left lower leg, subsequent encounter*/
,'S80862S'  /*Insect bite (nonvenomous), left lower leg, sequela*/
,'S80869D'  /*Insect bite (nonvenomous), unspecified lower leg, subsequent encounter*/
,'S80869S'  /*Insect bite (nonvenomous), unspecified lower leg, sequela*/
,'S80871D'  /*Other superficial bite, right lower leg, subsequent encounter*/
,'S80871S'  /*Other superficial bite, right lower leg, sequela*/
,'S80872D'  /*Other superficial bite, left lower leg, subsequent encounter*/
,'S80872S'  /*Other superficial bite, left lower leg, sequela*/
,'S80879D'  /*Other superficial bite, unspecified lower leg, subsequent encounter*/
,'S80879S'  /*Other superficial bite, unspecified lower leg, sequela*/
,'S80911D'  /*Unspecified superficial injury of right knee, subsequent encounter*/
,'S80911S'  /*Unspecified superficial injury of right knee, sequela*/
,'S80912D'  /*Unspecified superficial injury of left knee, subsequent encounter*/
,'S80912S'  /*Unspecified superficial injury of left knee, sequela*/
,'S80919D'  /*Unspecified superficial injury of unspecified knee, subsequent encounter*/
,'S80919S'  /*Unspecified superficial injury of unspecified knee, sequela*/
,'S80921D'  /*Unspecified superficial injury of right lower leg, subsequent encounter*/
,'S80921S'  /*Unspecified superficial injury of right lower leg, sequela*/
,'S80922D'  /*Unspecified superficial injury of left lower leg, subsequent encounter*/
,'S80922S'  /*Unspecified superficial injury of left lower leg, sequela*/
,'S80929D'  /*Unspecified superficial injury of unspecified lower leg, subsequent encounter*/
,'S80929S'  /*Unspecified superficial injury of unspecified lower leg, sequela*/
,'S81001D'  /*Unspecified open wound, right knee, subsequent encounter*/
,'S81001S'  /*Unspecified open wound, right knee, sequela*/
,'S81002D'  /*Unspecified open wound, left knee, subsequent encounter*/
,'S81002S'  /*Unspecified open wound, left knee, sequela*/
,'S81009D'  /*Unspecified open wound, unspecified knee, subsequent encounter*/
,'S81009S'  /*Unspecified open wound, unspecified knee, sequela*/
,'S81011D'  /*Laceration without foreign body, right knee, subsequent encounter*/
,'S81011S'  /*Laceration without foreign body, right knee, sequela*/
,'S81012D'  /*Laceration without foreign body, left knee, subsequent encounter*/
,'S81012S'  /*Laceration without foreign body, left knee, sequela*/
,'S81019D'  /*Laceration without foreign body, unspecified knee, subsequent encounter*/
,'S81019S'  /*Laceration without foreign body, unspecified knee, sequela*/
,'S81021D'  /*Laceration with foreign body, right knee, subsequent encounter*/
,'S81021S'  /*Laceration with foreign body, right knee, sequela*/
,'S81022D'  /*Laceration with foreign body, left knee, subsequent encounter*/
,'S81022S'  /*Laceration with foreign body, left knee, sequela*/
,'S81029D'  /*Laceration with foreign body, unspecified knee, subsequent encounter*/
,'S81029S'  /*Laceration with foreign body, unspecified knee, sequela*/
,'S81031D'  /*Puncture wound without foreign body, right knee, subsequent encounter*/
,'S81031S'  /*Puncture wound without foreign body, right knee, sequela*/
,'S81032D'  /*Puncture wound without foreign body, left knee, subsequent encounter*/
,'S81032S'  /*Puncture wound without foreign body, left knee, sequela*/
,'S81039D'  /*Puncture wound without foreign body, unspecified knee, subsequent encounter*/
,'S81039S'  /*Puncture wound without foreign body, unspecified knee, sequela*/
,'S81041D'  /*Puncture wound with foreign body, right knee, subsequent encounter*/
,'S81041S'  /*Puncture wound with foreign body, right knee, sequela*/
,'S81042D'  /*Puncture wound with foreign body, left knee, subsequent encounter*/
,'S81042S'  /*Puncture wound with foreign body, left knee, sequela*/
,'S81049D'  /*Puncture wound with foreign body, unspecified knee, subsequent encounter*/
,'S81049S'  /*Puncture wound with foreign body, unspecified knee, sequela*/
,'S81051D'  /*Open bite, right knee, subsequent encounter*/
,'S81051S'  /*Open bite, right knee, sequela*/
,'S81052D'  /*Open bite, left knee, subsequent encounter*/
,'S81052S'  /*Open bite, left knee, sequela*/
,'S81059D'  /*Open bite, unspecified knee, subsequent encounter*/
,'S81059S'  /*Open bite, unspecified knee, sequela*/
,'S81801D'  /*Unspecified open wound, right lower leg, subsequent encounter*/
,'S81801S'  /*Unspecified open wound, right lower leg, sequela*/
,'S81802D'  /*Unspecified open wound, left lower leg, subsequent encounter*/
,'S81802S'  /*Unspecified open wound, left lower leg, sequela*/
,'S81809D'  /*Unspecified open wound, unspecified lower leg, subsequent encounter*/
,'S81809S'  /*Unspecified open wound, unspecified lower leg, sequela*/
,'S81811D'  /*Laceration without foreign body, right lower leg, subsequent encounter*/
,'S81811S'  /*Laceration without foreign body, right lower leg, sequela*/
,'S81812D'  /*Laceration without foreign body, left lower leg, subsequent encounter*/
,'S81812S'  /*Laceration without foreign body, left lower leg, sequela*/
,'S81819D'  /*Laceration without foreign body, unspecified lower leg, subsequent encounter*/
,'S81819S'  /*Laceration without foreign body, unspecified lower leg, sequela*/
,'S81821D'  /*Laceration with foreign body, right lower leg, subsequent encounter*/
,'S81821S'  /*Laceration with foreign body, right lower leg, sequela*/
,'S81822D'  /*Laceration with foreign body, left lower leg, subsequent encounter*/
,'S81822S'  /*Laceration with foreign body, left lower leg, sequela*/
,'S81829D'  /*Laceration with foreign body, unspecified lower leg, subsequent encounter*/
,'S81829S'  /*Laceration with foreign body, unspecified lower leg, sequela*/
,'S81831D'  /*Puncture wound without foreign body, right lower leg, subsequent encounter*/
,'S81831S'  /*Puncture wound without foreign body, right lower leg, sequela*/
,'S81832D'  /*Puncture wound without foreign body, left lower leg, subsequent encounter*/
,'S81832S'  /*Puncture wound without foreign body, left lower leg, sequela*/
,'S81839D'  /*Puncture wound without foreign body, unspecified lower leg, subsequent encounter*/
,'S81839S'  /*Puncture wound without foreign body, unspecified lower leg, sequela*/
,'S81841D'  /*Puncture wound with foreign body, right lower leg, subsequent encounter*/
,'S81841S'  /*Puncture wound with foreign body, right lower leg, sequela*/
,'S81842D'  /*Puncture wound with foreign body, left lower leg, subsequent encounter*/
,'S81842S'  /*Puncture wound with foreign body, left lower leg, sequela*/
,'S81849D'  /*Puncture wound with foreign body, unspecified lower leg, subsequent encounter*/
,'S81849S'  /*Puncture wound with foreign body, unspecified lower leg, sequela*/
,'S81851D'  /*Open bite, right lower leg, subsequent encounter*/
,'S81851S'  /*Open bite, right lower leg, sequela*/
,'S81852D'  /*Open bite, left lower leg, subsequent encounter*/
,'S81852S'  /*Open bite, left lower leg, sequela*/
,'S81859D'  /*Open bite, unspecified lower leg, subsequent encounter*/
,'S81859S'  /*Open bite, unspecified lower leg, sequela*/
,'S82001D'  /*Unspecified fracture of right patella, subsequent encounter for closed fracture with routine healing*/
,'S82001E'  /*Unspecified fracture of right patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82001F'  /*Unspecified fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82001G'  /*Unspecified fracture of right patella, subsequent encounter for closed fracture with delayed healing*/
,'S82001H'  /*Unspecified fracture of right patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82001J'  /*Unspecified fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82001K'  /*Unspecified fracture of right patella, subsequent encounter for closed fracture with nonunion*/
,'S82001M'  /*Unspecified fracture of right patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82001N'  /*Unspecified fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82001P'  /*Unspecified fracture of right patella, subsequent encounter for closed fracture with malunion*/
,'S82001Q'  /*Unspecified fracture of right patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82001R'  /*Unspecified fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82001S'  /*Unspecified fracture of right patella, sequela*/
,'S82002D'  /*Unspecified fracture of left patella, subsequent encounter for closed fracture with routine healing*/
,'S82002E'  /*Unspecified fracture of left patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82002F'  /*Unspecified fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82002G'  /*Unspecified fracture of left patella, subsequent encounter for closed fracture with delayed healing*/
,'S82002H'  /*Unspecified fracture of left patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82002J'  /*Unspecified fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82002K'  /*Unspecified fracture of left patella, subsequent encounter for closed fracture with nonunion*/
,'S82002M'  /*Unspecified fracture of left patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82002N'  /*Unspecified fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82002P'  /*Unspecified fracture of left patella, subsequent encounter for closed fracture with malunion*/
,'S82002Q'  /*Unspecified fracture of left patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82002R'  /*Unspecified fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82002S'  /*Unspecified fracture of left patella, sequela*/
,'S82009D'  /*Unspecified fracture of unspecified patella, subsequent encounter for closed fracture with routine healing*/
,'S82009E'  /*Unspecified fracture of unspecified patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82009F'  /*Unspecified fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82009G'  /*Unspecified fracture of unspecified patella, subsequent encounter for closed fracture with delayed healing*/
,'S82009H'  /*Unspecified fracture of unspecified patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82009J'  /*Unspecified fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82009K'  /*Unspecified fracture of unspecified patella, subsequent encounter for closed fracture with nonunion*/
,'S82009M'  /*Unspecified fracture of unspecified patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82009N'  /*Unspecified fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82009P'  /*Unspecified fracture of unspecified patella, subsequent encounter for closed fracture with malunion*/
,'S82009Q'  /*Unspecified fracture of unspecified patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82009R'  /*Unspecified fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82009S'  /*Unspecified fracture of unspecified patella, sequela*/
,'S82011D'  /*Displaced osteochondral fracture of right patella, subsequent encounter for closed fracture with routine healing*/
,'S82011E'  /*Displaced osteochondral fracture of right patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82011F'  /*Displaced osteochondral fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82011G'  /*Displaced osteochondral fracture of right patella, subsequent encounter for closed fracture with delayed healing*/
,'S82011H'  /*Displaced osteochondral fracture of right patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82011J'  /*Displaced osteochondral fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82011K'  /*Displaced osteochondral fracture of right patella, subsequent encounter for closed fracture with nonunion*/
,'S82011M'  /*Displaced osteochondral fracture of right patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82011N'  /*Displaced osteochondral fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82011P'  /*Displaced osteochondral fracture of right patella, subsequent encounter for closed fracture with malunion*/
,'S82011Q'  /*Displaced osteochondral fracture of right patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82011R'  /*Displaced osteochondral fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82011S'  /*Displaced osteochondral fracture of right patella, sequela*/
,'S82012D'  /*Displaced osteochondral fracture of left patella, subsequent encounter for closed fracture with routine healing*/
,'S82012E'  /*Displaced osteochondral fracture of left patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82012F'  /*Displaced osteochondral fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82012G'  /*Displaced osteochondral fracture of left patella, subsequent encounter for closed fracture with delayed healing*/
,'S82012H'  /*Displaced osteochondral fracture of left patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82012J'  /*Displaced osteochondral fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82012K'  /*Displaced osteochondral fracture of left patella, subsequent encounter for closed fracture with nonunion*/
,'S82012M'  /*Displaced osteochondral fracture of left patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82012N'  /*Displaced osteochondral fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82012P'  /*Displaced osteochondral fracture of left patella, subsequent encounter for closed fracture with malunion*/
,'S82012Q'  /*Displaced osteochondral fracture of left patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82012R'  /*Displaced osteochondral fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82012S'  /*Displaced osteochondral fracture of left patella, sequela*/
,'S82013D'  /*Displaced osteochondral fracture of unspecified patella, subsequent encounter for closed fracture with routine healing*/
,'S82013E'  /*Displaced osteochondral fracture of unspecified patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82013F'  /*Displaced osteochondral fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82013G'  /*Displaced osteochondral fracture of unspecified patella, subsequent encounter for closed fracture with delayed healing*/
,'S82013H'  /*Displaced osteochondral fracture of unspecified patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82013J'  /*Displaced osteochondral fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82013K'  /*Displaced osteochondral fracture of unspecified patella, subsequent encounter for closed fracture with nonunion*/
,'S82013M'  /*Displaced osteochondral fracture of unspecified patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82013N'  /*Displaced osteochondral fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82013P'  /*Displaced osteochondral fracture of unspecified patella, subsequent encounter for closed fracture with malunion*/
,'S82013Q'  /*Displaced osteochondral fracture of unspecified patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82013R'  /*Displaced osteochondral fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82013S'  /*Displaced osteochondral fracture of unspecified patella, sequela*/
,'S82014D'  /*Nondisplaced osteochondral fracture of right patella, subsequent encounter for closed fracture with routine healing*/
,'S82014E'  /*Nondisplaced osteochondral fracture of right patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82014F'  /*Nondisplaced osteochondral fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82014G'  /*Nondisplaced osteochondral fracture of right patella, subsequent encounter for closed fracture with delayed healing*/
,'S82014H'  /*Nondisplaced osteochondral fracture of right patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82014J'  /*Nondisplaced osteochondral fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82014K'  /*Nondisplaced osteochondral fracture of right patella, subsequent encounter for closed fracture with nonunion*/
,'S82014M'  /*Nondisplaced osteochondral fracture of right patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82014N'  /*Nondisplaced osteochondral fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82014P'  /*Nondisplaced osteochondral fracture of right patella, subsequent encounter for closed fracture with malunion*/
,'S82014Q'  /*Nondisplaced osteochondral fracture of right patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82014R'  /*Nondisplaced osteochondral fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82014S'  /*Nondisplaced osteochondral fracture of right patella, sequela*/
,'S82015D'  /*Nondisplaced osteochondral fracture of left patella, subsequent encounter for closed fracture with routine healing*/
,'S82015E'  /*Nondisplaced osteochondral fracture of left patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82015F'  /*Nondisplaced osteochondral fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82015G'  /*Nondisplaced osteochondral fracture of left patella, subsequent encounter for closed fracture with delayed healing*/
,'S82015H'  /*Nondisplaced osteochondral fracture of left patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82015J'  /*Nondisplaced osteochondral fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82015K'  /*Nondisplaced osteochondral fracture of left patella, subsequent encounter for closed fracture with nonunion*/
,'S82015M'  /*Nondisplaced osteochondral fracture of left patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82015N'  /*Nondisplaced osteochondral fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82015P'  /*Nondisplaced osteochondral fracture of left patella, subsequent encounter for closed fracture with malunion*/
,'S82015Q'  /*Nondisplaced osteochondral fracture of left patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82015R'  /*Nondisplaced osteochondral fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82015S'  /*Nondisplaced osteochondral fracture of left patella, sequela*/
,'S82016D'  /*Nondisplaced osteochondral fracture of unspecified patella, subsequent encounter for closed fracture with routine healing*/
,'S82016E'  /*Nondisplaced osteochondral fracture of unspecified patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82016F'  /*Nondisplaced osteochondral fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82016G'  /*Nondisplaced osteochondral fracture of unspecified patella, subsequent encounter for closed fracture with delayed healing*/
,'S82016H'  /*Nondisplaced osteochondral fracture of unspecified patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82016J'  /*Nondisplaced osteochondral fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82016K'  /*Nondisplaced osteochondral fracture of unspecified patella, subsequent encounter for closed fracture with nonunion*/
,'S82016M'  /*Nondisplaced osteochondral fracture of unspecified patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82016N'  /*Nondisplaced osteochondral fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82016P'  /*Nondisplaced osteochondral fracture of unspecified patella, subsequent encounter for closed fracture with malunion*/
,'S82016Q'  /*Nondisplaced osteochondral fracture of unspecified patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82016R'  /*Nondisplaced osteochondral fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82016S'  /*Nondisplaced osteochondral fracture of unspecified patella, sequela*/
,'S82021D'  /*Displaced longitudinal fracture of right patella, subsequent encounter for closed fracture with routine healing*/
,'S82021E'  /*Displaced longitudinal fracture of right patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82021F'  /*Displaced longitudinal fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82021G'  /*Displaced longitudinal fracture of right patella, subsequent encounter for closed fracture with delayed healing*/
,'S82021H'  /*Displaced longitudinal fracture of right patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82021J'  /*Displaced longitudinal fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82021K'  /*Displaced longitudinal fracture of right patella, subsequent encounter for closed fracture with nonunion*/
,'S82021M'  /*Displaced longitudinal fracture of right patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82021N'  /*Displaced longitudinal fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82021P'  /*Displaced longitudinal fracture of right patella, subsequent encounter for closed fracture with malunion*/
,'S82021Q'  /*Displaced longitudinal fracture of right patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82021R'  /*Displaced longitudinal fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82021S'  /*Displaced longitudinal fracture of right patella, sequela*/
,'S82022D'  /*Displaced longitudinal fracture of left patella, subsequent encounter for closed fracture with routine healing*/
,'S82022E'  /*Displaced longitudinal fracture of left patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82022F'  /*Displaced longitudinal fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82022G'  /*Displaced longitudinal fracture of left patella, subsequent encounter for closed fracture with delayed healing*/
,'S82022H'  /*Displaced longitudinal fracture of left patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82022J'  /*Displaced longitudinal fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82022K'  /*Displaced longitudinal fracture of left patella, subsequent encounter for closed fracture with nonunion*/
,'S82022M'  /*Displaced longitudinal fracture of left patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82022N'  /*Displaced longitudinal fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82022P'  /*Displaced longitudinal fracture of left patella, subsequent encounter for closed fracture with malunion*/
,'S82022Q'  /*Displaced longitudinal fracture of left patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82022R'  /*Displaced longitudinal fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82022S'  /*Displaced longitudinal fracture of left patella, sequela*/
,'S82023D'  /*Displaced longitudinal fracture of unspecified patella, subsequent encounter for closed fracture with routine healing*/
,'S82023E'  /*Displaced longitudinal fracture of unspecified patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82023F'  /*Displaced longitudinal fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82023G'  /*Displaced longitudinal fracture of unspecified patella, subsequent encounter for closed fracture with delayed healing*/
,'S82023H'  /*Displaced longitudinal fracture of unspecified patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82023J'  /*Displaced longitudinal fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82023K'  /*Displaced longitudinal fracture of unspecified patella, subsequent encounter for closed fracture with nonunion*/
,'S82023M'  /*Displaced longitudinal fracture of unspecified patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82023N'  /*Displaced longitudinal fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82023P'  /*Displaced longitudinal fracture of unspecified patella, subsequent encounter for closed fracture with malunion*/
,'S82023Q'  /*Displaced longitudinal fracture of unspecified patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82023R'  /*Displaced longitudinal fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82023S'  /*Displaced longitudinal fracture of unspecified patella, sequela*/
,'S82024D'  /*Nondisplaced longitudinal fracture of right patella, subsequent encounter for closed fracture with routine healing*/
,'S82024E'  /*Nondisplaced longitudinal fracture of right patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82024F'  /*Nondisplaced longitudinal fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82024G'  /*Nondisplaced longitudinal fracture of right patella, subsequent encounter for closed fracture with delayed healing*/
,'S82024H'  /*Nondisplaced longitudinal fracture of right patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82024J'  /*Nondisplaced longitudinal fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82024K'  /*Nondisplaced longitudinal fracture of right patella, subsequent encounter for closed fracture with nonunion*/
,'S82024M'  /*Nondisplaced longitudinal fracture of right patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82024N'  /*Nondisplaced longitudinal fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82024P'  /*Nondisplaced longitudinal fracture of right patella, subsequent encounter for closed fracture with malunion*/
,'S82024Q'  /*Nondisplaced longitudinal fracture of right patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82024R'  /*Nondisplaced longitudinal fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82024S'  /*Nondisplaced longitudinal fracture of right patella, sequela*/
,'S82025D'  /*Nondisplaced longitudinal fracture of left patella, subsequent encounter for closed fracture with routine healing*/
,'S82025E'  /*Nondisplaced longitudinal fracture of left patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82025F'  /*Nondisplaced longitudinal fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82025G'  /*Nondisplaced longitudinal fracture of left patella, subsequent encounter for closed fracture with delayed healing*/
,'S82025H'  /*Nondisplaced longitudinal fracture of left patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82025J'  /*Nondisplaced longitudinal fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82025K'  /*Nondisplaced longitudinal fracture of left patella, subsequent encounter for closed fracture with nonunion*/
,'S82025M'  /*Nondisplaced longitudinal fracture of left patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82025N'  /*Nondisplaced longitudinal fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82025P'  /*Nondisplaced longitudinal fracture of left patella, subsequent encounter for closed fracture with malunion*/
,'S82025Q'  /*Nondisplaced longitudinal fracture of left patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82025R'  /*Nondisplaced longitudinal fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82025S'  /*Nondisplaced longitudinal fracture of left patella, sequela*/
,'S82026D'  /*Nondisplaced longitudinal fracture of unspecified patella, subsequent encounter for closed fracture with routine healing*/
,'S82026E'  /*Nondisplaced longitudinal fracture of unspecified patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82026F'  /*Nondisplaced longitudinal fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82026G'  /*Nondisplaced longitudinal fracture of unspecified patella, subsequent encounter for closed fracture with delayed healing*/
,'S82026H'  /*Nondisplaced longitudinal fracture of unspecified patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82026J'  /*Nondisplaced longitudinal fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82026K'  /*Nondisplaced longitudinal fracture of unspecified patella, subsequent encounter for closed fracture with nonunion*/
,'S82026M'  /*Nondisplaced longitudinal fracture of unspecified patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82026N'  /*Nondisplaced longitudinal fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82026P'  /*Nondisplaced longitudinal fracture of unspecified patella, subsequent encounter for closed fracture with malunion*/
,'S82026Q'  /*Nondisplaced longitudinal fracture of unspecified patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82026R'  /*Nondisplaced longitudinal fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82026S'  /*Nondisplaced longitudinal fracture of unspecified patella, sequela*/
,'S82031D'  /*Displaced transverse fracture of right patella, subsequent encounter for closed fracture with routine healing*/
,'S82031E'  /*Displaced transverse fracture of right patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82031F'  /*Displaced transverse fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82031G'  /*Displaced transverse fracture of right patella, subsequent encounter for closed fracture with delayed healing*/
,'S82031H'  /*Displaced transverse fracture of right patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82031J'  /*Displaced transverse fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82031K'  /*Displaced transverse fracture of right patella, subsequent encounter for closed fracture with nonunion*/
,'S82031M'  /*Displaced transverse fracture of right patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82031N'  /*Displaced transverse fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82031P'  /*Displaced transverse fracture of right patella, subsequent encounter for closed fracture with malunion*/
,'S82031Q'  /*Displaced transverse fracture of right patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82031R'  /*Displaced transverse fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82031S'  /*Displaced transverse fracture of right patella, sequela*/
,'S82032D'  /*Displaced transverse fracture of left patella, subsequent encounter for closed fracture with routine healing*/
,'S82032E'  /*Displaced transverse fracture of left patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82032F'  /*Displaced transverse fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82032G'  /*Displaced transverse fracture of left patella, subsequent encounter for closed fracture with delayed healing*/
,'S82032H'  /*Displaced transverse fracture of left patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82032J'  /*Displaced transverse fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82032K'  /*Displaced transverse fracture of left patella, subsequent encounter for closed fracture with nonunion*/
,'S82032M'  /*Displaced transverse fracture of left patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82032N'  /*Displaced transverse fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82032P'  /*Displaced transverse fracture of left patella, subsequent encounter for closed fracture with malunion*/
,'S82032Q'  /*Displaced transverse fracture of left patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82032R'  /*Displaced transverse fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82032S'  /*Displaced transverse fracture of left patella, sequela*/
,'S82033D'  /*Displaced transverse fracture of unspecified patella, subsequent encounter for closed fracture with routine healing*/
,'S82033E'  /*Displaced transverse fracture of unspecified patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82033F'  /*Displaced transverse fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82033G'  /*Displaced transverse fracture of unspecified patella, subsequent encounter for closed fracture with delayed healing*/
,'S82033H'  /*Displaced transverse fracture of unspecified patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82033J'  /*Displaced transverse fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82033K'  /*Displaced transverse fracture of unspecified patella, subsequent encounter for closed fracture with nonunion*/
,'S82033M'  /*Displaced transverse fracture of unspecified patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82033N'  /*Displaced transverse fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82033P'  /*Displaced transverse fracture of unspecified patella, subsequent encounter for closed fracture with malunion*/
,'S82033Q'  /*Displaced transverse fracture of unspecified patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82033R'  /*Displaced transverse fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82033S'  /*Displaced transverse fracture of unspecified patella, sequela*/
,'S82034D'  /*Nondisplaced transverse fracture of right patella, subsequent encounter for closed fracture with routine healing*/
,'S82034E'  /*Nondisplaced transverse fracture of right patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82034F'  /*Nondisplaced transverse fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82034G'  /*Nondisplaced transverse fracture of right patella, subsequent encounter for closed fracture with delayed healing*/
,'S82034H'  /*Nondisplaced transverse fracture of right patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82034J'  /*Nondisplaced transverse fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82034K'  /*Nondisplaced transverse fracture of right patella, subsequent encounter for closed fracture with nonunion*/
,'S82034M'  /*Nondisplaced transverse fracture of right patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82034N'  /*Nondisplaced transverse fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82034P'  /*Nondisplaced transverse fracture of right patella, subsequent encounter for closed fracture with malunion*/
,'S82034Q'  /*Nondisplaced transverse fracture of right patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82034R'  /*Nondisplaced transverse fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82034S'  /*Nondisplaced transverse fracture of right patella, sequela*/
,'S82035D'  /*Nondisplaced transverse fracture of left patella, subsequent encounter for closed fracture with routine healing*/
,'S82035E'  /*Nondisplaced transverse fracture of left patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82035F'  /*Nondisplaced transverse fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82035G'  /*Nondisplaced transverse fracture of left patella, subsequent encounter for closed fracture with delayed healing*/
,'S82035H'  /*Nondisplaced transverse fracture of left patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82035J'  /*Nondisplaced transverse fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82035K'  /*Nondisplaced transverse fracture of left patella, subsequent encounter for closed fracture with nonunion*/
,'S82035M'  /*Nondisplaced transverse fracture of left patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82035N'  /*Nondisplaced transverse fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82035P'  /*Nondisplaced transverse fracture of left patella, subsequent encounter for closed fracture with malunion*/
,'S82035Q'  /*Nondisplaced transverse fracture of left patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82035R'  /*Nondisplaced transverse fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82035S'  /*Nondisplaced transverse fracture of left patella, sequela*/
,'S82036D'  /*Nondisplaced transverse fracture of unspecified patella, subsequent encounter for closed fracture with routine healing*/
,'S82036E'  /*Nondisplaced transverse fracture of unspecified patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82036F'  /*Nondisplaced transverse fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82036G'  /*Nondisplaced transverse fracture of unspecified patella, subsequent encounter for closed fracture with delayed healing*/
,'S82036H'  /*Nondisplaced transverse fracture of unspecified patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82036J'  /*Nondisplaced transverse fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82036K'  /*Nondisplaced transverse fracture of unspecified patella, subsequent encounter for closed fracture with nonunion*/
,'S82036M'  /*Nondisplaced transverse fracture of unspecified patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82036N'  /*Nondisplaced transverse fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82036P'  /*Nondisplaced transverse fracture of unspecified patella, subsequent encounter for closed fracture with malunion*/
,'S82036Q'  /*Nondisplaced transverse fracture of unspecified patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82036R'  /*Nondisplaced transverse fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82036S'  /*Nondisplaced transverse fracture of unspecified patella, sequela*/
,'S82041D'  /*Displaced comminuted fracture of right patella, subsequent encounter for closed fracture with routine healing*/
,'S82041E'  /*Displaced comminuted fracture of right patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82041F'  /*Displaced comminuted fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82041G'  /*Displaced comminuted fracture of right patella, subsequent encounter for closed fracture with delayed healing*/
,'S82041H'  /*Displaced comminuted fracture of right patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82041J'  /*Displaced comminuted fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82041K'  /*Displaced comminuted fracture of right patella, subsequent encounter for closed fracture with nonunion*/
,'S82041M'  /*Displaced comminuted fracture of right patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82041N'  /*Displaced comminuted fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82041P'  /*Displaced comminuted fracture of right patella, subsequent encounter for closed fracture with malunion*/
,'S82041Q'  /*Displaced comminuted fracture of right patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82041R'  /*Displaced comminuted fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82041S'  /*Displaced comminuted fracture of right patella, sequela*/
,'S82042D'  /*Displaced comminuted fracture of left patella, subsequent encounter for closed fracture with routine healing*/
,'S82042E'  /*Displaced comminuted fracture of left patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82042F'  /*Displaced comminuted fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82042G'  /*Displaced comminuted fracture of left patella, subsequent encounter for closed fracture with delayed healing*/
,'S82042H'  /*Displaced comminuted fracture of left patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82042J'  /*Displaced comminuted fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82042K'  /*Displaced comminuted fracture of left patella, subsequent encounter for closed fracture with nonunion*/
,'S82042M'  /*Displaced comminuted fracture of left patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82042N'  /*Displaced comminuted fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82042P'  /*Displaced comminuted fracture of left patella, subsequent encounter for closed fracture with malunion*/
,'S82042Q'  /*Displaced comminuted fracture of left patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82042R'  /*Displaced comminuted fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82042S'  /*Displaced comminuted fracture of left patella, sequela*/
,'S82043D'  /*Displaced comminuted fracture of unspecified patella, subsequent encounter for closed fracture with routine healing*/
,'S82043E'  /*Displaced comminuted fracture of unspecified patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82043F'  /*Displaced comminuted fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82043G'  /*Displaced comminuted fracture of unspecified patella, subsequent encounter for closed fracture with delayed healing*/
,'S82043H'  /*Displaced comminuted fracture of unspecified patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82043J'  /*Displaced comminuted fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82043K'  /*Displaced comminuted fracture of unspecified patella, subsequent encounter for closed fracture with nonunion*/
,'S82043M'  /*Displaced comminuted fracture of unspecified patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82043N'  /*Displaced comminuted fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82043P'  /*Displaced comminuted fracture of unspecified patella, subsequent encounter for closed fracture with malunion*/
,'S82043Q'  /*Displaced comminuted fracture of unspecified patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82043R'  /*Displaced comminuted fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82043S'  /*Displaced comminuted fracture of unspecified patella, sequela*/
,'S82044D'  /*Nondisplaced comminuted fracture of right patella, subsequent encounter for closed fracture with routine healing*/
,'S82044E'  /*Nondisplaced comminuted fracture of right patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82044F'  /*Nondisplaced comminuted fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82044G'  /*Nondisplaced comminuted fracture of right patella, subsequent encounter for closed fracture with delayed healing*/
,'S82044H'  /*Nondisplaced comminuted fracture of right patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82044J'  /*Nondisplaced comminuted fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82044K'  /*Nondisplaced comminuted fracture of right patella, subsequent encounter for closed fracture with nonunion*/
,'S82044M'  /*Nondisplaced comminuted fracture of right patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82044N'  /*Nondisplaced comminuted fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82044P'  /*Nondisplaced comminuted fracture of right patella, subsequent encounter for closed fracture with malunion*/
,'S82044Q'  /*Nondisplaced comminuted fracture of right patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82044R'  /*Nondisplaced comminuted fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82044S'  /*Nondisplaced comminuted fracture of right patella, sequela*/
,'S82045D'  /*Nondisplaced comminuted fracture of left patella, subsequent encounter for closed fracture with routine healing*/
,'S82045E'  /*Nondisplaced comminuted fracture of left patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82045F'  /*Nondisplaced comminuted fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82045G'  /*Nondisplaced comminuted fracture of left patella, subsequent encounter for closed fracture with delayed healing*/
,'S82045H'  /*Nondisplaced comminuted fracture of left patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82045J'  /*Nondisplaced comminuted fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82045K'  /*Nondisplaced comminuted fracture of left patella, subsequent encounter for closed fracture with nonunion*/
,'S82045M'  /*Nondisplaced comminuted fracture of left patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82045N'  /*Nondisplaced comminuted fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82045P'  /*Nondisplaced comminuted fracture of left patella, subsequent encounter for closed fracture with malunion*/
,'S82045Q'  /*Nondisplaced comminuted fracture of left patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82045R'  /*Nondisplaced comminuted fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82045S'  /*Nondisplaced comminuted fracture of left patella, sequela*/
,'S82046D'  /*Nondisplaced comminuted fracture of unspecified patella, subsequent encounter for closed fracture with routine healing*/
,'S82046E'  /*Nondisplaced comminuted fracture of unspecified patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82046F'  /*Nondisplaced comminuted fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82046G'  /*Nondisplaced comminuted fracture of unspecified patella, subsequent encounter for closed fracture with delayed healing*/
,'S82046H'  /*Nondisplaced comminuted fracture of unspecified patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82046J'  /*Nondisplaced comminuted fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82046K'  /*Nondisplaced comminuted fracture of unspecified patella, subsequent encounter for closed fracture with nonunion*/
,'S82046M'  /*Nondisplaced comminuted fracture of unspecified patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82046N'  /*Nondisplaced comminuted fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82046P'  /*Nondisplaced comminuted fracture of unspecified patella, subsequent encounter for closed fracture with malunion*/
,'S82046Q'  /*Nondisplaced comminuted fracture of unspecified patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82046R'  /*Nondisplaced comminuted fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82046S'  /*Nondisplaced comminuted fracture of unspecified patella, sequela*/
,'S82091D'  /*Other fracture of right patella, subsequent encounter for closed fracture with routine healing*/
,'S82091E'  /*Other fracture of right patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82091F'  /*Other fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82091G'  /*Other fracture of right patella, subsequent encounter for closed fracture with delayed healing*/
,'S82091H'  /*Other fracture of right patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82091J'  /*Other fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82091K'  /*Other fracture of right patella, subsequent encounter for closed fracture with nonunion*/
,'S82091M'  /*Other fracture of right patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82091N'  /*Other fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82091P'  /*Other fracture of right patella, subsequent encounter for closed fracture with malunion*/
,'S82091Q'  /*Other fracture of right patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82091R'  /*Other fracture of right patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82091S'  /*Other fracture of right patella, sequela*/
,'S82092D'  /*Other fracture of left patella, subsequent encounter for closed fracture with routine healing*/
,'S82092E'  /*Other fracture of left patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82092F'  /*Other fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82092G'  /*Other fracture of left patella, subsequent encounter for closed fracture with delayed healing*/
,'S82092H'  /*Other fracture of left patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82092J'  /*Other fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82092K'  /*Other fracture of left patella, subsequent encounter for closed fracture with nonunion*/
,'S82092M'  /*Other fracture of left patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82092N'  /*Other fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82092P'  /*Other fracture of left patella, subsequent encounter for closed fracture with malunion*/
,'S82092Q'  /*Other fracture of left patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82092R'  /*Other fracture of left patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82092S'  /*Other fracture of left patella, sequela*/
,'S82099D'  /*Other fracture of unspecified patella, subsequent encounter for closed fracture with routine healing*/
,'S82099E'  /*Other fracture of unspecified patella, subsequent encounter for open fracture type I or II with routine healing*/
,'S82099F'  /*Other fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82099G'  /*Other fracture of unspecified patella, subsequent encounter for closed fracture with delayed healing*/
,'S82099H'  /*Other fracture of unspecified patella, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82099J'  /*Other fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82099K'  /*Other fracture of unspecified patella, subsequent encounter for closed fracture with nonunion*/
,'S82099M'  /*Other fracture of unspecified patella, subsequent encounter for open fracture type I or II with nonunion*/
,'S82099N'  /*Other fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82099P'  /*Other fracture of unspecified patella, subsequent encounter for closed fracture with malunion*/
,'S82099Q'  /*Other fracture of unspecified patella, subsequent encounter for open fracture type I or II with malunion*/
,'S82099R'  /*Other fracture of unspecified patella, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82099S'  /*Other fracture of unspecified patella, sequela*/
,'S82101D'  /*Unspecified fracture of upper end of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82101E'  /*Unspecified fracture of upper end of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82101F'  /*Unspecified fracture of upper end of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82101G'  /*Unspecified fracture of upper end of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82101H'  /*Unspecified fracture of upper end of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82101J'  /*Unspecified fracture of upper end of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82101K'  /*Unspecified fracture of upper end of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82101M'  /*Unspecified fracture of upper end of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82101N'  /*Unspecified fracture of upper end of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82101P'  /*Unspecified fracture of upper end of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82101Q'  /*Unspecified fracture of upper end of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82101R'  /*Unspecified fracture of upper end of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82101S'  /*Unspecified fracture of upper end of right tibia, sequela*/
,'S82102D'  /*Unspecified fracture of upper end of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82102E'  /*Unspecified fracture of upper end of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82102F'  /*Unspecified fracture of upper end of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82102G'  /*Unspecified fracture of upper end of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82102H'  /*Unspecified fracture of upper end of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82102J'  /*Unspecified fracture of upper end of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82102K'  /*Unspecified fracture of upper end of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82102M'  /*Unspecified fracture of upper end of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82102N'  /*Unspecified fracture of upper end of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82102P'  /*Unspecified fracture of upper end of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82102Q'  /*Unspecified fracture of upper end of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82102R'  /*Unspecified fracture of upper end of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82102S'  /*Unspecified fracture of upper end of left tibia, sequela*/
,'S82109D'  /*Unspecified fracture of upper end of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82109E'  /*Unspecified fracture of upper end of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82109F'  /*Unspecified fracture of upper end of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82109G'  /*Unspecified fracture of upper end of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82109H'  /*Unspecified fracture of upper end of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82109J'  /*Unspecified fracture of upper end of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82109K'  /*Unspecified fracture of upper end of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82109M'  /*Unspecified fracture of upper end of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82109N'  /*Unspecified fracture of upper end of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82109P'  /*Unspecified fracture of upper end of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82109Q'  /*Unspecified fracture of upper end of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82109R'  /*Unspecified fracture of upper end of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82109S'  /*Unspecified fracture of upper end of unspecified tibia, sequela*/
,'S82111D'  /*Displaced fracture of right tibial spine, subsequent encounter for closed fracture with routine healing*/
,'S82111E'  /*Displaced fracture of right tibial spine, subsequent encounter for open fracture type I or II with routine healing*/
,'S82111F'  /*Displaced fracture of right tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82111G'  /*Displaced fracture of right tibial spine, subsequent encounter for closed fracture with delayed healing*/
,'S82111H'  /*Displaced fracture of right tibial spine, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82111J'  /*Displaced fracture of right tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82111K'  /*Displaced fracture of right tibial spine, subsequent encounter for closed fracture with nonunion*/
,'S82111M'  /*Displaced fracture of right tibial spine, subsequent encounter for open fracture type I or II with nonunion*/
,'S82111N'  /*Displaced fracture of right tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82111P'  /*Displaced fracture of right tibial spine, subsequent encounter for closed fracture with malunion*/
,'S82111Q'  /*Displaced fracture of right tibial spine, subsequent encounter for open fracture type I or II with malunion*/
,'S82111R'  /*Displaced fracture of right tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82111S'  /*Displaced fracture of right tibial spine, sequela*/
,'S82112D'  /*Displaced fracture of left tibial spine, subsequent encounter for closed fracture with routine healing*/
,'S82112E'  /*Displaced fracture of left tibial spine, subsequent encounter for open fracture type I or II with routine healing*/
,'S82112F'  /*Displaced fracture of left tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82112G'  /*Displaced fracture of left tibial spine, subsequent encounter for closed fracture with delayed healing*/
,'S82112H'  /*Displaced fracture of left tibial spine, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82112J'  /*Displaced fracture of left tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82112K'  /*Displaced fracture of left tibial spine, subsequent encounter for closed fracture with nonunion*/
,'S82112M'  /*Displaced fracture of left tibial spine, subsequent encounter for open fracture type I or II with nonunion*/
,'S82112N'  /*Displaced fracture of left tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82112P'  /*Displaced fracture of left tibial spine, subsequent encounter for closed fracture with malunion*/
,'S82112Q'  /*Displaced fracture of left tibial spine, subsequent encounter for open fracture type I or II with malunion*/
,'S82112R'  /*Displaced fracture of left tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82112S'  /*Displaced fracture of left tibial spine, sequela*/
,'S82113D'  /*Displaced fracture of unspecified tibial spine, subsequent encounter for closed fracture with routine healing*/
,'S82113E'  /*Displaced fracture of unspecified tibial spine, subsequent encounter for open fracture type I or II with routine healing*/
,'S82113F'  /*Displaced fracture of unspecified tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82113G'  /*Displaced fracture of unspecified tibial spine, subsequent encounter for closed fracture with delayed healing*/
,'S82113H'  /*Displaced fracture of unspecified tibial spine, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82113J'  /*Displaced fracture of unspecified tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82113K'  /*Displaced fracture of unspecified tibial spine, subsequent encounter for closed fracture with nonunion*/
,'S82113M'  /*Displaced fracture of unspecified tibial spine, subsequent encounter for open fracture type I or II with nonunion*/
,'S82113N'  /*Displaced fracture of unspecified tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82113P'  /*Displaced fracture of unspecified tibial spine, subsequent encounter for closed fracture with malunion*/
,'S82113Q'  /*Displaced fracture of unspecified tibial spine, subsequent encounter for open fracture type I or II with malunion*/
,'S82113R'  /*Displaced fracture of unspecified tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82113S'  /*Displaced fracture of unspecified tibial spine, sequela*/
,'S82114D'  /*Nondisplaced fracture of right tibial spine, subsequent encounter for closed fracture with routine healing*/
,'S82114E'  /*Nondisplaced fracture of right tibial spine, subsequent encounter for open fracture type I or II with routine healing*/
,'S82114F'  /*Nondisplaced fracture of right tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82114G'  /*Nondisplaced fracture of right tibial spine, subsequent encounter for closed fracture with delayed healing*/
,'S82114H'  /*Nondisplaced fracture of right tibial spine, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82114J'  /*Nondisplaced fracture of right tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82114K'  /*Nondisplaced fracture of right tibial spine, subsequent encounter for closed fracture with nonunion*/
,'S82114M'  /*Nondisplaced fracture of right tibial spine, subsequent encounter for open fracture type I or II with nonunion*/
,'S82114N'  /*Nondisplaced fracture of right tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82114P'  /*Nondisplaced fracture of right tibial spine, subsequent encounter for closed fracture with malunion*/
,'S82114Q'  /*Nondisplaced fracture of right tibial spine, subsequent encounter for open fracture type I or II with malunion*/
,'S82114R'  /*Nondisplaced fracture of right tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82114S'  /*Nondisplaced fracture of right tibial spine, sequela*/
,'S82115D'  /*Nondisplaced fracture of left tibial spine, subsequent encounter for closed fracture with routine healing*/
,'S82115E'  /*Nondisplaced fracture of left tibial spine, subsequent encounter for open fracture type I or II with routine healing*/
,'S82115F'  /*Nondisplaced fracture of left tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82115G'  /*Nondisplaced fracture of left tibial spine, subsequent encounter for closed fracture with delayed healing*/
,'S82115H'  /*Nondisplaced fracture of left tibial spine, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82115J'  /*Nondisplaced fracture of left tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82115K'  /*Nondisplaced fracture of left tibial spine, subsequent encounter for closed fracture with nonunion*/
,'S82115M'  /*Nondisplaced fracture of left tibial spine, subsequent encounter for open fracture type I or II with nonunion*/
,'S82115N'  /*Nondisplaced fracture of left tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82115P'  /*Nondisplaced fracture of left tibial spine, subsequent encounter for closed fracture with malunion*/
,'S82115Q'  /*Nondisplaced fracture of left tibial spine, subsequent encounter for open fracture type I or II with malunion*/
,'S82115R'  /*Nondisplaced fracture of left tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82115S'  /*Nondisplaced fracture of left tibial spine, sequela*/
,'S82116D'  /*Nondisplaced fracture of unspecified tibial spine, subsequent encounter for closed fracture with routine healing*/
,'S82116E'  /*Nondisplaced fracture of unspecified tibial spine, subsequent encounter for open fracture type I or II with routine healing*/
,'S82116F'  /*Nondisplaced fracture of unspecified tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82116G'  /*Nondisplaced fracture of unspecified tibial spine, subsequent encounter for closed fracture with delayed healing*/
,'S82116H'  /*Nondisplaced fracture of unspecified tibial spine, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82116J'  /*Nondisplaced fracture of unspecified tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82116K'  /*Nondisplaced fracture of unspecified tibial spine, subsequent encounter for closed fracture with nonunion*/
,'S82116M'  /*Nondisplaced fracture of unspecified tibial spine, subsequent encounter for open fracture type I or II with nonunion*/
,'S82116N'  /*Nondisplaced fracture of unspecified tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82116P'  /*Nondisplaced fracture of unspecified tibial spine, subsequent encounter for closed fracture with malunion*/
,'S82116Q'  /*Nondisplaced fracture of unspecified tibial spine, subsequent encounter for open fracture type I or II with malunion*/
,'S82116R'  /*Nondisplaced fracture of unspecified tibial spine, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82116S'  /*Nondisplaced fracture of unspecified tibial spine, sequela*/
,'S82121D'  /*Displaced fracture of lateral condyle of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82121E'  /*Displaced fracture of lateral condyle of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82121F'  /*Displaced fracture of lateral condyle of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82121G'  /*Displaced fracture of lateral condyle of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82121H'  /*Displaced fracture of lateral condyle of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82121J'  /*Displaced fracture of lateral condyle of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82121K'  /*Displaced fracture of lateral condyle of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82121M'  /*Displaced fracture of lateral condyle of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82121N'  /*Displaced fracture of lateral condyle of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82121P'  /*Displaced fracture of lateral condyle of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82121Q'  /*Displaced fracture of lateral condyle of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82121R'  /*Displaced fracture of lateral condyle of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82121S'  /*Displaced fracture of lateral condyle of right tibia, sequela*/
,'S82122D'  /*Displaced fracture of lateral condyle of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82122E'  /*Displaced fracture of lateral condyle of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82122F'  /*Displaced fracture of lateral condyle of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82122G'  /*Displaced fracture of lateral condyle of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82122H'  /*Displaced fracture of lateral condyle of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82122J'  /*Displaced fracture of lateral condyle of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82122K'  /*Displaced fracture of lateral condyle of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82122M'  /*Displaced fracture of lateral condyle of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82122N'  /*Displaced fracture of lateral condyle of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82122P'  /*Displaced fracture of lateral condyle of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82122Q'  /*Displaced fracture of lateral condyle of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82122R'  /*Displaced fracture of lateral condyle of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82122S'  /*Displaced fracture of lateral condyle of left tibia, sequela*/
,'S82123D'  /*Displaced fracture of lateral condyle of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82123E'  /*Displaced fracture of lateral condyle of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82123F'  /*Displaced fracture of lateral condyle of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82123G'  /*Displaced fracture of lateral condyle of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82123H'  /*Displaced fracture of lateral condyle of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82123J'  /*Displaced fracture of lateral condyle of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82123K'  /*Displaced fracture of lateral condyle of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82123M'  /*Displaced fracture of lateral condyle of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82123N'  /*Displaced fracture of lateral condyle of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82123P'  /*Displaced fracture of lateral condyle of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82123Q'  /*Displaced fracture of lateral condyle of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82123R'  /*Displaced fracture of lateral condyle of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82123S'  /*Displaced fracture of lateral condyle of unspecified tibia, sequela*/
,'S82124D'  /*Nondisplaced fracture of lateral condyle of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82124E'  /*Nondisplaced fracture of lateral condyle of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82124F'  /*Nondisplaced fracture of lateral condyle of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82124G'  /*Nondisplaced fracture of lateral condyle of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82124H'  /*Nondisplaced fracture of lateral condyle of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82124J'  /*Nondisplaced fracture of lateral condyle of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82124K'  /*Nondisplaced fracture of lateral condyle of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82124M'  /*Nondisplaced fracture of lateral condyle of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82124N'  /*Nondisplaced fracture of lateral condyle of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82124P'  /*Nondisplaced fracture of lateral condyle of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82124Q'  /*Nondisplaced fracture of lateral condyle of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82124R'  /*Nondisplaced fracture of lateral condyle of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82124S'  /*Nondisplaced fracture of lateral condyle of right tibia, sequela*/
,'S82125D'  /*Nondisplaced fracture of lateral condyle of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82125E'  /*Nondisplaced fracture of lateral condyle of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82125F'  /*Nondisplaced fracture of lateral condyle of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82125G'  /*Nondisplaced fracture of lateral condyle of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82125H'  /*Nondisplaced fracture of lateral condyle of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82125J'  /*Nondisplaced fracture of lateral condyle of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82125K'  /*Nondisplaced fracture of lateral condyle of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82125M'  /*Nondisplaced fracture of lateral condyle of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82125N'  /*Nondisplaced fracture of lateral condyle of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82125P'  /*Nondisplaced fracture of lateral condyle of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82125Q'  /*Nondisplaced fracture of lateral condyle of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82125R'  /*Nondisplaced fracture of lateral condyle of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82125S'  /*Nondisplaced fracture of lateral condyle of left tibia, sequela*/
,'S82126D'  /*Nondisplaced fracture of lateral condyle of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82126E'  /*Nondisplaced fracture of lateral condyle of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82126F'  /*Nondisplaced fracture of lateral condyle of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82126G'  /*Nondisplaced fracture of lateral condyle of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82126H'  /*Nondisplaced fracture of lateral condyle of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82126J'  /*Nondisplaced fracture of lateral condyle of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82126K'  /*Nondisplaced fracture of lateral condyle of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82126M'  /*Nondisplaced fracture of lateral condyle of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82126N'  /*Nondisplaced fracture of lateral condyle of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82126P'  /*Nondisplaced fracture of lateral condyle of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82126Q'  /*Nondisplaced fracture of lateral condyle of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82126R'  /*Nondisplaced fracture of lateral condyle of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82126S'  /*Nondisplaced fracture of lateral condyle of unspecified tibia, sequela*/
,'S82131D'  /*Displaced fracture of medial condyle of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82131E'  /*Displaced fracture of medial condyle of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82131F'  /*Displaced fracture of medial condyle of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82131G'  /*Displaced fracture of medial condyle of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82131H'  /*Displaced fracture of medial condyle of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82131J'  /*Displaced fracture of medial condyle of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82131K'  /*Displaced fracture of medial condyle of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82131M'  /*Displaced fracture of medial condyle of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82131N'  /*Displaced fracture of medial condyle of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82131P'  /*Displaced fracture of medial condyle of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82131Q'  /*Displaced fracture of medial condyle of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82131R'  /*Displaced fracture of medial condyle of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82131S'  /*Displaced fracture of medial condyle of right tibia, sequela*/
,'S82132D'  /*Displaced fracture of medial condyle of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82132E'  /*Displaced fracture of medial condyle of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82132F'  /*Displaced fracture of medial condyle of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82132G'  /*Displaced fracture of medial condyle of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82132H'  /*Displaced fracture of medial condyle of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82132J'  /*Displaced fracture of medial condyle of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82132K'  /*Displaced fracture of medial condyle of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82132M'  /*Displaced fracture of medial condyle of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82132N'  /*Displaced fracture of medial condyle of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82132P'  /*Displaced fracture of medial condyle of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82132Q'  /*Displaced fracture of medial condyle of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82132R'  /*Displaced fracture of medial condyle of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82132S'  /*Displaced fracture of medial condyle of left tibia, sequela*/
,'S82133D'  /*Displaced fracture of medial condyle of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82133E'  /*Displaced fracture of medial condyle of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82133F'  /*Displaced fracture of medial condyle of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82133G'  /*Displaced fracture of medial condyle of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82133H'  /*Displaced fracture of medial condyle of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82133J'  /*Displaced fracture of medial condyle of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82133K'  /*Displaced fracture of medial condyle of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82133M'  /*Displaced fracture of medial condyle of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82133N'  /*Displaced fracture of medial condyle of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82133P'  /*Displaced fracture of medial condyle of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82133Q'  /*Displaced fracture of medial condyle of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82133R'  /*Displaced fracture of medial condyle of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82133S'  /*Displaced fracture of medial condyle of unspecified tibia, sequela*/
,'S82134D'  /*Nondisplaced fracture of medial condyle of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82134E'  /*Nondisplaced fracture of medial condyle of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82134F'  /*Nondisplaced fracture of medial condyle of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82134G'  /*Nondisplaced fracture of medial condyle of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82134H'  /*Nondisplaced fracture of medial condyle of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82134J'  /*Nondisplaced fracture of medial condyle of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82134K'  /*Nondisplaced fracture of medial condyle of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82134M'  /*Nondisplaced fracture of medial condyle of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82134N'  /*Nondisplaced fracture of medial condyle of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82134P'  /*Nondisplaced fracture of medial condyle of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82134Q'  /*Nondisplaced fracture of medial condyle of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82134R'  /*Nondisplaced fracture of medial condyle of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82134S'  /*Nondisplaced fracture of medial condyle of right tibia, sequela*/
,'S82135D'  /*Nondisplaced fracture of medial condyle of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82135E'  /*Nondisplaced fracture of medial condyle of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82135F'  /*Nondisplaced fracture of medial condyle of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82135G'  /*Nondisplaced fracture of medial condyle of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82135H'  /*Nondisplaced fracture of medial condyle of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82135J'  /*Nondisplaced fracture of medial condyle of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82135K'  /*Nondisplaced fracture of medial condyle of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82135M'  /*Nondisplaced fracture of medial condyle of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82135N'  /*Nondisplaced fracture of medial condyle of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82135P'  /*Nondisplaced fracture of medial condyle of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82135Q'  /*Nondisplaced fracture of medial condyle of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82135R'  /*Nondisplaced fracture of medial condyle of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82135S'  /*Nondisplaced fracture of medial condyle of left tibia, sequela*/
,'S82136D'  /*Nondisplaced fracture of medial condyle of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82136E'  /*Nondisplaced fracture of medial condyle of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82136F'  /*Nondisplaced fracture of medial condyle of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82136G'  /*Nondisplaced fracture of medial condyle of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82136H'  /*Nondisplaced fracture of medial condyle of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82136J'  /*Nondisplaced fracture of medial condyle of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82136K'  /*Nondisplaced fracture of medial condyle of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82136M'  /*Nondisplaced fracture of medial condyle of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82136N'  /*Nondisplaced fracture of medial condyle of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82136P'  /*Nondisplaced fracture of medial condyle of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82136Q'  /*Nondisplaced fracture of medial condyle of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82136R'  /*Nondisplaced fracture of medial condyle of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82136S'  /*Nondisplaced fracture of medial condyle of unspecified tibia, sequela*/
,'S82141D'  /*Displaced bicondylar fracture of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82141E'  /*Displaced bicondylar fracture of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82141F'  /*Displaced bicondylar fracture of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82141G'  /*Displaced bicondylar fracture of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82141H'  /*Displaced bicondylar fracture of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82141J'  /*Displaced bicondylar fracture of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82141K'  /*Displaced bicondylar fracture of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82141M'  /*Displaced bicondylar fracture of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82141N'  /*Displaced bicondylar fracture of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82141P'  /*Displaced bicondylar fracture of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82141Q'  /*Displaced bicondylar fracture of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82141R'  /*Displaced bicondylar fracture of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82141S'  /*Displaced bicondylar fracture of right tibia, sequela*/
,'S82142D'  /*Displaced bicondylar fracture of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82142E'  /*Displaced bicondylar fracture of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82142F'  /*Displaced bicondylar fracture of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82142G'  /*Displaced bicondylar fracture of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82142H'  /*Displaced bicondylar fracture of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82142J'  /*Displaced bicondylar fracture of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82142K'  /*Displaced bicondylar fracture of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82142M'  /*Displaced bicondylar fracture of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82142N'  /*Displaced bicondylar fracture of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82142P'  /*Displaced bicondylar fracture of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82142Q'  /*Displaced bicondylar fracture of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82142R'  /*Displaced bicondylar fracture of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82142S'  /*Displaced bicondylar fracture of left tibia, sequela*/
,'S82143D'  /*Displaced bicondylar fracture of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82143E'  /*Displaced bicondylar fracture of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82143F'  /*Displaced bicondylar fracture of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82143G'  /*Displaced bicondylar fracture of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82143H'  /*Displaced bicondylar fracture of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82143J'  /*Displaced bicondylar fracture of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82143K'  /*Displaced bicondylar fracture of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82143M'  /*Displaced bicondylar fracture of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82143N'  /*Displaced bicondylar fracture of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82143P'  /*Displaced bicondylar fracture of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82143Q'  /*Displaced bicondylar fracture of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82143R'  /*Displaced bicondylar fracture of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82143S'  /*Displaced bicondylar fracture of unspecified tibia, sequela*/
,'S82144D'  /*Nondisplaced bicondylar fracture of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82144E'  /*Nondisplaced bicondylar fracture of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82144F'  /*Nondisplaced bicondylar fracture of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82144G'  /*Nondisplaced bicondylar fracture of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82144H'  /*Nondisplaced bicondylar fracture of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82144J'  /*Nondisplaced bicondylar fracture of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82144K'  /*Nondisplaced bicondylar fracture of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82144M'  /*Nondisplaced bicondylar fracture of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82144N'  /*Nondisplaced bicondylar fracture of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82144P'  /*Nondisplaced bicondylar fracture of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82144Q'  /*Nondisplaced bicondylar fracture of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82144R'  /*Nondisplaced bicondylar fracture of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82144S'  /*Nondisplaced bicondylar fracture of right tibia, sequela*/
,'S82145D'  /*Nondisplaced bicondylar fracture of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82145E'  /*Nondisplaced bicondylar fracture of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82145F'  /*Nondisplaced bicondylar fracture of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82145G'  /*Nondisplaced bicondylar fracture of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82145H'  /*Nondisplaced bicondylar fracture of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82145J'  /*Nondisplaced bicondylar fracture of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82145K'  /*Nondisplaced bicondylar fracture of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82145M'  /*Nondisplaced bicondylar fracture of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82145N'  /*Nondisplaced bicondylar fracture of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82145P'  /*Nondisplaced bicondylar fracture of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82145Q'  /*Nondisplaced bicondylar fracture of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82145R'  /*Nondisplaced bicondylar fracture of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82145S'  /*Nondisplaced bicondylar fracture of left tibia, sequela*/
,'S82146D'  /*Nondisplaced bicondylar fracture of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82146E'  /*Nondisplaced bicondylar fracture of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82146F'  /*Nondisplaced bicondylar fracture of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82146G'  /*Nondisplaced bicondylar fracture of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82146H'  /*Nondisplaced bicondylar fracture of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82146J'  /*Nondisplaced bicondylar fracture of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82146K'  /*Nondisplaced bicondylar fracture of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82146M'  /*Nondisplaced bicondylar fracture of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82146N'  /*Nondisplaced bicondylar fracture of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82146P'  /*Nondisplaced bicondylar fracture of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82146Q'  /*Nondisplaced bicondylar fracture of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82146R'  /*Nondisplaced bicondylar fracture of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82146S'  /*Nondisplaced bicondylar fracture of unspecified tibia, sequela*/
,'S82151D'  /*Displaced fracture of right tibial tuberosity, subsequent encounter for closed fracture with routine healing*/
,'S82151E'  /*Displaced fracture of right tibial tuberosity, subsequent encounter for open fracture type I or II with routine healing*/
,'S82151F'  /*Displaced fracture of right tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82151G'  /*Displaced fracture of right tibial tuberosity, subsequent encounter for closed fracture with delayed healing*/
,'S82151H'  /*Displaced fracture of right tibial tuberosity, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82151J'  /*Displaced fracture of right tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82151K'  /*Displaced fracture of right tibial tuberosity, subsequent encounter for closed fracture with nonunion*/
,'S82151M'  /*Displaced fracture of right tibial tuberosity, subsequent encounter for open fracture type I or II with nonunion*/
,'S82151N'  /*Displaced fracture of right tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82151P'  /*Displaced fracture of right tibial tuberosity, subsequent encounter for closed fracture with malunion*/
,'S82151Q'  /*Displaced fracture of right tibial tuberosity, subsequent encounter for open fracture type I or II with malunion*/
,'S82151R'  /*Displaced fracture of right tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82151S'  /*Displaced fracture of right tibial tuberosity, sequela*/
,'S82152D'  /*Displaced fracture of left tibial tuberosity, subsequent encounter for closed fracture with routine healing*/
,'S82152E'  /*Displaced fracture of left tibial tuberosity, subsequent encounter for open fracture type I or II with routine healing*/
,'S82152F'  /*Displaced fracture of left tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82152G'  /*Displaced fracture of left tibial tuberosity, subsequent encounter for closed fracture with delayed healing*/
,'S82152H'  /*Displaced fracture of left tibial tuberosity, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82152J'  /*Displaced fracture of left tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82152K'  /*Displaced fracture of left tibial tuberosity, subsequent encounter for closed fracture with nonunion*/
,'S82152M'  /*Displaced fracture of left tibial tuberosity, subsequent encounter for open fracture type I or II with nonunion*/
,'S82152N'  /*Displaced fracture of left tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82152P'  /*Displaced fracture of left tibial tuberosity, subsequent encounter for closed fracture with malunion*/
,'S82152Q'  /*Displaced fracture of left tibial tuberosity, subsequent encounter for open fracture type I or II with malunion*/
,'S82152R'  /*Displaced fracture of left tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82152S'  /*Displaced fracture of left tibial tuberosity, sequela*/
,'S82153D'  /*Displaced fracture of unspecified tibial tuberosity, subsequent encounter for closed fracture with routine healing*/
,'S82153E'  /*Displaced fracture of unspecified tibial tuberosity, subsequent encounter for open fracture type I or II with routine healing*/
,'S82153F'  /*Displaced fracture of unspecified tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82153G'  /*Displaced fracture of unspecified tibial tuberosity, subsequent encounter for closed fracture with delayed healing*/
,'S82153H'  /*Displaced fracture of unspecified tibial tuberosity, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82153J'  /*Displaced fracture of unspecified tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82153K'  /*Displaced fracture of unspecified tibial tuberosity, subsequent encounter for closed fracture with nonunion*/
,'S82153M'  /*Displaced fracture of unspecified tibial tuberosity, subsequent encounter for open fracture type I or II with nonunion*/
,'S82153N'  /*Displaced fracture of unspecified tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82153P'  /*Displaced fracture of unspecified tibial tuberosity, subsequent encounter for closed fracture with malunion*/
,'S82153Q'  /*Displaced fracture of unspecified tibial tuberosity, subsequent encounter for open fracture type I or II with malunion*/
,'S82153R'  /*Displaced fracture of unspecified tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82153S'  /*Displaced fracture of unspecified tibial tuberosity, sequela*/
,'S82154D'  /*Nondisplaced fracture of right tibial tuberosity, subsequent encounter for closed fracture with routine healing*/
,'S82154E'  /*Nondisplaced fracture of right tibial tuberosity, subsequent encounter for open fracture type I or II with routine healing*/
,'S82154F'  /*Nondisplaced fracture of right tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82154G'  /*Nondisplaced fracture of right tibial tuberosity, subsequent encounter for closed fracture with delayed healing*/
,'S82154H'  /*Nondisplaced fracture of right tibial tuberosity, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82154J'  /*Nondisplaced fracture of right tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82154K'  /*Nondisplaced fracture of right tibial tuberosity, subsequent encounter for closed fracture with nonunion*/
,'S82154M'  /*Nondisplaced fracture of right tibial tuberosity, subsequent encounter for open fracture type I or II with nonunion*/
,'S82154N'  /*Nondisplaced fracture of right tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82154P'  /*Nondisplaced fracture of right tibial tuberosity, subsequent encounter for closed fracture with malunion*/
,'S82154Q'  /*Nondisplaced fracture of right tibial tuberosity, subsequent encounter for open fracture type I or II with malunion*/
,'S82154R'  /*Nondisplaced fracture of right tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82154S'  /*Nondisplaced fracture of right tibial tuberosity, sequela*/
,'S82155D'  /*Nondisplaced fracture of left tibial tuberosity, subsequent encounter for closed fracture with routine healing*/
,'S82155E'  /*Nondisplaced fracture of left tibial tuberosity, subsequent encounter for open fracture type I or II with routine healing*/
,'S82155F'  /*Nondisplaced fracture of left tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82155G'  /*Nondisplaced fracture of left tibial tuberosity, subsequent encounter for closed fracture with delayed healing*/
,'S82155H'  /*Nondisplaced fracture of left tibial tuberosity, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82155J'  /*Nondisplaced fracture of left tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82155K'  /*Nondisplaced fracture of left tibial tuberosity, subsequent encounter for closed fracture with nonunion*/
,'S82155M'  /*Nondisplaced fracture of left tibial tuberosity, subsequent encounter for open fracture type I or II with nonunion*/
,'S82155N'  /*Nondisplaced fracture of left tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82155P'  /*Nondisplaced fracture of left tibial tuberosity, subsequent encounter for closed fracture with malunion*/
,'S82155Q'  /*Nondisplaced fracture of left tibial tuberosity, subsequent encounter for open fracture type I or II with malunion*/
,'S82155R'  /*Nondisplaced fracture of left tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82155S'  /*Nondisplaced fracture of left tibial tuberosity, sequela*/
,'S82156D'  /*Nondisplaced fracture of unspecified tibial tuberosity, subsequent encounter for closed fracture with routine healing*/
,'S82156E'  /*Nondisplaced fracture of unspecified tibial tuberosity, subsequent encounter for open fracture type I or II with routine healing*/
,'S82156F'  /*Nondisplaced fracture of unspecified tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82156G'  /*Nondisplaced fracture of unspecified tibial tuberosity, subsequent encounter for closed fracture with delayed healing*/
,'S82156H'  /*Nondisplaced fracture of unspecified tibial tuberosity, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82156J'  /*Nondisplaced fracture of unspecified tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82156K'  /*Nondisplaced fracture of unspecified tibial tuberosity, subsequent encounter for closed fracture with nonunion*/
,'S82156M'  /*Nondisplaced fracture of unspecified tibial tuberosity, subsequent encounter for open fracture type I or II with nonunion*/
,'S82156N'  /*Nondisplaced fracture of unspecified tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82156P'  /*Nondisplaced fracture of unspecified tibial tuberosity, subsequent encounter for closed fracture with malunion*/
,'S82156Q'  /*Nondisplaced fracture of unspecified tibial tuberosity, subsequent encounter for open fracture type I or II with malunion*/
,'S82156R'  /*Nondisplaced fracture of unspecified tibial tuberosity, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82156S'  /*Nondisplaced fracture of unspecified tibial tuberosity, sequela*/
,'S82161D'  /*Torus fracture of upper end of right tibia, subsequent encounter for fracture with routine healing*/
,'S82161G'  /*Torus fracture of upper end of right tibia, subsequent encounter for fracture with delayed healing*/
,'S82161K'  /*Torus fracture of upper end of right tibia, subsequent encounter for fracture with nonunion*/
,'S82161P'  /*Torus fracture of upper end of right tibia, subsequent encounter for fracture with malunion*/
,'S82161S'  /*Torus fracture of upper end of right tibia, sequela*/
,'S82162D'  /*Torus fracture of upper end of left tibia, subsequent encounter for fracture with routine healing*/
,'S82162G'  /*Torus fracture of upper end of left tibia, subsequent encounter for fracture with delayed healing*/
,'S82162K'  /*Torus fracture of upper end of left tibia, subsequent encounter for fracture with nonunion*/
,'S82162P'  /*Torus fracture of upper end of left tibia, subsequent encounter for fracture with malunion*/
,'S82162S'  /*Torus fracture of upper end of left tibia, sequela*/
,'S82169D'  /*Torus fracture of upper end of unspecified tibia, subsequent encounter for fracture with routine healing*/
,'S82169G'  /*Torus fracture of upper end of unspecified tibia, subsequent encounter for fracture with delayed healing*/
,'S82169K'  /*Torus fracture of upper end of unspecified tibia, subsequent encounter for fracture with nonunion*/
,'S82169P'  /*Torus fracture of upper end of unspecified tibia, subsequent encounter for fracture with malunion*/
,'S82169S'  /*Torus fracture of upper end of unspecified tibia, sequela*/
,'S82191D'  /*Other fracture of upper end of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82191E'  /*Other fracture of upper end of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82191F'  /*Other fracture of upper end of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82191G'  /*Other fracture of upper end of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82191H'  /*Other fracture of upper end of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82191J'  /*Other fracture of upper end of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82191K'  /*Other fracture of upper end of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82191M'  /*Other fracture of upper end of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82191N'  /*Other fracture of upper end of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82191P'  /*Other fracture of upper end of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82191Q'  /*Other fracture of upper end of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82191R'  /*Other fracture of upper end of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82191S'  /*Other fracture of upper end of right tibia, sequela*/
,'S82192D'  /*Other fracture of upper end of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82192E'  /*Other fracture of upper end of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82192F'  /*Other fracture of upper end of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82192G'  /*Other fracture of upper end of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82192H'  /*Other fracture of upper end of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82192J'  /*Other fracture of upper end of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82192K'  /*Other fracture of upper end of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82192M'  /*Other fracture of upper end of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82192N'  /*Other fracture of upper end of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82192P'  /*Other fracture of upper end of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82192Q'  /*Other fracture of upper end of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82192R'  /*Other fracture of upper end of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82192S'  /*Other fracture of upper end of left tibia, sequela*/
,'S82199D'  /*Other fracture of upper end of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82199E'  /*Other fracture of upper end of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82199F'  /*Other fracture of upper end of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82199G'  /*Other fracture of upper end of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82199H'  /*Other fracture of upper end of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82199J'  /*Other fracture of upper end of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82199K'  /*Other fracture of upper end of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82199M'  /*Other fracture of upper end of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82199N'  /*Other fracture of upper end of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82199P'  /*Other fracture of upper end of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82199Q'  /*Other fracture of upper end of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82199R'  /*Other fracture of upper end of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82199S'  /*Other fracture of upper end of unspecified tibia, sequela*/
,'S82201D'  /*Unspecified fracture of shaft of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82201E'  /*Unspecified fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82201F'  /*Unspecified fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82201G'  /*Unspecified fracture of shaft of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82201H'  /*Unspecified fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82201J'  /*Unspecified fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82201K'  /*Unspecified fracture of shaft of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82201M'  /*Unspecified fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82201N'  /*Unspecified fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82201P'  /*Unspecified fracture of shaft of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82201Q'  /*Unspecified fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82201R'  /*Unspecified fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82201S'  /*Unspecified fracture of shaft of right tibia, sequela*/
,'S82202D'  /*Unspecified fracture of shaft of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82202E'  /*Unspecified fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82202F'  /*Unspecified fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82202G'  /*Unspecified fracture of shaft of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82202H'  /*Unspecified fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82202J'  /*Unspecified fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82202K'  /*Unspecified fracture of shaft of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82202M'  /*Unspecified fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82202N'  /*Unspecified fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82202P'  /*Unspecified fracture of shaft of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82202Q'  /*Unspecified fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82202R'  /*Unspecified fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82202S'  /*Unspecified fracture of shaft of left tibia, sequela*/
,'S82209D'  /*Unspecified fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82209E'  /*Unspecified fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82209F'  /*Unspecified fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82209G'  /*Unspecified fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82209H'  /*Unspecified fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82209J'  /*Unspecified fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82209K'  /*Unspecified fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82209M'  /*Unspecified fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82209N'  /*Unspecified fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82209P'  /*Unspecified fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82209Q'  /*Unspecified fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82209R'  /*Unspecified fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82209S'  /*Unspecified fracture of shaft of unspecified tibia, sequela*/
,'S82221D'  /*Displaced transverse fracture of shaft of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82221E'  /*Displaced transverse fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82221F'  /*Displaced transverse fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82221G'  /*Displaced transverse fracture of shaft of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82221H'  /*Displaced transverse fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82221J'  /*Displaced transverse fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82221K'  /*Displaced transverse fracture of shaft of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82221M'  /*Displaced transverse fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82221N'  /*Displaced transverse fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82221P'  /*Displaced transverse fracture of shaft of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82221Q'  /*Displaced transverse fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82221R'  /*Displaced transverse fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82221S'  /*Displaced transverse fracture of shaft of right tibia, sequela*/
,'S82222D'  /*Displaced transverse fracture of shaft of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82222E'  /*Displaced transverse fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82222F'  /*Displaced transverse fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82222G'  /*Displaced transverse fracture of shaft of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82222H'  /*Displaced transverse fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82222J'  /*Displaced transverse fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82222K'  /*Displaced transverse fracture of shaft of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82222M'  /*Displaced transverse fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82222N'  /*Displaced transverse fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82222P'  /*Displaced transverse fracture of shaft of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82222Q'  /*Displaced transverse fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82222R'  /*Displaced transverse fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82222S'  /*Displaced transverse fracture of shaft of left tibia, sequela*/
,'S82223D'  /*Displaced transverse fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82223E'  /*Displaced transverse fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82223F'  /*Displaced transverse fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82223G'  /*Displaced transverse fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82223H'  /*Displaced transverse fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82223J'  /*Displaced transverse fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82223K'  /*Displaced transverse fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82223M'  /*Displaced transverse fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82223N'  /*Displaced transverse fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82223P'  /*Displaced transverse fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82223Q'  /*Displaced transverse fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82223R'  /*Displaced transverse fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82223S'  /*Displaced transverse fracture of shaft of unspecified tibia, sequela*/
,'S82224D'  /*Nondisplaced transverse fracture of shaft of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82224E'  /*Nondisplaced transverse fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82224F'  /*Nondisplaced transverse fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82224G'  /*Nondisplaced transverse fracture of shaft of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82224H'  /*Nondisplaced transverse fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82224J'  /*Nondisplaced transverse fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82224K'  /*Nondisplaced transverse fracture of shaft of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82224M'  /*Nondisplaced transverse fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82224N'  /*Nondisplaced transverse fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82224P'  /*Nondisplaced transverse fracture of shaft of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82224Q'  /*Nondisplaced transverse fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82224R'  /*Nondisplaced transverse fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82224S'  /*Nondisplaced transverse fracture of shaft of right tibia, sequela*/
,'S82225D'  /*Nondisplaced transverse fracture of shaft of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82225E'  /*Nondisplaced transverse fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82225F'  /*Nondisplaced transverse fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82225G'  /*Nondisplaced transverse fracture of shaft of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82225H'  /*Nondisplaced transverse fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82225J'  /*Nondisplaced transverse fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82225K'  /*Nondisplaced transverse fracture of shaft of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82225M'  /*Nondisplaced transverse fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82225N'  /*Nondisplaced transverse fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82225P'  /*Nondisplaced transverse fracture of shaft of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82225Q'  /*Nondisplaced transverse fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82225R'  /*Nondisplaced transverse fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82225S'  /*Nondisplaced transverse fracture of shaft of left tibia, sequela*/
,'S82226D'  /*Nondisplaced transverse fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82226E'  /*Nondisplaced transverse fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82226F'  /*Nondisplaced transverse fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82226G'  /*Nondisplaced transverse fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82226H'  /*Nondisplaced transverse fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82226J'  /*Nondisplaced transverse fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82226K'  /*Nondisplaced transverse fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82226M'  /*Nondisplaced transverse fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82226N'  /*Nondisplaced transverse fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82226P'  /*Nondisplaced transverse fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82226Q'  /*Nondisplaced transverse fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82226R'  /*Nondisplaced transverse fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82226S'  /*Nondisplaced transverse fracture of shaft of unspecified tibia, sequela*/
,'S82231D'  /*Displaced oblique fracture of shaft of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82231E'  /*Displaced oblique fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82231F'  /*Displaced oblique fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82231G'  /*Displaced oblique fracture of shaft of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82231H'  /*Displaced oblique fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82231J'  /*Displaced oblique fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82231K'  /*Displaced oblique fracture of shaft of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82231M'  /*Displaced oblique fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82231N'  /*Displaced oblique fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82231P'  /*Displaced oblique fracture of shaft of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82231Q'  /*Displaced oblique fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82231R'  /*Displaced oblique fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82231S'  /*Displaced oblique fracture of shaft of right tibia, sequela*/
,'S82232D'  /*Displaced oblique fracture of shaft of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82232E'  /*Displaced oblique fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82232F'  /*Displaced oblique fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82232G'  /*Displaced oblique fracture of shaft of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82232H'  /*Displaced oblique fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82232J'  /*Displaced oblique fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82232K'  /*Displaced oblique fracture of shaft of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82232M'  /*Displaced oblique fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82232N'  /*Displaced oblique fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82232P'  /*Displaced oblique fracture of shaft of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82232Q'  /*Displaced oblique fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82232R'  /*Displaced oblique fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82232S'  /*Displaced oblique fracture of shaft of left tibia, sequela*/
,'S82233D'  /*Displaced oblique fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82233E'  /*Displaced oblique fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82233F'  /*Displaced oblique fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82233G'  /*Displaced oblique fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82233H'  /*Displaced oblique fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82233J'  /*Displaced oblique fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82233K'  /*Displaced oblique fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82233M'  /*Displaced oblique fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82233N'  /*Displaced oblique fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82233P'  /*Displaced oblique fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82233Q'  /*Displaced oblique fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82233R'  /*Displaced oblique fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82233S'  /*Displaced oblique fracture of shaft of unspecified tibia, sequela*/
,'S82234D'  /*Nondisplaced oblique fracture of shaft of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82234E'  /*Nondisplaced oblique fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82234F'  /*Nondisplaced oblique fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82234G'  /*Nondisplaced oblique fracture of shaft of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82234H'  /*Nondisplaced oblique fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82234J'  /*Nondisplaced oblique fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82234K'  /*Nondisplaced oblique fracture of shaft of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82234M'  /*Nondisplaced oblique fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82234N'  /*Nondisplaced oblique fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82234P'  /*Nondisplaced oblique fracture of shaft of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82234Q'  /*Nondisplaced oblique fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82234R'  /*Nondisplaced oblique fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82234S'  /*Nondisplaced oblique fracture of shaft of right tibia, sequela*/
,'S82235D'  /*Nondisplaced oblique fracture of shaft of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82235E'  /*Nondisplaced oblique fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82235F'  /*Nondisplaced oblique fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82235G'  /*Nondisplaced oblique fracture of shaft of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82235H'  /*Nondisplaced oblique fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82235J'  /*Nondisplaced oblique fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82235K'  /*Nondisplaced oblique fracture of shaft of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82235M'  /*Nondisplaced oblique fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82235N'  /*Nondisplaced oblique fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82235P'  /*Nondisplaced oblique fracture of shaft of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82235Q'  /*Nondisplaced oblique fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82235R'  /*Nondisplaced oblique fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82235S'  /*Nondisplaced oblique fracture of shaft of left tibia, sequela*/
,'S82236D'  /*Nondisplaced oblique fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82236E'  /*Nondisplaced oblique fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82236F'  /*Nondisplaced oblique fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82236G'  /*Nondisplaced oblique fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82236H'  /*Nondisplaced oblique fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82236J'  /*Nondisplaced oblique fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82236K'  /*Nondisplaced oblique fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82236M'  /*Nondisplaced oblique fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82236N'  /*Nondisplaced oblique fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82236P'  /*Nondisplaced oblique fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82236Q'  /*Nondisplaced oblique fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82236R'  /*Nondisplaced oblique fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82236S'  /*Nondisplaced oblique fracture of shaft of unspecified tibia, sequela*/
,'S82241D'  /*Displaced spiral fracture of shaft of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82241E'  /*Displaced spiral fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82241F'  /*Displaced spiral fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82241G'  /*Displaced spiral fracture of shaft of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82241H'  /*Displaced spiral fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82241J'  /*Displaced spiral fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82241K'  /*Displaced spiral fracture of shaft of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82241M'  /*Displaced spiral fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82241N'  /*Displaced spiral fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82241P'  /*Displaced spiral fracture of shaft of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82241Q'  /*Displaced spiral fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82241R'  /*Displaced spiral fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82241S'  /*Displaced spiral fracture of shaft of right tibia, sequela*/
,'S82242D'  /*Displaced spiral fracture of shaft of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82242E'  /*Displaced spiral fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82242F'  /*Displaced spiral fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82242G'  /*Displaced spiral fracture of shaft of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82242H'  /*Displaced spiral fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82242J'  /*Displaced spiral fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82242K'  /*Displaced spiral fracture of shaft of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82242M'  /*Displaced spiral fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82242N'  /*Displaced spiral fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82242P'  /*Displaced spiral fracture of shaft of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82242Q'  /*Displaced spiral fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82242R'  /*Displaced spiral fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82242S'  /*Displaced spiral fracture of shaft of left tibia, sequela*/
,'S82243D'  /*Displaced spiral fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82243E'  /*Displaced spiral fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82243F'  /*Displaced spiral fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82243G'  /*Displaced spiral fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82243H'  /*Displaced spiral fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82243J'  /*Displaced spiral fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82243K'  /*Displaced spiral fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82243M'  /*Displaced spiral fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82243N'  /*Displaced spiral fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82243P'  /*Displaced spiral fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82243Q'  /*Displaced spiral fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82243R'  /*Displaced spiral fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82243S'  /*Displaced spiral fracture of shaft of unspecified tibia, sequela*/
,'S82244D'  /*Nondisplaced spiral fracture of shaft of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82244E'  /*Nondisplaced spiral fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82244F'  /*Nondisplaced spiral fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82244G'  /*Nondisplaced spiral fracture of shaft of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82244H'  /*Nondisplaced spiral fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82244J'  /*Nondisplaced spiral fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82244K'  /*Nondisplaced spiral fracture of shaft of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82244M'  /*Nondisplaced spiral fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82244N'  /*Nondisplaced spiral fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82244P'  /*Nondisplaced spiral fracture of shaft of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82244Q'  /*Nondisplaced spiral fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82244R'  /*Nondisplaced spiral fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82244S'  /*Nondisplaced spiral fracture of shaft of right tibia, sequela*/
,'S82245D'  /*Nondisplaced spiral fracture of shaft of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82245E'  /*Nondisplaced spiral fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82245F'  /*Nondisplaced spiral fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82245G'  /*Nondisplaced spiral fracture of shaft of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82245H'  /*Nondisplaced spiral fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82245J'  /*Nondisplaced spiral fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82245K'  /*Nondisplaced spiral fracture of shaft of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82245M'  /*Nondisplaced spiral fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82245N'  /*Nondisplaced spiral fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82245P'  /*Nondisplaced spiral fracture of shaft of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82245Q'  /*Nondisplaced spiral fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82245R'  /*Nondisplaced spiral fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82245S'  /*Nondisplaced spiral fracture of shaft of left tibia, sequela*/
,'S82246D'  /*Nondisplaced spiral fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82246E'  /*Nondisplaced spiral fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82246F'  /*Nondisplaced spiral fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82246G'  /*Nondisplaced spiral fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82246H'  /*Nondisplaced spiral fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82246J'  /*Nondisplaced spiral fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82246K'  /*Nondisplaced spiral fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82246M'  /*Nondisplaced spiral fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82246N'  /*Nondisplaced spiral fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82246P'  /*Nondisplaced spiral fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82246Q'  /*Nondisplaced spiral fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82246R'  /*Nondisplaced spiral fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82246S'  /*Nondisplaced spiral fracture of shaft of unspecified tibia, sequela*/
,'S82251D'  /*Displaced comminuted fracture of shaft of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82251E'  /*Displaced comminuted fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82251F'  /*Displaced comminuted fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82251G'  /*Displaced comminuted fracture of shaft of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82251H'  /*Displaced comminuted fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82251J'  /*Displaced comminuted fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82251K'  /*Displaced comminuted fracture of shaft of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82251M'  /*Displaced comminuted fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82251N'  /*Displaced comminuted fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82251P'  /*Displaced comminuted fracture of shaft of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82251Q'  /*Displaced comminuted fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82251R'  /*Displaced comminuted fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82251S'  /*Displaced comminuted fracture of shaft of right tibia, sequela*/
,'S82252D'  /*Displaced comminuted fracture of shaft of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82252E'  /*Displaced comminuted fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82252F'  /*Displaced comminuted fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82252G'  /*Displaced comminuted fracture of shaft of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82252H'  /*Displaced comminuted fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82252J'  /*Displaced comminuted fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82252K'  /*Displaced comminuted fracture of shaft of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82252M'  /*Displaced comminuted fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82252N'  /*Displaced comminuted fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82252P'  /*Displaced comminuted fracture of shaft of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82252Q'  /*Displaced comminuted fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82252R'  /*Displaced comminuted fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82252S'  /*Displaced comminuted fracture of shaft of left tibia, sequela*/
,'S82253D'  /*Displaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82253E'  /*Displaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82253F'  /*Displaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82253G'  /*Displaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82253H'  /*Displaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82253J'  /*Displaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82253K'  /*Displaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82253M'  /*Displaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82253N'  /*Displaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82253P'  /*Displaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82253Q'  /*Displaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82253R'  /*Displaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82253S'  /*Displaced comminuted fracture of shaft of unspecified tibia, sequela*/
,'S82254D'  /*Nondisplaced comminuted fracture of shaft of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82254E'  /*Nondisplaced comminuted fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82254F'  /*Nondisplaced comminuted fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82254G'  /*Nondisplaced comminuted fracture of shaft of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82254H'  /*Nondisplaced comminuted fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82254J'  /*Nondisplaced comminuted fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82254K'  /*Nondisplaced comminuted fracture of shaft of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82254M'  /*Nondisplaced comminuted fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82254N'  /*Nondisplaced comminuted fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82254P'  /*Nondisplaced comminuted fracture of shaft of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82254Q'  /*Nondisplaced comminuted fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82254R'  /*Nondisplaced comminuted fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82254S'  /*Nondisplaced comminuted fracture of shaft of right tibia, sequela*/
,'S82255D'  /*Nondisplaced comminuted fracture of shaft of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82255E'  /*Nondisplaced comminuted fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82255F'  /*Nondisplaced comminuted fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82255G'  /*Nondisplaced comminuted fracture of shaft of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82255H'  /*Nondisplaced comminuted fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82255J'  /*Nondisplaced comminuted fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82255K'  /*Nondisplaced comminuted fracture of shaft of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82255M'  /*Nondisplaced comminuted fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82255N'  /*Nondisplaced comminuted fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82255P'  /*Nondisplaced comminuted fracture of shaft of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82255Q'  /*Nondisplaced comminuted fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82255R'  /*Nondisplaced comminuted fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82255S'  /*Nondisplaced comminuted fracture of shaft of left tibia, sequela*/
,'S82256D'  /*Nondisplaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82256E'  /*Nondisplaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82256F'  /*Nondisplaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82256G'  /*Nondisplaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82256H'  /*Nondisplaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82256J'  /*Nondisplaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82256K'  /*Nondisplaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82256M'  /*Nondisplaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82256N'  /*Nondisplaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82256P'  /*Nondisplaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82256Q'  /*Nondisplaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82256R'  /*Nondisplaced comminuted fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82256S'  /*Nondisplaced comminuted fracture of shaft of unspecified tibia, sequela*/
,'S82261D'  /*Displaced segmental fracture of shaft of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82261E'  /*Displaced segmental fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82261F'  /*Displaced segmental fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82261G'  /*Displaced segmental fracture of shaft of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82261H'  /*Displaced segmental fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82261J'  /*Displaced segmental fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82261K'  /*Displaced segmental fracture of shaft of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82261M'  /*Displaced segmental fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82261N'  /*Displaced segmental fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82261P'  /*Displaced segmental fracture of shaft of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82261Q'  /*Displaced segmental fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82261R'  /*Displaced segmental fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82261S'  /*Displaced segmental fracture of shaft of right tibia, sequela*/
,'S82262D'  /*Displaced segmental fracture of shaft of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82262E'  /*Displaced segmental fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82262F'  /*Displaced segmental fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82262G'  /*Displaced segmental fracture of shaft of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82262H'  /*Displaced segmental fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82262J'  /*Displaced segmental fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82262K'  /*Displaced segmental fracture of shaft of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82262M'  /*Displaced segmental fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82262N'  /*Displaced segmental fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82262P'  /*Displaced segmental fracture of shaft of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82262Q'  /*Displaced segmental fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82262R'  /*Displaced segmental fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82262S'  /*Displaced segmental fracture of shaft of left tibia, sequela*/
,'S82263D'  /*Displaced segmental fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82263E'  /*Displaced segmental fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82263F'  /*Displaced segmental fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82263G'  /*Displaced segmental fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82263H'  /*Displaced segmental fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82263J'  /*Displaced segmental fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82263K'  /*Displaced segmental fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82263M'  /*Displaced segmental fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82263N'  /*Displaced segmental fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82263P'  /*Displaced segmental fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82263Q'  /*Displaced segmental fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82263R'  /*Displaced segmental fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82263S'  /*Displaced segmental fracture of shaft of unspecified tibia, sequela*/
,'S82264D'  /*Nondisplaced segmental fracture of shaft of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82264E'  /*Nondisplaced segmental fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82264F'  /*Nondisplaced segmental fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82264G'  /*Nondisplaced segmental fracture of shaft of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82264H'  /*Nondisplaced segmental fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82264J'  /*Nondisplaced segmental fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82264K'  /*Nondisplaced segmental fracture of shaft of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82264M'  /*Nondisplaced segmental fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82264N'  /*Nondisplaced segmental fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82264P'  /*Nondisplaced segmental fracture of shaft of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82264Q'  /*Nondisplaced segmental fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82264R'  /*Nondisplaced segmental fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82264S'  /*Nondisplaced segmental fracture of shaft of right tibia, sequela*/
,'S82265D'  /*Nondisplaced segmental fracture of shaft of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82265E'  /*Nondisplaced segmental fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82265F'  /*Nondisplaced segmental fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82265G'  /*Nondisplaced segmental fracture of shaft of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82265H'  /*Nondisplaced segmental fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82265J'  /*Nondisplaced segmental fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82265K'  /*Nondisplaced segmental fracture of shaft of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82265M'  /*Nondisplaced segmental fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82265N'  /*Nondisplaced segmental fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82265P'  /*Nondisplaced segmental fracture of shaft of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82265Q'  /*Nondisplaced segmental fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82265R'  /*Nondisplaced segmental fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82265S'  /*Nondisplaced segmental fracture of shaft of left tibia, sequela*/
,'S82266D'  /*Nondisplaced segmental fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82266E'  /*Nondisplaced segmental fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82266F'  /*Nondisplaced segmental fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82266G'  /*Nondisplaced segmental fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82266H'  /*Nondisplaced segmental fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82266J'  /*Nondisplaced segmental fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82266K'  /*Nondisplaced segmental fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82266M'  /*Nondisplaced segmental fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82266N'  /*Nondisplaced segmental fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82266P'  /*Nondisplaced segmental fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82266Q'  /*Nondisplaced segmental fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82266R'  /*Nondisplaced segmental fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82266S'  /*Nondisplaced segmental fracture of shaft of unspecified tibia, sequela*/
,'S82291D'  /*Other fracture of shaft of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82291E'  /*Other fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82291F'  /*Other fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82291G'  /*Other fracture of shaft of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82291H'  /*Other fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82291J'  /*Other fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82291K'  /*Other fracture of shaft of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82291M'  /*Other fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82291N'  /*Other fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82291P'  /*Other fracture of shaft of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82291Q'  /*Other fracture of shaft of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82291R'  /*Other fracture of shaft of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82291S'  /*Other fracture of shaft of right tibia, sequela*/
,'S82292D'  /*Other fracture of shaft of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82292E'  /*Other fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82292F'  /*Other fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82292G'  /*Other fracture of shaft of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82292H'  /*Other fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82292J'  /*Other fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82292K'  /*Other fracture of shaft of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82292M'  /*Other fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82292N'  /*Other fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82292P'  /*Other fracture of shaft of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82292Q'  /*Other fracture of shaft of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82292R'  /*Other fracture of shaft of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82292S'  /*Other fracture of shaft of left tibia, sequela*/
,'S82299D'  /*Other fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82299E'  /*Other fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82299F'  /*Other fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82299G'  /*Other fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82299H'  /*Other fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82299J'  /*Other fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82299K'  /*Other fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82299M'  /*Other fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82299N'  /*Other fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82299P'  /*Other fracture of shaft of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82299Q'  /*Other fracture of shaft of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82299R'  /*Other fracture of shaft of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82299S'  /*Other fracture of shaft of unspecified tibia, sequela*/
,'S82301D'  /*Unspecified fracture of lower end of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82301E'  /*Unspecified fracture of lower end of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82301F'  /*Unspecified fracture of lower end of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82301G'  /*Unspecified fracture of lower end of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82301H'  /*Unspecified fracture of lower end of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82301J'  /*Unspecified fracture of lower end of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82301K'  /*Unspecified fracture of lower end of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82301M'  /*Unspecified fracture of lower end of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82301N'  /*Unspecified fracture of lower end of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82301P'  /*Unspecified fracture of lower end of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82301Q'  /*Unspecified fracture of lower end of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82301R'  /*Unspecified fracture of lower end of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82301S'  /*Unspecified fracture of lower end of right tibia, sequela*/
,'S82302D'  /*Unspecified fracture of lower end of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82302E'  /*Unspecified fracture of lower end of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82302F'  /*Unspecified fracture of lower end of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82302G'  /*Unspecified fracture of lower end of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82302H'  /*Unspecified fracture of lower end of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82302J'  /*Unspecified fracture of lower end of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82302K'  /*Unspecified fracture of lower end of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82302M'  /*Unspecified fracture of lower end of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82302N'  /*Unspecified fracture of lower end of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82302P'  /*Unspecified fracture of lower end of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82302Q'  /*Unspecified fracture of lower end of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82302R'  /*Unspecified fracture of lower end of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82302S'  /*Unspecified fracture of lower end of left tibia, sequela*/
,'S82309D'  /*Unspecified fracture of lower end of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82309E'  /*Unspecified fracture of lower end of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82309F'  /*Unspecified fracture of lower end of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82309G'  /*Unspecified fracture of lower end of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82309H'  /*Unspecified fracture of lower end of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82309J'  /*Unspecified fracture of lower end of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82309K'  /*Unspecified fracture of lower end of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82309M'  /*Unspecified fracture of lower end of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82309N'  /*Unspecified fracture of lower end of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82309P'  /*Unspecified fracture of lower end of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82309Q'  /*Unspecified fracture of lower end of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82309R'  /*Unspecified fracture of lower end of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82309S'  /*Unspecified fracture of lower end of unspecified tibia, sequela*/
,'S82311D'  /*Torus fracture of lower end of right tibia, subsequent encounter for fracture with routine healing*/
,'S82311G'  /*Torus fracture of lower end of right tibia, subsequent encounter for fracture with delayed healing*/
,'S82311K'  /*Torus fracture of lower end of right tibia, subsequent encounter for fracture with nonunion*/
,'S82311P'  /*Torus fracture of lower end of right tibia, subsequent encounter for fracture with malunion*/
,'S82311S'  /*Torus fracture of lower end of right tibia, sequela*/
,'S82312D'  /*Torus fracture of lower end of left tibia, subsequent encounter for fracture with routine healing*/
,'S82312G'  /*Torus fracture of lower end of left tibia, subsequent encounter for fracture with delayed healing*/
,'S82312K'  /*Torus fracture of lower end of left tibia, subsequent encounter for fracture with nonunion*/
,'S82312P'  /*Torus fracture of lower end of left tibia, subsequent encounter for fracture with malunion*/
,'S82312S'  /*Torus fracture of lower end of left tibia, sequela*/
,'S82319D'  /*Torus fracture of lower end of unspecified tibia, subsequent encounter for fracture with routine healing*/
,'S82319G'  /*Torus fracture of lower end of unspecified tibia, subsequent encounter for fracture with delayed healing*/
,'S82319K'  /*Torus fracture of lower end of unspecified tibia, subsequent encounter for fracture with nonunion*/
,'S82319P'  /*Torus fracture of lower end of unspecified tibia, subsequent encounter for fracture with malunion*/
,'S82319S'  /*Torus fracture of lower end of unspecified tibia, sequela*/
,'S82391D'  /*Other fracture of lower end of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82391E'  /*Other fracture of lower end of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82391F'  /*Other fracture of lower end of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82391G'  /*Other fracture of lower end of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82391H'  /*Other fracture of lower end of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82391J'  /*Other fracture of lower end of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82391K'  /*Other fracture of lower end of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82391M'  /*Other fracture of lower end of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82391N'  /*Other fracture of lower end of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82391P'  /*Other fracture of lower end of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82391Q'  /*Other fracture of lower end of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82391R'  /*Other fracture of lower end of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82391S'  /*Other fracture of lower end of right tibia, sequela*/
,'S82392D'  /*Other fracture of lower end of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82392E'  /*Other fracture of lower end of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82392F'  /*Other fracture of lower end of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82392G'  /*Other fracture of lower end of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82392H'  /*Other fracture of lower end of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82392J'  /*Other fracture of lower end of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82392K'  /*Other fracture of lower end of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82392M'  /*Other fracture of lower end of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82392N'  /*Other fracture of lower end of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82392P'  /*Other fracture of lower end of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82392Q'  /*Other fracture of lower end of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82392R'  /*Other fracture of lower end of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82392S'  /*Other fracture of lower end of left tibia, sequela*/
,'S82399D'  /*Other fracture of lower end of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82399E'  /*Other fracture of lower end of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82399F'  /*Other fracture of lower end of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82399G'  /*Other fracture of lower end of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82399H'  /*Other fracture of lower end of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82399J'  /*Other fracture of lower end of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82399K'  /*Other fracture of lower end of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82399M'  /*Other fracture of lower end of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82399N'  /*Other fracture of lower end of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82399P'  /*Other fracture of lower end of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82399Q'  /*Other fracture of lower end of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82399R'  /*Other fracture of lower end of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82399S'  /*Other fracture of lower end of unspecified tibia, sequela*/
,'S82401D'  /*Unspecified fracture of shaft of right fibula, subsequent encounter for closed fracture with routine healing*/
,'S82401E'  /*Unspecified fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82401F'  /*Unspecified fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82401G'  /*Unspecified fracture of shaft of right fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82401H'  /*Unspecified fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82401J'  /*Unspecified fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82401K'  /*Unspecified fracture of shaft of right fibula, subsequent encounter for closed fracture with nonunion*/
,'S82401M'  /*Unspecified fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82401N'  /*Unspecified fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82401P'  /*Unspecified fracture of shaft of right fibula, subsequent encounter for closed fracture with malunion*/
,'S82401Q'  /*Unspecified fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82401R'  /*Unspecified fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82401S'  /*Unspecified fracture of shaft of right fibula, sequela*/
,'S82402D'  /*Unspecified fracture of shaft of left fibula, subsequent encounter for closed fracture with routine healing*/
,'S82402E'  /*Unspecified fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82402F'  /*Unspecified fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82402G'  /*Unspecified fracture of shaft of left fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82402H'  /*Unspecified fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82402J'  /*Unspecified fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82402K'  /*Unspecified fracture of shaft of left fibula, subsequent encounter for closed fracture with nonunion*/
,'S82402M'  /*Unspecified fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82402N'  /*Unspecified fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82402P'  /*Unspecified fracture of shaft of left fibula, subsequent encounter for closed fracture with malunion*/
,'S82402Q'  /*Unspecified fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82402R'  /*Unspecified fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82402S'  /*Unspecified fracture of shaft of left fibula, sequela*/
,'S82409D'  /*Unspecified fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with routine healing*/
,'S82409E'  /*Unspecified fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82409F'  /*Unspecified fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82409G'  /*Unspecified fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82409H'  /*Unspecified fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82409J'  /*Unspecified fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82409K'  /*Unspecified fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with nonunion*/
,'S82409M'  /*Unspecified fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82409N'  /*Unspecified fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82409P'  /*Unspecified fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with malunion*/
,'S82409Q'  /*Unspecified fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82409R'  /*Unspecified fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82409S'  /*Unspecified fracture of shaft of unspecified fibula, sequela*/
,'S82421D'  /*Displaced transverse fracture of shaft of right fibula, subsequent encounter for closed fracture with routine healing*/
,'S82421E'  /*Displaced transverse fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82421F'  /*Displaced transverse fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82421G'  /*Displaced transverse fracture of shaft of right fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82421H'  /*Displaced transverse fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82421J'  /*Displaced transverse fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82421K'  /*Displaced transverse fracture of shaft of right fibula, subsequent encounter for closed fracture with nonunion*/
,'S82421M'  /*Displaced transverse fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82421N'  /*Displaced transverse fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82421P'  /*Displaced transverse fracture of shaft of right fibula, subsequent encounter for closed fracture with malunion*/
,'S82421Q'  /*Displaced transverse fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82421R'  /*Displaced transverse fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82421S'  /*Displaced transverse fracture of shaft of right fibula, sequela*/
,'S82422D'  /*Displaced transverse fracture of shaft of left fibula, subsequent encounter for closed fracture with routine healing*/
,'S82422E'  /*Displaced transverse fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82422F'  /*Displaced transverse fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82422G'  /*Displaced transverse fracture of shaft of left fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82422H'  /*Displaced transverse fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82422J'  /*Displaced transverse fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82422K'  /*Displaced transverse fracture of shaft of left fibula, subsequent encounter for closed fracture with nonunion*/
,'S82422M'  /*Displaced transverse fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82422N'  /*Displaced transverse fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82422P'  /*Displaced transverse fracture of shaft of left fibula, subsequent encounter for closed fracture with malunion*/
,'S82422Q'  /*Displaced transverse fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82422R'  /*Displaced transverse fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82422S'  /*Displaced transverse fracture of shaft of left fibula, sequela*/
,'S82423D'  /*Displaced transverse fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with routine healing*/
,'S82423E'  /*Displaced transverse fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82423F'  /*Displaced transverse fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82423G'  /*Displaced transverse fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82423H'  /*Displaced transverse fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82423J'  /*Displaced transverse fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82423K'  /*Displaced transverse fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with nonunion*/
,'S82423M'  /*Displaced transverse fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82423N'  /*Displaced transverse fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82423P'  /*Displaced transverse fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with malunion*/
,'S82423Q'  /*Displaced transverse fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82423R'  /*Displaced transverse fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82423S'  /*Displaced transverse fracture of shaft of unspecified fibula, sequela*/
,'S82424D'  /*Nondisplaced transverse fracture of shaft of right fibula, subsequent encounter for closed fracture with routine healing*/
,'S82424E'  /*Nondisplaced transverse fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82424F'  /*Nondisplaced transverse fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82424G'  /*Nondisplaced transverse fracture of shaft of right fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82424H'  /*Nondisplaced transverse fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82424J'  /*Nondisplaced transverse fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82424K'  /*Nondisplaced transverse fracture of shaft of right fibula, subsequent encounter for closed fracture with nonunion*/
,'S82424M'  /*Nondisplaced transverse fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82424N'  /*Nondisplaced transverse fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82424P'  /*Nondisplaced transverse fracture of shaft of right fibula, subsequent encounter for closed fracture with malunion*/
,'S82424Q'  /*Nondisplaced transverse fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82424R'  /*Nondisplaced transverse fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82424S'  /*Nondisplaced transverse fracture of shaft of right fibula, sequela*/
,'S82425D'  /*Nondisplaced transverse fracture of shaft of left fibula, subsequent encounter for closed fracture with routine healing*/
,'S82425E'  /*Nondisplaced transverse fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82425F'  /*Nondisplaced transverse fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82425G'  /*Nondisplaced transverse fracture of shaft of left fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82425H'  /*Nondisplaced transverse fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82425J'  /*Nondisplaced transverse fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82425K'  /*Nondisplaced transverse fracture of shaft of left fibula, subsequent encounter for closed fracture with nonunion*/
,'S82425M'  /*Nondisplaced transverse fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82425N'  /*Nondisplaced transverse fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82425P'  /*Nondisplaced transverse fracture of shaft of left fibula, subsequent encounter for closed fracture with malunion*/
,'S82425Q'  /*Nondisplaced transverse fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82425R'  /*Nondisplaced transverse fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82425S'  /*Nondisplaced transverse fracture of shaft of left fibula, sequela*/
,'S82426D'  /*Nondisplaced transverse fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with routine healing*/
,'S82426E'  /*Nondisplaced transverse fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82426F'  /*Nondisplaced transverse fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82426G'  /*Nondisplaced transverse fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82426H'  /*Nondisplaced transverse fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82426J'  /*Nondisplaced transverse fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82426K'  /*Nondisplaced transverse fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with nonunion*/
,'S82426M'  /*Nondisplaced transverse fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82426N'  /*Nondisplaced transverse fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82426P'  /*Nondisplaced transverse fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with malunion*/
,'S82426Q'  /*Nondisplaced transverse fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82426R'  /*Nondisplaced transverse fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82426S'  /*Nondisplaced transverse fracture of shaft of unspecified fibula, sequela*/
,'S82431D'  /*Displaced oblique fracture of shaft of right fibula, subsequent encounter for closed fracture with routine healing*/
,'S82431E'  /*Displaced oblique fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82431F'  /*Displaced oblique fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82431G'  /*Displaced oblique fracture of shaft of right fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82431H'  /*Displaced oblique fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82431J'  /*Displaced oblique fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82431K'  /*Displaced oblique fracture of shaft of right fibula, subsequent encounter for closed fracture with nonunion*/
,'S82431M'  /*Displaced oblique fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82431N'  /*Displaced oblique fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82431P'  /*Displaced oblique fracture of shaft of right fibula, subsequent encounter for closed fracture with malunion*/
,'S82431Q'  /*Displaced oblique fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82431R'  /*Displaced oblique fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82431S'  /*Displaced oblique fracture of shaft of right fibula, sequela*/
,'S82432D'  /*Displaced oblique fracture of shaft of left fibula, subsequent encounter for closed fracture with routine healing*/
,'S82432E'  /*Displaced oblique fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82432F'  /*Displaced oblique fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82432G'  /*Displaced oblique fracture of shaft of left fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82432H'  /*Displaced oblique fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82432J'  /*Displaced oblique fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82432K'  /*Displaced oblique fracture of shaft of left fibula, subsequent encounter for closed fracture with nonunion*/
,'S82432M'  /*Displaced oblique fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82432N'  /*Displaced oblique fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82432P'  /*Displaced oblique fracture of shaft of left fibula, subsequent encounter for closed fracture with malunion*/
,'S82432Q'  /*Displaced oblique fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82432R'  /*Displaced oblique fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82432S'  /*Displaced oblique fracture of shaft of left fibula, sequela*/
,'S82433D'  /*Displaced oblique fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with routine healing*/
,'S82433E'  /*Displaced oblique fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82433F'  /*Displaced oblique fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82433G'  /*Displaced oblique fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82433H'  /*Displaced oblique fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82433J'  /*Displaced oblique fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82433K'  /*Displaced oblique fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with nonunion*/
,'S82433M'  /*Displaced oblique fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82433N'  /*Displaced oblique fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82433P'  /*Displaced oblique fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with malunion*/
,'S82433Q'  /*Displaced oblique fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82433R'  /*Displaced oblique fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82433S'  /*Displaced oblique fracture of shaft of unspecified fibula, sequela*/
,'S82434D'  /*Nondisplaced oblique fracture of shaft of right fibula, subsequent encounter for closed fracture with routine healing*/
,'S82434E'  /*Nondisplaced oblique fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82434F'  /*Nondisplaced oblique fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82434G'  /*Nondisplaced oblique fracture of shaft of right fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82434H'  /*Nondisplaced oblique fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82434J'  /*Nondisplaced oblique fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82434K'  /*Nondisplaced oblique fracture of shaft of right fibula, subsequent encounter for closed fracture with nonunion*/
,'S82434M'  /*Nondisplaced oblique fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82434N'  /*Nondisplaced oblique fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82434P'  /*Nondisplaced oblique fracture of shaft of right fibula, subsequent encounter for closed fracture with malunion*/
,'S82434Q'  /*Nondisplaced oblique fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82434R'  /*Nondisplaced oblique fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82434S'  /*Nondisplaced oblique fracture of shaft of right fibula, sequela*/
,'S82435D'  /*Nondisplaced oblique fracture of shaft of left fibula, subsequent encounter for closed fracture with routine healing*/
,'S82435E'  /*Nondisplaced oblique fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82435F'  /*Nondisplaced oblique fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82435G'  /*Nondisplaced oblique fracture of shaft of left fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82435H'  /*Nondisplaced oblique fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82435J'  /*Nondisplaced oblique fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82435K'  /*Nondisplaced oblique fracture of shaft of left fibula, subsequent encounter for closed fracture with nonunion*/
,'S82435M'  /*Nondisplaced oblique fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82435N'  /*Nondisplaced oblique fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82435P'  /*Nondisplaced oblique fracture of shaft of left fibula, subsequent encounter for closed fracture with malunion*/
,'S82435Q'  /*Nondisplaced oblique fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82435R'  /*Nondisplaced oblique fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82435S'  /*Nondisplaced oblique fracture of shaft of left fibula, sequela*/
,'S82436D'  /*Nondisplaced oblique fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with routine healing*/
,'S82436E'  /*Nondisplaced oblique fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82436F'  /*Nondisplaced oblique fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82436G'  /*Nondisplaced oblique fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82436H'  /*Nondisplaced oblique fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82436J'  /*Nondisplaced oblique fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82436K'  /*Nondisplaced oblique fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with nonunion*/
,'S82436M'  /*Nondisplaced oblique fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82436N'  /*Nondisplaced oblique fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82436P'  /*Nondisplaced oblique fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with malunion*/
,'S82436Q'  /*Nondisplaced oblique fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82436R'  /*Nondisplaced oblique fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82436S'  /*Nondisplaced oblique fracture of shaft of unspecified fibula, sequela*/
,'S82441D'  /*Displaced spiral fracture of shaft of right fibula, subsequent encounter for closed fracture with routine healing*/
,'S82441E'  /*Displaced spiral fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82441F'  /*Displaced spiral fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82441G'  /*Displaced spiral fracture of shaft of right fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82441H'  /*Displaced spiral fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82441J'  /*Displaced spiral fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82441K'  /*Displaced spiral fracture of shaft of right fibula, subsequent encounter for closed fracture with nonunion*/
,'S82441M'  /*Displaced spiral fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82441N'  /*Displaced spiral fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82441P'  /*Displaced spiral fracture of shaft of right fibula, subsequent encounter for closed fracture with malunion*/
,'S82441Q'  /*Displaced spiral fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82441R'  /*Displaced spiral fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82441S'  /*Displaced spiral fracture of shaft of right fibula, sequela*/
,'S82442D'  /*Displaced spiral fracture of shaft of left fibula, subsequent encounter for closed fracture with routine healing*/
,'S82442E'  /*Displaced spiral fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82442F'  /*Displaced spiral fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82442G'  /*Displaced spiral fracture of shaft of left fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82442H'  /*Displaced spiral fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82442J'  /*Displaced spiral fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82442K'  /*Displaced spiral fracture of shaft of left fibula, subsequent encounter for closed fracture with nonunion*/
,'S82442M'  /*Displaced spiral fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82442N'  /*Displaced spiral fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82442P'  /*Displaced spiral fracture of shaft of left fibula, subsequent encounter for closed fracture with malunion*/
,'S82442Q'  /*Displaced spiral fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82442R'  /*Displaced spiral fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82442S'  /*Displaced spiral fracture of shaft of left fibula, sequela*/
,'S82443D'  /*Displaced spiral fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with routine healing*/
,'S82443E'  /*Displaced spiral fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82443F'  /*Displaced spiral fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82443G'  /*Displaced spiral fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82443H'  /*Displaced spiral fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82443J'  /*Displaced spiral fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82443K'  /*Displaced spiral fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with nonunion*/
,'S82443M'  /*Displaced spiral fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82443N'  /*Displaced spiral fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82443P'  /*Displaced spiral fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with malunion*/
,'S82443Q'  /*Displaced spiral fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82443R'  /*Displaced spiral fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82443S'  /*Displaced spiral fracture of shaft of unspecified fibula, sequela*/
,'S82444D'  /*Nondisplaced spiral fracture of shaft of right fibula, subsequent encounter for closed fracture with routine healing*/
,'S82444E'  /*Nondisplaced spiral fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82444F'  /*Nondisplaced spiral fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82444G'  /*Nondisplaced spiral fracture of shaft of right fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82444H'  /*Nondisplaced spiral fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82444J'  /*Nondisplaced spiral fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82444K'  /*Nondisplaced spiral fracture of shaft of right fibula, subsequent encounter for closed fracture with nonunion*/
,'S82444M'  /*Nondisplaced spiral fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82444N'  /*Nondisplaced spiral fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82444P'  /*Nondisplaced spiral fracture of shaft of right fibula, subsequent encounter for closed fracture with malunion*/
,'S82444Q'  /*Nondisplaced spiral fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82444R'  /*Nondisplaced spiral fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82444S'  /*Nondisplaced spiral fracture of shaft of right fibula, sequela*/
,'S82445D'  /*Nondisplaced spiral fracture of shaft of left fibula, subsequent encounter for closed fracture with routine healing*/
,'S82445E'  /*Nondisplaced spiral fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82445F'  /*Nondisplaced spiral fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82445G'  /*Nondisplaced spiral fracture of shaft of left fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82445H'  /*Nondisplaced spiral fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82445J'  /*Nondisplaced spiral fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82445K'  /*Nondisplaced spiral fracture of shaft of left fibula, subsequent encounter for closed fracture with nonunion*/
,'S82445M'  /*Nondisplaced spiral fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82445N'  /*Nondisplaced spiral fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82445P'  /*Nondisplaced spiral fracture of shaft of left fibula, subsequent encounter for closed fracture with malunion*/
,'S82445Q'  /*Nondisplaced spiral fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82445R'  /*Nondisplaced spiral fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82445S'  /*Nondisplaced spiral fracture of shaft of left fibula, sequela*/
,'S82446D'  /*Nondisplaced spiral fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with routine healing*/
,'S82446E'  /*Nondisplaced spiral fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82446F'  /*Nondisplaced spiral fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82446G'  /*Nondisplaced spiral fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82446H'  /*Nondisplaced spiral fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82446J'  /*Nondisplaced spiral fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82446K'  /*Nondisplaced spiral fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with nonunion*/
,'S82446M'  /*Nondisplaced spiral fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82446N'  /*Nondisplaced spiral fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82446P'  /*Nondisplaced spiral fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with malunion*/
,'S82446Q'  /*Nondisplaced spiral fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82446R'  /*Nondisplaced spiral fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82446S'  /*Nondisplaced spiral fracture of shaft of unspecified fibula, sequela*/
,'S82451D'  /*Displaced comminuted fracture of shaft of right fibula, subsequent encounter for closed fracture with routine healing*/
,'S82451E'  /*Displaced comminuted fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82451F'  /*Displaced comminuted fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82451G'  /*Displaced comminuted fracture of shaft of right fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82451H'  /*Displaced comminuted fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82451J'  /*Displaced comminuted fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82451K'  /*Displaced comminuted fracture of shaft of right fibula, subsequent encounter for closed fracture with nonunion*/
,'S82451M'  /*Displaced comminuted fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82451N'  /*Displaced comminuted fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82451P'  /*Displaced comminuted fracture of shaft of right fibula, subsequent encounter for closed fracture with malunion*/
,'S82451Q'  /*Displaced comminuted fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82451R'  /*Displaced comminuted fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82451S'  /*Displaced comminuted fracture of shaft of right fibula, sequela*/
,'S82452D'  /*Displaced comminuted fracture of shaft of left fibula, subsequent encounter for closed fracture with routine healing*/
,'S82452E'  /*Displaced comminuted fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82452F'  /*Displaced comminuted fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82452G'  /*Displaced comminuted fracture of shaft of left fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82452H'  /*Displaced comminuted fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82452J'  /*Displaced comminuted fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82452K'  /*Displaced comminuted fracture of shaft of left fibula, subsequent encounter for closed fracture with nonunion*/
,'S82452M'  /*Displaced comminuted fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82452N'  /*Displaced comminuted fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82452P'  /*Displaced comminuted fracture of shaft of left fibula, subsequent encounter for closed fracture with malunion*/
,'S82452Q'  /*Displaced comminuted fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82452R'  /*Displaced comminuted fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82452S'  /*Displaced comminuted fracture of shaft of left fibula, sequela*/
,'S82453D'  /*Displaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with routine healing*/
,'S82453E'  /*Displaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82453F'  /*Displaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82453G'  /*Displaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82453H'  /*Displaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82453J'  /*Displaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82453K'  /*Displaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with nonunion*/
,'S82453M'  /*Displaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82453N'  /*Displaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82453P'  /*Displaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with malunion*/
,'S82453Q'  /*Displaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82453R'  /*Displaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82453S'  /*Displaced comminuted fracture of shaft of unspecified fibula, sequela*/
,'S82454D'  /*Nondisplaced comminuted fracture of shaft of right fibula, subsequent encounter for closed fracture with routine healing*/
,'S82454E'  /*Nondisplaced comminuted fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82454F'  /*Nondisplaced comminuted fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82454G'  /*Nondisplaced comminuted fracture of shaft of right fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82454H'  /*Nondisplaced comminuted fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82454J'  /*Nondisplaced comminuted fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82454K'  /*Nondisplaced comminuted fracture of shaft of right fibula, subsequent encounter for closed fracture with nonunion*/
,'S82454M'  /*Nondisplaced comminuted fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82454N'  /*Nondisplaced comminuted fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82454P'  /*Nondisplaced comminuted fracture of shaft of right fibula, subsequent encounter for closed fracture with malunion*/
,'S82454Q'  /*Nondisplaced comminuted fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82454R'  /*Nondisplaced comminuted fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82454S'  /*Nondisplaced comminuted fracture of shaft of right fibula, sequela*/
,'S82455D'  /*Nondisplaced comminuted fracture of shaft of left fibula, subsequent encounter for closed fracture with routine healing*/
,'S82455E'  /*Nondisplaced comminuted fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82455F'  /*Nondisplaced comminuted fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82455G'  /*Nondisplaced comminuted fracture of shaft of left fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82455H'  /*Nondisplaced comminuted fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82455J'  /*Nondisplaced comminuted fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82455K'  /*Nondisplaced comminuted fracture of shaft of left fibula, subsequent encounter for closed fracture with nonunion*/
,'S82455M'  /*Nondisplaced comminuted fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82455N'  /*Nondisplaced comminuted fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82455P'  /*Nondisplaced comminuted fracture of shaft of left fibula, subsequent encounter for closed fracture with malunion*/
,'S82455Q'  /*Nondisplaced comminuted fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82455R'  /*Nondisplaced comminuted fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82455S'  /*Nondisplaced comminuted fracture of shaft of left fibula, sequela*/
,'S82456D'  /*Nondisplaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with routine healing*/
,'S82456E'  /*Nondisplaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82456F'  /*Nondisplaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82456G'  /*Nondisplaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82456H'  /*Nondisplaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82456J'  /*Nondisplaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82456K'  /*Nondisplaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with nonunion*/
,'S82456M'  /*Nondisplaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82456N'  /*Nondisplaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82456P'  /*Nondisplaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with malunion*/
,'S82456Q'  /*Nondisplaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82456R'  /*Nondisplaced comminuted fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82456S'  /*Nondisplaced comminuted fracture of shaft of unspecified fibula, sequela*/
,'S82461D'  /*Displaced segmental fracture of shaft of right fibula, subsequent encounter for closed fracture with routine healing*/
,'S82461E'  /*Displaced segmental fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82461F'  /*Displaced segmental fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82461G'  /*Displaced segmental fracture of shaft of right fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82461H'  /*Displaced segmental fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82461J'  /*Displaced segmental fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82461K'  /*Displaced segmental fracture of shaft of right fibula, subsequent encounter for closed fracture with nonunion*/
,'S82461M'  /*Displaced segmental fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82461N'  /*Displaced segmental fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82461P'  /*Displaced segmental fracture of shaft of right fibula, subsequent encounter for closed fracture with malunion*/
,'S82461Q'  /*Displaced segmental fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82461R'  /*Displaced segmental fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82461S'  /*Displaced segmental fracture of shaft of right fibula, sequela*/
,'S82462D'  /*Displaced segmental fracture of shaft of left fibula, subsequent encounter for closed fracture with routine healing*/
,'S82462E'  /*Displaced segmental fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82462F'  /*Displaced segmental fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82462G'  /*Displaced segmental fracture of shaft of left fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82462H'  /*Displaced segmental fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82462J'  /*Displaced segmental fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82462K'  /*Displaced segmental fracture of shaft of left fibula, subsequent encounter for closed fracture with nonunion*/
,'S82462M'  /*Displaced segmental fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82462N'  /*Displaced segmental fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82462P'  /*Displaced segmental fracture of shaft of left fibula, subsequent encounter for closed fracture with malunion*/
,'S82462Q'  /*Displaced segmental fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82462R'  /*Displaced segmental fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82462S'  /*Displaced segmental fracture of shaft of left fibula, sequela*/
,'S82463D'  /*Displaced segmental fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with routine healing*/
,'S82463E'  /*Displaced segmental fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82463F'  /*Displaced segmental fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82463G'  /*Displaced segmental fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82463H'  /*Displaced segmental fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82463J'  /*Displaced segmental fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82463K'  /*Displaced segmental fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with nonunion*/
,'S82463M'  /*Displaced segmental fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82463N'  /*Displaced segmental fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82463P'  /*Displaced segmental fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with malunion*/
,'S82463Q'  /*Displaced segmental fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82463R'  /*Displaced segmental fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82463S'  /*Displaced segmental fracture of shaft of unspecified fibula, sequela*/
,'S82464D'  /*Nondisplaced segmental fracture of shaft of right fibula, subsequent encounter for closed fracture with routine healing*/
,'S82464E'  /*Nondisplaced segmental fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82464F'  /*Nondisplaced segmental fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82464G'  /*Nondisplaced segmental fracture of shaft of right fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82464H'  /*Nondisplaced segmental fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82464J'  /*Nondisplaced segmental fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82464K'  /*Nondisplaced segmental fracture of shaft of right fibula, subsequent encounter for closed fracture with nonunion*/
,'S82464M'  /*Nondisplaced segmental fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82464N'  /*Nondisplaced segmental fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82464P'  /*Nondisplaced segmental fracture of shaft of right fibula, subsequent encounter for closed fracture with malunion*/
,'S82464Q'  /*Nondisplaced segmental fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82464R'  /*Nondisplaced segmental fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82464S'  /*Nondisplaced segmental fracture of shaft of right fibula, sequela*/
,'S82465D'  /*Nondisplaced segmental fracture of shaft of left fibula, subsequent encounter for closed fracture with routine healing*/
,'S82465E'  /*Nondisplaced segmental fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82465F'  /*Nondisplaced segmental fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82465G'  /*Nondisplaced segmental fracture of shaft of left fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82465H'  /*Nondisplaced segmental fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82465J'  /*Nondisplaced segmental fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82465K'  /*Nondisplaced segmental fracture of shaft of left fibula, subsequent encounter for closed fracture with nonunion*/
,'S82465M'  /*Nondisplaced segmental fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82465N'  /*Nondisplaced segmental fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82465P'  /*Nondisplaced segmental fracture of shaft of left fibula, subsequent encounter for closed fracture with malunion*/
,'S82465Q'  /*Nondisplaced segmental fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82465R'  /*Nondisplaced segmental fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82465S'  /*Nondisplaced segmental fracture of shaft of left fibula, sequela*/
,'S82466D'  /*Nondisplaced segmental fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with routine healing*/
,'S82466E'  /*Nondisplaced segmental fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82466F'  /*Nondisplaced segmental fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82466G'  /*Nondisplaced segmental fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82466H'  /*Nondisplaced segmental fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82466J'  /*Nondisplaced segmental fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82466K'  /*Nondisplaced segmental fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with nonunion*/
,'S82466M'  /*Nondisplaced segmental fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82466N'  /*Nondisplaced segmental fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82466P'  /*Nondisplaced segmental fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with malunion*/
,'S82466Q'  /*Nondisplaced segmental fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82466R'  /*Nondisplaced segmental fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82466S'  /*Nondisplaced segmental fracture of shaft of unspecified fibula, sequela*/
,'S82491D'  /*Other fracture of shaft of right fibula, subsequent encounter for closed fracture with routine healing*/
,'S82491E'  /*Other fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82491F'  /*Other fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82491G'  /*Other fracture of shaft of right fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82491H'  /*Other fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82491J'  /*Other fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82491K'  /*Other fracture of shaft of right fibula, subsequent encounter for closed fracture with nonunion*/
,'S82491M'  /*Other fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82491N'  /*Other fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82491P'  /*Other fracture of shaft of right fibula, subsequent encounter for closed fracture with malunion*/
,'S82491Q'  /*Other fracture of shaft of right fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82491R'  /*Other fracture of shaft of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82491S'  /*Other fracture of shaft of right fibula, sequela*/
,'S82492D'  /*Other fracture of shaft of left fibula, subsequent encounter for closed fracture with routine healing*/
,'S82492E'  /*Other fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82492F'  /*Other fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82492G'  /*Other fracture of shaft of left fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82492H'  /*Other fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82492J'  /*Other fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82492K'  /*Other fracture of shaft of left fibula, subsequent encounter for closed fracture with nonunion*/
,'S82492M'  /*Other fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82492N'  /*Other fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82492P'  /*Other fracture of shaft of left fibula, subsequent encounter for closed fracture with malunion*/
,'S82492Q'  /*Other fracture of shaft of left fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82492R'  /*Other fracture of shaft of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82492S'  /*Other fracture of shaft of left fibula, sequela*/
,'S82499D'  /*Other fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with routine healing*/
,'S82499E'  /*Other fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82499F'  /*Other fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82499G'  /*Other fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82499H'  /*Other fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82499J'  /*Other fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82499K'  /*Other fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with nonunion*/
,'S82499M'  /*Other fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82499N'  /*Other fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82499P'  /*Other fracture of shaft of unspecified fibula, subsequent encounter for closed fracture with malunion*/
,'S82499Q'  /*Other fracture of shaft of unspecified fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82499R'  /*Other fracture of shaft of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82499S'  /*Other fracture of shaft of unspecified fibula, sequela*/
,'S8251XD'  /*Displaced fracture of medial malleolus of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S8251XE'  /*Displaced fracture of medial malleolus of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S8251XF'  /*Displaced fracture of medial malleolus of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S8251XG'  /*Displaced fracture of medial malleolus of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S8251XH'  /*Displaced fracture of medial malleolus of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S8251XJ'  /*Displaced fracture of medial malleolus of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S8251XK'  /*Displaced fracture of medial malleolus of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S8251XM'  /*Displaced fracture of medial malleolus of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S8251XN'  /*Displaced fracture of medial malleolus of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S8251XP'  /*Displaced fracture of medial malleolus of right tibia, subsequent encounter for closed fracture with malunion*/
,'S8251XQ'  /*Displaced fracture of medial malleolus of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S8251XR'  /*Displaced fracture of medial malleolus of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S8251XS'  /*Displaced fracture of medial malleolus of right tibia, sequela*/
,'S8252XD'  /*Displaced fracture of medial malleolus of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S8252XE'  /*Displaced fracture of medial malleolus of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S8252XF'  /*Displaced fracture of medial malleolus of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S8252XG'  /*Displaced fracture of medial malleolus of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S8252XH'  /*Displaced fracture of medial malleolus of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S8252XJ'  /*Displaced fracture of medial malleolus of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S8252XK'  /*Displaced fracture of medial malleolus of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S8252XM'  /*Displaced fracture of medial malleolus of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S8252XN'  /*Displaced fracture of medial malleolus of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S8252XP'  /*Displaced fracture of medial malleolus of left tibia, subsequent encounter for closed fracture with malunion*/
,'S8252XQ'  /*Displaced fracture of medial malleolus of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S8252XR'  /*Displaced fracture of medial malleolus of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S8252XS'  /*Displaced fracture of medial malleolus of left tibia, sequela*/
,'S8253XD'  /*Displaced fracture of medial malleolus of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S8253XE'  /*Displaced fracture of medial malleolus of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S8253XF'  /*Displaced fracture of medial malleolus of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S8253XG'  /*Displaced fracture of medial malleolus of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S8253XH'  /*Displaced fracture of medial malleolus of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S8253XJ'  /*Displaced fracture of medial malleolus of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S8253XK'  /*Displaced fracture of medial malleolus of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S8253XM'  /*Displaced fracture of medial malleolus of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S8253XN'  /*Displaced fracture of medial malleolus of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S8253XP'  /*Displaced fracture of medial malleolus of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S8253XQ'  /*Displaced fracture of medial malleolus of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S8253XR'  /*Displaced fracture of medial malleolus of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S8253XS'  /*Displaced fracture of medial malleolus of unspecified tibia, sequela*/
,'S8254XD'  /*Nondisplaced fracture of medial malleolus of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S8254XE'  /*Nondisplaced fracture of medial malleolus of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S8254XF'  /*Nondisplaced fracture of medial malleolus of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S8254XG'  /*Nondisplaced fracture of medial malleolus of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S8254XH'  /*Nondisplaced fracture of medial malleolus of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S8254XJ'  /*Nondisplaced fracture of medial malleolus of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S8254XK'  /*Nondisplaced fracture of medial malleolus of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S8254XM'  /*Nondisplaced fracture of medial malleolus of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S8254XN'  /*Nondisplaced fracture of medial malleolus of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S8254XP'  /*Nondisplaced fracture of medial malleolus of right tibia, subsequent encounter for closed fracture with malunion*/
,'S8254XQ'  /*Nondisplaced fracture of medial malleolus of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S8254XR'  /*Nondisplaced fracture of medial malleolus of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S8254XS'  /*Nondisplaced fracture of medial malleolus of right tibia, sequela*/
,'S8255XD'  /*Nondisplaced fracture of medial malleolus of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S8255XE'  /*Nondisplaced fracture of medial malleolus of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S8255XF'  /*Nondisplaced fracture of medial malleolus of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S8255XG'  /*Nondisplaced fracture of medial malleolus of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S8255XH'  /*Nondisplaced fracture of medial malleolus of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S8255XJ'  /*Nondisplaced fracture of medial malleolus of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S8255XK'  /*Nondisplaced fracture of medial malleolus of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S8255XM'  /*Nondisplaced fracture of medial malleolus of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S8255XN'  /*Nondisplaced fracture of medial malleolus of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S8255XP'  /*Nondisplaced fracture of medial malleolus of left tibia, subsequent encounter for closed fracture with malunion*/
,'S8255XQ'  /*Nondisplaced fracture of medial malleolus of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S8255XR'  /*Nondisplaced fracture of medial malleolus of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S8255XS'  /*Nondisplaced fracture of medial malleolus of left tibia, sequela*/
,'S8256XD'  /*Nondisplaced fracture of medial malleolus of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S8256XE'  /*Nondisplaced fracture of medial malleolus of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S8256XF'  /*Nondisplaced fracture of medial malleolus of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S8256XG'  /*Nondisplaced fracture of medial malleolus of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S8256XH'  /*Nondisplaced fracture of medial malleolus of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S8256XJ'  /*Nondisplaced fracture of medial malleolus of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S8256XK'  /*Nondisplaced fracture of medial malleolus of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S8256XM'  /*Nondisplaced fracture of medial malleolus of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S8256XN'  /*Nondisplaced fracture of medial malleolus of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S8256XP'  /*Nondisplaced fracture of medial malleolus of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S8256XQ'  /*Nondisplaced fracture of medial malleolus of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S8256XR'  /*Nondisplaced fracture of medial malleolus of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S8256XS'  /*Nondisplaced fracture of medial malleolus of unspecified tibia, sequela*/
,'S8261XD'  /*Displaced fracture of lateral malleolus of right fibula, subsequent encounter for closed fracture with routine healing*/
,'S8261XE'  /*Displaced fracture of lateral malleolus of right fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S8261XF'  /*Displaced fracture of lateral malleolus of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S8261XG'  /*Displaced fracture of lateral malleolus of right fibula, subsequent encounter for closed fracture with delayed healing*/
,'S8261XH'  /*Displaced fracture of lateral malleolus of right fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S8261XJ'  /*Displaced fracture of lateral malleolus of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S8261XK'  /*Displaced fracture of lateral malleolus of right fibula, subsequent encounter for closed fracture with nonunion*/
,'S8261XM'  /*Displaced fracture of lateral malleolus of right fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S8261XN'  /*Displaced fracture of lateral malleolus of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S8261XP'  /*Displaced fracture of lateral malleolus of right fibula, subsequent encounter for closed fracture with malunion*/
,'S8261XQ'  /*Displaced fracture of lateral malleolus of right fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S8261XR'  /*Displaced fracture of lateral malleolus of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S8261XS'  /*Displaced fracture of lateral malleolus of right fibula, sequela*/
,'S8262XD'  /*Displaced fracture of lateral malleolus of left fibula, subsequent encounter for closed fracture with routine healing*/
,'S8262XE'  /*Displaced fracture of lateral malleolus of left fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S8262XF'  /*Displaced fracture of lateral malleolus of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S8262XG'  /*Displaced fracture of lateral malleolus of left fibula, subsequent encounter for closed fracture with delayed healing*/
,'S8262XH'  /*Displaced fracture of lateral malleolus of left fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S8262XJ'  /*Displaced fracture of lateral malleolus of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S8262XK'  /*Displaced fracture of lateral malleolus of left fibula, subsequent encounter for closed fracture with nonunion*/
,'S8262XM'  /*Displaced fracture of lateral malleolus of left fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S8262XN'  /*Displaced fracture of lateral malleolus of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S8262XP'  /*Displaced fracture of lateral malleolus of left fibula, subsequent encounter for closed fracture with malunion*/
,'S8262XQ'  /*Displaced fracture of lateral malleolus of left fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S8262XR'  /*Displaced fracture of lateral malleolus of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S8262XS'  /*Displaced fracture of lateral malleolus of left fibula, sequela*/
,'S8263XD'  /*Displaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for closed fracture with routine healing*/
,'S8263XE'  /*Displaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S8263XF'  /*Displaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S8263XG'  /*Displaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for closed fracture with delayed healing*/
,'S8263XH'  /*Displaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S8263XJ'  /*Displaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S8263XK'  /*Displaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for closed fracture with nonunion*/
,'S8263XM'  /*Displaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S8263XN'  /*Displaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S8263XP'  /*Displaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for closed fracture with malunion*/
,'S8263XQ'  /*Displaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S8263XR'  /*Displaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S8263XS'  /*Displaced fracture of lateral malleolus of unspecified fibula, sequela*/
,'S8264XD'  /*Nondisplaced fracture of lateral malleolus of right fibula, subsequent encounter for closed fracture with routine healing*/
,'S8264XE'  /*Nondisplaced fracture of lateral malleolus of right fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S8264XF'  /*Nondisplaced fracture of lateral malleolus of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S8264XG'  /*Nondisplaced fracture of lateral malleolus of right fibula, subsequent encounter for closed fracture with delayed healing*/
,'S8264XH'  /*Nondisplaced fracture of lateral malleolus of right fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S8264XJ'  /*Nondisplaced fracture of lateral malleolus of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S8264XK'  /*Nondisplaced fracture of lateral malleolus of right fibula, subsequent encounter for closed fracture with nonunion*/
,'S8264XM'  /*Nondisplaced fracture of lateral malleolus of right fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S8264XN'  /*Nondisplaced fracture of lateral malleolus of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S8264XP'  /*Nondisplaced fracture of lateral malleolus of right fibula, subsequent encounter for closed fracture with malunion*/
,'S8264XQ'  /*Nondisplaced fracture of lateral malleolus of right fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S8264XR'  /*Nondisplaced fracture of lateral malleolus of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S8264XS'  /*Nondisplaced fracture of lateral malleolus of right fibula, sequela*/
,'S8265XD'  /*Nondisplaced fracture of lateral malleolus of left fibula, subsequent encounter for closed fracture with routine healing*/
,'S8265XE'  /*Nondisplaced fracture of lateral malleolus of left fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S8265XF'  /*Nondisplaced fracture of lateral malleolus of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S8265XG'  /*Nondisplaced fracture of lateral malleolus of left fibula, subsequent encounter for closed fracture with delayed healing*/
,'S8265XH'  /*Nondisplaced fracture of lateral malleolus of left fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S8265XJ'  /*Nondisplaced fracture of lateral malleolus of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S8265XK'  /*Nondisplaced fracture of lateral malleolus of left fibula, subsequent encounter for closed fracture with nonunion*/
,'S8265XM'  /*Nondisplaced fracture of lateral malleolus of left fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S8265XN'  /*Nondisplaced fracture of lateral malleolus of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S8265XP'  /*Nondisplaced fracture of lateral malleolus of left fibula, subsequent encounter for closed fracture with malunion*/
,'S8265XQ'  /*Nondisplaced fracture of lateral malleolus of left fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S8265XR'  /*Nondisplaced fracture of lateral malleolus of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S8265XS'  /*Nondisplaced fracture of lateral malleolus of left fibula, sequela*/
,'S8266XD'  /*Nondisplaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for closed fracture with routine healing*/
,'S8266XE'  /*Nondisplaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S8266XF'  /*Nondisplaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S8266XG'  /*Nondisplaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for closed fracture with delayed healing*/
,'S8266XH'  /*Nondisplaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S8266XJ'  /*Nondisplaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S8266XK'  /*Nondisplaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for closed fracture with nonunion*/
,'S8266XM'  /*Nondisplaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S8266XN'  /*Nondisplaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S8266XP'  /*Nondisplaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for closed fracture with malunion*/
,'S8266XQ'  /*Nondisplaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S8266XR'  /*Nondisplaced fracture of lateral malleolus of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S8266XS'  /*Nondisplaced fracture of lateral malleolus of unspecified fibula, sequela*/
,'S82811D'  /*Torus fracture of upper end of right fibula, subsequent encounter for fracture with routine healing*/
,'S82811G'  /*Torus fracture of upper end of right fibula, subsequent encounter for fracture with delayed healing*/
,'S82811K'  /*Torus fracture of upper end of right fibula, subsequent encounter for fracture with nonunion*/
,'S82811P'  /*Torus fracture of upper end of right fibula, subsequent encounter for fracture with malunion*/
,'S82811S'  /*Torus fracture of upper end of right fibula, sequela*/
,'S82812D'  /*Torus fracture of upper end of left fibula, subsequent encounter for fracture with routine healing*/
,'S82812G'  /*Torus fracture of upper end of left fibula, subsequent encounter for fracture with delayed healing*/
,'S82812K'  /*Torus fracture of upper end of left fibula, subsequent encounter for fracture with nonunion*/
,'S82812P'  /*Torus fracture of upper end of left fibula, subsequent encounter for fracture with malunion*/
,'S82812S'  /*Torus fracture of upper end of left fibula, sequela*/
,'S82819D'  /*Torus fracture of upper end of unspecified fibula, subsequent encounter for fracture with routine healing*/
,'S82819G'  /*Torus fracture of upper end of unspecified fibula, subsequent encounter for fracture with delayed healing*/
,'S82819K'  /*Torus fracture of upper end of unspecified fibula, subsequent encounter for fracture with nonunion*/
,'S82819P'  /*Torus fracture of upper end of unspecified fibula, subsequent encounter for fracture with malunion*/
,'S82819S'  /*Torus fracture of upper end of unspecified fibula, sequela*/
,'S82821D'  /*Torus fracture of lower end of right fibula, subsequent encounter for fracture with routine healing*/
,'S82821G'  /*Torus fracture of lower end of right fibula, subsequent encounter for fracture with delayed healing*/
,'S82821K'  /*Torus fracture of lower end of right fibula, subsequent encounter for fracture with nonunion*/
,'S82821P'  /*Torus fracture of lower end of right fibula, subsequent encounter for fracture with malunion*/
,'S82821S'  /*Torus fracture of lower end of right fibula, sequela*/
,'S82822D'  /*Torus fracture of lower end of left fibula, subsequent encounter for fracture with routine healing*/
,'S82822G'  /*Torus fracture of lower end of left fibula, subsequent encounter for fracture with delayed healing*/
,'S82822K'  /*Torus fracture of lower end of left fibula, subsequent encounter for fracture with nonunion*/
,'S82822P'  /*Torus fracture of lower end of left fibula, subsequent encounter for fracture with malunion*/
,'S82822S'  /*Torus fracture of lower end of left fibula, sequela*/
,'S82829D'  /*Torus fracture of lower end of unspecified fibula, subsequent encounter for fracture with routine healing*/
,'S82829G'  /*Torus fracture of lower end of unspecified fibula, subsequent encounter for fracture with delayed healing*/
,'S82829K'  /*Torus fracture of lower end of unspecified fibula, subsequent encounter for fracture with nonunion*/
,'S82829P'  /*Torus fracture of lower end of unspecified fibula, subsequent encounter for fracture with malunion*/
,'S82829S'  /*Torus fracture of lower end of unspecified fibula, sequela*/
,'S82831D'  /*Other fracture of upper and lower end of right fibula, subsequent encounter for closed fracture with routine healing*/
,'S82831E'  /*Other fracture of upper and lower end of right fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82831F'  /*Other fracture of upper and lower end of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82831G'  /*Other fracture of upper and lower end of right fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82831H'  /*Other fracture of upper and lower end of right fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82831J'  /*Other fracture of upper and lower end of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82831K'  /*Other fracture of upper and lower end of right fibula, subsequent encounter for closed fracture with nonunion*/
,'S82831M'  /*Other fracture of upper and lower end of right fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82831N'  /*Other fracture of upper and lower end of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82831P'  /*Other fracture of upper and lower end of right fibula, subsequent encounter for closed fracture with malunion*/
,'S82831Q'  /*Other fracture of upper and lower end of right fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82831R'  /*Other fracture of upper and lower end of right fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82831S'  /*Other fracture of upper and lower end of right fibula, sequela*/
,'S82832D'  /*Other fracture of upper and lower end of left fibula, subsequent encounter for closed fracture with routine healing*/
,'S82832E'  /*Other fracture of upper and lower end of left fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82832F'  /*Other fracture of upper and lower end of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82832G'  /*Other fracture of upper and lower end of left fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82832H'  /*Other fracture of upper and lower end of left fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82832J'  /*Other fracture of upper and lower end of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82832K'  /*Other fracture of upper and lower end of left fibula, subsequent encounter for closed fracture with nonunion*/
,'S82832M'  /*Other fracture of upper and lower end of left fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82832N'  /*Other fracture of upper and lower end of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82832P'  /*Other fracture of upper and lower end of left fibula, subsequent encounter for closed fracture with malunion*/
,'S82832Q'  /*Other fracture of upper and lower end of left fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82832R'  /*Other fracture of upper and lower end of left fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82832S'  /*Other fracture of upper and lower end of left fibula, sequela*/
,'S82839D'  /*Other fracture of upper and lower end of unspecified fibula, subsequent encounter for closed fracture with routine healing*/
,'S82839E'  /*Other fracture of upper and lower end of unspecified fibula, subsequent encounter for open fracture type I or II with routine healing*/
,'S82839F'  /*Other fracture of upper and lower end of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82839G'  /*Other fracture of upper and lower end of unspecified fibula, subsequent encounter for closed fracture with delayed healing*/
,'S82839H'  /*Other fracture of upper and lower end of unspecified fibula, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82839J'  /*Other fracture of upper and lower end of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82839K'  /*Other fracture of upper and lower end of unspecified fibula, subsequent encounter for closed fracture with nonunion*/
,'S82839M'  /*Other fracture of upper and lower end of unspecified fibula, subsequent encounter for open fracture type I or II with nonunion*/
,'S82839N'  /*Other fracture of upper and lower end of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82839P'  /*Other fracture of upper and lower end of unspecified fibula, subsequent encounter for closed fracture with malunion*/
,'S82839Q'  /*Other fracture of upper and lower end of unspecified fibula, subsequent encounter for open fracture type I or II with malunion*/
,'S82839R'  /*Other fracture of upper and lower end of unspecified fibula, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82839S'  /*Other fracture of upper and lower end of unspecified fibula, sequela*/
,'S82841D'  /*Displaced bimalleolar fracture of right lower leg, subsequent encounter for closed fracture with routine healing*/
,'S82841E'  /*Displaced bimalleolar fracture of right lower leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S82841F'  /*Displaced bimalleolar fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82841G'  /*Displaced bimalleolar fracture of right lower leg, subsequent encounter for closed fracture with delayed healing*/
,'S82841H'  /*Displaced bimalleolar fracture of right lower leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82841J'  /*Displaced bimalleolar fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82841K'  /*Displaced bimalleolar fracture of right lower leg, subsequent encounter for closed fracture with nonunion*/
,'S82841M'  /*Displaced bimalleolar fracture of right lower leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S82841N'  /*Displaced bimalleolar fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82841P'  /*Displaced bimalleolar fracture of right lower leg, subsequent encounter for closed fracture with malunion*/
,'S82841Q'  /*Displaced bimalleolar fracture of right lower leg, subsequent encounter for open fracture type I or II with malunion*/
,'S82841R'  /*Displaced bimalleolar fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82841S'  /*Displaced bimalleolar fracture of right lower leg, sequela*/
,'S82842D'  /*Displaced bimalleolar fracture of left lower leg, subsequent encounter for closed fracture with routine healing*/
,'S82842E'  /*Displaced bimalleolar fracture of left lower leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S82842F'  /*Displaced bimalleolar fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82842G'  /*Displaced bimalleolar fracture of left lower leg, subsequent encounter for closed fracture with delayed healing*/
,'S82842H'  /*Displaced bimalleolar fracture of left lower leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82842J'  /*Displaced bimalleolar fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82842K'  /*Displaced bimalleolar fracture of left lower leg, subsequent encounter for closed fracture with nonunion*/
,'S82842M'  /*Displaced bimalleolar fracture of left lower leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S82842N'  /*Displaced bimalleolar fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82842P'  /*Displaced bimalleolar fracture of left lower leg, subsequent encounter for closed fracture with malunion*/
,'S82842Q'  /*Displaced bimalleolar fracture of left lower leg, subsequent encounter for open fracture type I or II with malunion*/
,'S82842R'  /*Displaced bimalleolar fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82842S'  /*Displaced bimalleolar fracture of left lower leg, sequela*/
,'S82843D'  /*Displaced bimalleolar fracture of unspecified lower leg, subsequent encounter for closed fracture with routine healing*/
,'S82843E'  /*Displaced bimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S82843F'  /*Displaced bimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82843G'  /*Displaced bimalleolar fracture of unspecified lower leg, subsequent encounter for closed fracture with delayed healing*/
,'S82843H'  /*Displaced bimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82843J'  /*Displaced bimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82843K'  /*Displaced bimalleolar fracture of unspecified lower leg, subsequent encounter for closed fracture with nonunion*/
,'S82843M'  /*Displaced bimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S82843N'  /*Displaced bimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82843P'  /*Displaced bimalleolar fracture of unspecified lower leg, subsequent encounter for closed fracture with malunion*/
,'S82843Q'  /*Displaced bimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with malunion*/
,'S82843R'  /*Displaced bimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82843S'  /*Displaced bimalleolar fracture of unspecified lower leg, sequela*/
,'S82844D'  /*Nondisplaced bimalleolar fracture of right lower leg, subsequent encounter for closed fracture with routine healing*/
,'S82844E'  /*Nondisplaced bimalleolar fracture of right lower leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S82844F'  /*Nondisplaced bimalleolar fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82844G'  /*Nondisplaced bimalleolar fracture of right lower leg, subsequent encounter for closed fracture with delayed healing*/
,'S82844H'  /*Nondisplaced bimalleolar fracture of right lower leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82844J'  /*Nondisplaced bimalleolar fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82844K'  /*Nondisplaced bimalleolar fracture of right lower leg, subsequent encounter for closed fracture with nonunion*/
,'S82844M'  /*Nondisplaced bimalleolar fracture of right lower leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S82844N'  /*Nondisplaced bimalleolar fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82844P'  /*Nondisplaced bimalleolar fracture of right lower leg, subsequent encounter for closed fracture with malunion*/
,'S82844Q'  /*Nondisplaced bimalleolar fracture of right lower leg, subsequent encounter for open fracture type I or II with malunion*/
,'S82844R'  /*Nondisplaced bimalleolar fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82844S'  /*Nondisplaced bimalleolar fracture of right lower leg, sequela*/
,'S82845D'  /*Nondisplaced bimalleolar fracture of left lower leg, subsequent encounter for closed fracture with routine healing*/
,'S82845E'  /*Nondisplaced bimalleolar fracture of left lower leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S82845F'  /*Nondisplaced bimalleolar fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82845G'  /*Nondisplaced bimalleolar fracture of left lower leg, subsequent encounter for closed fracture with delayed healing*/
,'S82845H'  /*Nondisplaced bimalleolar fracture of left lower leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82845J'  /*Nondisplaced bimalleolar fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82845K'  /*Nondisplaced bimalleolar fracture of left lower leg, subsequent encounter for closed fracture with nonunion*/
,'S82845M'  /*Nondisplaced bimalleolar fracture of left lower leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S82845N'  /*Nondisplaced bimalleolar fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82845P'  /*Nondisplaced bimalleolar fracture of left lower leg, subsequent encounter for closed fracture with malunion*/
,'S82845Q'  /*Nondisplaced bimalleolar fracture of left lower leg, subsequent encounter for open fracture type I or II with malunion*/
,'S82845R'  /*Nondisplaced bimalleolar fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82845S'  /*Nondisplaced bimalleolar fracture of left lower leg, sequela*/
,'S82846D'  /*Nondisplaced bimalleolar fracture of unspecified lower leg, subsequent encounter for closed fracture with routine healing*/
,'S82846E'  /*Nondisplaced bimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S82846F'  /*Nondisplaced bimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82846G'  /*Nondisplaced bimalleolar fracture of unspecified lower leg, subsequent encounter for closed fracture with delayed healing*/
,'S82846H'  /*Nondisplaced bimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82846J'  /*Nondisplaced bimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82846K'  /*Nondisplaced bimalleolar fracture of unspecified lower leg, subsequent encounter for closed fracture with nonunion*/
,'S82846M'  /*Nondisplaced bimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S82846N'  /*Nondisplaced bimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82846P'  /*Nondisplaced bimalleolar fracture of unspecified lower leg, subsequent encounter for closed fracture with malunion*/
,'S82846Q'  /*Nondisplaced bimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with malunion*/
,'S82846R'  /*Nondisplaced bimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82846S'  /*Nondisplaced bimalleolar fracture of unspecified lower leg, sequela*/
,'S82851D'  /*Displaced trimalleolar fracture of right lower leg, subsequent encounter for closed fracture with routine healing*/
,'S82851E'  /*Displaced trimalleolar fracture of right lower leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S82851F'  /*Displaced trimalleolar fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82851G'  /*Displaced trimalleolar fracture of right lower leg, subsequent encounter for closed fracture with delayed healing*/
,'S82851H'  /*Displaced trimalleolar fracture of right lower leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82851J'  /*Displaced trimalleolar fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82851K'  /*Displaced trimalleolar fracture of right lower leg, subsequent encounter for closed fracture with nonunion*/
,'S82851M'  /*Displaced trimalleolar fracture of right lower leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S82851N'  /*Displaced trimalleolar fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82851P'  /*Displaced trimalleolar fracture of right lower leg, subsequent encounter for closed fracture with malunion*/
,'S82851Q'  /*Displaced trimalleolar fracture of right lower leg, subsequent encounter for open fracture type I or II with malunion*/
,'S82851R'  /*Displaced trimalleolar fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82851S'  /*Displaced trimalleolar fracture of right lower leg, sequela*/
,'S82852D'  /*Displaced trimalleolar fracture of left lower leg, subsequent encounter for closed fracture with routine healing*/
,'S82852E'  /*Displaced trimalleolar fracture of left lower leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S82852F'  /*Displaced trimalleolar fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82852G'  /*Displaced trimalleolar fracture of left lower leg, subsequent encounter for closed fracture with delayed healing*/
,'S82852H'  /*Displaced trimalleolar fracture of left lower leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82852J'  /*Displaced trimalleolar fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82852K'  /*Displaced trimalleolar fracture of left lower leg, subsequent encounter for closed fracture with nonunion*/
,'S82852M'  /*Displaced trimalleolar fracture of left lower leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S82852N'  /*Displaced trimalleolar fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82852P'  /*Displaced trimalleolar fracture of left lower leg, subsequent encounter for closed fracture with malunion*/
,'S82852Q'  /*Displaced trimalleolar fracture of left lower leg, subsequent encounter for open fracture type I or II with malunion*/
,'S82852R'  /*Displaced trimalleolar fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82852S'  /*Displaced trimalleolar fracture of left lower leg, sequela*/
,'S82853D'  /*Displaced trimalleolar fracture of unspecified lower leg, subsequent encounter for closed fracture with routine healing*/
,'S82853E'  /*Displaced trimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S82853F'  /*Displaced trimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82853G'  /*Displaced trimalleolar fracture of unspecified lower leg, subsequent encounter for closed fracture with delayed healing*/
,'S82853H'  /*Displaced trimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82853J'  /*Displaced trimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82853K'  /*Displaced trimalleolar fracture of unspecified lower leg, subsequent encounter for closed fracture with nonunion*/
,'S82853M'  /*Displaced trimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S82853N'  /*Displaced trimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82853P'  /*Displaced trimalleolar fracture of unspecified lower leg, subsequent encounter for closed fracture with malunion*/
,'S82853Q'  /*Displaced trimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with malunion*/
,'S82853R'  /*Displaced trimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82853S'  /*Displaced trimalleolar fracture of unspecified lower leg, sequela*/
,'S82854D'  /*Nondisplaced trimalleolar fracture of right lower leg, subsequent encounter for closed fracture with routine healing*/
,'S82854E'  /*Nondisplaced trimalleolar fracture of right lower leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S82854F'  /*Nondisplaced trimalleolar fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82854G'  /*Nondisplaced trimalleolar fracture of right lower leg, subsequent encounter for closed fracture with delayed healing*/
,'S82854H'  /*Nondisplaced trimalleolar fracture of right lower leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82854J'  /*Nondisplaced trimalleolar fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82854K'  /*Nondisplaced trimalleolar fracture of right lower leg, subsequent encounter for closed fracture with nonunion*/
,'S82854M'  /*Nondisplaced trimalleolar fracture of right lower leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S82854N'  /*Nondisplaced trimalleolar fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82854P'  /*Nondisplaced trimalleolar fracture of right lower leg, subsequent encounter for closed fracture with malunion*/
,'S82854Q'  /*Nondisplaced trimalleolar fracture of right lower leg, subsequent encounter for open fracture type I or II with malunion*/
,'S82854R'  /*Nondisplaced trimalleolar fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82854S'  /*Nondisplaced trimalleolar fracture of right lower leg, sequela*/
,'S82855D'  /*Nondisplaced trimalleolar fracture of left lower leg, subsequent encounter for closed fracture with routine healing*/
,'S82855E'  /*Nondisplaced trimalleolar fracture of left lower leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S82855F'  /*Nondisplaced trimalleolar fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82855G'  /*Nondisplaced trimalleolar fracture of left lower leg, subsequent encounter for closed fracture with delayed healing*/
,'S82855H'  /*Nondisplaced trimalleolar fracture of left lower leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82855J'  /*Nondisplaced trimalleolar fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82855K'  /*Nondisplaced trimalleolar fracture of left lower leg, subsequent encounter for closed fracture with nonunion*/
,'S82855M'  /*Nondisplaced trimalleolar fracture of left lower leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S82855N'  /*Nondisplaced trimalleolar fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82855P'  /*Nondisplaced trimalleolar fracture of left lower leg, subsequent encounter for closed fracture with malunion*/
,'S82855Q'  /*Nondisplaced trimalleolar fracture of left lower leg, subsequent encounter for open fracture type I or II with malunion*/
,'S82855R'  /*Nondisplaced trimalleolar fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82855S'  /*Nondisplaced trimalleolar fracture of left lower leg, sequela*/
,'S82856D'  /*Nondisplaced trimalleolar fracture of unspecified lower leg, subsequent encounter for closed fracture with routine healing*/
,'S82856E'  /*Nondisplaced trimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S82856F'  /*Nondisplaced trimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82856G'  /*Nondisplaced trimalleolar fracture of unspecified lower leg, subsequent encounter for closed fracture with delayed healing*/
,'S82856H'  /*Nondisplaced trimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82856J'  /*Nondisplaced trimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82856K'  /*Nondisplaced trimalleolar fracture of unspecified lower leg, subsequent encounter for closed fracture with nonunion*/
,'S82856M'  /*Nondisplaced trimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S82856N'  /*Nondisplaced trimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82856P'  /*Nondisplaced trimalleolar fracture of unspecified lower leg, subsequent encounter for closed fracture with malunion*/
,'S82856Q'  /*Nondisplaced trimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with malunion*/
,'S82856R'  /*Nondisplaced trimalleolar fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82856S'  /*Nondisplaced trimalleolar fracture of unspecified lower leg, sequela*/
,'S82861D'  /*Displaced Maisonneuve's fracture of right leg, subsequent encounter for closed fracture with routine healing*/
,'S82861E'  /*Displaced Maisonneuve's fracture of right leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S82861F'  /*Displaced Maisonneuve's fracture of right leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82861G'  /*Displaced Maisonneuve's fracture of right leg, subsequent encounter for closed fracture with delayed healing*/
,'S82861H'  /*Displaced Maisonneuve's fracture of right leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82861J'  /*Displaced Maisonneuve's fracture of right leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82861K'  /*Displaced Maisonneuve's fracture of right leg, subsequent encounter for closed fracture with nonunion*/
,'S82861M'  /*Displaced Maisonneuve's fracture of right leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S82861N'  /*Displaced Maisonneuve's fracture of right leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82861P'  /*Displaced Maisonneuve's fracture of right leg, subsequent encounter for closed fracture with malunion*/
,'S82861Q'  /*Displaced Maisonneuve's fracture of right leg, subsequent encounter for open fracture type I or II with malunion*/
,'S82861R'  /*Displaced Maisonneuve's fracture of right leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82861S'  /*Displaced Maisonneuve's fracture of right leg, sequela*/
,'S82862D'  /*Displaced Maisonneuve's fracture of left leg, subsequent encounter for closed fracture with routine healing*/
,'S82862E'  /*Displaced Maisonneuve's fracture of left leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S82862F'  /*Displaced Maisonneuve's fracture of left leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82862G'  /*Displaced Maisonneuve's fracture of left leg, subsequent encounter for closed fracture with delayed healing*/
,'S82862H'  /*Displaced Maisonneuve's fracture of left leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82862J'  /*Displaced Maisonneuve's fracture of left leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82862K'  /*Displaced Maisonneuve's fracture of left leg, subsequent encounter for closed fracture with nonunion*/
,'S82862M'  /*Displaced Maisonneuve's fracture of left leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S82862N'  /*Displaced Maisonneuve's fracture of left leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82862P'  /*Displaced Maisonneuve's fracture of left leg, subsequent encounter for closed fracture with malunion*/
,'S82862Q'  /*Displaced Maisonneuve's fracture of left leg, subsequent encounter for open fracture type I or II with malunion*/
,'S82862R'  /*Displaced Maisonneuve's fracture of left leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82862S'  /*Displaced Maisonneuve's fracture of left leg, sequela*/
,'S82863D'  /*Displaced Maisonneuve's fracture of unspecified leg, subsequent encounter for closed fracture with routine healing*/
,'S82863E'  /*Displaced Maisonneuve's fracture of unspecified leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S82863F'  /*Displaced Maisonneuve's fracture of unspecified leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82863G'  /*Displaced Maisonneuve's fracture of unspecified leg, subsequent encounter for closed fracture with delayed healing*/
,'S82863H'  /*Displaced Maisonneuve's fracture of unspecified leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82863J'  /*Displaced Maisonneuve's fracture of unspecified leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82863K'  /*Displaced Maisonneuve's fracture of unspecified leg, subsequent encounter for closed fracture with nonunion*/
,'S82863M'  /*Displaced Maisonneuve's fracture of unspecified leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S82863N'  /*Displaced Maisonneuve's fracture of unspecified leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82863P'  /*Displaced Maisonneuve's fracture of unspecified leg, subsequent encounter for closed fracture with malunion*/
,'S82863Q'  /*Displaced Maisonneuve's fracture of unspecified leg, subsequent encounter for open fracture type I or II with malunion*/
,'S82863R'  /*Displaced Maisonneuve's fracture of unspecified leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82863S'  /*Displaced Maisonneuve's fracture of unspecified leg, sequela*/
,'S82864D'  /*Nondisplaced Maisonneuve's fracture of right leg, subsequent encounter for closed fracture with routine healing*/
,'S82864E'  /*Nondisplaced Maisonneuve's fracture of right leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S82864F'  /*Nondisplaced Maisonneuve's fracture of right leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82864G'  /*Nondisplaced Maisonneuve's fracture of right leg, subsequent encounter for closed fracture with delayed healing*/
,'S82864H'  /*Nondisplaced Maisonneuve's fracture of right leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82864J'  /*Nondisplaced Maisonneuve's fracture of right leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82864K'  /*Nondisplaced Maisonneuve's fracture of right leg, subsequent encounter for closed fracture with nonunion*/
,'S82864M'  /*Nondisplaced Maisonneuve's fracture of right leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S82864N'  /*Nondisplaced Maisonneuve's fracture of right leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82864P'  /*Nondisplaced Maisonneuve's fracture of right leg, subsequent encounter for closed fracture with malunion*/
,'S82864Q'  /*Nondisplaced Maisonneuve's fracture of right leg, subsequent encounter for open fracture type I or II with malunion*/
,'S82864R'  /*Nondisplaced Maisonneuve's fracture of right leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82864S'  /*Nondisplaced Maisonneuve's fracture of right leg, sequela*/
,'S82865D'  /*Nondisplaced Maisonneuve's fracture of left leg, subsequent encounter for closed fracture with routine healing*/
,'S82865E'  /*Nondisplaced Maisonneuve's fracture of left leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S82865F'  /*Nondisplaced Maisonneuve's fracture of left leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82865G'  /*Nondisplaced Maisonneuve's fracture of left leg, subsequent encounter for closed fracture with delayed healing*/
,'S82865H'  /*Nondisplaced Maisonneuve's fracture of left leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82865J'  /*Nondisplaced Maisonneuve's fracture of left leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82865K'  /*Nondisplaced Maisonneuve's fracture of left leg, subsequent encounter for closed fracture with nonunion*/
,'S82865M'  /*Nondisplaced Maisonneuve's fracture of left leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S82865N'  /*Nondisplaced Maisonneuve's fracture of left leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82865P'  /*Nondisplaced Maisonneuve's fracture of left leg, subsequent encounter for closed fracture with malunion*/
,'S82865Q'  /*Nondisplaced Maisonneuve's fracture of left leg, subsequent encounter for open fracture type I or II with malunion*/
,'S82865R'  /*Nondisplaced Maisonneuve's fracture of left leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82865S'  /*Nondisplaced Maisonneuve's fracture of left leg, sequela*/
,'S82866D'  /*Nondisplaced Maisonneuve's fracture of unspecified leg, subsequent encounter for closed fracture with routine healing*/
,'S82866E'  /*Nondisplaced Maisonneuve's fracture of unspecified leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S82866F'  /*Nondisplaced Maisonneuve's fracture of unspecified leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82866G'  /*Nondisplaced Maisonneuve's fracture of unspecified leg, subsequent encounter for closed fracture with delayed healing*/
,'S82866H'  /*Nondisplaced Maisonneuve's fracture of unspecified leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82866J'  /*Nondisplaced Maisonneuve's fracture of unspecified leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82866K'  /*Nondisplaced Maisonneuve's fracture of unspecified leg, subsequent encounter for closed fracture with nonunion*/
,'S82866M'  /*Nondisplaced Maisonneuve's fracture of unspecified leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S82866N'  /*Nondisplaced Maisonneuve's fracture of unspecified leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82866P'  /*Nondisplaced Maisonneuve's fracture of unspecified leg, subsequent encounter for closed fracture with malunion*/
,'S82866Q'  /*Nondisplaced Maisonneuve's fracture of unspecified leg, subsequent encounter for open fracture type I or II with malunion*/
,'S82866R'  /*Nondisplaced Maisonneuve's fracture of unspecified leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82866S'  /*Nondisplaced Maisonneuve's fracture of unspecified leg, sequela*/
,'S82871D'  /*Displaced pilon fracture of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82871E'  /*Displaced pilon fracture of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82871F'  /*Displaced pilon fracture of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82871G'  /*Displaced pilon fracture of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82871H'  /*Displaced pilon fracture of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82871J'  /*Displaced pilon fracture of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82871K'  /*Displaced pilon fracture of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82871M'  /*Displaced pilon fracture of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82871N'  /*Displaced pilon fracture of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82871P'  /*Displaced pilon fracture of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82871Q'  /*Displaced pilon fracture of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82871R'  /*Displaced pilon fracture of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82871S'  /*Displaced pilon fracture of right tibia, sequela*/
,'S82872D'  /*Displaced pilon fracture of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82872E'  /*Displaced pilon fracture of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82872F'  /*Displaced pilon fracture of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82872G'  /*Displaced pilon fracture of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82872H'  /*Displaced pilon fracture of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82872J'  /*Displaced pilon fracture of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82872K'  /*Displaced pilon fracture of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82872M'  /*Displaced pilon fracture of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82872N'  /*Displaced pilon fracture of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82872P'  /*Displaced pilon fracture of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82872Q'  /*Displaced pilon fracture of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82872R'  /*Displaced pilon fracture of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82872S'  /*Displaced pilon fracture of left tibia, sequela*/
,'S82873D'  /*Displaced pilon fracture of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82873E'  /*Displaced pilon fracture of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82873F'  /*Displaced pilon fracture of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82873G'  /*Displaced pilon fracture of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82873H'  /*Displaced pilon fracture of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82873J'  /*Displaced pilon fracture of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82873K'  /*Displaced pilon fracture of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82873M'  /*Displaced pilon fracture of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82873N'  /*Displaced pilon fracture of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82873P'  /*Displaced pilon fracture of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82873Q'  /*Displaced pilon fracture of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82873R'  /*Displaced pilon fracture of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82873S'  /*Displaced pilon fracture of unspecified tibia, sequela*/
,'S82874D'  /*Nondisplaced pilon fracture of right tibia, subsequent encounter for closed fracture with routine healing*/
,'S82874E'  /*Nondisplaced pilon fracture of right tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82874F'  /*Nondisplaced pilon fracture of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82874G'  /*Nondisplaced pilon fracture of right tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82874H'  /*Nondisplaced pilon fracture of right tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82874J'  /*Nondisplaced pilon fracture of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82874K'  /*Nondisplaced pilon fracture of right tibia, subsequent encounter for closed fracture with nonunion*/
,'S82874M'  /*Nondisplaced pilon fracture of right tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82874N'  /*Nondisplaced pilon fracture of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82874P'  /*Nondisplaced pilon fracture of right tibia, subsequent encounter for closed fracture with malunion*/
,'S82874Q'  /*Nondisplaced pilon fracture of right tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82874R'  /*Nondisplaced pilon fracture of right tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82874S'  /*Nondisplaced pilon fracture of right tibia, sequela*/
,'S82875D'  /*Nondisplaced pilon fracture of left tibia, subsequent encounter for closed fracture with routine healing*/
,'S82875E'  /*Nondisplaced pilon fracture of left tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82875F'  /*Nondisplaced pilon fracture of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82875G'  /*Nondisplaced pilon fracture of left tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82875H'  /*Nondisplaced pilon fracture of left tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82875J'  /*Nondisplaced pilon fracture of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82875K'  /*Nondisplaced pilon fracture of left tibia, subsequent encounter for closed fracture with nonunion*/
,'S82875M'  /*Nondisplaced pilon fracture of left tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82875N'  /*Nondisplaced pilon fracture of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82875P'  /*Nondisplaced pilon fracture of left tibia, subsequent encounter for closed fracture with malunion*/
,'S82875Q'  /*Nondisplaced pilon fracture of left tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82875R'  /*Nondisplaced pilon fracture of left tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82875S'  /*Nondisplaced pilon fracture of left tibia, sequela*/
,'S82876D'  /*Nondisplaced pilon fracture of unspecified tibia, subsequent encounter for closed fracture with routine healing*/
,'S82876E'  /*Nondisplaced pilon fracture of unspecified tibia, subsequent encounter for open fracture type I or II with routine healing*/
,'S82876F'  /*Nondisplaced pilon fracture of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82876G'  /*Nondisplaced pilon fracture of unspecified tibia, subsequent encounter for closed fracture with delayed healing*/
,'S82876H'  /*Nondisplaced pilon fracture of unspecified tibia, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82876J'  /*Nondisplaced pilon fracture of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82876K'  /*Nondisplaced pilon fracture of unspecified tibia, subsequent encounter for closed fracture with nonunion*/
,'S82876M'  /*Nondisplaced pilon fracture of unspecified tibia, subsequent encounter for open fracture type I or II with nonunion*/
,'S82876N'  /*Nondisplaced pilon fracture of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82876P'  /*Nondisplaced pilon fracture of unspecified tibia, subsequent encounter for closed fracture with malunion*/
,'S82876Q'  /*Nondisplaced pilon fracture of unspecified tibia, subsequent encounter for open fracture type I or II with malunion*/
,'S82876R'  /*Nondisplaced pilon fracture of unspecified tibia, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82876S'  /*Nondisplaced pilon fracture of unspecified tibia, sequela*/
,'S82891D'  /*Other fracture of right lower leg, subsequent encounter for closed fracture with routine healing*/
,'S82891E'  /*Other fracture of right lower leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S82891F'  /*Other fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82891G'  /*Other fracture of right lower leg, subsequent encounter for closed fracture with delayed healing*/
,'S82891H'  /*Other fracture of right lower leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82891J'  /*Other fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82891K'  /*Other fracture of right lower leg, subsequent encounter for closed fracture with nonunion*/
,'S82891M'  /*Other fracture of right lower leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S82891N'  /*Other fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82891P'  /*Other fracture of right lower leg, subsequent encounter for closed fracture with malunion*/
,'S82891Q'  /*Other fracture of right lower leg, subsequent encounter for open fracture type I or II with malunion*/
,'S82891R'  /*Other fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82891S'  /*Other fracture of right lower leg, sequela*/
,'S82892D'  /*Other fracture of left lower leg, subsequent encounter for closed fracture with routine healing*/
,'S82892E'  /*Other fracture of left lower leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S82892F'  /*Other fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82892G'  /*Other fracture of left lower leg, subsequent encounter for closed fracture with delayed healing*/
,'S82892H'  /*Other fracture of left lower leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82892J'  /*Other fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82892K'  /*Other fracture of left lower leg, subsequent encounter for closed fracture with nonunion*/
,'S82892M'  /*Other fracture of left lower leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S82892N'  /*Other fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82892P'  /*Other fracture of left lower leg, subsequent encounter for closed fracture with malunion*/
,'S82892Q'  /*Other fracture of left lower leg, subsequent encounter for open fracture type I or II with malunion*/
,'S82892R'  /*Other fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82892S'  /*Other fracture of left lower leg, sequela*/
,'S82899D'  /*Other fracture of unspecified lower leg, subsequent encounter for closed fracture with routine healing*/
,'S82899E'  /*Other fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S82899F'  /*Other fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S82899G'  /*Other fracture of unspecified lower leg, subsequent encounter for closed fracture with delayed healing*/
,'S82899H'  /*Other fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S82899J'  /*Other fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S82899K'  /*Other fracture of unspecified lower leg, subsequent encounter for closed fracture with nonunion*/
,'S82899M'  /*Other fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S82899N'  /*Other fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S82899P'  /*Other fracture of unspecified lower leg, subsequent encounter for closed fracture with malunion*/
,'S82899Q'  /*Other fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with malunion*/
,'S82899R'  /*Other fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S82899S'  /*Other fracture of unspecified lower leg, sequela*/
,'S8290XD'  /*Unspecified fracture of unspecified lower leg, subsequent encounter for closed fracture with routine healing*/
,'S8290XE'  /*Unspecified fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S8290XF'  /*Unspecified fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S8290XG'  /*Unspecified fracture of unspecified lower leg, subsequent encounter for closed fracture with delayed healing*/
,'S8290XH'  /*Unspecified fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S8290XJ'  /*Unspecified fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S8290XK'  /*Unspecified fracture of unspecified lower leg, subsequent encounter for closed fracture with nonunion*/
,'S8290XM'  /*Unspecified fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S8290XN'  /*Unspecified fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S8290XP'  /*Unspecified fracture of unspecified lower leg, subsequent encounter for closed fracture with malunion*/
,'S8290XQ'  /*Unspecified fracture of unspecified lower leg, subsequent encounter for open fracture type I or II with malunion*/
,'S8290XR'  /*Unspecified fracture of unspecified lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S8290XS'  /*Unspecified fracture of unspecified lower leg, sequela*/
,'S8291XD'  /*Unspecified fracture of right lower leg, subsequent encounter for closed fracture with routine healing*/
,'S8291XE'  /*Unspecified fracture of right lower leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S8291XF'  /*Unspecified fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S8291XG'  /*Unspecified fracture of right lower leg, subsequent encounter for closed fracture with delayed healing*/
,'S8291XH'  /*Unspecified fracture of right lower leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S8291XJ'  /*Unspecified fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S8291XK'  /*Unspecified fracture of right lower leg, subsequent encounter for closed fracture with nonunion*/
,'S8291XM'  /*Unspecified fracture of right lower leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S8291XN'  /*Unspecified fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S8291XP'  /*Unspecified fracture of right lower leg, subsequent encounter for closed fracture with malunion*/
,'S8291XQ'  /*Unspecified fracture of right lower leg, subsequent encounter for open fracture type I or II with malunion*/
,'S8291XR'  /*Unspecified fracture of right lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S8291XS'  /*Unspecified fracture of right lower leg, sequela*/
,'S8292XD'  /*Unspecified fracture of left lower leg, subsequent encounter for closed fracture with routine healing*/
,'S8292XE'  /*Unspecified fracture of left lower leg, subsequent encounter for open fracture type I or II with routine healing*/
,'S8292XF'  /*Unspecified fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with routine healing*/
,'S8292XG'  /*Unspecified fracture of left lower leg, subsequent encounter for closed fracture with delayed healing*/
,'S8292XH'  /*Unspecified fracture of left lower leg, subsequent encounter for open fracture type I or II with delayed healing*/
,'S8292XJ'  /*Unspecified fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with delayed healing*/
,'S8292XK'  /*Unspecified fracture of left lower leg, subsequent encounter for closed fracture with nonunion*/
,'S8292XM'  /*Unspecified fracture of left lower leg, subsequent encounter for open fracture type I or II with nonunion*/
,'S8292XN'  /*Unspecified fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with nonunion*/
,'S8292XP'  /*Unspecified fracture of left lower leg, subsequent encounter for closed fracture with malunion*/
,'S8292XQ'  /*Unspecified fracture of left lower leg, subsequent encounter for open fracture type I or II with malunion*/
,'S8292XR'  /*Unspecified fracture of left lower leg, subsequent encounter for open fracture type IIIA, IIIB, or IIIC with malunion*/
,'S8292XS'  /*Unspecified fracture of left lower leg, sequela*/
,'S83001D'  /*Unspecified subluxation of right patella, subsequent encounter*/
,'S83001S'  /*Unspecified subluxation of right patella, sequela*/
,'S83002D'  /*Unspecified subluxation of left patella, subsequent encounter*/
,'S83002S'  /*Unspecified subluxation of left patella, sequela*/
,'S83003D'  /*Unspecified subluxation of unspecified patella, subsequent encounter*/
,'S83003S'  /*Unspecified subluxation of unspecified patella, sequela*/
,'S83004D'  /*Unspecified dislocation of right patella, subsequent encounter*/
,'S83004S'  /*Unspecified dislocation of right patella, sequela*/
,'S83005D'  /*Unspecified dislocation of left patella, subsequent encounter*/
,'S83005S'  /*Unspecified dislocation of left patella, sequela*/
,'S83006D'  /*Unspecified dislocation of unspecified patella, subsequent encounter*/
,'S83006S'  /*Unspecified dislocation of unspecified patella, sequela*/
,'S83011D'  /*Lateral subluxation of right patella, subsequent encounter*/
,'S83011S'  /*Lateral subluxation of right patella, sequela*/
,'S83012D'  /*Lateral subluxation of left patella, subsequent encounter*/
,'S83012S'  /*Lateral subluxation of left patella, sequela*/
,'S83013D'  /*Lateral subluxation of unspecified patella, subsequent encounter*/
,'S83013S'  /*Lateral subluxation of unspecified patella, sequela*/
,'S83014D'  /*Lateral dislocation of right patella, subsequent encounter*/
,'S83014S'  /*Lateral dislocation of right patella, sequela*/
,'S83015D'  /*Lateral dislocation of left patella, subsequent encounter*/
,'S83015S'  /*Lateral dislocation of left patella, sequela*/
,'S83016D'  /*Lateral dislocation of unspecified patella, subsequent encounter*/
,'S83016S'  /*Lateral dislocation of unspecified patella, sequela*/
,'S83091D'  /*Other subluxation of right patella, subsequent encounter*/
,'S83091S'  /*Other subluxation of right patella, sequela*/
,'S83092D'  /*Other subluxation of left patella, subsequent encounter*/
,'S83092S'  /*Other subluxation of left patella, sequela*/
,'S83093D'  /*Other subluxation of unspecified patella, subsequent encounter*/
,'S83093S'  /*Other subluxation of unspecified patella, sequela*/
,'S83094D'  /*Other dislocation of right patella, subsequent encounter*/
,'S83094S'  /*Other dislocation of right patella, sequela*/
,'S83095D'  /*Other dislocation of left patella, subsequent encounter*/
,'S83095S'  /*Other dislocation of left patella, sequela*/
,'S83096D'  /*Other dislocation of unspecified patella, subsequent encounter*/
,'S83096S'  /*Other dislocation of unspecified patella, sequela*/
,'S83101D'  /*Unspecified subluxation of right knee, subsequent encounter*/
,'S83101S'  /*Unspecified subluxation of right knee, sequela*/
,'S83102D'  /*Unspecified subluxation of left knee, subsequent encounter*/
,'S83102S'  /*Unspecified subluxation of left knee, sequela*/
,'S83103D'  /*Unspecified subluxation of unspecified knee, subsequent encounter*/
,'S83103S'  /*Unspecified subluxation of unspecified knee, sequela*/
,'S83104D'  /*Unspecified dislocation of right knee, subsequent encounter*/
,'S83104S'  /*Unspecified dislocation of right knee, sequela*/
,'S83105D'  /*Unspecified dislocation of left knee, subsequent encounter*/
,'S83105S'  /*Unspecified dislocation of left knee, sequela*/
,'S83106D'  /*Unspecified dislocation of unspecified knee, subsequent encounter*/
,'S83106S'  /*Unspecified dislocation of unspecified knee, sequela*/
,'S83111D'  /*Anterior subluxation of proximal end of tibia, right knee, subsequent encounter*/
,'S83111S'  /*Anterior subluxation of proximal end of tibia, right knee, sequela*/
,'S83112D'  /*Anterior subluxation of proximal end of tibia, left knee, subsequent encounter*/
,'S83112S'  /*Anterior subluxation of proximal end of tibia, left knee, sequela*/
,'S83113D'  /*Anterior subluxation of proximal end of tibia, unspecified knee, subsequent encounter*/
,'S83113S'  /*Anterior subluxation of proximal end of tibia, unspecified knee, sequela*/
,'S83114D'  /*Anterior dislocation of proximal end of tibia, right knee, subsequent encounter*/
,'S83114S'  /*Anterior dislocation of proximal end of tibia, right knee, sequela*/
,'S83115D'  /*Anterior dislocation of proximal end of tibia, left knee, subsequent encounter*/
,'S83115S'  /*Anterior dislocation of proximal end of tibia, left knee, sequela*/
,'S83116D'  /*Anterior dislocation of proximal end of tibia, unspecified knee, subsequent encounter*/
,'S83116S'  /*Anterior dislocation of proximal end of tibia, unspecified knee, sequela*/
,'S83121D'  /*Posterior subluxation of proximal end of tibia, right knee, subsequent encounter*/
,'S83121S'  /*Posterior subluxation of proximal end of tibia, right knee, sequela*/
,'S83122D'  /*Posterior subluxation of proximal end of tibia, left knee, subsequent encounter*/
,'S83122S'  /*Posterior subluxation of proximal end of tibia, left knee, sequela*/
,'S83123D'  /*Posterior subluxation of proximal end of tibia, unspecified knee, subsequent encounter*/
,'S83123S'  /*Posterior subluxation of proximal end of tibia, unspecified knee, sequela*/
,'S83124D'  /*Posterior dislocation of proximal end of tibia, right knee, subsequent encounter*/
,'S83124S'  /*Posterior dislocation of proximal end of tibia, right knee, sequela*/
,'S83125D'  /*Posterior dislocation of proximal end of tibia, left knee, subsequent encounter*/
,'S83125S'  /*Posterior dislocation of proximal end of tibia, left knee, sequela*/
,'S83126D'  /*Posterior dislocation of proximal end of tibia, unspecified knee, subsequent encounter*/
,'S83126S'  /*Posterior dislocation of proximal end of tibia, unspecified knee, sequela*/
,'S83131D'  /*Medial subluxation of proximal end of tibia, right knee, subsequent encounter*/
,'S83131S'  /*Medial subluxation of proximal end of tibia, right knee, sequela*/
,'S83132D'  /*Medial subluxation of proximal end of tibia, left knee, subsequent encounter*/
,'S83132S'  /*Medial subluxation of proximal end of tibia, left knee, sequela*/
,'S83133D'  /*Medial subluxation of proximal end of tibia, unspecified knee, subsequent encounter*/
,'S83133S'  /*Medial subluxation of proximal end of tibia, unspecified knee, sequela*/
,'S83134D'  /*Medial dislocation of proximal end of tibia, right knee, subsequent encounter*/
,'S83134S'  /*Medial dislocation of proximal end of tibia, right knee, sequela*/
,'S83135D'  /*Medial dislocation of proximal end of tibia, left knee, subsequent encounter*/
,'S83135S'  /*Medial dislocation of proximal end of tibia, left knee, sequela*/
,'S83136D'  /*Medial dislocation of proximal end of tibia, unspecified knee, subsequent encounter*/
,'S83136S'  /*Medial dislocation of proximal end of tibia, unspecified knee, sequela*/
,'S83141D'  /*Lateral subluxation of proximal end of tibia, right knee, subsequent encounter*/
,'S83141S'  /*Lateral subluxation of proximal end of tibia, right knee, sequela*/
,'S83142D'  /*Lateral subluxation of proximal end of tibia, left knee, subsequent encounter*/
,'S83142S'  /*Lateral subluxation of proximal end of tibia, left knee, sequela*/
,'S83143D'  /*Lateral subluxation of proximal end of tibia, unspecified knee, subsequent encounter*/
,'S83143S'  /*Lateral subluxation of proximal end of tibia, unspecified knee, sequela*/
,'S83144D'  /*Lateral dislocation of proximal end of tibia, right knee, subsequent encounter*/
,'S83144S'  /*Lateral dislocation of proximal end of tibia, right knee, sequela*/
,'S83145D'  /*Lateral dislocation of proximal end of tibia, left knee, subsequent encounter*/
,'S83145S'  /*Lateral dislocation of proximal end of tibia, left knee, sequela*/
,'S83146D'  /*Lateral dislocation of proximal end of tibia, unspecified knee, subsequent encounter*/
,'S83146S'  /*Lateral dislocation of proximal end of tibia, unspecified knee, sequela*/
,'S83191D'  /*Other subluxation of right knee, subsequent encounter*/
,'S83191S'  /*Other subluxation of right knee, sequela*/
,'S83192D'  /*Other subluxation of left knee, subsequent encounter*/
,'S83192S'  /*Other subluxation of left knee, sequela*/
,'S83193D'  /*Other subluxation of unspecified knee, subsequent encounter*/
,'S83193S'  /*Other subluxation of unspecified knee, sequela*/
,'S83194D'  /*Other dislocation of right knee, subsequent encounter*/
,'S83194S'  /*Other dislocation of right knee, sequela*/
,'S83195D'  /*Other dislocation of left knee, subsequent encounter*/
,'S83195S'  /*Other dislocation of left knee, sequela*/
,'S83196D'  /*Other dislocation of unspecified knee, subsequent encounter*/
,'S83196S'  /*Other dislocation of unspecified knee, sequela*/
,'S83200D'  /*Bucket-handle tear of unspecified meniscus, current injury, right knee, subsequent encounter*/
,'S83200S'  /*Bucket-handle tear of unspecified meniscus, current injury, right knee, sequela*/
,'S83201D'  /*Bucket-handle tear of unspecified meniscus, current injury, left knee, subsequent encounter*/
,'S83201S'  /*Bucket-handle tear of unspecified meniscus, current injury, left knee, sequela*/
,'S83202D'  /*Bucket-handle tear of unspecified meniscus, current injury, unspecified knee, subsequent encounter*/
,'S83202S'  /*Bucket-handle tear of unspecified meniscus, current injury, unspecified knee, sequela*/
,'S83203D'  /*Other tear of unspecified meniscus, current injury, right knee, subsequent encounter*/
,'S83203S'  /*Other tear of unspecified meniscus, current injury, right knee, sequela*/
,'S83204D'  /*Other tear of unspecified meniscus, current injury, left knee, subsequent encounter*/
,'S83204S'  /*Other tear of unspecified meniscus, current injury, left knee, sequela*/
,'S83205D'  /*Other tear of unspecified meniscus, current injury, unspecified knee, subsequent encounter*/
,'S83205S'  /*Other tear of unspecified meniscus, current injury, unspecified knee, sequela*/
,'S83206D'  /*Unspecified tear of unspecified meniscus, current injury, right knee, subsequent encounter*/
,'S83206S'  /*Unspecified tear of unspecified meniscus, current injury, right knee, sequela*/
,'S83207D'  /*Unspecified tear of unspecified meniscus, current injury, left knee, subsequent encounter*/
,'S83207S'  /*Unspecified tear of unspecified meniscus, current injury, left knee, sequela*/
,'S83209D'  /*Unspecified tear of unspecified meniscus, current injury, unspecified knee, subsequent encounter*/
,'S83209S'  /*Unspecified tear of unspecified meniscus, current injury, unspecified knee, sequela*/
,'S83211D'  /*Bucket-handle tear of medial meniscus, current injury, right knee, subsequent encounter*/
,'S83211S'  /*Bucket-handle tear of medial meniscus, current injury, right knee, sequela*/
,'S83212D'  /*Bucket-handle tear of medial meniscus, current injury, left knee, subsequent encounter*/
,'S83212S'  /*Bucket-handle tear of medial meniscus, current injury, left knee, sequela*/
,'S83219D'  /*Bucket-handle tear of medial meniscus, current injury, unspecified knee, subsequent encounter*/
,'S83219S'  /*Bucket-handle tear of medial meniscus, current injury, unspecified knee, sequela*/
,'S83221D'  /*Peripheral tear of medial meniscus, current injury, right knee, subsequent encounter*/
,'S83221S'  /*Peripheral tear of medial meniscus, current injury, right knee, sequela*/
,'S83222D'  /*Peripheral tear of medial meniscus, current injury, left knee, subsequent encounter*/
,'S83222S'  /*Peripheral tear of medial meniscus, current injury, left knee, sequela*/
,'S83229D'  /*Peripheral tear of medial meniscus, current injury, unspecified knee, subsequent encounter*/
,'S83229S'  /*Peripheral tear of medial meniscus, current injury, unspecified knee, sequela*/
,'S83231D'  /*Complex tear of medial meniscus, current injury, right knee, subsequent encounter*/
,'S83231S'  /*Complex tear of medial meniscus, current injury, right knee, sequela*/
,'S83232D'  /*Complex tear of medial meniscus, current injury, left knee, subsequent encounter*/
,'S83232S'  /*Complex tear of medial meniscus, current injury, left knee, sequela*/
,'S83239D'  /*Complex tear of medial meniscus, current injury, unspecified knee, subsequent encounter*/
,'S83239S'  /*Complex tear of medial meniscus, current injury, unspecified knee, sequela*/
,'S83241D'  /*Other tear of medial meniscus, current injury, right knee, subsequent encounter*/
,'S83241S'  /*Other tear of medial meniscus, current injury, right knee, sequela*/
,'S83242D'  /*Other tear of medial meniscus, current injury, left knee, subsequent encounter*/
,'S83242S'  /*Other tear of medial meniscus, current injury, left knee, sequela*/
,'S83249D'  /*Other tear of medial meniscus, current injury, unspecified knee, subsequent encounter*/
,'S83249S'  /*Other tear of medial meniscus, current injury, unspecified knee, sequela*/
,'S83251D'  /*Bucket-handle tear of lateral meniscus, current injury, right knee, subsequent encounter*/
,'S83251S'  /*Bucket-handle tear of lateral meniscus, current injury, right knee, sequela*/
,'S83252D'  /*Bucket-handle tear of lateral meniscus, current injury, left knee, subsequent encounter*/
,'S83252S'  /*Bucket-handle tear of lateral meniscus, current injury, left knee, sequela*/
,'S83259D'  /*Bucket-handle tear of lateral meniscus, current injury, unspecified knee, subsequent encounter*/
,'S83259S'  /*Bucket-handle tear of lateral meniscus, current injury, unspecified knee, sequela*/
,'S83261D'  /*Peripheral tear of lateral meniscus, current injury, right knee, subsequent encounter*/
,'S83261S'  /*Peripheral tear of lateral meniscus, current injury, right knee, sequela*/
,'S83262D'  /*Peripheral tear of lateral meniscus, current injury, left knee, subsequent encounter*/
,'S83262S'  /*Peripheral tear of lateral meniscus, current injury, left knee, sequela*/
,'S83269D'  /*Peripheral tear of lateral meniscus, current injury, unspecified knee, subsequent encounter*/
,'S83269S'  /*Peripheral tear of lateral meniscus, current injury, unspecified knee, sequela*/
,'S83271D'  /*Complex tear of lateral meniscus, current injury, right knee, subsequent encounter*/
,'S83271S'  /*Complex tear of lateral meniscus, current injury, right knee, sequela*/
,'S83272D'  /*Complex tear of lateral meniscus, current injury, left knee, subsequent encounter*/
,'S83272S'  /*Complex tear of lateral meniscus, current injury, left knee, sequela*/
,'S83279D'  /*Complex tear of lateral meniscus, current injury, unspecified knee, subsequent encounter*/
,'S83279S'  /*Complex tear of lateral meniscus, current injury, unspecified knee, sequela*/
,'S83281D'  /*Other tear of lateral meniscus, current injury, right knee, subsequent encounter*/
,'S83281S'  /*Other tear of lateral meniscus, current injury, right knee, sequela*/
,'S83282D'  /*Other tear of lateral meniscus, current injury, left knee, subsequent encounter*/
,'S83282S'  /*Other tear of lateral meniscus, current injury, left knee, sequela*/
,'S83289D'  /*Other tear of lateral meniscus, current injury, unspecified knee, subsequent encounter*/
,'S83289S'  /*Other tear of lateral meniscus, current injury, unspecified knee, sequela*/
,'S8330XD'  /*Tear of articular cartilage of unspecified knee, current, subsequent encounter*/
,'S8330XS'  /*Tear of articular cartilage of unspecified knee, current, sequela*/
,'S8331XD'  /*Tear of articular cartilage of right knee, current, subsequent encounter*/
,'S8331XS'  /*Tear of articular cartilage of right knee, current, sequela*/
,'S8332XD'  /*Tear of articular cartilage of left knee, current, subsequent encounter*/
,'S8332XS'  /*Tear of articular cartilage of left knee, current, sequela*/
,'S83401D'  /*Sprain of unspecified collateral ligament of right knee, subsequent encounter*/
,'S83401S'  /*Sprain of unspecified collateral ligament of right knee, sequela*/
,'S83402D'  /*Sprain of unspecified collateral ligament of left knee, subsequent encounter*/
,'S83402S'  /*Sprain of unspecified collateral ligament of left knee, sequela*/
,'S83409D'  /*Sprain of unspecified collateral ligament of unspecified knee, subsequent encounter*/
,'S83409S'  /*Sprain of unspecified collateral ligament of unspecified knee, sequela*/
,'S83411D'  /*Sprain of medial collateral ligament of right knee, subsequent encounter*/
,'S83411S'  /*Sprain of medial collateral ligament of right knee, sequela*/
,'S83412D'  /*Sprain of medial collateral ligament of left knee, subsequent encounter*/
,'S83412S'  /*Sprain of medial collateral ligament of left knee, sequela*/
,'S83419D'  /*Sprain of medial collateral ligament of unspecified knee, subsequent encounter*/
,'S83419S'  /*Sprain of medial collateral ligament of unspecified knee, sequela*/
,'S83421D'  /*Sprain of lateral collateral ligament of right knee, subsequent encounter*/
,'S83421S'  /*Sprain of lateral collateral ligament of right knee, sequela*/
,'S83422D'  /*Sprain of lateral collateral ligament of left knee, subsequent encounter*/
,'S83422S'  /*Sprain of lateral collateral ligament of left knee, sequela*/
,'S83429D'  /*Sprain of lateral collateral ligament of unspecified knee, subsequent encounter*/
,'S83429S'  /*Sprain of lateral collateral ligament of unspecified knee, sequela*/
,'S83501D'  /*Sprain of unspecified cruciate ligament of right knee, subsequent encounter*/
,'S83501S'  /*Sprain of unspecified cruciate ligament of right knee, sequela*/
,'S83502D'  /*Sprain of unspecified cruciate ligament of left knee, subsequent encounter*/
,'S83502S'  /*Sprain of unspecified cruciate ligament of left knee, sequela*/
,'S83509D'  /*Sprain of unspecified cruciate ligament of unspecified knee, subsequent encounter*/
,'S83509S'  /*Sprain of unspecified cruciate ligament of unspecified knee, sequela*/
,'S83511D'  /*Sprain of anterior cruciate ligament of right knee, subsequent encounter*/
,'S83511S'  /*Sprain of anterior cruciate ligament of right knee, sequela*/
,'S83512D'  /*Sprain of anterior cruciate ligament of left knee, subsequent encounter*/
,'S83512S'  /*Sprain of anterior cruciate ligament of left knee, sequela*/
,'S83519D'  /*Sprain of anterior cruciate ligament of unspecified knee, subsequent encounter*/
,'S83519S'  /*Sprain of anterior cruciate ligament of unspecified knee, sequela*/
,'S83521D'  /*Sprain of posterior cruciate ligament of right knee, subsequent encounter*/
,'S83521S'  /*Sprain of posterior cruciate ligament of right knee, sequela*/
,'S83522D'  /*Sprain of posterior cruciate ligament of left knee, subsequent encounter*/
,'S83522S'  /*Sprain of posterior cruciate ligament of left knee, sequela*/
,'S83529D'  /*Sprain of posterior cruciate ligament of unspecified knee, subsequent encounter*/
,'S83529S'  /*Sprain of posterior cruciate ligament of unspecified knee, sequela*/
,'S8360XD'  /*Sprain of the superior tibiofibular joint and ligament, unspecified knee, subsequent encounter*/
,'S8360XS'  /*Sprain of the superior tibiofibular joint and ligament, unspecified knee, sequela*/
,'S8361XD'  /*Sprain of the superior tibiofibular joint and ligament, right knee, subsequent encounter*/
,'S8361XS'  /*Sprain of the superior tibiofibular joint and ligament, right knee, sequela*/
,'S8362XD'  /*Sprain of the superior tibiofibular joint and ligament, left knee, subsequent encounter*/
,'S8362XS'  /*Sprain of the superior tibiofibular joint and ligament, left knee, sequela*/
,'S838X1D'  /*Sprain of other specified parts of right knee, subsequent encounter*/
,'S838X1S'  /*Sprain of other specified parts of right knee, sequela*/
,'S838X2D'  /*Sprain of other specified parts of left knee, subsequent encounter*/
,'S838X2S'  /*Sprain of other specified parts of left knee, sequela*/
,'S838X9D'  /*Sprain of other specified parts of unspecified knee, subsequent encounter*/
,'S838X9S'  /*Sprain of other specified parts of unspecified knee, sequela*/
,'S8390XD'  /*Sprain of unspecified site of unspecified knee, subsequent encounter*/
,'S8390XS'  /*Sprain of unspecified site of unspecified knee, sequela*/
,'S8391XD'  /*Sprain of unspecified site of right knee, subsequent encounter*/
,'S8391XS'  /*Sprain of unspecified site of right knee, sequela*/
,'S8392XD'  /*Sprain of unspecified site of left knee, subsequent encounter*/
,'S8392XS'  /*Sprain of unspecified site of left knee, sequela*/
,'S8400XD'  /*Injury of tibial nerve at lower leg level, unspecified leg, subsequent encounter*/
,'S8400XS'  /*Injury of tibial nerve at lower leg level, unspecified leg, sequela*/
,'S8401XD'  /*Injury of tibial nerve at lower leg level, right leg, subsequent encounter*/
,'S8401XS'  /*Injury of tibial nerve at lower leg level, right leg, sequela*/
,'S8402XD'  /*Injury of tibial nerve at lower leg level, left leg, subsequent encounter*/
,'S8402XS'  /*Injury of tibial nerve at lower leg level, left leg, sequela*/
,'S8410XD'  /*Injury of peroneal nerve at lower leg level, unspecified leg, subsequent encounter*/
,'S8410XS'  /*Injury of peroneal nerve at lower leg level, unspecified leg, sequela*/
,'S8411XD'  /*Injury of peroneal nerve at lower leg level, right leg, subsequent encounter*/
,'S8411XS'  /*Injury of peroneal nerve at lower leg level, right leg, sequela*/
,'S8412XD'  /*Injury of peroneal nerve at lower leg level, left leg, subsequent encounter*/
,'S8412XS'  /*Injury of peroneal nerve at lower leg level, left leg, sequela*/
,'S8420XD'  /*Injury of cutaneous sensory nerve at lower leg level, unspecified leg, subsequent encounter*/
,'S8420XS'  /*Injury of cutaneous sensory nerve at lower leg level, unspecified leg, sequela*/
,'S8421XD'  /*Injury of cutaneous sensory nerve at lower leg level, right leg, subsequent encounter*/
,'S8421XS'  /*Injury of cutaneous sensory nerve at lower leg level, right leg, sequela*/
,'S8422XD'  /*Injury of cutaneous sensory nerve at lower leg level, left leg, subsequent encounter*/
,'S8422XS'  /*Injury of cutaneous sensory nerve at lower leg level, left leg, sequela*/
,'S84801D'  /*Injury of other nerves at lower leg level, right leg, subsequent encounter*/
,'S84801S'  /*Injury of other nerves at lower leg level, right leg, sequela*/
,'S84802D'  /*Injury of other nerves at lower leg level, left leg, subsequent encounter*/
,'S84802S'  /*Injury of other nerves at lower leg level, left leg, sequela*/
,'S84809D'  /*Injury of other nerves at lower leg level, unspecified leg, subsequent encounter*/
,'S84809S'  /*Injury of other nerves at lower leg level, unspecified leg, sequela*/
,'S8490XD'  /*Injury of unspecified nerve at lower leg level, unspecified leg, subsequent encounter*/
,'S8490XS'  /*Injury of unspecified nerve at lower leg level, unspecified leg, sequela*/
,'S8491XD'  /*Injury of unspecified nerve at lower leg level, right leg, subsequent encounter*/
,'S8491XS'  /*Injury of unspecified nerve at lower leg level, right leg, sequela*/
,'S8492XD'  /*Injury of unspecified nerve at lower leg level, left leg, subsequent encounter*/
,'S8492XS'  /*Injury of unspecified nerve at lower leg level, left leg, sequela*/
,'S85001D'  /*Unspecified injury of popliteal artery, right leg, subsequent encounter*/
,'S85001S'  /*Unspecified injury of popliteal artery, right leg, sequela*/
,'S85002D'  /*Unspecified injury of popliteal artery, left leg, subsequent encounter*/
,'S85002S'  /*Unspecified injury of popliteal artery, left leg, sequela*/
,'S85009D'  /*Unspecified injury of popliteal artery, unspecified leg, subsequent encounter*/
,'S85009S'  /*Unspecified injury of popliteal artery, unspecified leg, sequela*/
,'S85011D'  /*Laceration of popliteal artery, right leg, subsequent encounter*/
,'S85011S'  /*Laceration of popliteal artery, right leg, sequela*/
,'S85012D'  /*Laceration of popliteal artery, left leg, subsequent encounter*/
,'S85012S'  /*Laceration of popliteal artery, left leg, sequela*/
,'S85019D'  /*Laceration of popliteal artery, unspecified leg, subsequent encounter*/
,'S85019S'  /*Laceration of popliteal artery, unspecified leg, sequela*/
,'S85091D'  /*Other specified injury of popliteal artery, right leg, subsequent encounter*/
,'S85091S'  /*Other specified injury of popliteal artery, right leg, sequela*/
,'S85092D'  /*Other specified injury of popliteal artery, left leg, subsequent encounter*/
,'S85092S'  /*Other specified injury of popliteal artery, left leg, sequela*/
,'S85099D'  /*Other specified injury of popliteal artery, unspecified leg, subsequent encounter*/
,'S85099S'  /*Other specified injury of popliteal artery, unspecified leg, sequela*/
,'S85101D'  /*Unspecified injury of unspecified tibial artery, right leg, subsequent encounter*/
,'S85101S'  /*Unspecified injury of unspecified tibial artery, right leg, sequela*/
,'S85102D'  /*Unspecified injury of unspecified tibial artery, left leg, subsequent encounter*/
,'S85102S'  /*Unspecified injury of unspecified tibial artery, left leg, sequela*/
,'S85109D'  /*Unspecified injury of unspecified tibial artery, unspecified leg, subsequent encounter*/
,'S85109S'  /*Unspecified injury of unspecified tibial artery, unspecified leg, sequela*/
,'S85111D'  /*Laceration of unspecified tibial artery, right leg, subsequent encounter*/
,'S85111S'  /*Laceration of unspecified tibial artery, right leg, sequela*/
,'S85112D'  /*Laceration of unspecified tibial artery, left leg, subsequent encounter*/
,'S85112S'  /*Laceration of unspecified tibial artery, left leg, sequela*/
,'S85119D'  /*Laceration of unspecified tibial artery, unspecified leg, subsequent encounter*/
,'S85119S'  /*Laceration of unspecified tibial artery, unspecified leg, sequela*/
,'S85121D'  /*Other specified injury of unspecified tibial artery, right leg, subsequent encounter*/
,'S85121S'  /*Other specified injury of unspecified tibial artery, right leg, sequela*/
,'S85122D'  /*Other specified injury of unspecified tibial artery, left leg, subsequent encounter*/
,'S85122S'  /*Other specified injury of unspecified tibial artery, left leg, sequela*/
,'S85129D'  /*Other specified injury of unspecified tibial artery, unspecified leg, subsequent encounter*/
,'S85129S'  /*Other specified injury of unspecified tibial artery, unspecified leg, sequela*/
,'S85131D'  /*Unspecified injury of anterior tibial artery, right leg, subsequent encounter*/
,'S85131S'  /*Unspecified injury of anterior tibial artery, right leg, sequela*/
,'S85132D'  /*Unspecified injury of anterior tibial artery, left leg, subsequent encounter*/
,'S85132S'  /*Unspecified injury of anterior tibial artery, left leg, sequela*/
,'S85139D'  /*Unspecified injury of anterior tibial artery, unspecified leg, subsequent encounter*/
,'S85139S'  /*Unspecified injury of anterior tibial artery, unspecified leg, sequela*/
,'S85141D'  /*Laceration of anterior tibial artery, right leg, subsequent encounter*/
,'S85141S'  /*Laceration of anterior tibial artery, right leg, sequela*/
,'S85142D'  /*Laceration of anterior tibial artery, left leg, subsequent encounter*/
,'S85142S'  /*Laceration of anterior tibial artery, left leg, sequela*/
,'S85149D'  /*Laceration of anterior tibial artery, unspecified leg, subsequent encounter*/
,'S85149S'  /*Laceration of anterior tibial artery, unspecified leg, sequela*/
,'S85151D'  /*Other specified injury of anterior tibial artery, right leg, subsequent encounter*/
,'S85151S'  /*Other specified injury of anterior tibial artery, right leg, sequela*/
,'S85152D'  /*Other specified injury of anterior tibial artery, left leg, subsequent encounter*/
,'S85152S'  /*Other specified injury of anterior tibial artery, left leg, sequela*/
,'S85159D'  /*Other specified injury of anterior tibial artery, unspecified leg, subsequent encounter*/
,'S85159S'  /*Other specified injury of anterior tibial artery, unspecified leg, sequela*/
,'S85161D'  /*Unspecified injury of posterior tibial artery, right leg, subsequent encounter*/
,'S85161S'  /*Unspecified injury of posterior tibial artery, right leg, sequela*/
,'S85162D'  /*Unspecified injury of posterior tibial artery, left leg, subsequent encounter*/
,'S85162S'  /*Unspecified injury of posterior tibial artery, left leg, sequela*/
,'S85169D'  /*Unspecified injury of posterior tibial artery, unspecified leg, subsequent encounter*/
,'S85169S'  /*Unspecified injury of posterior tibial artery, unspecified leg, sequela*/
,'S85171D'  /*Laceration of posterior tibial artery, right leg, subsequent encounter*/
,'S85171S'  /*Laceration of posterior tibial artery, right leg, sequela*/
,'S85172D'  /*Laceration of posterior tibial artery, left leg, subsequent encounter*/
,'S85172S'  /*Laceration of posterior tibial artery, left leg, sequela*/
,'S85179D'  /*Laceration of posterior tibial artery, unspecified leg, subsequent encounter*/
,'S85179S'  /*Laceration of posterior tibial artery, unspecified leg, sequela*/
,'S85181D'  /*Other specified injury of posterior tibial artery, right leg, subsequent encounter*/
,'S85181S'  /*Other specified injury of posterior tibial artery, right leg, sequela*/
,'S85182D'  /*Other specified injury of posterior tibial artery, left leg, subsequent encounter*/
,'S85182S'  /*Other specified injury of posterior tibial artery, left leg, sequela*/
,'S85189D'  /*Other specified injury of posterior tibial artery, unspecified leg, subsequent encounter*/
,'S85189S'  /*Other specified injury of posterior tibial artery, unspecified leg, sequela*/
,'S85201D'  /*Unspecified injury of peroneal artery, right leg, subsequent encounter*/
,'S85201S'  /*Unspecified injury of peroneal artery, right leg, sequela*/
,'S85202D'  /*Unspecified injury of peroneal artery, left leg, subsequent encounter*/
,'S85202S'  /*Unspecified injury of peroneal artery, left leg, sequela*/
,'S85209D'  /*Unspecified injury of peroneal artery, unspecified leg, subsequent encounter*/
,'S85209S'  /*Unspecified injury of peroneal artery, unspecified leg, sequela*/
,'S85211D'  /*Laceration of peroneal artery, right leg, subsequent encounter*/
,'S85211S'  /*Laceration of peroneal artery, right leg, sequela*/
,'S85212D'  /*Laceration of peroneal artery, left leg, subsequent encounter*/
,'S85212S'  /*Laceration of peroneal artery, left leg, sequela*/
,'S85219D'  /*Laceration of peroneal artery, unspecified leg, subsequent encounter*/
,'S85219S'  /*Laceration of peroneal artery, unspecified leg, sequela*/
,'S85291D'  /*Other specified injury of peroneal artery, right leg, subsequent encounter*/
,'S85291S'  /*Other specified injury of peroneal artery, right leg, sequela*/
,'S85292D'  /*Other specified injury of peroneal artery, left leg, subsequent encounter*/
,'S85292S'  /*Other specified injury of peroneal artery, left leg, sequela*/
,'S85299D'  /*Other specified injury of peroneal artery, unspecified leg, subsequent encounter*/
,'S85299S'  /*Other specified injury of peroneal artery, unspecified leg, sequela*/
,'S85301D'  /*Unspecified injury of greater saphenous vein at lower leg level, right leg, subsequent encounter*/
,'S85301S'  /*Unspecified injury of greater saphenous vein at lower leg level, right leg, sequela*/
,'S85302D'  /*Unspecified injury of greater saphenous vein at lower leg level, left leg, subsequent encounter*/
,'S85302S'  /*Unspecified injury of greater saphenous vein at lower leg level, left leg, sequela*/
,'S85309D'  /*Unspecified injury of greater saphenous vein at lower leg level, unspecified leg, subsequent encounter*/
,'S85309S'  /*Unspecified injury of greater saphenous vein at lower leg level, unspecified leg, sequela*/
,'S85311D'  /*Laceration of greater saphenous vein at lower leg level, right leg, subsequent encounter*/
,'S85311S'  /*Laceration of greater saphenous vein at lower leg level, right leg, sequela*/
,'S85312D'  /*Laceration of greater saphenous vein at lower leg level, left leg, subsequent encounter*/
,'S85312S'  /*Laceration of greater saphenous vein at lower leg level, left leg, sequela*/
,'S85319D'  /*Laceration of greater saphenous vein at lower leg level, unspecified leg, subsequent encounter*/
,'S85319S'  /*Laceration of greater saphenous vein at lower leg level, unspecified leg, sequela*/
,'S85391D'  /*Other specified injury of greater saphenous vein at lower leg level, right leg, subsequent encounter*/
,'S85391S'  /*Other specified injury of greater saphenous vein at lower leg level, right leg, sequela*/
,'S85392D'  /*Other specified injury of greater saphenous vein at lower leg level, left leg, subsequent encounter*/
,'S85392S'  /*Other specified injury of greater saphenous vein at lower leg level, left leg, sequela*/
,'S85399D'  /*Other specified injury of greater saphenous vein at lower leg level, unspecified leg, subsequent encounter*/
,'S85399S'  /*Other specified injury of greater saphenous vein at lower leg level, unspecified leg, sequela*/
,'S85401D'  /*Unspecified injury of lesser saphenous vein at lower leg level, right leg, subsequent encounter*/
,'S85401S'  /*Unspecified injury of lesser saphenous vein at lower leg level, right leg, sequela*/
,'S85402D'  /*Unspecified injury of lesser saphenous vein at lower leg level, left leg, subsequent encounter*/
,'S85402S'  /*Unspecified injury of lesser saphenous vein at lower leg level, left leg, sequela*/
,'S85409D'  /*Unspecified injury of lesser saphenous vein at lower leg level, unspecified leg, subsequent encounter*/
,'S85409S'  /*Unspecified injury of lesser saphenous vein at lower leg level, unspecified leg, sequela*/
,'S85411D'  /*Laceration of lesser saphenous vein at lower leg level, right leg, subsequent encounter*/
,'S85411S'  /*Laceration of lesser saphenous vein at lower leg level, right leg, sequela*/
,'S85412D'  /*Laceration of lesser saphenous vein at lower leg level, left leg, subsequent encounter*/
,'S85412S'  /*Laceration of lesser saphenous vein at lower leg level, left leg, sequela*/
,'S85419D'  /*Laceration of lesser saphenous vein at lower leg level, unspecified leg, subsequent encounter*/
,'S85419S'  /*Laceration of lesser saphenous vein at lower leg level, unspecified leg, sequela*/
,'S85491D'  /*Other specified injury of lesser saphenous vein at lower leg level, right leg, subsequent encounter*/
,'S85491S'  /*Other specified injury of lesser saphenous vein at lower leg level, right leg, sequela*/
,'S85492D'  /*Other specified injury of lesser saphenous vein at lower leg level, left leg, subsequent encounter*/
,'S85492S'  /*Other specified injury of lesser saphenous vein at lower leg level, left leg, sequela*/
,'S85499D'  /*Other specified injury of lesser saphenous vein at lower leg level, unspecified leg, subsequent encounter*/
,'S85499S'  /*Other specified injury of lesser saphenous vein at lower leg level, unspecified leg, sequela*/
,'S85501D'  /*Unspecified injury of popliteal vein, right leg, subsequent encounter*/
,'S85501S'  /*Unspecified injury of popliteal vein, right leg, sequela*/
,'S85502D'  /*Unspecified injury of popliteal vein, left leg, subsequent encounter*/
,'S85502S'  /*Unspecified injury of popliteal vein, left leg, sequela*/
,'S85509D'  /*Unspecified injury of popliteal vein, unspecified leg, subsequent encounter*/
,'S85509S'  /*Unspecified injury of popliteal vein, unspecified leg, sequela*/
,'S85511D'  /*Laceration of popliteal vein, right leg, subsequent encounter*/
,'S85511S'  /*Laceration of popliteal vein, right leg, sequela*/
,'S85512D'  /*Laceration of popliteal vein, left leg, subsequent encounter*/
,'S85512S'  /*Laceration of popliteal vein, left leg, sequela*/
,'S85519D'  /*Laceration of popliteal vein, unspecified leg, subsequent encounter*/
,'S85519S'  /*Laceration of popliteal vein, unspecified leg, sequela*/
,'S85591D'  /*Other specified injury of popliteal vein, right leg, subsequent encounter*/
,'S85591S'  /*Other specified injury of popliteal vein, right leg, sequela*/
,'S85592D'  /*Other specified injury of popliteal vein, left leg, subsequent encounter*/
,'S85592S'  /*Other specified injury of popliteal vein, left leg, sequela*/
,'S85599D'  /*Other specified injury of popliteal vein, unspecified leg, subsequent encounter*/
,'S85599S'  /*Other specified injury of popliteal vein, unspecified leg, sequela*/
,'S85801D'  /*Unspecified injury of other blood vessels at lower leg level, right leg, subsequent encounter*/
,'S85801S'  /*Unspecified injury of other blood vessels at lower leg level, right leg, sequela*/
,'S85802D'  /*Unspecified injury of other blood vessels at lower leg level, left leg, subsequent encounter*/
,'S85802S'  /*Unspecified injury of other blood vessels at lower leg level, left leg, sequela*/
,'S85809D'  /*Unspecified injury of other blood vessels at lower leg level, unspecified leg, subsequent encounter*/
,'S85809S'  /*Unspecified injury of other blood vessels at lower leg level, unspecified leg, sequela*/
,'S85811D'  /*Laceration of other blood vessels at lower leg level, right leg, subsequent encounter*/
,'S85811S'  /*Laceration of other blood vessels at lower leg level, right leg, sequela*/
,'S85812D'  /*Laceration of other blood vessels at lower leg level, left leg, subsequent encounter*/
,'S85812S'  /*Laceration of other blood vessels at lower leg level, left leg, sequela*/
,'S85819D'  /*Laceration of other blood vessels at lower leg level, unspecified leg, subsequent encounter*/
,'S85819S'  /*Laceration of other blood vessels at lower leg level, unspecified leg, sequela*/
,'S85891D'  /*Other specified injury of other blood vessels at lower leg level, right leg, subsequent encounter*/
,'S85891S'  /*Other specified injury of other blood vessels at lower leg level, right leg, sequela*/
,'S85892D'  /*Other specified injury of other blood vessels at lower leg level, left leg, subsequent encounter*/
,'S85892S'  /*Other specified injury of other blood vessels at lower leg level, left leg, sequela*/
,'S85899D'  /*Other specified injury of other blood vessels at lower leg level, unspecified leg, subsequent encounter*/
,'S85899S'  /*Other specified injury of other blood vessels at lower leg level, unspecified leg, sequela*/
,'S85901D'  /*Unspecified injury of unspecified blood vessel at lower leg level, right leg, subsequent encounter*/
,'S85901S'  /*Unspecified injury of unspecified blood vessel at lower leg level, right leg, sequela*/
,'S85902D'  /*Unspecified injury of unspecified blood vessel at lower leg level, left leg, subsequent encounter*/
,'S85902S'  /*Unspecified injury of unspecified blood vessel at lower leg level, left leg, sequela*/
,'S85909D'  /*Unspecified injury of unspecified blood vessel at lower leg level, unspecified leg, subsequent encounter*/
,'S85909S'  /*Unspecified injury of unspecified blood vessel at lower leg level, unspecified leg, sequela*/
,'S85911D'  /*Laceration of unspecified blood vessel at lower leg level, right leg, subsequent encounter*/
,'S85911S'  /*Laceration of unspecified blood vessel at lower leg level, right leg, sequela*/
,'S85912D'  /*Laceration of unspecified blood vessel at lower leg level, left leg, subsequent encounter*/
,'S85912S'  /*Laceration of unspecified blood vessel at lower leg level, left leg, sequela*/
,'S85919D'  /*Laceration of unspecified blood vessel at lower leg level, unspecified leg, subsequent encounter*/
,'S85919S'  /*Laceration of unspecified blood vessel at lower leg level, unspecified leg, sequela*/
,'S85991D'  /*Other specified injury of unspecified blood vessel at lower leg level, right leg, subsequent encounter*/
,'S85991S'  /*Other specified injury of unspecified blood vessel at lower leg level, right leg, sequela*/
,'S85992D'  /*Other specified injury of unspecified blood vessel at lower leg level, left leg, subsequent encounter*/
,'S85992S'  /*Other specified injury of unspecified blood vessel at lower leg level, left leg, sequela*/
,'S85999D'  /*Other specified injury of unspecified blood vessel at lower leg level, unspecified leg, subsequent encounter*/
,'S85999S'  /*Other specified injury of unspecified blood vessel at lower leg level, unspecified leg, sequela*/
,'S86001D'  /*Unspecified injury of right Achilles tendon, subsequent encounter*/
,'S86001S'  /*Unspecified injury of right Achilles tendon, sequela*/
,'S86002D'  /*Unspecified injury of left Achilles tendon, subsequent encounter*/
,'S86002S'  /*Unspecified injury of left Achilles tendon, sequela*/
,'S86009D'  /*Unspecified injury of unspecified Achilles tendon, subsequent encounter*/
,'S86009S'  /*Unspecified injury of unspecified Achilles tendon, sequela*/
,'S86011D'  /*Strain of right Achilles tendon, subsequent encounter*/
,'S86011S'  /*Strain of right Achilles tendon, sequela*/
,'S86012D'  /*Strain of left Achilles tendon, subsequent encounter*/
,'S86012S'  /*Strain of left Achilles tendon, sequela*/
,'S86019D'  /*Strain of unspecified Achilles tendon, subsequent encounter*/
,'S86019S'  /*Strain of unspecified Achilles tendon, sequela*/
,'S86021D'  /*Laceration of right Achilles tendon, subsequent encounter*/
,'S86021S'  /*Laceration of right Achilles tendon, sequela*/
,'S86022D'  /*Laceration of left Achilles tendon, subsequent encounter*/
,'S86022S'  /*Laceration of left Achilles tendon, sequela*/
,'S86029D'  /*Laceration of unspecified Achilles tendon, subsequent encounter*/
,'S86029S'  /*Laceration of unspecified Achilles tendon, sequela*/
,'S86091D'  /*Other specified injury of right Achilles tendon, subsequent encounter*/
,'S86091S'  /*Other specified injury of right Achilles tendon, sequela*/
,'S86092D'  /*Other specified injury of left Achilles tendon, subsequent encounter*/
,'S86092S'  /*Other specified injury of left Achilles tendon, sequela*/
,'S86099D'  /*Other specified injury of unspecified Achilles tendon, subsequent encounter*/
,'S86099S'  /*Other specified injury of unspecified Achilles tendon, sequela*/
,'S86101D'  /*Unspecified injury of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, right leg, subsequent encounter*/
,'S86101S'  /*Unspecified injury of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, right leg, sequela*/
,'S86102D'  /*Unspecified injury of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, left leg, subsequent encounter*/
,'S86102S'  /*Unspecified injury of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, left leg, sequela*/
,'S86109D'  /*Unspecified injury of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, unspecified leg, subsequent encounter*/
,'S86109S'  /*Unspecified injury of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, unspecified leg, sequela*/
,'S86111D'  /*Strain of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, right leg, subsequent encounter*/
,'S86111S'  /*Strain of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, right leg, sequela*/
,'S86112D'  /*Strain of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, left leg, subsequent encounter*/
,'S86112S'  /*Strain of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, left leg, sequela*/
,'S86119D'  /*Strain of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, unspecified leg, subsequent encounter*/
,'S86119S'  /*Strain of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, unspecified leg, sequela*/
,'S86121D'  /*Laceration of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, right leg, subsequent encounter*/
,'S86121S'  /*Laceration of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, right leg, sequela*/
,'S86122D'  /*Laceration of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, left leg, subsequent encounter*/
,'S86122S'  /*Laceration of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, left leg, sequela*/
,'S86129D'  /*Laceration of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, unspecified leg, subsequent encounter*/
,'S86129S'  /*Laceration of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, unspecified leg, sequela*/
,'S86191D'  /*Other injury of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, right leg, subsequent encounter*/
,'S86191S'  /*Other injury of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, right leg, sequela*/
,'S86192D'  /*Other injury of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, left leg, subsequent encounter*/
,'S86192S'  /*Other injury of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, left leg, sequela*/
,'S86199D'  /*Other injury of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, unspecified leg, subsequent encounter*/
,'S86199S'  /*Other injury of other muscle(s) and tendon(s) of posterior muscle group at lower leg level, unspecified leg, sequela*/
,'S86201D'  /*Unspecified injury of muscle(s) and tendon(s) of anterior muscle group at lower leg level, right leg, subsequent encounter*/
,'S86201S'  /*Unspecified injury of muscle(s) and tendon(s) of anterior muscle group at lower leg level, right leg, sequela*/
,'S86202D'  /*Unspecified injury of muscle(s) and tendon(s) of anterior muscle group at lower leg level, left leg, subsequent encounter*/
,'S86202S'  /*Unspecified injury of muscle(s) and tendon(s) of anterior muscle group at lower leg level, left leg, sequela*/
,'S86209D'  /*Unspecified injury of muscle(s) and tendon(s) of anterior muscle group at lower leg level, unspecified leg, subsequent encounter*/
,'S86209S'  /*Unspecified injury of muscle(s) and tendon(s) of anterior muscle group at lower leg level, unspecified leg, sequela*/
,'S86211D'  /*Strain of muscle(s) and tendon(s) of anterior muscle group at lower leg level, right leg, subsequent encounter*/
,'S86211S'  /*Strain of muscle(s) and tendon(s) of anterior muscle group at lower leg level, right leg, sequela*/
,'S86212D'  /*Strain of muscle(s) and tendon(s) of anterior muscle group at lower leg level, left leg, subsequent encounter*/
,'S86212S'  /*Strain of muscle(s) and tendon(s) of anterior muscle group at lower leg level, left leg, sequela*/
,'S86219D'  /*Strain of muscle(s) and tendon(s) of anterior muscle group at lower leg level, unspecified leg, subsequent encounter*/
,'S86219S'  /*Strain of muscle(s) and tendon(s) of anterior muscle group at lower leg level, unspecified leg, sequela*/
,'S86221D'  /*Laceration of muscle(s) and tendon(s) of anterior muscle group at lower leg level, right leg, subsequent encounter*/
,'S86221S'  /*Laceration of muscle(s) and tendon(s) of anterior muscle group at lower leg level, right leg, sequela*/
,'S86222D'  /*Laceration of muscle(s) and tendon(s) of anterior muscle group at lower leg level, left leg, subsequent encounter*/
,'S86222S'  /*Laceration of muscle(s) and tendon(s) of anterior muscle group at lower leg level, left leg, sequela*/
,'S86229D'  /*Laceration of muscle(s) and tendon(s) of anterior muscle group at lower leg level, unspecified leg, subsequent encounter*/
,'S86229S'  /*Laceration of muscle(s) and tendon(s) of anterior muscle group at lower leg level, unspecified leg, sequela*/
,'S86291D'  /*Other injury of muscle(s) and tendon(s) of anterior muscle group at lower leg level, right leg, subsequent encounter*/
,'S86291S'  /*Other injury of muscle(s) and tendon(s) of anterior muscle group at lower leg level, right leg, sequela*/
,'S86292D'  /*Other injury of muscle(s) and tendon(s) of anterior muscle group at lower leg level, left leg, subsequent encounter*/
,'S86292S'  /*Other injury of muscle(s) and tendon(s) of anterior muscle group at lower leg level, left leg, sequela*/
,'S86299D'  /*Other injury of muscle(s) and tendon(s) of anterior muscle group at lower leg level, unspecified leg, subsequent encounter*/
,'S86299S'  /*Other injury of muscle(s) and tendon(s) of anterior muscle group at lower leg level, unspecified leg, sequela*/
,'S86301D'  /*Unspecified injury of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, right leg, subsequent encounter*/
,'S86301S'  /*Unspecified injury of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, right leg, sequela*/
,'S86302D'  /*Unspecified injury of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, left leg, subsequent encounter*/
,'S86302S'  /*Unspecified injury of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, left leg, sequela*/
,'S86309D'  /*Unspecified injury of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, unspecified leg, subsequent encounter*/
,'S86309S'  /*Unspecified injury of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, unspecified leg, sequela*/
,'S86311D'  /*Strain of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, right leg, subsequent encounter*/
,'S86311S'  /*Strain of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, right leg, sequela*/
,'S86312D'  /*Strain of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, left leg, subsequent encounter*/
,'S86312S'  /*Strain of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, left leg, sequela*/
,'S86319D'  /*Strain of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, unspecified leg, subsequent encounter*/
,'S86319S'  /*Strain of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, unspecified leg, sequela*/
,'S86321D'  /*Laceration of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, right leg, subsequent encounter*/
,'S86321S'  /*Laceration of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, right leg, sequela*/
,'S86322D'  /*Laceration of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, left leg, subsequent encounter*/
,'S86322S'  /*Laceration of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, left leg, sequela*/
,'S86329D'  /*Laceration of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, unspecified leg, subsequent encounter*/
,'S86329S'  /*Laceration of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, unspecified leg, sequela*/
,'S86391D'  /*Other injury of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, right leg, subsequent encounter*/
,'S86391S'  /*Other injury of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, right leg, sequela*/
,'S86392D'  /*Other injury of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, left leg, subsequent encounter*/
,'S86392S'  /*Other injury of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, left leg, sequela*/
,'S86399D'  /*Other injury of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, unspecified leg, subsequent encounter*/
,'S86399S'  /*Other injury of muscle(s) and tendon(s) of peroneal muscle group at lower leg level, unspecified leg, sequela*/
,'S86801D'  /*Unspecified injury of other muscle(s) and tendon(s) at lower leg level, right leg, subsequent encounter*/
,'S86801S'  /*Unspecified injury of other muscle(s) and tendon(s) at lower leg level, right leg, sequela*/
,'S86802D'  /*Unspecified injury of other muscle(s) and tendon(s) at lower leg level, left leg, subsequent encounter*/
,'S86802S'  /*Unspecified injury of other muscle(s) and tendon(s) at lower leg level, left leg, sequela*/
,'S86809D'  /*Unspecified injury of other muscle(s) and tendon(s) at lower leg level, unspecified leg, subsequent encounter*/
,'S86809S'  /*Unspecified injury of other muscle(s) and tendon(s) at lower leg level, unspecified leg, sequela*/
,'S86811D'  /*Strain of other muscle(s) and tendon(s) at lower leg level, right leg, subsequent encounter*/
,'S86811S'  /*Strain of other muscle(s) and tendon(s) at lower leg level, right leg, sequela*/
,'S86812D'  /*Strain of other muscle(s) and tendon(s) at lower leg level, left leg, subsequent encounter*/
,'S86812S'  /*Strain of other muscle(s) and tendon(s) at lower leg level, left leg, sequela*/
,'S86819D'  /*Strain of other muscle(s) and tendon(s) at lower leg level, unspecified leg, subsequent encounter*/
,'S86819S'  /*Strain of other muscle(s) and tendon(s) at lower leg level, unspecified leg, sequela*/
,'S86821D'  /*Laceration of other muscle(s) and tendon(s) at lower leg level, right leg, subsequent encounter*/
,'S86821S'  /*Laceration of other muscle(s) and tendon(s) at lower leg level, right leg, sequela*/
,'S86822D'  /*Laceration of other muscle(s) and tendon(s) at lower leg level, left leg, subsequent encounter*/
,'S86822S'  /*Laceration of other muscle(s) and tendon(s) at lower leg level, left leg, sequela*/
,'S86829D'  /*Laceration of other muscle(s) and tendon(s) at lower leg level, unspecified leg, subsequent encounter*/
,'S86829S'  /*Laceration of other muscle(s) and tendon(s) at lower leg level, unspecified leg, sequela*/
,'S86891D'  /*Other injury of other muscle(s) and tendon(s) at lower leg level, right leg, subsequent encounter*/
,'S86891S'  /*Other injury of other muscle(s) and tendon(s) at lower leg level, right leg, sequela*/
,'S86892D'  /*Other injury of other muscle(s) and tendon(s) at lower leg level, left leg, subsequent encounter*/
,'S86892S'  /*Other injury of other muscle(s) and tendon(s) at lower leg level, left leg, sequela*/
,'S86899D'  /*Other injury of other muscle(s) and tendon(s) at lower leg level, unspecified leg, subsequent encounter*/
,'S86899S'  /*Other injury of other muscle(s) and tendon(s) at lower leg level, unspecified leg, sequela*/
,'S86901D'  /*Unspecified injury of unspecified muscle(s) and tendon(s) at lower leg level, right leg, subsequent encounter*/
,'S86901S'  /*Unspecified injury of unspecified muscle(s) and tendon(s) at lower leg level, right leg, sequela*/
,'S86902D'  /*Unspecified injury of unspecified muscle(s) and tendon(s) at lower leg level, left leg, subsequent encounter*/
,'S86902S'  /*Unspecified injury of unspecified muscle(s) and tendon(s) at lower leg level, left leg, sequela*/
,'S86909D'  /*Unspecified injury of unspecified muscle(s) and tendon(s) at lower leg level, unspecified leg, subsequent encounter*/
,'S86909S'  /*Unspecified injury of unspecified muscle(s) and tendon(s) at lower leg level, unspecified leg, sequela*/
,'S86911D'  /*Strain of unspecified muscle(s) and tendon(s) at lower leg level, right leg, subsequent encounter*/
,'S86911S'  /*Strain of unspecified muscle(s) and tendon(s) at lower leg level, right leg, sequela*/
,'S86912D'  /*Strain of unspecified muscle(s) and tendon(s) at lower leg level, left leg, subsequent encounter*/
,'S86912S'  /*Strain of unspecified muscle(s) and tendon(s) at lower leg level, left leg, sequela*/
,'S86919D'  /*Strain of unspecified muscle(s) and tendon(s) at lower leg level, unspecified leg, subsequent encounter*/
,'S86919S'  /*Strain of unspecified muscle(s) and tendon(s) at lower leg level, unspecified leg, sequela*/
,'S86921D'  /*Laceration of unspecified muscle(s) and tendon(s) at lower leg level, right leg, subsequent encounter*/
,'S86921S'  /*Laceration of unspecified muscle(s) and tendon(s) at lower leg level, right leg, sequela*/
,'S86922D'  /*Laceration of unspecified muscle(s) and tendon(s) at lower leg level, left leg, subsequent encounter*/
,'S86922S'  /*Laceration of unspecified muscle(s) and tendon(s) at lower leg level, left leg, sequela*/
,'S86929D'  /*Laceration of unspecified muscle(s) and tendon(s) at lower leg level, unspecified leg, subsequent encounter*/
,'S86929S'  /*Laceration of unspecified muscle(s) and tendon(s) at lower leg level, unspecified leg, sequela*/
,'S86991D'  /*Other injury of unspecified muscle(s) and tendon(s) at lower leg level, right leg, subsequent encounter*/
,'S86991S'  /*Other injury of unspecified muscle(s) and tendon(s) at lower leg level, right leg, sequela*/
,'S86992D'  /*Other injury of unspecified muscle(s) and tendon(s) at lower leg level, left leg, subsequent encounter*/
,'S86992S'  /*Other injury of unspecified muscle(s) and tendon(s) at lower leg level, left leg, sequela*/
,'S86999D'  /*Other injury of unspecified muscle(s) and tendon(s) at lower leg level, unspecified leg, subsequent encounter*/
,'S86999S'  /*Other injury of unspecified muscle(s) and tendon(s) at lower leg level, unspecified leg, sequela*/
,'S8700XD'  /*Crushing injury of unspecified knee, subsequent encounter*/
,'S8700XS'  /*Crushing injury of unspecified knee, sequela*/
,'S8701XD'  /*Crushing injury of right knee, subsequent encounter*/
,'S8701XS'  /*Crushing injury of right knee, sequela*/
,'S8702XD'  /*Crushing injury of left knee, subsequent encounter*/
,'S8702XS'  /*Crushing injury of left knee, sequela*/
,'S8780XD'  /*Crushing injury of unspecified lower leg, subsequent encounter*/
,'S8780XS'  /*Crushing injury of unspecified lower leg, sequela*/
,'S8781XD'  /*Crushing injury of right lower leg, subsequent encounter*/
,'S8781XS'  /*Crushing injury of right lower leg, sequela*/
,'S8782XD'  /*Crushing injury of left lower leg, subsequent encounter*/
,'S8782XS'  /*Crushing injury of left lower leg, sequela*/
,'S88011D'  /*Complete traumatic amputation at knee level, right lower leg, subsequent encounter*/
,'S88011S'  /*Complete traumatic amputation at knee level, right lower leg, sequela*/
,'S88012D'  /*Complete traumatic amputation at knee level, left lower leg, subsequent encounter*/
,'S88012S'  /*Complete traumatic amputation at knee level, left lower leg, sequela*/
,'S88019D'  /*Complete traumatic amputation at knee level, unspecified lower leg, subsequent encounter*/
,'S88019S'  /*Complete traumatic amputation at knee level, unspecified lower leg, sequela*/
,'S88021D'  /*Partial traumatic amputation at knee level, right lower leg, subsequent encounter*/
,'S88021S'  /*Partial traumatic amputation at knee level, right lower leg, sequela*/
,'S88022D'  /*Partial traumatic amputation at knee level, left lower leg, subsequent encounter*/
,'S88022S'  /*Partial traumatic amputation at knee level, left lower leg, sequela*/
,'S88029D'  /*Partial traumatic amputation at knee level, unspecified lower leg, subsequent encounter*/
,'S88029S'  /*Partial traumatic amputation at knee level, unspecified lower leg, sequela*/
,'S88111D'  /*Complete traumatic amputation at level between knee and ankle, right lower leg, subsequent encounter*/
,'S88111S'  /*Complete traumatic amputation at level between knee and ankle, right lower leg, sequela*/
,'S88112D'  /*Complete traumatic amputation at level between knee and ankle, left lower leg, subsequent encounter*/
,'S88112S'  /*Complete traumatic amputation at level between knee and ankle, left lower leg, sequela*/
,'S88119D'  /*Complete traumatic amputation at level between knee and ankle, unspecified lower leg, subsequent encounter*/
,'S88119S'  /*Complete traumatic amputation at level between knee and ankle, unspecified lower leg, sequela*/
,'S88121D'  /*Partial traumatic amputation at level between knee and ankle, right lower leg, subsequent encounter*/
,'S88121S'  /*Partial traumatic amputation at level between knee and ankle, right lower leg, sequela*/
,'S88122D'  /*Partial traumatic amputation at level between knee and ankle, left lower leg, subsequent encounter*/
,'S88122S'  /*Partial traumatic amputation at level between knee and ankle, left lower leg, sequela*/
,'S88129D'  /*Partial traumatic amputation at level between knee and ankle, unspecified lower leg, subsequent encounter*/
,'S88129S'  /*Partial traumatic amputation at level between knee and ankle, unspecified lower leg, sequela*/
,'S88911D'  /*Complete traumatic amputation of right lower leg, level unspecified, subsequent encounter*/
,'S88911S'  /*Complete traumatic amputation of right lower leg, level unspecified, sequela*/
,'S88912D'  /*Complete traumatic amputation of left lower leg, level unspecified, subsequent encounter*/
,'S88912S'  /*Complete traumatic amputation of left lower leg, level unspecified, sequela*/
,'S88919D'  /*Complete traumatic amputation of unspecified lower leg, level unspecified, subsequent encounter*/
,'S88919S'  /*Complete traumatic amputation of unspecified lower leg, level unspecified, sequela*/
,'S88921D'  /*Partial traumatic amputation of right lower leg, level unspecified, subsequent encounter*/
,'S88921S'  /*Partial traumatic amputation of right lower leg, level unspecified, sequela*/
,'S88922D'  /*Partial traumatic amputation of left lower leg, level unspecified, subsequent encounter*/
,'S88922S'  /*Partial traumatic amputation of left lower leg, level unspecified, sequela*/
,'S88929D'  /*Partial traumatic amputation of unspecified lower leg, level unspecified, subsequent encounter*/
,'S88929S'  /*Partial traumatic amputation of unspecified lower leg, level unspecified, sequela*/
,'S89001D'  /*Unspecified physeal fracture of upper end of right tibia, subsequent encounter for fracture with routine healing*/
,'S89001G'  /*Unspecified physeal fracture of upper end of right tibia, subsequent encounter for fracture with delayed healing*/
,'S89001K'  /*Unspecified physeal fracture of upper end of right tibia, subsequent encounter for fracture with nonunion*/
,'S89001P'  /*Unspecified physeal fracture of upper end of right tibia, subsequent encounter for fracture with malunion*/
,'S89001S'  /*Unspecified physeal fracture of upper end of right tibia, sequela*/
,'S89002D'  /*Unspecified physeal fracture of upper end of left tibia, subsequent encounter for fracture with routine healing*/
,'S89002G'  /*Unspecified physeal fracture of upper end of left tibia, subsequent encounter for fracture with delayed healing*/
,'S89002K'  /*Unspecified physeal fracture of upper end of left tibia, subsequent encounter for fracture with nonunion*/
,'S89002P'  /*Unspecified physeal fracture of upper end of left tibia, subsequent encounter for fracture with malunion*/
,'S89002S'  /*Unspecified physeal fracture of upper end of left tibia, sequela*/
,'S89009D'  /*Unspecified physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with routine healing*/
,'S89009G'  /*Unspecified physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with delayed healing*/
,'S89009K'  /*Unspecified physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with nonunion*/
,'S89009P'  /*Unspecified physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with malunion*/
,'S89009S'  /*Unspecified physeal fracture of upper end of unspecified tibia, sequela*/
,'S89011D'  /*Salter-Harris Type I physeal fracture of upper end of right tibia, subsequent encounter for fracture with routine healing*/
,'S89011G'  /*Salter-Harris Type I physeal fracture of upper end of right tibia, subsequent encounter for fracture with delayed healing*/
,'S89011K'  /*Salter-Harris Type I physeal fracture of upper end of right tibia, subsequent encounter for fracture with nonunion*/
,'S89011P'  /*Salter-Harris Type I physeal fracture of upper end of right tibia, subsequent encounter for fracture with malunion*/
,'S89011S'  /*Salter-Harris Type I physeal fracture of upper end of right tibia, sequela*/
,'S89012D'  /*Salter-Harris Type I physeal fracture of upper end of left tibia, subsequent encounter for fracture with routine healing*/
,'S89012G'  /*Salter-Harris Type I physeal fracture of upper end of left tibia, subsequent encounter for fracture with delayed healing*/
,'S89012K'  /*Salter-Harris Type I physeal fracture of upper end of left tibia, subsequent encounter for fracture with nonunion*/
,'S89012P'  /*Salter-Harris Type I physeal fracture of upper end of left tibia, subsequent encounter for fracture with malunion*/
,'S89012S'  /*Salter-Harris Type I physeal fracture of upper end of left tibia, sequela*/
,'S89019D'  /*Salter-Harris Type I physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with routine healing*/
,'S89019G'  /*Salter-Harris Type I physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with delayed healing*/
,'S89019K'  /*Salter-Harris Type I physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with nonunion*/
,'S89019P'  /*Salter-Harris Type I physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with malunion*/
,'S89019S'  /*Salter-Harris Type I physeal fracture of upper end of unspecified tibia, sequela*/
,'S89021D'  /*Salter-Harris Type II physeal fracture of upper end of right tibia, subsequent encounter for fracture with routine healing*/
,'S89021G'  /*Salter-Harris Type II physeal fracture of upper end of right tibia, subsequent encounter for fracture with delayed healing*/
,'S89021K'  /*Salter-Harris Type II physeal fracture of upper end of right tibia, subsequent encounter for fracture with nonunion*/
,'S89021P'  /*Salter-Harris Type II physeal fracture of upper end of right tibia, subsequent encounter for fracture with malunion*/
,'S89021S'  /*Salter-Harris Type II physeal fracture of upper end of right tibia, sequela*/
,'S89022D'  /*Salter-Harris Type II physeal fracture of upper end of left tibia, subsequent encounter for fracture with routine healing*/
,'S89022G'  /*Salter-Harris Type II physeal fracture of upper end of left tibia, subsequent encounter for fracture with delayed healing*/
,'S89022K'  /*Salter-Harris Type II physeal fracture of upper end of left tibia, subsequent encounter for fracture with nonunion*/
,'S89022P'  /*Salter-Harris Type II physeal fracture of upper end of left tibia, subsequent encounter for fracture with malunion*/
,'S89022S'  /*Salter-Harris Type II physeal fracture of upper end of left tibia, sequela*/
,'S89029D'  /*Salter-Harris Type II physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with routine healing*/
,'S89029G'  /*Salter-Harris Type II physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with delayed healing*/
,'S89029K'  /*Salter-Harris Type II physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with nonunion*/
,'S89029P'  /*Salter-Harris Type II physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with malunion*/
,'S89029S'  /*Salter-Harris Type II physeal fracture of upper end of unspecified tibia, sequela*/
,'S89031D'  /*Salter-Harris Type III physeal fracture of upper end of right tibia, subsequent encounter for fracture with routine healing*/
,'S89031G'  /*Salter-Harris Type III physeal fracture of upper end of right tibia, subsequent encounter for fracture with delayed healing*/
,'S89031K'  /*Salter-Harris Type III physeal fracture of upper end of right tibia, subsequent encounter for fracture with nonunion*/
,'S89031P'  /*Salter-Harris Type III physeal fracture of upper end of right tibia, subsequent encounter for fracture with malunion*/
,'S89031S'  /*Salter-Harris Type III physeal fracture of upper end of right tibia, sequela*/
,'S89032D'  /*Salter-Harris Type III physeal fracture of upper end of left tibia, subsequent encounter for fracture with routine healing*/
,'S89032G'  /*Salter-Harris Type III physeal fracture of upper end of left tibia, subsequent encounter for fracture with delayed healing*/
,'S89032K'  /*Salter-Harris Type III physeal fracture of upper end of left tibia, subsequent encounter for fracture with nonunion*/
,'S89032P'  /*Salter-Harris Type III physeal fracture of upper end of left tibia, subsequent encounter for fracture with malunion*/
,'S89032S'  /*Salter-Harris Type III physeal fracture of upper end of left tibia, sequela*/
,'S89039D'  /*Salter-Harris Type III physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with routine healing*/
,'S89039G'  /*Salter-Harris Type III physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with delayed healing*/
,'S89039K'  /*Salter-Harris Type III physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with nonunion*/
,'S89039P'  /*Salter-Harris Type III physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with malunion*/
,'S89039S'  /*Salter-Harris Type III physeal fracture of upper end of unspecified tibia, sequela*/
,'S89041D'  /*Salter-Harris Type IV physeal fracture of upper end of right tibia, subsequent encounter for fracture with routine healing*/
,'S89041G'  /*Salter-Harris Type IV physeal fracture of upper end of right tibia, subsequent encounter for fracture with delayed healing*/
,'S89041K'  /*Salter-Harris Type IV physeal fracture of upper end of right tibia, subsequent encounter for fracture with nonunion*/
,'S89041P'  /*Salter-Harris Type IV physeal fracture of upper end of right tibia, subsequent encounter for fracture with malunion*/
,'S89041S'  /*Salter-Harris Type IV physeal fracture of upper end of right tibia, sequela*/
,'S89042D'  /*Salter-Harris Type IV physeal fracture of upper end of left tibia, subsequent encounter for fracture with routine healing*/
,'S89042G'  /*Salter-Harris Type IV physeal fracture of upper end of left tibia, subsequent encounter for fracture with delayed healing*/
,'S89042K'  /*Salter-Harris Type IV physeal fracture of upper end of left tibia, subsequent encounter for fracture with nonunion*/
,'S89042P'  /*Salter-Harris Type IV physeal fracture of upper end of left tibia, subsequent encounter for fracture with malunion*/
,'S89042S'  /*Salter-Harris Type IV physeal fracture of upper end of left tibia, sequela*/
,'S89049D'  /*Salter-Harris Type IV physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with routine healing*/
,'S89049G'  /*Salter-Harris Type IV physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with delayed healing*/
,'S89049K'  /*Salter-Harris Type IV physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with nonunion*/
,'S89049P'  /*Salter-Harris Type IV physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with malunion*/
,'S89049S'  /*Salter-Harris Type IV physeal fracture of upper end of unspecified tibia, sequela*/
,'S89091D'  /*Other physeal fracture of upper end of right tibia, subsequent encounter for fracture with routine healing*/
,'S89091G'  /*Other physeal fracture of upper end of right tibia, subsequent encounter for fracture with delayed healing*/
,'S89091K'  /*Other physeal fracture of upper end of right tibia, subsequent encounter for fracture with nonunion*/
,'S89091P'  /*Other physeal fracture of upper end of right tibia, subsequent encounter for fracture with malunion*/
,'S89091S'  /*Other physeal fracture of upper end of right tibia, sequela*/
,'S89092D'  /*Other physeal fracture of upper end of left tibia, subsequent encounter for fracture with routine healing*/
,'S89092G'  /*Other physeal fracture of upper end of left tibia, subsequent encounter for fracture with delayed healing*/
,'S89092K'  /*Other physeal fracture of upper end of left tibia, subsequent encounter for fracture with nonunion*/
,'S89092P'  /*Other physeal fracture of upper end of left tibia, subsequent encounter for fracture with malunion*/
,'S89092S'  /*Other physeal fracture of upper end of left tibia, sequela*/
,'S89099D'  /*Other physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with routine healing*/
,'S89099G'  /*Other physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with delayed healing*/
,'S89099K'  /*Other physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with nonunion*/
,'S89099P'  /*Other physeal fracture of upper end of unspecified tibia, subsequent encounter for fracture with malunion*/
,'S89099S'  /*Other physeal fracture of upper end of unspecified tibia, sequela*/
,'S89101D'  /*Unspecified physeal fracture of lower end of right tibia, subsequent encounter for fracture with routine healing*/
,'S89101G'  /*Unspecified physeal fracture of lower end of right tibia, subsequent encounter for fracture with delayed healing*/
,'S89101K'  /*Unspecified physeal fracture of lower end of right tibia, subsequent encounter for fracture with nonunion*/
,'S89101P'  /*Unspecified physeal fracture of lower end of right tibia, subsequent encounter for fracture with malunion*/
,'S89101S'  /*Unspecified physeal fracture of lower end of right tibia, sequela*/
,'S89102D'  /*Unspecified physeal fracture of lower end of left tibia, subsequent encounter for fracture with routine healing*/
,'S89102G'  /*Unspecified physeal fracture of lower end of left tibia, subsequent encounter for fracture with delayed healing*/
,'S89102K'  /*Unspecified physeal fracture of lower end of left tibia, subsequent encounter for fracture with nonunion*/
,'S89102P'  /*Unspecified physeal fracture of lower end of left tibia, subsequent encounter for fracture with malunion*/
,'S89102S'  /*Unspecified physeal fracture of lower end of left tibia, sequela*/
,'S89109D'  /*Unspecified physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with routine healing*/
,'S89109G'  /*Unspecified physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with delayed healing*/
,'S89109K'  /*Unspecified physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with nonunion*/
,'S89109P'  /*Unspecified physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with malunion*/
,'S89109S'  /*Unspecified physeal fracture of lower end of unspecified tibia, sequela*/
,'S89111D'  /*Salter-Harris Type I physeal fracture of lower end of right tibia, subsequent encounter for fracture with routine healing*/
,'S89111G'  /*Salter-Harris Type I physeal fracture of lower end of right tibia, subsequent encounter for fracture with delayed healing*/
,'S89111K'  /*Salter-Harris Type I physeal fracture of lower end of right tibia, subsequent encounter for fracture with nonunion*/
,'S89111P'  /*Salter-Harris Type I physeal fracture of lower end of right tibia, subsequent encounter for fracture with malunion*/
,'S89111S'  /*Salter-Harris Type I physeal fracture of lower end of right tibia, sequela*/
,'S89112D'  /*Salter-Harris Type I physeal fracture of lower end of left tibia, subsequent encounter for fracture with routine healing*/
,'S89112G'  /*Salter-Harris Type I physeal fracture of lower end of left tibia, subsequent encounter for fracture with delayed healing*/
,'S89112K'  /*Salter-Harris Type I physeal fracture of lower end of left tibia, subsequent encounter for fracture with nonunion*/
,'S89112P'  /*Salter-Harris Type I physeal fracture of lower end of left tibia, subsequent encounter for fracture with malunion*/
,'S89112S'  /*Salter-Harris Type I physeal fracture of lower end of left tibia, sequela*/
,'S89119D'  /*Salter-Harris Type I physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with routine healing*/
,'S89119G'  /*Salter-Harris Type I physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with delayed healing*/
,'S89119K'  /*Salter-Harris Type I physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with nonunion*/
,'S89119P'  /*Salter-Harris Type I physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with malunion*/
,'S89119S'  /*Salter-Harris Type I physeal fracture of lower end of unspecified tibia, sequela*/
,'S89121D'  /*Salter-Harris Type II physeal fracture of lower end of right tibia, subsequent encounter for fracture with routine healing*/
,'S89121G'  /*Salter-Harris Type II physeal fracture of lower end of right tibia, subsequent encounter for fracture with delayed healing*/
,'S89121K'  /*Salter-Harris Type II physeal fracture of lower end of right tibia, subsequent encounter for fracture with nonunion*/
,'S89121P'  /*Salter-Harris Type II physeal fracture of lower end of right tibia, subsequent encounter for fracture with malunion*/
,'S89121S'  /*Salter-Harris Type II physeal fracture of lower end of right tibia, sequela*/
,'S89122D'  /*Salter-Harris Type II physeal fracture of lower end of left tibia, subsequent encounter for fracture with routine healing*/
,'S89122G'  /*Salter-Harris Type II physeal fracture of lower end of left tibia, subsequent encounter for fracture with delayed healing*/
,'S89122K'  /*Salter-Harris Type II physeal fracture of lower end of left tibia, subsequent encounter for fracture with nonunion*/
,'S89122P'  /*Salter-Harris Type II physeal fracture of lower end of left tibia, subsequent encounter for fracture with malunion*/
,'S89122S'  /*Salter-Harris Type II physeal fracture of lower end of left tibia, sequela*/
,'S89129D'  /*Salter-Harris Type II physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with routine healing*/
,'S89129G'  /*Salter-Harris Type II physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with delayed healing*/
,'S89129K'  /*Salter-Harris Type II physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with nonunion*/
,'S89129P'  /*Salter-Harris Type II physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with malunion*/
,'S89129S'  /*Salter-Harris Type II physeal fracture of lower end of unspecified tibia, sequela*/
,'S89131D'  /*Salter-Harris Type III physeal fracture of lower end of right tibia, subsequent encounter for fracture with routine healing*/
,'S89131G'  /*Salter-Harris Type III physeal fracture of lower end of right tibia, subsequent encounter for fracture with delayed healing*/
,'S89131K'  /*Salter-Harris Type III physeal fracture of lower end of right tibia, subsequent encounter for fracture with nonunion*/
,'S89131P'  /*Salter-Harris Type III physeal fracture of lower end of right tibia, subsequent encounter for fracture with malunion*/
,'S89131S'  /*Salter-Harris Type III physeal fracture of lower end of right tibia, sequela*/
,'S89132D'  /*Salter-Harris Type III physeal fracture of lower end of left tibia, subsequent encounter for fracture with routine healing*/
,'S89132G'  /*Salter-Harris Type III physeal fracture of lower end of left tibia, subsequent encounter for fracture with delayed healing*/
,'S89132K'  /*Salter-Harris Type III physeal fracture of lower end of left tibia, subsequent encounter for fracture with nonunion*/
,'S89132P'  /*Salter-Harris Type III physeal fracture of lower end of left tibia, subsequent encounter for fracture with malunion*/
,'S89132S'  /*Salter-Harris Type III physeal fracture of lower end of left tibia, sequela*/
,'S89139D'  /*Salter-Harris Type III physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with routine healing*/
,'S89139G'  /*Salter-Harris Type III physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with delayed healing*/
,'S89139K'  /*Salter-Harris Type III physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with nonunion*/
,'S89139P'  /*Salter-Harris Type III physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with malunion*/
,'S89139S'  /*Salter-Harris Type III physeal fracture of lower end of unspecified tibia, sequela*/
,'S89141D'  /*Salter-Harris Type IV physeal fracture of lower end of right tibia, subsequent encounter for fracture with routine healing*/
,'S89141G'  /*Salter-Harris Type IV physeal fracture of lower end of right tibia, subsequent encounter for fracture with delayed healing*/
,'S89141K'  /*Salter-Harris Type IV physeal fracture of lower end of right tibia, subsequent encounter for fracture with nonunion*/
,'S89141P'  /*Salter-Harris Type IV physeal fracture of lower end of right tibia, subsequent encounter for fracture with malunion*/
,'S89141S'  /*Salter-Harris Type IV physeal fracture of lower end of right tibia, sequela*/
,'S89142D'  /*Salter-Harris Type IV physeal fracture of lower end of left tibia, subsequent encounter for fracture with routine healing*/
,'S89142G'  /*Salter-Harris Type IV physeal fracture of lower end of left tibia, subsequent encounter for fracture with delayed healing*/
,'S89142K'  /*Salter-Harris Type IV physeal fracture of lower end of left tibia, subsequent encounter for fracture with nonunion*/
,'S89142P'  /*Salter-Harris Type IV physeal fracture of lower end of left tibia, subsequent encounter for fracture with malunion*/
,'S89142S'  /*Salter-Harris Type IV physeal fracture of lower end of left tibia, sequela*/
,'S89149D'  /*Salter-Harris Type IV physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with routine healing*/
,'S89149G'  /*Salter-Harris Type IV physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with delayed healing*/
,'S89149K'  /*Salter-Harris Type IV physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with nonunion*/
,'S89149P'  /*Salter-Harris Type IV physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with malunion*/
,'S89149S'  /*Salter-Harris Type IV physeal fracture of lower end of unspecified tibia, sequela*/
,'S89191D'  /*Other physeal fracture of lower end of right tibia, subsequent encounter for fracture with routine healing*/
,'S89191G'  /*Other physeal fracture of lower end of right tibia, subsequent encounter for fracture with delayed healing*/
,'S89191K'  /*Other physeal fracture of lower end of right tibia, subsequent encounter for fracture with nonunion*/
,'S89191P'  /*Other physeal fracture of lower end of right tibia, subsequent encounter for fracture with malunion*/
,'S89191S'  /*Other physeal fracture of lower end of right tibia, sequela*/
,'S89192D'  /*Other physeal fracture of lower end of left tibia, subsequent encounter for fracture with routine healing*/
,'S89192G'  /*Other physeal fracture of lower end of left tibia, subsequent encounter for fracture with delayed healing*/
,'S89192K'  /*Other physeal fracture of lower end of left tibia, subsequent encounter for fracture with nonunion*/
,'S89192P'  /*Other physeal fracture of lower end of left tibia, subsequent encounter for fracture with malunion*/
,'S89192S'  /*Other physeal fracture of lower end of left tibia, sequela*/
,'S89199D'  /*Other physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with routine healing*/
,'S89199G'  /*Other physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with delayed healing*/
,'S89199K'  /*Other physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with nonunion*/
,'S89199P'  /*Other physeal fracture of lower end of unspecified tibia, subsequent encounter for fracture with malunion*/
,'S89199S'  /*Other physeal fracture of lower end of unspecified tibia, sequela*/
,'S89201D'  /*Unspecified physeal fracture of upper end of right fibula, subsequent encounter for fracture with routine healing*/
,'S89201G'  /*Unspecified physeal fracture of upper end of right fibula, subsequent encounter for fracture with delayed healing*/
,'S89201K'  /*Unspecified physeal fracture of upper end of right fibula, subsequent encounter for fracture with nonunion*/
,'S89201P'  /*Unspecified physeal fracture of upper end of right fibula, subsequent encounter for fracture with malunion*/
,'S89201S'  /*Unspecified physeal fracture of upper end of right fibula, sequela*/
,'S89202D'  /*Unspecified physeal fracture of upper end of left fibula, subsequent encounter for fracture with routine healing*/
,'S89202G'  /*Unspecified physeal fracture of upper end of left fibula, subsequent encounter for fracture with delayed healing*/
,'S89202K'  /*Unspecified physeal fracture of upper end of left fibula, subsequent encounter for fracture with nonunion*/
,'S89202P'  /*Unspecified physeal fracture of upper end of left fibula, subsequent encounter for fracture with malunion*/
,'S89202S'  /*Unspecified physeal fracture of upper end of left fibula, sequela*/
,'S89209D'  /*Unspecified physeal fracture of upper end of unspecified fibula, subsequent encounter for fracture with routine healing*/
,'S89209G'  /*Unspecified physeal fracture of upper end of unspecified fibula, subsequent encounter for fracture with delayed healing*/
,'S89209K'  /*Unspecified physeal fracture of upper end of unspecified fibula, subsequent encounter for fracture with nonunion*/
,'S89209P'  /*Unspecified physeal fracture of upper end of unspecified fibula, subsequent encounter for fracture with malunion*/
,'S89209S'  /*Unspecified physeal fracture of upper end of unspecified fibula, sequela*/
,'S89211D'  /*Salter-Harris Type I physeal fracture of upper end of right fibula, subsequent encounter for fracture with routine healing*/
,'S89211G'  /*Salter-Harris Type I physeal fracture of upper end of right fibula, subsequent encounter for fracture with delayed healing*/
,'S89211K'  /*Salter-Harris Type I physeal fracture of upper end of right fibula, subsequent encounter for fracture with nonunion*/
,'S89211P'  /*Salter-Harris Type I physeal fracture of upper end of right fibula, subsequent encounter for fracture with malunion*/
,'S89211S'  /*Salter-Harris Type I physeal fracture of upper end of right fibula, sequela*/
,'S89212D'  /*Salter-Harris Type I physeal fracture of upper end of left fibula, subsequent encounter for fracture with routine healing*/
,'S89212G'  /*Salter-Harris Type I physeal fracture of upper end of left fibula, subsequent encounter for fracture with delayed healing*/
,'S89212K'  /*Salter-Harris Type I physeal fracture of upper end of left fibula, subsequent encounter for fracture with nonunion*/
,'S89212P'  /*Salter-Harris Type I physeal fracture of upper end of left fibula, subsequent encounter for fracture with malunion*/
,'S89212S'  /*Salter-Harris Type I physeal fracture of upper end of left fibula, sequela*/
,'S89219D'  /*Salter-Harris Type I physeal fracture of upper end of unspecified fibula, subsequent encounter for fracture with routine healing*/
,'S89219G'  /*Salter-Harris Type I physeal fracture of upper end of unspecified fibula, subsequent encounter for fracture with delayed healing*/
,'S89219K'  /*Salter-Harris Type I physeal fracture of upper end of unspecified fibula, subsequent encounter for fracture with nonunion*/
,'S89219P'  /*Salter-Harris Type I physeal fracture of upper end of unspecified fibula, subsequent encounter for fracture with malunion*/
,'S89219S'  /*Salter-Harris Type I physeal fracture of upper end of unspecified fibula, sequela*/
,'S89221D'  /*Salter-Harris Type II physeal fracture of upper end of right fibula, subsequent encounter for fracture with routine healing*/
,'S89221G'  /*Salter-Harris Type II physeal fracture of upper end of right fibula, subsequent encounter for fracture with delayed healing*/
,'S89221K'  /*Salter-Harris Type II physeal fracture of upper end of right fibula, subsequent encounter for fracture with nonunion*/
,'S89221P'  /*Salter-Harris Type II physeal fracture of upper end of right fibula, subsequent encounter for fracture with malunion*/
,'S89221S'  /*Salter-Harris Type II physeal fracture of upper end of right fibula, sequela*/
,'S89222D'  /*Salter-Harris Type II physeal fracture of upper end of left fibula, subsequent encounter for fracture with routine healing*/
,'S89222G'  /*Salter-Harris Type II physeal fracture of upper end of left fibula, subsequent encounter for fracture with delayed healing*/
,'S89222K'  /*Salter-Harris Type II physeal fracture of upper end of left fibula, subsequent encounter for fracture with nonunion*/
,'S89222P'  /*Salter-Harris Type II physeal fracture of upper end of left fibula, subsequent encounter for fracture with malunion*/
,'S89222S'  /*Salter-Harris Type II physeal fracture of upper end of left fibula, sequela*/
,'S89229D'  /*Salter-Harris Type II physeal fracture of upper end of unspecified fibula, subsequent encounter for fracture with routine healing*/
,'S89229G'  /*Salter-Harris Type II physeal fracture of upper end of unspecified fibula, subsequent encounter for fracture with delayed healing*/
,'S89229K'  /*Salter-Harris Type II physeal fracture of upper end of unspecified fibula, subsequent encounter for fracture with nonunion*/
,'S89229P'  /*Salter-Harris Type II physeal fracture of upper end of unspecified fibula, subsequent encounter for fracture with malunion*/
,'S89229S'  /*Salter-Harris Type II physeal fracture of upper end of unspecified fibula, sequela*/
,'S89291D'  /*Other physeal fracture of upper end of right fibula, subsequent encounter for fracture with routine healing*/
,'S89291G'  /*Other physeal fracture of upper end of right fibula, subsequent encounter for fracture with delayed healing*/
,'S89291K'  /*Other physeal fracture of upper end of right fibula, subsequent encounter for fracture with nonunion*/
,'S89291P'  /*Other physeal fracture of upper end of right fibula, subsequent encounter for fracture with malunion*/
,'S89291S'  /*Other physeal fracture of upper end of right fibula, sequela*/
,'S89292D'  /*Other physeal fracture of upper end of left fibula, subsequent encounter for fracture with routine healing*/
,'S89292G'  /*Other physeal fracture of upper end of left fibula, subsequent encounter for fracture with delayed healing*/
,'S89292K'  /*Other physeal fracture of upper end of left fibula, subsequent encounter for fracture with nonunion*/
,'S89292P'  /*Other physeal fracture of upper end of left fibula, subsequent encounter for fracture with malunion*/
,'S89292S'  /*Other physeal fracture of upper end of left fibula, sequela*/
,'S89299D'  /*Other physeal fracture of upper end of unspecified fibula, subsequent encounter for fracture with routine healing*/
,'S89299G'  /*Other physeal fracture of upper end of unspecified fibula, subsequent encounter for fracture with delayed healing*/
,'S89299K'  /*Other physeal fracture of upper end of unspecified fibula, subsequent encounter for fracture with nonunion*/
,'S89299P'  /*Other physeal fracture of upper end of unspecified fibula, subsequent encounter for fracture with malunion*/
,'S89299S'  /*Other physeal fracture of upper end of unspecified fibula, sequela*/
,'S89301D'  /*Unspecified physeal fracture of lower end of right fibula, subsequent encounter for fracture with routine healing*/
,'S89301G'  /*Unspecified physeal fracture of lower end of right fibula, subsequent encounter for fracture with delayed healing*/
,'S89301K'  /*Unspecified physeal fracture of lower end of right fibula, subsequent encounter for fracture with nonunion*/
,'S89301P'  /*Unspecified physeal fracture of lower end of right fibula, subsequent encounter for fracture with malunion*/
,'S89301S'  /*Unspecified physeal fracture of lower end of right fibula, sequela*/
,'S89302D'  /*Unspecified physeal fracture of lower end of left fibula, subsequent encounter for fracture with routine healing*/
,'S89302G'  /*Unspecified physeal fracture of lower end of left fibula, subsequent encounter for fracture with delayed healing*/
,'S89302K'  /*Unspecified physeal fracture of lower end of left fibula, subsequent encounter for fracture with nonunion*/
,'S89302P'  /*Unspecified physeal fracture of lower end of left fibula, subsequent encounter for fracture with malunion*/
,'S89302S'  /*Unspecified physeal fracture of lower end of left fibula, sequela*/
,'S89309D'  /*Unspecified physeal fracture of lower end of unspecified fibula, subsequent encounter for fracture with routine healing*/
,'S89309G'  /*Unspecified physeal fracture of lower end of unspecified fibula, subsequent encounter for fracture with delayed healing*/
,'S89309K'  /*Unspecified physeal fracture of lower end of unspecified fibula, subsequent encounter for fracture with nonunion*/
,'S89309P'  /*Unspecified physeal fracture of lower end of unspecified fibula, subsequent encounter for fracture with malunion*/
,'S89309S'  /*Unspecified physeal fracture of lower end of unspecified fibula, sequela*/
,'S89311D'  /*Salter-Harris Type I physeal fracture of lower end of right fibula, subsequent encounter for fracture with routine healing*/
,'S89311G'  /*Salter-Harris Type I physeal fracture of lower end of right fibula, subsequent encounter for fracture with delayed healing*/
,'S89311K'  /*Salter-Harris Type I physeal fracture of lower end of right fibula, subsequent encounter for fracture with nonunion*/
,'S89311P'  /*Salter-Harris Type I physeal fracture of lower end of right fibula, subsequent encounter for fracture with malunion*/
,'S89311S'  /*Salter-Harris Type I physeal fracture of lower end of right fibula, sequela*/
,'S89312D'  /*Salter-Harris Type I physeal fracture of lower end of left fibula, subsequent encounter for fracture with routine healing*/
,'S89312G'  /*Salter-Harris Type I physeal fracture of lower end of left fibula, subsequent encounter for fracture with delayed healing*/
,'S89312K'  /*Salter-Harris Type I physeal fracture of lower end of left fibula, subsequent encounter for fracture with nonunion*/
,'S89312P'  /*Salter-Harris Type I physeal fracture of lower end of left fibula, subsequent encounter for fracture with malunion*/
,'S89312S'  /*Salter-Harris Type I physeal fracture of lower end of left fibula, sequela*/
,'S89319D'  /*Salter-Harris Type I physeal fracture of lower end of unspecified fibula, subsequent encounter for fracture with routine healing*/
,'S89319G'  /*Salter-Harris Type I physeal fracture of lower end of unspecified fibula, subsequent encounter for fracture with delayed healing*/
,'S89319K'  /*Salter-Harris Type I physeal fracture of lower end of unspecified fibula, subsequent encounter for fracture with nonunion*/
,'S89319P'  /*Salter-Harris Type I physeal fracture of lower end of unspecified fibula, subsequent encounter for fracture with malunion*/
,'S89319S'  /*Salter-Harris Type I physeal fracture of lower end of unspecified fibula, sequela*/
,'S89321D'  /*Salter-Harris Type II physeal fracture of lower end of right fibula, subsequent encounter for fracture with routine healing*/
,'S89321G'  /*Salter-Harris Type II physeal fracture of lower end of right fibula, subsequent encounter for fracture with delayed healing*/
,'S89321K'  /*Salter-Harris Type II physeal fracture of lower end of right fibula, subsequent encounter for fracture with nonunion*/
,'S89321P'  /*Salter-Harris Type II physeal fracture of lower end of right fibula, subsequent encounter for fracture with malunion*/
,'S89321S'  /*Salter-Harris Type II physeal fracture of lower end of right fibula, sequela*/
,'S89322D'  /*Salter-Harris Type II physeal fracture of lower end of left fibula, subsequent encounter for fracture with routine healing*/
,'S89322G'  /*Salter-Harris Type II physeal fracture of lower end of left fibula, subsequent encounter for fracture with delayed healing*/
,'S89322K'  /*Salter-Harris Type II physeal fracture of lower end of left fibula, subsequent encounter for fracture with nonunion*/
,'S89322P'  /*Salter-Harris Type II physeal fracture of lower end of left fibula, subsequent encounter for fracture with malunion*/
,'S89322S'  /*Salter-Harris Type II physeal fracture of lower end of left fibula, sequela*/
,'S89329D'  /*Salter-Harris Type II physeal fracture of lower end of unspecified fibula, subsequent encounter for fracture with routine healing*/
,'S89329G'  /*Salter-Harris Type II physeal fracture of lower end of unspecified fibula, subsequent encounter for fracture with delayed healing*/
,'S89329K'  /*Salter-Harris Type II physeal fracture of lower end of unspecified fibula, subsequent encounter for fracture with nonunion*/
,'S89329P'  /*Salter-Harris Type II physeal fracture of lower end of unspecified fibula, subsequent encounter for fracture with malunion*/
,'S89329S'  /*Salter-Harris Type II physeal fracture of lower end of unspecified fibula, sequela*/
,'S89391D'  /*Other physeal fracture of lower end of right fibula, subsequent encounter for fracture with routine healing*/
,'S89391G'  /*Other physeal fracture of lower end of right fibula, subsequent encounter for fracture with delayed healing*/
,'S89391K'  /*Other physeal fracture of lower end of right fibula, subsequent encounter for fracture with nonunion*/
,'S89391P'  /*Other physeal fracture of lower end of right fibula, subsequent encounter for fracture with malunion*/
,'S89391S'  /*Other physeal fracture of lower end of right fibula, sequela*/
,'S89392D'  /*Other physeal fracture of lower end of left fibula, subsequent encounter for fracture with routine healing*/
,'S89392G'  /*Other physeal fracture of lower end of left fibula, subsequent encounter for fracture with delayed healing*/
,'S89392K'  /*Other physeal fracture of lower end of left fibula, subsequent encounter for fracture with nonunion*/
,'S89392P'  /*Other physeal fracture of lower end of left fibula, subsequent encounter for fracture with malunion*/
,'S89392S'  /*Other physeal fracture of lower end of left fibula, sequela*/
,'S89399D'  /*Other physeal fracture of lower end of unspecified fibula, subsequent encounter for fracture with routine healing*/
,'S89399G'  /*Other physeal fracture of lower end of unspecified fibula, subsequent encounter for fracture with delayed healing*/
,'S89399K'  /*Other physeal fracture of lower end of unspecified fibula, subsequent encounter for fracture with nonunion*/
,'S89399P'  /*Other physeal fracture of lower end of unspecified fibula, subsequent encounter for fracture with malunion*/
,'S89399S'  /*Other physeal fracture of lower end of unspecified fibula, sequela*/
,'S8980XD'  /*Other specified injuries of unspecified lower leg, subsequent encounter*/
,'S8980XS'  /*Other specified injuries of unspecified lower leg, sequela*/
,'S8981XD'  /*Other specified injuries of right lower leg, subsequent encounter*/
,'S8981XS'  /*Other specified injuries of right lower leg, sequela*/
,'S8982XD'  /*Other specified injuries of left lower leg, subsequent encounter*/
,'S8982XS'  /*Other specified injuries of left lower leg, sequela*/
,'S8990XD'  /*Unspecified injury of unspecified lower leg, subsequent encounter*/
,'S8990XS'  /*Unspecified injury of unspecified lower leg, sequela*/
,'S8991XD'  /*Unspecified injury of right lower leg, subsequent encounter*/
,'S8991XS'  /*Unspecified injury of right lower leg, sequela*/
,'S8992XD'  /*Unspecified injury of left lower leg, subsequent encounter*/
,'S8992XS'  /*Unspecified injury of left lower leg, sequela*/
,'S9000XD'  /*Contusion of unspecified ankle, subsequent encounter*/
,'S9000XS'  /*Contusion of unspecified ankle, sequela*/
,'S9001XD'  /*Contusion of right ankle, subsequent encounter*/
,'S9001XS'  /*Contusion of right ankle, sequela*/
,'S9002XD'  /*Contusion of left ankle, subsequent encounter*/
,'S9002XS'  /*Contusion of left ankle, sequela*/
,'S90111D'  /*Contusion of right great toe without damage to nail, subsequent encounter*/
,'S90111S'  /*Contusion of right great toe without damage to nail, sequela*/
,'S90112D'  /*Contusion of left great toe without damage to nail, subsequent encounter*/
,'S90112S'  /*Contusion of left great toe without damage to nail, sequela*/
,'S90119D'  /*Contusion of unspecified great toe without damage to nail, subsequent encounter*/
,'S90119S'  /*Contusion of unspecified great toe without damage to nail, sequela*/
,'S90121D'  /*Contusion of right lesser toe(s) without damage to nail, subsequent encounter*/
,'S90121S'  /*Contusion of right lesser toe(s) without damage to nail, sequela*/
,'S90122D'  /*Contusion of left lesser toe(s) without damage to nail, subsequent encounter*/
,'S90122S'  /*Contusion of left lesser toe(s) without damage to nail, sequela*/
,'S90129D'  /*Contusion of unspecified lesser toe(s) without damage to nail, subsequent encounter*/
,'S90129S'  /*Contusion of unspecified lesser toe(s) without damage to nail, sequela*/
,'S90211D'  /*Contusion of right great toe with damage to nail, subsequent encounter*/
,'S90211S'  /*Contusion of right great toe with damage to nail, sequela*/
,'S90212D'  /*Contusion of left great toe with damage to nail, subsequent encounter*/
,'S90212S'  /*Contusion of left great toe with damage to nail, sequela*/
,'S90219D'  /*Contusion of unspecified great toe with damage to nail, subsequent encounter*/
,'S90219S'  /*Contusion of unspecified great toe with damage to nail, sequela*/
,'S90221D'  /*Contusion of right lesser toe(s) with damage to nail, subsequent encounter*/
,'S90221S'  /*Contusion of right lesser toe(s) with damage to nail, sequela*/
,'S90222D'  /*Contusion of left lesser toe(s) with damage to nail, subsequent encounter*/
,'S90222S'  /*Contusion of left lesser toe(s) with damage to nail, sequela*/
,'S90229D'  /*Contusion of unspecified lesser toe(s) with damage to nail, subsequent encounter*/
,'S90229S'  /*Contusion of unspecified lesser toe(s) with damage to nail, sequela*/
,'S9030XD'  /*Contusion of unspecified foot, subsequent encounter*/
,'S9030XS'  /*Contusion of unspecified foot, sequela*/
,'S9031XD'  /*Contusion of right foot, subsequent encounter*/
,'S9031XS'  /*Contusion of right foot, sequela*/
,'S9032XD'  /*Contusion of left foot, subsequent encounter*/
,'S9032XS'  /*Contusion of left foot, sequela*/
,'S90411D'  /*Abrasion, right great toe, subsequent encounter*/
,'S90411S'  /*Abrasion, right great toe, sequela*/
,'S90412D'  /*Abrasion, left great toe, subsequent encounter*/
,'S90412S'  /*Abrasion, left great toe, sequela*/
,'S90413D'  /*Abrasion, unspecified great toe, subsequent encounter*/
,'S90413S'  /*Abrasion, unspecified great toe, sequela*/
,'S90414D'  /*Abrasion, right lesser toe(s), subsequent encounter*/
,'S90414S'  /*Abrasion, right lesser toe(s), sequela*/
,'S90415D'  /*Abrasion, left lesser toe(s), subsequent encounter*/
,'S90415S'  /*Abrasion, left lesser toe(s), sequela*/
,'S90416D'  /*Abrasion, unspecified lesser toe(s), subsequent encounter*/
,'S90416S'  /*Abrasion, unspecified lesser toe(s), sequela*/
,'S90421D'  /*Blister (nonthermal), right great toe, subsequent encounter*/
,'S90421S'  /*Blister (nonthermal), right great toe, sequela*/
,'S90422D'  /*Blister (nonthermal), left great toe, subsequent encounter*/
,'S90422S'  /*Blister (nonthermal), left great toe, sequela*/
,'S90423D'  /*Blister (nonthermal), unspecified great toe, subsequent encounter*/
,'S90423S'  /*Blister (nonthermal), unspecified great toe, sequela*/
,'S90424D'  /*Blister (nonthermal), right lesser toe(s), subsequent encounter*/
,'S90424S'  /*Blister (nonthermal), right lesser toe(s), sequela*/
,'S90425D'  /*Blister (nonthermal), left lesser toe(s), subsequent encounter*/
,'S90425S'  /*Blister (nonthermal), left lesser toe(s), sequela*/
,'S90426D'  /*Blister (nonthermal), unspecified lesser toe(s), subsequent encounter*/
,'S90426S'  /*Blister (nonthermal), unspecified lesser toe(s), sequela*/
,'S90441D'  /*External constriction, right great toe, subsequent encounter*/
,'S90441S'  /*External constriction, right great toe, sequela*/
,'S90442D'  /*External constriction, left great toe, subsequent encounter*/
,'S90442S'  /*External constriction, left great toe, sequela*/
,'S90443D'  /*External constriction, unspecified great toe, subsequent encounter*/
,'S90443S'  /*External constriction, unspecified great toe, sequela*/
,'S90444D'  /*External constriction, right lesser toe(s), subsequent encounter*/
,'S90444S'  /*External constriction, right lesser toe(s), sequela*/
,'S90445D'  /*External constriction, left lesser toe(s), subsequent encounter*/
,'S90445S'  /*External constriction, left lesser toe(s), sequela*/
,'S90446D'  /*External constriction, unspecified lesser toe(s), subsequent encounter*/
,'S90446S'  /*External constriction, unspecified lesser toe(s), sequela*/
,'S90451D'  /*Superficial foreign body, right great toe, subsequent encounter*/
,'S90451S'  /*Superficial foreign body, right great toe, sequela*/
,'S90452D'  /*Superficial foreign body, left great toe, subsequent encounter*/
,'S90452S'  /*Superficial foreign body, left great toe, sequela*/
,'S90453D'  /*Superficial foreign body, unspecified great toe, subsequent encounter*/
,'S90453S'  /*Superficial foreign body, unspecified great toe, sequela*/
,'S90454D'  /*Superficial foreign body, right lesser toe(s), subsequent encounter*/
,'S90454S'  /*Superficial foreign body, right lesser toe(s), sequela*/
,'S90455D'  /*Superficial foreign body, left lesser toe(s), subsequent encounter*/
,'S90455S'  /*Superficial foreign body, left lesser toe(s), sequela*/
,'S90456D'  /*Superficial foreign body, unspecified lesser toe(s), subsequent encounter*/
,'S90456S'  /*Superficial foreign body, unspecified lesser toe(s), sequela*/
,'S90461D'  /*Insect bite (nonvenomous), right great toe, subsequent encounter*/
,'S90461S'  /*Insect bite (nonvenomous), right great toe, sequela*/
,'S90462D'  /*Insect bite (nonvenomous), left great toe, subsequent encounter*/
,'S90462S'  /*Insect bite (nonvenomous), left great toe, sequela*/
,'S90463D'  /*Insect bite (nonvenomous), unspecified great toe, subsequent encounter*/
,'S90463S'  /*Insect bite (nonvenomous), unspecified great toe, sequela*/
,'S90464D'  /*Insect bite (nonvenomous), right lesser toe(s), subsequent encounter*/
,'S90464S'  /*Insect bite (nonvenomous), right lesser toe(s), sequela*/
,'S90465D'  /*Insect bite (nonvenomous), left lesser toe(s), subsequent encounter*/
,'S90465S'  /*Insect bite (nonvenomous), left lesser toe(s), sequela*/
,'S90466D'  /*Insect bite (nonvenomous), unspecified lesser toe(s), subsequent encounter*/
,'S90466S'  /*Insect bite (nonvenomous), unspecified lesser toe(s), sequela*/
,'S90471D'  /*Other superficial bite of right great toe, subsequent encounter*/
,'S90471S'  /*Other superficial bite of right great toe, sequela*/
,'S90472D'  /*Other superficial bite of left great toe, subsequent encounter*/
,'S90472S'  /*Other superficial bite of left great toe, sequela*/
,'S90473D'  /*Other superficial bite of unspecified great toe, subsequent encounter*/
,'S90473S'  /*Other superficial bite of unspecified great toe, sequela*/
,'S90474D'  /*Other superficial bite of right lesser toe(s), subsequent encounter*/
,'S90474S'  /*Other superficial bite of right lesser toe(s), sequela*/
,'S90475D'  /*Other superficial bite of left lesser toe(s), subsequent encounter*/
,'S90475S'  /*Other superficial bite of left lesser toe(s), sequela*/
,'S90476D'  /*Other superficial bite of unspecified lesser toe(s), subsequent encounter*/
,'S90476S'  /*Other superficial bite of unspecified lesser toe(s), sequela*/
,'S90511D'  /*Abrasion, right ankle, subsequent encounter*/
,'S90511S'  /*Abrasion, right ankle, sequela*/
,'S90512D'  /*Abrasion, left ankle, subsequent encounter*/
,'S90512S'  /*Abrasion, left ankle, sequela*/
,'S90519D'  /*Abrasion, unspecified ankle, subsequent encounter*/
,'S90519S'  /*Abrasion, unspecified ankle, sequela*/
,'S90521D'  /*Blister (nonthermal), right ankle, subsequent encounter*/
,'S90521S'  /*Blister (nonthermal), right ankle, sequela*/
,'S90522D'  /*Blister (nonthermal), left ankle, subsequent encounter*/
,'S90522S'  /*Blister (nonthermal), left ankle, sequela*/
,'S90529D'  /*Blister (nonthermal), unspecified ankle, subsequent encounter*/
,'S90529S'  /*Blister (nonthermal), unspecified ankle, sequela*/
,'S90541D'  /*External constriction, right ankle, subsequent encounter*/
,'S90541S'  /*External constriction, right ankle, sequela*/
,'S90542D'  /*External constriction, left ankle, subsequent encounter*/
,'S90542S'  /*External constriction, left ankle, sequela*/
,'S90549D'  /*External constriction, unspecified ankle, subsequent encounter*/
,'S90549S'  /*External constriction, unspecified ankle, sequela*/
,'S90551D'  /*Superficial foreign body, right ankle, subsequent encounter*/
,'S90551S'  /*Superficial foreign body, right ankle, sequela*/
,'S90552D'  /*Superficial foreign body, left ankle, subsequent encounter*/
,'S90552S'  /*Superficial foreign body, left ankle, sequela*/
,'S90559D'  /*Superficial foreign body, unspecified ankle, subsequent encounter*/
,'S90559S'  /*Superficial foreign body, unspecified ankle, sequela*/
,'S90561D'  /*Insect bite (nonvenomous), right ankle, subsequent encounter*/
,'S90561S'  /*Insect bite (nonvenomous), right ankle, sequela*/
,'S90562D'  /*Insect bite (nonvenomous), left ankle, subsequent encounter*/
,'S90562S'  /*Insect bite (nonvenomous), left ankle, sequela*/
,'S90569D'  /*Insect bite (nonvenomous), unspecified ankle, subsequent encounter*/
,'S90569S'  /*Insect bite (nonvenomous), unspecified ankle, sequela*/
,'S90571D'  /*Other superficial bite of ankle, right ankle, subsequent encounter*/
,'S90571S'  /*Other superficial bite of ankle, right ankle, sequela*/
,'S90572D'  /*Other superficial bite of ankle, left ankle, subsequent encounter*/
,'S90572S'  /*Other superficial bite of ankle, left ankle, sequela*/
,'S90579D'  /*Other superficial bite of ankle, unspecified ankle, subsequent encounter*/
,'S90579S'  /*Other superficial bite of ankle, unspecified ankle, sequela*/
,'S90811D'  /*Abrasion, right foot, subsequent encounter*/
,'S90811S'  /*Abrasion, right foot, sequela*/
,'S90812D'  /*Abrasion, left foot, subsequent encounter*/
,'S90812S'  /*Abrasion, left foot, sequela*/
,'S90819D'  /*Abrasion, unspecified foot, subsequent encounter*/
,'S90819S'  /*Abrasion, unspecified foot, sequela*/
,'S90821D'  /*Blister (nonthermal), right foot, subsequent encounter*/
,'S90821S'  /*Blister (nonthermal), right foot, sequela*/
,'S90822D'  /*Blister (nonthermal), left foot, subsequent encounter*/
,'S90822S'  /*Blister (nonthermal), left foot, sequela*/
,'S90829D'  /*Blister (nonthermal), unspecified foot, subsequent encounter*/
,'S90829S'  /*Blister (nonthermal), unspecified foot, sequela*/
,'S90841D'  /*External constriction, right foot, subsequent encounter*/
,'S90841S'  /*External constriction, right foot, sequela*/
,'S90842D'  /*External constriction, left foot, subsequent encounter*/
,'S90842S'  /*External constriction, left foot, sequela*/
,'S90849D'  /*External constriction, unspecified foot, subsequent encounter*/
,'S90849S'  /*External constriction, unspecified foot, sequela*/
,'S90851D'  /*Superficial foreign body, right foot, subsequent encounter*/
,'S90851S'  /*Superficial foreign body, right foot, sequela*/
,'S90852D'  /*Superficial foreign body, left foot, subsequent encounter*/
,'S90852S'  /*Superficial foreign body, left foot, sequela*/
,'S90859D'  /*Superficial foreign body, unspecified foot, subsequent encounter*/
,'S90859S'  /*Superficial foreign body, unspecified foot, sequela*/
,'S90861D'  /*Insect bite (nonvenomous), right foot, subsequent encounter*/
,'S90861S'  /*Insect bite (nonvenomous), right foot, sequela*/
,'S90862D'  /*Insect bite (nonvenomous), left foot, subsequent encounter*/
,'S90862S'  /*Insect bite (nonvenomous), left foot, sequela*/
,'S90869D'  /*Insect bite (nonvenomous), unspecified foot, subsequent encounter*/
,'S90869S'  /*Insect bite (nonvenomous), unspecified foot, sequela*/
,'S90871D'  /*Other superficial bite of right foot, subsequent encounter*/
,'S90871S'  /*Other superficial bite of right foot, sequela*/
,'S90872D'  /*Other superficial bite of left foot, subsequent encounter*/
,'S90872S'  /*Other superficial bite of left foot, sequela*/
,'S90879D'  /*Other superficial bite of unspecified foot, subsequent encounter*/
,'S90879S'  /*Other superficial bite of unspecified foot, sequela*/
,'S90911D'  /*Unspecified superficial injury of right ankle, subsequent encounter*/
,'S90911S'  /*Unspecified superficial injury of right ankle, sequela*/
,'S90912D'  /*Unspecified superficial injury of left ankle, subsequent encounter*/
,'S90912S'  /*Unspecified superficial injury of left ankle, sequela*/
,'S90919D'  /*Unspecified superficial injury of unspecified ankle, subsequent encounter*/
,'S90919S'  /*Unspecified superficial injury of unspecified ankle, sequela*/
,'S90921D'  /*Unspecified superficial injury of right foot, subsequent encounter*/
,'S90921S'  /*Unspecified superficial injury of right foot, sequela*/
,'S90922D'  /*Unspecified superficial injury of left foot, subsequent encounter*/
,'S90922S'  /*Unspecified superficial injury of left foot, sequela*/
,'S90929D'  /*Unspecified superficial injury of unspecified foot, subsequent encounter*/
,'S90929S'  /*Unspecified superficial injury of unspecified foot, sequela*/
,'S90931D'  /*Unspecified superficial injury of right great toe, subsequent encounter*/
,'S90931S'  /*Unspecified superficial injury of right great toe, sequela*/
,'S90932D'  /*Unspecified superficial injury of left great toe, subsequent encounter*/
,'S90932S'  /*Unspecified superficial injury of left great toe, sequela*/
,'S90933D'  /*Unspecified superficial injury of unspecified great toe, subsequent encounter*/
,'S90933S'  /*Unspecified superficial injury of unspecified great toe, sequela*/
,'S90934D'  /*Unspecified superficial injury of right lesser toe(s), subsequent encounter*/
,'S90934S'  /*Unspecified superficial injury of right lesser toe(s), sequela*/
,'S90935D'  /*Unspecified superficial injury of left lesser toe(s), subsequent encounter*/
,'S90935S'  /*Unspecified superficial injury of left lesser toe(s), sequela*/
,'S90936D'  /*Unspecified superficial injury of unspecified lesser toe(s), subsequent encounter*/
,'S90936S'  /*Unspecified superficial injury of unspecified lesser toe(s), sequela*/
,'S91001D'  /*Unspecified open wound, right ankle, subsequent encounter*/
,'S91001S'  /*Unspecified open wound, right ankle, sequela*/
,'S91002D'  /*Unspecified open wound, left ankle, subsequent encounter*/
,'S91002S'  /*Unspecified open wound, left ankle, sequela*/
,'S91009D'  /*Unspecified open wound, unspecified ankle, subsequent encounter*/
,'S91009S'  /*Unspecified open wound, unspecified ankle, sequela*/
,'S91011D'  /*Laceration without foreign body, right ankle, subsequent encounter*/
,'S91011S'  /*Laceration without foreign body, right ankle, sequela*/
,'S91012D'  /*Laceration without foreign body, left ankle, subsequent encounter*/
,'S91012S'  /*Laceration without foreign body, left ankle, sequela*/
,'S91019D'  /*Laceration without foreign body, unspecified ankle, subsequent encounter*/
,'S91019S'  /*Laceration without foreign body, unspecified ankle, sequela*/
,'S91021D'  /*Laceration with foreign body, right ankle, subsequent encounter*/
,'S91021S'  /*Laceration with foreign body, right ankle, sequela*/
,'S91022D'  /*Laceration with foreign body, left ankle, subsequent encounter*/
,'S91022S'  /*Laceration with foreign body, left ankle, sequela*/
,'S91029D'  /*Laceration with foreign body, unspecified ankle, subsequent encounter*/
,'S91029S'  /*Laceration with foreign body, unspecified ankle, sequela*/
,'S91031D'  /*Puncture wound without foreign body, right ankle, subsequent encounter*/
,'S91031S'  /*Puncture wound without foreign body, right ankle, sequela*/
,'S91032D'  /*Puncture wound without foreign body, left ankle, subsequent encounter*/
,'S91032S'  /*Puncture wound without foreign body, left ankle, sequela*/
,'S91039D'  /*Puncture wound without foreign body, unspecified ankle, subsequent encounter*/
,'S91039S'  /*Puncture wound without foreign body, unspecified ankle, sequela*/
,'S91041D'  /*Puncture wound with foreign body, right ankle, subsequent encounter*/
,'S91041S'  /*Puncture wound with foreign body, right ankle, sequela*/
,'S91042D'  /*Puncture wound with foreign body, left ankle, subsequent encounter*/
,'S91042S'  /*Puncture wound with foreign body, left ankle, sequela*/
,'S91049D'  /*Puncture wound with foreign body, unspecified ankle, subsequent encounter*/
,'S91049S'  /*Puncture wound with foreign body, unspecified ankle, sequela*/
,'S91051D'  /*Open bite, right ankle, subsequent encounter*/
,'S91051S'  /*Open bite, right ankle, sequela*/
,'S91052D'  /*Open bite, left ankle, subsequent encounter*/
,'S91052S'  /*Open bite, left ankle, sequela*/
,'S91059D'  /*Open bite, unspecified ankle, subsequent encounter*/
,'S91059S'  /*Open bite, unspecified ankle, sequela*/
,'S91101D'  /*Unspecified open wound of right great toe without damage to nail, subsequent encounter*/
,'S91101S'  /*Unspecified open wound of right great toe without damage to nail, sequela*/
,'S91102D'  /*Unspecified open wound of left great toe without damage to nail, subsequent encounter*/
,'S91102S'  /*Unspecified open wound of left great toe without damage to nail, sequela*/
,'S91103D'  /*Unspecified open wound of unspecified great toe without damage to nail, subsequent encounter*/
,'S91103S'  /*Unspecified open wound of unspecified great toe without damage to nail, sequela*/
,'S91104D'  /*Unspecified open wound of right lesser toe(s) without damage to nail, subsequent encounter*/
,'S91104S'  /*Unspecified open wound of right lesser toe(s) without damage to nail, sequela*/
,'S91105D'  /*Unspecified open wound of left lesser toe(s) without damage to nail, subsequent encounter*/
,'S91105S'  /*Unspecified open wound of left lesser toe(s) without damage to nail, sequela*/
,'S91106D'  /*Unspecified open wound of unspecified lesser toe(s) without damage to nail, subsequent encounter*/
,'S91106S'  /*Unspecified open wound of unspecified lesser toe(s) without damage to nail, sequela*/
,'S91109D'  /*Unspecified open wound of unspecified toe(s) without damage to nail, subsequent encounter*/
,'S91109S'  /*Unspecified open wound of unspecified toe(s) without damage to nail, sequela*/
,'S91111D'  /*Laceration without foreign body of right great toe without damage to nail, subsequent encounter*/
,'S91111S'  /*Laceration without foreign body of right great toe without damage to nail, sequela*/
,'S91112D'  /*Laceration without foreign body of left great toe without damage to nail, subsequent encounter*/
,'S91112S'  /*Laceration without foreign body of left great toe without damage to nail, sequela*/
,'S91113D'  /*Laceration without foreign body of unspecified great toe without damage to nail, subsequent encounter*/
,'S91113S'  /*Laceration without foreign body of unspecified great toe without damage to nail, sequela*/
,'S91114D'  /*Laceration without foreign body of right lesser toe(s) without damage to nail, subsequent encounter*/
,'S91114S'  /*Laceration without foreign body of right lesser toe(s) without damage to nail, sequela*/
,'S91115D'  /*Laceration without foreign body of left lesser toe(s) without damage to nail, subsequent encounter*/
,'S91115S'  /*Laceration without foreign body of left lesser toe(s) without damage to nail, sequela*/
,'S91116D'  /*Laceration without foreign body of unspecified lesser toe(s) without damage to nail, subsequent encounter*/
,'S91116S'  /*Laceration without foreign body of unspecified lesser toe(s) without damage to nail, sequela*/
,'S91119D'  /*Laceration without foreign body of unspecified toe without damage to nail, subsequent encounter*/
,'S91119S'  /*Laceration without foreign body of unspecified toe without damage to nail, sequela*/
,'S91121D'  /*Laceration with foreign body of right great toe without damage to nail, subsequent encounter*/
,'S91121S'  /*Laceration with foreign body of right great toe without damage to nail, sequela*/
,'S91122D'  /*Laceration with foreign body of left great toe without damage to nail, subsequent encounter*/
,'S91122S'  /*Laceration with foreign body of left great toe without damage to nail, sequela*/
,'S91123D'  /*Laceration with foreign body of unspecified great toe without damage to nail, subsequent encounter*/
,'S91123S'  /*Laceration with foreign body of unspecified great toe without damage to nail, sequela*/
,'S91124D'  /*Laceration with foreign body of right lesser toe(s) without damage to nail, subsequent encounter*/
,'S91124S'  /*Laceration with foreign body of right lesser toe(s) without damage to nail, sequela*/
,'S91125D'  /*Laceration with foreign body of left lesser toe(s) without damage to nail, subsequent encounter*/
,'S91125S'  /*Laceration with foreign body of left lesser toe(s) without damage to nail, sequela*/
,'S91126D'  /*Laceration with foreign body of unspecified lesser toe(s) without damage to nail, subsequent encounter*/
,'S91126S'  /*Laceration with foreign body of unspecified lesser toe(s) without damage to nail, sequela*/
,'S91129D'  /*Laceration with foreign body of unspecified toe(s) without damage to nail, subsequent encounter*/
,'S91129S'  /*Laceration with foreign body of unspecified toe(s) without damage to nail, sequela*/
,'S91131D'  /*Puncture wound without foreign body of right great toe without damage to nail, subsequent encounter*/
,'S91131S'  /*Puncture wound without foreign body of right great toe without damage to nail, sequela*/
,'S91132D'  /*Puncture wound without foreign body of left great toe without damage to nail, subsequent encounter*/
,'S91132S'  /*Puncture wound without foreign body of left great toe without damage to nail, sequela*/
,'S91133D'  /*Puncture wound without foreign body of unspecified great toe without damage to nail, subsequent encounter*/
,'S91133S'  /*Puncture wound without foreign body of unspecified great toe without damage to nail, sequela*/
,'S91134D'  /*Puncture wound without foreign body of right lesser toe(s) without damage to nail, subsequent encounter*/
,'S91134S'  /*Puncture wound without foreign body of right lesser toe(s) without damage to nail, sequela*/
,'S91135D'  /*Puncture wound without foreign body of left lesser toe(s) without damage to nail, subsequent encounter*/
,'S91135S'  /*Puncture wound without foreign body of left lesser toe(s) without damage to nail, sequela*/
,'S91136D'  /*Puncture wound without foreign body of unspecified lesser toe(s) without damage to nail, subsequent encounter*/
,'S91136S'  /*Puncture wound without foreign body of unspecified lesser toe(s) without damage to nail, sequela*/
,'S91139D'  /*Puncture wound without foreign body of unspecified toe(s) without damage to nail, subsequent encounter*/
,'S91139S'  /*Puncture wound without foreign body of unspecified toe(s) without damage to nail, sequela*/
,'S91141D'  /*Puncture wound with foreign body of right great toe without damage to nail, subsequent encounter*/
,'S91141S'  /*Puncture wound with foreign body of right great toe without damage to nail, sequela*/
,'S91142D'  /*Puncture wound with foreign body of left great toe without damage to nail, subsequent encounter*/
,'S91142S'  /*Puncture wound with foreign body of left great toe without damage to nail, sequela*/
,'S91143D'  /*Puncture wound with foreign body of unspecified great toe without damage to nail, subsequent encounter*/
,'S91143S'  /*Puncture wound with foreign body of unspecified great toe without damage to nail, sequela*/
,'S91144D'  /*Puncture wound with foreign body of right lesser toe(s) without damage to nail, subsequent encounter*/
,'S91144S'  /*Puncture wound with foreign body of right lesser toe(s) without damage to nail, sequela*/
,'S91145D'  /*Puncture wound with foreign body of left lesser toe(s) without damage to nail, subsequent encounter*/
,'S91145S'  /*Puncture wound with foreign body of left lesser toe(s) without damage to nail, sequela*/
,'S91146D'  /*Puncture wound with foreign body of unspecified lesser toe(s) without damage to nail, subsequent encounter*/
,'S91146S'  /*Puncture wound with foreign body of unspecified lesser toe(s) without damage to nail, sequela*/
,'S91149D'  /*Puncture wound with foreign body of unspecified toe(s) without damage to nail, subsequent encounter*/
,'S91149S'  /*Puncture wound with foreign body of unspecified toe(s) without damage to nail, sequela*/
,'S91151D'  /*Open bite of right great toe without damage to nail, subsequent encounter*/
,'S91151S'  /*Open bite of right great toe without damage to nail, sequela*/
,'S91152D'  /*Open bite of left great toe without damage to nail, subsequent encounter*/
,'S91152S'  /*Open bite of left great toe without damage to nail, sequela*/
,'S91153D'  /*Open bite of unspecified great toe without damage to nail, subsequent encounter*/
,'S91153S'  /*Open bite of unspecified great toe without damage to nail, sequela*/
,'S91154D'  /*Open bite of right lesser toe(s) without damage to nail, subsequent encounter*/
,'S91154S'  /*Open bite of right lesser toe(s) without damage to nail, sequela*/
,'S91155D'  /*Open bite of left lesser toe(s) without damage to nail, subsequent encounter*/
,'S91155S'  /*Open bite of left lesser toe(s) without damage to nail, sequela*/
,'S91156D'  /*Open bite of unspecified lesser toe(s) without damage to nail, subsequent encounter*/
,'S91156S'  /*Open bite of unspecified lesser toe(s) without damage to nail, sequela*/
,'S91159D'  /*Open bite of unspecified toe(s) without damage to nail, subsequent encounter*/
,'S91159S'  /*Open bite of unspecified toe(s) without damage to nail, sequela*/
,'S91201D'  /*Unspecified open wound of right great toe with damage to nail, subsequent encounter*/
,'S91201S'  /*Unspecified open wound of right great toe with damage to nail, sequela*/
,'S91202D'  /*Unspecified open wound of left great toe with damage to nail, subsequent encounter*/
,'S91202S'  /*Unspecified open wound of left great toe with damage to nail, sequela*/
,'S91203D'  /*Unspecified open wound of unspecified great toe with damage to nail, subsequent encounter*/
,'S91203S'  /*Unspecified open wound of unspecified great toe with damage to nail, sequela*/
,'S91204D'  /*Unspecified open wound of right lesser toe(s) with damage to nail, subsequent encounter*/
,'S91204S'  /*Unspecified open wound of right lesser toe(s) with damage to nail, sequela*/
,'S91205D'  /*Unspecified open wound of left lesser toe(s) with damage to nail, subsequent encounter*/
,'S91205S'  /*Unspecified open wound of left lesser toe(s) with damage to nail, sequela*/
,'S91206D'  /*Unspecified open wound of unspecified lesser toe(s) with damage to nail, subsequent encounter*/
,'S91206S'  /*Unspecified open wound of unspecified lesser toe(s) with damage to nail, sequela*/
,'S91209D'  /*Unspecified open wound of unspecified toe(s) with damage to nail, subsequent encounter*/
,'S91209S'  /*Unspecified open wound of unspecified toe(s) with damage to nail, sequela*/
,'S91211D'  /*Laceration without foreign body of right great toe with damage to nail, subsequent encounter*/
,'S91211S'  /*Laceration without foreign body of right great toe with damage to nail, sequela*/
,'S91212D'  /*Laceration without foreign body of left great toe with damage to nail, subsequent encounter*/
,'S91212S'  /*Laceration without foreign body of left great toe with damage to nail, sequela*/
,'S91213D'  /*Laceration without foreign body of unspecified great toe with damage to nail, subsequent encounter*/
,'S91213S'  /*Laceration without foreign body of unspecified great toe with damage to nail, sequela*/
,'S91214D'  /*Laceration without foreign body of right lesser toe(s) with damage to nail, subsequent encounter*/
,'S91214S'  /*Laceration without foreign body of right lesser toe(s) with damage to nail, sequela*/
,'S91215D'  /*Laceration without foreign body of left lesser toe(s) with damage to nail, subsequent encounter*/
,'S91215S'  /*Laceration without foreign body of left lesser toe(s) with damage to nail, sequela*/
,'S91216D'  /*Laceration without foreign body of unspecified lesser toe(s) with damage to nail, subsequent encounter*/
,'S91216S'  /*Laceration without foreign body of unspecified lesser toe(s) with damage to nail, sequela*/
,'S91219D'  /*Laceration without foreign body of unspecified toe(s) with damage to nail, subsequent encounter*/
,'S91219S'  /*Laceration without foreign body of unspecified toe(s) with damage to nail, sequela*/
,'S91221D'  /*Laceration with foreign body of right great toe with damage to nail, subsequent encounter*/
,'S91221S'  /*Laceration with foreign body of right great toe with damage to nail, sequela*/
,'S91222D'  /*Laceration with foreign body of left great toe with damage to nail, subsequent encounter*/
,'S91222S'  /*Laceration with foreign body of left great toe with damage to nail, sequela*/
,'S91223D'  /*Laceration with foreign body of unspecified great toe with damage to nail, subsequent encounter*/
,'S91223S'  /*Laceration with foreign body of unspecified great toe with damage to nail, sequela*/
,'S91224D'  /*Laceration with foreign body of right lesser toe(s) with damage to nail, subsequent encounter*/
,'S91224S'  /*Laceration with foreign body of right lesser toe(s) with damage to nail, sequela*/
,'S91225D'  /*Laceration with foreign body of left lesser toe(s) with damage to nail, subsequent encounter*/
,'S91225S'  /*Laceration with foreign body of left lesser toe(s) with damage to nail, sequela*/
,'S91226D'  /*Laceration with foreign body of unspecified lesser toe(s) with damage to nail, subsequent encounter*/
,'S91226S'  /*Laceration with foreign body of unspecified lesser toe(s) with damage to nail, sequela*/
,'S91229D'  /*Laceration with foreign body of unspecified toe(s) with damage to nail, subsequent encounter*/
,'S91229S'  /*Laceration with foreign body of unspecified toe(s) with damage to nail, sequela*/
,'S91231D'  /*Puncture wound without foreign body of right great toe with damage to nail, subsequent encounter*/
,'S91231S'  /*Puncture wound without foreign body of right great toe with damage to nail, sequela*/
,'S91232D'  /*Puncture wound without foreign body of left great toe with damage to nail, subsequent encounter*/
,'S91232S'  /*Puncture wound without foreign body of left great toe with damage to nail, sequela*/
,'S91233D'  /*Puncture wound without foreign body of unspecified great toe with damage to nail, subsequent encounter*/
,'S91233S'  /*Puncture wound without foreign body of unspecified great toe with damage to nail, sequela*/
,'S91234D'  /*Puncture wound without foreign body of right lesser toe(s) with damage to nail, subsequent encounter*/
,'S91234S'  /*Puncture wound without foreign body of right lesser toe(s) with damage to nail, sequela*/
,'S91235D'  /*Puncture wound without foreign body of left lesser toe(s) with damage to nail, subsequent encounter*/
,'S91235S'  /*Puncture wound without foreign body of left lesser toe(s) with damage to nail, sequela*/
,'S91236D'  /*Puncture wound without foreign body of unspecified lesser toe(s) with damage to nail, subsequent encounter*/
,'S91236S'  /*Puncture wound without foreign body of unspecified lesser toe(s) with damage to nail, sequela*/
,'S91239D'  /*Puncture wound without foreign body of unspecified toe(s) with damage to nail, subsequent encounter*/
,'S91239S'  /*Puncture wound without foreign body of unspecified toe(s) with damage to nail, sequela*/
,'S91241D'  /*Puncture wound with foreign body of right great toe with damage to nail, subsequent encounter*/
,'S91241S'  /*Puncture wound with foreign body of right great toe with damage to nail, sequela*/
,'S91242D'  /*Puncture wound with foreign body of left great toe with damage to nail, subsequent encounter*/
,'S91242S'  /*Puncture wound with foreign body of left great toe with damage to nail, sequela*/
,'S91243D'  /*Puncture wound with foreign body of unspecified great toe with damage to nail, subsequent encounter*/
,'S91243S'  /*Puncture wound with foreign body of unspecified great toe with damage to nail, sequela*/
,'S91244D'  /*Puncture wound with foreign body of right lesser toe(s) with damage to nail, subsequent encounter*/
,'S91244S'  /*Puncture wound with foreign body of right lesser toe(s) with damage to nail, sequela*/
,'S91245D'  /*Puncture wound with foreign body of left lesser toe(s) with damage to nail, subsequent encounter*/
,'S91245S'  /*Puncture wound with foreign body of left lesser toe(s) with damage to nail, sequela*/
,'S91246D'  /*Puncture wound with foreign body of unspecified lesser toe(s) with damage to nail, subsequent encounter*/
,'S91246S'  /*Puncture wound with foreign body of unspecified lesser toe(s) with damage to nail, sequela*/
,'S91249D'  /*Puncture wound with foreign body of unspecified toe(s) with damage to nail, subsequent encounter*/
,'S91249S'  /*Puncture wound with foreign body of unspecified toe(s) with damage to nail, sequela*/
,'S91251D'  /*Open bite of right great toe with damage to nail, subsequent encounter*/
,'S91251S'  /*Open bite of right great toe with damage to nail, sequela*/
,'S91252D'  /*Open bite of left great toe with damage to nail, subsequent encounter*/
,'S91252S'  /*Open bite of left great toe with damage to nail, sequela*/
,'S91253D'  /*Open bite of unspecified great toe with damage to nail, subsequent encounter*/
,'S91253S'  /*Open bite of unspecified great toe with damage to nail, sequela*/
,'S91254D'  /*Open bite of right lesser toe(s) with damage to nail, subsequent encounter*/
,'S91254S'  /*Open bite of right lesser toe(s) with damage to nail, sequela*/
,'S91255D'  /*Open bite of left lesser toe(s) with damage to nail, subsequent encounter*/
,'S91255S'  /*Open bite of left lesser toe(s) with damage to nail, sequela*/
,'S91256D'  /*Open bite of unspecified lesser toe(s) with damage to nail, subsequent encounter*/
,'S91256S'  /*Open bite of unspecified lesser toe(s) with damage to nail, sequela*/
,'S91259D'  /*Open bite of unspecified toe(s) with damage to nail, subsequent encounter*/
,'S91259S'  /*Open bite of unspecified toe(s) with damage to nail, sequela*/
,'S91301D'  /*Unspecified open wound, right foot, subsequent encounter*/
,'S91301S'  /*Unspecified open wound, right foot, sequela*/
,'S91302D'  /*Unspecified open wound, left foot, subsequent encounter*/
,'S91302S'  /*Unspecified open wound, left foot, sequela*/
,'S91309D'  /*Unspecified open wound, unspecified foot, subsequent encounter*/
,'S91309S'  /*Unspecified open wound, unspecified foot, sequela*/
,'S91311D'  /*Laceration without foreign body, right foot, subsequent encounter*/
,'S91311S'  /*Laceration without foreign body, right foot, sequela*/
,'S91312D'  /*Laceration without foreign body, left foot, subsequent encounter*/
,'S91312S'  /*Laceration without foreign body, left foot, sequela*/
,'S91319D'  /*Laceration without foreign body, unspecified foot, subsequent encounter*/
,'S91319S'  /*Laceration without foreign body, unspecified foot, sequela*/
,'S91321D'  /*Laceration with foreign body, right foot, subsequent encounter*/
,'S91321S'  /*Laceration with foreign body, right foot, sequela*/
,'S91322D'  /*Laceration with foreign body, left foot, subsequent encounter*/
,'S91322S'  /*Laceration with foreign body, left foot, sequela*/
,'S91329D'  /*Laceration with foreign body, unspecified foot, subsequent encounter*/
,'S91329S'  /*Laceration with foreign body, unspecified foot, sequela*/
,'S91331D'  /*Puncture wound without foreign body, right foot, subsequent encounter*/
,'S91331S'  /*Puncture wound without foreign body, right foot, sequela*/
,'S91332D'  /*Puncture wound without foreign body, left foot, subsequent encounter*/
,'S91332S'  /*Puncture wound without foreign body, left foot, sequela*/
,'S91339D'  /*Puncture wound without foreign body, unspecified foot, subsequent encounter*/
,'S91339S'  /*Puncture wound without foreign body, unspecified foot, sequela*/
,'S91341D'  /*Puncture wound with foreign body, right foot, subsequent encounter*/
,'S91341S'  /*Puncture wound with foreign body, right foot, sequela*/
,'S91342D'  /*Puncture wound with foreign body, left foot, subsequent encounter*/
,'S91342S'  /*Puncture wound with foreign body, left foot, sequela*/
,'S91349D'  /*Puncture wound with foreign body, unspecified foot, subsequent encounter*/
,'S91349S'  /*Puncture wound with foreign body, unspecified foot, sequela*/
,'S91351D'  /*Open bite, right foot, subsequent encounter*/
,'S91351S'  /*Open bite, right foot, sequela*/
,'S91352D'  /*Open bite, left foot, subsequent encounter*/
,'S91352S'  /*Open bite, left foot, sequela*/
,'S91359D'  /*Open bite, unspecified foot, subsequent encounter*/
,'S91359S'  /*Open bite, unspecified foot, sequela*/
,'S92001D'  /*Unspecified fracture of right calcaneus, subsequent encounter for fracture with routine healing*/
,'S92001G'  /*Unspecified fracture of right calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92001K'  /*Unspecified fracture of right calcaneus, subsequent encounter for fracture with nonunion*/
,'S92001P'  /*Unspecified fracture of right calcaneus, subsequent encounter for fracture with malunion*/
,'S92001S'  /*Unspecified fracture of right calcaneus, sequela*/
,'S92002D'  /*Unspecified fracture of left calcaneus, subsequent encounter for fracture with routine healing*/
,'S92002G'  /*Unspecified fracture of left calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92002K'  /*Unspecified fracture of left calcaneus, subsequent encounter for fracture with nonunion*/
,'S92002P'  /*Unspecified fracture of left calcaneus, subsequent encounter for fracture with malunion*/
,'S92002S'  /*Unspecified fracture of left calcaneus, sequela*/
,'S92009D'  /*Unspecified fracture of unspecified calcaneus, subsequent encounter for fracture with routine healing*/
,'S92009G'  /*Unspecified fracture of unspecified calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92009K'  /*Unspecified fracture of unspecified calcaneus, subsequent encounter for fracture with nonunion*/
,'S92009P'  /*Unspecified fracture of unspecified calcaneus, subsequent encounter for fracture with malunion*/
,'S92009S'  /*Unspecified fracture of unspecified calcaneus, sequela*/
,'S92011D'  /*Displaced fracture of body of right calcaneus, subsequent encounter for fracture with routine healing*/
,'S92011G'  /*Displaced fracture of body of right calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92011K'  /*Displaced fracture of body of right calcaneus, subsequent encounter for fracture with nonunion*/
,'S92011P'  /*Displaced fracture of body of right calcaneus, subsequent encounter for fracture with malunion*/
,'S92011S'  /*Displaced fracture of body of right calcaneus, sequela*/
,'S92012D'  /*Displaced fracture of body of left calcaneus, subsequent encounter for fracture with routine healing*/
,'S92012G'  /*Displaced fracture of body of left calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92012K'  /*Displaced fracture of body of left calcaneus, subsequent encounter for fracture with nonunion*/
,'S92012P'  /*Displaced fracture of body of left calcaneus, subsequent encounter for fracture with malunion*/
,'S92012S'  /*Displaced fracture of body of left calcaneus, sequela*/
,'S92013D'  /*Displaced fracture of body of unspecified calcaneus, subsequent encounter for fracture with routine healing*/
,'S92013G'  /*Displaced fracture of body of unspecified calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92013K'  /*Displaced fracture of body of unspecified calcaneus, subsequent encounter for fracture with nonunion*/
,'S92013P'  /*Displaced fracture of body of unspecified calcaneus, subsequent encounter for fracture with malunion*/
,'S92013S'  /*Displaced fracture of body of unspecified calcaneus, sequela*/
,'S92014D'  /*Nondisplaced fracture of body of right calcaneus, subsequent encounter for fracture with routine healing*/
,'S92014G'  /*Nondisplaced fracture of body of right calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92014K'  /*Nondisplaced fracture of body of right calcaneus, subsequent encounter for fracture with nonunion*/
,'S92014P'  /*Nondisplaced fracture of body of right calcaneus, subsequent encounter for fracture with malunion*/
,'S92014S'  /*Nondisplaced fracture of body of right calcaneus, sequela*/
,'S92015D'  /*Nondisplaced fracture of body of left calcaneus, subsequent encounter for fracture with routine healing*/
,'S92015G'  /*Nondisplaced fracture of body of left calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92015K'  /*Nondisplaced fracture of body of left calcaneus, subsequent encounter for fracture with nonunion*/
,'S92015P'  /*Nondisplaced fracture of body of left calcaneus, subsequent encounter for fracture with malunion*/
,'S92015S'  /*Nondisplaced fracture of body of left calcaneus, sequela*/
,'S92016D'  /*Nondisplaced fracture of body of unspecified calcaneus, subsequent encounter for fracture with routine healing*/
,'S92016G'  /*Nondisplaced fracture of body of unspecified calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92016K'  /*Nondisplaced fracture of body of unspecified calcaneus, subsequent encounter for fracture with nonunion*/
,'S92016P'  /*Nondisplaced fracture of body of unspecified calcaneus, subsequent encounter for fracture with malunion*/
,'S92016S'  /*Nondisplaced fracture of body of unspecified calcaneus, sequela*/
,'S92021D'  /*Displaced fracture of anterior process of right calcaneus, subsequent encounter for fracture with routine healing*/
,'S92021G'  /*Displaced fracture of anterior process of right calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92021K'  /*Displaced fracture of anterior process of right calcaneus, subsequent encounter for fracture with nonunion*/
,'S92021P'  /*Displaced fracture of anterior process of right calcaneus, subsequent encounter for fracture with malunion*/
,'S92021S'  /*Displaced fracture of anterior process of right calcaneus, sequela*/
,'S92022D'  /*Displaced fracture of anterior process of left calcaneus, subsequent encounter for fracture with routine healing*/
,'S92022G'  /*Displaced fracture of anterior process of left calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92022K'  /*Displaced fracture of anterior process of left calcaneus, subsequent encounter for fracture with nonunion*/
,'S92022P'  /*Displaced fracture of anterior process of left calcaneus, subsequent encounter for fracture with malunion*/
,'S92022S'  /*Displaced fracture of anterior process of left calcaneus, sequela*/
,'S92023D'  /*Displaced fracture of anterior process of unspecified calcaneus, subsequent encounter for fracture with routine healing*/
,'S92023G'  /*Displaced fracture of anterior process of unspecified calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92023K'  /*Displaced fracture of anterior process of unspecified calcaneus, subsequent encounter for fracture with nonunion*/
,'S92023P'  /*Displaced fracture of anterior process of unspecified calcaneus, subsequent encounter for fracture with malunion*/
,'S92023S'  /*Displaced fracture of anterior process of unspecified calcaneus, sequela*/
,'S92024D'  /*Nondisplaced fracture of anterior process of right calcaneus, subsequent encounter for fracture with routine healing*/
,'S92024G'  /*Nondisplaced fracture of anterior process of right calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92024K'  /*Nondisplaced fracture of anterior process of right calcaneus, subsequent encounter for fracture with nonunion*/
,'S92024P'  /*Nondisplaced fracture of anterior process of right calcaneus, subsequent encounter for fracture with malunion*/
,'S92024S'  /*Nondisplaced fracture of anterior process of right calcaneus, sequela*/
,'S92025D'  /*Nondisplaced fracture of anterior process of left calcaneus, subsequent encounter for fracture with routine healing*/
,'S92025G'  /*Nondisplaced fracture of anterior process of left calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92025K'  /*Nondisplaced fracture of anterior process of left calcaneus, subsequent encounter for fracture with nonunion*/
,'S92025P'  /*Nondisplaced fracture of anterior process of left calcaneus, subsequent encounter for fracture with malunion*/
,'S92025S'  /*Nondisplaced fracture of anterior process of left calcaneus, sequela*/
,'S92026D'  /*Nondisplaced fracture of anterior process of unspecified calcaneus, subsequent encounter for fracture with routine healing*/
,'S92026G'  /*Nondisplaced fracture of anterior process of unspecified calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92026K'  /*Nondisplaced fracture of anterior process of unspecified calcaneus, subsequent encounter for fracture with nonunion*/
,'S92026P'  /*Nondisplaced fracture of anterior process of unspecified calcaneus, subsequent encounter for fracture with malunion*/
,'S92026S'  /*Nondisplaced fracture of anterior process of unspecified calcaneus, sequela*/
,'S92031D'  /*Displaced avulsion fracture of tuberosity of right calcaneus, subsequent encounter for fracture with routine healing*/
,'S92031G'  /*Displaced avulsion fracture of tuberosity of right calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92031K'  /*Displaced avulsion fracture of tuberosity of right calcaneus, subsequent encounter for fracture with nonunion*/
,'S92031P'  /*Displaced avulsion fracture of tuberosity of right calcaneus, subsequent encounter for fracture with malunion*/
,'S92031S'  /*Displaced avulsion fracture of tuberosity of right calcaneus, sequela*/
,'S92032D'  /*Displaced avulsion fracture of tuberosity of left calcaneus, subsequent encounter for fracture with routine healing*/
,'S92032G'  /*Displaced avulsion fracture of tuberosity of left calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92032K'  /*Displaced avulsion fracture of tuberosity of left calcaneus, subsequent encounter for fracture with nonunion*/
,'S92032P'  /*Displaced avulsion fracture of tuberosity of left calcaneus, subsequent encounter for fracture with malunion*/
,'S92032S'  /*Displaced avulsion fracture of tuberosity of left calcaneus, sequela*/
,'S92033D'  /*Displaced avulsion fracture of tuberosity of unspecified calcaneus, subsequent encounter for fracture with routine healing*/
,'S92033G'  /*Displaced avulsion fracture of tuberosity of unspecified calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92033K'  /*Displaced avulsion fracture of tuberosity of unspecified calcaneus, subsequent encounter for fracture with nonunion*/
,'S92033P'  /*Displaced avulsion fracture of tuberosity of unspecified calcaneus, subsequent encounter for fracture with malunion*/
,'S92033S'  /*Displaced avulsion fracture of tuberosity of unspecified calcaneus, sequela*/
,'S92034D'  /*Nondisplaced avulsion fracture of tuberosity of right calcaneus, subsequent encounter for fracture with routine healing*/
,'S92034G'  /*Nondisplaced avulsion fracture of tuberosity of right calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92034K'  /*Nondisplaced avulsion fracture of tuberosity of right calcaneus, subsequent encounter for fracture with nonunion*/
,'S92034P'  /*Nondisplaced avulsion fracture of tuberosity of right calcaneus, subsequent encounter for fracture with malunion*/
,'S92034S'  /*Nondisplaced avulsion fracture of tuberosity of right calcaneus, sequela*/
,'S92035D'  /*Nondisplaced avulsion fracture of tuberosity of left calcaneus, subsequent encounter for fracture with routine healing*/
,'S92035G'  /*Nondisplaced avulsion fracture of tuberosity of left calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92035K'  /*Nondisplaced avulsion fracture of tuberosity of left calcaneus, subsequent encounter for fracture with nonunion*/
,'S92035P'  /*Nondisplaced avulsion fracture of tuberosity of left calcaneus, subsequent encounter for fracture with malunion*/
,'S92035S'  /*Nondisplaced avulsion fracture of tuberosity of left calcaneus, sequela*/
,'S92036D'  /*Nondisplaced avulsion fracture of tuberosity of unspecified calcaneus, subsequent encounter for fracture with routine healing*/
,'S92036G'  /*Nondisplaced avulsion fracture of tuberosity of unspecified calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92036K'  /*Nondisplaced avulsion fracture of tuberosity of unspecified calcaneus, subsequent encounter for fracture with nonunion*/
,'S92036P'  /*Nondisplaced avulsion fracture of tuberosity of unspecified calcaneus, subsequent encounter for fracture with malunion*/
,'S92036S'  /*Nondisplaced avulsion fracture of tuberosity of unspecified calcaneus, sequela*/
,'S92041D'  /*Displaced other fracture of tuberosity of right calcaneus, subsequent encounter for fracture with routine healing*/
,'S92041G'  /*Displaced other fracture of tuberosity of right calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92041K'  /*Displaced other fracture of tuberosity of right calcaneus, subsequent encounter for fracture with nonunion*/
,'S92041P'  /*Displaced other fracture of tuberosity of right calcaneus, subsequent encounter for fracture with malunion*/
,'S92041S'  /*Displaced other fracture of tuberosity of right calcaneus, sequela*/
,'S92042D'  /*Displaced other fracture of tuberosity of left calcaneus, subsequent encounter for fracture with routine healing*/
,'S92042G'  /*Displaced other fracture of tuberosity of left calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92042K'  /*Displaced other fracture of tuberosity of left calcaneus, subsequent encounter for fracture with nonunion*/
,'S92042P'  /*Displaced other fracture of tuberosity of left calcaneus, subsequent encounter for fracture with malunion*/
,'S92042S'  /*Displaced other fracture of tuberosity of left calcaneus, sequela*/
,'S92043D'  /*Displaced other fracture of tuberosity of unspecified calcaneus, subsequent encounter for fracture with routine healing*/
,'S92043G'  /*Displaced other fracture of tuberosity of unspecified calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92043K'  /*Displaced other fracture of tuberosity of unspecified calcaneus, subsequent encounter for fracture with nonunion*/
,'S92043P'  /*Displaced other fracture of tuberosity of unspecified calcaneus, subsequent encounter for fracture with malunion*/
,'S92043S'  /*Displaced other fracture of tuberosity of unspecified calcaneus, sequela*/
,'S92044D'  /*Nondisplaced other fracture of tuberosity of right calcaneus, subsequent encounter for fracture with routine healing*/
,'S92044G'  /*Nondisplaced other fracture of tuberosity of right calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92044K'  /*Nondisplaced other fracture of tuberosity of right calcaneus, subsequent encounter for fracture with nonunion*/
,'S92044P'  /*Nondisplaced other fracture of tuberosity of right calcaneus, subsequent encounter for fracture with malunion*/
,'S92044S'  /*Nondisplaced other fracture of tuberosity of right calcaneus, sequela*/
,'S92045D'  /*Nondisplaced other fracture of tuberosity of left calcaneus, subsequent encounter for fracture with routine healing*/
,'S92045G'  /*Nondisplaced other fracture of tuberosity of left calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92045K'  /*Nondisplaced other fracture of tuberosity of left calcaneus, subsequent encounter for fracture with nonunion*/
,'S92045P'  /*Nondisplaced other fracture of tuberosity of left calcaneus, subsequent encounter for fracture with malunion*/
,'S92045S'  /*Nondisplaced other fracture of tuberosity of left calcaneus, sequela*/
,'S92046D'  /*Nondisplaced other fracture of tuberosity of unspecified calcaneus, subsequent encounter for fracture with routine healing*/
,'S92046G'  /*Nondisplaced other fracture of tuberosity of unspecified calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92046K'  /*Nondisplaced other fracture of tuberosity of unspecified calcaneus, subsequent encounter for fracture with nonunion*/
,'S92046P'  /*Nondisplaced other fracture of tuberosity of unspecified calcaneus, subsequent encounter for fracture with malunion*/
,'S92046S'  /*Nondisplaced other fracture of tuberosity of unspecified calcaneus, sequela*/
,'S92051D'  /*Displaced other extraarticular fracture of right calcaneus, subsequent encounter for fracture with routine healing*/
,'S92051G'  /*Displaced other extraarticular fracture of right calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92051K'  /*Displaced other extraarticular fracture of right calcaneus, subsequent encounter for fracture with nonunion*/
,'S92051P'  /*Displaced other extraarticular fracture of right calcaneus, subsequent encounter for fracture with malunion*/
,'S92051S'  /*Displaced other extraarticular fracture of right calcaneus, sequela*/
,'S92052D'  /*Displaced other extraarticular fracture of left calcaneus, subsequent encounter for fracture with routine healing*/
,'S92052G'  /*Displaced other extraarticular fracture of left calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92052K'  /*Displaced other extraarticular fracture of left calcaneus, subsequent encounter for fracture with nonunion*/
,'S92052P'  /*Displaced other extraarticular fracture of left calcaneus, subsequent encounter for fracture with malunion*/
,'S92052S'  /*Displaced other extraarticular fracture of left calcaneus, sequela*/
,'S92053D'  /*Displaced other extraarticular fracture of unspecified calcaneus, subsequent encounter for fracture with routine healing*/
,'S92053G'  /*Displaced other extraarticular fracture of unspecified calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92053K'  /*Displaced other extraarticular fracture of unspecified calcaneus, subsequent encounter for fracture with nonunion*/
,'S92053P'  /*Displaced other extraarticular fracture of unspecified calcaneus, subsequent encounter for fracture with malunion*/
,'S92053S'  /*Displaced other extraarticular fracture of unspecified calcaneus, sequela*/
,'S92054D'  /*Nondisplaced other extraarticular fracture of right calcaneus, subsequent encounter for fracture with routine healing*/
,'S92054G'  /*Nondisplaced other extraarticular fracture of right calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92054K'  /*Nondisplaced other extraarticular fracture of right calcaneus, subsequent encounter for fracture with nonunion*/
,'S92054P'  /*Nondisplaced other extraarticular fracture of right calcaneus, subsequent encounter for fracture with malunion*/
,'S92054S'  /*Nondisplaced other extraarticular fracture of right calcaneus, sequela*/
,'S92055D'  /*Nondisplaced other extraarticular fracture of left calcaneus, subsequent encounter for fracture with routine healing*/
,'S92055G'  /*Nondisplaced other extraarticular fracture of left calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92055K'  /*Nondisplaced other extraarticular fracture of left calcaneus, subsequent encounter for fracture with nonunion*/
,'S92055P'  /*Nondisplaced other extraarticular fracture of left calcaneus, subsequent encounter for fracture with malunion*/
,'S92055S'  /*Nondisplaced other extraarticular fracture of left calcaneus, sequela*/
,'S92056D'  /*Nondisplaced other extraarticular fracture of unspecified calcaneus, subsequent encounter for fracture with routine healing*/
,'S92056G'  /*Nondisplaced other extraarticular fracture of unspecified calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92056K'  /*Nondisplaced other extraarticular fracture of unspecified calcaneus, subsequent encounter for fracture with nonunion*/
,'S92056P'  /*Nondisplaced other extraarticular fracture of unspecified calcaneus, subsequent encounter for fracture with malunion*/
,'S92056S'  /*Nondisplaced other extraarticular fracture of unspecified calcaneus, sequela*/
,'S92061D'  /*Displaced intraarticular fracture of right calcaneus, subsequent encounter for fracture with routine healing*/
,'S92061G'  /*Displaced intraarticular fracture of right calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92061K'  /*Displaced intraarticular fracture of right calcaneus, subsequent encounter for fracture with nonunion*/
,'S92061P'  /*Displaced intraarticular fracture of right calcaneus, subsequent encounter for fracture with malunion*/
,'S92061S'  /*Displaced intraarticular fracture of right calcaneus, sequela*/
,'S92062D'  /*Displaced intraarticular fracture of left calcaneus, subsequent encounter for fracture with routine healing*/
,'S92062G'  /*Displaced intraarticular fracture of left calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92062K'  /*Displaced intraarticular fracture of left calcaneus, subsequent encounter for fracture with nonunion*/
,'S92062P'  /*Displaced intraarticular fracture of left calcaneus, subsequent encounter for fracture with malunion*/
,'S92062S'  /*Displaced intraarticular fracture of left calcaneus, sequela*/
,'S92063D'  /*Displaced intraarticular fracture of unspecified calcaneus, subsequent encounter for fracture with routine healing*/
,'S92063G'  /*Displaced intraarticular fracture of unspecified calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92063K'  /*Displaced intraarticular fracture of unspecified calcaneus, subsequent encounter for fracture with nonunion*/
,'S92063P'  /*Displaced intraarticular fracture of unspecified calcaneus, subsequent encounter for fracture with malunion*/
,'S92063S'  /*Displaced intraarticular fracture of unspecified calcaneus, sequela*/
,'S92064D'  /*Nondisplaced intraarticular fracture of right calcaneus, subsequent encounter for fracture with routine healing*/
,'S92064G'  /*Nondisplaced intraarticular fracture of right calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92064K'  /*Nondisplaced intraarticular fracture of right calcaneus, subsequent encounter for fracture with nonunion*/
,'S92064P'  /*Nondisplaced intraarticular fracture of right calcaneus, subsequent encounter for fracture with malunion*/
,'S92064S'  /*Nondisplaced intraarticular fracture of right calcaneus, sequela*/
,'S92065D'  /*Nondisplaced intraarticular fracture of left calcaneus, subsequent encounter for fracture with routine healing*/
,'S92065G'  /*Nondisplaced intraarticular fracture of left calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92065K'  /*Nondisplaced intraarticular fracture of left calcaneus, subsequent encounter for fracture with nonunion*/
,'S92065P'  /*Nondisplaced intraarticular fracture of left calcaneus, subsequent encounter for fracture with malunion*/
,'S92065S'  /*Nondisplaced intraarticular fracture of left calcaneus, sequela*/
,'S92066D'  /*Nondisplaced intraarticular fracture of unspecified calcaneus, subsequent encounter for fracture with routine healing*/
,'S92066G'  /*Nondisplaced intraarticular fracture of unspecified calcaneus, subsequent encounter for fracture with delayed healing*/
,'S92066K'  /*Nondisplaced intraarticular fracture of unspecified calcaneus, subsequent encounter for fracture with nonunion*/
,'S92066P'  /*Nondisplaced intraarticular fracture of unspecified calcaneus, subsequent encounter for fracture with malunion*/
,'S92066S'  /*Nondisplaced intraarticular fracture of unspecified calcaneus, sequela*/
,'S92101D'  /*Unspecified fracture of right talus, subsequent encounter for fracture with routine healing*/
,'S92101G'  /*Unspecified fracture of right talus, subsequent encounter for fracture with delayed healing*/
,'S92101K'  /*Unspecified fracture of right talus, subsequent encounter for fracture with nonunion*/
,'S92101P'  /*Unspecified fracture of right talus, subsequent encounter for fracture with malunion*/
,'S92101S'  /*Unspecified fracture of right talus, sequela*/
,'S92102D'  /*Unspecified fracture of left talus, subsequent encounter for fracture with routine healing*/
,'S92102G'  /*Unspecified fracture of left talus, subsequent encounter for fracture with delayed healing*/
,'S92102K'  /*Unspecified fracture of left talus, subsequent encounter for fracture with nonunion*/
,'S92102P'  /*Unspecified fracture of left talus, subsequent encounter for fracture with malunion*/
,'S92102S'  /*Unspecified fracture of left talus, sequela*/
,'S92109D'  /*Unspecified fracture of unspecified talus, subsequent encounter for fracture with routine healing*/
,'S92109G'  /*Unspecified fracture of unspecified talus, subsequent encounter for fracture with delayed healing*/
,'S92109K'  /*Unspecified fracture of unspecified talus, subsequent encounter for fracture with nonunion*/
,'S92109P'  /*Unspecified fracture of unspecified talus, subsequent encounter for fracture with malunion*/
,'S92109S'  /*Unspecified fracture of unspecified talus, sequela*/
,'S92111D'  /*Displaced fracture of neck of right talus, subsequent encounter for fracture with routine healing*/
,'S92111G'  /*Displaced fracture of neck of right talus, subsequent encounter for fracture with delayed healing*/
,'S92111K'  /*Displaced fracture of neck of right talus, subsequent encounter for fracture with nonunion*/
,'S92111P'  /*Displaced fracture of neck of right talus, subsequent encounter for fracture with malunion*/
,'S92111S'  /*Displaced fracture of neck of right talus, sequela*/
,'S92112D'  /*Displaced fracture of neck of left talus, subsequent encounter for fracture with routine healing*/
,'S92112G'  /*Displaced fracture of neck of left talus, subsequent encounter for fracture with delayed healing*/
,'S92112K'  /*Displaced fracture of neck of left talus, subsequent encounter for fracture with nonunion*/
,'S92112P'  /*Displaced fracture of neck of left talus, subsequent encounter for fracture with malunion*/
,'S92112S'  /*Displaced fracture of neck of left talus, sequela*/
,'S92113D'  /*Displaced fracture of neck of unspecified talus, subsequent encounter for fracture with routine healing*/
,'S92113G'  /*Displaced fracture of neck of unspecified talus, subsequent encounter for fracture with delayed healing*/
,'S92113K'  /*Displaced fracture of neck of unspecified talus, subsequent encounter for fracture with nonunion*/
,'S92113P'  /*Displaced fracture of neck of unspecified talus, subsequent encounter for fracture with malunion*/
,'S92113S'  /*Displaced fracture of neck of unspecified talus, sequela*/
,'S92114D'  /*Nondisplaced fracture of neck of right talus, subsequent encounter for fracture with routine healing*/
,'S92114G'  /*Nondisplaced fracture of neck of right talus, subsequent encounter for fracture with delayed healing*/
,'S92114K'  /*Nondisplaced fracture of neck of right talus, subsequent encounter for fracture with nonunion*/
,'S92114P'  /*Nondisplaced fracture of neck of right talus, subsequent encounter for fracture with malunion*/
,'S92114S'  /*Nondisplaced fracture of neck of right talus, sequela*/
,'S92115D'  /*Nondisplaced fracture of neck of left talus, subsequent encounter for fracture with routine healing*/
,'S92115G'  /*Nondisplaced fracture of neck of left talus, subsequent encounter for fracture with delayed healing*/
,'S92115K'  /*Nondisplaced fracture of neck of left talus, subsequent encounter for fracture with nonunion*/
,'S92115P'  /*Nondisplaced fracture of neck of left talus, subsequent encounter for fracture with malunion*/
,'S92115S'  /*Nondisplaced fracture of neck of left talus, sequela*/
,'S92116D'  /*Nondisplaced fracture of neck of unspecified talus, subsequent encounter for fracture with routine healing*/
,'S92116G'  /*Nondisplaced fracture of neck of unspecified talus, subsequent encounter for fracture with delayed healing*/
,'S92116K'  /*Nondisplaced fracture of neck of unspecified talus, subsequent encounter for fracture with nonunion*/
,'S92116P'  /*Nondisplaced fracture of neck of unspecified talus, subsequent encounter for fracture with malunion*/
,'S92116S'  /*Nondisplaced fracture of neck of unspecified talus, sequela*/
,'S92121D'  /*Displaced fracture of body of right talus, subsequent encounter for fracture with routine healing*/
,'S92121G'  /*Displaced fracture of body of right talus, subsequent encounter for fracture with delayed healing*/
,'S92121K'  /*Displaced fracture of body of right talus, subsequent encounter for fracture with nonunion*/
,'S92121P'  /*Displaced fracture of body of right talus, subsequent encounter for fracture with malunion*/
,'S92121S'  /*Displaced fracture of body of right talus, sequela*/
,'S92122D'  /*Displaced fracture of body of left talus, subsequent encounter for fracture with routine healing*/
,'S92122G'  /*Displaced fracture of body of left talus, subsequent encounter for fracture with delayed healing*/
,'S92122K'  /*Displaced fracture of body of left talus, subsequent encounter for fracture with nonunion*/
,'S92122P'  /*Displaced fracture of body of left talus, subsequent encounter for fracture with malunion*/
,'S92122S'  /*Displaced fracture of body of left talus, sequela*/
,'S92123D'  /*Displaced fracture of body of unspecified talus, subsequent encounter for fracture with routine healing*/
,'S92123G'  /*Displaced fracture of body of unspecified talus, subsequent encounter for fracture with delayed healing*/
,'S92123K'  /*Displaced fracture of body of unspecified talus, subsequent encounter for fracture with nonunion*/
,'S92123P'  /*Displaced fracture of body of unspecified talus, subsequent encounter for fracture with malunion*/
,'S92123S'  /*Displaced fracture of body of unspecified talus, sequela*/
,'S92124D'  /*Nondisplaced fracture of body of right talus, subsequent encounter for fracture with routine healing*/
,'S92124G'  /*Nondisplaced fracture of body of right talus, subsequent encounter for fracture with delayed healing*/
,'S92124K'  /*Nondisplaced fracture of body of right talus, subsequent encounter for fracture with nonunion*/
,'S92124P'  /*Nondisplaced fracture of body of right talus, subsequent encounter for fracture with malunion*/
,'S92124S'  /*Nondisplaced fracture of body of right talus, sequela*/
,'S92125D'  /*Nondisplaced fracture of body of left talus, subsequent encounter for fracture with routine healing*/
,'S92125G'  /*Nondisplaced fracture of body of left talus, subsequent encounter for fracture with delayed healing*/
,'S92125K'  /*Nondisplaced fracture of body of left talus, subsequent encounter for fracture with nonunion*/
,'S92125P'  /*Nondisplaced fracture of body of left talus, subsequent encounter for fracture with malunion*/
,'S92125S'  /*Nondisplaced fracture of body of left talus, sequela*/
,'S92126D'  /*Nondisplaced fracture of body of unspecified talus, subsequent encounter for fracture with routine healing*/
,'S92126G'  /*Nondisplaced fracture of body of unspecified talus, subsequent encounter for fracture with delayed healing*/
,'S92126K'  /*Nondisplaced fracture of body of unspecified talus, subsequent encounter for fracture with nonunion*/
,'S92126P'  /*Nondisplaced fracture of body of unspecified talus, subsequent encounter for fracture with malunion*/
,'S92126S'  /*Nondisplaced fracture of body of unspecified talus, sequela*/
,'S92131D'  /*Displaced fracture of posterior process of right talus, subsequent encounter for fracture with routine healing*/
,'S92131G'  /*Displaced fracture of posterior process of right talus, subsequent encounter for fracture with delayed healing*/
,'S92131K'  /*Displaced fracture of posterior process of right talus, subsequent encounter for fracture with nonunion*/
,'S92131P'  /*Displaced fracture of posterior process of right talus, subsequent encounter for fracture with malunion*/
,'S92131S'  /*Displaced fracture of posterior process of right talus, sequela*/
,'S92132D'  /*Displaced fracture of posterior process of left talus, subsequent encounter for fracture with routine healing*/
,'S92132G'  /*Displaced fracture of posterior process of left talus, subsequent encounter for fracture with delayed healing*/
,'S92132K'  /*Displaced fracture of posterior process of left talus, subsequent encounter for fracture with nonunion*/
,'S92132P'  /*Displaced fracture of posterior process of left talus, subsequent encounter for fracture with malunion*/
,'S92132S'  /*Displaced fracture of posterior process of left talus, sequela*/
,'S92133D'  /*Displaced fracture of posterior process of unspecified talus, subsequent encounter for fracture with routine healing*/
,'S92133G'  /*Displaced fracture of posterior process of unspecified talus, subsequent encounter for fracture with delayed healing*/
,'S92133K'  /*Displaced fracture of posterior process of unspecified talus, subsequent encounter for fracture with nonunion*/
,'S92133P'  /*Displaced fracture of posterior process of unspecified talus, subsequent encounter for fracture with malunion*/
,'S92133S'  /*Displaced fracture of posterior process of unspecified talus, sequela*/
,'S92134D'  /*Nondisplaced fracture of posterior process of right talus, subsequent encounter for fracture with routine healing*/
,'S92134G'  /*Nondisplaced fracture of posterior process of right talus, subsequent encounter for fracture with delayed healing*/
,'S92134K'  /*Nondisplaced fracture of posterior process of right talus, subsequent encounter for fracture with nonunion*/
,'S92134P'  /*Nondisplaced fracture of posterior process of right talus, subsequent encounter for fracture with malunion*/
,'S92134S'  /*Nondisplaced fracture of posterior process of right talus, sequela*/
,'S92135D'  /*Nondisplaced fracture of posterior process of left talus, subsequent encounter for fracture with routine healing*/
,'S92135G'  /*Nondisplaced fracture of posterior process of left talus, subsequent encounter for fracture with delayed healing*/
,'S92135K'  /*Nondisplaced fracture of posterior process of left talus, subsequent encounter for fracture with nonunion*/
,'S92135P'  /*Nondisplaced fracture of posterior process of left talus, subsequent encounter for fracture with malunion*/
,'S92135S'  /*Nondisplaced fracture of posterior process of left talus, sequela*/
,'S92136D'  /*Nondisplaced fracture of posterior process of unspecified talus, subsequent encounter for fracture with routine healing*/
,'S92136G'  /*Nondisplaced fracture of posterior process of unspecified talus, subsequent encounter for fracture with delayed healing*/
,'S92136K'  /*Nondisplaced fracture of posterior process of unspecified talus, subsequent encounter for fracture with nonunion*/
,'S92136P'  /*Nondisplaced fracture of posterior process of unspecified talus, subsequent encounter for fracture with malunion*/
,'S92136S'  /*Nondisplaced fracture of posterior process of unspecified talus, sequela*/
,'S92141D'  /*Displaced dome fracture of right talus, subsequent encounter for fracture with routine healing*/
,'S92141G'  /*Displaced dome fracture of right talus, subsequent encounter for fracture with delayed healing*/
,'S92141K'  /*Displaced dome fracture of right talus, subsequent encounter for fracture with nonunion*/
,'S92141P'  /*Displaced dome fracture of right talus, subsequent encounter for fracture with malunion*/
,'S92141S'  /*Displaced dome fracture of right talus, sequela*/
,'S92142D'  /*Displaced dome fracture of left talus, subsequent encounter for fracture with routine healing*/
,'S92142G'  /*Displaced dome fracture of left talus, subsequent encounter for fracture with delayed healing*/
,'S92142K'  /*Displaced dome fracture of left talus, subsequent encounter for fracture with nonunion*/
,'S92142P'  /*Displaced dome fracture of left talus, subsequent encounter for fracture with malunion*/
,'S92142S'  /*Displaced dome fracture of left talus, sequela*/
,'S92143D'  /*Displaced dome fracture of unspecified talus, subsequent encounter for fracture with routine healing*/
,'S92143G'  /*Displaced dome fracture of unspecified talus, subsequent encounter for fracture with delayed healing*/
,'S92143K'  /*Displaced dome fracture of unspecified talus, subsequent encounter for fracture with nonunion*/
,'S92143P'  /*Displaced dome fracture of unspecified talus, subsequent encounter for fracture with malunion*/
,'S92143S'  /*Displaced dome fracture of unspecified talus, sequela*/
,'S92144D'  /*Nondisplaced dome fracture of right talus, subsequent encounter for fracture with routine healing*/
,'S92144G'  /*Nondisplaced dome fracture of right talus, subsequent encounter for fracture with delayed healing*/
,'S92144K'  /*Nondisplaced dome fracture of right talus, subsequent encounter for fracture with nonunion*/
,'S92144P'  /*Nondisplaced dome fracture of right talus, subsequent encounter for fracture with malunion*/
,'S92144S'  /*Nondisplaced dome fracture of right talus, sequela*/
,'S92145D'  /*Nondisplaced dome fracture of left talus, subsequent encounter for fracture with routine healing*/
,'S92145G'  /*Nondisplaced dome fracture of left talus, subsequent encounter for fracture with delayed healing*/
,'S92145K'  /*Nondisplaced dome fracture of left talus, subsequent encounter for fracture with nonunion*/
,'S92145P'  /*Nondisplaced dome fracture of left talus, subsequent encounter for fracture with malunion*/
,'S92145S'  /*Nondisplaced dome fracture of left talus, sequela*/
,'S92146D'  /*Nondisplaced dome fracture of unspecified talus, subsequent encounter for fracture with routine healing*/
,'S92146G'  /*Nondisplaced dome fracture of unspecified talus, subsequent encounter for fracture with delayed healing*/
,'S92146K'  /*Nondisplaced dome fracture of unspecified talus, subsequent encounter for fracture with nonunion*/
,'S92146P'  /*Nondisplaced dome fracture of unspecified talus, subsequent encounter for fracture with malunion*/
,'S92146S'  /*Nondisplaced dome fracture of unspecified talus, sequela*/
,'S92151D'  /*Displaced avulsion fracture (chip fracture) of right talus, subsequent encounter for fracture with routine healing*/
,'S92151G'  /*Displaced avulsion fracture (chip fracture) of right talus, subsequent encounter for fracture with delayed healing*/
,'S92151K'  /*Displaced avulsion fracture (chip fracture) of right talus, subsequent encounter for fracture with nonunion*/
,'S92151P'  /*Displaced avulsion fracture (chip fracture) of right talus, subsequent encounter for fracture with malunion*/
,'S92151S'  /*Displaced avulsion fracture (chip fracture) of right talus, sequela*/
,'S92152D'  /*Displaced avulsion fracture (chip fracture) of left talus, subsequent encounter for fracture with routine healing*/
,'S92152G'  /*Displaced avulsion fracture (chip fracture) of left talus, subsequent encounter for fracture with delayed healing*/
,'S92152K'  /*Displaced avulsion fracture (chip fracture) of left talus, subsequent encounter for fracture with nonunion*/
,'S92152P'  /*Displaced avulsion fracture (chip fracture) of left talus, subsequent encounter for fracture with malunion*/
,'S92152S'  /*Displaced avulsion fracture (chip fracture) of left talus, sequela*/
,'S92153D'  /*Displaced avulsion fracture (chip fracture) of unspecified talus, subsequent encounter for fracture with routine healing*/
,'S92153G'  /*Displaced avulsion fracture (chip fracture) of unspecified talus, subsequent encounter for fracture with delayed healing*/
,'S92153K'  /*Displaced avulsion fracture (chip fracture) of unspecified talus, subsequent encounter for fracture with nonunion*/
,'S92153P'  /*Displaced avulsion fracture (chip fracture) of unspecified talus, subsequent encounter for fracture with malunion*/
,'S92153S'  /*Displaced avulsion fracture (chip fracture) of unspecified talus, sequela*/
,'S92154D'  /*Nondisplaced avulsion fracture (chip fracture) of right talus, subsequent encounter for fracture with routine healing*/
,'S92154G'  /*Nondisplaced avulsion fracture (chip fracture) of right talus, subsequent encounter for fracture with delayed healing*/
,'S92154K'  /*Nondisplaced avulsion fracture (chip fracture) of right talus, subsequent encounter for fracture with nonunion*/
,'S92154P'  /*Nondisplaced avulsion fracture (chip fracture) of right talus, subsequent encounter for fracture with malunion*/
,'S92154S'  /*Nondisplaced avulsion fracture (chip fracture) of right talus, sequela*/
,'S92155D'  /*Nondisplaced avulsion fracture (chip fracture) of left talus, subsequent encounter for fracture with routine healing*/
,'S92155G'  /*Nondisplaced avulsion fracture (chip fracture) of left talus, subsequent encounter for fracture with delayed healing*/
,'S92155K'  /*Nondisplaced avulsion fracture (chip fracture) of left talus, subsequent encounter for fracture with nonunion*/
,'S92155P'  /*Nondisplaced avulsion fracture (chip fracture) of left talus, subsequent encounter for fracture with malunion*/
,'S92155S'  /*Nondisplaced avulsion fracture (chip fracture) of left talus, sequela*/
,'S92156D'  /*Nondisplaced avulsion fracture (chip fracture) of unspecified talus, subsequent encounter for fracture with routine healing*/
,'S92156G'  /*Nondisplaced avulsion fracture (chip fracture) of unspecified talus, subsequent encounter for fracture with delayed healing*/
,'S92156K'  /*Nondisplaced avulsion fracture (chip fracture) of unspecified talus, subsequent encounter for fracture with nonunion*/
,'S92156P'  /*Nondisplaced avulsion fracture (chip fracture) of unspecified talus, subsequent encounter for fracture with malunion*/
,'S92156S'  /*Nondisplaced avulsion fracture (chip fracture) of unspecified talus, sequela*/
,'S92191D'  /*Other fracture of right talus, subsequent encounter for fracture with routine healing*/
,'S92191G'  /*Other fracture of right talus, subsequent encounter for fracture with delayed healing*/
,'S92191K'  /*Other fracture of right talus, subsequent encounter for fracture with nonunion*/
,'S92191P'  /*Other fracture of right talus, subsequent encounter for fracture with malunion*/
,'S92191S'  /*Other fracture of right talus, sequela*/
,'S92192D'  /*Other fracture of left talus, subsequent encounter for fracture with routine healing*/
,'S92192G'  /*Other fracture of left talus, subsequent encounter for fracture with delayed healing*/
,'S92192K'  /*Other fracture of left talus, subsequent encounter for fracture with nonunion*/
,'S92192P'  /*Other fracture of left talus, subsequent encounter for fracture with malunion*/
,'S92192S'  /*Other fracture of left talus, sequela*/
,'S92199D'  /*Other fracture of unspecified talus, subsequent encounter for fracture with routine healing*/
,'S92199G'  /*Other fracture of unspecified talus, subsequent encounter for fracture with delayed healing*/
,'S92199K'  /*Other fracture of unspecified talus, subsequent encounter for fracture with nonunion*/
,'S92199P'  /*Other fracture of unspecified talus, subsequent encounter for fracture with malunion*/
,'S92199S'  /*Other fracture of unspecified talus, sequela*/
,'S92201D'  /*Fracture of unspecified tarsal bone(s) of right foot, subsequent encounter for fracture with routine healing*/
,'S92201G'  /*Fracture of unspecified tarsal bone(s) of right foot, subsequent encounter for fracture with delayed healing*/
,'S92201K'  /*Fracture of unspecified tarsal bone(s) of right foot, subsequent encounter for fracture with nonunion*/
,'S92201P'  /*Fracture of unspecified tarsal bone(s) of right foot, subsequent encounter for fracture with malunion*/
,'S92201S'  /*Fracture of unspecified tarsal bone(s) of right foot, sequela*/
,'S92202D'  /*Fracture of unspecified tarsal bone(s) of left foot, subsequent encounter for fracture with routine healing*/
,'S92202G'  /*Fracture of unspecified tarsal bone(s) of left foot, subsequent encounter for fracture with delayed healing*/
,'S92202K'  /*Fracture of unspecified tarsal bone(s) of left foot, subsequent encounter for fracture with nonunion*/
,'S92202P'  /*Fracture of unspecified tarsal bone(s) of left foot, subsequent encounter for fracture with malunion*/
,'S92202S'  /*Fracture of unspecified tarsal bone(s) of left foot, sequela*/
,'S92209D'  /*Fracture of unspecified tarsal bone(s) of unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92209G'  /*Fracture of unspecified tarsal bone(s) of unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92209K'  /*Fracture of unspecified tarsal bone(s) of unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92209P'  /*Fracture of unspecified tarsal bone(s) of unspecified foot, subsequent encounter for fracture with malunion*/
,'S92209S'  /*Fracture of unspecified tarsal bone(s) of unspecified foot, sequela*/
,'S92211D'  /*Displaced fracture of cuboid bone of right foot, subsequent encounter for fracture with routine healing*/
,'S92211G'  /*Displaced fracture of cuboid bone of right foot, subsequent encounter for fracture with delayed healing*/
,'S92211K'  /*Displaced fracture of cuboid bone of right foot, subsequent encounter for fracture with nonunion*/
,'S92211P'  /*Displaced fracture of cuboid bone of right foot, subsequent encounter for fracture with malunion*/
,'S92211S'  /*Displaced fracture of cuboid bone of right foot, sequela*/
,'S92212D'  /*Displaced fracture of cuboid bone of left foot, subsequent encounter for fracture with routine healing*/
,'S92212G'  /*Displaced fracture of cuboid bone of left foot, subsequent encounter for fracture with delayed healing*/
,'S92212K'  /*Displaced fracture of cuboid bone of left foot, subsequent encounter for fracture with nonunion*/
,'S92212P'  /*Displaced fracture of cuboid bone of left foot, subsequent encounter for fracture with malunion*/
,'S92212S'  /*Displaced fracture of cuboid bone of left foot, sequela*/
,'S92213D'  /*Displaced fracture of cuboid bone of unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92213G'  /*Displaced fracture of cuboid bone of unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92213K'  /*Displaced fracture of cuboid bone of unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92213P'  /*Displaced fracture of cuboid bone of unspecified foot, subsequent encounter for fracture with malunion*/
,'S92213S'  /*Displaced fracture of cuboid bone of unspecified foot, sequela*/
,'S92214D'  /*Nondisplaced fracture of cuboid bone of right foot, subsequent encounter for fracture with routine healing*/
,'S92214G'  /*Nondisplaced fracture of cuboid bone of right foot, subsequent encounter for fracture with delayed healing*/
,'S92214K'  /*Nondisplaced fracture of cuboid bone of right foot, subsequent encounter for fracture with nonunion*/
,'S92214P'  /*Nondisplaced fracture of cuboid bone of right foot, subsequent encounter for fracture with malunion*/
,'S92214S'  /*Nondisplaced fracture of cuboid bone of right foot, sequela*/
,'S92215D'  /*Nondisplaced fracture of cuboid bone of left foot, subsequent encounter for fracture with routine healing*/
,'S92215G'  /*Nondisplaced fracture of cuboid bone of left foot, subsequent encounter for fracture with delayed healing*/
,'S92215K'  /*Nondisplaced fracture of cuboid bone of left foot, subsequent encounter for fracture with nonunion*/
,'S92215P'  /*Nondisplaced fracture of cuboid bone of left foot, subsequent encounter for fracture with malunion*/
,'S92215S'  /*Nondisplaced fracture of cuboid bone of left foot, sequela*/
,'S92216D'  /*Nondisplaced fracture of cuboid bone of unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92216G'  /*Nondisplaced fracture of cuboid bone of unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92216K'  /*Nondisplaced fracture of cuboid bone of unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92216P'  /*Nondisplaced fracture of cuboid bone of unspecified foot, subsequent encounter for fracture with malunion*/
,'S92216S'  /*Nondisplaced fracture of cuboid bone of unspecified foot, sequela*/
,'S92221D'  /*Displaced fracture of lateral cuneiform of right foot, subsequent encounter for fracture with routine healing*/
,'S92221G'  /*Displaced fracture of lateral cuneiform of right foot, subsequent encounter for fracture with delayed healing*/
,'S92221K'  /*Displaced fracture of lateral cuneiform of right foot, subsequent encounter for fracture with nonunion*/
,'S92221P'  /*Displaced fracture of lateral cuneiform of right foot, subsequent encounter for fracture with malunion*/
,'S92221S'  /*Displaced fracture of lateral cuneiform of right foot, sequela*/
,'S92222D'  /*Displaced fracture of lateral cuneiform of left foot, subsequent encounter for fracture with routine healing*/
,'S92222G'  /*Displaced fracture of lateral cuneiform of left foot, subsequent encounter for fracture with delayed healing*/
,'S92222K'  /*Displaced fracture of lateral cuneiform of left foot, subsequent encounter for fracture with nonunion*/
,'S92222P'  /*Displaced fracture of lateral cuneiform of left foot, subsequent encounter for fracture with malunion*/
,'S92222S'  /*Displaced fracture of lateral cuneiform of left foot, sequela*/
,'S92223D'  /*Displaced fracture of lateral cuneiform of unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92223G'  /*Displaced fracture of lateral cuneiform of unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92223K'  /*Displaced fracture of lateral cuneiform of unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92223P'  /*Displaced fracture of lateral cuneiform of unspecified foot, subsequent encounter for fracture with malunion*/
,'S92223S'  /*Displaced fracture of lateral cuneiform of unspecified foot, sequela*/
,'S92224D'  /*Nondisplaced fracture of lateral cuneiform of right foot, subsequent encounter for fracture with routine healing*/
,'S92224G'  /*Nondisplaced fracture of lateral cuneiform of right foot, subsequent encounter for fracture with delayed healing*/
,'S92224K'  /*Nondisplaced fracture of lateral cuneiform of right foot, subsequent encounter for fracture with nonunion*/
,'S92224P'  /*Nondisplaced fracture of lateral cuneiform of right foot, subsequent encounter for fracture with malunion*/
,'S92224S'  /*Nondisplaced fracture of lateral cuneiform of right foot, sequela*/
,'S92225D'  /*Nondisplaced fracture of lateral cuneiform of left foot, subsequent encounter for fracture with routine healing*/
,'S92225G'  /*Nondisplaced fracture of lateral cuneiform of left foot, subsequent encounter for fracture with delayed healing*/
,'S92225K'  /*Nondisplaced fracture of lateral cuneiform of left foot, subsequent encounter for fracture with nonunion*/
,'S92225P'  /*Nondisplaced fracture of lateral cuneiform of left foot, subsequent encounter for fracture with malunion*/
,'S92225S'  /*Nondisplaced fracture of lateral cuneiform of left foot, sequela*/
,'S92226D'  /*Nondisplaced fracture of lateral cuneiform of unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92226G'  /*Nondisplaced fracture of lateral cuneiform of unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92226K'  /*Nondisplaced fracture of lateral cuneiform of unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92226P'  /*Nondisplaced fracture of lateral cuneiform of unspecified foot, subsequent encounter for fracture with malunion*/
,'S92226S'  /*Nondisplaced fracture of lateral cuneiform of unspecified foot, sequela*/
,'S92231D'  /*Displaced fracture of intermediate cuneiform of right foot, subsequent encounter for fracture with routine healing*/
,'S92231G'  /*Displaced fracture of intermediate cuneiform of right foot, subsequent encounter for fracture with delayed healing*/
,'S92231K'  /*Displaced fracture of intermediate cuneiform of right foot, subsequent encounter for fracture with nonunion*/
,'S92231P'  /*Displaced fracture of intermediate cuneiform of right foot, subsequent encounter for fracture with malunion*/
,'S92231S'  /*Displaced fracture of intermediate cuneiform of right foot, sequela*/
,'S92232D'  /*Displaced fracture of intermediate cuneiform of left foot, subsequent encounter for fracture with routine healing*/
,'S92232G'  /*Displaced fracture of intermediate cuneiform of left foot, subsequent encounter for fracture with delayed healing*/
,'S92232K'  /*Displaced fracture of intermediate cuneiform of left foot, subsequent encounter for fracture with nonunion*/
,'S92232P'  /*Displaced fracture of intermediate cuneiform of left foot, subsequent encounter for fracture with malunion*/
,'S92232S'  /*Displaced fracture of intermediate cuneiform of left foot, sequela*/
,'S92233D'  /*Displaced fracture of intermediate cuneiform of unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92233G'  /*Displaced fracture of intermediate cuneiform of unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92233K'  /*Displaced fracture of intermediate cuneiform of unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92233P'  /*Displaced fracture of intermediate cuneiform of unspecified foot, subsequent encounter for fracture with malunion*/
,'S92233S'  /*Displaced fracture of intermediate cuneiform of unspecified foot, sequela*/
,'S92234D'  /*Nondisplaced fracture of intermediate cuneiform of right foot, subsequent encounter for fracture with routine healing*/
,'S92234G'  /*Nondisplaced fracture of intermediate cuneiform of right foot, subsequent encounter for fracture with delayed healing*/
,'S92234K'  /*Nondisplaced fracture of intermediate cuneiform of right foot, subsequent encounter for fracture with nonunion*/
,'S92234P'  /*Nondisplaced fracture of intermediate cuneiform of right foot, subsequent encounter for fracture with malunion*/
,'S92234S'  /*Nondisplaced fracture of intermediate cuneiform of right foot, sequela*/
,'S92235D'  /*Nondisplaced fracture of intermediate cuneiform of left foot, subsequent encounter for fracture with routine healing*/
,'S92235G'  /*Nondisplaced fracture of intermediate cuneiform of left foot, subsequent encounter for fracture with delayed healing*/
,'S92235K'  /*Nondisplaced fracture of intermediate cuneiform of left foot, subsequent encounter for fracture with nonunion*/
,'S92235P'  /*Nondisplaced fracture of intermediate cuneiform of left foot, subsequent encounter for fracture with malunion*/
,'S92235S'  /*Nondisplaced fracture of intermediate cuneiform of left foot, sequela*/
,'S92236D'  /*Nondisplaced fracture of intermediate cuneiform of unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92236G'  /*Nondisplaced fracture of intermediate cuneiform of unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92236K'  /*Nondisplaced fracture of intermediate cuneiform of unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92236P'  /*Nondisplaced fracture of intermediate cuneiform of unspecified foot, subsequent encounter for fracture with malunion*/
,'S92236S'  /*Nondisplaced fracture of intermediate cuneiform of unspecified foot, sequela*/
,'S92241D'  /*Displaced fracture of medial cuneiform of right foot, subsequent encounter for fracture with routine healing*/
,'S92241G'  /*Displaced fracture of medial cuneiform of right foot, subsequent encounter for fracture with delayed healing*/
,'S92241K'  /*Displaced fracture of medial cuneiform of right foot, subsequent encounter for fracture with nonunion*/
,'S92241P'  /*Displaced fracture of medial cuneiform of right foot, subsequent encounter for fracture with malunion*/
,'S92241S'  /*Displaced fracture of medial cuneiform of right foot, sequela*/
,'S92242D'  /*Displaced fracture of medial cuneiform of left foot, subsequent encounter for fracture with routine healing*/
,'S92242G'  /*Displaced fracture of medial cuneiform of left foot, subsequent encounter for fracture with delayed healing*/
,'S92242K'  /*Displaced fracture of medial cuneiform of left foot, subsequent encounter for fracture with nonunion*/
,'S92242P'  /*Displaced fracture of medial cuneiform of left foot, subsequent encounter for fracture with malunion*/
,'S92242S'  /*Displaced fracture of medial cuneiform of left foot, sequela*/
,'S92243D'  /*Displaced fracture of medial cuneiform of unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92243G'  /*Displaced fracture of medial cuneiform of unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92243K'  /*Displaced fracture of medial cuneiform of unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92243P'  /*Displaced fracture of medial cuneiform of unspecified foot, subsequent encounter for fracture with malunion*/
,'S92243S'  /*Displaced fracture of medial cuneiform of unspecified foot, sequela*/
,'S92244D'  /*Nondisplaced fracture of medial cuneiform of right foot, subsequent encounter for fracture with routine healing*/
,'S92244G'  /*Nondisplaced fracture of medial cuneiform of right foot, subsequent encounter for fracture with delayed healing*/
,'S92244K'  /*Nondisplaced fracture of medial cuneiform of right foot, subsequent encounter for fracture with nonunion*/
,'S92244P'  /*Nondisplaced fracture of medial cuneiform of right foot, subsequent encounter for fracture with malunion*/
,'S92244S'  /*Nondisplaced fracture of medial cuneiform of right foot, sequela*/
,'S92245D'  /*Nondisplaced fracture of medial cuneiform of left foot, subsequent encounter for fracture with routine healing*/
,'S92245G'  /*Nondisplaced fracture of medial cuneiform of left foot, subsequent encounter for fracture with delayed healing*/
,'S92245K'  /*Nondisplaced fracture of medial cuneiform of left foot, subsequent encounter for fracture with nonunion*/
,'S92245P'  /*Nondisplaced fracture of medial cuneiform of left foot, subsequent encounter for fracture with malunion*/
,'S92245S'  /*Nondisplaced fracture of medial cuneiform of left foot, sequela*/
,'S92246D'  /*Nondisplaced fracture of medial cuneiform of unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92246G'  /*Nondisplaced fracture of medial cuneiform of unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92246K'  /*Nondisplaced fracture of medial cuneiform of unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92246P'  /*Nondisplaced fracture of medial cuneiform of unspecified foot, subsequent encounter for fracture with malunion*/
,'S92246S'  /*Nondisplaced fracture of medial cuneiform of unspecified foot, sequela*/
,'S92251D'  /*Displaced fracture of navicular [scaphoid] of right foot, subsequent encounter for fracture with routine healing*/
,'S92251G'  /*Displaced fracture of navicular [scaphoid] of right foot, subsequent encounter for fracture with delayed healing*/
,'S92251K'  /*Displaced fracture of navicular [scaphoid] of right foot, subsequent encounter for fracture with nonunion*/
,'S92251P'  /*Displaced fracture of navicular [scaphoid] of right foot, subsequent encounter for fracture with malunion*/
,'S92251S'  /*Displaced fracture of navicular [scaphoid] of right foot, sequela*/
,'S92252D'  /*Displaced fracture of navicular [scaphoid] of left foot, subsequent encounter for fracture with routine healing*/
,'S92252G'  /*Displaced fracture of navicular [scaphoid] of left foot, subsequent encounter for fracture with delayed healing*/
,'S92252K'  /*Displaced fracture of navicular [scaphoid] of left foot, subsequent encounter for fracture with nonunion*/
,'S92252P'  /*Displaced fracture of navicular [scaphoid] of left foot, subsequent encounter for fracture with malunion*/
,'S92252S'  /*Displaced fracture of navicular [scaphoid] of left foot, sequela*/
,'S92253D'  /*Displaced fracture of navicular [scaphoid] of unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92253G'  /*Displaced fracture of navicular [scaphoid] of unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92253K'  /*Displaced fracture of navicular [scaphoid] of unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92253P'  /*Displaced fracture of navicular [scaphoid] of unspecified foot, subsequent encounter for fracture with malunion*/
,'S92253S'  /*Displaced fracture of navicular [scaphoid] of unspecified foot, sequela*/
,'S92254D'  /*Nondisplaced fracture of navicular [scaphoid] of right foot, subsequent encounter for fracture with routine healing*/
,'S92254G'  /*Nondisplaced fracture of navicular [scaphoid] of right foot, subsequent encounter for fracture with delayed healing*/
,'S92254K'  /*Nondisplaced fracture of navicular [scaphoid] of right foot, subsequent encounter for fracture with nonunion*/
,'S92254P'  /*Nondisplaced fracture of navicular [scaphoid] of right foot, subsequent encounter for fracture with malunion*/
,'S92254S'  /*Nondisplaced fracture of navicular [scaphoid] of right foot, sequela*/
,'S92255D'  /*Nondisplaced fracture of navicular [scaphoid] of left foot, subsequent encounter for fracture with routine healing*/
,'S92255G'  /*Nondisplaced fracture of navicular [scaphoid] of left foot, subsequent encounter for fracture with delayed healing*/
,'S92255K'  /*Nondisplaced fracture of navicular [scaphoid] of left foot, subsequent encounter for fracture with nonunion*/
,'S92255P'  /*Nondisplaced fracture of navicular [scaphoid] of left foot, subsequent encounter for fracture with malunion*/
,'S92255S'  /*Nondisplaced fracture of navicular [scaphoid] of left foot, sequela*/
,'S92256D'  /*Nondisplaced fracture of navicular [scaphoid] of unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92256G'  /*Nondisplaced fracture of navicular [scaphoid] of unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92256K'  /*Nondisplaced fracture of navicular [scaphoid] of unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92256P'  /*Nondisplaced fracture of navicular [scaphoid] of unspecified foot, subsequent encounter for fracture with malunion*/
,'S92256S'  /*Nondisplaced fracture of navicular [scaphoid] of unspecified foot, sequela*/
,'S92301D'  /*Fracture of unspecified metatarsal bone(s), right foot, subsequent encounter for fracture with routine healing*/
,'S92301G'  /*Fracture of unspecified metatarsal bone(s), right foot, subsequent encounter for fracture with delayed healing*/
,'S92301K'  /*Fracture of unspecified metatarsal bone(s), right foot, subsequent encounter for fracture with nonunion*/
,'S92301P'  /*Fracture of unspecified metatarsal bone(s), right foot, subsequent encounter for fracture with malunion*/
,'S92301S'  /*Fracture of unspecified metatarsal bone(s), right foot, sequela*/
,'S92302D'  /*Fracture of unspecified metatarsal bone(s), left foot, subsequent encounter for fracture with routine healing*/
,'S92302G'  /*Fracture of unspecified metatarsal bone(s), left foot, subsequent encounter for fracture with delayed healing*/
,'S92302K'  /*Fracture of unspecified metatarsal bone(s), left foot, subsequent encounter for fracture with nonunion*/
,'S92302P'  /*Fracture of unspecified metatarsal bone(s), left foot, subsequent encounter for fracture with malunion*/
,'S92302S'  /*Fracture of unspecified metatarsal bone(s), left foot, sequela*/
,'S92309D'  /*Fracture of unspecified metatarsal bone(s), unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92309G'  /*Fracture of unspecified metatarsal bone(s), unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92309K'  /*Fracture of unspecified metatarsal bone(s), unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92309P'  /*Fracture of unspecified metatarsal bone(s), unspecified foot, subsequent encounter for fracture with malunion*/
,'S92309S'  /*Fracture of unspecified metatarsal bone(s), unspecified foot, sequela*/
,'S92311D'  /*Displaced fracture of first metatarsal bone, right foot, subsequent encounter for fracture with routine healing*/
,'S92311G'  /*Displaced fracture of first metatarsal bone, right foot, subsequent encounter for fracture with delayed healing*/
,'S92311K'  /*Displaced fracture of first metatarsal bone, right foot, subsequent encounter for fracture with nonunion*/
,'S92311P'  /*Displaced fracture of first metatarsal bone, right foot, subsequent encounter for fracture with malunion*/
,'S92311S'  /*Displaced fracture of first metatarsal bone, right foot, sequela*/
,'S92312D'  /*Displaced fracture of first metatarsal bone, left foot, subsequent encounter for fracture with routine healing*/
,'S92312G'  /*Displaced fracture of first metatarsal bone, left foot, subsequent encounter for fracture with delayed healing*/
,'S92312K'  /*Displaced fracture of first metatarsal bone, left foot, subsequent encounter for fracture with nonunion*/
,'S92312P'  /*Displaced fracture of first metatarsal bone, left foot, subsequent encounter for fracture with malunion*/
,'S92312S'  /*Displaced fracture of first metatarsal bone, left foot, sequela*/
,'S92313D'  /*Displaced fracture of first metatarsal bone, unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92313G'  /*Displaced fracture of first metatarsal bone, unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92313K'  /*Displaced fracture of first metatarsal bone, unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92313P'  /*Displaced fracture of first metatarsal bone, unspecified foot, subsequent encounter for fracture with malunion*/
,'S92313S'  /*Displaced fracture of first metatarsal bone, unspecified foot, sequela*/
,'S92314D'  /*Nondisplaced fracture of first metatarsal bone, right foot, subsequent encounter for fracture with routine healing*/
,'S92314G'  /*Nondisplaced fracture of first metatarsal bone, right foot, subsequent encounter for fracture with delayed healing*/
,'S92314K'  /*Nondisplaced fracture of first metatarsal bone, right foot, subsequent encounter for fracture with nonunion*/
,'S92314P'  /*Nondisplaced fracture of first metatarsal bone, right foot, subsequent encounter for fracture with malunion*/
,'S92314S'  /*Nondisplaced fracture of first metatarsal bone, right foot, sequela*/
,'S92315D'  /*Nondisplaced fracture of first metatarsal bone, left foot, subsequent encounter for fracture with routine healing*/
,'S92315G'  /*Nondisplaced fracture of first metatarsal bone, left foot, subsequent encounter for fracture with delayed healing*/
,'S92315K'  /*Nondisplaced fracture of first metatarsal bone, left foot, subsequent encounter for fracture with nonunion*/
,'S92315P'  /*Nondisplaced fracture of first metatarsal bone, left foot, subsequent encounter for fracture with malunion*/
,'S92315S'  /*Nondisplaced fracture of first metatarsal bone, left foot, sequela*/
,'S92316D'  /*Nondisplaced fracture of first metatarsal bone, unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92316G'  /*Nondisplaced fracture of first metatarsal bone, unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92316K'  /*Nondisplaced fracture of first metatarsal bone, unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92316P'  /*Nondisplaced fracture of first metatarsal bone, unspecified foot, subsequent encounter for fracture with malunion*/
,'S92316S'  /*Nondisplaced fracture of first metatarsal bone, unspecified foot, sequela*/
,'S92321D'  /*Displaced fracture of second metatarsal bone, right foot, subsequent encounter for fracture with routine healing*/
,'S92321G'  /*Displaced fracture of second metatarsal bone, right foot, subsequent encounter for fracture with delayed healing*/
,'S92321K'  /*Displaced fracture of second metatarsal bone, right foot, subsequent encounter for fracture with nonunion*/
,'S92321P'  /*Displaced fracture of second metatarsal bone, right foot, subsequent encounter for fracture with malunion*/
,'S92321S'  /*Displaced fracture of second metatarsal bone, right foot, sequela*/
,'S92322D'  /*Displaced fracture of second metatarsal bone, left foot, subsequent encounter for fracture with routine healing*/
,'S92322G'  /*Displaced fracture of second metatarsal bone, left foot, subsequent encounter for fracture with delayed healing*/
,'S92322K'  /*Displaced fracture of second metatarsal bone, left foot, subsequent encounter for fracture with nonunion*/
,'S92322P'  /*Displaced fracture of second metatarsal bone, left foot, subsequent encounter for fracture with malunion*/
,'S92322S'  /*Displaced fracture of second metatarsal bone, left foot, sequela*/
,'S92323D'  /*Displaced fracture of second metatarsal bone, unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92323G'  /*Displaced fracture of second metatarsal bone, unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92323K'  /*Displaced fracture of second metatarsal bone, unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92323P'  /*Displaced fracture of second metatarsal bone, unspecified foot, subsequent encounter for fracture with malunion*/
,'S92323S'  /*Displaced fracture of second metatarsal bone, unspecified foot, sequela*/
,'S92324D'  /*Nondisplaced fracture of second metatarsal bone, right foot, subsequent encounter for fracture with routine healing*/
,'S92324G'  /*Nondisplaced fracture of second metatarsal bone, right foot, subsequent encounter for fracture with delayed healing*/
,'S92324K'  /*Nondisplaced fracture of second metatarsal bone, right foot, subsequent encounter for fracture with nonunion*/
,'S92324P'  /*Nondisplaced fracture of second metatarsal bone, right foot, subsequent encounter for fracture with malunion*/
,'S92324S'  /*Nondisplaced fracture of second metatarsal bone, right foot, sequela*/
,'S92325D'  /*Nondisplaced fracture of second metatarsal bone, left foot, subsequent encounter for fracture with routine healing*/
,'S92325G'  /*Nondisplaced fracture of second metatarsal bone, left foot, subsequent encounter for fracture with delayed healing*/
,'S92325K'  /*Nondisplaced fracture of second metatarsal bone, left foot, subsequent encounter for fracture with nonunion*/
,'S92325P'  /*Nondisplaced fracture of second metatarsal bone, left foot, subsequent encounter for fracture with malunion*/
,'S92325S'  /*Nondisplaced fracture of second metatarsal bone, left foot, sequela*/
,'S92326D'  /*Nondisplaced fracture of second metatarsal bone, unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92326G'  /*Nondisplaced fracture of second metatarsal bone, unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92326K'  /*Nondisplaced fracture of second metatarsal bone, unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92326P'  /*Nondisplaced fracture of second metatarsal bone, unspecified foot, subsequent encounter for fracture with malunion*/
,'S92326S'  /*Nondisplaced fracture of second metatarsal bone, unspecified foot, sequela*/
,'S92331D'  /*Displaced fracture of third metatarsal bone, right foot, subsequent encounter for fracture with routine healing*/
,'S92331G'  /*Displaced fracture of third metatarsal bone, right foot, subsequent encounter for fracture with delayed healing*/
,'S92331K'  /*Displaced fracture of third metatarsal bone, right foot, subsequent encounter for fracture with nonunion*/
,'S92331P'  /*Displaced fracture of third metatarsal bone, right foot, subsequent encounter for fracture with malunion*/
,'S92331S'  /*Displaced fracture of third metatarsal bone, right foot, sequela*/
,'S92332D'  /*Displaced fracture of third metatarsal bone, left foot, subsequent encounter for fracture with routine healing*/
,'S92332G'  /*Displaced fracture of third metatarsal bone, left foot, subsequent encounter for fracture with delayed healing*/
,'S92332K'  /*Displaced fracture of third metatarsal bone, left foot, subsequent encounter for fracture with nonunion*/
,'S92332P'  /*Displaced fracture of third metatarsal bone, left foot, subsequent encounter for fracture with malunion*/
,'S92332S'  /*Displaced fracture of third metatarsal bone, left foot, sequela*/
,'S92333D'  /*Displaced fracture of third metatarsal bone, unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92333G'  /*Displaced fracture of third metatarsal bone, unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92333K'  /*Displaced fracture of third metatarsal bone, unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92333P'  /*Displaced fracture of third metatarsal bone, unspecified foot, subsequent encounter for fracture with malunion*/
,'S92333S'  /*Displaced fracture of third metatarsal bone, unspecified foot, sequela*/
,'S92334D'  /*Nondisplaced fracture of third metatarsal bone, right foot, subsequent encounter for fracture with routine healing*/
,'S92334G'  /*Nondisplaced fracture of third metatarsal bone, right foot, subsequent encounter for fracture with delayed healing*/
,'S92334K'  /*Nondisplaced fracture of third metatarsal bone, right foot, subsequent encounter for fracture with nonunion*/
,'S92334P'  /*Nondisplaced fracture of third metatarsal bone, right foot, subsequent encounter for fracture with malunion*/
,'S92334S'  /*Nondisplaced fracture of third metatarsal bone, right foot, sequela*/
,'S92335D'  /*Nondisplaced fracture of third metatarsal bone, left foot, subsequent encounter for fracture with routine healing*/
,'S92335G'  /*Nondisplaced fracture of third metatarsal bone, left foot, subsequent encounter for fracture with delayed healing*/
,'S92335K'  /*Nondisplaced fracture of third metatarsal bone, left foot, subsequent encounter for fracture with nonunion*/
,'S92335P'  /*Nondisplaced fracture of third metatarsal bone, left foot, subsequent encounter for fracture with malunion*/
,'S92335S'  /*Nondisplaced fracture of third metatarsal bone, left foot, sequela*/
,'S92336D'  /*Nondisplaced fracture of third metatarsal bone, unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92336G'  /*Nondisplaced fracture of third metatarsal bone, unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92336K'  /*Nondisplaced fracture of third metatarsal bone, unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92336P'  /*Nondisplaced fracture of third metatarsal bone, unspecified foot, subsequent encounter for fracture with malunion*/
,'S92336S'  /*Nondisplaced fracture of third metatarsal bone, unspecified foot, sequela*/
,'S92341D'  /*Displaced fracture of fourth metatarsal bone, right foot, subsequent encounter for fracture with routine healing*/
,'S92341G'  /*Displaced fracture of fourth metatarsal bone, right foot, subsequent encounter for fracture with delayed healing*/
,'S92341K'  /*Displaced fracture of fourth metatarsal bone, right foot, subsequent encounter for fracture with nonunion*/
,'S92341P'  /*Displaced fracture of fourth metatarsal bone, right foot, subsequent encounter for fracture with malunion*/
,'S92341S'  /*Displaced fracture of fourth metatarsal bone, right foot, sequela*/
,'S92342D'  /*Displaced fracture of fourth metatarsal bone, left foot, subsequent encounter for fracture with routine healing*/
,'S92342G'  /*Displaced fracture of fourth metatarsal bone, left foot, subsequent encounter for fracture with delayed healing*/
,'S92342K'  /*Displaced fracture of fourth metatarsal bone, left foot, subsequent encounter for fracture with nonunion*/
,'S92342P'  /*Displaced fracture of fourth metatarsal bone, left foot, subsequent encounter for fracture with malunion*/
,'S92342S'  /*Displaced fracture of fourth metatarsal bone, left foot, sequela*/
,'S92343D'  /*Displaced fracture of fourth metatarsal bone, unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92343G'  /*Displaced fracture of fourth metatarsal bone, unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92343K'  /*Displaced fracture of fourth metatarsal bone, unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92343P'  /*Displaced fracture of fourth metatarsal bone, unspecified foot, subsequent encounter for fracture with malunion*/
,'S92343S'  /*Displaced fracture of fourth metatarsal bone, unspecified foot, sequela*/
,'S92344D'  /*Nondisplaced fracture of fourth metatarsal bone, right foot, subsequent encounter for fracture with routine healing*/
,'S92344G'  /*Nondisplaced fracture of fourth metatarsal bone, right foot, subsequent encounter for fracture with delayed healing*/
,'S92344K'  /*Nondisplaced fracture of fourth metatarsal bone, right foot, subsequent encounter for fracture with nonunion*/
,'S92344P'  /*Nondisplaced fracture of fourth metatarsal bone, right foot, subsequent encounter for fracture with malunion*/
,'S92344S'  /*Nondisplaced fracture of fourth metatarsal bone, right foot, sequela*/
,'S92345D'  /*Nondisplaced fracture of fourth metatarsal bone, left foot, subsequent encounter for fracture with routine healing*/
,'S92345G'  /*Nondisplaced fracture of fourth metatarsal bone, left foot, subsequent encounter for fracture with delayed healing*/
,'S92345K'  /*Nondisplaced fracture of fourth metatarsal bone, left foot, subsequent encounter for fracture with nonunion*/
,'S92345P'  /*Nondisplaced fracture of fourth metatarsal bone, left foot, subsequent encounter for fracture with malunion*/
,'S92345S'  /*Nondisplaced fracture of fourth metatarsal bone, left foot, sequela*/
,'S92346D'  /*Nondisplaced fracture of fourth metatarsal bone, unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92346G'  /*Nondisplaced fracture of fourth metatarsal bone, unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92346K'  /*Nondisplaced fracture of fourth metatarsal bone, unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92346P'  /*Nondisplaced fracture of fourth metatarsal bone, unspecified foot, subsequent encounter for fracture with malunion*/
,'S92346S'  /*Nondisplaced fracture of fourth metatarsal bone, unspecified foot, sequela*/
,'S92351D'  /*Displaced fracture of fifth metatarsal bone, right foot, subsequent encounter for fracture with routine healing*/
,'S92351G'  /*Displaced fracture of fifth metatarsal bone, right foot, subsequent encounter for fracture with delayed healing*/
,'S92351K'  /*Displaced fracture of fifth metatarsal bone, right foot, subsequent encounter for fracture with nonunion*/
,'S92351P'  /*Displaced fracture of fifth metatarsal bone, right foot, subsequent encounter for fracture with malunion*/
,'S92351S'  /*Displaced fracture of fifth metatarsal bone, right foot, sequela*/
,'S92352D'  /*Displaced fracture of fifth metatarsal bone, left foot, subsequent encounter for fracture with routine healing*/
,'S92352G'  /*Displaced fracture of fifth metatarsal bone, left foot, subsequent encounter for fracture with delayed healing*/
,'S92352K'  /*Displaced fracture of fifth metatarsal bone, left foot, subsequent encounter for fracture with nonunion*/
,'S92352P'  /*Displaced fracture of fifth metatarsal bone, left foot, subsequent encounter for fracture with malunion*/
,'S92352S'  /*Displaced fracture of fifth metatarsal bone, left foot, sequela*/
,'S92353D'  /*Displaced fracture of fifth metatarsal bone, unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92353G'  /*Displaced fracture of fifth metatarsal bone, unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92353K'  /*Displaced fracture of fifth metatarsal bone, unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92353P'  /*Displaced fracture of fifth metatarsal bone, unspecified foot, subsequent encounter for fracture with malunion*/
,'S92353S'  /*Displaced fracture of fifth metatarsal bone, unspecified foot, sequela*/
,'S92354D'  /*Nondisplaced fracture of fifth metatarsal bone, right foot, subsequent encounter for fracture with routine healing*/
,'S92354G'  /*Nondisplaced fracture of fifth metatarsal bone, right foot, subsequent encounter for fracture with delayed healing*/
,'S92354K'  /*Nondisplaced fracture of fifth metatarsal bone, right foot, subsequent encounter for fracture with nonunion*/
,'S92354P'  /*Nondisplaced fracture of fifth metatarsal bone, right foot, subsequent encounter for fracture with malunion*/
,'S92354S'  /*Nondisplaced fracture of fifth metatarsal bone, right foot, sequela*/
,'S92355D'  /*Nondisplaced fracture of fifth metatarsal bone, left foot, subsequent encounter for fracture with routine healing*/
,'S92355G'  /*Nondisplaced fracture of fifth metatarsal bone, left foot, subsequent encounter for fracture with delayed healing*/
,'S92355K'  /*Nondisplaced fracture of fifth metatarsal bone, left foot, subsequent encounter for fracture with nonunion*/
,'S92355P'  /*Nondisplaced fracture of fifth metatarsal bone, left foot, subsequent encounter for fracture with malunion*/
,'S92355S'  /*Nondisplaced fracture of fifth metatarsal bone, left foot, sequela*/
,'S92356D'  /*Nondisplaced fracture of fifth metatarsal bone, unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92356G'  /*Nondisplaced fracture of fifth metatarsal bone, unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92356K'  /*Nondisplaced fracture of fifth metatarsal bone, unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92356P'  /*Nondisplaced fracture of fifth metatarsal bone, unspecified foot, subsequent encounter for fracture with malunion*/
,'S92356S'  /*Nondisplaced fracture of fifth metatarsal bone, unspecified foot, sequela*/
,'S92401D'  /*Displaced unspecified fracture of right great toe, subsequent encounter for fracture with routine healing*/
,'S92401G'  /*Displaced unspecified fracture of right great toe, subsequent encounter for fracture with delayed healing*/
,'S92401K'  /*Displaced unspecified fracture of right great toe, subsequent encounter for fracture with nonunion*/
,'S92401P'  /*Displaced unspecified fracture of right great toe, subsequent encounter for fracture with malunion*/
,'S92401S'  /*Displaced unspecified fracture of right great toe, sequela*/
,'S92402D'  /*Displaced unspecified fracture of left great toe, subsequent encounter for fracture with routine healing*/
,'S92402G'  /*Displaced unspecified fracture of left great toe, subsequent encounter for fracture with delayed healing*/
,'S92402K'  /*Displaced unspecified fracture of left great toe, subsequent encounter for fracture with nonunion*/
,'S92402P'  /*Displaced unspecified fracture of left great toe, subsequent encounter for fracture with malunion*/
,'S92402S'  /*Displaced unspecified fracture of left great toe, sequela*/
,'S92403D'  /*Displaced unspecified fracture of unspecified great toe, subsequent encounter for fracture with routine healing*/
,'S92403G'  /*Displaced unspecified fracture of unspecified great toe, subsequent encounter for fracture with delayed healing*/
,'S92403K'  /*Displaced unspecified fracture of unspecified great toe, subsequent encounter for fracture with nonunion*/
,'S92403P'  /*Displaced unspecified fracture of unspecified great toe, subsequent encounter for fracture with malunion*/
,'S92403S'  /*Displaced unspecified fracture of unspecified great toe, sequela*/
,'S92404D'  /*Nondisplaced unspecified fracture of right great toe, subsequent encounter for fracture with routine healing*/
,'S92404G'  /*Nondisplaced unspecified fracture of right great toe, subsequent encounter for fracture with delayed healing*/
,'S92404K'  /*Nondisplaced unspecified fracture of right great toe, subsequent encounter for fracture with nonunion*/
,'S92404P'  /*Nondisplaced unspecified fracture of right great toe, subsequent encounter for fracture with malunion*/
,'S92404S'  /*Nondisplaced unspecified fracture of right great toe, sequela*/
,'S92405D'  /*Nondisplaced unspecified fracture of left great toe, subsequent encounter for fracture with routine healing*/
,'S92405G'  /*Nondisplaced unspecified fracture of left great toe, subsequent encounter for fracture with delayed healing*/
,'S92405K'  /*Nondisplaced unspecified fracture of left great toe, subsequent encounter for fracture with nonunion*/
,'S92405P'  /*Nondisplaced unspecified fracture of left great toe, subsequent encounter for fracture with malunion*/
,'S92405S'  /*Nondisplaced unspecified fracture of left great toe, sequela*/
,'S92406D'  /*Nondisplaced unspecified fracture of unspecified great toe, subsequent encounter for fracture with routine healing*/
,'S92406G'  /*Nondisplaced unspecified fracture of unspecified great toe, subsequent encounter for fracture with delayed healing*/
,'S92406K'  /*Nondisplaced unspecified fracture of unspecified great toe, subsequent encounter for fracture with nonunion*/
,'S92406P'  /*Nondisplaced unspecified fracture of unspecified great toe, subsequent encounter for fracture with malunion*/
,'S92406S'  /*Nondisplaced unspecified fracture of unspecified great toe, sequela*/
,'S92411D'  /*Displaced fracture of proximal phalanx of right great toe, subsequent encounter for fracture with routine healing*/
,'S92411G'  /*Displaced fracture of proximal phalanx of right great toe, subsequent encounter for fracture with delayed healing*/
,'S92411K'  /*Displaced fracture of proximal phalanx of right great toe, subsequent encounter for fracture with nonunion*/
,'S92411P'  /*Displaced fracture of proximal phalanx of right great toe, subsequent encounter for fracture with malunion*/
,'S92411S'  /*Displaced fracture of proximal phalanx of right great toe, sequela*/
,'S92412D'  /*Displaced fracture of proximal phalanx of left great toe, subsequent encounter for fracture with routine healing*/
,'S92412G'  /*Displaced fracture of proximal phalanx of left great toe, subsequent encounter for fracture with delayed healing*/
,'S92412K'  /*Displaced fracture of proximal phalanx of left great toe, subsequent encounter for fracture with nonunion*/
,'S92412P'  /*Displaced fracture of proximal phalanx of left great toe, subsequent encounter for fracture with malunion*/
,'S92412S'  /*Displaced fracture of proximal phalanx of left great toe, sequela*/
,'S92413D'  /*Displaced fracture of proximal phalanx of unspecified great toe, subsequent encounter for fracture with routine healing*/
,'S92413G'  /*Displaced fracture of proximal phalanx of unspecified great toe, subsequent encounter for fracture with delayed healing*/
,'S92413K'  /*Displaced fracture of proximal phalanx of unspecified great toe, subsequent encounter for fracture with nonunion*/
,'S92413P'  /*Displaced fracture of proximal phalanx of unspecified great toe, subsequent encounter for fracture with malunion*/
,'S92413S'  /*Displaced fracture of proximal phalanx of unspecified great toe, sequela*/
,'S92414D'  /*Nondisplaced fracture of proximal phalanx of right great toe, subsequent encounter for fracture with routine healing*/
,'S92414G'  /*Nondisplaced fracture of proximal phalanx of right great toe, subsequent encounter for fracture with delayed healing*/
,'S92414K'  /*Nondisplaced fracture of proximal phalanx of right great toe, subsequent encounter for fracture with nonunion*/
,'S92414P'  /*Nondisplaced fracture of proximal phalanx of right great toe, subsequent encounter for fracture with malunion*/
,'S92414S'  /*Nondisplaced fracture of proximal phalanx of right great toe, sequela*/
,'S92415D'  /*Nondisplaced fracture of proximal phalanx of left great toe, subsequent encounter for fracture with routine healing*/
,'S92415G'  /*Nondisplaced fracture of proximal phalanx of left great toe, subsequent encounter for fracture with delayed healing*/
,'S92415K'  /*Nondisplaced fracture of proximal phalanx of left great toe, subsequent encounter for fracture with nonunion*/
,'S92415P'  /*Nondisplaced fracture of proximal phalanx of left great toe, subsequent encounter for fracture with malunion*/
,'S92415S'  /*Nondisplaced fracture of proximal phalanx of left great toe, sequela*/
,'S92416D'  /*Nondisplaced fracture of proximal phalanx of unspecified great toe, subsequent encounter for fracture with routine healing*/
,'S92416G'  /*Nondisplaced fracture of proximal phalanx of unspecified great toe, subsequent encounter for fracture with delayed healing*/
,'S92416K'  /*Nondisplaced fracture of proximal phalanx of unspecified great toe, subsequent encounter for fracture with nonunion*/
,'S92416P'  /*Nondisplaced fracture of proximal phalanx of unspecified great toe, subsequent encounter for fracture with malunion*/
,'S92416S'  /*Nondisplaced fracture of proximal phalanx of unspecified great toe, sequela*/
,'S92421D'  /*Displaced fracture of distal phalanx of right great toe, subsequent encounter for fracture with routine healing*/
,'S92421G'  /*Displaced fracture of distal phalanx of right great toe, subsequent encounter for fracture with delayed healing*/
,'S92421K'  /*Displaced fracture of distal phalanx of right great toe, subsequent encounter for fracture with nonunion*/
,'S92421P'  /*Displaced fracture of distal phalanx of right great toe, subsequent encounter for fracture with malunion*/
,'S92421S'  /*Displaced fracture of distal phalanx of right great toe, sequela*/
,'S92422D'  /*Displaced fracture of distal phalanx of left great toe, subsequent encounter for fracture with routine healing*/
,'S92422G'  /*Displaced fracture of distal phalanx of left great toe, subsequent encounter for fracture with delayed healing*/
,'S92422K'  /*Displaced fracture of distal phalanx of left great toe, subsequent encounter for fracture with nonunion*/
,'S92422P'  /*Displaced fracture of distal phalanx of left great toe, subsequent encounter for fracture with malunion*/
,'S92422S'  /*Displaced fracture of distal phalanx of left great toe, sequela*/
,'S92423D'  /*Displaced fracture of distal phalanx of unspecified great toe, subsequent encounter for fracture with routine healing*/
,'S92423G'  /*Displaced fracture of distal phalanx of unspecified great toe, subsequent encounter for fracture with delayed healing*/
,'S92423K'  /*Displaced fracture of distal phalanx of unspecified great toe, subsequent encounter for fracture with nonunion*/
,'S92423P'  /*Displaced fracture of distal phalanx of unspecified great toe, subsequent encounter for fracture with malunion*/
,'S92423S'  /*Displaced fracture of distal phalanx of unspecified great toe, sequela*/
,'S92424D'  /*Nondisplaced fracture of distal phalanx of right great toe, subsequent encounter for fracture with routine healing*/
,'S92424G'  /*Nondisplaced fracture of distal phalanx of right great toe, subsequent encounter for fracture with delayed healing*/
,'S92424K'  /*Nondisplaced fracture of distal phalanx of right great toe, subsequent encounter for fracture with nonunion*/
,'S92424P'  /*Nondisplaced fracture of distal phalanx of right great toe, subsequent encounter for fracture with malunion*/
,'S92424S'  /*Nondisplaced fracture of distal phalanx of right great toe, sequela*/
,'S92425D'  /*Nondisplaced fracture of distal phalanx of left great toe, subsequent encounter for fracture with routine healing*/
,'S92425G'  /*Nondisplaced fracture of distal phalanx of left great toe, subsequent encounter for fracture with delayed healing*/
,'S92425K'  /*Nondisplaced fracture of distal phalanx of left great toe, subsequent encounter for fracture with nonunion*/
,'S92425P'  /*Nondisplaced fracture of distal phalanx of left great toe, subsequent encounter for fracture with malunion*/
,'S92425S'  /*Nondisplaced fracture of distal phalanx of left great toe, sequela*/
,'S92426D'  /*Nondisplaced fracture of distal phalanx of unspecified great toe, subsequent encounter for fracture with routine healing*/
,'S92426G'  /*Nondisplaced fracture of distal phalanx of unspecified great toe, subsequent encounter for fracture with delayed healing*/
,'S92426K'  /*Nondisplaced fracture of distal phalanx of unspecified great toe, subsequent encounter for fracture with nonunion*/
,'S92426P'  /*Nondisplaced fracture of distal phalanx of unspecified great toe, subsequent encounter for fracture with malunion*/
,'S92426S'  /*Nondisplaced fracture of distal phalanx of unspecified great toe, sequela*/
,'S92491D'  /*Other fracture of right great toe, subsequent encounter for fracture with routine healing*/
,'S92491G'  /*Other fracture of right great toe, subsequent encounter for fracture with delayed healing*/
,'S92491K'  /*Other fracture of right great toe, subsequent encounter for fracture with nonunion*/
,'S92491P'  /*Other fracture of right great toe, subsequent encounter for fracture with malunion*/
,'S92491S'  /*Other fracture of right great toe, sequela*/
,'S92492D'  /*Other fracture of left great toe, subsequent encounter for fracture with routine healing*/
,'S92492G'  /*Other fracture of left great toe, subsequent encounter for fracture with delayed healing*/
,'S92492K'  /*Other fracture of left great toe, subsequent encounter for fracture with nonunion*/
,'S92492P'  /*Other fracture of left great toe, subsequent encounter for fracture with malunion*/
,'S92492S'  /*Other fracture of left great toe, sequela*/
,'S92499D'  /*Other fracture of unspecified great toe, subsequent encounter for fracture with routine healing*/
,'S92499G'  /*Other fracture of unspecified great toe, subsequent encounter for fracture with delayed healing*/
,'S92499K'  /*Other fracture of unspecified great toe, subsequent encounter for fracture with nonunion*/
,'S92499P'  /*Other fracture of unspecified great toe, subsequent encounter for fracture with malunion*/
,'S92499S'  /*Other fracture of unspecified great toe, sequela*/
,'S92501D'  /*Displaced unspecified fracture of right lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92501G'  /*Displaced unspecified fracture of right lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92501K'  /*Displaced unspecified fracture of right lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92501P'  /*Displaced unspecified fracture of right lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92501S'  /*Displaced unspecified fracture of right lesser toe(s), sequela*/
,'S92502D'  /*Displaced unspecified fracture of left lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92502G'  /*Displaced unspecified fracture of left lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92502K'  /*Displaced unspecified fracture of left lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92502P'  /*Displaced unspecified fracture of left lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92502S'  /*Displaced unspecified fracture of left lesser toe(s), sequela*/
,'S92503D'  /*Displaced unspecified fracture of unspecified lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92503G'  /*Displaced unspecified fracture of unspecified lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92503K'  /*Displaced unspecified fracture of unspecified lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92503P'  /*Displaced unspecified fracture of unspecified lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92503S'  /*Displaced unspecified fracture of unspecified lesser toe(s), sequela*/
,'S92504D'  /*Nondisplaced unspecified fracture of right lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92504G'  /*Nondisplaced unspecified fracture of right lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92504K'  /*Nondisplaced unspecified fracture of right lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92504P'  /*Nondisplaced unspecified fracture of right lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92504S'  /*Nondisplaced unspecified fracture of right lesser toe(s), sequela*/
,'S92505D'  /*Nondisplaced unspecified fracture of left lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92505G'  /*Nondisplaced unspecified fracture of left lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92505K'  /*Nondisplaced unspecified fracture of left lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92505P'  /*Nondisplaced unspecified fracture of left lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92505S'  /*Nondisplaced unspecified fracture of left lesser toe(s), sequela*/
,'S92506D'  /*Nondisplaced unspecified fracture of unspecified lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92506G'  /*Nondisplaced unspecified fracture of unspecified lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92506K'  /*Nondisplaced unspecified fracture of unspecified lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92506P'  /*Nondisplaced unspecified fracture of unspecified lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92506S'  /*Nondisplaced unspecified fracture of unspecified lesser toe(s), sequela*/
,'S92511D'  /*Displaced fracture of proximal phalanx of right lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92511G'  /*Displaced fracture of proximal phalanx of right lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92511K'  /*Displaced fracture of proximal phalanx of right lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92511P'  /*Displaced fracture of proximal phalanx of right lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92511S'  /*Displaced fracture of proximal phalanx of right lesser toe(s), sequela*/
,'S92512D'  /*Displaced fracture of proximal phalanx of left lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92512G'  /*Displaced fracture of proximal phalanx of left lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92512K'  /*Displaced fracture of proximal phalanx of left lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92512P'  /*Displaced fracture of proximal phalanx of left lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92512S'  /*Displaced fracture of proximal phalanx of left lesser toe(s), sequela*/
,'S92513D'  /*Displaced fracture of proximal phalanx of unspecified lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92513G'  /*Displaced fracture of proximal phalanx of unspecified lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92513K'  /*Displaced fracture of proximal phalanx of unspecified lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92513P'  /*Displaced fracture of proximal phalanx of unspecified lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92513S'  /*Displaced fracture of proximal phalanx of unspecified lesser toe(s), sequela*/
,'S92514D'  /*Nondisplaced fracture of proximal phalanx of right lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92514G'  /*Nondisplaced fracture of proximal phalanx of right lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92514K'  /*Nondisplaced fracture of proximal phalanx of right lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92514P'  /*Nondisplaced fracture of proximal phalanx of right lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92514S'  /*Nondisplaced fracture of proximal phalanx of right lesser toe(s), sequela*/
,'S92515D'  /*Nondisplaced fracture of proximal phalanx of left lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92515G'  /*Nondisplaced fracture of proximal phalanx of left lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92515K'  /*Nondisplaced fracture of proximal phalanx of left lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92515P'  /*Nondisplaced fracture of proximal phalanx of left lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92515S'  /*Nondisplaced fracture of proximal phalanx of left lesser toe(s), sequela*/
,'S92516D'  /*Nondisplaced fracture of proximal phalanx of unspecified lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92516G'  /*Nondisplaced fracture of proximal phalanx of unspecified lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92516K'  /*Nondisplaced fracture of proximal phalanx of unspecified lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92516P'  /*Nondisplaced fracture of proximal phalanx of unspecified lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92516S'  /*Nondisplaced fracture of proximal phalanx of unspecified lesser toe(s), sequela*/
,'S92521D'  /*Displaced fracture of medial phalanx of right lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92521G'  /*Displaced fracture of medial phalanx of right lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92521K'  /*Displaced fracture of medial phalanx of right lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92521P'  /*Displaced fracture of medial phalanx of right lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92521S'  /*Displaced fracture of medial phalanx of right lesser toe(s), sequela*/
,'S92522D'  /*Displaced fracture of medial phalanx of left lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92522G'  /*Displaced fracture of medial phalanx of left lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92522K'  /*Displaced fracture of medial phalanx of left lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92522P'  /*Displaced fracture of medial phalanx of left lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92522S'  /*Displaced fracture of medial phalanx of left lesser toe(s), sequela*/
,'S92523D'  /*Displaced fracture of medial phalanx of unspecified lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92523G'  /*Displaced fracture of medial phalanx of unspecified lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92523K'  /*Displaced fracture of medial phalanx of unspecified lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92523P'  /*Displaced fracture of medial phalanx of unspecified lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92523S'  /*Displaced fracture of medial phalanx of unspecified lesser toe(s), sequela*/
,'S92524D'  /*Nondisplaced fracture of medial phalanx of right lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92524G'  /*Nondisplaced fracture of medial phalanx of right lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92524K'  /*Nondisplaced fracture of medial phalanx of right lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92524P'  /*Nondisplaced fracture of medial phalanx of right lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92524S'  /*Nondisplaced fracture of medial phalanx of right lesser toe(s), sequela*/
,'S92525D'  /*Nondisplaced fracture of medial phalanx of left lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92525G'  /*Nondisplaced fracture of medial phalanx of left lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92525K'  /*Nondisplaced fracture of medial phalanx of left lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92525P'  /*Nondisplaced fracture of medial phalanx of left lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92525S'  /*Nondisplaced fracture of medial phalanx of left lesser toe(s), sequela*/
,'S92526D'  /*Nondisplaced fracture of medial phalanx of unspecified lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92526G'  /*Nondisplaced fracture of medial phalanx of unspecified lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92526K'  /*Nondisplaced fracture of medial phalanx of unspecified lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92526P'  /*Nondisplaced fracture of medial phalanx of unspecified lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92526S'  /*Nondisplaced fracture of medial phalanx of unspecified lesser toe(s), sequela*/
,'S92531D'  /*Displaced fracture of distal phalanx of right lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92531G'  /*Displaced fracture of distal phalanx of right lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92531K'  /*Displaced fracture of distal phalanx of right lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92531P'  /*Displaced fracture of distal phalanx of right lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92531S'  /*Displaced fracture of distal phalanx of right lesser toe(s), sequela*/
,'S92532D'  /*Displaced fracture of distal phalanx of left lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92532G'  /*Displaced fracture of distal phalanx of left lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92532K'  /*Displaced fracture of distal phalanx of left lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92532P'  /*Displaced fracture of distal phalanx of left lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92532S'  /*Displaced fracture of distal phalanx of left lesser toe(s), sequela*/
,'S92533D'  /*Displaced fracture of distal phalanx of unspecified lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92533G'  /*Displaced fracture of distal phalanx of unspecified lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92533K'  /*Displaced fracture of distal phalanx of unspecified lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92533P'  /*Displaced fracture of distal phalanx of unspecified lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92533S'  /*Displaced fracture of distal phalanx of unspecified lesser toe(s), sequela*/
,'S92534D'  /*Nondisplaced fracture of distal phalanx of right lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92534G'  /*Nondisplaced fracture of distal phalanx of right lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92534K'  /*Nondisplaced fracture of distal phalanx of right lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92534P'  /*Nondisplaced fracture of distal phalanx of right lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92534S'  /*Nondisplaced fracture of distal phalanx of right lesser toe(s), sequela*/
,'S92535D'  /*Nondisplaced fracture of distal phalanx of left lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92535G'  /*Nondisplaced fracture of distal phalanx of left lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92535K'  /*Nondisplaced fracture of distal phalanx of left lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92535P'  /*Nondisplaced fracture of distal phalanx of left lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92535S'  /*Nondisplaced fracture of distal phalanx of left lesser toe(s), sequela*/
,'S92536D'  /*Nondisplaced fracture of distal phalanx of unspecified lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92536G'  /*Nondisplaced fracture of distal phalanx of unspecified lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92536K'  /*Nondisplaced fracture of distal phalanx of unspecified lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92536P'  /*Nondisplaced fracture of distal phalanx of unspecified lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92536S'  /*Nondisplaced fracture of distal phalanx of unspecified lesser toe(s), sequela*/
,'S92591D'  /*Other fracture of right lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92591G'  /*Other fracture of right lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92591K'  /*Other fracture of right lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92591P'  /*Other fracture of right lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92591S'  /*Other fracture of right lesser toe(s), sequela*/
,'S92592D'  /*Other fracture of left lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92592G'  /*Other fracture of left lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92592K'  /*Other fracture of left lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92592P'  /*Other fracture of left lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92592S'  /*Other fracture of left lesser toe(s), sequela*/
,'S92599D'  /*Other fracture of unspecified lesser toe(s), subsequent encounter for fracture with routine healing*/
,'S92599G'  /*Other fracture of unspecified lesser toe(s), subsequent encounter for fracture with delayed healing*/
,'S92599K'  /*Other fracture of unspecified lesser toe(s), subsequent encounter for fracture with nonunion*/
,'S92599P'  /*Other fracture of unspecified lesser toe(s), subsequent encounter for fracture with malunion*/
,'S92599S'  /*Other fracture of unspecified lesser toe(s), sequela*/
,'S92811D'  /*Other fracture of right foot, subsequent encounter for fracture with routine healing*/
,'S92811G'  /*Other fracture of right foot, subsequent encounter for fracture with delayed healing*/
,'S92811K'  /*Other fracture of right foot, subsequent encounter for fracture with nonunion*/
,'S92811P'  /*Other fracture of right foot, subsequent encounter for fracture with malunion*/
,'S92811S'  /*Other fracture of right foot, sequela*/
,'S92812D'  /*Other fracture of left foot, subsequent encounter for fracture with routine healing*/
,'S92812G'  /*Other fracture of left foot, subsequent encounter for fracture with delayed healing*/
,'S92812K'  /*Other fracture of left foot, subsequent encounter for fracture with nonunion*/
,'S92812P'  /*Other fracture of left foot, subsequent encounter for fracture with malunion*/
,'S92812S'  /*Other fracture of left foot, sequela*/
,'S92819D'  /*Other fracture of unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92819G'  /*Other fracture of unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92819K'  /*Other fracture of unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92819P'  /*Other fracture of unspecified foot, subsequent encounter for fracture with malunion*/
,'S92819S'  /*Other fracture of unspecified foot, sequela*/
,'S92901D'  /*Unspecified fracture of right foot, subsequent encounter for fracture with routine healing*/
,'S92901G'  /*Unspecified fracture of right foot, subsequent encounter for fracture with delayed healing*/
,'S92901K'  /*Unspecified fracture of right foot, subsequent encounter for fracture with nonunion*/
,'S92901P'  /*Unspecified fracture of right foot, subsequent encounter for fracture with malunion*/
,'S92901S'  /*Unspecified fracture of right foot, sequela*/
,'S92902D'  /*Unspecified fracture of left foot, subsequent encounter for fracture with routine healing*/
,'S92902G'  /*Unspecified fracture of left foot, subsequent encounter for fracture with delayed healing*/
,'S92902K'  /*Unspecified fracture of left foot, subsequent encounter for fracture with nonunion*/
,'S92902P'  /*Unspecified fracture of left foot, subsequent encounter for fracture with malunion*/
,'S92902S'  /*Unspecified fracture of left foot, sequela*/
,'S92909D'  /*Unspecified fracture of unspecified foot, subsequent encounter for fracture with routine healing*/
,'S92909G'  /*Unspecified fracture of unspecified foot, subsequent encounter for fracture with delayed healing*/
,'S92909K'  /*Unspecified fracture of unspecified foot, subsequent encounter for fracture with nonunion*/
,'S92909P'  /*Unspecified fracture of unspecified foot, subsequent encounter for fracture with malunion*/
,'S92909S'  /*Unspecified fracture of unspecified foot, sequela*/
,'S92911D'  /*Unspecified fracture of right toe(s), subsequent encounter for fracture with routine healing*/
,'S92911G'  /*Unspecified fracture of right toe(s), subsequent encounter for fracture with delayed healing*/
,'S92911K'  /*Unspecified fracture of right toe(s), subsequent encounter for fracture with nonunion*/
,'S92911P'  /*Unspecified fracture of right toe(s), subsequent encounter for fracture with malunion*/
,'S92911S'  /*Unspecified fracture of right toe(s), sequela*/
,'S92912D'  /*Unspecified fracture of left toe(s), subsequent encounter for fracture with routine healing*/
,'S92912G'  /*Unspecified fracture of left toe(s), subsequent encounter for fracture with delayed healing*/
,'S92912K'  /*Unspecified fracture of left toe(s), subsequent encounter for fracture with nonunion*/
,'S92912P'  /*Unspecified fracture of left toe(s), subsequent encounter for fracture with malunion*/
,'S92912S'  /*Unspecified fracture of left toe(s), sequela*/
,'S92919D'  /*Unspecified fracture of unspecified toe(s), subsequent encounter for fracture with routine healing*/
,'S92919G'  /*Unspecified fracture of unspecified toe(s), subsequent encounter for fracture with delayed healing*/
,'S92919K'  /*Unspecified fracture of unspecified toe(s), subsequent encounter for fracture with nonunion*/
,'S92919P'  /*Unspecified fracture of unspecified toe(s), subsequent encounter for fracture with malunion*/
,'S92919S'  /*Unspecified fracture of unspecified toe(s), sequela*/
,'S9301XD'  /*Subluxation of right ankle joint, subsequent encounter*/
,'S9301XS'  /*Subluxation of right ankle joint, sequela*/
,'S9302XD'  /*Subluxation of left ankle joint, subsequent encounter*/
,'S9302XS'  /*Subluxation of left ankle joint, sequela*/
,'S9303XD'  /*Subluxation of unspecified ankle joint, subsequent encounter*/
,'S9303XS'  /*Subluxation of unspecified ankle joint, sequela*/
,'S9304XD'  /*Dislocation of right ankle joint, subsequent encounter*/
,'S9304XS'  /*Dislocation of right ankle joint, sequela*/
,'S9305XD'  /*Dislocation of left ankle joint, subsequent encounter*/
,'S9305XS'  /*Dislocation of left ankle joint, sequela*/
,'S9306XD'  /*Dislocation of unspecified ankle joint, subsequent encounter*/
,'S9306XS'  /*Dislocation of unspecified ankle joint, sequela*/
,'S93101D'  /*Unspecified subluxation of right toe(s), subsequent encounter*/
,'S93101S'  /*Unspecified subluxation of right toe(s), sequela*/
,'S93102D'  /*Unspecified subluxation of left toe(s), subsequent encounter*/
,'S93102S'  /*Unspecified subluxation of left toe(s), sequela*/
,'S93103D'  /*Unspecified subluxation of unspecified toe(s), subsequent encounter*/
,'S93103S'  /*Unspecified subluxation of unspecified toe(s), sequela*/
,'S93104D'  /*Unspecified dislocation of right toe(s), subsequent encounter*/
,'S93104S'  /*Unspecified dislocation of right toe(s), sequela*/
,'S93105D'  /*Unspecified dislocation of left toe(s), subsequent encounter*/
,'S93105S'  /*Unspecified dislocation of left toe(s), sequela*/
,'S93106D'  /*Unspecified dislocation of unspecified toe(s), subsequent encounter*/
,'S93106S'  /*Unspecified dislocation of unspecified toe(s), sequela*/
,'S93111D'  /*Dislocation of interphalangeal joint of right great toe, subsequent encounter*/
,'S93111S'  /*Dislocation of interphalangeal joint of right great toe, sequela*/
,'S93112D'  /*Dislocation of interphalangeal joint of left great toe, subsequent encounter*/
,'S93112S'  /*Dislocation of interphalangeal joint of left great toe, sequela*/
,'S93113D'  /*Dislocation of interphalangeal joint of unspecified great toe, subsequent encounter*/
,'S93113S'  /*Dislocation of interphalangeal joint of unspecified great toe, sequela*/
,'S93114D'  /*Dislocation of interphalangeal joint of right lesser toe(s), subsequent encounter*/
,'S93114S'  /*Dislocation of interphalangeal joint of right lesser toe(s), sequela*/
,'S93115D'  /*Dislocation of interphalangeal joint of left lesser toe(s), subsequent encounter*/
,'S93115S'  /*Dislocation of interphalangeal joint of left lesser toe(s), sequela*/
,'S93116D'  /*Dislocation of interphalangeal joint of unspecified lesser toe(s), subsequent encounter*/
,'S93116S'  /*Dislocation of interphalangeal joint of unspecified lesser toe(s), sequela*/
,'S93119D'  /*Dislocation of interphalangeal joint of unspecified toe(s), subsequent encounter*/
,'S93119S'  /*Dislocation of interphalangeal joint of unspecified toe(s), sequela*/
,'S93121D'  /*Dislocation of metatarsophalangeal joint of right great toe, subsequent encounter*/
,'S93121S'  /*Dislocation of metatarsophalangeal joint of right great toe, sequela*/
,'S93122D'  /*Dislocation of metatarsophalangeal joint of left great toe, subsequent encounter*/
,'S93122S'  /*Dislocation of metatarsophalangeal joint of left great toe, sequela*/
,'S93123D'  /*Dislocation of metatarsophalangeal joint of unspecified great toe, subsequent encounter*/
,'S93123S'  /*Dislocation of metatarsophalangeal joint of unspecified great toe, sequela*/
,'S93124D'  /*Dislocation of metatarsophalangeal joint of right lesser toe(s), subsequent encounter*/
,'S93124S'  /*Dislocation of metatarsophalangeal joint of right lesser toe(s), sequela*/
,'S93125D'  /*Dislocation of metatarsophalangeal joint of left lesser toe(s), subsequent encounter*/
,'S93125S'  /*Dislocation of metatarsophalangeal joint of left lesser toe(s), sequela*/
,'S93126D'  /*Dislocation of metatarsophalangeal joint of unspecified lesser toe(s), subsequent encounter*/
,'S93126S'  /*Dislocation of metatarsophalangeal joint of unspecified lesser toe(s), sequela*/
,'S93129D'  /*Dislocation of metatarsophalangeal joint of unspecified toe(s), subsequent encounter*/
,'S93129S'  /*Dislocation of metatarsophalangeal joint of unspecified toe(s), sequela*/
,'S93131D'  /*Subluxation of interphalangeal joint of right great toe, subsequent encounter*/
,'S93131S'  /*Subluxation of interphalangeal joint of right great toe, sequela*/
,'S93132D'  /*Subluxation of interphalangeal joint of left great toe, subsequent encounter*/
,'S93132S'  /*Subluxation of interphalangeal joint of left great toe, sequela*/
,'S93133D'  /*Subluxation of interphalangeal joint of unspecified great toe, subsequent encounter*/
,'S93133S'  /*Subluxation of interphalangeal joint of unspecified great toe, sequela*/
,'S93134D'  /*Subluxation of interphalangeal joint of right lesser toe(s), subsequent encounter*/
,'S93134S'  /*Subluxation of interphalangeal joint of right lesser toe(s), sequela*/
,'S93135D'  /*Subluxation of interphalangeal joint of left lesser toe(s), subsequent encounter*/
,'S93135S'  /*Subluxation of interphalangeal joint of left lesser toe(s), sequela*/
,'S93136D'  /*Subluxation of interphalangeal joint of unspecified lesser toe(s), subsequent encounter*/
,'S93136S'  /*Subluxation of interphalangeal joint of unspecified lesser toe(s), sequela*/
,'S93139D'  /*Subluxation of interphalangeal joint of unspecified toe(s), subsequent encounter*/
,'S93139S'  /*Subluxation of interphalangeal joint of unspecified toe(s), sequela*/
,'S93141D'  /*Subluxation of metatarsophalangeal joint of right great toe, subsequent encounter*/
,'S93141S'  /*Subluxation of metatarsophalangeal joint of right great toe, sequela*/
,'S93142D'  /*Subluxation of metatarsophalangeal joint of left great toe, subsequent encounter*/
,'S93142S'  /*Subluxation of metatarsophalangeal joint of left great toe, sequela*/
,'S93143D'  /*Subluxation of metatarsophalangeal joint of unspecified great toe, subsequent encounter*/
,'S93143S'  /*Subluxation of metatarsophalangeal joint of unspecified great toe, sequela*/
,'S93144D'  /*Subluxation of metatarsophalangeal joint of right lesser toe(s), subsequent encounter*/
,'S93144S'  /*Subluxation of metatarsophalangeal joint of right lesser toe(s), sequela*/
,'S93145D'  /*Subluxation of metatarsophalangeal joint of left lesser toe(s), subsequent encounter*/
,'S93145S'  /*Subluxation of metatarsophalangeal joint of left lesser toe(s), sequela*/
,'S93146D'  /*Subluxation of metatarsophalangeal joint of unspecified lesser toe(s), subsequent encounter*/
,'S93146S'  /*Subluxation of metatarsophalangeal joint of unspecified lesser toe(s), sequela*/
,'S93149D'  /*Subluxation of metatarsophalangeal joint of unspecified toe(s), subsequent encounter*/
,'S93149S'  /*Subluxation of metatarsophalangeal joint of unspecified toe(s), sequela*/
,'S93301D'  /*Unspecified subluxation of right foot, subsequent encounter*/
,'S93301S'  /*Unspecified subluxation of right foot, sequela*/
,'S93302D'  /*Unspecified subluxation of left foot, subsequent encounter*/
,'S93302S'  /*Unspecified subluxation of left foot, sequela*/
,'S93303D'  /*Unspecified subluxation of unspecified foot, subsequent encounter*/
,'S93303S'  /*Unspecified subluxation of unspecified foot, sequela*/
,'S93304D'  /*Unspecified dislocation of right foot, subsequent encounter*/
,'S93304S'  /*Unspecified dislocation of right foot, sequela*/
,'S93305D'  /*Unspecified dislocation of left foot, subsequent encounter*/
,'S93305S'  /*Unspecified dislocation of left foot, sequela*/
,'S93306D'  /*Unspecified dislocation of unspecified foot, subsequent encounter*/
,'S93306S'  /*Unspecified dislocation of unspecified foot, sequela*/
,'S93311D'  /*Subluxation of tarsal joint of right foot, subsequent encounter*/
,'S93311S'  /*Subluxation of tarsal joint of right foot, sequela*/
,'S93312D'  /*Subluxation of tarsal joint of left foot, subsequent encounter*/
,'S93312S'  /*Subluxation of tarsal joint of left foot, sequela*/
,'S93313D'  /*Subluxation of tarsal joint of unspecified foot, subsequent encounter*/
,'S93313S'  /*Subluxation of tarsal joint of unspecified foot, sequela*/
,'S93314D'  /*Dislocation of tarsal joint of right foot, subsequent encounter*/
,'S93314S'  /*Dislocation of tarsal joint of right foot, sequela*/
,'S93315D'  /*Dislocation of tarsal joint of left foot, subsequent encounter*/
,'S93315S'  /*Dislocation of tarsal joint of left foot, sequela*/
,'S93316D'  /*Dislocation of tarsal joint of unspecified foot, subsequent encounter*/
,'S93316S'  /*Dislocation of tarsal joint of unspecified foot, sequela*/
,'S93321D'  /*Subluxation of tarsometatarsal joint of right foot, subsequent encounter*/
,'S93321S'  /*Subluxation of tarsometatarsal joint of right foot, sequela*/
,'S93322D'  /*Subluxation of tarsometatarsal joint of left foot, subsequent encounter*/
,'S93322S'  /*Subluxation of tarsometatarsal joint of left foot, sequela*/
,'S93323D'  /*Subluxation of tarsometatarsal joint of unspecified foot, subsequent encounter*/
,'S93323S'  /*Subluxation of tarsometatarsal joint of unspecified foot, sequela*/
,'S93324D'  /*Dislocation of tarsometatarsal joint of right foot, subsequent encounter*/
,'S93324S'  /*Dislocation of tarsometatarsal joint of right foot, sequela*/
,'S93325D'  /*Dislocation of tarsometatarsal joint of left foot, subsequent encounter*/
,'S93325S'  /*Dislocation of tarsometatarsal joint of left foot, sequela*/
,'S93326D'  /*Dislocation of tarsometatarsal joint of unspecified foot, subsequent encounter*/
,'S93326S'  /*Dislocation of tarsometatarsal joint of unspecified foot, sequela*/
,'S93331D'  /*Other subluxation of right foot, subsequent encounter*/
,'S93331S'  /*Other subluxation of right foot, sequela*/
,'S93332D'  /*Other subluxation of left foot, subsequent encounter*/
,'S93332S'  /*Other subluxation of left foot, sequela*/
,'S93333D'  /*Other subluxation of unspecified foot, subsequent encounter*/
,'S93333S'  /*Other subluxation of unspecified foot, sequela*/
,'S93334D'  /*Other dislocation of right foot, subsequent encounter*/
,'S93334S'  /*Other dislocation of right foot, sequela*/
,'S93335D'  /*Other dislocation of left foot, subsequent encounter*/
,'S93335S'  /*Other dislocation of left foot, sequela*/
,'S93336D'  /*Other dislocation of unspecified foot, subsequent encounter*/
,'S93336S'  /*Other dislocation of unspecified foot, sequela*/
,'S93401D'  /*Sprain of unspecified ligament of right ankle, subsequent encounter*/
,'S93401S'  /*Sprain of unspecified ligament of right ankle, sequela*/
,'S93402D'  /*Sprain of unspecified ligament of left ankle, subsequent encounter*/
,'S93402S'  /*Sprain of unspecified ligament of left ankle, sequela*/
,'S93409D'  /*Sprain of unspecified ligament of unspecified ankle, subsequent encounter*/
,'S93409S'  /*Sprain of unspecified ligament of unspecified ankle, sequela*/
,'S93411D'  /*Sprain of calcaneofibular ligament of right ankle, subsequent encounter*/
,'S93411S'  /*Sprain of calcaneofibular ligament of right ankle, sequela*/
,'S93412D'  /*Sprain of calcaneofibular ligament of left ankle, subsequent encounter*/
,'S93412S'  /*Sprain of calcaneofibular ligament of left ankle, sequela*/
,'S93419D'  /*Sprain of calcaneofibular ligament of unspecified ankle, subsequent encounter*/
,'S93419S'  /*Sprain of calcaneofibular ligament of unspecified ankle, sequela*/
,'S93421D'  /*Sprain of deltoid ligament of right ankle, subsequent encounter*/
,'S93421S'  /*Sprain of deltoid ligament of right ankle, sequela*/
,'S93422D'  /*Sprain of deltoid ligament of left ankle, subsequent encounter*/
,'S93422S'  /*Sprain of deltoid ligament of left ankle, sequela*/
,'S93429D'  /*Sprain of deltoid ligament of unspecified ankle, subsequent encounter*/
,'S93429S'  /*Sprain of deltoid ligament of unspecified ankle, sequela*/
,'S93431D'  /*Sprain of tibiofibular ligament of right ankle, subsequent encounter*/
,'S93431S'  /*Sprain of tibiofibular ligament of right ankle, sequela*/
,'S93432D'  /*Sprain of tibiofibular ligament of left ankle, subsequent encounter*/
,'S93432S'  /*Sprain of tibiofibular ligament of left ankle, sequela*/
,'S93439D'  /*Sprain of tibiofibular ligament of unspecified ankle, subsequent encounter*/
,'S93439S'  /*Sprain of tibiofibular ligament of unspecified ankle, sequela*/
,'S93491D'  /*Sprain of other ligament of right ankle, subsequent encounter*/
,'S93491S'  /*Sprain of other ligament of right ankle, sequela*/
,'S93492D'  /*Sprain of other ligament of left ankle, subsequent encounter*/
,'S93492S'  /*Sprain of other ligament of left ankle, sequela*/
,'S93499D'  /*Sprain of other ligament of unspecified ankle, subsequent encounter*/
,'S93499S'  /*Sprain of other ligament of unspecified ankle, sequela*/
,'S93501D'  /*Unspecified sprain of right great toe, subsequent encounter*/
,'S93501S'  /*Unspecified sprain of right great toe, sequela*/
,'S93502D'  /*Unspecified sprain of left great toe, subsequent encounter*/
,'S93502S'  /*Unspecified sprain of left great toe, sequela*/
,'S93503D'  /*Unspecified sprain of unspecified great toe, subsequent encounter*/
,'S93503S'  /*Unspecified sprain of unspecified great toe, sequela*/
,'S93504D'  /*Unspecified sprain of right lesser toe(s), subsequent encounter*/
,'S93504S'  /*Unspecified sprain of right lesser toe(s), sequela*/
,'S93505D'  /*Unspecified sprain of left lesser toe(s), subsequent encounter*/
,'S93505S'  /*Unspecified sprain of left lesser toe(s), sequela*/
,'S93506D'  /*Unspecified sprain of unspecified lesser toe(s), subsequent encounter*/
,'S93506S'  /*Unspecified sprain of unspecified lesser toe(s), sequela*/
,'S93509D'  /*Unspecified sprain of unspecified toe(s), subsequent encounter*/
,'S93509S'  /*Unspecified sprain of unspecified toe(s), sequela*/
,'S93511D'  /*Sprain of interphalangeal joint of right great toe, subsequent encounter*/
,'S93511S'  /*Sprain of interphalangeal joint of right great toe, sequela*/
,'S93512D'  /*Sprain of interphalangeal joint of left great toe, subsequent encounter*/
,'S93512S'  /*Sprain of interphalangeal joint of left great toe, sequela*/
,'S93513D'  /*Sprain of interphalangeal joint of unspecified great toe, subsequent encounter*/
,'S93513S'  /*Sprain of interphalangeal joint of unspecified great toe, sequela*/
,'S93514D'  /*Sprain of interphalangeal joint of right lesser toe(s), subsequent encounter*/
,'S93514S'  /*Sprain of interphalangeal joint of right lesser toe(s), sequela*/
,'S93515D'  /*Sprain of interphalangeal joint of left lesser toe(s), subsequent encounter*/
,'S93515S'  /*Sprain of interphalangeal joint of left lesser toe(s), sequela*/
,'S93516D'  /*Sprain of interphalangeal joint of unspecified lesser toe(s), subsequent encounter*/
,'S93516S'  /*Sprain of interphalangeal joint of unspecified lesser toe(s), sequela*/
,'S93519D'  /*Sprain of interphalangeal joint of unspecified toe(s), subsequent encounter*/
,'S93519S'  /*Sprain of interphalangeal joint of unspecified toe(s), sequela*/
,'S93521D'  /*Sprain of metatarsophalangeal joint of right great toe, subsequent encounter*/
,'S93521S'  /*Sprain of metatarsophalangeal joint of right great toe, sequela*/
,'S93522D'  /*Sprain of metatarsophalangeal joint of left great toe, subsequent encounter*/
,'S93522S'  /*Sprain of metatarsophalangeal joint of left great toe, sequela*/
,'S93523D'  /*Sprain of metatarsophalangeal joint of unspecified great toe, subsequent encounter*/
,'S93523S'  /*Sprain of metatarsophalangeal joint of unspecified great toe, sequela*/
,'S93524D'  /*Sprain of metatarsophalangeal joint of right lesser toe(s), subsequent encounter*/
,'S93524S'  /*Sprain of metatarsophalangeal joint of right lesser toe(s), sequela*/
,'S93525D'  /*Sprain of metatarsophalangeal joint of left lesser toe(s), subsequent encounter*/
,'S93525S'  /*Sprain of metatarsophalangeal joint of left lesser toe(s), sequela*/
,'S93526D'  /*Sprain of metatarsophalangeal joint of unspecified lesser toe(s), subsequent encounter*/
,'S93526S'  /*Sprain of metatarsophalangeal joint of unspecified lesser toe(s), sequela*/
,'S93529D'  /*Sprain of metatarsophalangeal joint of unspecified toe(s), subsequent encounter*/
,'S93529S'  /*Sprain of metatarsophalangeal joint of unspecified toe(s), sequela*/
,'S93601D'  /*Unspecified sprain of right foot, subsequent encounter*/
,'S93601S'  /*Unspecified sprain of right foot, sequela*/
,'S93602D'  /*Unspecified sprain of left foot, subsequent encounter*/
,'S93602S'  /*Unspecified sprain of left foot, sequela*/
,'S93609D'  /*Unspecified sprain of unspecified foot, subsequent encounter*/
,'S93609S'  /*Unspecified sprain of unspecified foot, sequela*/
,'S93611D'  /*Sprain of tarsal ligament of right foot, subsequent encounter*/
,'S93611S'  /*Sprain of tarsal ligament of right foot, sequela*/
,'S93612D'  /*Sprain of tarsal ligament of left foot, subsequent encounter*/
,'S93612S'  /*Sprain of tarsal ligament of left foot, sequela*/
,'S93619D'  /*Sprain of tarsal ligament of unspecified foot, subsequent encounter*/
,'S93619S'  /*Sprain of tarsal ligament of unspecified foot, sequela*/
,'S93621D'  /*Sprain of tarsometatarsal ligament of right foot, subsequent encounter*/
,'S93621S'  /*Sprain of tarsometatarsal ligament of right foot, sequela*/
,'S93622D'  /*Sprain of tarsometatarsal ligament of left foot, subsequent encounter*/
,'S93622S'  /*Sprain of tarsometatarsal ligament of left foot, sequela*/
,'S93629D'  /*Sprain of tarsometatarsal ligament of unspecified foot, subsequent encounter*/
,'S93629S'  /*Sprain of tarsometatarsal ligament of unspecified foot, sequela*/
,'S93691D'  /*Other sprain of right foot, subsequent encounter*/
,'S93691S'  /*Other sprain of right foot, sequela*/
,'S93692D'  /*Other sprain of left foot, subsequent encounter*/
,'S93692S'  /*Other sprain of left foot, sequela*/
,'S93699D'  /*Other sprain of unspecified foot, subsequent encounter*/
,'S93699S'  /*Other sprain of unspecified foot, sequela*/
,'S9400XD'  /*Injury of lateral plantar nerve, unspecified leg, subsequent encounter*/
,'S9400XS'  /*Injury of lateral plantar nerve, unspecified leg, sequela*/
,'S9401XD'  /*Injury of lateral plantar nerve, right leg, subsequent encounter*/
,'S9401XS'  /*Injury of lateral plantar nerve, right leg, sequela*/
,'S9402XD'  /*Injury of lateral plantar nerve, left leg, subsequent encounter*/
,'S9402XS'  /*Injury of lateral plantar nerve, left leg, sequela*/
,'S9410XD'  /*Injury of medial plantar nerve, unspecified leg, subsequent encounter*/
,'S9410XS'  /*Injury of medial plantar nerve, unspecified leg, sequela*/
,'S9411XD'  /*Injury of medial plantar nerve, right leg, subsequent encounter*/
,'S9411XS'  /*Injury of medial plantar nerve, right leg, sequela*/
,'S9412XD'  /*Injury of medial plantar nerve, left leg, subsequent encounter*/
,'S9412XS'  /*Injury of medial plantar nerve, left leg, sequela*/
,'S9420XD'  /*Injury of deep peroneal nerve at ankle and foot level, unspecified leg, subsequent encounter*/
,'S9420XS'  /*Injury of deep peroneal nerve at ankle and foot level, unspecified leg, sequela*/
,'S9421XD'  /*Injury of deep peroneal nerve at ankle and foot level, right leg, subsequent encounter*/
,'S9421XS'  /*Injury of deep peroneal nerve at ankle and foot level, right leg, sequela*/
,'S9422XD'  /*Injury of deep peroneal nerve at ankle and foot level, left leg, subsequent encounter*/
,'S9422XS'  /*Injury of deep peroneal nerve at ankle and foot level, left leg, sequela*/
,'S9430XD'  /*Injury of cutaneous sensory nerve at ankle and foot level, unspecified leg, subsequent encounter*/
,'S9430XS'  /*Injury of cutaneous sensory nerve at ankle and foot level, unspecified leg, sequela*/
,'S9431XD'  /*Injury of cutaneous sensory nerve at ankle and foot level, right leg, subsequent encounter*/
,'S9431XS'  /*Injury of cutaneous sensory nerve at ankle and foot level, right leg, sequela*/
,'S9432XD'  /*Injury of cutaneous sensory nerve at ankle and foot level, left leg, subsequent encounter*/
,'S9432XS'  /*Injury of cutaneous sensory nerve at ankle and foot level, left leg, sequela*/
,'S948X1D'  /*Injury of other nerves at ankle and foot level, right leg, subsequent encounter*/
,'S948X1S'  /*Injury of other nerves at ankle and foot level, right leg, sequela*/
,'S948X2D'  /*Injury of other nerves at ankle and foot level, left leg, subsequent encounter*/
,'S948X2S'  /*Injury of other nerves at ankle and foot level, left leg, sequela*/
,'S948X9D'  /*Injury of other nerves at ankle and foot level, unspecified leg, subsequent encounter*/
,'S948X9S'  /*Injury of other nerves at ankle and foot level, unspecified leg, sequela*/
,'S9490XD'  /*Injury of unspecified nerve at ankle and foot level, unspecified leg, subsequent encounter*/
,'S9490XS'  /*Injury of unspecified nerve at ankle and foot level, unspecified leg, sequela*/
,'S9491XD'  /*Injury of unspecified nerve at ankle and foot level, right leg, subsequent encounter*/
,'S9491XS'  /*Injury of unspecified nerve at ankle and foot level, right leg, sequela*/
,'S9492XD'  /*Injury of unspecified nerve at ankle and foot level, left leg, subsequent encounter*/
,'S9492XS'  /*Injury of unspecified nerve at ankle and foot level, left leg, sequela*/
,'S95001D'  /*Unspecified injury of dorsal artery of right foot, subsequent encounter*/
,'S95001S'  /*Unspecified injury of dorsal artery of right foot, sequela*/
,'S95002D'  /*Unspecified injury of dorsal artery of left foot, subsequent encounter*/
,'S95002S'  /*Unspecified injury of dorsal artery of left foot, sequela*/
,'S95009D'  /*Unspecified injury of dorsal artery of unspecified foot, subsequent encounter*/
,'S95009S'  /*Unspecified injury of dorsal artery of unspecified foot, sequela*/
,'S95011D'  /*Laceration of dorsal artery of right foot, subsequent encounter*/
,'S95011S'  /*Laceration of dorsal artery of right foot, sequela*/
,'S95012D'  /*Laceration of dorsal artery of left foot, subsequent encounter*/
,'S95012S'  /*Laceration of dorsal artery of left foot, sequela*/
,'S95019D'  /*Laceration of dorsal artery of unspecified foot, subsequent encounter*/
,'S95019S'  /*Laceration of dorsal artery of unspecified foot, sequela*/
,'S95091D'  /*Other specified injury of dorsal artery of right foot, subsequent encounter*/
,'S95091S'  /*Other specified injury of dorsal artery of right foot, sequela*/
,'S95092D'  /*Other specified injury of dorsal artery of left foot, subsequent encounter*/
,'S95092S'  /*Other specified injury of dorsal artery of left foot, sequela*/
,'S95099D'  /*Other specified injury of dorsal artery of unspecified foot, subsequent encounter*/
,'S95099S'  /*Other specified injury of dorsal artery of unspecified foot, sequela*/
,'S95101D'  /*Unspecified injury of plantar artery of right foot, subsequent encounter*/
,'S95101S'  /*Unspecified injury of plantar artery of right foot, sequela*/
,'S95102D'  /*Unspecified injury of plantar artery of left foot, subsequent encounter*/
,'S95102S'  /*Unspecified injury of plantar artery of left foot, sequela*/
,'S95109D'  /*Unspecified injury of plantar artery of unspecified foot, subsequent encounter*/
,'S95109S'  /*Unspecified injury of plantar artery of unspecified foot, sequela*/
,'S95111D'  /*Laceration of plantar artery of right foot, subsequent encounter*/
,'S95111S'  /*Laceration of plantar artery of right foot, sequela*/
,'S95112D'  /*Laceration of plantar artery of left foot, subsequent encounter*/
,'S95112S'  /*Laceration of plantar artery of left foot, sequela*/
,'S95119D'  /*Laceration of plantar artery of unspecified foot, subsequent encounter*/
,'S95119S'  /*Laceration of plantar artery of unspecified foot, sequela*/
,'S95191D'  /*Other specified injury of plantar artery of right foot, subsequent encounter*/
,'S95191S'  /*Other specified injury of plantar artery of right foot, sequela*/
,'S95192D'  /*Other specified injury of plantar artery of left foot, subsequent encounter*/
,'S95192S'  /*Other specified injury of plantar artery of left foot, sequela*/
,'S95199D'  /*Other specified injury of plantar artery of unspecified foot, subsequent encounter*/
,'S95199S'  /*Other specified injury of plantar artery of unspecified foot, sequela*/
,'S95201D'  /*Unspecified injury of dorsal vein of right foot, subsequent encounter*/
,'S95201S'  /*Unspecified injury of dorsal vein of right foot, sequela*/
,'S95202D'  /*Unspecified injury of dorsal vein of left foot, subsequent encounter*/
,'S95202S'  /*Unspecified injury of dorsal vein of left foot, sequela*/
,'S95209D'  /*Unspecified injury of dorsal vein of unspecified foot, subsequent encounter*/
,'S95209S'  /*Unspecified injury of dorsal vein of unspecified foot, sequela*/
,'S95211D'  /*Laceration of dorsal vein of right foot, subsequent encounter*/
,'S95211S'  /*Laceration of dorsal vein of right foot, sequela*/
,'S95212D'  /*Laceration of dorsal vein of left foot, subsequent encounter*/
,'S95212S'  /*Laceration of dorsal vein of left foot, sequela*/
,'S95219D'  /*Laceration of dorsal vein of unspecified foot, subsequent encounter*/
,'S95219S'  /*Laceration of dorsal vein of unspecified foot, sequela*/
,'S95291D'  /*Other specified injury of dorsal vein of right foot, subsequent encounter*/
,'S95291S'  /*Other specified injury of dorsal vein of right foot, sequela*/
,'S95292D'  /*Other specified injury of dorsal vein of left foot, subsequent encounter*/
,'S95292S'  /*Other specified injury of dorsal vein of left foot, sequela*/
,'S95299D'  /*Other specified injury of dorsal vein of unspecified foot, subsequent encounter*/
,'S95299S'  /*Other specified injury of dorsal vein of unspecified foot, sequela*/
,'S95801D'  /*Unspecified injury of other blood vessels at ankle and foot level, right leg, subsequent encounter*/
,'S95801S'  /*Unspecified injury of other blood vessels at ankle and foot level, right leg, sequela*/
,'S95802D'  /*Unspecified injury of other blood vessels at ankle and foot level, left leg, subsequent encounter*/
,'S95802S'  /*Unspecified injury of other blood vessels at ankle and foot level, left leg, sequela*/
,'S95809D'  /*Unspecified injury of other blood vessels at ankle and foot level, unspecified leg, subsequent encounter*/
,'S95809S'  /*Unspecified injury of other blood vessels at ankle and foot level, unspecified leg, sequela*/
,'S95811D'  /*Laceration of other blood vessels at ankle and foot level, right leg, subsequent encounter*/
,'S95811S'  /*Laceration of other blood vessels at ankle and foot level, right leg, sequela*/
,'S95812D'  /*Laceration of other blood vessels at ankle and foot level, left leg, subsequent encounter*/
,'S95812S'  /*Laceration of other blood vessels at ankle and foot level, left leg, sequela*/
,'S95819D'  /*Laceration of other blood vessels at ankle and foot level, unspecified leg, subsequent encounter*/
,'S95819S'  /*Laceration of other blood vessels at ankle and foot level, unspecified leg, sequela*/
,'S95891D'  /*Other specified injury of other blood vessels at ankle and foot level, right leg, subsequent encounter*/
,'S95891S'  /*Other specified injury of other blood vessels at ankle and foot level, right leg, sequela*/
,'S95892D'  /*Other specified injury of other blood vessels at ankle and foot level, left leg, subsequent encounter*/
,'S95892S'  /*Other specified injury of other blood vessels at ankle and foot level, left leg, sequela*/
,'S95899D'  /*Other specified injury of other blood vessels at ankle and foot level, unspecified leg, subsequent encounter*/
,'S95899S'  /*Other specified injury of other blood vessels at ankle and foot level, unspecified leg, sequela*/
,'S95901D'  /*Unspecified injury of unspecified blood vessel at ankle and foot level, right leg, subsequent encounter*/
,'S95901S'  /*Unspecified injury of unspecified blood vessel at ankle and foot level, right leg, sequela*/
,'S95902D'  /*Unspecified injury of unspecified blood vessel at ankle and foot level, left leg, subsequent encounter*/
,'S95902S'  /*Unspecified injury of unspecified blood vessel at ankle and foot level, left leg, sequela*/
,'S95909D'  /*Unspecified injury of unspecified blood vessel at ankle and foot level, unspecified leg, subsequent encounter*/
,'S95909S'  /*Unspecified injury of unspecified blood vessel at ankle and foot level, unspecified leg, sequela*/
,'S95911D'  /*Laceration of unspecified blood vessel at ankle and foot level, right leg, subsequent encounter*/
,'S95911S'  /*Laceration of unspecified blood vessel at ankle and foot level, right leg, sequela*/
,'S95912D'  /*Laceration of unspecified blood vessel at ankle and foot level, left leg, subsequent encounter*/
,'S95912S'  /*Laceration of unspecified blood vessel at ankle and foot level, left leg, sequela*/
,'S95919D'  /*Laceration of unspecified blood vessel at ankle and foot level, unspecified leg, subsequent encounter*/
,'S95919S'  /*Laceration of unspecified blood vessel at ankle and foot level, unspecified leg, sequela*/
,'S95991D'  /*Other specified injury of unspecified blood vessel at ankle and foot level, right leg, subsequent encounter*/
,'S95991S'  /*Other specified injury of unspecified blood vessel at ankle and foot level, right leg, sequela*/
,'S95992D'  /*Other specified injury of unspecified blood vessel at ankle and foot level, left leg, subsequent encounter*/
,'S95992S'  /*Other specified injury of unspecified blood vessel at ankle and foot level, left leg, sequela*/
,'S95999D'  /*Other specified injury of unspecified blood vessel at ankle and foot level, unspecified leg, subsequent encounter*/
,'S95999S'  /*Other specified injury of unspecified blood vessel at ankle and foot level, unspecified leg, sequela*/
,'S96001D'  /*Unspecified injury of muscle and tendon of long flexor muscle of toe at ankle and foot level, right foot, subsequent encounter*/
,'S96001S'  /*Unspecified injury of muscle and tendon of long flexor muscle of toe at ankle and foot level, right foot, sequela*/
,'S96002D'  /*Unspecified injury of muscle and tendon of long flexor muscle of toe at ankle and foot level, left foot, subsequent encounter*/
,'S96002S'  /*Unspecified injury of muscle and tendon of long flexor muscle of toe at ankle and foot level, left foot, sequela*/
,'S96009D'  /*Unspecified injury of muscle and tendon of long flexor muscle of toe at ankle and foot level, unspecified foot, subsequent encounter*/
,'S96009S'  /*Unspecified injury of muscle and tendon of long flexor muscle of toe at ankle and foot level, unspecified foot, sequela*/
,'S96011D'  /*Strain of muscle and tendon of long flexor muscle of toe at ankle and foot level, right foot, subsequent encounter*/
,'S96011S'  /*Strain of muscle and tendon of long flexor muscle of toe at ankle and foot level, right foot, sequela*/
,'S96012D'  /*Strain of muscle and tendon of long flexor muscle of toe at ankle and foot level, left foot, subsequent encounter*/
,'S96012S'  /*Strain of muscle and tendon of long flexor muscle of toe at ankle and foot level, left foot, sequela*/
,'S96019D'  /*Strain of muscle and tendon of long flexor muscle of toe at ankle and foot level, unspecified foot, subsequent encounter*/
,'S96019S'  /*Strain of muscle and tendon of long flexor muscle of toe at ankle and foot level, unspecified foot, sequela*/
,'S96021D'  /*Laceration of muscle and tendon of long flexor muscle of toe at ankle and foot level, right foot, subsequent encounter*/
,'S96021S'  /*Laceration of muscle and tendon of long flexor muscle of toe at ankle and foot level, right foot, sequela*/
,'S96022D'  /*Laceration of muscle and tendon of long flexor muscle of toe at ankle and foot level, left foot, subsequent encounter*/
,'S96022S'  /*Laceration of muscle and tendon of long flexor muscle of toe at ankle and foot level, left foot, sequela*/
,'S96029D'  /*Laceration of muscle and tendon of long flexor muscle of toe at ankle and foot level, unspecified foot, subsequent encounter*/
,'S96029S'  /*Laceration of muscle and tendon of long flexor muscle of toe at ankle and foot level, unspecified foot, sequela*/
,'S96091D'  /*Other injury of muscle and tendon of long flexor muscle of toe at ankle and foot level, right foot, subsequent encounter*/
,'S96091S'  /*Other injury of muscle and tendon of long flexor muscle of toe at ankle and foot level, right foot, sequela*/
,'S96092D'  /*Other injury of muscle and tendon of long flexor muscle of toe at ankle and foot level, left foot, subsequent encounter*/
,'S96092S'  /*Other injury of muscle and tendon of long flexor muscle of toe at ankle and foot level, left foot, sequela*/
,'S96099D'  /*Other injury of muscle and tendon of long flexor muscle of toe at ankle and foot level, unspecified foot, subsequent encounter*/
,'S96099S'  /*Other injury of muscle and tendon of long flexor muscle of toe at ankle and foot level, unspecified foot, sequela*/
,'S96101D'  /*Unspecified injury of muscle and tendon of long extensor muscle of toe at ankle and foot level, right foot, subsequent encounter*/
,'S96101S'  /*Unspecified injury of muscle and tendon of long extensor muscle of toe at ankle and foot level, right foot, sequela*/
,'S96102D'  /*Unspecified injury of muscle and tendon of long extensor muscle of toe at ankle and foot level, left foot, subsequent encounter*/
,'S96102S'  /*Unspecified injury of muscle and tendon of long extensor muscle of toe at ankle and foot level, left foot, sequela*/
,'S96109D'  /*Unspecified injury of muscle and tendon of long extensor muscle of toe at ankle and foot level, unspecified foot, subsequent encounter*/
,'S96109S'  /*Unspecified injury of muscle and tendon of long extensor muscle of toe at ankle and foot level, unspecified foot, sequela*/
,'S96111D'  /*Strain of muscle and tendon of long extensor muscle of toe at ankle and foot level, right foot, subsequent encounter*/
,'S96111S'  /*Strain of muscle and tendon of long extensor muscle of toe at ankle and foot level, right foot, sequela*/
,'S96112D'  /*Strain of muscle and tendon of long extensor muscle of toe at ankle and foot level, left foot, subsequent encounter*/
,'S96112S'  /*Strain of muscle and tendon of long extensor muscle of toe at ankle and foot level, left foot, sequela*/
,'S96119D'  /*Strain of muscle and tendon of long extensor muscle of toe at ankle and foot level, unspecified foot, subsequent encounter*/
,'S96119S'  /*Strain of muscle and tendon of long extensor muscle of toe at ankle and foot level, unspecified foot, sequela*/
,'S96121D'  /*Laceration of muscle and tendon of long extensor muscle of toe at ankle and foot level, right foot, subsequent encounter*/
,'S96121S'  /*Laceration of muscle and tendon of long extensor muscle of toe at ankle and foot level, right foot, sequela*/
,'S96122D'  /*Laceration of muscle and tendon of long extensor muscle of toe at ankle and foot level, left foot, subsequent encounter*/
,'S96122S'  /*Laceration of muscle and tendon of long extensor muscle of toe at ankle and foot level, left foot, sequela*/
,'S96129D'  /*Laceration of muscle and tendon of long extensor muscle of toe at ankle and foot level, unspecified foot, subsequent encounter*/
,'S96129S'  /*Laceration of muscle and tendon of long extensor muscle of toe at ankle and foot level, unspecified foot, sequela*/
,'S96191D'  /*Other specified injury of muscle and tendon of long extensor muscle of toe at ankle and foot level, right foot, subsequent encounter*/
,'S96191S'  /*Other specified injury of muscle and tendon of long extensor muscle of toe at ankle and foot level, right foot, sequela*/
,'S96192D'  /*Other specified injury of muscle and tendon of long extensor muscle of toe at ankle and foot level, left foot, subsequent encounter*/
,'S96192S'  /*Other specified injury of muscle and tendon of long extensor muscle of toe at ankle and foot level, left foot, sequela*/
,'S96199D'  /*Other specified injury of muscle and tendon of long extensor muscle of toe at ankle and foot level, unspecified foot, subsequent encounter*/
,'S96199S'  /*Other specified injury of muscle and tendon of long extensor muscle of toe at ankle and foot level, unspecified foot, sequela*/
,'S96201D'  /*Unspecified injury of intrinsic muscle and tendon at ankle and foot level, right foot, subsequent encounter*/
,'S96201S'  /*Unspecified injury of intrinsic muscle and tendon at ankle and foot level, right foot, sequela*/
,'S96202D'  /*Unspecified injury of intrinsic muscle and tendon at ankle and foot level, left foot, subsequent encounter*/
,'S96202S'  /*Unspecified injury of intrinsic muscle and tendon at ankle and foot level, left foot, sequela*/
,'S96209D'  /*Unspecified injury of intrinsic muscle and tendon at ankle and foot level, unspecified foot, subsequent encounter*/
,'S96209S'  /*Unspecified injury of intrinsic muscle and tendon at ankle and foot level, unspecified foot, sequela*/
,'S96211D'  /*Strain of intrinsic muscle and tendon at ankle and foot level, right foot, subsequent encounter*/
,'S96211S'  /*Strain of intrinsic muscle and tendon at ankle and foot level, right foot, sequela*/
,'S96212D'  /*Strain of intrinsic muscle and tendon at ankle and foot level, left foot, subsequent encounter*/
,'S96212S'  /*Strain of intrinsic muscle and tendon at ankle and foot level, left foot, sequela*/
,'S96219D'  /*Strain of intrinsic muscle and tendon at ankle and foot level, unspecified foot, subsequent encounter*/
,'S96219S'  /*Strain of intrinsic muscle and tendon at ankle and foot level, unspecified foot, sequela*/
,'S96221D'  /*Laceration of intrinsic muscle and tendon at ankle and foot level, right foot, subsequent encounter*/
,'S96221S'  /*Laceration of intrinsic muscle and tendon at ankle and foot level, right foot, sequela*/
,'S96222D'  /*Laceration of intrinsic muscle and tendon at ankle and foot level, left foot, subsequent encounter*/
,'S96222S'  /*Laceration of intrinsic muscle and tendon at ankle and foot level, left foot, sequela*/
,'S96229D'  /*Laceration of intrinsic muscle and tendon at ankle and foot level, unspecified foot, subsequent encounter*/
,'S96229S'  /*Laceration of intrinsic muscle and tendon at ankle and foot level, unspecified foot, sequela*/
,'S96291D'  /*Other specified injury of intrinsic muscle and tendon at ankle and foot level, right foot, subsequent encounter*/
,'S96291S'  /*Other specified injury of intrinsic muscle and tendon at ankle and foot level, right foot, sequela*/
,'S96292D'  /*Other specified injury of intrinsic muscle and tendon at ankle and foot level, left foot, subsequent encounter*/
,'S96292S'  /*Other specified injury of intrinsic muscle and tendon at ankle and foot level, left foot, sequela*/
,'S96299D'  /*Other specified injury of intrinsic muscle and tendon at ankle and foot level, unspecified foot, subsequent encounter*/
,'S96299S'  /*Other specified injury of intrinsic muscle and tendon at ankle and foot level, unspecified foot, sequela*/
,'S96801D'  /*Unspecified injury of other specified muscles and tendons at ankle and foot level, right foot, subsequent encounter*/
,'S96801S'  /*Unspecified injury of other specified muscles and tendons at ankle and foot level, right foot, sequela*/
,'S96802D'  /*Unspecified injury of other specified muscles and tendons at ankle and foot level, left foot, subsequent encounter*/
,'S96802S'  /*Unspecified injury of other specified muscles and tendons at ankle and foot level, left foot, sequela*/
,'S96809D'  /*Unspecified injury of other specified muscles and tendons at ankle and foot level, unspecified foot, subsequent encounter*/
,'S96809S'  /*Unspecified injury of other specified muscles and tendons at ankle and foot level, unspecified foot, sequela*/
,'S96811D'  /*Strain of other specified muscles and tendons at ankle and foot level, right foot, subsequent encounter*/
,'S96811S'  /*Strain of other specified muscles and tendons at ankle and foot level, right foot, sequela*/
,'S96812D'  /*Strain of other specified muscles and tendons at ankle and foot level, left foot, subsequent encounter*/
,'S96812S'  /*Strain of other specified muscles and tendons at ankle and foot level, left foot, sequela*/
,'S96819D'  /*Strain of other specified muscles and tendons at ankle and foot level, unspecified foot, subsequent encounter*/
,'S96819S'  /*Strain of other specified muscles and tendons at ankle and foot level, unspecified foot, sequela*/
,'S96821D'  /*Laceration of other specified muscles and tendons at ankle and foot level, right foot, subsequent encounter*/
,'S96821S'  /*Laceration of other specified muscles and tendons at ankle and foot level, right foot, sequela*/
,'S96822D'  /*Laceration of other specified muscles and tendons at ankle and foot level, left foot, subsequent encounter*/
,'S96822S'  /*Laceration of other specified muscles and tendons at ankle and foot level, left foot, sequela*/
,'S96829D'  /*Laceration of other specified muscles and tendons at ankle and foot level, unspecified foot, subsequent encounter*/
,'S96829S'  /*Laceration of other specified muscles and tendons at ankle and foot level, unspecified foot, sequela*/
,'S96891D'  /*Other specified injury of other specified muscles and tendons at ankle and foot level, right foot, subsequent encounter*/
,'S96891S'  /*Other specified injury of other specified muscles and tendons at ankle and foot level, right foot, sequela*/
,'S96892D'  /*Other specified injury of other specified muscles and tendons at ankle and foot level, left foot, subsequent encounter*/
,'S96892S'  /*Other specified injury of other specified muscles and tendons at ankle and foot level, left foot, sequela*/
,'S96899D'  /*Other specified injury of other specified muscles and tendons at ankle and foot level, unspecified foot, subsequent encounter*/
,'S96899S'  /*Other specified injury of other specified muscles and tendons at ankle and foot level, unspecified foot, sequela*/
,'S96901D'  /*Unspecified injury of unspecified muscle and tendon at ankle and foot level, right foot, subsequent encounter*/
,'S96901S'  /*Unspecified injury of unspecified muscle and tendon at ankle and foot level, right foot, sequela*/
,'S96902D'  /*Unspecified injury of unspecified muscle and tendon at ankle and foot level, left foot, subsequent encounter*/
,'S96902S'  /*Unspecified injury of unspecified muscle and tendon at ankle and foot level, left foot, sequela*/
,'S96909D'  /*Unspecified injury of unspecified muscle and tendon at ankle and foot level, unspecified foot, subsequent encounter*/
,'S96909S'  /*Unspecified injury of unspecified muscle and tendon at ankle and foot level, unspecified foot, sequela*/
,'S96911D'  /*Strain of unspecified muscle and tendon at ankle and foot level, right foot, subsequent encounter*/
,'S96911S'  /*Strain of unspecified muscle and tendon at ankle and foot level, right foot, sequela*/
,'S96912D'  /*Strain of unspecified muscle and tendon at ankle and foot level, left foot, subsequent encounter*/
,'S96912S'  /*Strain of unspecified muscle and tendon at ankle and foot level, left foot, sequela*/
,'S96919D'  /*Strain of unspecified muscle and tendon at ankle and foot level, unspecified foot, subsequent encounter*/
,'S96919S'  /*Strain of unspecified muscle and tendon at ankle and foot level, unspecified foot, sequela*/
,'S96921D'  /*Laceration of unspecified muscle and tendon at ankle and foot level, right foot, subsequent encounter*/
,'S96921S'  /*Laceration of unspecified muscle and tendon at ankle and foot level, right foot, sequela*/
,'S96922D'  /*Laceration of unspecified muscle and tendon at ankle and foot level, left foot, subsequent encounter*/
,'S96922S'  /*Laceration of unspecified muscle and tendon at ankle and foot level, left foot, sequela*/
,'S96929D'  /*Laceration of unspecified muscle and tendon at ankle and foot level, unspecified foot, subsequent encounter*/
,'S96929S'  /*Laceration of unspecified muscle and tendon at ankle and foot level, unspecified foot, sequela*/
,'S96991D'  /*Other specified injury of unspecified muscle and tendon at ankle and foot level, right foot, subsequent encounter*/
,'S96991S'  /*Other specified injury of unspecified muscle and tendon at ankle and foot level, right foot, sequela*/
,'S96992D'  /*Other specified injury of unspecified muscle and tendon at ankle and foot level, left foot, subsequent encounter*/
,'S96992S'  /*Other specified injury of unspecified muscle and tendon at ankle and foot level, left foot, sequela*/
,'S96999D'  /*Other specified injury of unspecified muscle and tendon at ankle and foot level, unspecified foot, subsequent encounter*/
,'S96999S'  /*Other specified injury of unspecified muscle and tendon at ankle and foot level, unspecified foot, sequela*/
,'S9700XD'  /*Crushing injury of unspecified ankle, subsequent encounter*/
,'S9700XS'  /*Crushing injury of unspecified ankle, sequela*/
,'S9701XD'  /*Crushing injury of right ankle, subsequent encounter*/
,'S9701XS'  /*Crushing injury of right ankle, sequela*/
,'S9702XD'  /*Crushing injury of left ankle, subsequent encounter*/
,'S9702XS'  /*Crushing injury of left ankle, sequela*/
,'S97101D'  /*Crushing injury of unspecified right toe(s), subsequent encounter*/
,'S97101S'  /*Crushing injury of unspecified right toe(s), sequela*/
,'S97102D'  /*Crushing injury of unspecified left toe(s), subsequent encounter*/
,'S97102S'  /*Crushing injury of unspecified left toe(s), sequela*/
,'S97109D'  /*Crushing injury of unspecified toe(s), subsequent encounter*/
,'S97109S'  /*Crushing injury of unspecified toe(s), sequela*/
,'S97111D'  /*Crushing injury of right great toe, subsequent encounter*/
,'S97111S'  /*Crushing injury of right great toe, sequela*/
,'S97112D'  /*Crushing injury of left great toe, subsequent encounter*/
,'S97112S'  /*Crushing injury of left great toe, sequela*/
,'S97119D'  /*Crushing injury of unspecified great toe, subsequent encounter*/
,'S97119S'  /*Crushing injury of unspecified great toe, sequela*/
,'S97121D'  /*Crushing injury of right lesser toe(s), subsequent encounter*/
,'S97121S'  /*Crushing injury of right lesser toe(s), sequela*/
,'S97122D'  /*Crushing injury of left lesser toe(s), subsequent encounter*/
,'S97122S'  /*Crushing injury of left lesser toe(s), sequela*/
,'S97129D'  /*Crushing injury of unspecified lesser toe(s), subsequent encounter*/
,'S97129S'  /*Crushing injury of unspecified lesser toe(s), sequela*/
,'S9780XD'  /*Crushing injury of unspecified foot, subsequent encounter*/
,'S9780XS'  /*Crushing injury of unspecified foot, sequela*/
,'S9781XD'  /*Crushing injury of right foot, subsequent encounter*/
,'S9781XS'  /*Crushing injury of right foot, sequela*/
,'S9782XD'  /*Crushing injury of left foot, subsequent encounter*/
,'S9782XS'  /*Crushing injury of left foot, sequela*/
,'S98011D'  /*Complete traumatic amputation of right foot at ankle level, subsequent encounter*/
,'S98011S'  /*Complete traumatic amputation of right foot at ankle level, sequela*/
,'S98012D'  /*Complete traumatic amputation of left foot at ankle level, subsequent encounter*/
,'S98012S'  /*Complete traumatic amputation of left foot at ankle level, sequela*/
,'S98019D'  /*Complete traumatic amputation of unspecified foot at ankle level, subsequent encounter*/
,'S98019S'  /*Complete traumatic amputation of unspecified foot at ankle level, sequela*/
,'S98021D'  /*Partial traumatic amputation of right foot at ankle level, subsequent encounter*/
,'S98021S'  /*Partial traumatic amputation of right foot at ankle level, sequela*/
,'S98022D'  /*Partial traumatic amputation of left foot at ankle level, subsequent encounter*/
,'S98022S'  /*Partial traumatic amputation of left foot at ankle level, sequela*/
,'S98029D'  /*Partial traumatic amputation of unspecified foot at ankle level, subsequent encounter*/
,'S98029S'  /*Partial traumatic amputation of unspecified foot at ankle level, sequela*/
,'S98111D'  /*Complete traumatic amputation of right great toe, subsequent encounter*/
,'S98111S'  /*Complete traumatic amputation of right great toe, sequela*/
,'S98112D'  /*Complete traumatic amputation of left great toe, subsequent encounter*/
,'S98112S'  /*Complete traumatic amputation of left great toe, sequela*/
,'S98119D'  /*Complete traumatic amputation of unspecified great toe, subsequent encounter*/
,'S98119S'  /*Complete traumatic amputation of unspecified great toe, sequela*/
,'S98121D'  /*Partial traumatic amputation of right great toe, subsequent encounter*/
,'S98121S'  /*Partial traumatic amputation of right great toe, sequela*/
,'S98122D'  /*Partial traumatic amputation of left great toe, subsequent encounter*/
,'S98122S'  /*Partial traumatic amputation of left great toe, sequela*/
,'S98129D'  /*Partial traumatic amputation of unspecified great toe, subsequent encounter*/
,'S98129S'  /*Partial traumatic amputation of unspecified great toe, sequela*/
,'S98131D'  /*Complete traumatic amputation of one right lesser toe, subsequent encounter*/
,'S98131S'  /*Complete traumatic amputation of one right lesser toe, sequela*/
,'S98132D'  /*Complete traumatic amputation of one left lesser toe, subsequent encounter*/
,'S98132S'  /*Complete traumatic amputation of one left lesser toe, sequela*/
,'S98139D'  /*Complete traumatic amputation of one unspecified lesser toe, subsequent encounter*/
,'S98139S'  /*Complete traumatic amputation of one unspecified lesser toe, sequela*/
,'S98141D'  /*Partial traumatic amputation of one right lesser toe, subsequent encounter*/
,'S98141S'  /*Partial traumatic amputation of one right lesser toe, sequela*/
,'S98142D'  /*Partial traumatic amputation of one left lesser toe, subsequent encounter*/
,'S98142S'  /*Partial traumatic amputation of one left lesser toe, sequela*/
,'S98149D'  /*Partial traumatic amputation of one unspecified lesser toe, subsequent encounter*/
,'S98149S'  /*Partial traumatic amputation of one unspecified lesser toe, sequela*/
,'S98211D'  /*Complete traumatic amputation of two or more right lesser toes, subsequent encounter*/
,'S98211S'  /*Complete traumatic amputation of two or more right lesser toes, sequela*/
,'S98212D'  /*Complete traumatic amputation of two or more left lesser toes, subsequent encounter*/
,'S98212S'  /*Complete traumatic amputation of two or more left lesser toes, sequela*/
,'S98219D'  /*Complete traumatic amputation of two or more unspecified lesser toes, subsequent encounter*/
,'S98219S'  /*Complete traumatic amputation of two or more unspecified lesser toes, sequela*/
,'S98221D'  /*Partial traumatic amputation of two or more right lesser toes, subsequent encounter*/
,'S98221S'  /*Partial traumatic amputation of two or more right lesser toes, sequela*/
,'S98222D'  /*Partial traumatic amputation of two or more left lesser toes, subsequent encounter*/
,'S98222S'  /*Partial traumatic amputation of two or more left lesser toes, sequela*/
,'S98229D'  /*Partial traumatic amputation of two or more unspecified lesser toes, subsequent encounter*/
,'S98229S'  /*Partial traumatic amputation of two or more unspecified lesser toes, sequela*/
,'S98311D'  /*Complete traumatic amputation of right midfoot, subsequent encounter*/
,'S98311S'  /*Complete traumatic amputation of right midfoot, sequela*/
,'S98312D'  /*Complete traumatic amputation of left midfoot, subsequent encounter*/
,'S98312S'  /*Complete traumatic amputation of left midfoot, sequela*/
,'S98319D'  /*Complete traumatic amputation of unspecified midfoot, subsequent encounter*/
,'S98319S'  /*Complete traumatic amputation of unspecified midfoot, sequela*/
,'S98321D'  /*Partial traumatic amputation of right midfoot, subsequent encounter*/
,'S98321S'  /*Partial traumatic amputation of right midfoot, sequela*/
,'S98322D'  /*Partial traumatic amputation of left midfoot, subsequent encounter*/
,'S98322S'  /*Partial traumatic amputation of left midfoot, sequela*/
,'S98329D'  /*Partial traumatic amputation of unspecified midfoot, subsequent encounter*/
,'S98329S'  /*Partial traumatic amputation of unspecified midfoot, sequela*/
,'S98911D'  /*Complete traumatic amputation of right foot, level unspecified, subsequent encounter*/
,'S98911S'  /*Complete traumatic amputation of right foot, level unspecified, sequela*/
,'S98912D'  /*Complete traumatic amputation of left foot, level unspecified, subsequent encounter*/
,'S98912S'  /*Complete traumatic amputation of left foot, level unspecified, sequela*/
,'S98919D'  /*Complete traumatic amputation of unspecified foot, level unspecified, subsequent encounter*/
,'S98919S'  /*Complete traumatic amputation of unspecified foot, level unspecified, sequela*/
,'S98921D'  /*Partial traumatic amputation of right foot, level unspecified, subsequent encounter*/
,'S98921S'  /*Partial traumatic amputation of right foot, level unspecified, sequela*/
,'S98922D'  /*Partial traumatic amputation of left foot, level unspecified, subsequent encounter*/
,'S98922S'  /*Partial traumatic amputation of left foot, level unspecified, sequela*/
,'S98929D'  /*Partial traumatic amputation of unspecified foot, level unspecified, subsequent encounter*/
,'S98929S'  /*Partial traumatic amputation of unspecified foot, level unspecified, sequela*/
,'S99001D'  /*Unspecified physeal fracture of right calcaneus, subsequent encounter for fracture with routine healing*/
,'S99001G'  /*Unspecified physeal fracture of right calcaneus, subsequent encounter for fracture with delayed healing*/
,'S99001K'  /*Unspecified physeal fracture of right calcaneus, subsequent encounter for fracture with nonunion*/
,'S99001P'  /*Unspecified physeal fracture of right calcaneus, subsequent encounter for fracture with malunion*/
,'S99001S'  /*Unspecified physeal fracture of right calcaneus, sequela*/
,'S99002D'  /*Unspecified physeal fracture of left calcaneus, subsequent encounter for fracture with routine healing*/
,'S99002G'  /*Unspecified physeal fracture of left calcaneus, subsequent encounter for fracture with delayed healing*/
,'S99002K'  /*Unspecified physeal fracture of left calcaneus, subsequent encounter for fracture with nonunion*/
,'S99002P'  /*Unspecified physeal fracture of left calcaneus, subsequent encounter for fracture with malunion*/
,'S99002S'  /*Unspecified physeal fracture of left calcaneus, sequela*/
,'S99009D'  /*Unspecified physeal fracture of unspecified calcaneus, subsequent encounter for fracture with routine healing*/
,'S99009G'  /*Unspecified physeal fracture of unspecified calcaneus, subsequent encounter for fracture with delayed healing*/
,'S99009K'  /*Unspecified physeal fracture of unspecified calcaneus, subsequent encounter for fracture with nonunion*/
,'S99009P'  /*Unspecified physeal fracture of unspecified calcaneus, subsequent encounter for fracture with malunion*/
,'S99009S'  /*Unspecified physeal fracture of unspecified calcaneus, sequela*/
,'S99011D'  /*Salter-Harris Type I physeal fracture of right calcaneus, subsequent encounter for fracture with routine healing*/
,'S99011G'  /*Salter-Harris Type I physeal fracture of right calcaneus, subsequent encounter for fracture with delayed healing*/
,'S99011K'  /*Salter-Harris Type I physeal fracture of right calcaneus, subsequent encounter for fracture with nonunion*/
,'S99011P'  /*Salter-Harris Type I physeal fracture of right calcaneus, subsequent encounter for fracture with malunion*/
,'S99011S'  /*Salter-Harris Type I physeal fracture of right calcaneus, sequela*/
,'S99012D'  /*Salter-Harris Type I physeal fracture of left calcaneus, subsequent encounter for fracture with routine healing*/
,'S99012G'  /*Salter-Harris Type I physeal fracture of left calcaneus, subsequent encounter for fracture with delayed healing*/
,'S99012K'  /*Salter-Harris Type I physeal fracture of left calcaneus, subsequent encounter for fracture with nonunion*/
,'S99012P'  /*Salter-Harris Type I physeal fracture of left calcaneus, subsequent encounter for fracture with malunion*/
,'S99012S'  /*Salter-Harris Type I physeal fracture of left calcaneus, sequela*/
,'S99019D'  /*Salter-Harris Type I physeal fracture of unspecified calcaneus, subsequent encounter for fracture with routine healing*/
,'S99019G'  /*Salter-Harris Type I physeal fracture of unspecified calcaneus, subsequent encounter for fracture with delayed healing*/
,'S99019K'  /*Salter-Harris Type I physeal fracture of unspecified calcaneus, subsequent encounter for fracture with nonunion*/
,'S99019P'  /*Salter-Harris Type I physeal fracture of unspecified calcaneus, subsequent encounter for fracture with malunion*/
,'S99019S'  /*Salter-Harris Type I physeal fracture of unspecified calcaneus, sequela*/
,'S99021D'  /*Salter-Harris Type II physeal fracture of right calcaneus, subsequent encounter for fracture with routine healing*/
,'S99021G'  /*Salter-Harris Type II physeal fracture of right calcaneus, subsequent encounter for fracture with delayed healing*/
,'S99021K'  /*Salter-Harris Type II physeal fracture of right calcaneus, subsequent encounter for fracture with nonunion*/
,'S99021P'  /*Salter-Harris Type II physeal fracture of right calcaneus, subsequent encounter for fracture with malunion*/
,'S99021S'  /*Salter-Harris Type II physeal fracture of right calcaneus, sequela*/
,'S99022D'  /*Salter-Harris Type II physeal fracture of left calcaneus, subsequent encounter for fracture with routine healing*/
,'S99022G'  /*Salter-Harris Type II physeal fracture of left calcaneus, subsequent encounter for fracture with delayed healing*/
,'S99022K'  /*Salter-Harris Type II physeal fracture of left calcaneus, subsequent encounter for fracture with nonunion*/
,'S99022P'  /*Salter-Harris Type II physeal fracture of left calcaneus, subsequent encounter for fracture with malunion*/
,'S99022S'  /*Salter-Harris Type II physeal fracture of left calcaneus, sequela*/
,'S99029D'  /*Salter-Harris Type II physeal fracture of unspecified calcaneus, subsequent encounter for fracture with routine healing*/
,'S99029G'  /*Salter-Harris Type II physeal fracture of unspecified calcaneus, subsequent encounter for fracture with delayed healing*/
,'S99029K'  /*Salter-Harris Type II physeal fracture of unspecified calcaneus, subsequent encounter for fracture with nonunion*/
,'S99029P'  /*Salter-Harris Type II physeal fracture of unspecified calcaneus, subsequent encounter for fracture with malunion*/
,'S99029S'  /*Salter-Harris Type II physeal fracture of unspecified calcaneus, sequela*/
,'S99031D'  /*Salter-Harris Type III physeal fracture of right calcaneus, subsequent encounter for fracture with routine healing*/
,'S99031G'  /*Salter-Harris Type III physeal fracture of right calcaneus, subsequent encounter for fracture with delayed healing*/
,'S99031K'  /*Salter-Harris Type III physeal fracture of right calcaneus, subsequent encounter for fracture with nonunion*/
,'S99031P'  /*Salter-Harris Type III physeal fracture of right calcaneus, subsequent encounter for fracture with malunion*/
,'S99031S'  /*Salter-Harris Type III physeal fracture of right calcaneus, sequela*/
,'S99032D'  /*Salter-Harris Type III physeal fracture of left calcaneus, subsequent encounter for fracture with routine healing*/
,'S99032G'  /*Salter-Harris Type III physeal fracture of left calcaneus, subsequent encounter for fracture with delayed healing*/
,'S99032K'  /*Salter-Harris Type III physeal fracture of left calcaneus, subsequent encounter for fracture with nonunion*/
,'S99032P'  /*Salter-Harris Type III physeal fracture of left calcaneus, subsequent encounter for fracture with malunion*/
,'S99032S'  /*Salter-Harris Type III physeal fracture of left calcaneus, sequela*/
,'S99039D'  /*Salter-Harris Type III physeal fracture of unspecified calcaneus, subsequent encounter for fracture with routine healing*/
,'S99039G'  /*Salter-Harris Type III physeal fracture of unspecified calcaneus, subsequent encounter for fracture with delayed healing*/
,'S99039K'  /*Salter-Harris Type III physeal fracture of unspecified calcaneus, subsequent encounter for fracture with nonunion*/
,'S99039P'  /*Salter-Harris Type III physeal fracture of unspecified calcaneus, subsequent encounter for fracture with malunion*/
,'S99039S'  /*Salter-Harris Type III physeal fracture of unspecified calcaneus, sequela*/
,'S99041D'  /*Salter-Harris Type IV physeal fracture of right calcaneus, subsequent encounter for fracture with routine healing*/
,'S99041G'  /*Salter-Harris Type IV physeal fracture of right calcaneus, subsequent encounter for fracture with delayed healing*/
,'S99041K'  /*Salter-Harris Type IV physeal fracture of right calcaneus, subsequent encounter for fracture with nonunion*/
,'S99041P'  /*Salter-Harris Type IV physeal fracture of right calcaneus, subsequent encounter for fracture with malunion*/
,'S99041S'  /*Salter-Harris Type IV physeal fracture of right calcaneus, sequela*/
,'S99042D'  /*Salter-Harris Type IV physeal fracture of left calcaneus, subsequent encounter for fracture with routine healing*/
,'S99042G'  /*Salter-Harris Type IV physeal fracture of left calcaneus, subsequent encounter for fracture with delayed healing*/
,'S99042K'  /*Salter-Harris Type IV physeal fracture of left calcaneus, subsequent encounter for fracture with nonunion*/
,'S99042P'  /*Salter-Harris Type IV physeal fracture of left calcaneus, subsequent encounter for fracture with malunion*/
,'S99042S'  /*Salter-Harris Type IV physeal fracture of left calcaneus, sequela*/
,'S99049D'  /*Salter-Harris Type IV physeal fracture of unspecified calcaneus, subsequent encounter for fracture with routine healing*/
,'S99049G'  /*Salter-Harris Type IV physeal fracture of unspecified calcaneus, subsequent encounter for fracture with delayed healing*/
,'S99049K'  /*Salter-Harris Type IV physeal fracture of unspecified calcaneus, subsequent encounter for fracture with nonunion*/
,'S99049P'  /*Salter-Harris Type IV physeal fracture of unspecified calcaneus, subsequent encounter for fracture with malunion*/
,'S99049S'  /*Salter-Harris Type IV physeal fracture of unspecified calcaneus, sequela*/
,'S99091D'  /*Other physeal fracture of right calcaneus, subsequent encounter for fracture with routine healing*/
,'S99091G'  /*Other physeal fracture of right calcaneus, subsequent encounter for fracture with delayed healing*/
,'S99091K'  /*Other physeal fracture of right calcaneus, subsequent encounter for fracture with nonunion*/
,'S99091P'  /*Other physeal fracture of right calcaneus, subsequent encounter for fracture with malunion*/
,'S99091S'  /*Other physeal fracture of right calcaneus, sequela*/
,'S99092D'  /*Other physeal fracture of left calcaneus, subsequent encounter for fracture with routine healing*/
,'S99092G'  /*Other physeal fracture of left calcaneus, subsequent encounter for fracture with delayed healing*/
,'S99092K'  /*Other physeal fracture of left calcaneus, subsequent encounter for fracture with nonunion*/
,'S99092P'  /*Other physeal fracture of left calcaneus, subsequent encounter for fracture with malunion*/
,'S99092S'  /*Other physeal fracture of left calcaneus, sequela*/
,'S99099D'  /*Other physeal fracture of unspecified calcaneus, subsequent encounter for fracture with routine healing*/
,'S99099G'  /*Other physeal fracture of unspecified calcaneus, subsequent encounter for fracture with delayed healing*/
,'S99099K'  /*Other physeal fracture of unspecified calcaneus, subsequent encounter for fracture with nonunion*/
,'S99099P'  /*Other physeal fracture of unspecified calcaneus, subsequent encounter for fracture with malunion*/
,'S99099S'  /*Other physeal fracture of unspecified calcaneus, sequela*/
,'S99101D'  /*Unspecified physeal fracture of right metatarsal, subsequent encounter for fracture with routine healing*/
,'S99101G'  /*Unspecified physeal fracture of right metatarsal, subsequent encounter for fracture with delayed healing*/
,'S99101K'  /*Unspecified physeal fracture of right metatarsal, subsequent encounter for fracture with nonunion*/
,'S99101P'  /*Unspecified physeal fracture of right metatarsal, subsequent encounter for fracture with malunion*/
,'S99101S'  /*Unspecified physeal fracture of right metatarsal, sequela*/
,'S99102D'  /*Unspecified physeal fracture of left metatarsal, subsequent encounter for fracture with routine healing*/
,'S99102G'  /*Unspecified physeal fracture of left metatarsal, subsequent encounter for fracture with delayed healing*/
,'S99102K'  /*Unspecified physeal fracture of left metatarsal, subsequent encounter for fracture with nonunion*/
,'S99102P'  /*Unspecified physeal fracture of left metatarsal, subsequent encounter for fracture with malunion*/
,'S99102S'  /*Unspecified physeal fracture of left metatarsal, sequela*/
,'S99109D'  /*Unspecified physeal fracture of unspecified metatarsal, subsequent encounter for fracture with routine healing*/
,'S99109G'  /*Unspecified physeal fracture of unspecified metatarsal, subsequent encounter for fracture with delayed healing*/
,'S99109K'  /*Unspecified physeal fracture of unspecified metatarsal, subsequent encounter for fracture with nonunion*/
,'S99109P'  /*Unspecified physeal fracture of unspecified metatarsal, subsequent encounter for fracture with malunion*/
,'S99109S'  /*Unspecified physeal fracture of unspecified metatarsal, sequela*/
,'S99111D'  /*Salter-Harris Type I physeal fracture of right metatarsal, subsequent encounter for fracture with routine healing*/
,'S99111G'  /*Salter-Harris Type I physeal fracture of right metatarsal, subsequent encounter for fracture with delayed healing*/
,'S99111K'  /*Salter-Harris Type I physeal fracture of right metatarsal, subsequent encounter for fracture with nonunion*/
,'S99111P'  /*Salter-Harris Type I physeal fracture of right metatarsal, subsequent encounter for fracture with malunion*/
,'S99111S'  /*Salter-Harris Type I physeal fracture of right metatarsal, sequela*/
,'S99112D'  /*Salter-Harris Type I physeal fracture of left metatarsal, subsequent encounter for fracture with routine healing*/
,'S99112G'  /*Salter-Harris Type I physeal fracture of left metatarsal, subsequent encounter for fracture with delayed healing*/
,'S99112K'  /*Salter-Harris Type I physeal fracture of left metatarsal, subsequent encounter for fracture with nonunion*/
,'S99112P'  /*Salter-Harris Type I physeal fracture of left metatarsal, subsequent encounter for fracture with malunion*/
,'S99112S'  /*Salter-Harris Type I physeal fracture of left metatarsal, sequela*/
,'S99119D'  /*Salter-Harris Type I physeal fracture of unspecified metatarsal, subsequent encounter for fracture with routine healing*/
,'S99119G'  /*Salter-Harris Type I physeal fracture of unspecified metatarsal, subsequent encounter for fracture with delayed healing*/
,'S99119K'  /*Salter-Harris Type I physeal fracture of unspecified metatarsal, subsequent encounter for fracture with nonunion*/
,'S99119P'  /*Salter-Harris Type I physeal fracture of unspecified metatarsal, subsequent encounter for fracture with malunion*/
,'S99119S'  /*Salter-Harris Type I physeal fracture of unspecified metatarsal, sequela*/
,'S99121D'  /*Salter-Harris Type II physeal fracture of right metatarsal, subsequent encounter for fracture with routine healing*/
,'S99121G'  /*Salter-Harris Type II physeal fracture of right metatarsal, subsequent encounter for fracture with delayed healing*/
,'S99121K'  /*Salter-Harris Type II physeal fracture of right metatarsal, subsequent encounter for fracture with nonunion*/
,'S99121P'  /*Salter-Harris Type II physeal fracture of right metatarsal, subsequent encounter for fracture with malunion*/
,'S99122D'  /*Salter-Harris Type II physeal fracture of left metatarsal, subsequent encounter for fracture with routine healing*/
,'S99122G'  /*Salter-Harris Type II physeal fracture of left metatarsal, subsequent encounter for fracture with delayed healing*/
,'S99122K'  /*Salter-Harris Type II physeal fracture of left metatarsal, subsequent encounter for fracture with nonunion*/
,'S99122P'  /*Salter-Harris Type II physeal fracture of left metatarsal, subsequent encounter for fracture with malunion*/
,'S99122S'  /*Salter-Harris Type II physeal fracture of left metatarsal, sequela*/
,'S99129D'  /*Salter-Harris Type II physeal fracture of unspecified metatarsal, subsequent encounter for fracture with routine healing*/
,'S99129G'  /*Salter-Harris Type II physeal fracture of unspecified metatarsal, subsequent encounter for fracture with delayed healing*/
,'S99129K'  /*Salter-Harris Type II physeal fracture of unspecified metatarsal, subsequent encounter for fracture with nonunion*/
,'S99129P'  /*Salter-Harris Type II physeal fracture of unspecified metatarsal, subsequent encounter for fracture with malunion*/
,'S99129S'  /*Salter-Harris Type II physeal fracture of unspecified metatarsal, sequela*/
,'S99131D'  /*Salter-Harris Type III physeal fracture of right metatarsal, subsequent encounter for fracture with routine healing*/
,'S99131G'  /*Salter-Harris Type III physeal fracture of right metatarsal, subsequent encounter for fracture with delayed healing*/
,'S99131K'  /*Salter-Harris Type III physeal fracture of right metatarsal, subsequent encounter for fracture with nonunion*/
,'S99131P'  /*Salter-Harris Type III physeal fracture of right metatarsal, subsequent encounter for fracture with malunion*/
,'S99131S'  /*Salter-Harris Type III physeal fracture of right metatarsal, sequela*/
,'S99132D'  /*Salter-Harris Type III physeal fracture of left metatarsal, subsequent encounter for fracture with routine healing*/
,'S99132G'  /*Salter-Harris Type III physeal fracture of left metatarsal, subsequent encounter for fracture with delayed healing*/
,'S99132K'  /*Salter-Harris Type III physeal fracture of left metatarsal, subsequent encounter for fracture with nonunion*/
,'S99132P'  /*Salter-Harris Type III physeal fracture of left metatarsal, subsequent encounter for fracture with malunion*/
,'S99132S'  /*Salter-Harris Type III physeal fracture of left metatarsal, sequela*/
,'S99139D'  /*Salter-Harris Type III physeal fracture of unspecified metatarsal, subsequent encounter for fracture with routine healing*/
,'S99139G'  /*Salter-Harris Type III physeal fracture of unspecified metatarsal, subsequent encounter for fracture with delayed healing*/
,'S99139K'  /*Salter-Harris Type III physeal fracture of unspecified metatarsal, subsequent encounter for fracture with nonunion*/
,'S99139P'  /*Salter-Harris Type III physeal fracture of unspecified metatarsal, subsequent encounter for fracture with malunion*/
,'S99139S'  /*Salter-Harris Type III physeal fracture of unspecified metatarsal, sequela*/
,'S99141D'  /*Salter-Harris Type IV physeal fracture of right metatarsal, subsequent encounter for fracture with routine healing*/
,'S99141G'  /*Salter-Harris Type IV physeal fracture of right metatarsal, subsequent encounter for fracture with delayed healing*/
,'S99141K'  /*Salter-Harris Type IV physeal fracture of right metatarsal, subsequent encounter for fracture with nonunion*/
,'S99141P'  /*Salter-Harris Type IV physeal fracture of right metatarsal, subsequent encounter for fracture with malunion*/
,'S99141S'  /*Salter-Harris Type IV physeal fracture of right metatarsal, sequela*/
,'S99142D'  /*Salter-Harris Type IV physeal fracture of left metatarsal, subsequent encounter for fracture with routine healing*/
,'S99142G'  /*Salter-Harris Type IV physeal fracture of left metatarsal, subsequent encounter for fracture with delayed healing*/
,'S99142K'  /*Salter-Harris Type IV physeal fracture of left metatarsal, subsequent encounter for fracture with nonunion*/
,'S99142P'  /*Salter-Harris Type IV physeal fracture of left metatarsal, subsequent encounter for fracture with malunion*/
,'S99142S'  /*Salter-Harris Type IV physeal fracture of left metatarsal, sequela*/
,'S99149D'  /*Salter-Harris Type IV physeal fracture of unspecified metatarsal, subsequent encounter for fracture with routine healing*/
,'S99149G'  /*Salter-Harris Type IV physeal fracture of unspecified metatarsal, subsequent encounter for fracture with delayed healing*/
,'S99149K'  /*Salter-Harris Type IV physeal fracture of unspecified metatarsal, subsequent encounter for fracture with nonunion*/
,'S99149P'  /*Salter-Harris Type IV physeal fracture of unspecified metatarsal, subsequent encounter for fracture with malunion*/
,'S99149S'  /*Salter-Harris Type IV physeal fracture of unspecified metatarsal, sequela*/
,'S99191D'  /*Other physeal fracture of right metatarsal, subsequent encounter for fracture with routine healing*/
,'S99191G'  /*Other physeal fracture of right metatarsal, subsequent encounter for fracture with delayed healing*/
,'S99191K'  /*Other physeal fracture of right metatarsal, subsequent encounter for fracture with nonunion*/
,'S99191P'  /*Other physeal fracture of right metatarsal, subsequent encounter for fracture with malunion*/
,'S99191S'  /*Other physeal fracture of right metatarsal, sequela*/
,'S99192D'  /*Other physeal fracture of left metatarsal, subsequent encounter for fracture with routine healing*/
,'S99192G'  /*Other physeal fracture of left metatarsal, subsequent encounter for fracture with delayed healing*/
,'S99192K'  /*Other physeal fracture of left metatarsal, subsequent encounter for fracture with nonunion*/
,'S99192P'  /*Other physeal fracture of left metatarsal, subsequent encounter for fracture with malunion*/
,'S99192S'  /*Other physeal fracture of left metatarsal, sequela*/
,'S99199D'  /*Other physeal fracture of unspecified metatarsal, subsequent encounter for fracture with routine healing*/
,'S99199G'  /*Other physeal fracture of unspecified metatarsal, subsequent encounter for fracture with delayed healing*/
,'S99199K'  /*Other physeal fracture of unspecified metatarsal, subsequent encounter for fracture with nonunion*/
,'S99199P'  /*Other physeal fracture of unspecified metatarsal, subsequent encounter for fracture with malunion*/
,'S99199S'  /*Other physeal fracture of unspecified metatarsal, sequela*/
,'S99201D'  /*Unspecified physeal fracture of phalanx of right toe, subsequent encounter for fracture with routine healing*/
,'S99201G'  /*Unspecified physeal fracture of phalanx of right toe, subsequent encounter for fracture with delayed healing*/
,'S99201K'  /*Unspecified physeal fracture of phalanx of right toe, subsequent encounter for fracture with nonunion*/
,'S99201P'  /*Unspecified physeal fracture of phalanx of right toe, subsequent encounter for fracture with malunion*/
,'S99201S'  /*Unspecified physeal fracture of phalanx of right toe, sequela*/
,'S99202D'  /*Unspecified physeal fracture of phalanx of left toe, subsequent encounter for fracture with routine healing*/
,'S99202G'  /*Unspecified physeal fracture of phalanx of left toe, subsequent encounter for fracture with delayed healing*/
,'S99202K'  /*Unspecified physeal fracture of phalanx of left toe, subsequent encounter for fracture with nonunion*/
,'S99202P'  /*Unspecified physeal fracture of phalanx of left toe, subsequent encounter for fracture with malunion*/
,'S99202S'  /*Unspecified physeal fracture of phalanx of left toe, sequela*/
,'S99209D'  /*Unspecified physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with routine healing*/
,'S99209G'  /*Unspecified physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with delayed healing*/
,'S99209K'  /*Unspecified physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with nonunion*/
,'S99209P'  /*Unspecified physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with malunion*/
,'S99209S'  /*Unspecified physeal fracture of phalanx of unspecified toe, sequela*/
,'S99211D'  /*Salter-Harris Type I physeal fracture of phalanx of right toe, subsequent encounter for fracture with routine healing*/
,'S99211G'  /*Salter-Harris Type I physeal fracture of phalanx of right toe, subsequent encounter for fracture with delayed healing*/
,'S99211K'  /*Salter-Harris Type I physeal fracture of phalanx of right toe, subsequent encounter for fracture with nonunion*/
,'S99211P'  /*Salter-Harris Type I physeal fracture of phalanx of right toe, subsequent encounter for fracture with malunion*/
,'S99211S'  /*Salter-Harris Type I physeal fracture of phalanx of right toe, sequela*/
,'S99212D'  /*Salter-Harris Type I physeal fracture of phalanx of left toe, subsequent encounter for fracture with routine healing*/
,'S99212G'  /*Salter-Harris Type I physeal fracture of phalanx of left toe, subsequent encounter for fracture with delayed healing*/
,'S99212K'  /*Salter-Harris Type I physeal fracture of phalanx of left toe, subsequent encounter for fracture with nonunion*/
,'S99212P'  /*Salter-Harris Type I physeal fracture of phalanx of left toe, subsequent encounter for fracture with malunion*/
,'S99212S'  /*Salter-Harris Type I physeal fracture of phalanx of left toe, sequela*/
,'S99219D'  /*Salter-Harris Type I physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with routine healing*/
,'S99219G'  /*Salter-Harris Type I physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with delayed healing*/
,'S99219K'  /*Salter-Harris Type I physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with nonunion*/
,'S99219P'  /*Salter-Harris Type I physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with malunion*/
,'S99219S'  /*Salter-Harris Type I physeal fracture of phalanx of unspecified toe, sequela*/
,'S99221D'  /*Salter-Harris Type II physeal fracture of phalanx of right toe, subsequent encounter for fracture with routine healing*/
,'S99221G'  /*Salter-Harris Type II physeal fracture of phalanx of right toe, subsequent encounter for fracture with delayed healing*/
,'S99221K'  /*Salter-Harris Type II physeal fracture of phalanx of right toe, subsequent encounter for fracture with nonunion*/
,'S99221P'  /*Salter-Harris Type II physeal fracture of phalanx of right toe, subsequent encounter for fracture with malunion*/
,'S99221S'  /*Salter-Harris Type II physeal fracture of phalanx of right toe, sequela*/
,'S99222D'  /*Salter-Harris Type II physeal fracture of phalanx of left toe, subsequent encounter for fracture with routine healing*/
,'S99222G'  /*Salter-Harris Type II physeal fracture of phalanx of left toe, subsequent encounter for fracture with delayed healing*/
,'S99222K'  /*Salter-Harris Type II physeal fracture of phalanx of left toe, subsequent encounter for fracture with nonunion*/
,'S99222P'  /*Salter-Harris Type II physeal fracture of phalanx of left toe, subsequent encounter for fracture with malunion*/
,'S99222S'  /*Salter-Harris Type II physeal fracture of phalanx of left toe, sequela*/
,'S99229D'  /*Salter-Harris Type II physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with routine healing*/
,'S99229G'  /*Salter-Harris Type II physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with delayed healing*/
,'S99229K'  /*Salter-Harris Type II physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with nonunion*/
,'S99229P'  /*Salter-Harris Type II physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with malunion*/
,'S99229S'  /*Salter-Harris Type II physeal fracture of phalanx of unspecified toe, sequela*/
,'S99231D'  /*Salter-Harris Type III physeal fracture of phalanx of right toe, subsequent encounter for fracture with routine healing*/
,'S99231G'  /*Salter-Harris Type III physeal fracture of phalanx of right toe, subsequent encounter for fracture with delayed healing*/
,'S99231K'  /*Salter-Harris Type III physeal fracture of phalanx of right toe, subsequent encounter for fracture with nonunion*/
,'S99231P'  /*Salter-Harris Type III physeal fracture of phalanx of right toe, subsequent encounter for fracture with malunion*/
,'S99231S'  /*Salter-Harris Type III physeal fracture of phalanx of right toe, sequela*/
,'S99232D'  /*Salter-Harris Type III physeal fracture of phalanx of left toe, subsequent encounter for fracture with routine healing*/
,'S99232G'  /*Salter-Harris Type III physeal fracture of phalanx of left toe, subsequent encounter for fracture with delayed healing*/
,'S99232K'  /*Salter-Harris Type III physeal fracture of phalanx of left toe, subsequent encounter for fracture with nonunion*/
,'S99232P'  /*Salter-Harris Type III physeal fracture of phalanx of left toe, subsequent encounter for fracture with malunion*/
,'S99232S'  /*Salter-Harris Type III physeal fracture of phalanx of left toe, sequela*/
,'S99239D'  /*Salter-Harris Type III physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with routine healing*/
,'S99239G'  /*Salter-Harris Type III physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with delayed healing*/
,'S99239K'  /*Salter-Harris Type III physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with nonunion*/
,'S99239P'  /*Salter-Harris Type III physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with malunion*/
,'S99241D'  /*Salter-Harris Type IV physeal fracture of phalanx of right toe, subsequent encounter for fracture with routine healing*/
,'S99241G'  /*Salter-Harris Type IV physeal fracture of phalanx of right toe, subsequent encounter for fracture with delayed healing*/
,'S99241K'  /*Salter-Harris Type IV physeal fracture of phalanx of right toe, subsequent encounter for fracture with nonunion*/
,'S99241P'  /*Salter-Harris Type IV physeal fracture of phalanx of right toe, subsequent encounter for fracture with malunion*/
,'S99241S'  /*Salter-Harris Type IV physeal fracture of phalanx of right toe, sequela*/
,'S99242D'  /*Salter-Harris Type IV physeal fracture of phalanx of left toe, subsequent encounter for fracture with routine healing*/
,'S99242G'  /*Salter-Harris Type IV physeal fracture of phalanx of left toe, subsequent encounter for fracture with delayed healing*/
,'S99242K'  /*Salter-Harris Type IV physeal fracture of phalanx of left toe, subsequent encounter for fracture with nonunion*/
,'S99242P'  /*Salter-Harris Type IV physeal fracture of phalanx of left toe, subsequent encounter for fracture with malunion*/
,'S99242S'  /*Salter-Harris Type IV physeal fracture of phalanx of left toe, sequela*/
,'S99249D'  /*Salter-Harris Type IV physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with routine healing*/
,'S99249G'  /*Salter-Harris Type IV physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with delayed healing*/
,'S99249K'  /*Salter-Harris Type IV physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with nonunion*/
,'S99249P'  /*Salter-Harris Type IV physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with malunion*/
,'S99249S'  /*Salter-Harris Type IV physeal fracture of phalanx of unspecified toe, sequela*/
,'S99291D'  /*Other physeal fracture of phalanx of right toe, subsequent encounter for fracture with routine healing*/
,'S99291G'  /*Other physeal fracture of phalanx of right toe, subsequent encounter for fracture with delayed healing*/
,'S99291K'  /*Other physeal fracture of phalanx of right toe, subsequent encounter for fracture with nonunion*/
,'S99291P'  /*Other physeal fracture of phalanx of right toe, subsequent encounter for fracture with malunion*/
,'S99291S'  /*Other physeal fracture of phalanx of right toe, sequela*/
,'S99292D'  /*Other physeal fracture of phalanx of left toe, subsequent encounter for fracture with routine healing*/
,'S99292G'  /*Other physeal fracture of phalanx of left toe, subsequent encounter for fracture with delayed healing*/
,'S99292K'  /*Other physeal fracture of phalanx of left toe, subsequent encounter for fracture with nonunion*/
,'S99292P'  /*Other physeal fracture of phalanx of left toe, subsequent encounter for fracture with malunion*/
,'S99292S'  /*Other physeal fracture of phalanx of left toe, sequela*/
,'S99299D'  /*Other physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with routine healing*/
,'S99299G'  /*Other physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with delayed healing*/
,'S99299K'  /*Other physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with nonunion*/
,'S99299P'  /*Other physeal fracture of phalanx of unspecified toe, subsequent encounter for fracture with malunion*/
,'S99299S'  /*Other physeal fracture of phalanx of unspecified toe, sequela*/
,'S99811D'  /*Other specified injuries of right ankle, subsequent encounter*/
,'S99811S'  /*Other specified injuries of right ankle, sequela*/
,'S99812D'  /*Other specified injuries of left ankle, subsequent encounter*/
,'S99812S'  /*Other specified injuries of left ankle, sequela*/
,'S99819D'  /*Other specified injuries of unspecified ankle, subsequent encounter*/
,'S99819S'  /*Other specified injuries of unspecified ankle, sequela*/
,'S99821D'  /*Other specified injuries of right foot, subsequent encounter*/
,'S99821S'  /*Other specified injuries of right foot, sequela*/
,'S99822D'  /*Other specified injuries of left foot, subsequent encounter*/
,'S99822S'  /*Other specified injuries of left foot, sequela*/
,'S99829D'  /*Other specified injuries of unspecified foot, subsequent encounter*/
,'S99829S'  /*Other specified injuries of unspecified foot, sequela*/
,'S99911D'  /*Unspecified injury of right ankle, subsequent encounter*/
,'S99911S'  /*Unspecified injury of right ankle, sequela*/
,'S99912D'  /*Unspecified injury of left ankle, subsequent encounter*/
,'S99912S'  /*Unspecified injury of left ankle, sequela*/
,'S99919D'  /*Unspecified injury of unspecified ankle, subsequent encounter*/
,'S99919S'  /*Unspecified injury of unspecified ankle, sequela*/
,'S99921D'  /*Unspecified injury of right foot, subsequent encounter*/
,'S99921S'  /*Unspecified injury of right foot, sequela*/
,'S99922D'  /*Unspecified injury of left foot, subsequent encounter*/
,'S99922S'  /*Unspecified injury of left foot, sequela*/
,'S99929D'  /*Unspecified injury of unspecified foot, subsequent encounter*/
,'S99929S'  /*Unspecified injury of unspecified foot, sequela*/
,'T1500XD'  /*Foreign body in cornea, unspecified eye, subsequent encounter*/
,'T1500XS'  /*Foreign body in cornea, unspecified eye, sequela*/
,'T1501XD'  /*Foreign body in cornea, right eye, subsequent encounter*/
,'T1501XS'  /*Foreign body in cornea, right eye, sequela*/
,'T1502XD'  /*Foreign body in cornea, left eye, subsequent encounter*/
,'T1502XS'  /*Foreign body in cornea, left eye, sequela*/
,'T1510XD'  /*Foreign body in conjunctival sac, unspecified eye, subsequent encounter*/
,'T1510XS'  /*Foreign body in conjunctival sac, unspecified eye, sequela*/
,'T1511XD'  /*Foreign body in conjunctival sac, right eye, subsequent encounter*/
,'T1511XS'  /*Foreign body in conjunctival sac, right eye, sequela*/
,'T1512XD'  /*Foreign body in conjunctival sac, left eye, subsequent encounter*/
,'T1512XS'  /*Foreign body in conjunctival sac, left eye, sequela*/
,'T1580XD'  /*Foreign body in other and multiple parts of external eye, unspecified eye, subsequent encounter*/
,'T1580XS'  /*Foreign body in other and multiple parts of external eye, unspecified eye, sequela*/
,'T1581XD'  /*Foreign body in other and multiple parts of external eye, right eye, subsequent encounter*/
,'T1581XS'  /*Foreign body in other and multiple parts of external eye, right eye, sequela*/
,'T1582XD'  /*Foreign body in other and multiple parts of external eye, left eye, subsequent encounter*/
,'T1582XS'  /*Foreign body in other and multiple parts of external eye, left eye, sequela*/
,'T1590XD'  /*Foreign body on external eye, part unspecified, unspecified eye, subsequent encounter*/
,'T1590XS'  /*Foreign body on external eye, part unspecified, unspecified eye, sequela*/
,'T1591XD'  /*Foreign body on external eye, part unspecified, right eye, subsequent encounter*/
,'T1591XS'  /*Foreign body on external eye, part unspecified, right eye, sequela*/
,'T1592XD'  /*Foreign body on external eye, part unspecified, left eye, subsequent encounter*/
,'T1592XS'  /*Foreign body on external eye, part unspecified, left eye, sequela*/
,'T161XXD'  /*Foreign body in right ear, subsequent encounter*/
,'T161XXS'  /*Foreign body in right ear, sequela*/
,'T162XXD'  /*Foreign body in left ear, subsequent encounter*/
,'T162XXS'  /*Foreign body in left ear, sequela*/
,'T169XXD'  /*Foreign body in ear, unspecified ear, subsequent encounter*/
,'T169XXS'  /*Foreign body in ear, unspecified ear, sequela*/
,'T170XXD'  /*Foreign body in nasal sinus, subsequent encounter*/
,'T170XXS'  /*Foreign body in nasal sinus, sequela*/
,'T171XXD'  /*Foreign body in nostril, subsequent encounter*/
,'T171XXS'  /*Foreign body in nostril, sequela*/
,'T17200D'  /*Unspecified foreign body in pharynx causing asphyxiation, subsequent encounter*/
,'T17200S'  /*Unspecified foreign body in pharynx causing asphyxiation, sequela*/
,'T17208D'  /*Unspecified foreign body in pharynx causing other injury, subsequent encounter*/
,'T17208S'  /*Unspecified foreign body in pharynx causing other injury, sequela*/
,'T17210D'  /*Gastric contents in pharynx causing asphyxiation, subsequent encounter*/
,'T17210S'  /*Gastric contents in pharynx causing asphyxiation, sequela*/
,'T17218D'  /*Gastric contents in pharynx causing other injury, subsequent encounter*/
,'T17218S'  /*Gastric contents in pharynx causing other injury, sequela*/
,'T17220D'  /*Food in pharynx causing asphyxiation, subsequent encounter*/
,'T17220S'  /*Food in pharynx causing asphyxiation, sequela*/
,'T17228D'  /*Food in pharynx causing other injury, subsequent encounter*/
,'T17228S'  /*Food in pharynx causing other injury, sequela*/
,'T17290D'  /*Other foreign object in pharynx causing asphyxiation, subsequent encounter*/
,'T17290S'  /*Other foreign object in pharynx causing asphyxiation, sequela*/
,'T17298D'  /*Other foreign object in pharynx causing other injury, subsequent encounter*/
,'T17298S'  /*Other foreign object in pharynx causing other injury, sequela*/
,'T17300D'  /*Unspecified foreign body in larynx causing asphyxiation, subsequent encounter*/
,'T17300S'  /*Unspecified foreign body in larynx causing asphyxiation, sequela*/
,'T17308D'  /*Unspecified foreign body in larynx causing other injury, subsequent encounter*/
,'T17308S'  /*Unspecified foreign body in larynx causing other injury, sequela*/
,'T17310D'  /*Gastric contents in larynx causing asphyxiation, subsequent encounter*/
,'T17310S'  /*Gastric contents in larynx causing asphyxiation, sequela*/
,'T17318D'  /*Gastric contents in larynx causing other injury, subsequent encounter*/
,'T17318S'  /*Gastric contents in larynx causing other injury, sequela*/
,'T17320D'  /*Food in larynx causing asphyxiation, subsequent encounter*/
,'T17320S'  /*Food in larynx causing asphyxiation, sequela*/
,'T17328D'  /*Food in larynx causing other injury, subsequent encounter*/
,'T17328S'  /*Food in larynx causing other injury, sequela*/
,'T17390D'  /*Other foreign object in larynx causing asphyxiation, subsequent encounter*/
,'T17390S'  /*Other foreign object in larynx causing asphyxiation, sequela*/
,'T17398D'  /*Other foreign object in larynx causing other injury, subsequent encounter*/
,'T17398S'  /*Other foreign object in larynx causing other injury, sequela*/
,'T17400D'  /*Unspecified foreign body in trachea causing asphyxiation, subsequent encounter*/
,'T17400S'  /*Unspecified foreign body in trachea causing asphyxiation, sequela*/
,'T17408D'  /*Unspecified foreign body in trachea causing other injury, subsequent encounter*/
,'T17408S'  /*Unspecified foreign body in trachea causing other injury, sequela*/
,'T17410D'  /*Gastric contents in trachea causing asphyxiation, subsequent encounter*/
,'T17410S'  /*Gastric contents in trachea causing asphyxiation, sequela*/
,'T17418D'  /*Gastric contents in trachea causing other injury, subsequent encounter*/
,'T17418S'  /*Gastric contents in trachea causing other injury, sequela*/
,'T17420D'  /*Food in trachea causing asphyxiation, subsequent encounter*/
,'T17420S'  /*Food in trachea causing asphyxiation, sequela*/
,'T17428D'  /*Food in trachea causing other injury, subsequent encounter*/
,'T17428S'  /*Food in trachea causing other injury, sequela*/
,'T17490D'  /*Other foreign object in trachea causing asphyxiation, subsequent encounter*/
,'T17490S'  /*Other foreign object in trachea causing asphyxiation, sequela*/
,'T17498D'  /*Other foreign object in trachea causing other injury, subsequent encounter*/
,'T17498S'  /*Other foreign object in trachea causing other injury, sequela*/
,'T17500D'  /*Unspecified foreign body in bronchus causing asphyxiation, subsequent encounter*/
,'T17500S'  /*Unspecified foreign body in bronchus causing asphyxiation, sequela*/
,'T17508D'  /*Unspecified foreign body in bronchus causing other injury, subsequent encounter*/
,'T17508S'  /*Unspecified foreign body in bronchus causing other injury, sequela*/
,'T17510D'  /*Gastric contents in bronchus causing asphyxiation, subsequent encounter*/
,'T17510S'  /*Gastric contents in bronchus causing asphyxiation, sequela*/
,'T17518D'  /*Gastric contents in bronchus causing other injury, subsequent encounter*/
,'T17518S'  /*Gastric contents in bronchus causing other injury, sequela*/
,'T17520D'  /*Food in bronchus causing asphyxiation, subsequent encounter*/
,'T17520S'  /*Food in bronchus causing asphyxiation, sequela*/
,'T17528D'  /*Food in bronchus causing other injury, subsequent encounter*/
,'T17528S'  /*Food in bronchus causing other injury, sequela*/
,'T17590D'  /*Other foreign object in bronchus causing asphyxiation, subsequent encounter*/
,'T17590S'  /*Other foreign object in bronchus causing asphyxiation, sequela*/
,'T17598D'  /*Other foreign object in bronchus causing other injury, subsequent encounter*/
,'T17598S'  /*Other foreign object in bronchus causing other injury, sequela*/
,'T17800D'  /*Unspecified foreign body in other parts of respiratory tract causing asphyxiation, subsequent encounter*/
,'T17800S'  /*Unspecified foreign body in other parts of respiratory tract causing asphyxiation, sequela*/
,'T17808D'  /*Unspecified foreign body in other parts of respiratory tract causing other injury, subsequent encounter*/
,'T17808S'  /*Unspecified foreign body in other parts of respiratory tract causing other injury, sequela*/
,'T17810D'  /*Gastric contents in other parts of respiratory tract causing asphyxiation, subsequent encounter*/
,'T17810S'  /*Gastric contents in other parts of respiratory tract causing asphyxiation, sequela*/
,'T17818D'  /*Gastric contents in other parts of respiratory tract causing other injury, subsequent encounter*/
,'T17818S'  /*Gastric contents in other parts of respiratory tract causing other injury, sequela*/
,'T17820D'  /*Food in other parts of respiratory tract causing asphyxiation, subsequent encounter*/
,'T17820S'  /*Food in other parts of respiratory tract causing asphyxiation, sequela*/
,'T17828D'  /*Food in other parts of respiratory tract causing other injury, subsequent encounter*/
,'T17828S'  /*Food in other parts of respiratory tract causing other injury, sequela*/
,'T17890D'  /*Other foreign object in other parts of respiratory tract causing asphyxiation, subsequent encounter*/
,'T17890S'  /*Other foreign object in other parts of respiratory tract causing asphyxiation, sequela*/
,'T17898D'  /*Other foreign object in other parts of respiratory tract causing other injury, subsequent encounter*/
,'T17898S'  /*Other foreign object in other parts of respiratory tract causing other injury, sequela*/
,'T17900D'  /*Unspecified foreign body in respiratory tract, part unspecified causing asphyxiation, subsequent encounter*/
,'T17900S'  /*Unspecified foreign body in respiratory tract, part unspecified causing asphyxiation, sequela*/
,'T17908D'  /*Unspecified foreign body in respiratory tract, part unspecified causing other injury, subsequent encounter*/
,'T17908S'  /*Unspecified foreign body in respiratory tract, part unspecified causing other injury, sequela*/
,'T17910D'  /*Gastric contents in respiratory tract, part unspecified causing asphyxiation, subsequent encounter*/
,'T17910S'  /*Gastric contents in respiratory tract, part unspecified causing asphyxiation, sequela*/
,'T17918D'  /*Gastric contents in respiratory tract, part unspecified causing other injury, subsequent encounter*/
,'T17918S'  /*Gastric contents in respiratory tract, part unspecified causing other injury, sequela*/
,'T17920D'  /*Food in respiratory tract, part unspecified causing asphyxiation, subsequent encounter*/
,'T17920S'  /*Food in respiratory tract, part unspecified causing asphyxiation, sequela*/
,'T17928D'  /*Food in respiratory tract, part unspecified causing other injury, subsequent encounter*/
,'T17928S'  /*Food in respiratory tract, part unspecified causing other injury, sequela*/
,'T17990D'  /*Other foreign object in respiratory tract, part unspecified in causing asphyxiation, subsequent encounter*/
,'T17990S'  /*Other foreign object in respiratory tract, part unspecified in causing asphyxiation, sequela*/
,'T17998D'  /*Other foreign object in respiratory tract, part unspecified causing other injury, subsequent encounter*/
,'T17998S'  /*Other foreign object in respiratory tract, part unspecified causing other injury, sequela*/
,'T180XXD'  /*Foreign body in mouth, subsequent encounter*/
,'T180XXS'  /*Foreign body in mouth, sequela*/
,'T18100D'  /*Unspecified foreign body in esophagus causing compression of trachea, subsequent encounter*/
,'T18100S'  /*Unspecified foreign body in esophagus causing compression of trachea, sequela*/
,'T18108D'  /*Unspecified foreign body in esophagus causing other injury, subsequent encounter*/
,'T18108S'  /*Unspecified foreign body in esophagus causing other injury, sequela*/
,'T18110D'  /*Gastric contents in esophagus causing compression of trachea, subsequent encounter*/
,'T18110S'  /*Gastric contents in esophagus causing compression of trachea, sequela*/
,'T18118D'  /*Gastric contents in esophagus causing other injury, subsequent encounter*/
,'T18118S'  /*Gastric contents in esophagus causing other injury, sequela*/
,'T18120D'  /*Food in esophagus causing compression of trachea, subsequent encounter*/
,'T18120S'  /*Food in esophagus causing compression of trachea, sequela*/
,'T18128D'  /*Food in esophagus causing other injury, subsequent encounter*/
,'T18128S'  /*Food in esophagus causing other injury, sequela*/
,'T18190D'  /*Other foreign object in esophagus causing compression of trachea, subsequent encounter*/
,'T18190S'  /*Other foreign object in esophagus causing compression of trachea, sequela*/
,'T18198D'  /*Other foreign object in esophagus causing other injury, subsequent encounter*/
,'T18198S'  /*Other foreign object in esophagus causing other injury, sequela*/
,'T182XXD'  /*Foreign body in stomach, subsequent encounter*/
,'T182XXS'  /*Foreign body in stomach, sequela*/
,'T183XXD'  /*Foreign body in small intestine, subsequent encounter*/
,'T183XXS'  /*Foreign body in small intestine, sequela*/
,'T184XXD'  /*Foreign body in colon, subsequent encounter*/
,'T184XXS'  /*Foreign body in colon, sequela*/
,'T185XXD'  /*Foreign body in anus and rectum, subsequent encounter*/
,'T185XXS'  /*Foreign body in anus and rectum, sequela*/
,'T188XXD'  /*Foreign body in other parts of alimentary tract, subsequent encounter*/
,'T188XXS'  /*Foreign body in other parts of alimentary tract, sequela*/
,'T189XXD'  /*Foreign body of alimentary tract, part unspecified, subsequent encounter*/
,'T189XXS'  /*Foreign body of alimentary tract, part unspecified, sequela*/
,'T190XXD'  /*Foreign body in urethra, subsequent encounter*/
,'T190XXS'  /*Foreign body in urethra, sequela*/
,'T191XXD'  /*Foreign body in bladder, subsequent encounter*/
,'T191XXS'  /*Foreign body in bladder, sequela*/
,'T192XXD'  /*Foreign body in vulva and vagina, subsequent encounter*/
,'T192XXS'  /*Foreign body in vulva and vagina, sequela*/
,'T193XXD'  /*Foreign body in uterus, subsequent encounter*/
,'T193XXS'  /*Foreign body in uterus, sequela*/
,'T194XXD'  /*Foreign body in penis, subsequent encounter*/
,'T194XXS'  /*Foreign body in penis, sequela*/
,'T198XXD'  /*Foreign body in other parts of genitourinary tract, subsequent encounter*/
,'T198XXS'  /*Foreign body in other parts of genitourinary tract, sequela*/
,'T199XXD'  /*Foreign body in genitourinary tract, part unspecified, subsequent encounter*/
,'T199XXS'  /*Foreign body in genitourinary tract, part unspecified, sequela*/
,'T2000XD'  /*Burn of unspecified degree of head, face, and neck, unspecified site, subsequent encounter*/
,'T2000XS'  /*Burn of unspecified degree of head, face, and neck, unspecified site, sequela*/
,'T20011D'  /*Burn of unspecified degree of right ear [any part, except ear drum], subsequent encounter*/
,'T20011S'  /*Burn of unspecified degree of right ear [any part, except ear drum], sequela*/
,'T20012D'  /*Burn of unspecified degree of left ear [any part, except ear drum], subsequent encounter*/
,'T20012S'  /*Burn of unspecified degree of left ear [any part, except ear drum], sequela*/
,'T20019D'  /*Burn of unspecified degree of unspecified ear [any part, except ear drum], subsequent encounter*/
,'T20019S'  /*Burn of unspecified degree of unspecified ear [any part, except ear drum], sequela*/
,'T2002XD'  /*Burn of unspecified degree of lip(s), subsequent encounter*/
,'T2002XS'  /*Burn of unspecified degree of lip(s), sequela*/
,'T2003XD'  /*Burn of unspecified degree of chin, subsequent encounter*/
,'T2003XS'  /*Burn of unspecified degree of chin, sequela*/
,'T2004XD'  /*Burn of unspecified degree of nose (septum), subsequent encounter*/
,'T2004XS'  /*Burn of unspecified degree of nose (septum), sequela*/
,'T2005XD'  /*Burn of unspecified degree of scalp [any part], subsequent encounter*/
,'T2005XS'  /*Burn of unspecified degree of scalp [any part], sequela*/
,'T2006XD'  /*Burn of unspecified degree of forehead and cheek, subsequent encounter*/
,'T2006XS'  /*Burn of unspecified degree of forehead and cheek, sequela*/
,'T2007XD'  /*Burn of unspecified degree of neck, subsequent encounter*/
,'T2007XS'  /*Burn of unspecified degree of neck, sequela*/
,'T2009XD'  /*Burn of unspecified degree of multiple sites of head, face, and neck, subsequent encounter*/
,'T2009XS'  /*Burn of unspecified degree of multiple sites of head, face, and neck, sequela*/
,'T2010XD'  /*Burn of first degree of head, face, and neck, unspecified site, subsequent encounter*/
,'T2010XS'  /*Burn of first degree of head, face, and neck, unspecified site, sequela*/
,'T20111D'  /*Burn of first degree of right ear [any part, except ear drum], subsequent encounter*/
,'T20111S'  /*Burn of first degree of right ear [any part, except ear drum], sequela*/
,'T20112D'  /*Burn of first degree of left ear [any part, except ear drum], subsequent encounter*/
,'T20112S'  /*Burn of first degree of left ear [any part, except ear drum], sequela*/
,'T20119D'  /*Burn of first degree of unspecified ear [any part, except ear drum], subsequent encounter*/
,'T20119S'  /*Burn of first degree of unspecified ear [any part, except ear drum], sequela*/
,'T2012XD'  /*Burn of first degree of lip(s), subsequent encounter*/
,'T2012XS'  /*Burn of first degree of lip(s), sequela*/
,'T2013XD'  /*Burn of first degree of chin, subsequent encounter*/
,'T2013XS'  /*Burn of first degree of chin, sequela*/
,'T2014XD'  /*Burn of first degree of nose (septum), subsequent encounter*/
,'T2014XS'  /*Burn of first degree of nose (septum), sequela*/
,'T2015XD'  /*Burn of first degree of scalp [any part], subsequent encounter*/
,'T2015XS'  /*Burn of first degree of scalp [any part], sequela*/
,'T2016XD'  /*Burn of first degree of forehead and cheek, subsequent encounter*/
,'T2016XS'  /*Burn of first degree of forehead and cheek, sequela*/
,'T2017XD'  /*Burn of first degree of neck, subsequent encounter*/
,'T2017XS'  /*Burn of first degree of neck, sequela*/
,'T2019XD'  /*Burn of first degree of multiple sites of head, face, and neck, subsequent encounter*/
,'T2019XS'  /*Burn of first degree of multiple sites of head, face, and neck, sequela*/
,'T2020XD'  /*Burn of second degree of head, face, and neck, unspecified site, subsequent encounter*/
,'T2020XS'  /*Burn of second degree of head, face, and neck, unspecified site, sequela*/
,'T20211D'  /*Burn of second degree of right ear [any part, except ear drum], subsequent encounter*/
,'T20211S'  /*Burn of second degree of right ear [any part, except ear drum], sequela*/
,'T20212D'  /*Burn of second degree of left ear [any part, except ear drum], subsequent encounter*/
,'T20212S'  /*Burn of second degree of left ear [any part, except ear drum], sequela*/
,'T20219D'  /*Burn of second degree of unspecified ear [any part, except ear drum], subsequent encounter*/
,'T20219S'  /*Burn of second degree of unspecified ear [any part, except ear drum], sequela*/
,'T2022XD'  /*Burn of second degree of lip(s), subsequent encounter*/
,'T2022XS'  /*Burn of second degree of lip(s), sequela*/
,'T2023XD'  /*Burn of second degree of chin, subsequent encounter*/
,'T2023XS'  /*Burn of second degree of chin, sequela*/
,'T2024XD'  /*Burn of second degree of nose (septum), subsequent encounter*/
,'T2024XS'  /*Burn of second degree of nose (septum), sequela*/
,'T2025XD'  /*Burn of second degree of scalp [any part], subsequent encounter*/
,'T2025XS'  /*Burn of second degree of scalp [any part], sequela*/
,'T2026XD'  /*Burn of second degree of forehead and cheek, subsequent encounter*/
,'T2026XS'  /*Burn of second degree of forehead and cheek, sequela*/
,'T2027XD'  /*Burn of second degree of neck, subsequent encounter*/
,'T2027XS'  /*Burn of second degree of neck, sequela*/
,'T2029XD'  /*Burn of second degree of multiple sites of head, face, and neck, subsequent encounter*/
,'T2029XS'  /*Burn of second degree of multiple sites of head, face, and neck, sequela*/
,'T2030XD'  /*Burn of third degree of head, face, and neck, unspecified site, subsequent encounter*/
,'T2030XS'  /*Burn of third degree of head, face, and neck, unspecified site, sequela*/
,'T20311D'  /*Burn of third degree of right ear [any part, except ear drum], subsequent encounter*/
,'T20311S'  /*Burn of third degree of right ear [any part, except ear drum], sequela*/
,'T20312D'  /*Burn of third degree of left ear [any part, except ear drum], subsequent encounter*/
,'T20312S'  /*Burn of third degree of left ear [any part, except ear drum], sequela*/
,'T20319D'  /*Burn of third degree of unspecified ear [any part, except ear drum], subsequent encounter*/
,'T20319S'  /*Burn of third degree of unspecified ear [any part, except ear drum], sequela*/
,'T2032XD'  /*Burn of third degree of lip(s), subsequent encounter*/
,'T2032XS'  /*Burn of third degree of lip(s), sequela*/
,'T2033XD'  /*Burn of third degree of chin, subsequent encounter*/
,'T2033XS'  /*Burn of third degree of chin, sequela*/
,'T2034XD'  /*Burn of third degree of nose (septum), subsequent encounter*/
,'T2034XS'  /*Burn of third degree of nose (septum), sequela*/
,'T2035XD'  /*Burn of third degree of scalp [any part], subsequent encounter*/
,'T2035XS'  /*Burn of third degree of scalp [any part], sequela*/
,'T2036XD'  /*Burn of third degree of forehead and cheek, subsequent encounter*/
,'T2036XS'  /*Burn of third degree of forehead and cheek, sequela*/
,'T2037XD'  /*Burn of third degree of neck, subsequent encounter*/
,'T2037XS'  /*Burn of third degree of neck, sequela*/
,'T2039XD'  /*Burn of third degree of multiple sites of head, face, and neck, subsequent encounter*/
,'T2039XS'  /*Burn of third degree of multiple sites of head, face, and neck, sequela*/
,'T2040XD'  /*Corrosion of unspecified degree of head, face, and neck, unspecified site, subsequent encounter*/
,'T2040XS'  /*Corrosion of unspecified degree of head, face, and neck, unspecified site, sequela*/
,'T20411D'  /*Corrosion of unspecified degree of right ear [any part, except ear drum], subsequent encounter*/
,'T20411S'  /*Corrosion of unspecified degree of right ear [any part, except ear drum], sequela*/
,'T20412D'  /*Corrosion of unspecified degree of left ear [any part, except ear drum], subsequent encounter*/
,'T20412S'  /*Corrosion of unspecified degree of left ear [any part, except ear drum], sequela*/
,'T20419D'  /*Corrosion of unspecified degree of unspecified ear [any part, except ear drum], subsequent encounter*/
,'T20419S'  /*Corrosion of unspecified degree of unspecified ear [any part, except ear drum], sequela*/
,'T2042XD'  /*Corrosion of unspecified degree of lip(s), subsequent encounter*/
,'T2042XS'  /*Corrosion of unspecified degree of lip(s), sequela*/
,'T2043XD'  /*Corrosion of unspecified degree of chin, subsequent encounter*/
,'T2043XS'  /*Corrosion of unspecified degree of chin, sequela*/
,'T2044XD'  /*Corrosion of unspecified degree of nose (septum), subsequent encounter*/
,'T2044XS'  /*Corrosion of unspecified degree of nose (septum), sequela*/
,'T2045XD'  /*Corrosion of unspecified degree of scalp [any part], subsequent encounter*/
,'T2045XS'  /*Corrosion of unspecified degree of scalp [any part], sequela*/
,'T2046XD'  /*Corrosion of unspecified degree of forehead and cheek, subsequent encounter*/
,'T2046XS'  /*Corrosion of unspecified degree of forehead and cheek, sequela*/
,'T2047XD'  /*Corrosion of unspecified degree of neck, subsequent encounter*/
,'T2047XS'  /*Corrosion of unspecified degree of neck, sequela*/
,'T2049XD'  /*Corrosion of unspecified degree of multiple sites of head, face, and neck, subsequent encounter*/
,'T2049XS'  /*Corrosion of unspecified degree of multiple sites of head, face, and neck, sequela*/
,'T2050XD'  /*Corrosion of first degree of head, face, and neck, unspecified site, subsequent encounter*/
,'T2050XS'  /*Corrosion of first degree of head, face, and neck, unspecified site, sequela*/
,'T20511D'  /*Corrosion of first degree of right ear [any part, except ear drum], subsequent encounter*/
,'T20511S'  /*Corrosion of first degree of right ear [any part, except ear drum], sequela*/
,'T20512D'  /*Corrosion of first degree of left ear [any part, except ear drum], subsequent encounter*/
,'T20512S'  /*Corrosion of first degree of left ear [any part, except ear drum], sequela*/
,'T20519D'  /*Corrosion of first degree of unspecified ear [any part, except ear drum], subsequent encounter*/
,'T20519S'  /*Corrosion of first degree of unspecified ear [any part, except ear drum], sequela*/
,'T2052XD'  /*Corrosion of first degree of lip(s), subsequent encounter*/
,'T2052XS'  /*Corrosion of first degree of lip(s), sequela*/
,'T2053XD'  /*Corrosion of first degree of chin, subsequent encounter*/
,'T2053XS'  /*Corrosion of first degree of chin, sequela*/
,'T2054XD'  /*Corrosion of first degree of nose (septum), subsequent encounter*/
,'T2054XS'  /*Corrosion of first degree of nose (septum), sequela*/
,'T2055XD'  /*Corrosion of first degree of scalp [any part], subsequent encounter*/
,'T2055XS'  /*Corrosion of first degree of scalp [any part], sequela*/
,'T2056XD'  /*Corrosion of first degree of forehead and cheek, subsequent encounter*/
,'T2056XS'  /*Corrosion of first degree of forehead and cheek, sequela*/
,'T2057XD'  /*Corrosion of first degree of neck, subsequent encounter*/
,'T2057XS'  /*Corrosion of first degree of neck, sequela*/
,'T2059XD'  /*Corrosion of first degree of multiple sites of head, face, and neck, subsequent encounter*/
,'T2059XS'  /*Corrosion of first degree of multiple sites of head, face, and neck, sequela*/
,'T2060XD'  /*Corrosion of second degree of head, face, and neck, unspecified site, subsequent encounter*/
,'T2060XS'  /*Corrosion of second degree of head, face, and neck, unspecified site, sequela*/
,'T20611D'  /*Corrosion of second degree of right ear [any part, except ear drum], subsequent encounter*/
,'T20611S'  /*Corrosion of second degree of right ear [any part, except ear drum], sequela*/
,'T20612D'  /*Corrosion of second degree of left ear [any part, except ear drum], subsequent encounter*/
,'T20612S'  /*Corrosion of second degree of left ear [any part, except ear drum], sequela*/
,'T20619D'  /*Corrosion of second degree of unspecified ear [any part, except ear drum], subsequent encounter*/
,'T20619S'  /*Corrosion of second degree of unspecified ear [any part, except ear drum], sequela*/
,'T2062XD'  /*Corrosion of second degree of lip(s), subsequent encounter*/
,'T2062XS'  /*Corrosion of second degree of lip(s), sequela*/
,'T2063XD'  /*Corrosion of second degree of chin, subsequent encounter*/
,'T2063XS'  /*Corrosion of second degree of chin, sequela*/
,'T2064XD'  /*Corrosion of second degree of nose (septum), subsequent encounter*/
,'T2064XS'  /*Corrosion of second degree of nose (septum), sequela*/
,'T2065XD'  /*Corrosion of second degree of scalp [any part], subsequent encounter*/
,'T2065XS'  /*Corrosion of second degree of scalp [any part], sequela*/
,'T2066XD'  /*Corrosion of second degree of forehead and cheek, subsequent encounter*/
,'T2066XS'  /*Corrosion of second degree of forehead and cheek, sequela*/
,'T2067XD'  /*Corrosion of second degree of neck, subsequent encounter*/
,'T2067XS'  /*Corrosion of second degree of neck, sequela*/
,'T2069XD'  /*Corrosion of second degree of multiple sites of head, face, and neck, subsequent encounter*/
,'T2069XS'  /*Corrosion of second degree of multiple sites of head, face, and neck, sequela*/
,'T2070XD'  /*Corrosion of third degree of head, face, and neck, unspecified site, subsequent encounter*/
,'T2070XS'  /*Corrosion of third degree of head, face, and neck, unspecified site, sequela*/
,'T20711D'  /*Corrosion of third degree of right ear [any part, except ear drum], subsequent encounter*/
,'T20711S'  /*Corrosion of third degree of right ear [any part, except ear drum], sequela*/
,'T20712D'  /*Corrosion of third degree of left ear [any part, except ear drum], subsequent encounter*/
,'T20712S'  /*Corrosion of third degree of left ear [any part, except ear drum], sequela*/
,'T20719D'  /*Corrosion of third degree of unspecified ear [any part, except ear drum], subsequent encounter*/
,'T20719S'  /*Corrosion of third degree of unspecified ear [any part, except ear drum], sequela*/
,'T2072XD'  /*Corrosion of third degree of lip(s), subsequent encounter*/
,'T2072XS'  /*Corrosion of third degree of lip(s), sequela*/
,'T2073XD'  /*Corrosion of third degree of chin, subsequent encounter*/
,'T2073XS'  /*Corrosion of third degree of chin, sequela*/
,'T2074XD'  /*Corrosion of third degree of nose (septum), subsequent encounter*/
,'T2074XS'  /*Corrosion of third degree of nose (septum), sequela*/
,'T2075XD'  /*Corrosion of third degree of scalp [any part], subsequent encounter*/
,'T2075XS'  /*Corrosion of third degree of scalp [any part], sequela*/
,'T2076XD'  /*Corrosion of third degree of forehead and cheek, subsequent encounter*/
,'T2076XS'  /*Corrosion of third degree of forehead and cheek, sequela*/
,'T2077XD'  /*Corrosion of third degree of neck, subsequent encounter*/
,'T2077XS'  /*Corrosion of third degree of neck, sequela*/
,'T2079XD'  /*Corrosion of third degree of multiple sites of head, face, and neck, subsequent encounter*/
,'T2079XS'  /*Corrosion of third degree of multiple sites of head, face, and neck, sequela*/
,'T2100XD'  /*Burn of unspecified degree of trunk, unspecified site, subsequent encounter*/
,'T2100XS'  /*Burn of unspecified degree of trunk, unspecified site, sequela*/
,'T2101XD'  /*Burn of unspecified degree of chest wall, subsequent encounter*/
,'T2101XS'  /*Burn of unspecified degree of chest wall, sequela*/
,'T2102XD'  /*Burn of unspecified degree of abdominal wall, subsequent encounter*/
,'T2102XS'  /*Burn of unspecified degree of abdominal wall, sequela*/
,'T2103XD'  /*Burn of unspecified degree of upper back, subsequent encounter*/
,'T2103XS'  /*Burn of unspecified degree of upper back, sequela*/
,'T2104XD'  /*Burn of unspecified degree of lower back, subsequent encounter*/
,'T2104XS'  /*Burn of unspecified degree of lower back, sequela*/
,'T2105XD'  /*Burn of unspecified degree of buttock, subsequent encounter*/
,'T2105XS'  /*Burn of unspecified degree of buttock, sequela*/
,'T2106XD'  /*Burn of unspecified degree of male genital region, subsequent encounter*/
,'T2106XS'  /*Burn of unspecified degree of male genital region, sequela*/
,'T2107XD'  /*Burn of unspecified degree of female genital region, subsequent encounter*/
,'T2107XS'  /*Burn of unspecified degree of female genital region, sequela*/
,'T2109XD'  /*Burn of unspecified degree of other site of trunk, subsequent encounter*/
,'T2109XS'  /*Burn of unspecified degree of other site of trunk, sequela*/
,'T2110XD'  /*Burn of first degree of trunk, unspecified site, subsequent encounter*/
,'T2110XS'  /*Burn of first degree of trunk, unspecified site, sequela*/
,'T2111XD'  /*Burn of first degree of chest wall, subsequent encounter*/
,'T2111XS'  /*Burn of first degree of chest wall, sequela*/
,'T2112XD'  /*Burn of first degree of abdominal wall, subsequent encounter*/
,'T2112XS'  /*Burn of first degree of abdominal wall, sequela*/
,'T2113XD'  /*Burn of first degree of upper back, subsequent encounter*/
,'T2113XS'  /*Burn of first degree of upper back, sequela*/
,'T2114XD'  /*Burn of first degree of lower back, subsequent encounter*/
,'T2114XS'  /*Burn of first degree of lower back, sequela*/
,'T2115XD'  /*Burn of first degree of buttock, subsequent encounter*/
,'T2115XS'  /*Burn of first degree of buttock, sequela*/
,'T2116XD'  /*Burn of first degree of male genital region, subsequent encounter*/
,'T2116XS'  /*Burn of first degree of male genital region, sequela*/
,'T2117XD'  /*Burn of first degree of female genital region, subsequent encounter*/
,'T2117XS'  /*Burn of first degree of female genital region, sequela*/
,'T2119XD'  /*Burn of first degree of other site of trunk, subsequent encounter*/
,'T2119XS'  /*Burn of first degree of other site of trunk, sequela*/
,'T2120XD'  /*Burn of second degree of trunk, unspecified site, subsequent encounter*/
,'T2120XS'  /*Burn of second degree of trunk, unspecified site, sequela*/
,'T2121XD'  /*Burn of second degree of chest wall, subsequent encounter*/
,'T2121XS'  /*Burn of second degree of chest wall, sequela*/
,'T2122XD'  /*Burn of second degree of abdominal wall, subsequent encounter*/
,'T2122XS'  /*Burn of second degree of abdominal wall, sequela*/
,'T2123XD'  /*Burn of second degree of upper back, subsequent encounter*/
,'T2123XS'  /*Burn of second degree of upper back, sequela*/
,'T2124XD'  /*Burn of second degree of lower back, subsequent encounter*/
,'T2124XS'  /*Burn of second degree of lower back, sequela*/
,'T2125XD'  /*Burn of second degree of buttock, subsequent encounter*/
,'T2125XS'  /*Burn of second degree of buttock, sequela*/
,'T2126XD'  /*Burn of second degree of male genital region, subsequent encounter*/
,'T2126XS'  /*Burn of second degree of male genital region, sequela*/
,'T2127XD'  /*Burn of second degree of female genital region, subsequent encounter*/
,'T2127XS'  /*Burn of second degree of female genital region, sequela*/
,'T2129XD'  /*Burn of second degree of other site of trunk, subsequent encounter*/
,'T2129XS'  /*Burn of second degree of other site of trunk, sequela*/
,'T2130XD'  /*Burn of third degree of trunk, unspecified site, subsequent encounter*/
,'T2130XS'  /*Burn of third degree of trunk, unspecified site, sequela*/
,'T2131XD'  /*Burn of third degree of chest wall, subsequent encounter*/
,'T2131XS'  /*Burn of third degree of chest wall, sequela*/
,'T2132XD'  /*Burn of third degree of abdominal wall, subsequent encounter*/
,'T2132XS'  /*Burn of third degree of abdominal wall, sequela*/
,'T2133XD'  /*Burn of third degree of upper back, subsequent encounter*/
,'T2133XS'  /*Burn of third degree of upper back, sequela*/
,'T2134XD'  /*Burn of third degree of lower back, subsequent encounter*/
,'T2134XS'  /*Burn of third degree of lower back, sequela*/
,'T2135XD'  /*Burn of third degree of buttock, subsequent encounter*/
,'T2135XS'  /*Burn of third degree of buttock, sequela*/
,'T2136XD'  /*Burn of third degree of male genital region, subsequent encounter*/
,'T2136XS'  /*Burn of third degree of male genital region, sequela*/
,'T2137XD'  /*Burn of third degree of female genital region, subsequent encounter*/
,'T2137XS'  /*Burn of third degree of female genital region, sequela*/
,'T2139XD'  /*Burn of third degree of other site of trunk, subsequent encounter*/
,'T2139XS'  /*Burn of third degree of other site of trunk, sequela*/
,'T2140XD'  /*Corrosion of unspecified degree of trunk, unspecified site, subsequent encounter*/
,'T2140XS'  /*Corrosion of unspecified degree of trunk, unspecified site, sequela*/
,'T2141XD'  /*Corrosion of unspecified degree of chest wall, subsequent encounter*/
,'T2141XS'  /*Corrosion of unspecified degree of chest wall, sequela*/
,'T2142XD'  /*Corrosion of unspecified degree of abdominal wall, subsequent encounter*/
,'T2142XS'  /*Corrosion of unspecified degree of abdominal wall, sequela*/
,'T2143XD'  /*Corrosion of unspecified degree of upper back, subsequent encounter*/
,'T2143XS'  /*Corrosion of unspecified degree of upper back, sequela*/
,'T2144XD'  /*Corrosion of unspecified degree of lower back, subsequent encounter*/
,'T2144XS'  /*Corrosion of unspecified degree of lower back, sequela*/
,'T2145XD'  /*Corrosion of unspecified degree of buttock, subsequent encounter*/
,'T2145XS'  /*Corrosion of unspecified degree of buttock, sequela*/
,'T2146XD'  /*Corrosion of unspecified degree of male genital region, subsequent encounter*/
,'T2146XS'  /*Corrosion of unspecified degree of male genital region, sequela*/
,'T2147XD'  /*Corrosion of unspecified degree of female genital region, subsequent encounter*/
,'T2147XS'  /*Corrosion of unspecified degree of female genital region, sequela*/
,'T2149XD'  /*Corrosion of unspecified degree of other site of trunk, subsequent encounter*/
,'T2149XS'  /*Corrosion of unspecified degree of other site of trunk, sequela*/
,'T2150XD'  /*Corrosion of first degree of trunk, unspecified site, subsequent encounter*/
,'T2150XS'  /*Corrosion of first degree of trunk, unspecified site, sequela*/
,'T2151XD'  /*Corrosion of first degree of chest wall, subsequent encounter*/
,'T2151XS'  /*Corrosion of first degree of chest wall, sequela*/
,'T2152XD'  /*Corrosion of first degree of abdominal wall, subsequent encounter*/
,'T2152XS'  /*Corrosion of first degree of abdominal wall, sequela*/
,'T2153XD'  /*Corrosion of first degree of upper back, subsequent encounter*/
,'T2153XS'  /*Corrosion of first degree of upper back, sequela*/
,'T2154XD'  /*Corrosion of first degree of lower back, subsequent encounter*/
,'T2154XS'  /*Corrosion of first degree of lower back, sequela*/
,'T2155XD'  /*Corrosion of first degree of buttock, subsequent encounter*/
,'T2155XS'  /*Corrosion of first degree of buttock, sequela*/
,'T2156XD'  /*Corrosion of first degree of male genital region, subsequent encounter*/
,'T2156XS'  /*Corrosion of first degree of male genital region, sequela*/
,'T2157XD'  /*Corrosion of first degree of female genital region, subsequent encounter*/
,'T2157XS'  /*Corrosion of first degree of female genital region, sequela*/
,'T2159XD'  /*Corrosion of first degree of other site of trunk, subsequent encounter*/
,'T2159XS'  /*Corrosion of first degree of other site of trunk, sequela*/
,'T2160XD'  /*Corrosion of second degree of trunk, unspecified site, subsequent encounter*/
,'T2160XS'  /*Corrosion of second degree of trunk, unspecified site, sequela*/
,'T2161XD'  /*Corrosion of second degree of chest wall, subsequent encounter*/
,'T2161XS'  /*Corrosion of second degree of chest wall, sequela*/
,'T2162XD'  /*Corrosion of second degree of abdominal wall, subsequent encounter*/
,'T2162XS'  /*Corrosion of second degree of abdominal wall, sequela*/
,'T2163XD'  /*Corrosion of second degree of upper back, subsequent encounter*/
,'T2163XS'  /*Corrosion of second degree of upper back, sequela*/
,'T2164XD'  /*Corrosion of second degree of lower back, subsequent encounter*/
,'T2164XS'  /*Corrosion of second degree of lower back, sequela*/
,'T2165XD'  /*Corrosion of second degree of buttock, subsequent encounter*/
,'T2165XS'  /*Corrosion of second degree of buttock, sequela*/
,'T2166XD'  /*Corrosion of second degree of male genital region, subsequent encounter*/
,'T2166XS'  /*Corrosion of second degree of male genital region, sequela*/
,'T2167XD'  /*Corrosion of second degree of female genital region, subsequent encounter*/
,'T2167XS'  /*Corrosion of second degree of female genital region, sequela*/
,'T2169XD'  /*Corrosion of second degree of other site of trunk, subsequent encounter*/
,'T2169XS'  /*Corrosion of second degree of other site of trunk, sequela*/
,'T2170XD'  /*Corrosion of third degree of trunk, unspecified site, subsequent encounter*/
,'T2170XS'  /*Corrosion of third degree of trunk, unspecified site, sequela*/
,'T2171XD'  /*Corrosion of third degree of chest wall, subsequent encounter*/
,'T2171XS'  /*Corrosion of third degree of chest wall, sequela*/
,'T2172XD'  /*Corrosion of third degree of abdominal wall, subsequent encounter*/
,'T2172XS'  /*Corrosion of third degree of abdominal wall, sequela*/
,'T2173XD'  /*Corrosion of third degree of upper back, subsequent encounter*/
,'T2173XS'  /*Corrosion of third degree of upper back, sequela*/
,'T2174XD'  /*Corrosion of third degree of lower back, subsequent encounter*/
,'T2174XS'  /*Corrosion of third degree of lower back, sequela*/
,'T2175XD'  /*Corrosion of third degree of buttock, subsequent encounter*/
,'T2175XS'  /*Corrosion of third degree of buttock, sequela*/
,'T2176XD'  /*Corrosion of third degree of male genital region, subsequent encounter*/
,'T2176XS'  /*Corrosion of third degree of male genital region, sequela*/
,'T2177XD'  /*Corrosion of third degree of female genital region, subsequent encounter*/
,'T2177XS'  /*Corrosion of third degree of female genital region, sequela*/
,'T2179XD'  /*Corrosion of third degree of other site of trunk, subsequent encounter*/
,'T2179XS'  /*Corrosion of third degree of other site of trunk, sequela*/
,'T2200XD'  /*Burn of unspecified degree of shoulder and upper limb, except wrist and hand, unspecified site, subsequent encounter*/
,'T2200XS'  /*Burn of unspecified degree of shoulder and upper limb, except wrist and hand, unspecified site, sequela*/
,'T22011D'  /*Burn of unspecified degree of right forearm, subsequent encounter*/
,'T22011S'  /*Burn of unspecified degree of right forearm, sequela*/
,'T22012D'  /*Burn of unspecified degree of left forearm, subsequent encounter*/
,'T22012S'  /*Burn of unspecified degree of left forearm, sequela*/
,'T22019D'  /*Burn of unspecified degree of unspecified forearm, subsequent encounter*/
,'T22019S'  /*Burn of unspecified degree of unspecified forearm, sequela*/
,'T22021D'  /*Burn of unspecified degree of right elbow, subsequent encounter*/
,'T22021S'  /*Burn of unspecified degree of right elbow, sequela*/
,'T22022D'  /*Burn of unspecified degree of left elbow, subsequent encounter*/
,'T22022S'  /*Burn of unspecified degree of left elbow, sequela*/
,'T22029D'  /*Burn of unspecified degree of unspecified elbow, subsequent encounter*/
,'T22029S'  /*Burn of unspecified degree of unspecified elbow, sequela*/
,'T22031D'  /*Burn of unspecified degree of right upper arm, subsequent encounter*/
,'T22031S'  /*Burn of unspecified degree of right upper arm, sequela*/
,'T22032D'  /*Burn of unspecified degree of left upper arm, subsequent encounter*/
,'T22032S'  /*Burn of unspecified degree of left upper arm, sequela*/
,'T22039D'  /*Burn of unspecified degree of unspecified upper arm, subsequent encounter*/
,'T22039S'  /*Burn of unspecified degree of unspecified upper arm, sequela*/
,'T22041D'  /*Burn of unspecified degree of right axilla, subsequent encounter*/
,'T22041S'  /*Burn of unspecified degree of right axilla, sequela*/
,'T22042D'  /*Burn of unspecified degree of left axilla, subsequent encounter*/
,'T22042S'  /*Burn of unspecified degree of left axilla, sequela*/
,'T22049D'  /*Burn of unspecified degree of unspecified axilla, subsequent encounter*/
,'T22049S'  /*Burn of unspecified degree of unspecified axilla, sequela*/
,'T22051D'  /*Burn of unspecified degree of right shoulder, subsequent encounter*/
,'T22051S'  /*Burn of unspecified degree of right shoulder, sequela*/
,'T22052D'  /*Burn of unspecified degree of left shoulder, subsequent encounter*/
,'T22052S'  /*Burn of unspecified degree of left shoulder, sequela*/
,'T22059D'  /*Burn of unspecified degree of unspecified shoulder, subsequent encounter*/
,'T22059S'  /*Burn of unspecified degree of unspecified shoulder, sequela*/
,'T22061D'  /*Burn of unspecified degree of right scapular region, subsequent encounter*/
,'T22061S'  /*Burn of unspecified degree of right scapular region, sequela*/
,'T22062D'  /*Burn of unspecified degree of left scapular region, subsequent encounter*/
,'T22062S'  /*Burn of unspecified degree of left scapular region, sequela*/
,'T22069D'  /*Burn of unspecified degree of unspecified scapular region, subsequent encounter*/
,'T22069S'  /*Burn of unspecified degree of unspecified scapular region, sequela*/
,'T22091D'  /*Burn of unspecified degree of multiple sites of right shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22091S'  /*Burn of unspecified degree of multiple sites of right shoulder and upper limb, except wrist and hand, sequela*/
,'T22092D'  /*Burn of unspecified degree of multiple sites of left shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22092S'  /*Burn of unspecified degree of multiple sites of left shoulder and upper limb, except wrist and hand, sequela*/
,'T22099D'  /*Burn of unspecified degree of multiple sites of unspecified shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22099S'  /*Burn of unspecified degree of multiple sites of unspecified shoulder and upper limb, except wrist and hand, sequela*/
,'T2210XD'  /*Burn of first degree of shoulder and upper limb, except wrist and hand, unspecified site, subsequent encounter*/
,'T2210XS'  /*Burn of first degree of shoulder and upper limb, except wrist and hand, unspecified site, sequela*/
,'T22111D'  /*Burn of first degree of right forearm, subsequent encounter*/
,'T22111S'  /*Burn of first degree of right forearm, sequela*/
,'T22112D'  /*Burn of first degree of left forearm, subsequent encounter*/
,'T22112S'  /*Burn of first degree of left forearm, sequela*/
,'T22119D'  /*Burn of first degree of unspecified forearm, subsequent encounter*/
,'T22119S'  /*Burn of first degree of unspecified forearm, sequela*/
,'T22121D'  /*Burn of first degree of right elbow, subsequent encounter*/
,'T22121S'  /*Burn of first degree of right elbow, sequela*/
,'T22122D'  /*Burn of first degree of left elbow, subsequent encounter*/
,'T22122S'  /*Burn of first degree of left elbow, sequela*/
,'T22129D'  /*Burn of first degree of unspecified elbow, subsequent encounter*/
,'T22129S'  /*Burn of first degree of unspecified elbow, sequela*/
,'T22131D'  /*Burn of first degree of right upper arm, subsequent encounter*/
,'T22131S'  /*Burn of first degree of right upper arm, sequela*/
,'T22132D'  /*Burn of first degree of left upper arm, subsequent encounter*/
,'T22132S'  /*Burn of first degree of left upper arm, sequela*/
,'T22139D'  /*Burn of first degree of unspecified upper arm, subsequent encounter*/
,'T22139S'  /*Burn of first degree of unspecified upper arm, sequela*/
,'T22141D'  /*Burn of first degree of right axilla, subsequent encounter*/
,'T22141S'  /*Burn of first degree of right axilla, sequela*/
,'T22142D'  /*Burn of first degree of left axilla, subsequent encounter*/
,'T22142S'  /*Burn of first degree of left axilla, sequela*/
,'T22149D'  /*Burn of first degree of unspecified axilla, subsequent encounter*/
,'T22149S'  /*Burn of first degree of unspecified axilla, sequela*/
,'T22151D'  /*Burn of first degree of right shoulder, subsequent encounter*/
,'T22151S'  /*Burn of first degree of right shoulder, sequela*/
,'T22152D'  /*Burn of first degree of left shoulder, subsequent encounter*/
,'T22152S'  /*Burn of first degree of left shoulder, sequela*/
,'T22159D'  /*Burn of first degree of unspecified shoulder, subsequent encounter*/
,'T22159S'  /*Burn of first degree of unspecified shoulder, sequela*/
,'T22161D'  /*Burn of first degree of right scapular region, subsequent encounter*/
,'T22161S'  /*Burn of first degree of right scapular region, sequela*/
,'T22162D'  /*Burn of first degree of left scapular region, subsequent encounter*/
,'T22162S'  /*Burn of first degree of left scapular region, sequela*/
,'T22169D'  /*Burn of first degree of unspecified scapular region, subsequent encounter*/
,'T22169S'  /*Burn of first degree of unspecified scapular region, sequela*/
,'T22191D'  /*Burn of first degree of multiple sites of right shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22191S'  /*Burn of first degree of multiple sites of right shoulder and upper limb, except wrist and hand, sequela*/
,'T22192D'  /*Burn of first degree of multiple sites of left shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22192S'  /*Burn of first degree of multiple sites of left shoulder and upper limb, except wrist and hand, sequela*/
,'T22199D'  /*Burn of first degree of multiple sites of unspecified shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22199S'  /*Burn of first degree of multiple sites of unspecified shoulder and upper limb, except wrist and hand, sequela*/
,'T2220XD'  /*Burn of second degree of shoulder and upper limb, except wrist and hand, unspecified site, subsequent encounter*/
,'T2220XS'  /*Burn of second degree of shoulder and upper limb, except wrist and hand, unspecified site, sequela*/
,'T22211D'  /*Burn of second degree of right forearm, subsequent encounter*/
,'T22211S'  /*Burn of second degree of right forearm, sequela*/
,'T22212D'  /*Burn of second degree of left forearm, subsequent encounter*/
,'T22212S'  /*Burn of second degree of left forearm, sequela*/
,'T22219D'  /*Burn of second degree of unspecified forearm, subsequent encounter*/
,'T22219S'  /*Burn of second degree of unspecified forearm, sequela*/
,'T22221D'  /*Burn of second degree of right elbow, subsequent encounter*/
,'T22221S'  /*Burn of second degree of right elbow, sequela*/
,'T22222D'  /*Burn of second degree of left elbow, subsequent encounter*/
,'T22222S'  /*Burn of second degree of left elbow, sequela*/
,'T22229D'  /*Burn of second degree of unspecified elbow, subsequent encounter*/
,'T22229S'  /*Burn of second degree of unspecified elbow, sequela*/
,'T22231D'  /*Burn of second degree of right upper arm, subsequent encounter*/
,'T22231S'  /*Burn of second degree of right upper arm, sequela*/
,'T22232D'  /*Burn of second degree of left upper arm, subsequent encounter*/
,'T22232S'  /*Burn of second degree of left upper arm, sequela*/
,'T22239D'  /*Burn of second degree of unspecified upper arm, subsequent encounter*/
,'T22239S'  /*Burn of second degree of unspecified upper arm, sequela*/
,'T22241D'  /*Burn of second degree of right axilla, subsequent encounter*/
,'T22241S'  /*Burn of second degree of right axilla, sequela*/
,'T22242D'  /*Burn of second degree of left axilla, subsequent encounter*/
,'T22242S'  /*Burn of second degree of left axilla, sequela*/
,'T22249D'  /*Burn of second degree of unspecified axilla, subsequent encounter*/
,'T22249S'  /*Burn of second degree of unspecified axilla, sequela*/
,'T22251D'  /*Burn of second degree of right shoulder, subsequent encounter*/
,'T22251S'  /*Burn of second degree of right shoulder, sequela*/
,'T22252D'  /*Burn of second degree of left shoulder, subsequent encounter*/
,'T22252S'  /*Burn of second degree of left shoulder, sequela*/
,'T22259D'  /*Burn of second degree of unspecified shoulder, subsequent encounter*/
,'T22259S'  /*Burn of second degree of unspecified shoulder, sequela*/
,'T22261D'  /*Burn of second degree of right scapular region, subsequent encounter*/
,'T22261S'  /*Burn of second degree of right scapular region, sequela*/
,'T22262D'  /*Burn of second degree of left scapular region, subsequent encounter*/
,'T22262S'  /*Burn of second degree of left scapular region, sequela*/
,'T22269D'  /*Burn of second degree of unspecified scapular region, subsequent encounter*/
,'T22269S'  /*Burn of second degree of unspecified scapular region, sequela*/
,'T22291D'  /*Burn of second degree of multiple sites of right shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22291S'  /*Burn of second degree of multiple sites of right shoulder and upper limb, except wrist and hand, sequela*/
,'T22292D'  /*Burn of second degree of multiple sites of left shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22292S'  /*Burn of second degree of multiple sites of left shoulder and upper limb, except wrist and hand, sequela*/
,'T22299D'  /*Burn of second degree of multiple sites of unspecified shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22299S'  /*Burn of second degree of multiple sites of unspecified shoulder and upper limb, except wrist and hand, sequela*/
,'T2230XD'  /*Burn of third degree of shoulder and upper limb, except wrist and hand, unspecified site, subsequent encounter*/
,'T2230XS'  /*Burn of third degree of shoulder and upper limb, except wrist and hand, unspecified site, sequela*/
,'T22311D'  /*Burn of third degree of right forearm, subsequent encounter*/
,'T22311S'  /*Burn of third degree of right forearm, sequela*/
,'T22312D'  /*Burn of third degree of left forearm, subsequent encounter*/
,'T22312S'  /*Burn of third degree of left forearm, sequela*/
,'T22319D'  /*Burn of third degree of unspecified forearm, subsequent encounter*/
,'T22319S'  /*Burn of third degree of unspecified forearm, sequela*/
,'T22321D'  /*Burn of third degree of right elbow, subsequent encounter*/
,'T22321S'  /*Burn of third degree of right elbow, sequela*/
,'T22322D'  /*Burn of third degree of left elbow, subsequent encounter*/
,'T22322S'  /*Burn of third degree of left elbow, sequela*/
,'T22329D'  /*Burn of third degree of unspecified elbow, subsequent encounter*/
,'T22329S'  /*Burn of third degree of unspecified elbow, sequela*/
,'T22331D'  /*Burn of third degree of right upper arm, subsequent encounter*/
,'T22331S'  /*Burn of third degree of right upper arm, sequela*/
,'T22332D'  /*Burn of third degree of left upper arm, subsequent encounter*/
,'T22332S'  /*Burn of third degree of left upper arm, sequela*/
,'T22339D'  /*Burn of third degree of unspecified upper arm, subsequent encounter*/
,'T22339S'  /*Burn of third degree of unspecified upper arm, sequela*/
,'T22341D'  /*Burn of third degree of right axilla, subsequent encounter*/
,'T22341S'  /*Burn of third degree of right axilla, sequela*/
,'T22342D'  /*Burn of third degree of left axilla, subsequent encounter*/
,'T22342S'  /*Burn of third degree of left axilla, sequela*/
,'T22349D'  /*Burn of third degree of unspecified axilla, subsequent encounter*/
,'T22349S'  /*Burn of third degree of unspecified axilla, sequela*/
,'T22351D'  /*Burn of third degree of right shoulder, subsequent encounter*/
,'T22351S'  /*Burn of third degree of right shoulder, sequela*/
,'T22352D'  /*Burn of third degree of left shoulder, subsequent encounter*/
,'T22352S'  /*Burn of third degree of left shoulder, sequela*/
,'T22359D'  /*Burn of third degree of unspecified shoulder, subsequent encounter*/
,'T22359S'  /*Burn of third degree of unspecified shoulder, sequela*/
,'T22361D'  /*Burn of third degree of right scapular region, subsequent encounter*/
,'T22361S'  /*Burn of third degree of right scapular region, sequela*/
,'T22362D'  /*Burn of third degree of left scapular region, subsequent encounter*/
,'T22362S'  /*Burn of third degree of left scapular region, sequela*/
,'T22369D'  /*Burn of third degree of unspecified scapular region, subsequent encounter*/
,'T22369S'  /*Burn of third degree of unspecified scapular region, sequela*/
,'T22391D'  /*Burn of third degree of multiple sites of right shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22391S'  /*Burn of third degree of multiple sites of right shoulder and upper limb, except wrist and hand, sequela*/
,'T22392D'  /*Burn of third degree of multiple sites of left shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22392S'  /*Burn of third degree of multiple sites of left shoulder and upper limb, except wrist and hand, sequela*/
,'T22399D'  /*Burn of third degree of multiple sites of unspecified shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22399S'  /*Burn of third degree of multiple sites of unspecified shoulder and upper limb, except wrist and hand, sequela*/
,'T2240XD'  /*Corrosion of unspecified degree of shoulder and upper limb, except wrist and hand, unspecified site, subsequent encounter*/
,'T2240XS'  /*Corrosion of unspecified degree of shoulder and upper limb, except wrist and hand, unspecified site, sequela*/
,'T22411D'  /*Corrosion of unspecified degree of right forearm, subsequent encounter*/
,'T22411S'  /*Corrosion of unspecified degree of right forearm, sequela*/
,'T22412D'  /*Corrosion of unspecified degree of left forearm, subsequent encounter*/
,'T22412S'  /*Corrosion of unspecified degree of left forearm, sequela*/
,'T22419D'  /*Corrosion of unspecified degree of unspecified forearm, subsequent encounter*/
,'T22419S'  /*Corrosion of unspecified degree of unspecified forearm, sequela*/
,'T22421D'  /*Corrosion of unspecified degree of right elbow, subsequent encounter*/
,'T22421S'  /*Corrosion of unspecified degree of right elbow, sequela*/
,'T22422D'  /*Corrosion of unspecified degree of left elbow, subsequent encounter*/
,'T22422S'  /*Corrosion of unspecified degree of left elbow, sequela*/
,'T22429D'  /*Corrosion of unspecified degree of unspecified elbow, subsequent encounter*/
,'T22429S'  /*Corrosion of unspecified degree of unspecified elbow, sequela*/
,'T22431D'  /*Corrosion of unspecified degree of right upper arm, subsequent encounter*/
,'T22431S'  /*Corrosion of unspecified degree of right upper arm, sequela*/
,'T22432D'  /*Corrosion of unspecified degree of left upper arm, subsequent encounter*/
,'T22432S'  /*Corrosion of unspecified degree of left upper arm, sequela*/
,'T22439D'  /*Corrosion of unspecified degree of unspecified upper arm, subsequent encounter*/
,'T22439S'  /*Corrosion of unspecified degree of unspecified upper arm, sequela*/
,'T22441D'  /*Corrosion of unspecified degree of right axilla, subsequent encounter*/
,'T22441S'  /*Corrosion of unspecified degree of right axilla, sequela*/
,'T22442D'  /*Corrosion of unspecified degree of left axilla, subsequent encounter*/
,'T22442S'  /*Corrosion of unspecified degree of left axilla, sequela*/
,'T22449D'  /*Corrosion of unspecified degree of unspecified axilla, subsequent encounter*/
,'T22449S'  /*Corrosion of unspecified degree of unspecified axilla, sequela*/
,'T22451D'  /*Corrosion of unspecified degree of right shoulder, subsequent encounter*/
,'T22451S'  /*Corrosion of unspecified degree of right shoulder, sequela*/
,'T22452D'  /*Corrosion of unspecified degree of left shoulder, subsequent encounter*/
,'T22452S'  /*Corrosion of unspecified degree of left shoulder, sequela*/
,'T22459D'  /*Corrosion of unspecified degree of unspecified shoulder, subsequent encounter*/
,'T22459S'  /*Corrosion of unspecified degree of unspecified shoulder, sequela*/
,'T22461D'  /*Corrosion of unspecified degree of right scapular region, subsequent encounter*/
,'T22461S'  /*Corrosion of unspecified degree of right scapular region, sequela*/
,'T22462D'  /*Corrosion of unspecified degree of left scapular region, subsequent encounter*/
,'T22462S'  /*Corrosion of unspecified degree of left scapular region, sequela*/
,'T22469D'  /*Corrosion of unspecified degree of unspecified scapular region, subsequent encounter*/
,'T22469S'  /*Corrosion of unspecified degree of unspecified scapular region, sequela*/
,'T22491D'  /*Corrosion of unspecified degree of multiple sites of right shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22491S'  /*Corrosion of unspecified degree of multiple sites of right shoulder and upper limb, except wrist and hand, sequela*/
,'T22492D'  /*Corrosion of unspecified degree of multiple sites of left shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22492S'  /*Corrosion of unspecified degree of multiple sites of left shoulder and upper limb, except wrist and hand, sequela*/
,'T22499D'  /*Corrosion of unspecified degree of multiple sites of unspecified shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22499S'  /*Corrosion of unspecified degree of multiple sites of unspecified shoulder and upper limb, except wrist and hand, sequela*/
,'T2250XD'  /*Corrosion of first degree of shoulder and upper limb, except wrist and hand unspecified site, subsequent encounter*/
,'T2250XS'  /*Corrosion of first degree of shoulder and upper limb, except wrist and hand unspecified site, sequela*/
,'T22511D'  /*Corrosion of first degree of right forearm, subsequent encounter*/
,'T22511S'  /*Corrosion of first degree of right forearm, sequela*/
,'T22512D'  /*Corrosion of first degree of left forearm, subsequent encounter*/
,'T22512S'  /*Corrosion of first degree of left forearm, sequela*/
,'T22519D'  /*Corrosion of first degree of unspecified forearm, subsequent encounter*/
,'T22519S'  /*Corrosion of first degree of unspecified forearm, sequela*/
,'T22521D'  /*Corrosion of first degree of right elbow, subsequent encounter*/
,'T22521S'  /*Corrosion of first degree of right elbow, sequela*/
,'T22522D'  /*Corrosion of first degree of left elbow, subsequent encounter*/
,'T22522S'  /*Corrosion of first degree of left elbow, sequela*/
,'T22529D'  /*Corrosion of first degree of unspecified elbow, subsequent encounter*/
,'T22529S'  /*Corrosion of first degree of unspecified elbow, sequela*/
,'T22531D'  /*Corrosion of first degree of right upper arm, subsequent encounter*/
,'T22531S'  /*Corrosion of first degree of right upper arm, sequela*/
,'T22532D'  /*Corrosion of first degree of left upper arm, subsequent encounter*/
,'T22532S'  /*Corrosion of first degree of left upper arm, sequela*/
,'T22539D'  /*Corrosion of first degree of unspecified upper arm, subsequent encounter*/
,'T22539S'  /*Corrosion of first degree of unspecified upper arm, sequela*/
,'T22541D'  /*Corrosion of first degree of right axilla, subsequent encounter*/
,'T22541S'  /*Corrosion of first degree of right axilla, sequela*/
,'T22542D'  /*Corrosion of first degree of left axilla, subsequent encounter*/
,'T22542S'  /*Corrosion of first degree of left axilla, sequela*/
,'T22549D'  /*Corrosion of first degree of unspecified axilla, subsequent encounter*/
,'T22549S'  /*Corrosion of first degree of unspecified axilla, sequela*/
,'T22551D'  /*Corrosion of first degree of right shoulder, subsequent encounter*/
,'T22551S'  /*Corrosion of first degree of right shoulder, sequela*/
,'T22552D'  /*Corrosion of first degree of left shoulder, subsequent encounter*/
,'T22552S'  /*Corrosion of first degree of left shoulder, sequela*/
,'T22559D'  /*Corrosion of first degree of unspecified shoulder, subsequent encounter*/
,'T22559S'  /*Corrosion of first degree of unspecified shoulder, sequela*/
,'T22561D'  /*Corrosion of first degree of right scapular region, subsequent encounter*/
,'T22561S'  /*Corrosion of first degree of right scapular region, sequela*/
,'T22562D'  /*Corrosion of first degree of left scapular region, subsequent encounter*/
,'T22562S'  /*Corrosion of first degree of left scapular region, sequela*/
,'T22569D'  /*Corrosion of first degree of unspecified scapular region, subsequent encounter*/
,'T22569S'  /*Corrosion of first degree of unspecified scapular region, sequela*/
,'T22591D'  /*Corrosion of first degree of multiple sites of right shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22591S'  /*Corrosion of first degree of multiple sites of right shoulder and upper limb, except wrist and hand, sequela*/
,'T22592D'  /*Corrosion of first degree of multiple sites of left shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22592S'  /*Corrosion of first degree of multiple sites of left shoulder and upper limb, except wrist and hand, sequela*/
,'T22599D'  /*Corrosion of first degree of multiple sites of unspecified shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22599S'  /*Corrosion of first degree of multiple sites of unspecified shoulder and upper limb, except wrist and hand, sequela*/
,'T2260XD'  /*Corrosion of second degree of shoulder and upper limb, except wrist and hand, unspecified site, subsequent encounter*/
,'T2260XS'  /*Corrosion of second degree of shoulder and upper limb, except wrist and hand, unspecified site, sequela*/
,'T22611D'  /*Corrosion of second degree of right forearm, subsequent encounter*/
,'T22611S'  /*Corrosion of second degree of right forearm, sequela*/
,'T22612D'  /*Corrosion of second degree of left forearm, subsequent encounter*/
,'T22612S'  /*Corrosion of second degree of left forearm, sequela*/
,'T22619D'  /*Corrosion of second degree of unspecified forearm, subsequent encounter*/
,'T22619S'  /*Corrosion of second degree of unspecified forearm, sequela*/
,'T22621D'  /*Corrosion of second degree of right elbow, subsequent encounter*/
,'T22621S'  /*Corrosion of second degree of right elbow, sequela*/
,'T22622D'  /*Corrosion of second degree of left elbow, subsequent encounter*/
,'T22622S'  /*Corrosion of second degree of left elbow, sequela*/
,'T22629D'  /*Corrosion of second degree of unspecified elbow, subsequent encounter*/
,'T22629S'  /*Corrosion of second degree of unspecified elbow, sequela*/
,'T22631D'  /*Corrosion of second degree of right upper arm, subsequent encounter*/
,'T22631S'  /*Corrosion of second degree of right upper arm, sequela*/
,'T22632D'  /*Corrosion of second degree of left upper arm, subsequent encounter*/
,'T22632S'  /*Corrosion of second degree of left upper arm, sequela*/
,'T22639D'  /*Corrosion of second degree of unspecified upper arm, subsequent encounter*/
,'T22639S'  /*Corrosion of second degree of unspecified upper arm, sequela*/
,'T22641D'  /*Corrosion of second degree of right axilla, subsequent encounter*/
,'T22641S'  /*Corrosion of second degree of right axilla, sequela*/
,'T22642D'  /*Corrosion of second degree of left axilla, subsequent encounter*/
,'T22642S'  /*Corrosion of second degree of left axilla, sequela*/
,'T22649D'  /*Corrosion of second degree of unspecified axilla, subsequent encounter*/
,'T22649S'  /*Corrosion of second degree of unspecified axilla, sequela*/
,'T22651D'  /*Corrosion of second degree of right shoulder, subsequent encounter*/
,'T22651S'  /*Corrosion of second degree of right shoulder, sequela*/
,'T22652D'  /*Corrosion of second degree of left shoulder, subsequent encounter*/
,'T22652S'  /*Corrosion of second degree of left shoulder, sequela*/
,'T22659D'  /*Corrosion of second degree of unspecified shoulder, subsequent encounter*/
,'T22659S'  /*Corrosion of second degree of unspecified shoulder, sequela*/
,'T22661D'  /*Corrosion of second degree of right scapular region, subsequent encounter*/
,'T22661S'  /*Corrosion of second degree of right scapular region, sequela*/
,'T22662D'  /*Corrosion of second degree of left scapular region, subsequent encounter*/
,'T22662S'  /*Corrosion of second degree of left scapular region, sequela*/
,'T22669D'  /*Corrosion of second degree of unspecified scapular region, subsequent encounter*/
,'T22669S'  /*Corrosion of second degree of unspecified scapular region, sequela*/
,'T22691D'  /*Corrosion of second degree of multiple sites of right shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22691S'  /*Corrosion of second degree of multiple sites of right shoulder and upper limb, except wrist and hand, sequela*/
,'T22692D'  /*Corrosion of second degree of multiple sites of left shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22692S'  /*Corrosion of second degree of multiple sites of left shoulder and upper limb, except wrist and hand, sequela*/
,'T22699D'  /*Corrosion of second degree of multiple sites of unspecified shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22699S'  /*Corrosion of second degree of multiple sites of unspecified shoulder and upper limb, except wrist and hand, sequela*/
,'T2270XD'  /*Corrosion of third degree of shoulder and upper limb, except wrist and hand, unspecified site, subsequent encounter*/
,'T2270XS'  /*Corrosion of third degree of shoulder and upper limb, except wrist and hand, unspecified site, sequela*/
,'T22711D'  /*Corrosion of third degree of right forearm, subsequent encounter*/
,'T22711S'  /*Corrosion of third degree of right forearm, sequela*/
,'T22712D'  /*Corrosion of third degree of left forearm, subsequent encounter*/
,'T22712S'  /*Corrosion of third degree of left forearm, sequela*/
,'T22719D'  /*Corrosion of third degree of unspecified forearm, subsequent encounter*/
,'T22719S'  /*Corrosion of third degree of unspecified forearm, sequela*/
,'T22721D'  /*Corrosion of third degree of right elbow, subsequent encounter*/
,'T22721S'  /*Corrosion of third degree of right elbow, sequela*/
,'T22722D'  /*Corrosion of third degree of left elbow, subsequent encounter*/
,'T22722S'  /*Corrosion of third degree of left elbow, sequela*/
,'T22729D'  /*Corrosion of third degree of unspecified elbow, subsequent encounter*/
,'T22729S'  /*Corrosion of third degree of unspecified elbow, sequela*/
,'T22731D'  /*Corrosion of third degree of right upper arm, subsequent encounter*/
,'T22731S'  /*Corrosion of third degree of right upper arm, sequela*/
,'T22732D'  /*Corrosion of third degree of left upper arm, subsequent encounter*/
,'T22732S'  /*Corrosion of third degree of left upper arm, sequela*/
,'T22739D'  /*Corrosion of third degree of unspecified upper arm, subsequent encounter*/
,'T22739S'  /*Corrosion of third degree of unspecified upper arm, sequela*/
,'T22741D'  /*Corrosion of third degree of right axilla, subsequent encounter*/
,'T22741S'  /*Corrosion of third degree of right axilla, sequela*/
,'T22742D'  /*Corrosion of third degree of left axilla, subsequent encounter*/
,'T22742S'  /*Corrosion of third degree of left axilla, sequela*/
,'T22749D'  /*Corrosion of third degree of unspecified axilla, subsequent encounter*/
,'T22749S'  /*Corrosion of third degree of unspecified axilla, sequela*/
,'T22751D'  /*Corrosion of third degree of right shoulder, subsequent encounter*/
,'T22751S'  /*Corrosion of third degree of right shoulder, sequela*/
,'T22752D'  /*Corrosion of third degree of left shoulder, subsequent encounter*/
,'T22752S'  /*Corrosion of third degree of left shoulder, sequela*/
,'T22759D'  /*Corrosion of third degree of unspecified shoulder, subsequent encounter*/
,'T22759S'  /*Corrosion of third degree of unspecified shoulder, sequela*/
,'T22761D'  /*Corrosion of third degree of right scapular region, subsequent encounter*/
,'T22761S'  /*Corrosion of third degree of right scapular region, sequela*/
,'T22762D'  /*Corrosion of third degree of left scapular region, subsequent encounter*/
,'T22762S'  /*Corrosion of third degree of left scapular region, sequela*/
,'T22769D'  /*Corrosion of third degree of unspecified scapular region, subsequent encounter*/
,'T22769S'  /*Corrosion of third degree of unspecified scapular region, sequela*/
,'T22791D'  /*Corrosion of third degree of multiple sites of right shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22791S'  /*Corrosion of third degree of multiple sites of right shoulder and upper limb, except wrist and hand, sequela*/
,'T22792D'  /*Corrosion of third degree of multiple sites of left shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22792S'  /*Corrosion of third degree of multiple sites of left shoulder and upper limb, except wrist and hand, sequela*/
,'T22799D'  /*Corrosion of third degree of multiple sites of unspecified shoulder and upper limb, except wrist and hand, subsequent encounter*/
,'T22799S'  /*Corrosion of third degree of multiple sites of unspecified shoulder and upper limb, except wrist and hand, sequela*/
,'T23001D'  /*Burn of unspecified degree of right hand, unspecified site, subsequent encounter*/
,'T23001S'  /*Burn of unspecified degree of right hand, unspecified site, sequela*/
,'T23002D'  /*Burn of unspecified degree of left hand, unspecified site, subsequent encounter*/
,'T23002S'  /*Burn of unspecified degree of left hand, unspecified site, sequela*/
,'T23009D'  /*Burn of unspecified degree of unspecified hand, unspecified site, subsequent encounter*/
,'T23009S'  /*Burn of unspecified degree of unspecified hand, unspecified site, sequela*/
,'T23011D'  /*Burn of unspecified degree of right thumb (nail), subsequent encounter*/
,'T23011S'  /*Burn of unspecified degree of right thumb (nail), sequela*/
,'T23012D'  /*Burn of unspecified degree of left thumb (nail), subsequent encounter*/
,'T23012S'  /*Burn of unspecified degree of left thumb (nail), sequela*/
,'T23019D'  /*Burn of unspecified degree of unspecified thumb (nail), subsequent encounter*/
,'T23019S'  /*Burn of unspecified degree of unspecified thumb (nail), sequela*/
,'T23021D'  /*Burn of unspecified degree of single right finger (nail) except thumb, subsequent encounter*/
,'T23021S'  /*Burn of unspecified degree of single right finger (nail) except thumb, sequela*/
,'T23022D'  /*Burn of unspecified degree of single left finger (nail) except thumb, subsequent encounter*/
,'T23022S'  /*Burn of unspecified degree of single left finger (nail) except thumb, sequela*/
,'T23029D'  /*Burn of unspecified degree of unspecified single finger (nail) except thumb, subsequent encounter*/
,'T23029S'  /*Burn of unspecified degree of unspecified single finger (nail) except thumb, sequela*/
,'T23031D'  /*Burn of unspecified degree of multiple right fingers (nail), not including thumb, subsequent encounter*/
,'T23031S'  /*Burn of unspecified degree of multiple right fingers (nail), not including thumb, sequela*/
,'T23032D'  /*Burn of unspecified degree of multiple left fingers (nail), not including thumb, subsequent encounter*/
,'T23032S'  /*Burn of unspecified degree of multiple left fingers (nail), not including thumb, sequela*/
,'T23039D'  /*Burn of unspecified degree of unspecified multiple fingers (nail), not including thumb, subsequent encounter*/
,'T23039S'  /*Burn of unspecified degree of unspecified multiple fingers (nail), not including thumb, sequela*/
,'T23041D'  /*Burn of unspecified degree of multiple right fingers (nail), including thumb, subsequent encounter*/
,'T23041S'  /*Burn of unspecified degree of multiple right fingers (nail), including thumb, sequela*/
,'T23042D'  /*Burn of unspecified degree of multiple left fingers (nail), including thumb, subsequent encounter*/
,'T23042S'  /*Burn of unspecified degree of multiple left fingers (nail), including thumb, sequela*/
,'T23049D'  /*Burn of unspecified degree of unspecified multiple fingers (nail), including thumb, subsequent encounter*/
,'T23049S'  /*Burn of unspecified degree of unspecified multiple fingers (nail), including thumb, sequela*/
,'T23051D'  /*Burn of unspecified degree of right palm, subsequent encounter*/
,'T23051S'  /*Burn of unspecified degree of right palm, sequela*/
,'T23052D'  /*Burn of unspecified degree of left palm, subsequent encounter*/
,'T23052S'  /*Burn of unspecified degree of left palm, sequela*/
,'T23059D'  /*Burn of unspecified degree of unspecified palm, subsequent encounter*/
,'T23059S'  /*Burn of unspecified degree of unspecified palm, sequela*/
,'T23061D'  /*Burn of unspecified degree of back of right hand, subsequent encounter*/
,'T23061S'  /*Burn of unspecified degree of back of right hand, sequela*/
,'T23062D'  /*Burn of unspecified degree of back of left hand, subsequent encounter*/
,'T23062S'  /*Burn of unspecified degree of back of left hand, sequela*/
,'T23069D'  /*Burn of unspecified degree of back of unspecified hand, subsequent encounter*/
,'T23069S'  /*Burn of unspecified degree of back of unspecified hand, sequela*/
,'T23071D'  /*Burn of unspecified degree of right wrist, subsequent encounter*/
,'T23071S'  /*Burn of unspecified degree of right wrist, sequela*/
,'T23072D'  /*Burn of unspecified degree of left wrist, subsequent encounter*/
,'T23072S'  /*Burn of unspecified degree of left wrist, sequela*/
,'T23079D'  /*Burn of unspecified degree of unspecified wrist, subsequent encounter*/
,'T23079S'  /*Burn of unspecified degree of unspecified wrist, sequela*/
,'T23091D'  /*Burn of unspecified degree of multiple sites of right wrist and hand, subsequent encounter*/
,'T23091S'  /*Burn of unspecified degree of multiple sites of right wrist and hand, sequela*/
,'T23092D'  /*Burn of unspecified degree of multiple sites of left wrist and hand, subsequent encounter*/
,'T23092S'  /*Burn of unspecified degree of multiple sites of left wrist and hand, sequela*/
,'T23099D'  /*Burn of unspecified degree of multiple sites of unspecified wrist and hand, subsequent encounter*/
,'T23099S'  /*Burn of unspecified degree of multiple sites of unspecified wrist and hand, sequela*/
,'T23101D'  /*Burn of first degree of right hand, unspecified site, subsequent encounter*/
,'T23101S'  /*Burn of first degree of right hand, unspecified site, sequela*/
,'T23102D'  /*Burn of first degree of left hand, unspecified site, subsequent encounter*/
,'T23102S'  /*Burn of first degree of left hand, unspecified site, sequela*/
,'T23109D'  /*Burn of first degree of unspecified hand, unspecified site, subsequent encounter*/
,'T23109S'  /*Burn of first degree of unspecified hand, unspecified site, sequela*/
,'T23111D'  /*Burn of first degree of right thumb (nail), subsequent encounter*/
,'T23111S'  /*Burn of first degree of right thumb (nail), sequela*/
,'T23112D'  /*Burn of first degree of left thumb (nail), subsequent encounter*/
,'T23112S'  /*Burn of first degree of left thumb (nail), sequela*/
,'T23119D'  /*Burn of first degree of unspecified thumb (nail), subsequent encounter*/
,'T23119S'  /*Burn of first degree of unspecified thumb (nail), sequela*/
,'T23121D'  /*Burn of first degree of single right finger (nail) except thumb, subsequent encounter*/
,'T23121S'  /*Burn of first degree of single right finger (nail) except thumb, sequela*/
,'T23122D'  /*Burn of first degree of single left finger (nail) except thumb, subsequent encounter*/
,'T23122S'  /*Burn of first degree of single left finger (nail) except thumb, sequela*/
,'T23129D'  /*Burn of first degree of unspecified single finger (nail) except thumb, subsequent encounter*/
,'T23129S'  /*Burn of first degree of unspecified single finger (nail) except thumb, sequela*/
,'T23131D'  /*Burn of first degree of multiple right fingers (nail), not including thumb, subsequent encounter*/
,'T23131S'  /*Burn of first degree of multiple right fingers (nail), not including thumb, sequela*/
,'T23132D'  /*Burn of first degree of multiple left fingers (nail), not including thumb, subsequent encounter*/
,'T23132S'  /*Burn of first degree of multiple left fingers (nail), not including thumb, sequela*/
,'T23139D'  /*Burn of first degree of unspecified multiple fingers (nail), not including thumb, subsequent encounter*/
,'T23139S'  /*Burn of first degree of unspecified multiple fingers (nail), not including thumb, sequela*/
,'T23141D'  /*Burn of first degree of multiple right fingers (nail), including thumb, subsequent encounter*/
,'T23141S'  /*Burn of first degree of multiple right fingers (nail), including thumb, sequela*/
,'T23142D'  /*Burn of first degree of multiple left fingers (nail), including thumb, subsequent encounter*/
,'T23142S'  /*Burn of first degree of multiple left fingers (nail), including thumb, sequela*/
,'T23149D'  /*Burn of first degree of unspecified multiple fingers (nail), including thumb, subsequent encounter*/
,'T23149S'  /*Burn of first degree of unspecified multiple fingers (nail), including thumb, sequela*/
,'T23151D'  /*Burn of first degree of right palm, subsequent encounter*/
,'T23151S'  /*Burn of first degree of right palm, sequela*/
,'T23152D'  /*Burn of first degree of left palm, subsequent encounter*/
,'T23152S'  /*Burn of first degree of left palm, sequela*/
,'T23159D'  /*Burn of first degree of unspecified palm, subsequent encounter*/
,'T23159S'  /*Burn of first degree of unspecified palm, sequela*/
,'T23161D'  /*Burn of first degree of back of right hand, subsequent encounter*/
,'T23161S'  /*Burn of first degree of back of right hand, sequela*/
,'T23162D'  /*Burn of first degree of back of left hand, subsequent encounter*/
,'T23162S'  /*Burn of first degree of back of left hand, sequela*/
,'T23169D'  /*Burn of first degree of back of unspecified hand, subsequent encounter*/
,'T23169S'  /*Burn of first degree of back of unspecified hand, sequela*/
,'T23171D'  /*Burn of first degree of right wrist, subsequent encounter*/
,'T23171S'  /*Burn of first degree of right wrist, sequela*/
,'T23172D'  /*Burn of first degree of left wrist, subsequent encounter*/
,'T23172S'  /*Burn of first degree of left wrist, sequela*/
,'T23179D'  /*Burn of first degree of unspecified wrist, subsequent encounter*/
,'T23179S'  /*Burn of first degree of unspecified wrist, sequela*/
,'T23191D'  /*Burn of first degree of multiple sites of right wrist and hand, subsequent encounter*/
,'T23191S'  /*Burn of first degree of multiple sites of right wrist and hand, sequela*/
,'T23192D'  /*Burn of first degree of multiple sites of left wrist and hand, subsequent encounter*/
,'T23192S'  /*Burn of first degree of multiple sites of left wrist and hand, sequela*/
,'T23199D'  /*Burn of first degree of multiple sites of unspecified wrist and hand, subsequent encounter*/
,'T23199S'  /*Burn of first degree of multiple sites of unspecified wrist and hand, sequela*/
,'T23201D'  /*Burn of second degree of right hand, unspecified site, subsequent encounter*/
,'T23201S'  /*Burn of second degree of right hand, unspecified site, sequela*/
,'T23202D'  /*Burn of second degree of left hand, unspecified site, subsequent encounter*/
,'T23202S'  /*Burn of second degree of left hand, unspecified site, sequela*/
,'T23209D'  /*Burn of second degree of unspecified hand, unspecified site, subsequent encounter*/
,'T23209S'  /*Burn of second degree of unspecified hand, unspecified site, sequela*/
,'T23211D'  /*Burn of second degree of right thumb (nail), subsequent encounter*/
,'T23211S'  /*Burn of second degree of right thumb (nail), sequela*/
,'T23212D'  /*Burn of second degree of left thumb (nail), subsequent encounter*/
,'T23212S'  /*Burn of second degree of left thumb (nail), sequela*/
,'T23219D'  /*Burn of second degree of unspecified thumb (nail), subsequent encounter*/
,'T23219S'  /*Burn of second degree of unspecified thumb (nail), sequela*/
,'T23221D'  /*Burn of second degree of single right finger (nail) except thumb, subsequent encounter*/
,'T23221S'  /*Burn of second degree of single right finger (nail) except thumb, sequela*/
,'T23222D'  /*Burn of second degree of single left finger (nail) except thumb, subsequent encounter*/
,'T23222S'  /*Burn of second degree of single left finger (nail) except thumb, sequela*/
,'T23229D'  /*Burn of second degree of unspecified single finger (nail) except thumb, subsequent encounter*/
,'T23229S'  /*Burn of second degree of unspecified single finger (nail) except thumb, sequela*/
,'T23231D'  /*Burn of second degree of multiple right fingers (nail), not including thumb, subsequent encounter*/
,'T23231S'  /*Burn of second degree of multiple right fingers (nail), not including thumb, sequela*/
,'T23232D'  /*Burn of second degree of multiple left fingers (nail), not including thumb, subsequent encounter*/
,'T23232S'  /*Burn of second degree of multiple left fingers (nail), not including thumb, sequela*/
,'T23239D'  /*Burn of second degree of unspecified multiple fingers (nail), not including thumb, subsequent encounter*/
,'T23239S'  /*Burn of second degree of unspecified multiple fingers (nail), not including thumb, sequela*/
,'T23241D'  /*Burn of second degree of multiple right fingers (nail), including thumb, subsequent encounter*/
,'T23241S'  /*Burn of second degree of multiple right fingers (nail), including thumb, sequela*/
,'T23242D'  /*Burn of second degree of multiple left fingers (nail), including thumb, subsequent encounter*/
,'T23242S'  /*Burn of second degree of multiple left fingers (nail), including thumb, sequela*/
,'T23249D'  /*Burn of second degree of unspecified multiple fingers (nail), including thumb, subsequent encounter*/
,'T23249S'  /*Burn of second degree of unspecified multiple fingers (nail), including thumb, sequela*/
,'T23251D'  /*Burn of second degree of right palm, subsequent encounter*/
,'T23251S'  /*Burn of second degree of right palm, sequela*/
,'T23252D'  /*Burn of second degree of left palm, subsequent encounter*/
,'T23252S'  /*Burn of second degree of left palm, sequela*/
,'T23259D'  /*Burn of second degree of unspecified palm, subsequent encounter*/
,'T23259S'  /*Burn of second degree of unspecified palm, sequela*/
,'T23261D'  /*Burn of second degree of back of right hand, subsequent encounter*/
,'T23261S'  /*Burn of second degree of back of right hand, sequela*/
,'T23262D'  /*Burn of second degree of back of left hand, subsequent encounter*/
,'T23262S'  /*Burn of second degree of back of left hand, sequela*/
,'T23269D'  /*Burn of second degree of back of unspecified hand, subsequent encounter*/
,'T23269S'  /*Burn of second degree of back of unspecified hand, sequela*/
,'T23271D'  /*Burn of second degree of right wrist, subsequent encounter*/
,'T23271S'  /*Burn of second degree of right wrist, sequela*/
,'T23272D'  /*Burn of second degree of left wrist, subsequent encounter*/
,'T23272S'  /*Burn of second degree of left wrist, sequela*/
,'T23279D'  /*Burn of second degree of unspecified wrist, subsequent encounter*/
,'T23279S'  /*Burn of second degree of unspecified wrist, sequela*/
,'T23291D'  /*Burn of second degree of multiple sites of right wrist and hand, subsequent encounter*/
,'T23291S'  /*Burn of second degree of multiple sites of right wrist and hand, sequela*/
,'T23292D'  /*Burn of second degree of multiple sites of left wrist and hand, subsequent encounter*/
,'T23292S'  /*Burn of second degree of multiple sites of left wrist and hand, sequela*/
,'T23299D'  /*Burn of second degree of multiple sites of unspecified wrist and hand, subsequent encounter*/
,'T23299S'  /*Burn of second degree of multiple sites of unspecified wrist and hand, sequela*/
,'T23301D'  /*Burn of third degree of right hand, unspecified site, subsequent encounter*/
,'T23301S'  /*Burn of third degree of right hand, unspecified site, sequela*/
,'T23302D'  /*Burn of third degree of left hand, unspecified site, subsequent encounter*/
,'T23302S'  /*Burn of third degree of left hand, unspecified site, sequela*/
,'T23309D'  /*Burn of third degree of unspecified hand, unspecified site, subsequent encounter*/
,'T23309S'  /*Burn of third degree of unspecified hand, unspecified site, sequela*/
,'T23311D'  /*Burn of third degree of right thumb (nail), subsequent encounter*/
,'T23311S'  /*Burn of third degree of right thumb (nail), sequela*/
,'T23312D'  /*Burn of third degree of left thumb (nail), subsequent encounter*/
,'T23312S'  /*Burn of third degree of left thumb (nail), sequela*/
,'T23319D'  /*Burn of third degree of unspecified thumb (nail), subsequent encounter*/
,'T23319S'  /*Burn of third degree of unspecified thumb (nail), sequela*/
,'T23321D'  /*Burn of third degree of single right finger (nail) except thumb, subsequent encounter*/
,'T23321S'  /*Burn of third degree of single right finger (nail) except thumb, sequela*/
,'T23322D'  /*Burn of third degree of single left finger (nail) except thumb, subsequent encounter*/
,'T23322S'  /*Burn of third degree of single left finger (nail) except thumb, sequela*/
,'T23329D'  /*Burn of third degree of unspecified single finger (nail) except thumb, subsequent encounter*/
,'T23329S'  /*Burn of third degree of unspecified single finger (nail) except thumb, sequela*/
,'T23331D'  /*Burn of third degree of multiple right fingers (nail), not including thumb, subsequent encounter*/
,'T23331S'  /*Burn of third degree of multiple right fingers (nail), not including thumb, sequela*/
,'T23332D'  /*Burn of third degree of multiple left fingers (nail), not including thumb, subsequent encounter*/
,'T23332S'  /*Burn of third degree of multiple left fingers (nail), not including thumb, sequela*/
,'T23339D'  /*Burn of third degree of unspecified multiple fingers (nail), not including thumb, subsequent encounter*/
,'T23339S'  /*Burn of third degree of unspecified multiple fingers (nail), not including thumb, sequela*/
,'T23341D'  /*Burn of third degree of multiple right fingers (nail), including thumb, subsequent encounter*/
,'T23341S'  /*Burn of third degree of multiple right fingers (nail), including thumb, sequela*/
,'T23342D'  /*Burn of third degree of multiple left fingers (nail), including thumb, subsequent encounter*/
,'T23342S'  /*Burn of third degree of multiple left fingers (nail), including thumb, sequela*/
,'T23349D'  /*Burn of third degree of unspecified multiple fingers (nail), including thumb, subsequent encounter*/
,'T23349S'  /*Burn of third degree of unspecified multiple fingers (nail), including thumb, sequela*/
,'T23351D'  /*Burn of third degree of right palm, subsequent encounter*/
,'T23351S'  /*Burn of third degree of right palm, sequela*/
,'T23352D'  /*Burn of third degree of left palm, subsequent encounter*/
,'T23352S'  /*Burn of third degree of left palm, sequela*/
,'T23359D'  /*Burn of third degree of unspecified palm, subsequent encounter*/
,'T23359S'  /*Burn of third degree of unspecified palm, sequela*/
,'T23361D'  /*Burn of third degree of back of right hand, subsequent encounter*/
,'T23361S'  /*Burn of third degree of back of right hand, sequela*/
,'T23362D'  /*Burn of third degree of back of left hand, subsequent encounter*/
,'T23362S'  /*Burn of third degree of back of left hand, sequela*/
,'T23369D'  /*Burn of third degree of back of unspecified hand, subsequent encounter*/
,'T23369S'  /*Burn of third degree of back of unspecified hand, sequela*/
,'T23371D'  /*Burn of third degree of right wrist, subsequent encounter*/
,'T23371S'  /*Burn of third degree of right wrist, sequela*/
,'T23372D'  /*Burn of third degree of left wrist, subsequent encounter*/
,'T23372S'  /*Burn of third degree of left wrist, sequela*/
,'T23379D'  /*Burn of third degree of unspecified wrist, subsequent encounter*/
,'T23379S'  /*Burn of third degree of unspecified wrist, sequela*/
,'T23391D'  /*Burn of third degree of multiple sites of right wrist and hand, subsequent encounter*/
,'T23391S'  /*Burn of third degree of multiple sites of right wrist and hand, sequela*/
,'T23392D'  /*Burn of third degree of multiple sites of left wrist and hand, subsequent encounter*/
,'T23392S'  /*Burn of third degree of multiple sites of left wrist and hand, sequela*/
,'T23399D'  /*Burn of third degree of multiple sites of unspecified wrist and hand, subsequent encounter*/
,'T23399S'  /*Burn of third degree of multiple sites of unspecified wrist and hand, sequela*/
,'T23401D'  /*Corrosion of unspecified degree of right hand, unspecified site, subsequent encounter*/
,'T23401S'  /*Corrosion of unspecified degree of right hand, unspecified site, sequela*/
,'T23402D'  /*Corrosion of unspecified degree of left hand, unspecified site, subsequent encounter*/
,'T23402S'  /*Corrosion of unspecified degree of left hand, unspecified site, sequela*/
,'T23409D'  /*Corrosion of unspecified degree of unspecified hand, unspecified site, subsequent encounter*/
,'T23409S'  /*Corrosion of unspecified degree of unspecified hand, unspecified site, sequela*/
,'T23411D'  /*Corrosion of unspecified degree of right thumb (nail), subsequent encounter*/
,'T23411S'  /*Corrosion of unspecified degree of right thumb (nail), sequela*/
,'T23412D'  /*Corrosion of unspecified degree of left thumb (nail), subsequent encounter*/
,'T23412S'  /*Corrosion of unspecified degree of left thumb (nail), sequela*/
,'T23419D'  /*Corrosion of unspecified degree of unspecified thumb (nail), subsequent encounter*/
,'T23419S'  /*Corrosion of unspecified degree of unspecified thumb (nail), sequela*/
,'T23421D'  /*Corrosion of unspecified degree of single right finger (nail) except thumb, subsequent encounter*/
,'T23421S'  /*Corrosion of unspecified degree of single right finger (nail) except thumb, sequela*/
,'T23422D'  /*Corrosion of unspecified degree of single left finger (nail) except thumb, subsequent encounter*/
,'T23422S'  /*Corrosion of unspecified degree of single left finger (nail) except thumb, sequela*/
,'T23429D'  /*Corrosion of unspecified degree of unspecified single finger (nail) except thumb, subsequent encounter*/
,'T23429S'  /*Corrosion of unspecified degree of unspecified single finger (nail) except thumb, sequela*/
,'T23431D'  /*Corrosion of unspecified degree of multiple right fingers (nail), not including thumb, subsequent encounter*/
,'T23431S'  /*Corrosion of unspecified degree of multiple right fingers (nail), not including thumb, sequela*/
,'T23432D'  /*Corrosion of unspecified degree of multiple left fingers (nail), not including thumb, subsequent encounter*/
,'T23432S'  /*Corrosion of unspecified degree of multiple left fingers (nail), not including thumb, sequela*/
,'T23439D'  /*Corrosion of unspecified degree of unspecified multiple fingers (nail), not including thumb, subsequent encounter*/
,'T23439S'  /*Corrosion of unspecified degree of unspecified multiple fingers (nail), not including thumb, sequela*/
,'T23441D'  /*Corrosion of unspecified degree of multiple right fingers (nail), including thumb, subsequent encounter*/
,'T23441S'  /*Corrosion of unspecified degree of multiple right fingers (nail), including thumb, sequela*/
,'T23442D'  /*Corrosion of unspecified degree of multiple left fingers (nail), including thumb, subsequent encounter*/
,'T23442S'  /*Corrosion of unspecified degree of multiple left fingers (nail), including thumb, sequela*/
,'T23449D'  /*Corrosion of unspecified degree of unspecified multiple fingers (nail), including thumb, subsequent encounter*/
,'T23449S'  /*Corrosion of unspecified degree of unspecified multiple fingers (nail), including thumb, sequela*/
,'T23451D'  /*Corrosion of unspecified degree of right palm, subsequent encounter*/
,'T23451S'  /*Corrosion of unspecified degree of right palm, sequela*/
,'T23452D'  /*Corrosion of unspecified degree of left palm, subsequent encounter*/
,'T23452S'  /*Corrosion of unspecified degree of left palm, sequela*/
,'T23459D'  /*Corrosion of unspecified degree of unspecified palm, subsequent encounter*/
,'T23459S'  /*Corrosion of unspecified degree of unspecified palm, sequela*/
,'T23461D'  /*Corrosion of unspecified degree of back of right hand, subsequent encounter*/
,'T23461S'  /*Corrosion of unspecified degree of back of right hand, sequela*/
,'T23462D'  /*Corrosion of unspecified degree of back of left hand, subsequent encounter*/
,'T23462S'  /*Corrosion of unspecified degree of back of left hand, sequela*/
,'T23469D'  /*Corrosion of unspecified degree of back of unspecified hand, subsequent encounter*/
,'T23469S'  /*Corrosion of unspecified degree of back of unspecified hand, sequela*/
,'T23471D'  /*Corrosion of unspecified degree of right wrist, subsequent encounter*/
,'T23471S'  /*Corrosion of unspecified degree of right wrist, sequela*/
,'T23472D'  /*Corrosion of unspecified degree of left wrist, subsequent encounter*/
,'T23472S'  /*Corrosion of unspecified degree of left wrist, sequela*/
,'T23479D'  /*Corrosion of unspecified degree of unspecified wrist, subsequent encounter*/
,'T23479S'  /*Corrosion of unspecified degree of unspecified wrist, sequela*/
,'T23491D'  /*Corrosion of unspecified degree of multiple sites of right wrist and hand, subsequent encounter*/
,'T23491S'  /*Corrosion of unspecified degree of multiple sites of right wrist and hand, sequela*/
,'T23492D'  /*Corrosion of unspecified degree of multiple sites of left wrist and hand, subsequent encounter*/
,'T23492S'  /*Corrosion of unspecified degree of multiple sites of left wrist and hand, sequela*/
,'T23499D'  /*Corrosion of unspecified degree of multiple sites of unspecified wrist and hand, subsequent encounter*/
,'T23499S'  /*Corrosion of unspecified degree of multiple sites of unspecified wrist and hand, sequela*/
,'T23501D'  /*Corrosion of first degree of right hand, unspecified site, subsequent encounter*/
,'T23501S'  /*Corrosion of first degree of right hand, unspecified site, sequela*/
,'T23502D'  /*Corrosion of first degree of left hand, unspecified site, subsequent encounter*/
,'T23502S'  /*Corrosion of first degree of left hand, unspecified site, sequela*/
,'T23509D'  /*Corrosion of first degree of unspecified hand, unspecified site, subsequent encounter*/
,'T23509S'  /*Corrosion of first degree of unspecified hand, unspecified site, sequela*/
,'T23511D'  /*Corrosion of first degree of right thumb (nail), subsequent encounter*/
,'T23511S'  /*Corrosion of first degree of right thumb (nail), sequela*/
,'T23512D'  /*Corrosion of first degree of left thumb (nail), subsequent encounter*/
,'T23512S'  /*Corrosion of first degree of left thumb (nail), sequela*/
,'T23519D'  /*Corrosion of first degree of unspecified thumb (nail), subsequent encounter*/
,'T23519S'  /*Corrosion of first degree of unspecified thumb (nail), sequela*/
,'T23521D'  /*Corrosion of first degree of single right finger (nail) except thumb, subsequent encounter*/
,'T23521S'  /*Corrosion of first degree of single right finger (nail) except thumb, sequela*/
,'T23522D'  /*Corrosion of first degree of single left finger (nail) except thumb, subsequent encounter*/
,'T23522S'  /*Corrosion of first degree of single left finger (nail) except thumb, sequela*/
,'T23529D'  /*Corrosion of first degree of unspecified single finger (nail) except thumb, subsequent encounter*/
,'T23529S'  /*Corrosion of first degree of unspecified single finger (nail) except thumb, sequela*/
,'T23531D'  /*Corrosion of first degree of multiple right fingers (nail), not including thumb, subsequent encounter*/
,'T23531S'  /*Corrosion of first degree of multiple right fingers (nail), not including thumb, sequela*/
,'T23532D'  /*Corrosion of first degree of multiple left fingers (nail), not including thumb, subsequent encounter*/
,'T23532S'  /*Corrosion of first degree of multiple left fingers (nail), not including thumb, sequela*/
,'T23539D'  /*Corrosion of first degree of unspecified multiple fingers (nail), not including thumb, subsequent encounter*/
,'T23539S'  /*Corrosion of first degree of unspecified multiple fingers (nail), not including thumb, sequela*/
,'T23541D'  /*Corrosion of first degree of multiple right fingers (nail), including thumb, subsequent encounter*/
,'T23541S'  /*Corrosion of first degree of multiple right fingers (nail), including thumb, sequela*/
,'T23542D'  /*Corrosion of first degree of multiple left fingers (nail), including thumb, subsequent encounter*/
,'T23542S'  /*Corrosion of first degree of multiple left fingers (nail), including thumb, sequela*/
,'T23549D'  /*Corrosion of first degree of unspecified multiple fingers (nail), including thumb, subsequent encounter*/
,'T23549S'  /*Corrosion of first degree of unspecified multiple fingers (nail), including thumb, sequela*/
,'T23551D'  /*Corrosion of first degree of right palm, subsequent encounter*/
,'T23551S'  /*Corrosion of first degree of right palm, sequela*/
,'T23552D'  /*Corrosion of first degree of left palm, subsequent encounter*/
,'T23552S'  /*Corrosion of first degree of left palm, sequela*/
,'T23559D'  /*Corrosion of first degree of unspecified palm, subsequent encounter*/
,'T23559S'  /*Corrosion of first degree of unspecified palm, sequela*/
,'T23561D'  /*Corrosion of first degree of back of right hand, subsequent encounter*/
,'T23561S'  /*Corrosion of first degree of back of right hand, sequela*/
,'T23562D'  /*Corrosion of first degree of back of left hand, subsequent encounter*/
,'T23562S'  /*Corrosion of first degree of back of left hand, sequela*/
,'T23569D'  /*Corrosion of first degree of back of unspecified hand, subsequent encounter*/
,'T23569S'  /*Corrosion of first degree of back of unspecified hand, sequela*/
,'T23571D'  /*Corrosion of first degree of right wrist, subsequent encounter*/
,'T23571S'  /*Corrosion of first degree of right wrist, sequela*/
,'T23572D'  /*Corrosion of first degree of left wrist, subsequent encounter*/
,'T23572S'  /*Corrosion of first degree of left wrist, sequela*/
,'T23579D'  /*Corrosion of first degree of unspecified wrist, subsequent encounter*/
,'T23579S'  /*Corrosion of first degree of unspecified wrist, sequela*/
,'T23591D'  /*Corrosion of first degree of multiple sites of right wrist and hand, subsequent encounter*/
,'T23591S'  /*Corrosion of first degree of multiple sites of right wrist and hand, sequela*/
,'T23592D'  /*Corrosion of first degree of multiple sites of left wrist and hand, subsequent encounter*/
,'T23592S'  /*Corrosion of first degree of multiple sites of left wrist and hand, sequela*/
,'T23599D'  /*Corrosion of first degree of multiple sites of unspecified wrist and hand, subsequent encounter*/
,'T23599S'  /*Corrosion of first degree of multiple sites of unspecified wrist and hand, sequela*/
,'T23601D'  /*Corrosion of second degree of right hand, unspecified site, subsequent encounter*/
,'T23601S'  /*Corrosion of second degree of right hand, unspecified site, sequela*/
,'T23602D'  /*Corrosion of second degree of left hand, unspecified site, subsequent encounter*/
,'T23602S'  /*Corrosion of second degree of left hand, unspecified site, sequela*/
,'T23609D'  /*Corrosion of second degree of unspecified hand, unspecified site, subsequent encounter*/
,'T23609S'  /*Corrosion of second degree of unspecified hand, unspecified site, sequela*/
,'T23611D'  /*Corrosion of second degree of right thumb (nail), subsequent encounter*/
,'T23611S'  /*Corrosion of second degree of right thumb (nail), sequela*/
,'T23612D'  /*Corrosion of second degree of left thumb (nail), subsequent encounter*/
,'T23612S'  /*Corrosion of second degree of left thumb (nail), sequela*/
,'T23619D'  /*Corrosion of second degree of unspecified thumb (nail), subsequent encounter*/
,'T23619S'  /*Corrosion of second degree of unspecified thumb (nail), sequela*/
,'T23621D'  /*Corrosion of second degree of single right finger (nail) except thumb, subsequent encounter*/
,'T23621S'  /*Corrosion of second degree of single right finger (nail) except thumb, sequela*/
,'T23622D'  /*Corrosion of second degree of single left finger (nail) except thumb, subsequent encounter*/
,'T23622S'  /*Corrosion of second degree of single left finger (nail) except thumb, sequela*/
,'T23629D'  /*Corrosion of second degree of unspecified single finger (nail) except thumb, subsequent encounter*/
,'T23629S'  /*Corrosion of second degree of unspecified single finger (nail) except thumb, sequela*/
,'T23631D'  /*Corrosion of second degree of multiple right fingers (nail), not including thumb, subsequent encounter*/
,'T23631S'  /*Corrosion of second degree of multiple right fingers (nail), not including thumb, sequela*/
,'T23632D'  /*Corrosion of second degree of multiple left fingers (nail), not including thumb, subsequent encounter*/
,'T23632S'  /*Corrosion of second degree of multiple left fingers (nail), not including thumb, sequela*/
,'T23639D'  /*Corrosion of second degree of unspecified multiple fingers (nail), not including thumb, subsequent encounter*/
,'T23639S'  /*Corrosion of second degree of unspecified multiple fingers (nail), not including thumb, sequela*/
,'T23641D'  /*Corrosion of second degree of multiple right fingers (nail), including thumb, subsequent encounter*/
,'T23641S'  /*Corrosion of second degree of multiple right fingers (nail), including thumb, sequela*/
,'T23642D'  /*Corrosion of second degree of multiple left fingers (nail), including thumb, subsequent encounter*/
,'T23642S'  /*Corrosion of second degree of multiple left fingers (nail), including thumb, sequela*/
,'T23649D'  /*Corrosion of second degree of unspecified multiple fingers (nail), including thumb, subsequent encounter*/
,'T23649S'  /*Corrosion of second degree of unspecified multiple fingers (nail), including thumb, sequela*/
,'T23651D'  /*Corrosion of second degree of right palm, subsequent encounter*/
,'T23651S'  /*Corrosion of second degree of right palm, sequela*/
,'T23652D'  /*Corrosion of second degree of left palm, subsequent encounter*/
,'T23652S'  /*Corrosion of second degree of left palm, sequela*/
,'T23659D'  /*Corrosion of second degree of unspecified palm, subsequent encounter*/
,'T23659S'  /*Corrosion of second degree of unspecified palm, sequela*/
,'T23661D'  /*Corrosion of second degree back of right hand, subsequent encounter*/
,'T23661S'  /*Corrosion of second degree back of right hand, sequela*/
,'T23662D'  /*Corrosion of second degree back of left hand, subsequent encounter*/
,'T23662S'  /*Corrosion of second degree back of left hand, sequela*/
,'T23669D'  /*Corrosion of second degree back of unspecified hand, subsequent encounter*/
,'T23669S'  /*Corrosion of second degree back of unspecified hand, sequela*/
,'T23671D'  /*Corrosion of second degree of right wrist, subsequent encounter*/
,'T23671S'  /*Corrosion of second degree of right wrist, sequela*/
,'T23672D'  /*Corrosion of second degree of left wrist, subsequent encounter*/
,'T23672S'  /*Corrosion of second degree of left wrist, sequela*/
,'T23679D'  /*Corrosion of second degree of unspecified wrist, subsequent encounter*/
,'T23679S'  /*Corrosion of second degree of unspecified wrist, sequela*/
,'T23691D'  /*Corrosion of second degree of multiple sites of right wrist and hand, subsequent encounter*/
,'T23691S'  /*Corrosion of second degree of multiple sites of right wrist and hand, sequela*/
,'T23692D'  /*Corrosion of second degree of multiple sites of left wrist and hand, subsequent encounter*/
,'T23692S'  /*Corrosion of second degree of multiple sites of left wrist and hand, sequela*/
,'T23699D'  /*Corrosion of second degree of multiple sites of unspecified wrist and hand, subsequent encounter*/
,'T23699S'  /*Corrosion of second degree of multiple sites of unspecified wrist and hand, sequela*/
,'T23701D'  /*Corrosion of third degree of right hand, unspecified site, subsequent encounter*/
,'T23701S'  /*Corrosion of third degree of right hand, unspecified site, sequela*/
,'T23702D'  /*Corrosion of third degree of left hand, unspecified site, subsequent encounter*/
,'T23702S'  /*Corrosion of third degree of left hand, unspecified site, sequela*/
,'T23709D'  /*Corrosion of third degree of unspecified hand, unspecified site, subsequent encounter*/
,'T23709S'  /*Corrosion of third degree of unspecified hand, unspecified site, sequela*/
,'T23711D'  /*Corrosion of third degree of right thumb (nail), subsequent encounter*/
,'T23711S'  /*Corrosion of third degree of right thumb (nail), sequela*/
,'T23712D'  /*Corrosion of third degree of left thumb (nail), subsequent encounter*/
,'T23712S'  /*Corrosion of third degree of left thumb (nail), sequela*/
,'T23719D'  /*Corrosion of third degree of unspecified thumb (nail), subsequent encounter*/
,'T23719S'  /*Corrosion of third degree of unspecified thumb (nail), sequela*/
,'T23721D'  /*Corrosion of third degree of single right finger (nail) except thumb, subsequent encounter*/
,'T23721S'  /*Corrosion of third degree of single right finger (nail) except thumb, sequela*/
,'T23722D'  /*Corrosion of third degree of single left finger (nail) except thumb, subsequent encounter*/
,'T23722S'  /*Corrosion of third degree of single left finger (nail) except thumb, sequela*/
,'T23729D'  /*Corrosion of third degree of unspecified single finger (nail) except thumb, subsequent encounter*/
,'T23729S'  /*Corrosion of third degree of unspecified single finger (nail) except thumb, sequela*/
,'T23731D'  /*Corrosion of third degree of multiple right fingers (nail), not including thumb, subsequent encounter*/
,'T23731S'  /*Corrosion of third degree of multiple right fingers (nail), not including thumb, sequela*/
,'T23732D'  /*Corrosion of third degree of multiple left fingers (nail), not including thumb, subsequent encounter*/
,'T23732S'  /*Corrosion of third degree of multiple left fingers (nail), not including thumb, sequela*/
,'T23739D'  /*Corrosion of third degree of unspecified multiple fingers (nail), not including thumb, subsequent encounter*/
,'T23739S'  /*Corrosion of third degree of unspecified multiple fingers (nail), not including thumb, sequela*/
,'T23741D'  /*Corrosion of third degree of multiple right fingers (nail), including thumb, subsequent encounter*/
,'T23741S'  /*Corrosion of third degree of multiple right fingers (nail), including thumb, sequela*/
,'T23742D'  /*Corrosion of third degree of multiple left fingers (nail), including thumb, subsequent encounter*/
,'T23742S'  /*Corrosion of third degree of multiple left fingers (nail), including thumb, sequela*/
,'T23749D'  /*Corrosion of third degree of unspecified multiple fingers (nail), including thumb, subsequent encounter*/
,'T23749S'  /*Corrosion of third degree of unspecified multiple fingers (nail), including thumb, sequela*/
,'T23751D'  /*Corrosion of third degree of right palm, subsequent encounter*/
,'T23751S'  /*Corrosion of third degree of right palm, sequela*/
,'T23752D'  /*Corrosion of third degree of left palm, subsequent encounter*/
,'T23752S'  /*Corrosion of third degree of left palm, sequela*/
,'T23759D'  /*Corrosion of third degree of unspecified palm, subsequent encounter*/
,'T23759S'  /*Corrosion of third degree of unspecified palm, sequela*/
,'T23761D'  /*Corrosion of third degree of back of right hand, subsequent encounter*/
,'T23761S'  /*Corrosion of third degree of back of right hand, sequela*/
,'T23762D'  /*Corrosion of third degree of back of left hand, subsequent encounter*/
,'T23762S'  /*Corrosion of third degree of back of left hand, sequela*/
,'T23769D'  /*Corrosion of third degree back of unspecified hand, subsequent encounter*/
,'T23769S'  /*Corrosion of third degree back of unspecified hand, sequela*/
,'T23771D'  /*Corrosion of third degree of right wrist, subsequent encounter*/
,'T23771S'  /*Corrosion of third degree of right wrist, sequela*/
,'T23772D'  /*Corrosion of third degree of left wrist, subsequent encounter*/
,'T23772S'  /*Corrosion of third degree of left wrist, sequela*/
,'T23779D'  /*Corrosion of third degree of unspecified wrist, subsequent encounter*/
,'T23779S'  /*Corrosion of third degree of unspecified wrist, sequela*/
,'T23791D'  /*Corrosion of third degree of multiple sites of right wrist and hand, subsequent encounter*/
,'T23791S'  /*Corrosion of third degree of multiple sites of right wrist and hand, sequela*/
,'T23792D'  /*Corrosion of third degree of multiple sites of left wrist and hand, subsequent encounter*/
,'T23792S'  /*Corrosion of third degree of multiple sites of left wrist and hand, sequela*/
,'T23799D'  /*Corrosion of third degree of multiple sites of unspecified wrist and hand, subsequent encounter*/
,'T23799S'  /*Corrosion of third degree of multiple sites of unspecified wrist and hand, sequela*/
,'T24001D'  /*Burn of unspecified degree of unspecified site of right lower limb, except ankle and foot, subsequent encounter*/
,'T24001S'  /*Burn of unspecified degree of unspecified site of right lower limb, except ankle and foot, sequela*/
,'T24002D'  /*Burn of unspecified degree of unspecified site of left lower limb, except ankle and foot, subsequent encounter*/
,'T24002S'  /*Burn of unspecified degree of unspecified site of left lower limb, except ankle and foot, sequela*/
,'T24009D'  /*Burn of unspecified degree of unspecified site of unspecified lower limb, except ankle and foot, subsequent encounter*/
,'T24009S'  /*Burn of unspecified degree of unspecified site of unspecified lower limb, except ankle and foot, sequela*/
,'T24011D'  /*Burn of unspecified degree of right thigh, subsequent encounter*/
,'T24011S'  /*Burn of unspecified degree of right thigh, sequela*/
,'T24012D'  /*Burn of unspecified degree of left thigh, subsequent encounter*/
,'T24012S'  /*Burn of unspecified degree of left thigh, sequela*/
,'T24019D'  /*Burn of unspecified degree of unspecified thigh, subsequent encounter*/
,'T24019S'  /*Burn of unspecified degree of unspecified thigh, sequela*/
,'T24021D'  /*Burn of unspecified degree of right knee, subsequent encounter*/
,'T24021S'  /*Burn of unspecified degree of right knee, sequela*/
,'T24022D'  /*Burn of unspecified degree of left knee, subsequent encounter*/
,'T24022S'  /*Burn of unspecified degree of left knee, sequela*/
,'T24029D'  /*Burn of unspecified degree of unspecified knee, subsequent encounter*/
,'T24029S'  /*Burn of unspecified degree of unspecified knee, sequela*/
,'T24031D'  /*Burn of unspecified degree of right lower leg, subsequent encounter*/
,'T24031S'  /*Burn of unspecified degree of right lower leg, sequela*/
,'T24032D'  /*Burn of unspecified degree of left lower leg, subsequent encounter*/
,'T24032S'  /*Burn of unspecified degree of left lower leg, sequela*/
,'T24039D'  /*Burn of unspecified degree of unspecified lower leg, subsequent encounter*/
,'T24039S'  /*Burn of unspecified degree of unspecified lower leg, sequela*/
,'T24091D'  /*Burn of unspecified degree of multiple sites of right lower limb, except ankle and foot, subsequent encounter*/
,'T24091S'  /*Burn of unspecified degree of multiple sites of right lower limb, except ankle and foot, sequela*/
,'T24092D'  /*Burn of unspecified degree of multiple sites of left lower limb, except ankle and foot, subsequent encounter*/
,'T24092S'  /*Burn of unspecified degree of multiple sites of left lower limb, except ankle and foot, sequela*/
,'T24099D'  /*Burn of unspecified degree of multiple sites of unspecified lower limb, except ankle and foot, subsequent encounter*/
,'T24099S'  /*Burn of unspecified degree of multiple sites of unspecified lower limb, except ankle and foot, sequela*/
,'T24101D'  /*Burn of first degree of unspecified site of right lower limb, except ankle and foot, subsequent encounter*/
,'T24101S'  /*Burn of first degree of unspecified site of right lower limb, except ankle and foot, sequela*/
,'T24102D'  /*Burn of first degree of unspecified site of left lower limb, except ankle and foot, subsequent encounter*/
,'T24102S'  /*Burn of first degree of unspecified site of left lower limb, except ankle and foot, sequela*/
,'T24109D'  /*Burn of first degree of unspecified site of unspecified lower limb, except ankle and foot, subsequent encounter*/
,'T24109S'  /*Burn of first degree of unspecified site of unspecified lower limb, except ankle and foot, sequela*/
,'T24111D'  /*Burn of first degree of right thigh, subsequent encounter*/
,'T24111S'  /*Burn of first degree of right thigh, sequela*/
,'T24112D'  /*Burn of first degree of left thigh, subsequent encounter*/
,'T24112S'  /*Burn of first degree of left thigh, sequela*/
,'T24119D'  /*Burn of first degree of unspecified thigh, subsequent encounter*/
,'T24119S'  /*Burn of first degree of unspecified thigh, sequela*/
,'T24121D'  /*Burn of first degree of right knee, subsequent encounter*/
,'T24121S'  /*Burn of first degree of right knee, sequela*/
,'T24122D'  /*Burn of first degree of left knee, subsequent encounter*/
,'T24122S'  /*Burn of first degree of left knee, sequela*/
,'T24129D'  /*Burn of first degree of unspecified knee, subsequent encounter*/
,'T24129S'  /*Burn of first degree of unspecified knee, sequela*/
,'T24131D'  /*Burn of first degree of right lower leg, subsequent encounter*/
,'T24131S'  /*Burn of first degree of right lower leg, sequela*/
,'T24132D'  /*Burn of first degree of left lower leg, subsequent encounter*/
,'T24132S'  /*Burn of first degree of left lower leg, sequela*/
,'T24139D'  /*Burn of first degree of unspecified lower leg, subsequent encounter*/
,'T24139S'  /*Burn of first degree of unspecified lower leg, sequela*/
,'T24191D'  /*Burn of first degree of multiple sites of right lower limb, except ankle and foot, subsequent encounter*/
,'T24191S'  /*Burn of first degree of multiple sites of right lower limb, except ankle and foot, sequela*/
,'T24192D'  /*Burn of first degree of multiple sites of left lower limb, except ankle and foot, subsequent encounter*/
,'T24192S'  /*Burn of first degree of multiple sites of left lower limb, except ankle and foot, sequela*/
,'T24199D'  /*Burn of first degree of multiple sites of unspecified lower limb, except ankle and foot, subsequent encounter*/
,'T24199S'  /*Burn of first degree of multiple sites of unspecified lower limb, except ankle and foot, sequela*/
,'T24201D'  /*Burn of second degree of unspecified site of right lower limb, except ankle and foot, subsequent encounter*/
,'T24201S'  /*Burn of second degree of unspecified site of right lower limb, except ankle and foot, sequela*/
,'T24202D'  /*Burn of second degree of unspecified site of left lower limb, except ankle and foot, subsequent encounter*/
,'T24202S'  /*Burn of second degree of unspecified site of left lower limb, except ankle and foot, sequela*/
,'T24209D'  /*Burn of second degree of unspecified site of unspecified lower limb, except ankle and foot, subsequent encounter*/
,'T24209S'  /*Burn of second degree of unspecified site of unspecified lower limb, except ankle and foot, sequela*/
,'T24211D'  /*Burn of second degree of right thigh, subsequent encounter*/
,'T24211S'  /*Burn of second degree of right thigh, sequela*/
,'T24212D'  /*Burn of second degree of left thigh, subsequent encounter*/
,'T24212S'  /*Burn of second degree of left thigh, sequela*/
,'T24219D'  /*Burn of second degree of unspecified thigh, subsequent encounter*/
,'T24219S'  /*Burn of second degree of unspecified thigh, sequela*/
,'T24221D'  /*Burn of second degree of right knee, subsequent encounter*/
,'T24221S'  /*Burn of second degree of right knee, sequela*/
,'T24222D'  /*Burn of second degree of left knee, subsequent encounter*/
,'T24222S'  /*Burn of second degree of left knee, sequela*/
,'T24229D'  /*Burn of second degree of unspecified knee, subsequent encounter*/
,'T24229S'  /*Burn of second degree of unspecified knee, sequela*/
,'T24231D'  /*Burn of second degree of right lower leg, subsequent encounter*/
,'T24231S'  /*Burn of second degree of right lower leg, sequela*/
,'T24232D'  /*Burn of second degree of left lower leg, subsequent encounter*/
,'T24232S'  /*Burn of second degree of left lower leg, sequela*/
,'T24239D'  /*Burn of second degree of unspecified lower leg, subsequent encounter*/
,'T24239S'  /*Burn of second degree of unspecified lower leg, sequela*/
,'T24291D'  /*Burn of second degree of multiple sites of right lower limb, except ankle and foot, subsequent encounter*/
,'T24291S'  /*Burn of second degree of multiple sites of right lower limb, except ankle and foot, sequela*/
,'T24292D'  /*Burn of second degree of multiple sites of left lower limb, except ankle and foot, subsequent encounter*/
,'T24292S'  /*Burn of second degree of multiple sites of left lower limb, except ankle and foot, sequela*/
,'T24299D'  /*Burn of second degree of multiple sites of unspecified lower limb, except ankle and foot, subsequent encounter*/
,'T24299S'  /*Burn of second degree of multiple sites of unspecified lower limb, except ankle and foot, sequela*/
,'T24301D'  /*Burn of third degree of unspecified site of right lower limb, except ankle and foot, subsequent encounter*/
,'T24301S'  /*Burn of third degree of unspecified site of right lower limb, except ankle and foot, sequela*/
,'T24302D'  /*Burn of third degree of unspecified site of left lower limb, except ankle and foot, subsequent encounter*/
,'T24302S'  /*Burn of third degree of unspecified site of left lower limb, except ankle and foot, sequela*/
,'T24309D'  /*Burn of third degree of unspecified site of unspecified lower limb, except ankle and foot, subsequent encounter*/
,'T24309S'  /*Burn of third degree of unspecified site of unspecified lower limb, except ankle and foot, sequela*/
,'T24311D'  /*Burn of third degree of right thigh, subsequent encounter*/
,'T24311S'  /*Burn of third degree of right thigh, sequela*/
,'T24312D'  /*Burn of third degree of left thigh, subsequent encounter*/
,'T24312S'  /*Burn of third degree of left thigh, sequela*/
,'T24319D'  /*Burn of third degree of unspecified thigh, subsequent encounter*/
,'T24319S'  /*Burn of third degree of unspecified thigh, sequela*/
,'T24321D'  /*Burn of third degree of right knee, subsequent encounter*/
,'T24321S'  /*Burn of third degree of right knee, sequela*/
,'T24322D'  /*Burn of third degree of left knee, subsequent encounter*/
,'T24322S'  /*Burn of third degree of left knee, sequela*/
,'T24329D'  /*Burn of third degree of unspecified knee, subsequent encounter*/
,'T24329S'  /*Burn of third degree of unspecified knee, sequela*/
,'T24331D'  /*Burn of third degree of right lower leg, subsequent encounter*/
,'T24331S'  /*Burn of third degree of right lower leg, sequela*/
,'T24332D'  /*Burn of third degree of left lower leg, subsequent encounter*/
,'T24332S'  /*Burn of third degree of left lower leg, sequela*/
,'T24339D'  /*Burn of third degree of unspecified lower leg, subsequent encounter*/
,'T24339S'  /*Burn of third degree of unspecified lower leg, sequela*/
,'T24391D'  /*Burn of third degree of multiple sites of right lower limb, except ankle and foot, subsequent encounter*/
,'T24391S'  /*Burn of third degree of multiple sites of right lower limb, except ankle and foot, sequela*/
,'T24392D'  /*Burn of third degree of multiple sites of left lower limb, except ankle and foot, subsequent encounter*/
,'T24392S'  /*Burn of third degree of multiple sites of left lower limb, except ankle and foot, sequela*/
,'T24399D'  /*Burn of third degree of multiple sites of unspecified lower limb, except ankle and foot, subsequent encounter*/
,'T24399S'  /*Burn of third degree of multiple sites of unspecified lower limb, except ankle and foot, sequela*/
,'T24401D'  /*Corrosion of unspecified degree of unspecified site of right lower limb, except ankle and foot, subsequent encounter*/
,'T24401S'  /*Corrosion of unspecified degree of unspecified site of right lower limb, except ankle and foot, sequela*/
,'T24402D'  /*Corrosion of unspecified degree of unspecified site of left lower limb, except ankle and foot, subsequent encounter*/
,'T24402S'  /*Corrosion of unspecified degree of unspecified site of left lower limb, except ankle and foot, sequela*/
,'T24409D'  /*Corrosion of unspecified degree of unspecified site of unspecified lower limb, except ankle and foot, subsequent encounter*/
,'T24409S'  /*Corrosion of unspecified degree of unspecified site of unspecified lower limb, except ankle and foot, sequela*/
,'T24411D'  /*Corrosion of unspecified degree of right thigh, subsequent encounter*/
,'T24411S'  /*Corrosion of unspecified degree of right thigh, sequela*/
,'T24412D'  /*Corrosion of unspecified degree of left thigh, subsequent encounter*/
,'T24412S'  /*Corrosion of unspecified degree of left thigh, sequela*/
,'T24419D'  /*Corrosion of unspecified degree of unspecified thigh, subsequent encounter*/
,'T24419S'  /*Corrosion of unspecified degree of unspecified thigh, sequela*/
,'T24421D'  /*Corrosion of unspecified degree of right knee, subsequent encounter*/
,'T24421S'  /*Corrosion of unspecified degree of right knee, sequela*/
,'T24422D'  /*Corrosion of unspecified degree of left knee, subsequent encounter*/
,'T24422S'  /*Corrosion of unspecified degree of left knee, sequela*/
,'T24429D'  /*Corrosion of unspecified degree of unspecified knee, subsequent encounter*/
,'T24429S'  /*Corrosion of unspecified degree of unspecified knee, sequela*/
,'T24431D'  /*Corrosion of unspecified degree of right lower leg, subsequent encounter*/
,'T24431S'  /*Corrosion of unspecified degree of right lower leg, sequela*/
,'T24432D'  /*Corrosion of unspecified degree of left lower leg, subsequent encounter*/
,'T24432S'  /*Corrosion of unspecified degree of left lower leg, sequela*/
,'T24439D'  /*Corrosion of unspecified degree of unspecified lower leg, subsequent encounter*/
,'T24439S'  /*Corrosion of unspecified degree of unspecified lower leg, sequela*/
,'T24491D'  /*Corrosion of unspecified degree of multiple sites of right lower limb, except ankle and foot, subsequent encounter*/
,'T24491S'  /*Corrosion of unspecified degree of multiple sites of right lower limb, except ankle and foot, sequela*/
,'T24492D'  /*Corrosion of unspecified degree of multiple sites of left lower limb, except ankle and foot, subsequent encounter*/
,'T24492S'  /*Corrosion of unspecified degree of multiple sites of left lower limb, except ankle and foot, sequela*/
,'T24499D'  /*Corrosion of unspecified degree of multiple sites of unspecified lower limb, except ankle and foot, subsequent encounter*/
,'T24499S'  /*Corrosion of unspecified degree of multiple sites of unspecified lower limb, except ankle and foot, sequela*/
,'T24501D'  /*Corrosion of first degree of unspecified site of right lower limb, except ankle and foot, subsequent encounter*/
,'T24501S'  /*Corrosion of first degree of unspecified site of right lower limb, except ankle and foot, sequela*/
,'T24502D'  /*Corrosion of first degree of unspecified site of left lower limb, except ankle and foot, subsequent encounter*/
,'T24502S'  /*Corrosion of first degree of unspecified site of left lower limb, except ankle and foot, sequela*/
,'T24509D'  /*Corrosion of first degree of unspecified site of unspecified lower limb, except ankle and foot, subsequent encounter*/
,'T24509S'  /*Corrosion of first degree of unspecified site of unspecified lower limb, except ankle and foot, sequela*/
,'T24511D'  /*Corrosion of first degree of right thigh, subsequent encounter*/
,'T24511S'  /*Corrosion of first degree of right thigh, sequela*/
,'T24512D'  /*Corrosion of first degree of left thigh, subsequent encounter*/
,'T24512S'  /*Corrosion of first degree of left thigh, sequela*/
,'T24519D'  /*Corrosion of first degree of unspecified thigh, subsequent encounter*/
,'T24519S'  /*Corrosion of first degree of unspecified thigh, sequela*/
,'T24521D'  /*Corrosion of first degree of right knee, subsequent encounter*/
,'T24521S'  /*Corrosion of first degree of right knee, sequela*/
,'T24522D'  /*Corrosion of first degree of left knee, subsequent encounter*/
,'T24522S'  /*Corrosion of first degree of left knee, sequela*/
,'T24529D'  /*Corrosion of first degree of unspecified knee, subsequent encounter*/
,'T24529S'  /*Corrosion of first degree of unspecified knee, sequela*/
,'T24531D'  /*Corrosion of first degree of right lower leg, subsequent encounter*/
,'T24531S'  /*Corrosion of first degree of right lower leg, sequela*/
,'T24532D'  /*Corrosion of first degree of left lower leg, subsequent encounter*/
,'T24532S'  /*Corrosion of first degree of left lower leg, sequela*/
,'T24539D'  /*Corrosion of first degree of unspecified lower leg, subsequent encounter*/
,'T24539S'  /*Corrosion of first degree of unspecified lower leg, sequela*/
,'T24591D'  /*Corrosion of first degree of multiple sites of right lower limb, except ankle and foot, subsequent encounter*/
,'T24591S'  /*Corrosion of first degree of multiple sites of right lower limb, except ankle and foot, sequela*/
,'T24592D'  /*Corrosion of first degree of multiple sites of left lower limb, except ankle and foot, subsequent encounter*/
,'T24592S'  /*Corrosion of first degree of multiple sites of left lower limb, except ankle and foot, sequela*/
,'T24599D'  /*Corrosion of first degree of multiple sites of unspecified lower limb, except ankle and foot, subsequent encounter*/
,'T24599S'  /*Corrosion of first degree of multiple sites of unspecified lower limb, except ankle and foot, sequela*/
,'T24601D'  /*Corrosion of second degree of unspecified site of right lower limb, except ankle and foot, subsequent encounter*/
,'T24601S'  /*Corrosion of second degree of unspecified site of right lower limb, except ankle and foot, sequela*/
,'T24602D'  /*Corrosion of second degree of unspecified site of left lower limb, except ankle and foot, subsequent encounter*/
,'T24602S'  /*Corrosion of second degree of unspecified site of left lower limb, except ankle and foot, sequela*/
,'T24609D'  /*Corrosion of second degree of unspecified site of unspecified lower limb, except ankle and foot, subsequent encounter*/
,'T24609S'  /*Corrosion of second degree of unspecified site of unspecified lower limb, except ankle and foot, sequela*/
,'T24611D'  /*Corrosion of second degree of right thigh, subsequent encounter*/
,'T24611S'  /*Corrosion of second degree of right thigh, sequela*/
,'T24612D'  /*Corrosion of second degree of left thigh, subsequent encounter*/
,'T24612S'  /*Corrosion of second degree of left thigh, sequela*/
,'T24619D'  /*Corrosion of second degree of unspecified thigh, subsequent encounter*/
,'T24619S'  /*Corrosion of second degree of unspecified thigh, sequela*/
,'T24621D'  /*Corrosion of second degree of right knee, subsequent encounter*/
,'T24621S'  /*Corrosion of second degree of right knee, sequela*/
,'T24622D'  /*Corrosion of second degree of left knee, subsequent encounter*/
,'T24622S'  /*Corrosion of second degree of left knee, sequela*/
,'T24629D'  /*Corrosion of second degree of unspecified knee, subsequent encounter*/
,'T24629S'  /*Corrosion of second degree of unspecified knee, sequela*/
,'T24631D'  /*Corrosion of second degree of right lower leg, subsequent encounter*/
,'T24631S'  /*Corrosion of second degree of right lower leg, sequela*/
,'T24632D'  /*Corrosion of second degree of left lower leg, subsequent encounter*/
,'T24632S'  /*Corrosion of second degree of left lower leg, sequela*/
,'T24639D'  /*Corrosion of second degree of unspecified lower leg, subsequent encounter*/
,'T24639S'  /*Corrosion of second degree of unspecified lower leg, sequela*/
,'T24691D'  /*Corrosion of second degree of multiple sites of right lower limb, except ankle and foot, subsequent encounter*/
,'T24691S'  /*Corrosion of second degree of multiple sites of right lower limb, except ankle and foot, sequela*/
,'T24692D'  /*Corrosion of second degree of multiple sites of left lower limb, except ankle and foot, subsequent encounter*/
,'T24692S'  /*Corrosion of second degree of multiple sites of left lower limb, except ankle and foot, sequela*/
,'T24699D'  /*Corrosion of second degree of multiple sites of unspecified lower limb, except ankle and foot, subsequent encounter*/
,'T24699S'  /*Corrosion of second degree of multiple sites of unspecified lower limb, except ankle and foot, sequela*/
,'T24701D'  /*Corrosion of third degree of unspecified site of right lower limb, except ankle and foot, subsequent encounter*/
,'T24701S'  /*Corrosion of third degree of unspecified site of right lower limb, except ankle and foot, sequela*/
,'T24702D'  /*Corrosion of third degree of unspecified site of left lower limb, except ankle and foot, subsequent encounter*/
,'T24702S'  /*Corrosion of third degree of unspecified site of left lower limb, except ankle and foot, sequela*/
,'T24709D'  /*Corrosion of third degree of unspecified site of unspecified lower limb, except ankle and foot, subsequent encounter*/
,'T24709S'  /*Corrosion of third degree of unspecified site of unspecified lower limb, except ankle and foot, sequela*/
,'T24711D'  /*Corrosion of third degree of right thigh, subsequent encounter*/
,'T24711S'  /*Corrosion of third degree of right thigh, sequela*/
,'T24712D'  /*Corrosion of third degree of left thigh, subsequent encounter*/
,'T24712S'  /*Corrosion of third degree of left thigh, sequela*/
,'T24719D'  /*Corrosion of third degree of unspecified thigh, subsequent encounter*/
,'T24719S'  /*Corrosion of third degree of unspecified thigh, sequela*/
,'T24721D'  /*Corrosion of third degree of right knee, subsequent encounter*/
,'T24721S'  /*Corrosion of third degree of right knee, sequela*/
,'T24722D'  /*Corrosion of third degree of left knee, subsequent encounter*/
,'T24722S'  /*Corrosion of third degree of left knee, sequela*/
,'T24729D'  /*Corrosion of third degree of unspecified knee, subsequent encounter*/
,'T24729S'  /*Corrosion of third degree of unspecified knee, sequela*/
,'T24731D'  /*Corrosion of third degree of right lower leg, subsequent encounter*/
,'T24731S'  /*Corrosion of third degree of right lower leg, sequela*/
,'T24732D'  /*Corrosion of third degree of left lower leg, subsequent encounter*/
,'T24732S'  /*Corrosion of third degree of left lower leg, sequela*/
,'T24739D'  /*Corrosion of third degree of unspecified lower leg, subsequent encounter*/
,'T24739S'  /*Corrosion of third degree of unspecified lower leg, sequela*/
,'T24791D'  /*Corrosion of third degree of multiple sites of right lower limb, except ankle and foot, subsequent encounter*/
,'T24791S'  /*Corrosion of third degree of multiple sites of right lower limb, except ankle and foot, sequela*/
,'T24792D'  /*Corrosion of third degree of multiple sites of left lower limb, except ankle and foot, subsequent encounter*/
,'T24792S'  /*Corrosion of third degree of multiple sites of left lower limb, except ankle and foot, sequela*/
,'T24799D'  /*Corrosion of third degree of multiple sites of unspecified lower limb, except ankle and foot, subsequent encounter*/
,'T24799S'  /*Corrosion of third degree of multiple sites of unspecified lower limb, except ankle and foot, sequela*/
,'T25011D'  /*Burn of unspecified degree of right ankle, subsequent encounter*/
,'T25011S'  /*Burn of unspecified degree of right ankle, sequela*/
,'T25012D'  /*Burn of unspecified degree of left ankle, subsequent encounter*/
,'T25012S'  /*Burn of unspecified degree of left ankle, sequela*/
,'T25019D'  /*Burn of unspecified degree of unspecified ankle, subsequent encounter*/
,'T25019S'  /*Burn of unspecified degree of unspecified ankle, sequela*/
,'T25021D'  /*Burn of unspecified degree of right foot, subsequent encounter*/
,'T25021S'  /*Burn of unspecified degree of right foot, sequela*/
,'T25022D'  /*Burn of unspecified degree of left foot, subsequent encounter*/
,'T25022S'  /*Burn of unspecified degree of left foot, sequela*/
,'T25029D'  /*Burn of unspecified degree of unspecified foot, subsequent encounter*/
,'T25029S'  /*Burn of unspecified degree of unspecified foot, sequela*/
,'T25031D'  /*Burn of unspecified degree of right toe(s) (nail), subsequent encounter*/
,'T25031S'  /*Burn of unspecified degree of right toe(s) (nail), sequela*/
,'T25032D'  /*Burn of unspecified degree of left toe(s) (nail), subsequent encounter*/
,'T25032S'  /*Burn of unspecified degree of left toe(s) (nail), sequela*/
,'T25039D'  /*Burn of unspecified degree of unspecified toe(s) (nail), subsequent encounter*/
,'T25039S'  /*Burn of unspecified degree of unspecified toe(s) (nail), sequela*/
,'T25091D'  /*Burn of unspecified degree of multiple sites of right ankle and foot, subsequent encounter*/
,'T25091S'  /*Burn of unspecified degree of multiple sites of right ankle and foot, sequela*/
,'T25092D'  /*Burn of unspecified degree of multiple sites of left ankle and foot, subsequent encounter*/
,'T25092S'  /*Burn of unspecified degree of multiple sites of left ankle and foot, sequela*/
,'T25099D'  /*Burn of unspecified degree of multiple sites of unspecified ankle and foot, subsequent encounter*/
,'T25099S'  /*Burn of unspecified degree of multiple sites of unspecified ankle and foot, sequela*/
,'T25111D'  /*Burn of first degree of right ankle, subsequent encounter*/
,'T25111S'  /*Burn of first degree of right ankle, sequela*/
,'T25112D'  /*Burn of first degree of left ankle, subsequent encounter*/
,'T25112S'  /*Burn of first degree of left ankle, sequela*/
,'T25119D'  /*Burn of first degree of unspecified ankle, subsequent encounter*/
,'T25119S'  /*Burn of first degree of unspecified ankle, sequela*/
,'T25121D'  /*Burn of first degree of right foot, subsequent encounter*/
,'T25121S'  /*Burn of first degree of right foot, sequela*/
,'T25122D'  /*Burn of first degree of left foot, subsequent encounter*/
,'T25122S'  /*Burn of first degree of left foot, sequela*/
,'T25129D'  /*Burn of first degree of unspecified foot, subsequent encounter*/
,'T25129S'  /*Burn of first degree of unspecified foot, sequela*/
,'T25131D'  /*Burn of first degree of right toe(s) (nail), subsequent encounter*/
,'T25131S'  /*Burn of first degree of right toe(s) (nail), sequela*/
,'T25132D'  /*Burn of first degree of left toe(s) (nail), subsequent encounter*/
,'T25132S'  /*Burn of first degree of left toe(s) (nail), sequela*/
,'T25139D'  /*Burn of first degree of unspecified toe(s) (nail), subsequent encounter*/
,'T25139S'  /*Burn of first degree of unspecified toe(s) (nail), sequela*/
,'T25191D'  /*Burn of first degree of multiple sites of right ankle and foot, subsequent encounter*/
,'T25191S'  /*Burn of first degree of multiple sites of right ankle and foot, sequela*/
,'T25192D'  /*Burn of first degree of multiple sites of left ankle and foot, subsequent encounter*/
,'T25192S'  /*Burn of first degree of multiple sites of left ankle and foot, sequela*/
,'T25199D'  /*Burn of first degree of multiple sites of unspecified ankle and foot, subsequent encounter*/
,'T25199S'  /*Burn of first degree of multiple sites of unspecified ankle and foot, sequela*/
,'T25211D'  /*Burn of second degree of right ankle, subsequent encounter*/
,'T25211S'  /*Burn of second degree of right ankle, sequela*/
,'T25212D'  /*Burn of second degree of left ankle, subsequent encounter*/
,'T25212S'  /*Burn of second degree of left ankle, sequela*/
,'T25219D'  /*Burn of second degree of unspecified ankle, subsequent encounter*/
,'T25219S'  /*Burn of second degree of unspecified ankle, sequela*/
,'T25221D'  /*Burn of second degree of right foot, subsequent encounter*/
,'T25221S'  /*Burn of second degree of right foot, sequela*/
,'T25222D'  /*Burn of second degree of left foot, subsequent encounter*/
,'T25222S'  /*Burn of second degree of left foot, sequela*/
,'T25229D'  /*Burn of second degree of unspecified foot, subsequent encounter*/
,'T25229S'  /*Burn of second degree of unspecified foot, sequela*/
,'T25231D'  /*Burn of second degree of right toe(s) (nail), subsequent encounter*/
,'T25231S'  /*Burn of second degree of right toe(s) (nail), sequela*/
,'T25232D'  /*Burn of second degree of left toe(s) (nail), subsequent encounter*/
,'T25232S'  /*Burn of second degree of left toe(s) (nail), sequela*/
,'T25239D'  /*Burn of second degree of unspecified toe(s) (nail), subsequent encounter*/
,'T25239S'  /*Burn of second degree of unspecified toe(s) (nail), sequela*/
,'T25291D'  /*Burn of second degree of multiple sites of right ankle and foot, subsequent encounter*/
,'T25291S'  /*Burn of second degree of multiple sites of right ankle and foot, sequela*/
,'T25292D'  /*Burn of second degree of multiple sites of left ankle and foot, subsequent encounter*/
,'T25292S'  /*Burn of second degree of multiple sites of left ankle and foot, sequela*/
,'T25299D'  /*Burn of second degree of multiple sites of unspecified ankle and foot, subsequent encounter*/
,'T25299S'  /*Burn of second degree of multiple sites of unspecified ankle and foot, sequela*/
,'T25311D'  /*Burn of third degree of right ankle, subsequent encounter*/
,'T25311S'  /*Burn of third degree of right ankle, sequela*/
,'T25312D'  /*Burn of third degree of left ankle, subsequent encounter*/
,'T25312S'  /*Burn of third degree of left ankle, sequela*/
,'T25319D'  /*Burn of third degree of unspecified ankle, subsequent encounter*/
,'T25319S'  /*Burn of third degree of unspecified ankle, sequela*/
,'T25321D'  /*Burn of third degree of right foot, subsequent encounter*/
,'T25321S'  /*Burn of third degree of right foot, sequela*/
,'T25322D'  /*Burn of third degree of left foot, subsequent encounter*/
,'T25322S'  /*Burn of third degree of left foot, sequela*/
,'T25329D'  /*Burn of third degree of unspecified foot, subsequent encounter*/
,'T25329S'  /*Burn of third degree of unspecified foot, sequela*/
,'T25331D'  /*Burn of third degree of right toe(s) (nail), subsequent encounter*/
,'T25331S'  /*Burn of third degree of right toe(s) (nail), sequela*/
,'T25332D'  /*Burn of third degree of left toe(s) (nail), subsequent encounter*/
,'T25332S'  /*Burn of third degree of left toe(s) (nail), sequela*/
,'T25339D'  /*Burn of third degree of unspecified toe(s) (nail), subsequent encounter*/
,'T25339S'  /*Burn of third degree of unspecified toe(s) (nail), sequela*/
,'T25391D'  /*Burn of third degree of multiple sites of right ankle and foot, subsequent encounter*/
,'T25391S'  /*Burn of third degree of multiple sites of right ankle and foot, sequela*/
,'T25392D'  /*Burn of third degree of multiple sites of left ankle and foot, subsequent encounter*/
,'T25392S'  /*Burn of third degree of multiple sites of left ankle and foot, sequela*/
,'T25399D'  /*Burn of third degree of multiple sites of unspecified ankle and foot, subsequent encounter*/
,'T25399S'  /*Burn of third degree of multiple sites of unspecified ankle and foot, sequela*/
,'T25411D'  /*Corrosion of unspecified degree of right ankle, subsequent encounter*/
,'T25411S'  /*Corrosion of unspecified degree of right ankle, sequela*/
,'T25412D'  /*Corrosion of unspecified degree of left ankle, subsequent encounter*/
,'T25412S'  /*Corrosion of unspecified degree of left ankle, sequela*/
,'T25419D'  /*Corrosion of unspecified degree of unspecified ankle, subsequent encounter*/
,'T25419S'  /*Corrosion of unspecified degree of unspecified ankle, sequela*/
,'T25421D'  /*Corrosion of unspecified degree of right foot, subsequent encounter*/
,'T25421S'  /*Corrosion of unspecified degree of right foot, sequela*/
,'T25422D'  /*Corrosion of unspecified degree of left foot, subsequent encounter*/
,'T25422S'  /*Corrosion of unspecified degree of left foot, sequela*/
,'T25429D'  /*Corrosion of unspecified degree of unspecified foot, subsequent encounter*/
,'T25429S'  /*Corrosion of unspecified degree of unspecified foot, sequela*/
,'T25431D'  /*Corrosion of unspecified degree of right toe(s) (nail), subsequent encounter*/
,'T25431S'  /*Corrosion of unspecified degree of right toe(s) (nail), sequela*/
,'T25432D'  /*Corrosion of unspecified degree of left toe(s) (nail), subsequent encounter*/
,'T25432S'  /*Corrosion of unspecified degree of left toe(s) (nail), sequela*/
,'T25439D'  /*Corrosion of unspecified degree of unspecified toe(s) (nail), subsequent encounter*/
,'T25439S'  /*Corrosion of unspecified degree of unspecified toe(s) (nail), sequela*/
,'T25491D'  /*Corrosion of unspecified degree of multiple sites of right ankle and foot, subsequent encounter*/
,'T25491S'  /*Corrosion of unspecified degree of multiple sites of right ankle and foot, sequela*/
,'T25492D'  /*Corrosion of unspecified degree of multiple sites of left ankle and foot, subsequent encounter*/
,'T25492S'  /*Corrosion of unspecified degree of multiple sites of left ankle and foot, sequela*/
,'T25499D'  /*Corrosion of unspecified degree of multiple sites of unspecified ankle and foot, subsequent encounter*/
,'T25499S'  /*Corrosion of unspecified degree of multiple sites of unspecified ankle and foot, sequela*/
,'T25511D'  /*Corrosion of first degree of right ankle, subsequent encounter*/
,'T25511S'  /*Corrosion of first degree of right ankle, sequela*/
,'T25512D'  /*Corrosion of first degree of left ankle, subsequent encounter*/
,'T25512S'  /*Corrosion of first degree of left ankle, sequela*/
,'T25519D'  /*Corrosion of first degree of unspecified ankle, subsequent encounter*/
,'T25519S'  /*Corrosion of first degree of unspecified ankle, sequela*/
,'T25521D'  /*Corrosion of first degree of right foot, subsequent encounter*/
,'T25521S'  /*Corrosion of first degree of right foot, sequela*/
,'T25522D'  /*Corrosion of first degree of left foot, subsequent encounter*/
,'T25522S'  /*Corrosion of first degree of left foot, sequela*/
,'T25529D'  /*Corrosion of first degree of unspecified foot, subsequent encounter*/
,'T25529S'  /*Corrosion of first degree of unspecified foot, sequela*/
,'T25531D'  /*Corrosion of first degree of right toe(s) (nail), subsequent encounter*/
,'T25531S'  /*Corrosion of first degree of right toe(s) (nail), sequela*/
,'T25532D'  /*Corrosion of first degree of left toe(s) (nail), subsequent encounter*/
,'T25532S'  /*Corrosion of first degree of left toe(s) (nail), sequela*/
,'T25539D'  /*Corrosion of first degree of unspecified toe(s) (nail), subsequent encounter*/
,'T25539S'  /*Corrosion of first degree of unspecified toe(s) (nail), sequela*/
,'T25591D'  /*Corrosion of first degree of multiple sites of right ankle and foot, subsequent encounter*/
,'T25591S'  /*Corrosion of first degree of multiple sites of right ankle and foot, sequela*/
,'T25592D'  /*Corrosion of first degree of multiple sites of left ankle and foot, subsequent encounter*/
,'T25592S'  /*Corrosion of first degree of multiple sites of left ankle and foot, sequela*/
,'T25599D'  /*Corrosion of first degree of multiple sites of unspecified ankle and foot, subsequent encounter*/
,'T25599S'  /*Corrosion of first degree of multiple sites of unspecified ankle and foot, sequela*/
,'T25611D'  /*Corrosion of second degree of right ankle, subsequent encounter*/
,'T25611S'  /*Corrosion of second degree of right ankle, sequela*/
,'T25612D'  /*Corrosion of second degree of left ankle, subsequent encounter*/
,'T25612S'  /*Corrosion of second degree of left ankle, sequela*/
,'T25619D'  /*Corrosion of second degree of unspecified ankle, subsequent encounter*/
,'T25619S'  /*Corrosion of second degree of unspecified ankle, sequela*/
,'T25621D'  /*Corrosion of second degree of right foot, subsequent encounter*/
,'T25621S'  /*Corrosion of second degree of right foot, sequela*/
,'T25622D'  /*Corrosion of second degree of left foot, subsequent encounter*/
,'T25622S'  /*Corrosion of second degree of left foot, sequela*/
,'T25629D'  /*Corrosion of second degree of unspecified foot, subsequent encounter*/
,'T25629S'  /*Corrosion of second degree of unspecified foot, sequela*/
,'T25631D'  /*Corrosion of second degree of right toe(s) (nail), subsequent encounter*/
,'T25631S'  /*Corrosion of second degree of right toe(s) (nail), sequela*/
,'T25632D'  /*Corrosion of second degree of left toe(s) (nail), subsequent encounter*/
,'T25632S'  /*Corrosion of second degree of left toe(s) (nail), sequela*/
,'T25639D'  /*Corrosion of second degree of unspecified toe(s) (nail), subsequent encounter*/
,'T25639S'  /*Corrosion of second degree of unspecified toe(s) (nail), sequela*/
,'T25691D'  /*Corrosion of second degree of right ankle and foot, subsequent encounter*/
,'T25691S'  /*Corrosion of second degree of right ankle and foot, sequela*/
,'T25692D'  /*Corrosion of second degree of left ankle and foot, subsequent encounter*/
,'T25692S'  /*Corrosion of second degree of left ankle and foot, sequela*/
,'T25699D'  /*Corrosion of second degree of unspecified ankle and foot, subsequent encounter*/
,'T25699S'  /*Corrosion of second degree of unspecified ankle and foot, sequela*/
,'T25711D'  /*Corrosion of third degree of right ankle, subsequent encounter*/
,'T25711S'  /*Corrosion of third degree of right ankle, sequela*/
,'T25712D'  /*Corrosion of third degree of left ankle, subsequent encounter*/
,'T25712S'  /*Corrosion of third degree of left ankle, sequela*/
,'T25719D'  /*Corrosion of third degree of unspecified ankle, subsequent encounter*/
,'T25719S'  /*Corrosion of third degree of unspecified ankle, sequela*/
,'T25721D'  /*Corrosion of third degree of right foot, subsequent encounter*/
,'T25721S'  /*Corrosion of third degree of right foot, sequela*/
,'T25722D'  /*Corrosion of third degree of left foot, subsequent encounter*/
,'T25722S'  /*Corrosion of third degree of left foot, sequela*/
,'T25729D'  /*Corrosion of third degree of unspecified foot, subsequent encounter*/
,'T25729S'  /*Corrosion of third degree of unspecified foot, sequela*/
,'T25731D'  /*Corrosion of third degree of right toe(s) (nail), subsequent encounter*/
,'T25731S'  /*Corrosion of third degree of right toe(s) (nail), sequela*/
,'T25732D'  /*Corrosion of third degree of left toe(s) (nail), subsequent encounter*/
,'T25732S'  /*Corrosion of third degree of left toe(s) (nail), sequela*/
,'T25739D'  /*Corrosion of third degree of unspecified toe(s) (nail), subsequent encounter*/
,'T25739S'  /*Corrosion of third degree of unspecified toe(s) (nail), sequela*/
,'T25791D'  /*Corrosion of third degree of multiple sites of right ankle and foot, subsequent encounter*/
,'T25791S'  /*Corrosion of third degree of multiple sites of right ankle and foot, sequela*/
,'T25792D'  /*Corrosion of third degree of multiple sites of left ankle and foot, subsequent encounter*/
,'T25792S'  /*Corrosion of third degree of multiple sites of left ankle and foot, sequela*/
,'T25799D'  /*Corrosion of third degree of multiple sites of unspecified ankle and foot, subsequent encounter*/
,'T25799S'  /*Corrosion of third degree of multiple sites of unspecified ankle and foot, sequela*/
,'T2600XD'  /*Burn of unspecified eyelid and periocular area, subsequent encounter*/
,'T2600XS'  /*Burn of unspecified eyelid and periocular area, sequela*/
,'T2601XD'  /*Burn of right eyelid and periocular area, subsequent encounter*/
,'T2601XS'  /*Burn of right eyelid and periocular area, sequela*/
,'T2602XD'  /*Burn of left eyelid and periocular area, subsequent encounter*/
,'T2602XS'  /*Burn of left eyelid and periocular area, sequela*/
,'T2610XD'  /*Burn of cornea and conjunctival sac, unspecified eye, subsequent encounter*/
,'T2610XS'  /*Burn of cornea and conjunctival sac, unspecified eye, sequela*/
,'T2611XD'  /*Burn of cornea and conjunctival sac, right eye, subsequent encounter*/
,'T2611XS'  /*Burn of cornea and conjunctival sac, right eye, sequela*/
,'T2612XD'  /*Burn of cornea and conjunctival sac, left eye, subsequent encounter*/
,'T2612XS'  /*Burn of cornea and conjunctival sac, left eye, sequela*/
,'T2620XD'  /*Burn with resulting rupture and destruction of unspecified eyeball, subsequent encounter*/
,'T2620XS'  /*Burn with resulting rupture and destruction of unspecified eyeball, sequela*/
,'T2621XD'  /*Burn with resulting rupture and destruction of right eyeball, subsequent encounter*/
,'T2621XS'  /*Burn with resulting rupture and destruction of right eyeball, sequela*/
,'T2622XD'  /*Burn with resulting rupture and destruction of left eyeball, subsequent encounter*/
,'T2622XS'  /*Burn with resulting rupture and destruction of left eyeball, sequela*/
,'T2630XD'  /*Burns of other specified parts of unspecified eye and adnexa, subsequent encounter*/
,'T2630XS'  /*Burns of other specified parts of unspecified eye and adnexa, sequela*/
,'T2631XD'  /*Burns of other specified parts of right eye and adnexa, subsequent encounter*/
,'T2631XS'  /*Burns of other specified parts of right eye and adnexa, sequela*/
,'T2632XD'  /*Burns of other specified parts of left eye and adnexa, subsequent encounter*/
,'T2632XS'  /*Burns of other specified parts of left eye and adnexa, sequela*/
,'T2640XD'  /*Burn of unspecified eye and adnexa, part unspecified, subsequent encounter*/
,'T2640XS'  /*Burn of unspecified eye and adnexa, part unspecified, sequela*/
,'T2641XD'  /*Burn of right eye and adnexa, part unspecified, subsequent encounter*/
,'T2641XS'  /*Burn of right eye and adnexa, part unspecified, sequela*/
,'T2642XD'  /*Burn of left eye and adnexa, part unspecified, subsequent encounter*/
,'T2642XS'  /*Burn of left eye and adnexa, part unspecified, sequela*/
,'T2650XD'  /*Corrosion of unspecified eyelid and periocular area, subsequent encounter*/
,'T2650XS'  /*Corrosion of unspecified eyelid and periocular area, sequela*/
,'T2651XD'  /*Corrosion of right eyelid and periocular area, subsequent encounter*/
,'T2651XS'  /*Corrosion of right eyelid and periocular area, sequela*/
,'T2652XD'  /*Corrosion of left eyelid and periocular area, subsequent encounter*/
,'T2652XS'  /*Corrosion of left eyelid and periocular area, sequela*/
,'T2660XD'  /*Corrosion of cornea and conjunctival sac, unspecified eye, subsequent encounter*/
,'T2660XS'  /*Corrosion of cornea and conjunctival sac, unspecified eye, sequela*/
,'T2661XD'  /*Corrosion of cornea and conjunctival sac, right eye, subsequent encounter*/
,'T2661XS'  /*Corrosion of cornea and conjunctival sac, right eye, sequela*/
,'T2662XD'  /*Corrosion of cornea and conjunctival sac, left eye, subsequent encounter*/
,'T2662XS'  /*Corrosion of cornea and conjunctival sac, left eye, sequela*/
,'T2670XD'  /*Corrosion with resulting rupture and destruction of unspecified eyeball, subsequent encounter*/
,'T2670XS'  /*Corrosion with resulting rupture and destruction of unspecified eyeball, sequela*/
,'T2671XD'  /*Corrosion with resulting rupture and destruction of right eyeball, subsequent encounter*/
,'T2671XS'  /*Corrosion with resulting rupture and destruction of right eyeball, sequela*/
,'T2672XD'  /*Corrosion with resulting rupture and destruction of left eyeball, subsequent encounter*/
,'T2672XS'  /*Corrosion with resulting rupture and destruction of left eyeball, sequela*/
,'T2680XD'  /*Corrosions of other specified parts of unspecified eye and adnexa, subsequent encounter*/
,'T2680XS'  /*Corrosions of other specified parts of unspecified eye and adnexa, sequela*/
,'T2681XD'  /*Corrosions of other specified parts of right eye and adnexa, subsequent encounter*/
,'T2681XS'  /*Corrosions of other specified parts of right eye and adnexa, sequela*/
,'T2682XD'  /*Corrosions of other specified parts of left eye and adnexa, subsequent encounter*/
,'T2682XS'  /*Corrosions of other specified parts of left eye and adnexa, sequela*/
,'T2690XD'  /*Corrosion of unspecified eye and adnexa, part unspecified, subsequent encounter*/
,'T2690XS'  /*Corrosion of unspecified eye and adnexa, part unspecified, sequela*/
,'T2691XD'  /*Corrosion of right eye and adnexa, part unspecified, subsequent encounter*/
,'T2691XS'  /*Corrosion of right eye and adnexa, part unspecified, sequela*/
,'T2692XD'  /*Corrosion of left eye and adnexa, part unspecified, subsequent encounter*/
,'T2692XS'  /*Corrosion of left eye and adnexa, part unspecified, sequela*/
,'T270XXD'  /*Burn of larynx and trachea, subsequent encounter*/
,'T270XXS'  /*Burn of larynx and trachea, sequela*/
,'T271XXD'  /*Burn involving larynx and trachea with lung, subsequent encounter*/
,'T271XXS'  /*Burn involving larynx and trachea with lung, sequela*/
,'T272XXD'  /*Burn of other parts of respiratory tract, subsequent encounter*/
,'T272XXS'  /*Burn of other parts of respiratory tract, sequela*/
,'T273XXD'  /*Burn of respiratory tract, part unspecified, subsequent encounter*/
,'T273XXS'  /*Burn of respiratory tract, part unspecified, sequela*/
,'T274XXD'  /*Corrosion of larynx and trachea, subsequent encounter*/
,'T274XXS'  /*Corrosion of larynx and trachea, sequela*/
,'T275XXD'  /*Corrosion involving larynx and trachea with lung, subsequent encounter*/
,'T275XXS'  /*Corrosion involving larynx and trachea with lung, sequela*/
,'T276XXD'  /*Corrosion of other parts of respiratory tract, subsequent encounter*/
,'T276XXS'  /*Corrosion of other parts of respiratory tract, sequela*/
,'T277XXD'  /*Corrosion of respiratory tract, part unspecified, subsequent encounter*/
,'T277XXS'  /*Corrosion of respiratory tract, part unspecified, sequela*/
,'T280XXD'  /*Burn of mouth and pharynx, subsequent encounter*/
,'T280XXS'  /*Burn of mouth and pharynx, sequela*/
,'T281XXD'  /*Burn of esophagus, subsequent encounter*/
,'T281XXS'  /*Burn of esophagus, sequela*/
,'T282XXD'  /*Burn of other parts of alimentary tract, subsequent encounter*/
,'T282XXS'  /*Burn of other parts of alimentary tract, sequela*/
,'T283XXD'  /*Burn of internal genitourinary organs, subsequent encounter*/
,'T283XXS'  /*Burn of internal genitourinary organs, sequela*/
,'T2840XD'  /*Burn of unspecified internal organ, subsequent encounter*/
,'T2840XS'  /*Burn of unspecified internal organ, sequela*/
,'T28411D'  /*Burn of right ear drum, subsequent encounter*/
,'T28411S'  /*Burn of right ear drum, sequela*/
,'T28412D'  /*Burn of left ear drum, subsequent encounter*/
,'T28412S'  /*Burn of left ear drum, sequela*/
,'T28419D'  /*Burn of unspecified ear drum, subsequent encounter*/
,'T28419S'  /*Burn of unspecified ear drum, sequela*/
,'T2849XD'  /*Burn of other internal organ, subsequent encounter*/
,'T2849XS'  /*Burn of other internal organ, sequela*/
,'T285XXD'  /*Corrosion of mouth and pharynx, subsequent encounter*/
,'T285XXS'  /*Corrosion of mouth and pharynx, sequela*/
,'T286XXD'  /*Corrosion of esophagus, subsequent encounter*/
,'T286XXS'  /*Corrosion of esophagus, sequela*/
,'T287XXD'  /*Corrosion of other parts of alimentary tract, subsequent encounter*/
,'T287XXS'  /*Corrosion of other parts of alimentary tract, sequela*/
,'T288XXD'  /*Corrosion of internal genitourinary organs, subsequent encounter*/
,'T288XXS'  /*Corrosion of internal genitourinary organs, sequela*/
,'T2890XD'  /*Corrosions of unspecified internal organs, subsequent encounter*/
,'T2890XS'  /*Corrosions of unspecified internal organs, sequela*/
,'T28911D'  /*Corrosions of right ear drum, subsequent encounter*/
,'T28911S'  /*Corrosions of right ear drum, sequela*/
,'T28912D'  /*Corrosions of left ear drum, subsequent encounter*/
,'T28912S'  /*Corrosions of left ear drum, sequela*/
,'T28919D'  /*Corrosions of unspecified ear drum, subsequent encounter*/
,'T28919S'  /*Corrosions of unspecified ear drum, sequela*/
,'T2899XD'  /*Corrosions of other internal organs, subsequent encounter*/
,'T2899XS'  /*Corrosions of other internal organs, sequela*/
,'T33011D'  /*Superficial frostbite of right ear, subsequent encounter*/
,'T33011S'  /*Superficial frostbite of right ear, sequela*/
,'T33012D'  /*Superficial frostbite of left ear, subsequent encounter*/
,'T33012S'  /*Superficial frostbite of left ear, sequela*/
,'T33019D'  /*Superficial frostbite of unspecified ear, subsequent encounter*/
,'T33019S'  /*Superficial frostbite of unspecified ear, sequela*/
,'T3302XD'  /*Superficial frostbite of nose, subsequent encounter*/
,'T3302XS'  /*Superficial frostbite of nose, sequela*/
,'T3309XD'  /*Superficial frostbite of other part of head, subsequent encounter*/
,'T3309XS'  /*Superficial frostbite of other part of head, sequela*/
,'T331XXD'  /*Superficial frostbite of neck, subsequent encounter*/
,'T331XXS'  /*Superficial frostbite of neck, sequela*/
,'T332XXD'  /*Superficial frostbite of thorax, subsequent encounter*/
,'T332XXS'  /*Superficial frostbite of thorax, sequela*/
,'T333XXD'  /*Superficial frostbite of abdominal wall, lower back and pelvis, subsequent encounter*/
,'T333XXS'  /*Superficial frostbite of abdominal wall, lower back and pelvis, sequela*/
,'T3340XD'  /*Superficial frostbite of unspecified arm, subsequent encounter*/
,'T3340XS'  /*Superficial frostbite of unspecified arm, sequela*/
,'T3341XD'  /*Superficial frostbite of right arm, subsequent encounter*/
,'T3341XS'  /*Superficial frostbite of right arm, sequela*/
,'T3342XD'  /*Superficial frostbite of left arm, subsequent encounter*/
,'T3342XS'  /*Superficial frostbite of left arm, sequela*/
,'T33511D'  /*Superficial frostbite of right wrist, subsequent encounter*/
,'T33511S'  /*Superficial frostbite of right wrist, sequela*/
,'T33512D'  /*Superficial frostbite of left wrist, subsequent encounter*/
,'T33512S'  /*Superficial frostbite of left wrist, sequela*/
,'T33519D'  /*Superficial frostbite of unspecified wrist, subsequent encounter*/
,'T33519S'  /*Superficial frostbite of unspecified wrist, sequela*/
,'T33521D'  /*Superficial frostbite of right hand, subsequent encounter*/
,'T33521S'  /*Superficial frostbite of right hand, sequela*/
,'T33522D'  /*Superficial frostbite of left hand, subsequent encounter*/
,'T33522S'  /*Superficial frostbite of left hand, sequela*/
,'T33529D'  /*Superficial frostbite of unspecified hand, subsequent encounter*/
,'T33529S'  /*Superficial frostbite of unspecified hand, sequela*/
,'T33531D'  /*Superficial frostbite of right finger(s), subsequent encounter*/
,'T33531S'  /*Superficial frostbite of right finger(s), sequela*/
,'T33532D'  /*Superficial frostbite of left finger(s), subsequent encounter*/
,'T33532S'  /*Superficial frostbite of left finger(s), sequela*/
,'T33539D'  /*Superficial frostbite of unspecified finger(s), subsequent encounter*/
,'T33539S'  /*Superficial frostbite of unspecified finger(s), sequela*/
,'T3360XD'  /*Superficial frostbite of unspecified hip and thigh, subsequent encounter*/
,'T3360XS'  /*Superficial frostbite of unspecified hip and thigh, sequela*/
,'T3361XD'  /*Superficial frostbite of right hip and thigh, subsequent encounter*/
,'T3361XS'  /*Superficial frostbite of right hip and thigh, sequela*/
,'T3362XD'  /*Superficial frostbite of left hip and thigh, subsequent encounter*/
,'T3362XS'  /*Superficial frostbite of left hip and thigh, sequela*/
,'T3370XD'  /*Superficial frostbite of unspecified knee and lower leg, subsequent encounter*/
,'T3370XS'  /*Superficial frostbite of unspecified knee and lower leg, sequela*/
,'T3371XD'  /*Superficial frostbite of right knee and lower leg, subsequent encounter*/
,'T3371XS'  /*Superficial frostbite of right knee and lower leg, sequela*/
,'T3372XD'  /*Superficial frostbite of left knee and lower leg, subsequent encounter*/
,'T3372XS'  /*Superficial frostbite of left knee and lower leg, sequela*/
,'T33811D'  /*Superficial frostbite of right ankle, subsequent encounter*/
,'T33811S'  /*Superficial frostbite of right ankle, sequela*/
,'T33812D'  /*Superficial frostbite of left ankle, subsequent encounter*/
,'T33812S'  /*Superficial frostbite of left ankle, sequela*/
,'T33819D'  /*Superficial frostbite of unspecified ankle, subsequent encounter*/
,'T33819S'  /*Superficial frostbite of unspecified ankle, sequela*/
,'T33821D'  /*Superficial frostbite of right foot, subsequent encounter*/
,'T33821S'  /*Superficial frostbite of right foot, sequela*/
,'T33822D'  /*Superficial frostbite of left foot, subsequent encounter*/
,'T33822S'  /*Superficial frostbite of left foot, sequela*/
,'T33829D'  /*Superficial frostbite of unspecified foot, subsequent encounter*/
,'T33829S'  /*Superficial frostbite of unspecified foot, sequela*/
,'T33831D'  /*Superficial frostbite of right toe(s), subsequent encounter*/
,'T33831S'  /*Superficial frostbite of right toe(s), sequela*/
,'T33832D'  /*Superficial frostbite of left toe(s), subsequent encounter*/
,'T33832S'  /*Superficial frostbite of left toe(s), sequela*/
,'T33839D'  /*Superficial frostbite of unspecified toe(s), subsequent encounter*/
,'T33839S'  /*Superficial frostbite of unspecified toe(s), sequela*/
,'T3390XD'  /*Superficial frostbite of unspecified sites, subsequent encounter*/
,'T3390XS'  /*Superficial frostbite of unspecified sites, sequela*/
,'T3399XD'  /*Superficial frostbite of other sites, subsequent encounter*/
,'T3399XS'  /*Superficial frostbite of other sites, sequela*/
,'T34011D'  /*Frostbite with tissue necrosis of right ear, subsequent encounter*/
,'T34011S'  /*Frostbite with tissue necrosis of right ear, sequela*/
,'T34012D'  /*Frostbite with tissue necrosis of left ear, subsequent encounter*/
,'T34012S'  /*Frostbite with tissue necrosis of left ear, sequela*/
,'T34019D'  /*Frostbite with tissue necrosis of unspecified ear, subsequent encounter*/
,'T34019S'  /*Frostbite with tissue necrosis of unspecified ear, sequela*/
,'T3402XD'  /*Frostbite with tissue necrosis of nose, subsequent encounter*/
,'T3402XS'  /*Frostbite with tissue necrosis of nose, sequela*/
,'T3409XD'  /*Frostbite with tissue necrosis of other part of head, subsequent encounter*/
,'T3409XS'  /*Frostbite with tissue necrosis of other part of head, sequela*/
,'T341XXD'  /*Frostbite with tissue necrosis of neck, subsequent encounter*/
,'T341XXS'  /*Frostbite with tissue necrosis of neck, sequela*/
,'T342XXD'  /*Frostbite with tissue necrosis of thorax, subsequent encounter*/
,'T342XXS'  /*Frostbite with tissue necrosis of thorax, sequela*/
,'T343XXD'  /*Frostbite with tissue necrosis of abdominal wall, lower back and pelvis, subsequent encounter*/
,'T343XXS'  /*Frostbite with tissue necrosis of abdominal wall, lower back and pelvis, sequela*/
,'T3440XD'  /*Frostbite with tissue necrosis of unspecified arm, subsequent encounter*/
,'T3440XS'  /*Frostbite with tissue necrosis of unspecified arm, sequela*/
,'T3441XD'  /*Frostbite with tissue necrosis of right arm, subsequent encounter*/
,'T3441XS'  /*Frostbite with tissue necrosis of right arm, sequela*/
,'T3442XD'  /*Frostbite with tissue necrosis of left arm, subsequent encounter*/
,'T3442XS'  /*Frostbite with tissue necrosis of left arm, sequela*/
,'T34511D'  /*Frostbite with tissue necrosis of right wrist, subsequent encounter*/
,'T34511S'  /*Frostbite with tissue necrosis of right wrist, sequela*/
,'T34512D'  /*Frostbite with tissue necrosis of left wrist, subsequent encounter*/
,'T34512S'  /*Frostbite with tissue necrosis of left wrist, sequela*/
,'T34519D'  /*Frostbite with tissue necrosis of unspecified wrist, subsequent encounter*/
,'T34519S'  /*Frostbite with tissue necrosis of unspecified wrist, sequela*/
,'T34521D'  /*Frostbite with tissue necrosis of right hand, subsequent encounter*/
,'T34521S'  /*Frostbite with tissue necrosis of right hand, sequela*/
,'T34522D'  /*Frostbite with tissue necrosis of left hand, subsequent encounter*/
,'T34522S'  /*Frostbite with tissue necrosis of left hand, sequela*/
,'T34529D'  /*Frostbite with tissue necrosis of unspecified hand, subsequent encounter*/
,'T34529S'  /*Frostbite with tissue necrosis of unspecified hand, sequela*/
,'T34531D'  /*Frostbite with tissue necrosis of right finger(s), subsequent encounter*/
,'T34531S'  /*Frostbite with tissue necrosis of right finger(s), sequela*/
,'T34532D'  /*Frostbite with tissue necrosis of left finger(s), subsequent encounter*/
,'T34532S'  /*Frostbite with tissue necrosis of left finger(s), sequela*/
,'T34539D'  /*Frostbite with tissue necrosis of unspecified finger(s), subsequent encounter*/
,'T34539S'  /*Frostbite with tissue necrosis of unspecified finger(s), sequela*/
,'T3460XD'  /*Frostbite with tissue necrosis of unspecified hip and thigh, subsequent encounter*/
,'T3460XS'  /*Frostbite with tissue necrosis of unspecified hip and thigh, sequela*/
,'T3461XD'  /*Frostbite with tissue necrosis of right hip and thigh, subsequent encounter*/
,'T3461XS'  /*Frostbite with tissue necrosis of right hip and thigh, sequela*/
,'T3462XD'  /*Frostbite with tissue necrosis of left hip and thigh, subsequent encounter*/
,'T3462XS'  /*Frostbite with tissue necrosis of left hip and thigh, sequela*/
,'T3470XD'  /*Frostbite with tissue necrosis of unspecified knee and lower leg, subsequent encounter*/
,'T3470XS'  /*Frostbite with tissue necrosis of unspecified knee and lower leg, sequela*/
,'T3471XD'  /*Frostbite with tissue necrosis of right knee and lower leg, subsequent encounter*/
,'T3471XS'  /*Frostbite with tissue necrosis of right knee and lower leg, sequela*/
,'T3472XD'  /*Frostbite with tissue necrosis of left knee and lower leg, subsequent encounter*/
,'T3472XS'  /*Frostbite with tissue necrosis of left knee and lower leg, sequela*/
,'T34811D'  /*Frostbite with tissue necrosis of right ankle, subsequent encounter*/
,'T34811S'  /*Frostbite with tissue necrosis of right ankle, sequela*/
,'T34812D'  /*Frostbite with tissue necrosis of left ankle, subsequent encounter*/
,'T34812S'  /*Frostbite with tissue necrosis of left ankle, sequela*/
,'T34819D'  /*Frostbite with tissue necrosis of unspecified ankle, subsequent encounter*/
,'T34819S'  /*Frostbite with tissue necrosis of unspecified ankle, sequela*/
,'T34821D'  /*Frostbite with tissue necrosis of right foot, subsequent encounter*/
,'T34821S'  /*Frostbite with tissue necrosis of right foot, sequela*/
,'T34822D'  /*Frostbite with tissue necrosis of left foot, subsequent encounter*/
,'T34822S'  /*Frostbite with tissue necrosis of left foot, sequela*/
,'T34829D'  /*Frostbite with tissue necrosis of unspecified foot, subsequent encounter*/
,'T34829S'  /*Frostbite with tissue necrosis of unspecified foot, sequela*/
,'T34831D'  /*Frostbite with tissue necrosis of right toe(s), subsequent encounter*/
,'T34831S'  /*Frostbite with tissue necrosis of right toe(s), sequela*/
,'T34832D'  /*Frostbite with tissue necrosis of left toe(s), subsequent encounter*/
,'T34832S'  /*Frostbite with tissue necrosis of left toe(s), sequela*/
,'T34839D'  /*Frostbite with tissue necrosis of unspecified toe(s), subsequent encounter*/
,'T34839S'  /*Frostbite with tissue necrosis of unspecified toe(s), sequela*/
,'T3490XD'  /*Frostbite with tissue necrosis of unspecified sites, subsequent encounter*/
,'T3490XS'  /*Frostbite with tissue necrosis of unspecified sites, sequela*/
,'T3499XD'  /*Frostbite with tissue necrosis of other sites, subsequent encounter*/
,'T3499XS'  /*Frostbite with tissue necrosis of other sites, sequela*/
,'T360X1D'  /*Poisoning by penicillins, accidental (unintentional), subsequent encounter*/
,'T360X1S'  /*Poisoning by penicillins, accidental (unintentional), sequela*/
,'T360X2D'  /*Poisoning by penicillins, intentional self-harm, subsequent encounter*/
,'T360X2S'  /*Poisoning by penicillins, intentional self-harm, sequela*/
,'T360X3D'  /*Poisoning by penicillins, assault, subsequent encounter*/
,'T360X3S'  /*Poisoning by penicillins, assault, sequela*/
,'T360X4D'  /*Poisoning by penicillins, undetermined, subsequent encounter*/
,'T360X4S'  /*Poisoning by penicillins, undetermined, sequela*/
,'T360X5D'  /*Adverse effect of penicillins, subsequent encounter*/
,'T360X5S'  /*Adverse effect of penicillins, sequela*/
,'T360X6D'  /*Underdosing of penicillins, subsequent encounter*/
,'T360X6S'  /*Underdosing of penicillins, sequela*/
,'T361X1D'  /*Poisoning by cephalosporins and other beta-lactam antibiotics, accidental (unintentional), subsequent encounter*/
,'T361X1S'  /*Poisoning by cephalosporins and other beta-lactam antibiotics, accidental (unintentional), sequela*/
,'T361X2D'  /*Poisoning by cephalosporins and other beta-lactam antibiotics, intentional self-harm, subsequent encounter*/
,'T361X2S'  /*Poisoning by cephalosporins and other beta-lactam antibiotics, intentional self-harm, sequela*/
,'T361X3D'  /*Poisoning by cephalosporins and other beta-lactam antibiotics, assault, subsequent encounter*/
,'T361X3S'  /*Poisoning by cephalosporins and other beta-lactam antibiotics, assault, sequela*/
,'T361X4D'  /*Poisoning by cephalosporins and other beta-lactam antibiotics, undetermined, subsequent encounter*/
,'T361X4S'  /*Poisoning by cephalosporins and other beta-lactam antibiotics, undetermined, sequela*/
,'T361X5D'  /*Adverse effect of cephalosporins and other beta-lactam antibiotics, subsequent encounter*/
,'T361X5S'  /*Adverse effect of cephalosporins and other beta-lactam antibiotics, sequela*/
,'T361X6D'  /*Underdosing of cephalosporins and other beta-lactam antibiotics, subsequent encounter*/
,'T361X6S'  /*Underdosing of cephalosporins and other beta-lactam antibiotics, sequela*/
,'T362X1D'  /*Poisoning by chloramphenicol group, accidental (unintentional), subsequent encounter*/
,'T362X1S'  /*Poisoning by chloramphenicol group, accidental (unintentional), sequela*/
,'T362X2D'  /*Poisoning by chloramphenicol group, intentional self-harm, subsequent encounter*/
,'T362X2S'  /*Poisoning by chloramphenicol group, intentional self-harm, sequela*/
,'T362X3D'  /*Poisoning by chloramphenicol group, assault, subsequent encounter*/
,'T362X3S'  /*Poisoning by chloramphenicol group, assault, sequela*/
,'T362X4D'  /*Poisoning by chloramphenicol group, undetermined, subsequent encounter*/
,'T362X4S'  /*Poisoning by chloramphenicol group, undetermined, sequela*/
,'T362X5D'  /*Adverse effect of chloramphenicol group, subsequent encounter*/
,'T362X5S'  /*Adverse effect of chloramphenicol group, sequela*/
,'T362X6D'  /*Underdosing of chloramphenicol group, subsequent encounter*/
,'T362X6S'  /*Underdosing of chloramphenicol group, sequela*/
,'T363X1D'  /*Poisoning by macrolides, accidental (unintentional), subsequent encounter*/
,'T363X1S'  /*Poisoning by macrolides, accidental (unintentional), sequela*/
,'T363X2D'  /*Poisoning by macrolides, intentional self-harm, subsequent encounter*/
,'T363X2S'  /*Poisoning by macrolides, intentional self-harm, sequela*/
,'T363X3D'  /*Poisoning by macrolides, assault, subsequent encounter*/
,'T363X3S'  /*Poisoning by macrolides, assault, sequela*/
,'T363X4D'  /*Poisoning by macrolides, undetermined, subsequent encounter*/
,'T363X4S'  /*Poisoning by macrolides, undetermined, sequela*/
,'T363X5D'  /*Adverse effect of macrolides, subsequent encounter*/
,'T363X5S'  /*Adverse effect of macrolides, sequela*/
,'T363X6D'  /*Underdosing of macrolides, subsequent encounter*/
,'T363X6S'  /*Underdosing of macrolides, sequela*/
,'T364X1D'  /*Poisoning by tetracyclines, accidental (unintentional), subsequent encounter*/
,'T364X1S'  /*Poisoning by tetracyclines, accidental (unintentional), sequela*/
,'T364X2D'  /*Poisoning by tetracyclines, intentional self-harm, subsequent encounter*/
,'T364X2S'  /*Poisoning by tetracyclines, intentional self-harm, sequela*/
,'T364X3D'  /*Poisoning by tetracyclines, assault, subsequent encounter*/
,'T364X3S'  /*Poisoning by tetracyclines, assault, sequela*/
,'T364X4D'  /*Poisoning by tetracyclines, undetermined, subsequent encounter*/
,'T364X4S'  /*Poisoning by tetracyclines, undetermined, sequela*/
,'T364X5D'  /*Adverse effect of tetracyclines, subsequent encounter*/
,'T364X5S'  /*Adverse effect of tetracyclines, sequela*/
,'T364X6D'  /*Underdosing of tetracyclines, subsequent encounter*/
,'T364X6S'  /*Underdosing of tetracyclines, sequela*/
,'T365X1D'  /*Poisoning by aminoglycosides, accidental (unintentional), subsequent encounter*/
,'T365X1S'  /*Poisoning by aminoglycosides, accidental (unintentional), sequela*/
,'T365X2D'  /*Poisoning by aminoglycosides, intentional self-harm, subsequent encounter*/
,'T365X2S'  /*Poisoning by aminoglycosides, intentional self-harm, sequela*/
,'T365X3D'  /*Poisoning by aminoglycosides, assault, subsequent encounter*/
,'T365X3S'  /*Poisoning by aminoglycosides, assault, sequela*/
,'T365X4D'  /*Poisoning by aminoglycosides, undetermined, subsequent encounter*/
,'T365X4S'  /*Poisoning by aminoglycosides, undetermined, sequela*/
,'T365X5D'  /*Adverse effect of aminoglycosides, subsequent encounter*/
,'T365X5S'  /*Adverse effect of aminoglycosides, sequela*/
,'T365X6D'  /*Underdosing of aminoglycosides, subsequent encounter*/
,'T365X6S'  /*Underdosing of aminoglycosides, sequela*/
,'T366X1D'  /*Poisoning by rifampicins, accidental (unintentional), subsequent encounter*/
,'T366X1S'  /*Poisoning by rifampicins, accidental (unintentional), sequela*/
,'T366X2D'  /*Poisoning by rifampicins, intentional self-harm, subsequent encounter*/
,'T366X2S'  /*Poisoning by rifampicins, intentional self-harm, sequela*/
,'T366X3D'  /*Poisoning by rifampicins, assault, subsequent encounter*/
,'T366X3S'  /*Poisoning by rifampicins, assault, sequela*/
,'T366X4D'  /*Poisoning by rifampicins, undetermined, subsequent encounter*/
,'T366X4S'  /*Poisoning by rifampicins, undetermined, sequela*/
,'T366X5D'  /*Adverse effect of rifampicins, subsequent encounter*/
,'T366X5S'  /*Adverse effect of rifampicins, sequela*/
,'T366X6D'  /*Underdosing of rifampicins, subsequent encounter*/
,'T366X6S'  /*Underdosing of rifampicins, sequela*/
,'T367X1D'  /*Poisoning by antifungal antibiotics, systemically used, accidental (unintentional), subsequent encounter*/
,'T367X1S'  /*Poisoning by antifungal antibiotics, systemically used, accidental (unintentional), sequela*/
,'T367X2D'  /*Poisoning by antifungal antibiotics, systemically used, intentional self-harm, subsequent encounter*/
,'T367X2S'  /*Poisoning by antifungal antibiotics, systemically used, intentional self-harm, sequela*/
,'T367X3D'  /*Poisoning by antifungal antibiotics, systemically used, assault, subsequent encounter*/
,'T367X3S'  /*Poisoning by antifungal antibiotics, systemically used, assault, sequela*/
,'T367X4D'  /*Poisoning by antifungal antibiotics, systemically used, undetermined, subsequent encounter*/
,'T367X4S'  /*Poisoning by antifungal antibiotics, systemically used, undetermined, sequela*/
,'T367X5D'  /*Adverse effect of antifungal antibiotics, systemically used, subsequent encounter*/
,'T367X5S'  /*Adverse effect of antifungal antibiotics, systemically used, sequela*/
,'T367X6D'  /*Underdosing of antifungal antibiotics, systemically used, subsequent encounter*/
,'T367X6S'  /*Underdosing of antifungal antibiotics, systemically used, sequela*/
,'T368X1D'  /*Poisoning by other systemic antibiotics, accidental (unintentional), subsequent encounter*/
,'T368X1S'  /*Poisoning by other systemic antibiotics, accidental (unintentional), sequela*/
,'T368X2D'  /*Poisoning by other systemic antibiotics, intentional self-harm, subsequent encounter*/
,'T368X2S'  /*Poisoning by other systemic antibiotics, intentional self-harm, sequela*/
,'T368X3D'  /*Poisoning by other systemic antibiotics, assault, subsequent encounter*/
,'T368X3S'  /*Poisoning by other systemic antibiotics, assault, sequela*/
,'T368X4D'  /*Poisoning by other systemic antibiotics, undetermined, subsequent encounter*/
,'T368X4S'  /*Poisoning by other systemic antibiotics, undetermined, sequela*/
,'T368X5D'  /*Adverse effect of other systemic antibiotics, subsequent encounter*/
,'T368X5S'  /*Adverse effect of other systemic antibiotics, sequela*/
,'T368X6D'  /*Underdosing of other systemic antibiotics, subsequent encounter*/
,'T368X6S'  /*Underdosing of other systemic antibiotics, sequela*/
,'T3691XD'  /*Poisoning by unspecified systemic antibiotic, accidental (unintentional), subsequent encounter*/
,'T3691XS'  /*Poisoning by unspecified systemic antibiotic, accidental (unintentional), sequela*/
,'T3692XD'  /*Poisoning by unspecified systemic antibiotic, intentional self-harm, subsequent encounter*/
,'T3692XS'  /*Poisoning by unspecified systemic antibiotic, intentional self-harm, sequela*/
,'T3693XD'  /*Poisoning by unspecified systemic antibiotic, assault, subsequent encounter*/
,'T3693XS'  /*Poisoning by unspecified systemic antibiotic, assault, sequela*/
,'T3694XD'  /*Poisoning by unspecified systemic antibiotic, undetermined, subsequent encounter*/
,'T3694XS'  /*Poisoning by unspecified systemic antibiotic, undetermined, sequela*/
,'T3695XD'  /*Adverse effect of unspecified systemic antibiotic, subsequent encounter*/
,'T3695XS'  /*Adverse effect of unspecified systemic antibiotic, sequela*/
,'T3696XD'  /*Underdosing of unspecified systemic antibiotic, subsequent encounter*/
,'T3696XS'  /*Underdosing of unspecified systemic antibiotic, sequela*/
,'T370X1D'  /*Poisoning by sulfonamides, accidental (unintentional), subsequent encounter*/
,'T370X1S'  /*Poisoning by sulfonamides, accidental (unintentional), sequela*/
,'T370X2D'  /*Poisoning by sulfonamides, intentional self-harm, subsequent encounter*/
,'T370X2S'  /*Poisoning by sulfonamides, intentional self-harm, sequela*/
,'T370X3D'  /*Poisoning by sulfonamides, assault, subsequent encounter*/
,'T370X3S'  /*Poisoning by sulfonamides, assault, sequela*/
,'T370X4D'  /*Poisoning by sulfonamides, undetermined, subsequent encounter*/
,'T370X4S'  /*Poisoning by sulfonamides, undetermined, sequela*/
,'T370X5D'  /*Adverse effect of sulfonamides, subsequent encounter*/
,'T370X5S'  /*Adverse effect of sulfonamides, sequela*/
,'T370X6D'  /*Underdosing of sulfonamides, subsequent encounter*/
,'T370X6S'  /*Underdosing of sulfonamides, sequela*/
,'T371X1D'  /*Poisoning by antimycobacterial drugs, accidental (unintentional), subsequent encounter*/
,'T371X1S'  /*Poisoning by antimycobacterial drugs, accidental (unintentional), sequela*/
,'T371X2D'  /*Poisoning by antimycobacterial drugs, intentional self-harm, subsequent encounter*/
,'T371X2S'  /*Poisoning by antimycobacterial drugs, intentional self-harm, sequela*/
,'T371X3D'  /*Poisoning by antimycobacterial drugs, assault, subsequent encounter*/
,'T371X3S'  /*Poisoning by antimycobacterial drugs, assault, sequela*/
,'T371X4D'  /*Poisoning by antimycobacterial drugs, undetermined, subsequent encounter*/
,'T371X4S'  /*Poisoning by antimycobacterial drugs, undetermined, sequela*/
,'T371X5D'  /*Adverse effect of antimycobacterial drugs, subsequent encounter*/
,'T371X5S'  /*Adverse effect of antimycobacterial drugs, sequela*/
,'T371X6D'  /*Underdosing of antimycobacterial drugs, subsequent encounter*/
,'T371X6S'  /*Underdosing of antimycobacterial drugs, sequela*/
,'T372X1D'  /*Poisoning by antimalarials and drugs acting on other blood protozoa, accidental (unintentional), subsequent encounter*/
,'T372X1S'  /*Poisoning by antimalarials and drugs acting on other blood protozoa, accidental (unintentional), sequela*/
,'T372X2D'  /*Poisoning by antimalarials and drugs acting on other blood protozoa, intentional self-harm, subsequent encounter*/
,'T372X2S'  /*Poisoning by antimalarials and drugs acting on other blood protozoa, intentional self-harm, sequela*/
,'T372X3D'  /*Poisoning by antimalarials and drugs acting on other blood protozoa, assault, subsequent encounter*/
,'T372X3S'  /*Poisoning by antimalarials and drugs acting on other blood protozoa, assault, sequela*/
,'T372X4D'  /*Poisoning by antimalarials and drugs acting on other blood protozoa, undetermined, subsequent encounter*/
,'T372X4S'  /*Poisoning by antimalarials and drugs acting on other blood protozoa, undetermined, sequela*/
,'T372X5D'  /*Adverse effect of antimalarials and drugs acting on other blood protozoa, subsequent encounter*/
,'T372X5S'  /*Adverse effect of antimalarials and drugs acting on other blood protozoa, sequela*/
,'T372X6D'  /*Underdosing of antimalarials and drugs acting on other blood protozoa, subsequent encounter*/
,'T372X6S'  /*Underdosing of antimalarials and drugs acting on other blood protozoa, sequela*/
,'T373X1D'  /*Poisoning by other antiprotozoal drugs, accidental (unintentional), subsequent encounter*/
,'T373X1S'  /*Poisoning by other antiprotozoal drugs, accidental (unintentional), sequela*/
,'T373X2D'  /*Poisoning by other antiprotozoal drugs, intentional self-harm, subsequent encounter*/
,'T373X2S'  /*Poisoning by other antiprotozoal drugs, intentional self-harm, sequela*/
,'T373X3D'  /*Poisoning by other antiprotozoal drugs, assault, subsequent encounter*/
,'T373X3S'  /*Poisoning by other antiprotozoal drugs, assault, sequela*/
,'T373X4D'  /*Poisoning by other antiprotozoal drugs, undetermined, subsequent encounter*/
,'T373X4S'  /*Poisoning by other antiprotozoal drugs, undetermined, sequela*/
,'T373X5D'  /*Adverse effect of other antiprotozoal drugs, subsequent encounter*/
,'T373X5S'  /*Adverse effect of other antiprotozoal drugs, sequela*/
,'T373X6D'  /*Underdosing of other antiprotozoal drugs, subsequent encounter*/
,'T373X6S'  /*Underdosing of other antiprotozoal drugs, sequela*/
,'T374X1D'  /*Poisoning by anthelminthics, accidental (unintentional), subsequent encounter*/
,'T374X1S'  /*Poisoning by anthelminthics, accidental (unintentional), sequela*/
,'T374X2D'  /*Poisoning by anthelminthics, intentional self-harm, subsequent encounter*/
,'T374X2S'  /*Poisoning by anthelminthics, intentional self-harm, sequela*/
,'T374X3D'  /*Poisoning by anthelminthics, assault, subsequent encounter*/
,'T374X3S'  /*Poisoning by anthelminthics, assault, sequela*/
,'T374X4D'  /*Poisoning by anthelminthics, undetermined, subsequent encounter*/
,'T374X4S'  /*Poisoning by anthelminthics, undetermined, sequela*/
,'T374X5D'  /*Adverse effect of anthelminthics, subsequent encounter*/
,'T374X5S'  /*Adverse effect of anthelminthics, sequela*/
,'T374X6D'  /*Underdosing of anthelminthics, subsequent encounter*/
,'T374X6S'  /*Underdosing of anthelminthics, sequela*/
,'T375X1D'  /*Poisoning by antiviral drugs, accidental (unintentional), subsequent encounter*/
,'T375X1S'  /*Poisoning by antiviral drugs, accidental (unintentional), sequela*/
,'T375X2D'  /*Poisoning by antiviral drugs, intentional self-harm, subsequent encounter*/
,'T375X2S'  /*Poisoning by antiviral drugs, intentional self-harm, sequela*/
,'T375X3D'  /*Poisoning by antiviral drugs, assault, subsequent encounter*/
,'T375X3S'  /*Poisoning by antiviral drugs, assault, sequela*/
,'T375X4D'  /*Poisoning by antiviral drugs, undetermined, subsequent encounter*/
,'T375X4S'  /*Poisoning by antiviral drugs, undetermined, sequela*/
,'T375X5D'  /*Adverse effect of antiviral drugs, subsequent encounter*/
,'T375X5S'  /*Adverse effect of antiviral drugs, sequela*/
,'T375X6D'  /*Underdosing of antiviral drugs, subsequent encounter*/
,'T375X6S'  /*Underdosing of antiviral drugs, sequela*/
,'T378X1D'  /*Poisoning by other specified systemic anti-infectives and antiparasitics, accidental (unintentional), subsequent encounter*/
,'T378X1S'  /*Poisoning by other specified systemic anti-infectives and antiparasitics, accidental (unintentional), sequela*/
,'T378X2D'  /*Poisoning by other specified systemic anti-infectives and antiparasitics, intentional self-harm, subsequent encounter*/
,'T378X2S'  /*Poisoning by other specified systemic anti-infectives and antiparasitics, intentional self-harm, sequela*/
,'T378X3D'  /*Poisoning by other specified systemic anti-infectives and antiparasitics, assault, subsequent encounter*/
,'T378X3S'  /*Poisoning by other specified systemic anti-infectives and antiparasitics, assault, sequela*/
,'T378X4D'  /*Poisoning by other specified systemic anti-infectives and antiparasitics, undetermined, subsequent encounter*/
,'T378X4S'  /*Poisoning by other specified systemic anti-infectives and antiparasitics, undetermined, sequela*/
,'T378X5D'  /*Adverse effect of other specified systemic anti-infectives and antiparasitics, subsequent encounter*/
,'T378X5S'  /*Adverse effect of other specified systemic anti-infectives and antiparasitics, sequela*/
,'T378X6D'  /*Underdosing of other specified systemic anti-infectives and antiparasitics, subsequent encounter*/
,'T378X6S'  /*Underdosing of other specified systemic anti-infectives and antiparasitics, sequela*/
,'T3791XD'  /*Poisoning by unspecified systemic anti-infective and antiparasitics, accidental (unintentional), subsequent encounter*/
,'T3791XS'  /*Poisoning by unspecified systemic anti-infective and antiparasitics, accidental (unintentional), sequela*/
,'T3792XD'  /*Poisoning by unspecified systemic anti-infective and antiparasitics, intentional self-harm, subsequent encounter*/
,'T3792XS'  /*Poisoning by unspecified systemic anti-infective and antiparasitics, intentional self-harm, sequela*/
,'T3793XD'  /*Poisoning by unspecified systemic anti-infective and antiparasitics, assault, subsequent encounter*/
,'T3793XS'  /*Poisoning by unspecified systemic anti-infective and antiparasitics, assault, sequela*/
,'T3794XD'  /*Poisoning by unspecified systemic anti-infective and antiparasitics, undetermined, subsequent encounter*/
,'T3794XS'  /*Poisoning by unspecified systemic anti-infective and antiparasitics, undetermined, sequela*/
,'T3795XD'  /*Adverse effect of unspecified systemic anti-infective and antiparasitic, subsequent encounter*/
,'T3795XS'  /*Adverse effect of unspecified systemic anti-infective and antiparasitic, sequela*/
,'T3796XD'  /*Underdosing of unspecified systemic anti-infectives and antiparasitics, subsequent encounter*/
,'T3796XS'  /*Underdosing of unspecified systemic anti-infectives and antiparasitics, sequela*/
,'T380X1D'  /*Poisoning by glucocorticoids and synthetic analogues, accidental (unintentional), subsequent encounter*/
,'T380X1S'  /*Poisoning by glucocorticoids and synthetic analogues, accidental (unintentional), sequela*/
,'T380X2D'  /*Poisoning by glucocorticoids and synthetic analogues, intentional self-harm, subsequent encounter*/
,'T380X2S'  /*Poisoning by glucocorticoids and synthetic analogues, intentional self-harm, sequela*/
,'T380X3D'  /*Poisoning by glucocorticoids and synthetic analogues, assault, subsequent encounter*/
,'T380X3S'  /*Poisoning by glucocorticoids and synthetic analogues, assault, sequela*/
,'T380X4D'  /*Poisoning by glucocorticoids and synthetic analogues, undetermined, subsequent encounter*/
,'T380X4S'  /*Poisoning by glucocorticoids and synthetic analogues, undetermined, sequela*/
,'T380X5D'  /*Adverse effect of glucocorticoids and synthetic analogues, subsequent encounter*/
,'T380X5S'  /*Adverse effect of glucocorticoids and synthetic analogues, sequela*/
,'T380X6D'  /*Underdosing of glucocorticoids and synthetic analogues, subsequent encounter*/
,'T380X6S'  /*Underdosing of glucocorticoids and synthetic analogues, sequela*/
,'T381X1D'  /*Poisoning by thyroid hormones and substitutes, accidental (unintentional), subsequent encounter*/
,'T381X1S'  /*Poisoning by thyroid hormones and substitutes, accidental (unintentional), sequela*/
,'T381X2D'  /*Poisoning by thyroid hormones and substitutes, intentional self-harm, subsequent encounter*/
,'T381X2S'  /*Poisoning by thyroid hormones and substitutes, intentional self-harm, sequela*/
,'T381X3D'  /*Poisoning by thyroid hormones and substitutes, assault, subsequent encounter*/
,'T381X3S'  /*Poisoning by thyroid hormones and substitutes, assault, sequela*/
,'T381X4D'  /*Poisoning by thyroid hormones and substitutes, undetermined, subsequent encounter*/
,'T381X4S'  /*Poisoning by thyroid hormones and substitutes, undetermined, sequela*/
,'T381X5D'  /*Adverse effect of thyroid hormones and substitutes, subsequent encounter*/
,'T381X5S'  /*Adverse effect of thyroid hormones and substitutes, sequela*/
,'T381X6D'  /*Underdosing of thyroid hormones and substitutes, subsequent encounter*/
,'T381X6S'  /*Underdosing of thyroid hormones and substitutes, sequela*/
,'T382X1D'  /*Poisoning by antithyroid drugs, accidental (unintentional), subsequent encounter*/
,'T382X1S'  /*Poisoning by antithyroid drugs, accidental (unintentional), sequela*/
,'T382X2D'  /*Poisoning by antithyroid drugs, intentional self-harm, subsequent encounter*/
,'T382X2S'  /*Poisoning by antithyroid drugs, intentional self-harm, sequela*/
,'T382X3D'  /*Poisoning by antithyroid drugs, assault, subsequent encounter*/
,'T382X3S'  /*Poisoning by antithyroid drugs, assault, sequela*/
,'T382X4D'  /*Poisoning by antithyroid drugs, undetermined, subsequent encounter*/
,'T382X4S'  /*Poisoning by antithyroid drugs, undetermined, sequela*/
,'T382X5D'  /*Adverse effect of antithyroid drugs, subsequent encounter*/
,'T382X5S'  /*Adverse effect of antithyroid drugs, sequela*/
,'T382X6D'  /*Underdosing of antithyroid drugs, subsequent encounter*/
,'T382X6S'  /*Underdosing of antithyroid drugs, sequela*/
,'T383X1D'  /*Poisoning by insulin and oral hypoglycemic [antidiabetic] drugs, accidental (unintentional), subsequent encounter*/
,'T383X1S'  /*Poisoning by insulin and oral hypoglycemic [antidiabetic] drugs, accidental (unintentional), sequela*/
,'T383X2D'  /*Poisoning by insulin and oral hypoglycemic [antidiabetic] drugs, intentional self-harm, subsequent encounter*/
,'T383X2S'  /*Poisoning by insulin and oral hypoglycemic [antidiabetic] drugs, intentional self-harm, sequela*/
,'T383X3D'  /*Poisoning by insulin and oral hypoglycemic [antidiabetic] drugs, assault, subsequent encounter*/
,'T383X3S'  /*Poisoning by insulin and oral hypoglycemic [antidiabetic] drugs, assault, sequela*/
,'T383X4D'  /*Poisoning by insulin and oral hypoglycemic [antidiabetic] drugs, undetermined, subsequent encounter*/
,'T383X4S'  /*Poisoning by insulin and oral hypoglycemic [antidiabetic] drugs, undetermined, sequela*/
,'T383X5D'  /*Adverse effect of insulin and oral hypoglycemic [antidiabetic] drugs, subsequent encounter*/
,'T383X5S'  /*Adverse effect of insulin and oral hypoglycemic [antidiabetic] drugs, sequela*/
,'T383X6D'  /*Underdosing of insulin and oral hypoglycemic [antidiabetic] drugs, subsequent encounter*/
,'T383X6S'  /*Underdosing of insulin and oral hypoglycemic [antidiabetic] drugs, sequela*/
,'T384X1D'  /*Poisoning by oral contraceptives, accidental (unintentional), subsequent encounter*/
,'T384X1S'  /*Poisoning by oral contraceptives, accidental (unintentional), sequela*/
,'T384X2D'  /*Poisoning by oral contraceptives, intentional self-harm, subsequent encounter*/
,'T384X2S'  /*Poisoning by oral contraceptives, intentional self-harm, sequela*/
,'T384X3D'  /*Poisoning by oral contraceptives, assault, subsequent encounter*/
,'T384X3S'  /*Poisoning by oral contraceptives, assault, sequela*/
,'T384X4D'  /*Poisoning by oral contraceptives, undetermined, subsequent encounter*/
,'T384X4S'  /*Poisoning by oral contraceptives, undetermined, sequela*/
,'T384X5D'  /*Adverse effect of oral contraceptives, subsequent encounter*/
,'T384X5S'  /*Adverse effect of oral contraceptives, sequela*/
,'T384X6D'  /*Underdosing of oral contraceptives, subsequent encounter*/
,'T384X6S'  /*Underdosing of oral contraceptives, sequela*/
,'T385X1D'  /*Poisoning by other estrogens and progestogens, accidental (unintentional), subsequent encounter*/
,'T385X1S'  /*Poisoning by other estrogens and progestogens, accidental (unintentional), sequela*/
,'T385X2D'  /*Poisoning by other estrogens and progestogens, intentional self-harm, subsequent encounter*/
,'T385X2S'  /*Poisoning by other estrogens and progestogens, intentional self-harm, sequela*/
,'T385X3D'  /*Poisoning by other estrogens and progestogens, assault, subsequent encounter*/
,'T385X3S'  /*Poisoning by other estrogens and progestogens, assault, sequela*/
,'T385X4D'  /*Poisoning by other estrogens and progestogens, undetermined, subsequent encounter*/
,'T385X4S'  /*Poisoning by other estrogens and progestogens, undetermined, sequela*/
,'T385X5D'  /*Adverse effect of other estrogens and progestogens, subsequent encounter*/
,'T385X5S'  /*Adverse effect of other estrogens and progestogens, sequela*/
,'T385X6D'  /*Underdosing of other estrogens and progestogens, subsequent encounter*/
,'T385X6S'  /*Underdosing of other estrogens and progestogens, sequela*/
,'T386X1D'  /*Poisoning by antigonadotrophins, antiestrogens, antiandrogens, not elsewhere classified, accidental (unintentional), subsequent encounter*/
,'T386X1S'  /*Poisoning by antigonadotrophins, antiestrogens, antiandrogens, not elsewhere classified, accidental (unintentional), sequela*/
,'T386X2D'  /*Poisoning by antigonadotrophins, antiestrogens, antiandrogens, not elsewhere classified, intentional self-harm, subsequent encounter*/
,'T386X2S'  /*Poisoning by antigonadotrophins, antiestrogens, antiandrogens, not elsewhere classified, intentional self-harm, sequela*/
,'T386X3D'  /*Poisoning by antigonadotrophins, antiestrogens, antiandrogens, not elsewhere classified, assault, subsequent encounter*/
,'T386X3S'  /*Poisoning by antigonadotrophins, antiestrogens, antiandrogens, not elsewhere classified, assault, sequela*/
,'T386X4D'  /*Poisoning by antigonadotrophins, antiestrogens, antiandrogens, not elsewhere classified, undetermined, subsequent encounter*/
,'T386X4S'  /*Poisoning by antigonadotrophins, antiestrogens, antiandrogens, not elsewhere classified, undetermined, sequela*/
,'T386X5D'  /*Adverse effect of antigonadotrophins, antiestrogens, antiandrogens, not elsewhere classified, subsequent encounter*/
,'T386X5S'  /*Adverse effect of antigonadotrophins, antiestrogens, antiandrogens, not elsewhere classified, sequela*/
,'T386X6D'  /*Underdosing of antigonadotrophins, antiestrogens, antiandrogens, not elsewhere classified, subsequent encounter*/
,'T386X6S'  /*Underdosing of antigonadotrophins, antiestrogens, antiandrogens, not elsewhere classified, sequela*/
,'T387X1D'  /*Poisoning by androgens and anabolic congeners, accidental (unintentional), subsequent encounter*/
,'T387X1S'  /*Poisoning by androgens and anabolic congeners, accidental (unintentional), sequela*/
,'T387X2D'  /*Poisoning by androgens and anabolic congeners, intentional self-harm, subsequent encounter*/
,'T387X2S'  /*Poisoning by androgens and anabolic congeners, intentional self-harm, sequela*/
,'T387X3D'  /*Poisoning by androgens and anabolic congeners, assault, subsequent encounter*/
,'T387X3S'  /*Poisoning by androgens and anabolic congeners, assault, sequela*/
,'T387X4D'  /*Poisoning by androgens and anabolic congeners, undetermined, subsequent encounter*/
,'T387X4S'  /*Poisoning by androgens and anabolic congeners, undetermined, sequela*/
,'T387X5D'  /*Adverse effect of androgens and anabolic congeners, subsequent encounter*/
,'T387X5S'  /*Adverse effect of androgens and anabolic congeners, sequela*/
,'T387X6D'  /*Underdosing of androgens and anabolic congeners, subsequent encounter*/
,'T387X6S'  /*Underdosing of androgens and anabolic congeners, sequela*/
,'T38801D'  /*Poisoning by unspecified hormones and synthetic substitutes, accidental (unintentional), subsequent encounter*/
,'T38801S'  /*Poisoning by unspecified hormones and synthetic substitutes, accidental (unintentional), sequela*/
,'T38802D'  /*Poisoning by unspecified hormones and synthetic substitutes, intentional self-harm, subsequent encounter*/
,'T38802S'  /*Poisoning by unspecified hormones and synthetic substitutes, intentional self-harm, sequela*/
,'T38803D'  /*Poisoning by unspecified hormones and synthetic substitutes, assault, subsequent encounter*/
,'T38803S'  /*Poisoning by unspecified hormones and synthetic substitutes, assault, sequela*/
,'T38804D'  /*Poisoning by unspecified hormones and synthetic substitutes, undetermined, subsequent encounter*/
,'T38804S'  /*Poisoning by unspecified hormones and synthetic substitutes, undetermined, sequela*/
,'T38805D'  /*Adverse effect of unspecified hormones and synthetic substitutes, subsequent encounter*/
,'T38805S'  /*Adverse effect of unspecified hormones and synthetic substitutes, sequela*/
,'T38806D'  /*Underdosing of unspecified hormones and synthetic substitutes, subsequent encounter*/
,'T38806S'  /*Underdosing of unspecified hormones and synthetic substitutes, sequela*/
,'T38811D'  /*Poisoning by anterior pituitary [adenohypophyseal] hormones, accidental (unintentional), subsequent encounter*/
,'T38811S'  /*Poisoning by anterior pituitary [adenohypophyseal] hormones, accidental (unintentional), sequela*/
,'T38812D'  /*Poisoning by anterior pituitary [adenohypophyseal] hormones, intentional self-harm, subsequent encounter*/
,'T38812S'  /*Poisoning by anterior pituitary [adenohypophyseal] hormones, intentional self-harm, sequela*/
,'T38813D'  /*Poisoning by anterior pituitary [adenohypophyseal] hormones, assault, subsequent encounter*/
,'T38813S'  /*Poisoning by anterior pituitary [adenohypophyseal] hormones, assault, sequela*/
,'T38814D'  /*Poisoning by anterior pituitary [adenohypophyseal] hormones, undetermined, subsequent encounter*/
,'T38814S'  /*Poisoning by anterior pituitary [adenohypophyseal] hormones, undetermined, sequela*/
,'T38815D'  /*Adverse effect of anterior pituitary [adenohypophyseal] hormones, subsequent encounter*/
,'T38815S'  /*Adverse effect of anterior pituitary [adenohypophyseal] hormones, sequela*/
,'T38816D'  /*Underdosing of anterior pituitary [adenohypophyseal] hormones, subsequent encounter*/
,'T38816S'  /*Underdosing of anterior pituitary [adenohypophyseal] hormones, sequela*/
,'T38891D'  /*Poisoning by other hormones and synthetic substitutes, accidental (unintentional), subsequent encounter*/
,'T38891S'  /*Poisoning by other hormones and synthetic substitutes, accidental (unintentional), sequela*/
,'T38892D'  /*Poisoning by other hormones and synthetic substitutes, intentional self-harm, subsequent encounter*/
,'T38892S'  /*Poisoning by other hormones and synthetic substitutes, intentional self-harm, sequela*/
,'T38893D'  /*Poisoning by other hormones and synthetic substitutes, assault, subsequent encounter*/
,'T38893S'  /*Poisoning by other hormones and synthetic substitutes, assault, sequela*/
,'T38894D'  /*Poisoning by other hormones and synthetic substitutes, undetermined, subsequent encounter*/
,'T38894S'  /*Poisoning by other hormones and synthetic substitutes, undetermined, sequela*/
,'T38895D'  /*Adverse effect of other hormones and synthetic substitutes, subsequent encounter*/
,'T38895S'  /*Adverse effect of other hormones and synthetic substitutes, sequela*/
,'T38896D'  /*Underdosing of other hormones and synthetic substitutes, subsequent encounter*/
,'T38896S'  /*Underdosing of other hormones and synthetic substitutes, sequela*/
,'T38901D'  /*Poisoning by unspecified hormone antagonists, accidental (unintentional), subsequent encounter*/
,'T38901S'  /*Poisoning by unspecified hormone antagonists, accidental (unintentional), sequela*/
,'T38902D'  /*Poisoning by unspecified hormone antagonists, intentional self-harm, subsequent encounter*/
,'T38902S'  /*Poisoning by unspecified hormone antagonists, intentional self-harm, sequela*/
,'T38903D'  /*Poisoning by unspecified hormone antagonists, assault, subsequent encounter*/
,'T38903S'  /*Poisoning by unspecified hormone antagonists, assault, sequela*/
,'T38904D'  /*Poisoning by unspecified hormone antagonists, undetermined, subsequent encounter*/
,'T38904S'  /*Poisoning by unspecified hormone antagonists, undetermined, sequela*/
,'T38905D'  /*Adverse effect of unspecified hormone antagonists, subsequent encounter*/
,'T38905S'  /*Adverse effect of unspecified hormone antagonists, sequela*/
,'T38906D'  /*Underdosing of unspecified hormone antagonists, subsequent encounter*/
,'T38906S'  /*Underdosing of unspecified hormone antagonists, sequela*/
,'T38991D'  /*Poisoning by other hormone antagonists, accidental (unintentional), subsequent encounter*/
,'T38991S'  /*Poisoning by other hormone antagonists, accidental (unintentional), sequela*/
,'T38992D'  /*Poisoning by other hormone antagonists, intentional self-harm, subsequent encounter*/
,'T38992S'  /*Poisoning by other hormone antagonists, intentional self-harm, sequela*/
,'T38993D'  /*Poisoning by other hormone antagonists, assault, subsequent encounter*/
,'T38993S'  /*Poisoning by other hormone antagonists, assault, sequela*/
,'T38994D'  /*Poisoning by other hormone antagonists, undetermined, subsequent encounter*/
,'T38994S'  /*Poisoning by other hormone antagonists, undetermined, sequela*/
,'T38995D'  /*Adverse effect of other hormone antagonists, subsequent encounter*/
,'T38995S'  /*Adverse effect of other hormone antagonists, sequela*/
,'T38996D'  /*Underdosing of other hormone antagonists, subsequent encounter*/
,'T38996S'  /*Underdosing of other hormone antagonists, sequela*/
,'T39011D'  /*Poisoning by aspirin, accidental (unintentional), subsequent encounter*/
,'T39011S'  /*Poisoning by aspirin, accidental (unintentional), sequela*/
,'T39012D'  /*Poisoning by aspirin, intentional self-harm, subsequent encounter*/
,'T39012S'  /*Poisoning by aspirin, intentional self-harm, sequela*/
,'T39013D'  /*Poisoning by aspirin, assault, subsequent encounter*/
,'T39013S'  /*Poisoning by aspirin, assault, sequela*/
,'T39014D'  /*Poisoning by aspirin, undetermined, subsequent encounter*/
,'T39014S'  /*Poisoning by aspirin, undetermined, sequela*/
,'T39015D'  /*Adverse effect of aspirin, subsequent encounter*/
,'T39015S'  /*Adverse effect of aspirin, sequela*/
,'T39016D'  /*Underdosing of aspirin, subsequent encounter*/
,'T39016S'  /*Underdosing of aspirin, sequela*/
,'T39091D'  /*Poisoning by salicylates, accidental (unintentional), subsequent encounter*/
,'T39091S'  /*Poisoning by salicylates, accidental (unintentional), sequela*/
,'T39092D'  /*Poisoning by salicylates, intentional self-harm, subsequent encounter*/
,'T39092S'  /*Poisoning by salicylates, intentional self-harm, sequela*/
,'T39093D'  /*Poisoning by salicylates, assault, subsequent encounter*/
,'T39093S'  /*Poisoning by salicylates, assault, sequela*/
,'T39094D'  /*Poisoning by salicylates, undetermined, subsequent encounter*/
,'T39094S'  /*Poisoning by salicylates, undetermined, sequela*/
,'T39095D'  /*Adverse effect of salicylates, subsequent encounter*/
,'T39095S'  /*Adverse effect of salicylates, sequela*/
,'T39096D'  /*Underdosing of salicylates, subsequent encounter*/
,'T39096S'  /*Underdosing of salicylates, sequela*/
,'T391X1D'  /*Poisoning by 4-Aminophenol derivatives, accidental (unintentional), subsequent encounter*/
,'T391X1S'  /*Poisoning by 4-Aminophenol derivatives, accidental (unintentional), sequela*/
,'T391X2D'  /*Poisoning by 4-Aminophenol derivatives, intentional self-harm, subsequent encounter*/
,'T391X2S'  /*Poisoning by 4-Aminophenol derivatives, intentional self-harm, sequela*/
,'T391X3D'  /*Poisoning by 4-Aminophenol derivatives, assault, subsequent encounter*/
,'T391X3S'  /*Poisoning by 4-Aminophenol derivatives, assault, sequela*/
,'T391X4D'  /*Poisoning by 4-Aminophenol derivatives, undetermined, subsequent encounter*/
,'T391X4S'  /*Poisoning by 4-Aminophenol derivatives, undetermined, sequela*/
,'T391X5D'  /*Adverse effect of 4-Aminophenol derivatives, subsequent encounter*/
,'T391X5S'  /*Adverse effect of 4-Aminophenol derivatives, sequela*/
,'T391X6D'  /*Underdosing of 4-Aminophenol derivatives, subsequent encounter*/
,'T391X6S'  /*Underdosing of 4-Aminophenol derivatives, sequela*/
,'T392X1D'  /*Poisoning by pyrazolone derivatives, accidental (unintentional), subsequent encounter*/
,'T392X1S'  /*Poisoning by pyrazolone derivatives, accidental (unintentional), sequela*/
,'T392X2D'  /*Poisoning by pyrazolone derivatives, intentional self-harm, subsequent encounter*/
,'T392X2S'  /*Poisoning by pyrazolone derivatives, intentional self-harm, sequela*/
,'T392X3D'  /*Poisoning by pyrazolone derivatives, assault, subsequent encounter*/
,'T392X3S'  /*Poisoning by pyrazolone derivatives, assault, sequela*/
,'T392X4D'  /*Poisoning by pyrazolone derivatives, undetermined, subsequent encounter*/
,'T392X4S'  /*Poisoning by pyrazolone derivatives, undetermined, sequela*/
,'T392X5D'  /*Adverse effect of pyrazolone derivatives, subsequent encounter*/
,'T392X5S'  /*Adverse effect of pyrazolone derivatives, sequela*/
,'T392X6D'  /*Underdosing of pyrazolone derivatives, subsequent encounter*/
,'T392X6S'  /*Underdosing of pyrazolone derivatives, sequela*/
,'T39311D'  /*Poisoning by propionic acid derivatives, accidental (unintentional), subsequent encounter*/
,'T39311S'  /*Poisoning by propionic acid derivatives, accidental (unintentional), sequela*/
,'T39312D'  /*Poisoning by propionic acid derivatives, intentional self-harm, subsequent encounter*/
,'T39312S'  /*Poisoning by propionic acid derivatives, intentional self-harm, sequela*/
,'T39313D'  /*Poisoning by propionic acid derivatives, assault, subsequent encounter*/
,'T39313S'  /*Poisoning by propionic acid derivatives, assault, sequela*/
,'T39314D'  /*Poisoning by propionic acid derivatives, undetermined, subsequent encounter*/
,'T39314S'  /*Poisoning by propionic acid derivatives, undetermined, sequela*/
,'T39315D'  /*Adverse effect of propionic acid derivatives, subsequent encounter*/
,'T39315S'  /*Adverse effect of propionic acid derivatives, sequela*/
,'T39316D'  /*Underdosing of propionic acid derivatives, subsequent encounter*/
,'T39316S'  /*Underdosing of propionic acid derivatives, sequela*/
,'T39391D'  /*Poisoning by other nonsteroidal anti-inflammatory drugs [NSAID], accidental (unintentional), subsequent encounter*/
,'T39391S'  /*Poisoning by other nonsteroidal anti-inflammatory drugs [NSAID], accidental (unintentional), sequela*/
,'T39392D'  /*Poisoning by other nonsteroidal anti-inflammatory drugs [NSAID], intentional self-harm, subsequent encounter*/
,'T39392S'  /*Poisoning by other nonsteroidal anti-inflammatory drugs [NSAID], intentional self-harm, sequela*/
,'T39393D'  /*Poisoning by other nonsteroidal anti-inflammatory drugs [NSAID], assault, subsequent encounter*/
,'T39393S'  /*Poisoning by other nonsteroidal anti-inflammatory drugs [NSAID], assault, sequela*/
,'T39394D'  /*Poisoning by other nonsteroidal anti-inflammatory drugs [NSAID], undetermined, subsequent encounter*/
,'T39394S'  /*Poisoning by other nonsteroidal anti-inflammatory drugs [NSAID], undetermined, sequela*/
,'T39395D'  /*Adverse effect of other nonsteroidal anti-inflammatory drugs [NSAID], subsequent encounter*/
,'T39395S'  /*Adverse effect of other nonsteroidal anti-inflammatory drugs [NSAID], sequela*/
,'T39396D'  /*Underdosing of other nonsteroidal anti-inflammatory drugs [NSAID], subsequent encounter*/
,'T39396S'  /*Underdosing of other nonsteroidal anti-inflammatory drugs [NSAID], sequela*/
,'T394X1D'  /*Poisoning by antirheumatics, not elsewhere classified, accidental (unintentional), subsequent encounter*/
,'T394X1S'  /*Poisoning by antirheumatics, not elsewhere classified, accidental (unintentional), sequela*/
,'T394X2D'  /*Poisoning by antirheumatics, not elsewhere classified, intentional self-harm, subsequent encounter*/
,'T394X2S'  /*Poisoning by antirheumatics, not elsewhere classified, intentional self-harm, sequela*/
,'T394X3D'  /*Poisoning by antirheumatics, not elsewhere classified, assault, subsequent encounter*/
,'T394X3S'  /*Poisoning by antirheumatics, not elsewhere classified, assault, sequela*/
,'T394X4D'  /*Poisoning by antirheumatics, not elsewhere classified, undetermined, subsequent encounter*/
,'T394X4S'  /*Poisoning by antirheumatics, not elsewhere classified, undetermined, sequela*/
,'T394X5D'  /*Adverse effect of antirheumatics, not elsewhere classified, subsequent encounter*/
,'T394X5S'  /*Adverse effect of antirheumatics, not elsewhere classified, sequela*/
,'T394X6D'  /*Underdosing of antirheumatics, not elsewhere classified, subsequent encounter*/
,'T394X6S'  /*Underdosing of antirheumatics, not elsewhere classified, sequela*/
,'T398X1D'  /*Poisoning by other nonopioid analgesics and antipyretics, not elsewhere classified, accidental (unintentional), subsequent encounter*/
,'T398X1S'  /*Poisoning by other nonopioid analgesics and antipyretics, not elsewhere classified, accidental (unintentional), sequela*/
,'T398X2D'  /*Poisoning by other nonopioid analgesics and antipyretics, not elsewhere classified, intentional self-harm, subsequent encounter*/
,'T398X2S'  /*Poisoning by other nonopioid analgesics and antipyretics, not elsewhere classified, intentional self-harm, sequela*/
,'T398X3D'  /*Poisoning by other nonopioid analgesics and antipyretics, not elsewhere classified, assault, subsequent encounter*/
,'T398X3S'  /*Poisoning by other nonopioid analgesics and antipyretics, not elsewhere classified, assault, sequela*/
,'T398X4D'  /*Poisoning by other nonopioid analgesics and antipyretics, not elsewhere classified, undetermined, subsequent encounter*/
,'T398X4S'  /*Poisoning by other nonopioid analgesics and antipyretics, not elsewhere classified, undetermined, sequela*/
,'T398X5D'  /*Adverse effect of other nonopioid analgesics and antipyretics, not elsewhere classified, subsequent encounter*/
,'T398X5S'  /*Adverse effect of other nonopioid analgesics and antipyretics, not elsewhere classified, sequela*/
,'T398X6D'  /*Underdosing of other nonopioid analgesics and antipyretics, not elsewhere classified, subsequent encounter*/
,'T398X6S'  /*Underdosing of other nonopioid analgesics and antipyretics, not elsewhere classified, sequela*/
,'T3991XD'  /*Poisoning by unspecified nonopioid analgesic, antipyretic and antirheumatic, accidental (unintentional), subsequent encounter*/
,'T3991XS'  /*Poisoning by unspecified nonopioid analgesic, antipyretic and antirheumatic, accidental (unintentional), sequela*/
,'T3992XD'  /*Poisoning by unspecified nonopioid analgesic, antipyretic and antirheumatic, intentional self-harm, subsequent encounter*/
,'T3992XS'  /*Poisoning by unspecified nonopioid analgesic, antipyretic and antirheumatic, intentional self-harm, sequela*/
,'T3993XD'  /*Poisoning by unspecified nonopioid analgesic, antipyretic and antirheumatic, assault, subsequent encounter*/
,'T3993XS'  /*Poisoning by unspecified nonopioid analgesic, antipyretic and antirheumatic, assault, sequela*/
,'T3994XD'  /*Poisoning by unspecified nonopioid analgesic, antipyretic and antirheumatic, undetermined, subsequent encounter*/
,'T3994XS'  /*Poisoning by unspecified nonopioid analgesic, antipyretic and antirheumatic, undetermined, sequela*/
,'T3995XD'  /*Adverse effect of unspecified nonopioid analgesic, antipyretic and antirheumatic, subsequent encounter*/
,'T3995XS'  /*Adverse effect of unspecified nonopioid analgesic, antipyretic and antirheumatic, sequela*/
,'T3996XD'  /*Underdosing of unspecified nonopioid analgesic, antipyretic and antirheumatic, subsequent encounter*/
,'T3996XS'  /*Underdosing of unspecified nonopioid analgesic, antipyretic and antirheumatic, sequela*/
,'T400X1D'  /*Poisoning by opium, accidental (unintentional), subsequent encounter*/
,'T400X1S'  /*Poisoning by opium, accidental (unintentional), sequela*/
,'T400X2D'  /*Poisoning by opium, intentional self-harm, subsequent encounter*/
,'T400X2S'  /*Poisoning by opium, intentional self-harm, sequela*/
,'T400X3D'  /*Poisoning by opium, assault, subsequent encounter*/
,'T400X3S'  /*Poisoning by opium, assault, sequela*/
,'T400X4D'  /*Poisoning by opium, undetermined, subsequent encounter*/
,'T400X4S'  /*Poisoning by opium, undetermined, sequela*/
,'T400X5D'  /*Adverse effect of opium, subsequent encounter*/
,'T400X5S'  /*Adverse effect of opium, sequela*/
,'T400X6D'  /*Underdosing of opium, subsequent encounter*/
,'T400X6S'  /*Underdosing of opium, sequela*/
,'T401X1D'  /*Poisoning by heroin, accidental (unintentional), subsequent encounter*/
,'T401X1S'  /*Poisoning by heroin, accidental (unintentional), sequela*/
,'T401X2D'  /*Poisoning by heroin, intentional self-harm, subsequent encounter*/
,'T401X2S'  /*Poisoning by heroin, intentional self-harm, sequela*/
,'T401X3D'  /*Poisoning by heroin, assault, subsequent encounter*/
,'T401X3S'  /*Poisoning by heroin, assault, sequela*/
,'T401X4D'  /*Poisoning by heroin, undetermined, subsequent encounter*/
,'T401X4S'  /*Poisoning by heroin, undetermined, sequela*/
,'T402X1D'  /*Poisoning by other opioids, accidental (unintentional), subsequent encounter*/
,'T402X1S'  /*Poisoning by other opioids, accidental (unintentional), sequela*/
,'T402X2D'  /*Poisoning by other opioids, intentional self-harm, subsequent encounter*/
,'T402X2S'  /*Poisoning by other opioids, intentional self-harm, sequela*/
,'T402X3D'  /*Poisoning by other opioids, assault, subsequent encounter*/
,'T402X3S'  /*Poisoning by other opioids, assault, sequela*/
,'T402X4D'  /*Poisoning by other opioids, undetermined, subsequent encounter*/
,'T402X4S'  /*Poisoning by other opioids, undetermined, sequela*/
,'T402X5D'  /*Adverse effect of other opioids, subsequent encounter*/
,'T402X5S'  /*Adverse effect of other opioids, sequela*/
,'T402X6D'  /*Underdosing of other opioids, subsequent encounter*/
,'T402X6S'  /*Underdosing of other opioids, sequela*/
,'T403X1D'  /*Poisoning by methadone, accidental (unintentional), subsequent encounter*/
,'T403X1S'  /*Poisoning by methadone, accidental (unintentional), sequela*/
,'T403X2D'  /*Poisoning by methadone, intentional self-harm, subsequent encounter*/
,'T403X2S'  /*Poisoning by methadone, intentional self-harm, sequela*/
,'T403X3D'  /*Poisoning by methadone, assault, subsequent encounter*/
,'T403X3S'  /*Poisoning by methadone, assault, sequela*/
,'T403X4D'  /*Poisoning by methadone, undetermined, subsequent encounter*/
,'T403X4S'  /*Poisoning by methadone, undetermined, sequela*/
,'T403X5D'  /*Adverse effect of methadone, subsequent encounter*/
,'T403X5S'  /*Adverse effect of methadone, sequela*/
,'T403X6D'  /*Underdosing of methadone, subsequent encounter*/
,'T403X6S'  /*Underdosing of methadone, sequela*/
,'T404X1D'  /*Poisoning by other synthetic narcotics, accidental (unintentional), subsequent encounter*/
,'T404X1S'  /*Poisoning by other synthetic narcotics, accidental (unintentional), sequela*/
,'T404X2D'  /*Poisoning by other synthetic narcotics, intentional self-harm, subsequent encounter*/
,'T404X2S'  /*Poisoning by other synthetic narcotics, intentional self-harm, sequela*/
,'T404X3D'  /*Poisoning by other synthetic narcotics, assault, subsequent encounter*/
,'T404X3S'  /*Poisoning by other synthetic narcotics, assault, sequela*/
,'T404X4D'  /*Poisoning by other synthetic narcotics, undetermined, subsequent encounter*/
,'T404X4S'  /*Poisoning by other synthetic narcotics, undetermined, sequela*/
,'T404X5D'  /*Adverse effect of other synthetic narcotics, subsequent encounter*/
,'T404X5S'  /*Adverse effect of other synthetic narcotics, sequela*/
,'T404X6D'  /*Underdosing of other synthetic narcotics, subsequent encounter*/
,'T404X6S'  /*Underdosing of other synthetic narcotics, sequela*/
,'T405X1D'  /*Poisoning by cocaine, accidental (unintentional), subsequent encounter*/
,'T405X1S'  /*Poisoning by cocaine, accidental (unintentional), sequela*/
,'T405X2D'  /*Poisoning by cocaine, intentional self-harm, subsequent encounter*/
,'T405X2S'  /*Poisoning by cocaine, intentional self-harm, sequela*/
,'T405X3D'  /*Poisoning by cocaine, assault, subsequent encounter*/
,'T405X3S'  /*Poisoning by cocaine, assault, sequela*/
,'T405X4D'  /*Poisoning by cocaine, undetermined, subsequent encounter*/
,'T405X4S'  /*Poisoning by cocaine, undetermined, sequela*/
,'T405X5D'  /*Adverse effect of cocaine, subsequent encounter*/
,'T405X5S'  /*Adverse effect of cocaine, sequela*/
,'T405X6D'  /*Underdosing of cocaine, subsequent encounter*/
,'T405X6S'  /*Underdosing of cocaine, sequela*/
,'T40601D'  /*Poisoning by unspecified narcotics, accidental (unintentional), subsequent encounter*/
,'T40601S'  /*Poisoning by unspecified narcotics, accidental (unintentional), sequela*/
,'T40602D'  /*Poisoning by unspecified narcotics, intentional self-harm, subsequent encounter*/
,'T40602S'  /*Poisoning by unspecified narcotics, intentional self-harm, sequela*/
,'T40603D'  /*Poisoning by unspecified narcotics, assault, subsequent encounter*/
,'T40603S'  /*Poisoning by unspecified narcotics, assault, sequela*/
,'T40604D'  /*Poisoning by unspecified narcotics, undetermined, subsequent encounter*/
,'T40604S'  /*Poisoning by unspecified narcotics, undetermined, sequela*/
,'T40605D'  /*Adverse effect of unspecified narcotics, subsequent encounter*/
,'T40605S'  /*Adverse effect of unspecified narcotics, sequela*/
,'T40606D'  /*Underdosing of unspecified narcotics, subsequent encounter*/
,'T40606S'  /*Underdosing of unspecified narcotics, sequela*/
,'T40691D'  /*Poisoning by other narcotics, accidental (unintentional), subsequent encounter*/
,'T40691S'  /*Poisoning by other narcotics, accidental (unintentional), sequela*/
,'T40692D'  /*Poisoning by other narcotics, intentional self-harm, subsequent encounter*/
,'T40692S'  /*Poisoning by other narcotics, intentional self-harm, sequela*/
,'T40693D'  /*Poisoning by other narcotics, assault, subsequent encounter*/
,'T40693S'  /*Poisoning by other narcotics, assault, sequela*/
,'T40694D'  /*Poisoning by other narcotics, undetermined, subsequent encounter*/
,'T40694S'  /*Poisoning by other narcotics, undetermined, sequela*/
,'T40695D'  /*Adverse effect of other narcotics, subsequent encounter*/
,'T40695S'  /*Adverse effect of other narcotics, sequela*/
,'T40696D'  /*Underdosing of other narcotics, subsequent encounter*/
,'T40696S'  /*Underdosing of other narcotics, sequela*/
,'T407X1D'  /*Poisoning by cannabis (derivatives), accidental (unintentional), subsequent encounter*/
,'T407X1S'  /*Poisoning by cannabis (derivatives), accidental (unintentional), sequela*/
,'T407X2D'  /*Poisoning by cannabis (derivatives), intentional self-harm, subsequent encounter*/
,'T407X2S'  /*Poisoning by cannabis (derivatives), intentional self-harm, sequela*/
,'T407X3D'  /*Poisoning by cannabis (derivatives), assault, subsequent encounter*/
,'T407X3S'  /*Poisoning by cannabis (derivatives), assault, sequela*/
,'T407X4D'  /*Poisoning by cannabis (derivatives), undetermined, subsequent encounter*/
,'T407X4S'  /*Poisoning by cannabis (derivatives), undetermined, sequela*/
,'T407X5D'  /*Adverse effect of cannabis (derivatives), subsequent encounter*/
,'T407X5S'  /*Adverse effect of cannabis (derivatives), sequela*/
,'T407X6D'  /*Underdosing of cannabis (derivatives), subsequent encounter*/
,'T407X6S'  /*Underdosing of cannabis (derivatives), sequela*/
,'T408X1D'  /*Poisoning by lysergide [LSD], accidental (unintentional), subsequent encounter*/
,'T408X1S'  /*Poisoning by lysergide [LSD], accidental (unintentional), sequela*/
,'T408X2D'  /*Poisoning by lysergide [LSD], intentional self-harm, subsequent encounter*/
,'T408X2S'  /*Poisoning by lysergide [LSD], intentional self-harm, sequela*/
,'T408X3D'  /*Poisoning by lysergide [LSD], assault, subsequent encounter*/
,'T408X3S'  /*Poisoning by lysergide [LSD], assault, sequela*/
,'T408X4D'  /*Poisoning by lysergide [LSD], undetermined, subsequent encounter*/
,'T408X4S'  /*Poisoning by lysergide [LSD], undetermined, sequela*/
,'T40901D'  /*Poisoning by unspecified psychodysleptics [hallucinogens], accidental (unintentional), subsequent encounter*/
,'T40901S'  /*Poisoning by unspecified psychodysleptics [hallucinogens], accidental (unintentional), sequela*/
,'T40902D'  /*Poisoning by unspecified psychodysleptics [hallucinogens], intentional self-harm, subsequent encounter*/
,'T40902S'  /*Poisoning by unspecified psychodysleptics [hallucinogens], intentional self-harm, sequela*/
,'T40903D'  /*Poisoning by unspecified psychodysleptics [hallucinogens], assault, subsequent encounter*/
,'T40903S'  /*Poisoning by unspecified psychodysleptics [hallucinogens], assault, sequela*/
,'T40904D'  /*Poisoning by unspecified psychodysleptics [hallucinogens], undetermined, subsequent encounter*/
,'T40904S'  /*Poisoning by unspecified psychodysleptics [hallucinogens], undetermined, sequela*/
,'T40905D'  /*Adverse effect of unspecified psychodysleptics [hallucinogens], subsequent encounter*/
,'T40905S'  /*Adverse effect of unspecified psychodysleptics [hallucinogens], sequela*/
,'T40906D'  /*Underdosing of unspecified psychodysleptics, subsequent encounter*/
,'T40906S'  /*Underdosing of unspecified psychodysleptics, sequela*/
,'T40991D'  /*Poisoning by other psychodysleptics [hallucinogens], accidental (unintentional), subsequent encounter*/
,'T40991S'  /*Poisoning by other psychodysleptics [hallucinogens], accidental (unintentional), sequela*/
,'T40992D'  /*Poisoning by other psychodysleptics [hallucinogens], intentional self-harm, subsequent encounter*/
,'T40992S'  /*Poisoning by other psychodysleptics [hallucinogens], intentional self-harm, sequela*/
,'T40993D'  /*Poisoning by other psychodysleptics [hallucinogens], assault, subsequent encounter*/
,'T40993S'  /*Poisoning by other psychodysleptics [hallucinogens], assault, sequela*/
,'T40994D'  /*Poisoning by other psychodysleptics [hallucinogens], undetermined, subsequent encounter*/
,'T40994S'  /*Poisoning by other psychodysleptics [hallucinogens], undetermined, sequela*/
,'T40995D'  /*Adverse effect of other psychodysleptics [hallucinogens], subsequent encounter*/
,'T40995S'  /*Adverse effect of other psychodysleptics [hallucinogens], sequela*/
,'T40996D'  /*Underdosing of other psychodysleptics, subsequent encounter*/
,'T40996S'  /*Underdosing of other psychodysleptics, sequela*/
,'T410X1D'  /*Poisoning by inhaled anesthetics, accidental (unintentional), subsequent encounter*/
,'T410X1S'  /*Poisoning by inhaled anesthetics, accidental (unintentional), sequela*/
,'T410X2D'  /*Poisoning by inhaled anesthetics, intentional self-harm, subsequent encounter*/
,'T410X2S'  /*Poisoning by inhaled anesthetics, intentional self-harm, sequela*/
,'T410X3D'  /*Poisoning by inhaled anesthetics, assault, subsequent encounter*/
,'T410X3S'  /*Poisoning by inhaled anesthetics, assault, sequela*/
,'T410X4D'  /*Poisoning by inhaled anesthetics, undetermined, subsequent encounter*/
,'T410X4S'  /*Poisoning by inhaled anesthetics, undetermined, sequela*/
,'T410X5D'  /*Adverse effect of inhaled anesthetics, subsequent encounter*/
,'T410X5S'  /*Adverse effect of inhaled anesthetics, sequela*/
,'T410X6D'  /*Underdosing of inhaled anesthetics, subsequent encounter*/
,'T410X6S'  /*Underdosing of inhaled anesthetics, sequela*/
,'T411X1D'  /*Poisoning by intravenous anesthetics, accidental (unintentional), subsequent encounter*/
,'T411X1S'  /*Poisoning by intravenous anesthetics, accidental (unintentional), sequela*/
,'T411X2D'  /*Poisoning by intravenous anesthetics, intentional self-harm, subsequent encounter*/
,'T411X2S'  /*Poisoning by intravenous anesthetics, intentional self-harm, sequela*/
,'T411X3D'  /*Poisoning by intravenous anesthetics, assault, subsequent encounter*/
,'T411X3S'  /*Poisoning by intravenous anesthetics, assault, sequela*/
,'T411X4D'  /*Poisoning by intravenous anesthetics, undetermined, subsequent encounter*/
,'T411X4S'  /*Poisoning by intravenous anesthetics, undetermined, sequela*/
,'T411X5D'  /*Adverse effect of intravenous anesthetics, subsequent encounter*/
,'T411X5S'  /*Adverse effect of intravenous anesthetics, sequela*/
,'T411X6D'  /*Underdosing of intravenous anesthetics, subsequent encounter*/
,'T411X6S'  /*Underdosing of intravenous anesthetics, sequela*/
,'T41201D'  /*Poisoning by unspecified general anesthetics, accidental (unintentional), subsequent encounter*/
,'T41201S'  /*Poisoning by unspecified general anesthetics, accidental (unintentional), sequela*/
,'T41202D'  /*Poisoning by unspecified general anesthetics, intentional self-harm, subsequent encounter*/
,'T41202S'  /*Poisoning by unspecified general anesthetics, intentional self-harm, sequela*/
,'T41203D'  /*Poisoning by unspecified general anesthetics, assault, subsequent encounter*/
,'T41203S'  /*Poisoning by unspecified general anesthetics, assault, sequela*/
,'T41204D'  /*Poisoning by unspecified general anesthetics, undetermined, subsequent encounter*/
,'T41204S'  /*Poisoning by unspecified general anesthetics, undetermined, sequela*/
,'T41205D'  /*Adverse effect of unspecified general anesthetics, subsequent encounter*/
,'T41205S'  /*Adverse effect of unspecified general anesthetics, sequela*/
,'T41206D'  /*Underdosing of unspecified general anesthetics, subsequent encounter*/
,'T41206S'  /*Underdosing of unspecified general anesthetics, sequela*/
,'T41291D'  /*Poisoning by other general anesthetics, accidental (unintentional), subsequent encounter*/
,'T41291S'  /*Poisoning by other general anesthetics, accidental (unintentional), sequela*/
,'T41292D'  /*Poisoning by other general anesthetics, intentional self-harm, subsequent encounter*/
,'T41292S'  /*Poisoning by other general anesthetics, intentional self-harm, sequela*/
,'T41293D'  /*Poisoning by other general anesthetics, assault, subsequent encounter*/
,'T41293S'  /*Poisoning by other general anesthetics, assault, sequela*/
,'T41294D'  /*Poisoning by other general anesthetics, undetermined, subsequent encounter*/
,'T41294S'  /*Poisoning by other general anesthetics, undetermined, sequela*/
,'T41295D'  /*Adverse effect of other general anesthetics, subsequent encounter*/
,'T41295S'  /*Adverse effect of other general anesthetics, sequela*/
,'T41296D'  /*Underdosing of other general anesthetics, subsequent encounter*/
,'T41296S'  /*Underdosing of other general anesthetics, sequela*/
,'T413X1D'  /*Poisoning by local anesthetics, accidental (unintentional), subsequent encounter*/
,'T413X1S'  /*Poisoning by local anesthetics, accidental (unintentional), sequela*/
,'T413X2D'  /*Poisoning by local anesthetics, intentional self-harm, subsequent encounter*/
,'T413X2S'  /*Poisoning by local anesthetics, intentional self-harm, sequela*/
,'T413X3D'  /*Poisoning by local anesthetics, assault, subsequent encounter*/
,'T413X3S'  /*Poisoning by local anesthetics, assault, sequela*/
,'T413X4D'  /*Poisoning by local anesthetics, undetermined, subsequent encounter*/
,'T413X4S'  /*Poisoning by local anesthetics, undetermined, sequela*/
,'T413X5D'  /*Adverse effect of local anesthetics, subsequent encounter*/
,'T413X5S'  /*Adverse effect of local anesthetics, sequela*/
,'T413X6D'  /*Underdosing of local anesthetics, subsequent encounter*/
,'T413X6S'  /*Underdosing of local anesthetics, sequela*/
,'T4141XD'  /*Poisoning by unspecified anesthetic, accidental (unintentional), subsequent encounter*/
,'T4141XS'  /*Poisoning by unspecified anesthetic, accidental (unintentional), sequela*/
,'T4142XD'  /*Poisoning by unspecified anesthetic, intentional self-harm, subsequent encounter*/
,'T4142XS'  /*Poisoning by unspecified anesthetic, intentional self-harm, sequela*/
,'T4143XD'  /*Poisoning by unspecified anesthetic, assault, subsequent encounter*/
,'T4143XS'  /*Poisoning by unspecified anesthetic, assault, sequela*/
,'T4144XD'  /*Poisoning by unspecified anesthetic, undetermined, subsequent encounter*/
,'T4144XS'  /*Poisoning by unspecified anesthetic, undetermined, sequela*/
,'T4145XD'  /*Adverse effect of unspecified anesthetic, subsequent encounter*/
,'T4145XS'  /*Adverse effect of unspecified anesthetic, sequela*/
,'T4146XD'  /*Underdosing of unspecified anesthetics, subsequent encounter*/
,'T4146XS'  /*Underdosing of unspecified anesthetics, sequela*/
,'T415X1D'  /*Poisoning by therapeutic gases, accidental (unintentional), subsequent encounter*/
,'T415X1S'  /*Poisoning by therapeutic gases, accidental (unintentional), sequela*/
,'T415X2D'  /*Poisoning by therapeutic gases, intentional self-harm, subsequent encounter*/
,'T415X2S'  /*Poisoning by therapeutic gases, intentional self-harm, sequela*/
,'T415X3D'  /*Poisoning by therapeutic gases, assault, subsequent encounter*/
,'T415X3S'  /*Poisoning by therapeutic gases, assault, sequela*/
,'T415X4D'  /*Poisoning by therapeutic gases, undetermined, subsequent encounter*/
,'T415X4S'  /*Poisoning by therapeutic gases, undetermined, sequela*/
,'T415X5D'  /*Adverse effect of therapeutic gases, subsequent encounter*/
,'T415X5S'  /*Adverse effect of therapeutic gases, sequela*/
,'T415X6D'  /*Underdosing of therapeutic gases, subsequent encounter*/
,'T415X6S'  /*Underdosing of therapeutic gases, sequela*/
,'T420X1D'  /*Poisoning by hydantoin derivatives, accidental (unintentional), subsequent encounter*/
,'T420X1S'  /*Poisoning by hydantoin derivatives, accidental (unintentional), sequela*/
,'T420X2D'  /*Poisoning by hydantoin derivatives, intentional self-harm, subsequent encounter*/
,'T420X2S'  /*Poisoning by hydantoin derivatives, intentional self-harm, sequela*/
,'T420X3D'  /*Poisoning by hydantoin derivatives, assault, subsequent encounter*/
,'T420X3S'  /*Poisoning by hydantoin derivatives, assault, sequela*/
,'T420X4D'  /*Poisoning by hydantoin derivatives, undetermined, subsequent encounter*/
,'T420X4S'  /*Poisoning by hydantoin derivatives, undetermined, sequela*/
,'T420X5D'  /*Adverse effect of hydantoin derivatives, subsequent encounter*/
,'T420X5S'  /*Adverse effect of hydantoin derivatives, sequela*/
,'T420X6D'  /*Underdosing of hydantoin derivatives, subsequent encounter*/
,'T420X6S'  /*Underdosing of hydantoin derivatives, sequela*/
,'T421X1D'  /*Poisoning by iminostilbenes, accidental (unintentional), subsequent encounter*/
,'T421X1S'  /*Poisoning by iminostilbenes, accidental (unintentional), sequela*/
,'T421X2D'  /*Poisoning by iminostilbenes, intentional self-harm, subsequent encounter*/
,'T421X2S'  /*Poisoning by iminostilbenes, intentional self-harm, sequela*/
,'T421X3D'  /*Poisoning by iminostilbenes, assault, subsequent encounter*/
,'T421X3S'  /*Poisoning by iminostilbenes, assault, sequela*/
,'T421X4D'  /*Poisoning by iminostilbenes, undetermined, subsequent encounter*/
,'T421X4S'  /*Poisoning by iminostilbenes, undetermined, sequela*/
,'T421X5D'  /*Adverse effect of iminostilbenes, subsequent encounter*/
,'T421X5S'  /*Adverse effect of iminostilbenes, sequela*/
,'T421X6D'  /*Underdosing of iminostilbenes, subsequent encounter*/
,'T421X6S'  /*Underdosing of iminostilbenes, sequela*/
,'T422X1D'  /*Poisoning by succinimides and oxazolidinediones, accidental (unintentional), subsequent encounter*/
,'T422X1S'  /*Poisoning by succinimides and oxazolidinediones, accidental (unintentional), sequela*/
,'T422X2D'  /*Poisoning by succinimides and oxazolidinediones, intentional self-harm, subsequent encounter*/
,'T422X2S'  /*Poisoning by succinimides and oxazolidinediones, intentional self-harm, sequela*/
,'T422X3D'  /*Poisoning by succinimides and oxazolidinediones, assault, subsequent encounter*/
,'T422X3S'  /*Poisoning by succinimides and oxazolidinediones, assault, sequela*/
,'T422X4D'  /*Poisoning by succinimides and oxazolidinediones, undetermined, subsequent encounter*/
,'T422X4S'  /*Poisoning by succinimides and oxazolidinediones, undetermined, sequela*/
,'T422X5D'  /*Adverse effect of succinimides and oxazolidinediones, subsequent encounter*/
,'T422X5S'  /*Adverse effect of succinimides and oxazolidinediones, sequela*/
,'T422X6D'  /*Underdosing of succinimides and oxazolidinediones, subsequent encounter*/
,'T422X6S'  /*Underdosing of succinimides and oxazolidinediones, sequela*/
,'T423X1D'  /*Poisoning by barbiturates, accidental (unintentional), subsequent encounter*/
,'T423X1S'  /*Poisoning by barbiturates, accidental (unintentional), sequela*/
,'T423X2D'  /*Poisoning by barbiturates, intentional self-harm, subsequent encounter*/
,'T423X2S'  /*Poisoning by barbiturates, intentional self-harm, sequela*/
,'T423X3D'  /*Poisoning by barbiturates, assault, subsequent encounter*/
,'T423X3S'  /*Poisoning by barbiturates, assault, sequela*/
,'T423X4D'  /*Poisoning by barbiturates, undetermined, subsequent encounter*/
,'T423X4S'  /*Poisoning by barbiturates, undetermined, sequela*/
,'T423X5D'  /*Adverse effect of barbiturates, subsequent encounter*/
,'T423X5S'  /*Adverse effect of barbiturates, sequela*/
,'T423X6D'  /*Underdosing of barbiturates, subsequent encounter*/
,'T423X6S'  /*Underdosing of barbiturates, sequela*/
,'T424X1D'  /*Poisoning by benzodiazepines, accidental (unintentional), subsequent encounter*/
,'T424X1S'  /*Poisoning by benzodiazepines, accidental (unintentional), sequela*/
,'T424X2D'  /*Poisoning by benzodiazepines, intentional self-harm, subsequent encounter*/
,'T424X2S'  /*Poisoning by benzodiazepines, intentional self-harm, sequela*/
,'T424X3D'  /*Poisoning by benzodiazepines, assault, subsequent encounter*/
,'T424X3S'  /*Poisoning by benzodiazepines, assault, sequela*/
,'T424X4D'  /*Poisoning by benzodiazepines, undetermined, subsequent encounter*/
,'T424X4S'  /*Poisoning by benzodiazepines, undetermined, sequela*/
,'T424X5D'  /*Adverse effect of benzodiazepines, subsequent encounter*/
,'T424X5S'  /*Adverse effect of benzodiazepines, sequela*/
,'T424X6D'  /*Underdosing of benzodiazepines, subsequent encounter*/
,'T424X6S'  /*Underdosing of benzodiazepines, sequela*/
,'T425X1D'  /*Poisoning by mixed antiepileptics, accidental (unintentional), subsequent encounter*/
,'T425X1S'  /*Poisoning by mixed antiepileptics, accidental (unintentional), sequela*/
,'T425X2D'  /*Poisoning by mixed antiepileptics, intentional self-harm, subsequent encounter*/
,'T425X2S'  /*Poisoning by mixed antiepileptics, intentional self-harm, sequela*/
,'T425X3D'  /*Poisoning by mixed antiepileptics, assault, subsequent encounter*/
,'T425X3S'  /*Poisoning by mixed antiepileptics, assault, sequela*/
,'T425X4D'  /*Poisoning by mixed antiepileptics, undetermined, subsequent encounter*/
,'T425X4S'  /*Poisoning by mixed antiepileptics, undetermined, sequela*/
,'T425X5D'  /*Adverse effect of mixed antiepileptics, subsequent encounter*/
,'T425X5S'  /*Adverse effect of mixed antiepileptics, sequela*/
,'T425X6D'  /*Underdosing of mixed antiepileptics, subsequent encounter*/
,'T425X6S'  /*Underdosing of mixed antiepileptics, sequela*/
,'T426X1D'  /*Poisoning by other antiepileptic and sedative-hypnotic drugs, accidental (unintentional), subsequent encounter*/
,'T426X1S'  /*Poisoning by other antiepileptic and sedative-hypnotic drugs, accidental (unintentional), sequela*/
,'T426X2D'  /*Poisoning by other antiepileptic and sedative-hypnotic drugs, intentional self-harm, subsequent encounter*/
,'T426X2S'  /*Poisoning by other antiepileptic and sedative-hypnotic drugs, intentional self-harm, sequela*/
,'T426X3D'  /*Poisoning by other antiepileptic and sedative-hypnotic drugs, assault, subsequent encounter*/
,'T426X3S'  /*Poisoning by other antiepileptic and sedative-hypnotic drugs, assault, sequela*/
,'T426X4D'  /*Poisoning by other antiepileptic and sedative-hypnotic drugs, undetermined, subsequent encounter*/
,'T426X4S'  /*Poisoning by other antiepileptic and sedative-hypnotic drugs, undetermined, sequela*/
,'T426X5D'  /*Adverse effect of other antiepileptic and sedative-hypnotic drugs, subsequent encounter*/
,'T426X5S'  /*Adverse effect of other antiepileptic and sedative-hypnotic drugs, sequela*/
,'T426X6D'  /*Underdosing of other antiepileptic and sedative-hypnotic drugs, subsequent encounter*/
,'T426X6S'  /*Underdosing of other antiepileptic and sedative-hypnotic drugs, sequela*/
,'T4271XD'  /*Poisoning by unspecified antiepileptic and sedative-hypnotic drugs, accidental (unintentional), subsequent encounter*/
,'T4271XS'  /*Poisoning by unspecified antiepileptic and sedative-hypnotic drugs, accidental (unintentional), sequela*/
,'T4272XD'  /*Poisoning by unspecified antiepileptic and sedative-hypnotic drugs, intentional self-harm, subsequent encounter*/
,'T4272XS'  /*Poisoning by unspecified antiepileptic and sedative-hypnotic drugs, intentional self-harm, sequela*/
,'T4273XD'  /*Poisoning by unspecified antiepileptic and sedative-hypnotic drugs, assault, subsequent encounter*/
,'T4273XS'  /*Poisoning by unspecified antiepileptic and sedative-hypnotic drugs, assault, sequela*/
,'T4274XD'  /*Poisoning by unspecified antiepileptic and sedative-hypnotic drugs, undetermined, subsequent encounter*/
,'T4274XS'  /*Poisoning by unspecified antiepileptic and sedative-hypnotic drugs, undetermined, sequela*/
,'T4275XD'  /*Adverse effect of unspecified antiepileptic and sedative-hypnotic drugs, subsequent encounter*/
,'T4275XS'  /*Adverse effect of unspecified antiepileptic and sedative-hypnotic drugs, sequela*/
,'T4276XD'  /*Underdosing of unspecified antiepileptic and sedative-hypnotic drugs, subsequent encounter*/
,'T4276XS'  /*Underdosing of unspecified antiepileptic and sedative-hypnotic drugs, sequela*/
,'T428X1D'  /*Poisoning by antiparkinsonism drugs and other central muscle-tone depressants, accidental (unintentional), subsequent encounter*/
,'T428X1S'  /*Poisoning by antiparkinsonism drugs and other central muscle-tone depressants, accidental (unintentional), sequela*/
,'T428X2D'  /*Poisoning by antiparkinsonism drugs and other central muscle-tone depressants, intentional self-harm, subsequent encounter*/
,'T428X2S'  /*Poisoning by antiparkinsonism drugs and other central muscle-tone depressants, intentional self-harm, sequela*/
,'T428X3D'  /*Poisoning by antiparkinsonism drugs and other central muscle-tone depressants, assault, subsequent encounter*/
,'T428X3S'  /*Poisoning by antiparkinsonism drugs and other central muscle-tone depressants, assault, sequela*/
,'T428X4D'  /*Poisoning by antiparkinsonism drugs and other central muscle-tone depressants, undetermined, subsequent encounter*/
,'T428X4S'  /*Poisoning by antiparkinsonism drugs and other central muscle-tone depressants, undetermined, sequela*/
,'T428X5D'  /*Adverse effect of antiparkinsonism drugs and other central muscle-tone depressants, subsequent encounter*/
,'T428X5S'  /*Adverse effect of antiparkinsonism drugs and other central muscle-tone depressants, sequela*/
,'T428X6D'  /*Underdosing of antiparkinsonism drugs and other central muscle-tone depressants, subsequent encounter*/
,'T428X6S'  /*Underdosing of antiparkinsonism drugs and other central muscle-tone depressants, sequela*/
,'T43011D'  /*Poisoning by tricyclic antidepressants, accidental (unintentional), subsequent encounter*/
,'T43011S'  /*Poisoning by tricyclic antidepressants, accidental (unintentional), sequela*/
,'T43012D'  /*Poisoning by tricyclic antidepressants, intentional self-harm, subsequent encounter*/
,'T43012S'  /*Poisoning by tricyclic antidepressants, intentional self-harm, sequela*/
,'T43013D'  /*Poisoning by tricyclic antidepressants, assault, subsequent encounter*/
,'T43013S'  /*Poisoning by tricyclic antidepressants, assault, sequela*/
,'T43014D'  /*Poisoning by tricyclic antidepressants, undetermined, subsequent encounter*/
,'T43014S'  /*Poisoning by tricyclic antidepressants, undetermined, sequela*/
,'T43015D'  /*Adverse effect of tricyclic antidepressants, subsequent encounter*/
,'T43015S'  /*Adverse effect of tricyclic antidepressants, sequela*/
,'T43016D'  /*Underdosing of tricyclic antidepressants, subsequent encounter*/
,'T43016S'  /*Underdosing of tricyclic antidepressants, sequela*/
,'T43021D'  /*Poisoning by tetracyclic antidepressants, accidental (unintentional), subsequent encounter*/
,'T43021S'  /*Poisoning by tetracyclic antidepressants, accidental (unintentional), sequela*/
,'T43022D'  /*Poisoning by tetracyclic antidepressants, intentional self-harm, subsequent encounter*/
,'T43022S'  /*Poisoning by tetracyclic antidepressants, intentional self-harm, sequela*/
,'T43023D'  /*Poisoning by tetracyclic antidepressants, assault, subsequent encounter*/
,'T43023S'  /*Poisoning by tetracyclic antidepressants, assault, sequela*/
,'T43024D'  /*Poisoning by tetracyclic antidepressants, undetermined, subsequent encounter*/
,'T43024S'  /*Poisoning by tetracyclic antidepressants, undetermined, sequela*/
,'T43025D'  /*Adverse effect of tetracyclic antidepressants, subsequent encounter*/
,'T43025S'  /*Adverse effect of tetracyclic antidepressants, sequela*/
,'T43026D'  /*Underdosing of tetracyclic antidepressants, subsequent encounter*/
,'T43026S'  /*Underdosing of tetracyclic antidepressants, sequela*/
,'T431X1D'  /*Poisoning by monoamine-oxidase-inhibitor antidepressants, accidental (unintentional), subsequent encounter*/
,'T431X1S'  /*Poisoning by monoamine-oxidase-inhibitor antidepressants, accidental (unintentional), sequela*/
,'T431X2D'  /*Poisoning by monoamine-oxidase-inhibitor antidepressants, intentional self-harm, subsequent encounter*/
,'T431X2S'  /*Poisoning by monoamine-oxidase-inhibitor antidepressants, intentional self-harm, sequela*/
,'T431X3D'  /*Poisoning by monoamine-oxidase-inhibitor antidepressants, assault, subsequent encounter*/
,'T431X3S'  /*Poisoning by monoamine-oxidase-inhibitor antidepressants, assault, sequela*/
,'T431X4D'  /*Poisoning by monoamine-oxidase-inhibitor antidepressants, undetermined, subsequent encounter*/
,'T431X4S'  /*Poisoning by monoamine-oxidase-inhibitor antidepressants, undetermined, sequela*/
,'T431X5D'  /*Adverse effect of monoamine-oxidase-inhibitor antidepressants, subsequent encounter*/
,'T431X5S'  /*Adverse effect of monoamine-oxidase-inhibitor antidepressants, sequela*/
,'T431X6D'  /*Underdosing of monoamine-oxidase-inhibitor antidepressants, subsequent encounter*/
,'T431X6S'  /*Underdosing of monoamine-oxidase-inhibitor antidepressants, sequela*/
,'T43201D'  /*Poisoning by unspecified antidepressants, accidental (unintentional), subsequent encounter*/
,'T43201S'  /*Poisoning by unspecified antidepressants, accidental (unintentional), sequela*/
,'T43202D'  /*Poisoning by unspecified antidepressants, intentional self-harm, subsequent encounter*/
,'T43202S'  /*Poisoning by unspecified antidepressants, intentional self-harm, sequela*/
,'T43203D'  /*Poisoning by unspecified antidepressants, assault, subsequent encounter*/
,'T43203S'  /*Poisoning by unspecified antidepressants, assault, sequela*/
,'T43204D'  /*Poisoning by unspecified antidepressants, undetermined, subsequent encounter*/
,'T43204S'  /*Poisoning by unspecified antidepressants, undetermined, sequela*/
,'T43205D'  /*Adverse effect of unspecified antidepressants, subsequent encounter*/
,'T43205S'  /*Adverse effect of unspecified antidepressants, sequela*/
,'T43206D'  /*Underdosing of unspecified antidepressants, subsequent encounter*/
,'T43206S'  /*Underdosing of unspecified antidepressants, sequela*/
,'T43211D'  /*Poisoning by selective serotonin and norepinephrine reuptake inhibitors, accidental (unintentional), subsequent encounter*/
,'T43211S'  /*Poisoning by selective serotonin and norepinephrine reuptake inhibitors, accidental (unintentional), sequela*/
,'T43212D'  /*Poisoning by selective serotonin and norepinephrine reuptake inhibitors, intentional self-harm, subsequent encounter*/
,'T43212S'  /*Poisoning by selective serotonin and norepinephrine reuptake inhibitors, intentional self-harm, sequela*/
,'T43213D'  /*Poisoning by selective serotonin and norepinephrine reuptake inhibitors, assault, subsequent encounter*/
,'T43213S'  /*Poisoning by selective serotonin and norepinephrine reuptake inhibitors, assault, sequela*/
,'T43214D'  /*Poisoning by selective serotonin and norepinephrine reuptake inhibitors, undetermined, subsequent encounter*/
,'T43214S'  /*Poisoning by selective serotonin and norepinephrine reuptake inhibitors, undetermined, sequela*/
,'T43215D'  /*Adverse effect of selective serotonin and norepinephrine reuptake inhibitors, subsequent encounter*/
,'T43215S'  /*Adverse effect of selective serotonin and norepinephrine reuptake inhibitors, sequela*/
,'T43216D'  /*Underdosing of selective serotonin and norepinephrine reuptake inhibitors, subsequent encounter*/
,'T43216S'  /*Underdosing of selective serotonin and norepinephrine reuptake inhibitors, sequela*/
,'T43221D'  /*Poisoning by selective serotonin reuptake inhibitors, accidental (unintentional), subsequent encounter*/
,'T43221S'  /*Poisoning by selective serotonin reuptake inhibitors, accidental (unintentional), sequela*/
,'T43222D'  /*Poisoning by selective serotonin reuptake inhibitors, intentional self-harm, subsequent encounter*/
,'T43222S'  /*Poisoning by selective serotonin reuptake inhibitors, intentional self-harm, sequela*/
,'T43223D'  /*Poisoning by selective serotonin reuptake inhibitors, assault, subsequent encounter*/
,'T43223S'  /*Poisoning by selective serotonin reuptake inhibitors, assault, sequela*/
,'T43224D'  /*Poisoning by selective serotonin reuptake inhibitors, undetermined, subsequent encounter*/
,'T43224S'  /*Poisoning by selective serotonin reuptake inhibitors, undetermined, sequela*/
,'T43225D'  /*Adverse effect of selective serotonin reuptake inhibitors, subsequent encounter*/
,'T43225S'  /*Adverse effect of selective serotonin reuptake inhibitors, sequela*/
,'T43226D'  /*Underdosing of selective serotonin reuptake inhibitors, subsequent encounter*/
,'T43226S'  /*Underdosing of selective serotonin reuptake inhibitors, sequela*/
,'T43291D'  /*Poisoning by other antidepressants, accidental (unintentional), subsequent encounter*/
,'T43291S'  /*Poisoning by other antidepressants, accidental (unintentional), sequela*/
,'T43292D'  /*Poisoning by other antidepressants, intentional self-harm, subsequent encounter*/
,'T43292S'  /*Poisoning by other antidepressants, intentional self-harm, sequela*/
,'T43293D'  /*Poisoning by other antidepressants, assault, subsequent encounter*/
,'T43293S'  /*Poisoning by other antidepressants, assault, sequela*/
,'T43294D'  /*Poisoning by other antidepressants, undetermined, subsequent encounter*/
,'T43294S'  /*Poisoning by other antidepressants, undetermined, sequela*/
,'T43295D'  /*Adverse effect of other antidepressants, subsequent encounter*/
,'T43295S'  /*Adverse effect of other antidepressants, sequela*/
,'T43296D'  /*Underdosing of other antidepressants, subsequent encounter*/
,'T43296S'  /*Underdosing of other antidepressants, sequela*/
,'T433X1D'  /*Poisoning by phenothiazine antipsychotics and neuroleptics, accidental (unintentional), subsequent encounter*/
,'T433X1S'  /*Poisoning by phenothiazine antipsychotics and neuroleptics, accidental (unintentional), sequela*/
,'T433X2D'  /*Poisoning by phenothiazine antipsychotics and neuroleptics, intentional self-harm, subsequent encounter*/
,'T433X2S'  /*Poisoning by phenothiazine antipsychotics and neuroleptics, intentional self-harm, sequela*/
,'T433X3D'  /*Poisoning by phenothiazine antipsychotics and neuroleptics, assault, subsequent encounter*/
,'T433X3S'  /*Poisoning by phenothiazine antipsychotics and neuroleptics, assault, sequela*/
,'T433X4D'  /*Poisoning by phenothiazine antipsychotics and neuroleptics, undetermined, subsequent encounter*/
,'T433X4S'  /*Poisoning by phenothiazine antipsychotics and neuroleptics, undetermined, sequela*/
,'T433X5D'  /*Adverse effect of phenothiazine antipsychotics and neuroleptics, subsequent encounter*/
,'T433X5S'  /*Adverse effect of phenothiazine antipsychotics and neuroleptics, sequela*/
,'T433X6D'  /*Underdosing of phenothiazine antipsychotics and neuroleptics, subsequent encounter*/
,'T433X6S'  /*Underdosing of phenothiazine antipsychotics and neuroleptics, sequela*/
,'T434X1D'  /*Poisoning by butyrophenone and thiothixene neuroleptics, accidental (unintentional), subsequent encounter*/
,'T434X1S'  /*Poisoning by butyrophenone and thiothixene neuroleptics, accidental (unintentional), sequela*/
,'T434X2D'  /*Poisoning by butyrophenone and thiothixene neuroleptics, intentional self-harm, subsequent encounter*/
,'T434X2S'  /*Poisoning by butyrophenone and thiothixene neuroleptics, intentional self-harm, sequela*/
,'T434X3D'  /*Poisoning by butyrophenone and thiothixene neuroleptics, assault, subsequent encounter*/
,'T434X3S'  /*Poisoning by butyrophenone and thiothixene neuroleptics, assault, sequela*/
,'T434X4D'  /*Poisoning by butyrophenone and thiothixene neuroleptics, undetermined, subsequent encounter*/
,'T434X4S'  /*Poisoning by butyrophenone and thiothixene neuroleptics, undetermined, sequela*/
,'T434X5D'  /*Adverse effect of butyrophenone and thiothixene neuroleptics, subsequent encounter*/
,'T434X5S'  /*Adverse effect of butyrophenone and thiothixene neuroleptics, sequela*/
,'T434X6D'  /*Underdosing of butyrophenone and thiothixene neuroleptics, subsequent encounter*/
,'T434X6S'  /*Underdosing of butyrophenone and thiothixene neuroleptics, sequela*/
,'T43501D'  /*Poisoning by unspecified antipsychotics and neuroleptics, accidental (unintentional), subsequent encounter*/
,'T43501S'  /*Poisoning by unspecified antipsychotics and neuroleptics, accidental (unintentional), sequela*/
,'T43502D'  /*Poisoning by unspecified antipsychotics and neuroleptics, intentional self-harm, subsequent encounter*/
,'T43502S'  /*Poisoning by unspecified antipsychotics and neuroleptics, intentional self-harm, sequela*/
,'T43503D'  /*Poisoning by unspecified antipsychotics and neuroleptics, assault, subsequent encounter*/
,'T43503S'  /*Poisoning by unspecified antipsychotics and neuroleptics, assault, sequela*/
,'T43504D'  /*Poisoning by unspecified antipsychotics and neuroleptics, undetermined, subsequent encounter*/
,'T43504S'  /*Poisoning by unspecified antipsychotics and neuroleptics, undetermined, sequela*/
,'T43505D'  /*Adverse effect of unspecified antipsychotics and neuroleptics, subsequent encounter*/
,'T43505S'  /*Adverse effect of unspecified antipsychotics and neuroleptics, sequela*/
,'T43506D'  /*Underdosing of unspecified antipsychotics and neuroleptics, subsequent encounter*/
,'T43506S'  /*Underdosing of unspecified antipsychotics and neuroleptics, sequela*/
,'T43591D'  /*Poisoning by other antipsychotics and neuroleptics, accidental (unintentional), subsequent encounter*/
,'T43591S'  /*Poisoning by other antipsychotics and neuroleptics, accidental (unintentional), sequela*/
,'T43592D'  /*Poisoning by other antipsychotics and neuroleptics, intentional self-harm, subsequent encounter*/
,'T43592S'  /*Poisoning by other antipsychotics and neuroleptics, intentional self-harm, sequela*/
,'T43593D'  /*Poisoning by other antipsychotics and neuroleptics, assault, subsequent encounter*/
,'T43593S'  /*Poisoning by other antipsychotics and neuroleptics, assault, sequela*/
,'T43594D'  /*Poisoning by other antipsychotics and neuroleptics, undetermined, subsequent encounter*/
,'T43594S'  /*Poisoning by other antipsychotics and neuroleptics, undetermined, sequela*/
,'T43595D'  /*Adverse effect of other antipsychotics and neuroleptics, subsequent encounter*/
,'T43595S'  /*Adverse effect of other antipsychotics and neuroleptics, sequela*/
,'T43596D'  /*Underdosing of other antipsychotics and neuroleptics, subsequent encounter*/
,'T43596S'  /*Underdosing of other antipsychotics and neuroleptics, sequela*/
,'T43601D'  /*Poisoning by unspecified psychostimulants, accidental (unintentional), subsequent encounter*/
,'T43601S'  /*Poisoning by unspecified psychostimulants, accidental (unintentional), sequela*/
,'T43602D'  /*Poisoning by unspecified psychostimulants, intentional self-harm, subsequent encounter*/
,'T43602S'  /*Poisoning by unspecified psychostimulants, intentional self-harm, sequela*/
,'T43603D'  /*Poisoning by unspecified psychostimulants, assault, subsequent encounter*/
,'T43603S'  /*Poisoning by unspecified psychostimulants, assault, sequela*/
,'T43604D'  /*Poisoning by unspecified psychostimulants, undetermined, subsequent encounter*/
,'T43604S'  /*Poisoning by unspecified psychostimulants, undetermined, sequela*/
,'T43605D'  /*Adverse effect of unspecified psychostimulants, subsequent encounter*/
,'T43605S'  /*Adverse effect of unspecified psychostimulants, sequela*/
,'T43606D'  /*Underdosing of unspecified psychostimulants, subsequent encounter*/
,'T43606S'  /*Underdosing of unspecified psychostimulants, sequela*/
,'T43611D'  /*Poisoning by caffeine, accidental (unintentional), subsequent encounter*/
,'T43611S'  /*Poisoning by caffeine, accidental (unintentional), sequela*/
,'T43612D'  /*Poisoning by caffeine, intentional self-harm, subsequent encounter*/
,'T43612S'  /*Poisoning by caffeine, intentional self-harm, sequela*/
,'T43613D'  /*Poisoning by caffeine, assault, subsequent encounter*/
,'T43613S'  /*Poisoning by caffeine, assault, sequela*/
,'T43614D'  /*Poisoning by caffeine, undetermined, subsequent encounter*/
,'T43614S'  /*Poisoning by caffeine, undetermined, sequela*/
,'T43615D'  /*Adverse effect of caffeine, subsequent encounter*/
,'T43615S'  /*Adverse effect of caffeine, sequela*/
,'T43616D'  /*Underdosing of caffeine, subsequent encounter*/
,'T43616S'  /*Underdosing of caffeine, sequela*/
,'T43621D'  /*Poisoning by amphetamines, accidental (unintentional), subsequent encounter*/
,'T43621S'  /*Poisoning by amphetamines, accidental (unintentional), sequela*/
,'T43622D'  /*Poisoning by amphetamines, intentional self-harm, subsequent encounter*/
,'T43622S'  /*Poisoning by amphetamines, intentional self-harm, sequela*/
,'T43623D'  /*Poisoning by amphetamines, assault, subsequent encounter*/
,'T43623S'  /*Poisoning by amphetamines, assault, sequela*/
,'T43624D'  /*Poisoning by amphetamines, undetermined, subsequent encounter*/
,'T43624S'  /*Poisoning by amphetamines, undetermined, sequela*/
,'T43625D'  /*Adverse effect of amphetamines, subsequent encounter*/
,'T43625S'  /*Adverse effect of amphetamines, sequela*/
,'T43626D'  /*Underdosing of amphetamines, subsequent encounter*/
,'T43626S'  /*Underdosing of amphetamines, sequela*/
,'T43631D'  /*Poisoning by methylphenidate, accidental (unintentional), subsequent encounter*/
,'T43631S'  /*Poisoning by methylphenidate, accidental (unintentional), sequela*/
,'T43632D'  /*Poisoning by methylphenidate, intentional self-harm, subsequent encounter*/
,'T43632S'  /*Poisoning by methylphenidate, intentional self-harm, sequela*/
,'T43633D'  /*Poisoning by methylphenidate, assault, subsequent encounter*/
,'T43633S'  /*Poisoning by methylphenidate, assault, sequela*/
,'T43634D'  /*Poisoning by methylphenidate, undetermined, subsequent encounter*/
,'T43634S'  /*Poisoning by methylphenidate, undetermined, sequela*/
,'T43635D'  /*Adverse effect of methylphenidate, subsequent encounter*/
,'T43635S'  /*Adverse effect of methylphenidate, sequela*/
,'T43636D'  /*Underdosing of methylphenidate, subsequent encounter*/
,'T43636S'  /*Underdosing of methylphenidate, sequela*/
,'T43691D'  /*Poisoning by other psychostimulants, accidental (unintentional), subsequent encounter*/
,'T43691S'  /*Poisoning by other psychostimulants, accidental (unintentional), sequela*/
,'T43692D'  /*Poisoning by other psychostimulants, intentional self-harm, subsequent encounter*/
,'T43692S'  /*Poisoning by other psychostimulants, intentional self-harm, sequela*/
,'T43693D'  /*Poisoning by other psychostimulants, assault, subsequent encounter*/
,'T43693S'  /*Poisoning by other psychostimulants, assault, sequela*/
,'T43694D'  /*Poisoning by other psychostimulants, undetermined, subsequent encounter*/
,'T43694S'  /*Poisoning by other psychostimulants, undetermined, sequela*/
,'T43695D'  /*Adverse effect of other psychostimulants, subsequent encounter*/
,'T43695S'  /*Adverse effect of other psychostimulants, sequela*/
,'T43696D'  /*Underdosing of other psychostimulants, subsequent encounter*/
,'T43696S'  /*Underdosing of other psychostimulants, sequela*/
,'T438X1D'  /*Poisoning by other psychotropic drugs, accidental (unintentional), subsequent encounter*/
,'T438X1S'  /*Poisoning by other psychotropic drugs, accidental (unintentional), sequela*/
,'T438X2D'  /*Poisoning by other psychotropic drugs, intentional self-harm, subsequent encounter*/
,'T438X2S'  /*Poisoning by other psychotropic drugs, intentional self-harm, sequela*/
,'T438X3D'  /*Poisoning by other psychotropic drugs, assault, subsequent encounter*/
,'T438X3S'  /*Poisoning by other psychotropic drugs, assault, sequela*/
,'T438X4D'  /*Poisoning by other psychotropic drugs, undetermined, subsequent encounter*/
,'T438X4S'  /*Poisoning by other psychotropic drugs, undetermined, sequela*/
,'T438X5D'  /*Adverse effect of other psychotropic drugs, subsequent encounter*/
,'T438X5S'  /*Adverse effect of other psychotropic drugs, sequela*/
,'T438X6D'  /*Underdosing of other psychotropic drugs, subsequent encounter*/
,'T438X6S'  /*Underdosing of other psychotropic drugs, sequela*/
,'T4391XD'  /*Poisoning by unspecified psychotropic drug, accidental (unintentional), subsequent encounter*/
,'T4391XS'  /*Poisoning by unspecified psychotropic drug, accidental (unintentional), sequela*/
,'T4392XD'  /*Poisoning by unspecified psychotropic drug, intentional self-harm, subsequent encounter*/
,'T4392XS'  /*Poisoning by unspecified psychotropic drug, intentional self-harm, sequela*/
,'T4393XD'  /*Poisoning by unspecified psychotropic drug, assault, subsequent encounter*/
,'T4393XS'  /*Poisoning by unspecified psychotropic drug, assault, sequela*/
,'T4394XD'  /*Poisoning by unspecified psychotropic drug, undetermined, subsequent encounter*/
,'T4394XS'  /*Poisoning by unspecified psychotropic drug, undetermined, sequela*/
,'T4395XD'  /*Adverse effect of unspecified psychotropic drug, subsequent encounter*/
,'T4395XS'  /*Adverse effect of unspecified psychotropic drug, sequela*/
,'T4396XD'  /*Underdosing of unspecified psychotropic drug, subsequent encounter*/
,'T4396XS'  /*Underdosing of unspecified psychotropic drug, sequela*/
,'T440X1D'  /*Poisoning by anticholinesterase agents, accidental (unintentional), subsequent encounter*/
,'T440X1S'  /*Poisoning by anticholinesterase agents, accidental (unintentional), sequela*/
,'T440X2D'  /*Poisoning by anticholinesterase agents, intentional self-harm, subsequent encounter*/
,'T440X2S'  /*Poisoning by anticholinesterase agents, intentional self-harm, sequela*/
,'T440X3D'  /*Poisoning by anticholinesterase agents, assault, subsequent encounter*/
,'T440X3S'  /*Poisoning by anticholinesterase agents, assault, sequela*/
,'T440X4D'  /*Poisoning by anticholinesterase agents, undetermined, subsequent encounter*/
,'T440X4S'  /*Poisoning by anticholinesterase agents, undetermined, sequela*/
,'T440X5D'  /*Adverse effect of anticholinesterase agents, subsequent encounter*/
,'T440X5S'  /*Adverse effect of anticholinesterase agents, sequela*/
,'T440X6D'  /*Underdosing of anticholinesterase agents, subsequent encounter*/
,'T440X6S'  /*Underdosing of anticholinesterase agents, sequela*/
,'T441X1D'  /*Poisoning by other parasympathomimetics [cholinergics], accidental (unintentional), subsequent encounter*/
,'T441X1S'  /*Poisoning by other parasympathomimetics [cholinergics], accidental (unintentional), sequela*/
,'T441X2D'  /*Poisoning by other parasympathomimetics [cholinergics], intentional self-harm, subsequent encounter*/
,'T441X2S'  /*Poisoning by other parasympathomimetics [cholinergics], intentional self-harm, sequela*/
,'T441X3D'  /*Poisoning by other parasympathomimetics [cholinergics], assault, subsequent encounter*/
,'T441X3S'  /*Poisoning by other parasympathomimetics [cholinergics], assault, sequela*/
,'T441X4D'  /*Poisoning by other parasympathomimetics [cholinergics], undetermined, subsequent encounter*/
,'T441X4S'  /*Poisoning by other parasympathomimetics [cholinergics], undetermined, sequela*/
,'T441X5D'  /*Adverse effect of other parasympathomimetics [cholinergics], subsequent encounter*/
,'T441X5S'  /*Adverse effect of other parasympathomimetics [cholinergics], sequela*/
,'T441X6D'  /*Underdosing of other parasympathomimetics, subsequent encounter*/
,'T441X6S'  /*Underdosing of other parasympathomimetics, sequela*/
,'T442X1D'  /*Poisoning by ganglionic blocking drugs, accidental (unintentional), subsequent encounter*/
,'T442X1S'  /*Poisoning by ganglionic blocking drugs, accidental (unintentional), sequela*/
,'T442X2D'  /*Poisoning by ganglionic blocking drugs, intentional self-harm, subsequent encounter*/
,'T442X2S'  /*Poisoning by ganglionic blocking drugs, intentional self-harm, sequela*/
,'T442X3D'  /*Poisoning by ganglionic blocking drugs, assault, subsequent encounter*/
,'T442X3S'  /*Poisoning by ganglionic blocking drugs, assault, sequela*/
,'T442X4D'  /*Poisoning by ganglionic blocking drugs, undetermined, subsequent encounter*/
,'T442X4S'  /*Poisoning by ganglionic blocking drugs, undetermined, sequela*/
,'T442X5D'  /*Adverse effect of ganglionic blocking drugs, subsequent encounter*/
,'T442X5S'  /*Adverse effect of ganglionic blocking drugs, sequela*/
,'T442X6D'  /*Underdosing of ganglionic blocking drugs, subsequent encounter*/
,'T442X6S'  /*Underdosing of ganglionic blocking drugs, sequela*/
,'T443X1D'  /*Poisoning by other parasympatholytics [anticholinergics and antimuscarinics] and spasmolytics, accidental (unintentional), subsequent encounter*/
,'T443X1S'  /*Poisoning by other parasympatholytics [anticholinergics and antimuscarinics] and spasmolytics, accidental (unintentional), sequela*/
,'T443X2D'  /*Poisoning by other parasympatholytics [anticholinergics and antimuscarinics] and spasmolytics, intentional self-harm, subsequent encounter*/
,'T443X2S'  /*Poisoning by other parasympatholytics [anticholinergics and antimuscarinics] and spasmolytics, intentional self-harm, sequela*/
,'T443X3D'  /*Poisoning by other parasympatholytics [anticholinergics and antimuscarinics] and spasmolytics, assault, subsequent encounter*/
,'T443X3S'  /*Poisoning by other parasympatholytics [anticholinergics and antimuscarinics] and spasmolytics, assault, sequela*/
,'T443X4D'  /*Poisoning by other parasympatholytics [anticholinergics and antimuscarinics] and spasmolytics, undetermined, subsequent encounter*/
,'T443X4S'  /*Poisoning by other parasympatholytics [anticholinergics and antimuscarinics] and spasmolytics, undetermined, sequela*/
,'T443X5D'  /*Adverse effect of other parasympatholytics [anticholinergics and antimuscarinics] and spasmolytics, subsequent encounter*/
,'T443X5S'  /*Adverse effect of other parasympatholytics [anticholinergics and antimuscarinics] and spasmolytics, sequela*/
,'T443X6D'  /*Underdosing of other parasympatholytics [anticholinergics and antimuscarinics] and spasmolytics, subsequent encounter*/
,'T443X6S'  /*Underdosing of other parasympatholytics [anticholinergics and antimuscarinics] and spasmolytics, sequela*/
,'T444X1D'  /*Poisoning by predominantly alpha-adrenoreceptor agonists, accidental (unintentional), subsequent encounter*/
,'T444X1S'  /*Poisoning by predominantly alpha-adrenoreceptor agonists, accidental (unintentional), sequela*/
,'T444X2D'  /*Poisoning by predominantly alpha-adrenoreceptor agonists, intentional self-harm, subsequent encounter*/
,'T444X2S'  /*Poisoning by predominantly alpha-adrenoreceptor agonists, intentional self-harm, sequela*/
,'T444X3D'  /*Poisoning by predominantly alpha-adrenoreceptor agonists, assault, subsequent encounter*/
,'T444X3S'  /*Poisoning by predominantly alpha-adrenoreceptor agonists, assault, sequela*/
,'T444X4D'  /*Poisoning by predominantly alpha-adrenoreceptor agonists, undetermined, subsequent encounter*/
,'T444X4S'  /*Poisoning by predominantly alpha-adrenoreceptor agonists, undetermined, sequela*/
,'T444X5D'  /*Adverse effect of predominantly alpha-adrenoreceptor agonists, subsequent encounter*/
,'T444X5S'  /*Adverse effect of predominantly alpha-adrenoreceptor agonists, sequela*/
,'T444X6D'  /*Underdosing of predominantly alpha-adrenoreceptor agonists, subsequent encounter*/
,'T444X6S'  /*Underdosing of predominantly alpha-adrenoreceptor agonists, sequela*/
,'T445X1D'  /*Poisoning by predominantly beta-adrenoreceptor agonists, accidental (unintentional), subsequent encounter*/
,'T445X1S'  /*Poisoning by predominantly beta-adrenoreceptor agonists, accidental (unintentional), sequela*/
,'T445X2D'  /*Poisoning by predominantly beta-adrenoreceptor agonists, intentional self-harm, subsequent encounter*/
,'T445X2S'  /*Poisoning by predominantly beta-adrenoreceptor agonists, intentional self-harm, sequela*/
,'T445X3D'  /*Poisoning by predominantly beta-adrenoreceptor agonists, assault, subsequent encounter*/
,'T445X3S'  /*Poisoning by predominantly beta-adrenoreceptor agonists, assault, sequela*/
,'T445X4D'  /*Poisoning by predominantly beta-adrenoreceptor agonists, undetermined, subsequent encounter*/
,'T445X4S'  /*Poisoning by predominantly beta-adrenoreceptor agonists, undetermined, sequela*/
,'T445X5D'  /*Adverse effect of predominantly beta-adrenoreceptor agonists, subsequent encounter*/
,'T445X5S'  /*Adverse effect of predominantly beta-adrenoreceptor agonists, sequela*/
,'T445X6D'  /*Underdosing of predominantly beta-adrenoreceptor agonists, subsequent encounter*/
,'T445X6S'  /*Underdosing of predominantly beta-adrenoreceptor agonists, sequela*/
,'T446X1D'  /*Poisoning by alpha-adrenoreceptor antagonists, accidental (unintentional), subsequent encounter*/
,'T446X1S'  /*Poisoning by alpha-adrenoreceptor antagonists, accidental (unintentional), sequela*/
,'T446X2D'  /*Poisoning by alpha-adrenoreceptor antagonists, intentional self-harm, subsequent encounter*/
,'T446X2S'  /*Poisoning by alpha-adrenoreceptor antagonists, intentional self-harm, sequela*/
,'T446X3D'  /*Poisoning by alpha-adrenoreceptor antagonists, assault, subsequent encounter*/
,'T446X3S'  /*Poisoning by alpha-adrenoreceptor antagonists, assault, sequela*/
,'T446X4D'  /*Poisoning by alpha-adrenoreceptor antagonists, undetermined, subsequent encounter*/
,'T446X4S'  /*Poisoning by alpha-adrenoreceptor antagonists, undetermined, sequela*/
,'T446X5D'  /*Adverse effect of alpha-adrenoreceptor antagonists, subsequent encounter*/
,'T446X5S'  /*Adverse effect of alpha-adrenoreceptor antagonists, sequela*/
,'T446X6D'  /*Underdosing of alpha-adrenoreceptor antagonists, subsequent encounter*/
,'T446X6S'  /*Underdosing of alpha-adrenoreceptor antagonists, sequela*/
,'T447X1D'  /*Poisoning by beta-adrenoreceptor antagonists, accidental (unintentional), subsequent encounter*/
,'T447X1S'  /*Poisoning by beta-adrenoreceptor antagonists, accidental (unintentional), sequela*/
,'T447X2D'  /*Poisoning by beta-adrenoreceptor antagonists, intentional self-harm, subsequent encounter*/
,'T447X2S'  /*Poisoning by beta-adrenoreceptor antagonists, intentional self-harm, sequela*/
,'T447X3D'  /*Poisoning by beta-adrenoreceptor antagonists, assault, subsequent encounter*/
,'T447X3S'  /*Poisoning by beta-adrenoreceptor antagonists, assault, sequela*/
,'T447X4D'  /*Poisoning by beta-adrenoreceptor antagonists, undetermined, subsequent encounter*/
,'T447X4S'  /*Poisoning by beta-adrenoreceptor antagonists, undetermined, sequela*/
,'T447X5D'  /*Adverse effect of beta-adrenoreceptor antagonists, subsequent encounter*/
,'T447X5S'  /*Adverse effect of beta-adrenoreceptor antagonists, sequela*/
,'T447X6D'  /*Underdosing of beta-adrenoreceptor antagonists, subsequent encounter*/
,'T447X6S'  /*Underdosing of beta-adrenoreceptor antagonists, sequela*/
,'T448X1D'  /*Poisoning by centrally-acting and adrenergic-neuron-blocking agents, accidental (unintentional), subsequent encounter*/
,'T448X1S'  /*Poisoning by centrally-acting and adrenergic-neuron-blocking agents, accidental (unintentional), sequela*/
,'T448X2D'  /*Poisoning by centrally-acting and adrenergic-neuron-blocking agents, intentional self-harm, subsequent encounter*/
,'T448X2S'  /*Poisoning by centrally-acting and adrenergic-neuron-blocking agents, intentional self-harm, sequela*/
,'T448X3D'  /*Poisoning by centrally-acting and adrenergic-neuron-blocking agents, assault, subsequent encounter*/
,'T448X3S'  /*Poisoning by centrally-acting and adrenergic-neuron-blocking agents, assault, sequela*/
,'T448X4D'  /*Poisoning by centrally-acting and adrenergic-neuron-blocking agents, undetermined, subsequent encounter*/
,'T448X4S'  /*Poisoning by centrally-acting and adrenergic-neuron-blocking agents, undetermined, sequela*/
,'T448X5D'  /*Adverse effect of centrally-acting and adrenergic-neuron-blocking agents, subsequent encounter*/
,'T448X5S'  /*Adverse effect of centrally-acting and adrenergic-neuron-blocking agents, sequela*/
,'T448X6D'  /*Underdosing of centrally-acting and adrenergic-neuron-blocking agents, subsequent encounter*/
,'T448X6S'  /*Underdosing of centrally-acting and adrenergic-neuron-blocking agents, sequela*/
,'T44901D'  /*Poisoning by unspecified drugs primarily affecting the autonomic nervous system, accidental (unintentional), subsequent encounter*/
,'T44901S'  /*Poisoning by unspecified drugs primarily affecting the autonomic nervous system, accidental (unintentional), sequela*/
,'T44902D'  /*Poisoning by unspecified drugs primarily affecting the autonomic nervous system, intentional self-harm, subsequent encounter*/
,'T44902S'  /*Poisoning by unspecified drugs primarily affecting the autonomic nervous system, intentional self-harm, sequela*/
,'T44903D'  /*Poisoning by unspecified drugs primarily affecting the autonomic nervous system, assault, subsequent encounter*/
,'T44903S'  /*Poisoning by unspecified drugs primarily affecting the autonomic nervous system, assault, sequela*/
,'T44904D'  /*Poisoning by unspecified drugs primarily affecting the autonomic nervous system, undetermined, subsequent encounter*/
,'T44904S'  /*Poisoning by unspecified drugs primarily affecting the autonomic nervous system, undetermined, sequela*/
,'T44905D'  /*Adverse effect of unspecified drugs primarily affecting the autonomic nervous system, subsequent encounter*/
,'T44905S'  /*Adverse effect of unspecified drugs primarily affecting the autonomic nervous system, sequela*/
,'T44906D'  /*Underdosing of unspecified drugs primarily affecting the autonomic nervous system, subsequent encounter*/
,'T44906S'  /*Underdosing of unspecified drugs primarily affecting the autonomic nervous system, sequela*/
,'T44991D'  /*Poisoning by other drug primarily affecting the autonomic nervous system, accidental (unintentional), subsequent encounter*/
,'T44991S'  /*Poisoning by other drug primarily affecting the autonomic nervous system, accidental (unintentional), sequela*/
,'T44992D'  /*Poisoning by other drug primarily affecting the autonomic nervous system, intentional self-harm, subsequent encounter*/
,'T44992S'  /*Poisoning by other drug primarily affecting the autonomic nervous system, intentional self-harm, sequela*/
,'T44993D'  /*Poisoning by other drug primarily affecting the autonomic nervous system, assault, subsequent encounter*/
,'T44993S'  /*Poisoning by other drug primarily affecting the autonomic nervous system, assault, sequela*/
,'T44994D'  /*Poisoning by other drug primarily affecting the autonomic nervous system, undetermined, subsequent encounter*/
,'T44994S'  /*Poisoning by other drug primarily affecting the autonomic nervous system, undetermined, sequela*/
,'T44995D'  /*Adverse effect of other drug primarily affecting the autonomic nervous system, subsequent encounter*/
,'T44995S'  /*Adverse effect of other drug primarily affecting the autonomic nervous system, sequela*/
,'T44996D'  /*Underdosing of other drug primarily affecting the autonomic nervous system, subsequent encounter*/
,'T44996S'  /*Underdosing of other drug primarily affecting the autonomic nervous system, sequela*/
,'T450X1D'  /*Poisoning by antiallergic and antiemetic drugs, accidental (unintentional), subsequent encounter*/
,'T450X1S'  /*Poisoning by antiallergic and antiemetic drugs, accidental (unintentional), sequela*/
,'T450X2D'  /*Poisoning by antiallergic and antiemetic drugs, intentional self-harm, subsequent encounter*/
,'T450X2S'  /*Poisoning by antiallergic and antiemetic drugs, intentional self-harm, sequela*/
,'T450X3D'  /*Poisoning by antiallergic and antiemetic drugs, assault, subsequent encounter*/
,'T450X3S'  /*Poisoning by antiallergic and antiemetic drugs, assault, sequela*/
,'T450X4D'  /*Poisoning by antiallergic and antiemetic drugs, undetermined, subsequent encounter*/
,'T450X4S'  /*Poisoning by antiallergic and antiemetic drugs, undetermined, sequela*/
,'T450X5D'  /*Adverse effect of antiallergic and antiemetic drugs, subsequent encounter*/
,'T450X5S'  /*Adverse effect of antiallergic and antiemetic drugs, sequela*/
,'T450X6D'  /*Underdosing of antiallergic and antiemetic drugs, subsequent encounter*/
,'T450X6S'  /*Underdosing of antiallergic and antiemetic drugs, sequela*/
,'T451X1D'  /*Poisoning by antineoplastic and immunosuppressive drugs, accidental (unintentional), subsequent encounter*/
,'T451X1S'  /*Poisoning by antineoplastic and immunosuppressive drugs, accidental (unintentional), sequela*/
,'T451X2D'  /*Poisoning by antineoplastic and immunosuppressive drugs, intentional self-harm, subsequent encounter*/
,'T451X2S'  /*Poisoning by antineoplastic and immunosuppressive drugs, intentional self-harm, sequela*/
,'T451X3D'  /*Poisoning by antineoplastic and immunosuppressive drugs, assault, subsequent encounter*/
,'T451X3S'  /*Poisoning by antineoplastic and immunosuppressive drugs, assault, sequela*/
,'T451X4D'  /*Poisoning by antineoplastic and immunosuppressive drugs, undetermined, subsequent encounter*/
,'T451X4S'  /*Poisoning by antineoplastic and immunosuppressive drugs, undetermined, sequela*/
,'T451X5D'  /*Adverse effect of antineoplastic and immunosuppressive drugs, subsequent encounter*/
,'T451X5S'  /*Adverse effect of antineoplastic and immunosuppressive drugs, sequela*/
,'T451X6D'  /*Underdosing of antineoplastic and immunosuppressive drugs, subsequent encounter*/
,'T451X6S'  /*Underdosing of antineoplastic and immunosuppressive drugs, sequela*/
,'T452X1D'  /*Poisoning by vitamins, accidental (unintentional), subsequent encounter*/
,'T452X1S'  /*Poisoning by vitamins, accidental (unintentional), sequela*/
,'T452X2D'  /*Poisoning by vitamins, intentional self-harm, subsequent encounter*/
,'T452X2S'  /*Poisoning by vitamins, intentional self-harm, sequela*/
,'T452X3D'  /*Poisoning by vitamins, assault, subsequent encounter*/
,'T452X3S'  /*Poisoning by vitamins, assault, sequela*/
,'T452X4D'  /*Poisoning by vitamins, undetermined, subsequent encounter*/
,'T452X4S'  /*Poisoning by vitamins, undetermined, sequela*/
,'T452X5D'  /*Adverse effect of vitamins, subsequent encounter*/
,'T452X5S'  /*Adverse effect of vitamins, sequela*/
,'T452X6D'  /*Underdosing of vitamins, subsequent encounter*/
,'T452X6S'  /*Underdosing of vitamins, sequela*/
,'T453X1D'  /*Poisoning by enzymes, accidental (unintentional), subsequent encounter*/
,'T453X1S'  /*Poisoning by enzymes, accidental (unintentional), sequela*/
,'T453X2D'  /*Poisoning by enzymes, intentional self-harm, subsequent encounter*/
,'T453X2S'  /*Poisoning by enzymes, intentional self-harm, sequela*/
,'T453X3D'  /*Poisoning by enzymes, assault, subsequent encounter*/
,'T453X3S'  /*Poisoning by enzymes, assault, sequela*/
,'T453X4D'  /*Poisoning by enzymes, undetermined, subsequent encounter*/
,'T453X4S'  /*Poisoning by enzymes, undetermined, sequela*/
,'T453X5D'  /*Adverse effect of enzymes, subsequent encounter*/
,'T453X5S'  /*Adverse effect of enzymes, sequela*/
,'T453X6D'  /*Underdosing of enzymes, subsequent encounter*/
,'T453X6S'  /*Underdosing of enzymes, sequela*/
,'T454X1D'  /*Poisoning by iron and its compounds, accidental (unintentional), subsequent encounter*/
,'T454X1S'  /*Poisoning by iron and its compounds, accidental (unintentional), sequela*/
,'T454X2D'  /*Poisoning by iron and its compounds, intentional self-harm, subsequent encounter*/
,'T454X2S'  /*Poisoning by iron and its compounds, intentional self-harm, sequela*/
,'T454X3D'  /*Poisoning by iron and its compounds, assault, subsequent encounter*/
,'T454X3S'  /*Poisoning by iron and its compounds, assault, sequela*/
,'T454X4D'  /*Poisoning by iron and its compounds, undetermined, subsequent encounter*/
,'T454X4S'  /*Poisoning by iron and its compounds, undetermined, sequela*/
,'T454X5D'  /*Adverse effect of iron and its compounds, subsequent encounter*/
,'T454X5S'  /*Adverse effect of iron and its compounds, sequela*/
,'T454X6D'  /*Underdosing of iron and its compounds, subsequent encounter*/
,'T454X6S'  /*Underdosing of iron and its compounds, sequela*/
,'T45511D'  /*Poisoning by anticoagulants, accidental (unintentional), subsequent encounter*/
,'T45511S'  /*Poisoning by anticoagulants, accidental (unintentional), sequela*/
,'T45512D'  /*Poisoning by anticoagulants, intentional self-harm, subsequent encounter*/
,'T45512S'  /*Poisoning by anticoagulants, intentional self-harm, sequela*/
,'T45513D'  /*Poisoning by anticoagulants, assault, subsequent encounter*/
,'T45513S'  /*Poisoning by anticoagulants, assault, sequela*/
,'T45514D'  /*Poisoning by anticoagulants, undetermined, subsequent encounter*/
,'T45514S'  /*Poisoning by anticoagulants, undetermined, sequela*/
,'T45515D'  /*Adverse effect of anticoagulants, subsequent encounter*/
,'T45515S'  /*Adverse effect of anticoagulants, sequela*/
,'T45516D'  /*Underdosing of anticoagulants, subsequent encounter*/
,'T45516S'  /*Underdosing of anticoagulants, sequela*/
,'T45521D'  /*Poisoning by antithrombotic drugs, accidental (unintentional), subsequent encounter*/
,'T45521S'  /*Poisoning by antithrombotic drugs, accidental (unintentional), sequela*/
,'T45522D'  /*Poisoning by antithrombotic drugs, intentional self-harm, subsequent encounter*/
,'T45522S'  /*Poisoning by antithrombotic drugs, intentional self-harm, sequela*/
,'T45523D'  /*Poisoning by antithrombotic drugs, assault, subsequent encounter*/
,'T45523S'  /*Poisoning by antithrombotic drugs, assault, sequela*/
,'T45524D'  /*Poisoning by antithrombotic drugs, undetermined, subsequent encounter*/
,'T45524S'  /*Poisoning by antithrombotic drugs, undetermined, sequela*/
,'T45525D'  /*Adverse effect of antithrombotic drugs, subsequent encounter*/
,'T45525S'  /*Adverse effect of antithrombotic drugs, sequela*/
,'T45526D'  /*Underdosing of antithrombotic drugs, subsequent encounter*/
,'T45526S'  /*Underdosing of antithrombotic drugs, sequela*/
,'T45601D'  /*Poisoning by unspecified fibrinolysis-affecting drugs, accidental (unintentional), subsequent encounter*/
,'T45601S'  /*Poisoning by unspecified fibrinolysis-affecting drugs, accidental (unintentional), sequela*/
,'T45602D'  /*Poisoning by unspecified fibrinolysis-affecting drugs, intentional self-harm, subsequent encounter*/
,'T45602S'  /*Poisoning by unspecified fibrinolysis-affecting drugs, intentional self-harm, sequela*/
,'T45603D'  /*Poisoning by unspecified fibrinolysis-affecting drugs, assault, subsequent encounter*/
,'T45603S'  /*Poisoning by unspecified fibrinolysis-affecting drugs, assault, sequela*/
,'T45604D'  /*Poisoning by unspecified fibrinolysis-affecting drugs, undetermined, subsequent encounter*/
,'T45604S'  /*Poisoning by unspecified fibrinolysis-affecting drugs, undetermined, sequela*/
,'T45605D'  /*Adverse effect of unspecified fibrinolysis-affecting drugs, subsequent encounter*/
,'T45605S'  /*Adverse effect of unspecified fibrinolysis-affecting drugs, sequela*/
,'T45606D'  /*Underdosing of unspecified fibrinolysis-affecting drugs, subsequent encounter*/
,'T45606S'  /*Underdosing of unspecified fibrinolysis-affecting drugs, sequela*/
,'T45611D'  /*Poisoning by thrombolytic drug, accidental (unintentional), subsequent encounter*/
,'T45611S'  /*Poisoning by thrombolytic drug, accidental (unintentional), sequela*/
,'T45612D'  /*Poisoning by thrombolytic drug, intentional self-harm, subsequent encounter*/
,'T45612S'  /*Poisoning by thrombolytic drug, intentional self-harm, sequela*/
,'T45613D'  /*Poisoning by thrombolytic drug, assault, subsequent encounter*/
,'T45613S'  /*Poisoning by thrombolytic drug, assault, sequela*/
,'T45614D'  /*Poisoning by thrombolytic drug, undetermined, subsequent encounter*/
,'T45614S'  /*Poisoning by thrombolytic drug, undetermined, sequela*/
,'T45615D'  /*Adverse effect of thrombolytic drugs, subsequent encounter*/
,'T45615S'  /*Adverse effect of thrombolytic drugs, sequela*/
,'T45616D'  /*Underdosing of thrombolytic drugs, subsequent encounter*/
,'T45616S'  /*Underdosing of thrombolytic drugs, sequela*/
,'T45621D'  /*Poisoning by hemostatic drug, accidental (unintentional), subsequent encounter*/
,'T45621S'  /*Poisoning by hemostatic drug, accidental (unintentional), sequela*/
,'T45622D'  /*Poisoning by hemostatic drug, intentional self-harm, subsequent encounter*/
,'T45622S'  /*Poisoning by hemostatic drug, intentional self-harm, sequela*/
,'T45623D'  /*Poisoning by hemostatic drug, assault, subsequent encounter*/
,'T45623S'  /*Poisoning by hemostatic drug, assault, sequela*/
,'T45624D'  /*Poisoning by hemostatic drug, undetermined, subsequent encounter*/
,'T45624S'  /*Poisoning by hemostatic drug, undetermined, sequela*/
,'T45625D'  /*Adverse effect of hemostatic drug, subsequent encounter*/
,'T45625S'  /*Adverse effect of hemostatic drug, sequela*/
,'T45626D'  /*Underdosing of hemostatic drugs, subsequent encounter*/
,'T45626S'  /*Underdosing of hemostatic drugs, sequela*/
,'T45691D'  /*Poisoning by other fibrinolysis-affecting drugs, accidental (unintentional), subsequent encounter*/
,'T45691S'  /*Poisoning by other fibrinolysis-affecting drugs, accidental (unintentional), sequela*/
,'T45692D'  /*Poisoning by other fibrinolysis-affecting drugs, intentional self-harm, subsequent encounter*/
,'T45692S'  /*Poisoning by other fibrinolysis-affecting drugs, intentional self-harm, sequela*/
,'T45693D'  /*Poisoning by other fibrinolysis-affecting drugs, assault, subsequent encounter*/
,'T45693S'  /*Poisoning by other fibrinolysis-affecting drugs, assault, sequela*/
,'T45694D'  /*Poisoning by other fibrinolysis-affecting drugs, undetermined, subsequent encounter*/
,'T45694S'  /*Poisoning by other fibrinolysis-affecting drugs, undetermined, sequela*/
,'T45695D'  /*Adverse effect of other fibrinolysis-affecting drugs, subsequent encounter*/
,'T45695S'  /*Adverse effect of other fibrinolysis-affecting drugs, sequela*/
,'T45696D'  /*Underdosing of other fibrinolysis-affecting drugs, subsequent encounter*/
,'T45696S'  /*Underdosing of other fibrinolysis-affecting drugs, sequela*/
,'T457X1D'  /*Poisoning by anticoagulant antagonists, vitamin K and other coagulants, accidental (unintentional), subsequent encounter*/
,'T457X1S'  /*Poisoning by anticoagulant antagonists, vitamin K and other coagulants, accidental (unintentional), sequela*/
,'T457X2D'  /*Poisoning by anticoagulant antagonists, vitamin K and other coagulants, intentional self-harm, subsequent encounter*/
,'T457X2S'  /*Poisoning by anticoagulant antagonists, vitamin K and other coagulants, intentional self-harm, sequela*/
,'T457X3D'  /*Poisoning by anticoagulant antagonists, vitamin K and other coagulants, assault, subsequent encounter*/
,'T457X3S'  /*Poisoning by anticoagulant antagonists, vitamin K and other coagulants, assault, sequela*/
,'T457X4D'  /*Poisoning by anticoagulant antagonists, vitamin K and other coagulants, undetermined, subsequent encounter*/
,'T457X4S'  /*Poisoning by anticoagulant antagonists, vitamin K and other coagulants, undetermined, sequela*/
,'T457X5D'  /*Adverse effect of anticoagulant antagonists, vitamin K and other coagulants, subsequent encounter*/
,'T457X5S'  /*Adverse effect of anticoagulant antagonists, vitamin K and other coagulants, sequela*/
,'T457X6D'  /*Underdosing of anticoagulant antagonist, vitamin K and other coagulants, subsequent encounter*/
,'T457X6S'  /*Underdosing of anticoagulant antagonist, vitamin K and other coagulants, sequela*/
,'T458X1D'  /*Poisoning by other primarily systemic and hematological agents, accidental (unintentional), subsequent encounter*/
,'T458X1S'  /*Poisoning by other primarily systemic and hematological agents, accidental (unintentional), sequela*/
,'T458X2D'  /*Poisoning by other primarily systemic and hematological agents, intentional self-harm, subsequent encounter*/
,'T458X2S'  /*Poisoning by other primarily systemic and hematological agents, intentional self-harm, sequela*/
,'T458X3D'  /*Poisoning by other primarily systemic and hematological agents, assault, subsequent encounter*/
,'T458X3S'  /*Poisoning by other primarily systemic and hematological agents, assault, sequela*/
,'T458X4D'  /*Poisoning by other primarily systemic and hematological agents, undetermined, subsequent encounter*/
,'T458X4S'  /*Poisoning by other primarily systemic and hematological agents, undetermined, sequela*/
,'T458X5D'  /*Adverse effect of other primarily systemic and hematological agents, subsequent encounter*/
,'T458X5S'  /*Adverse effect of other primarily systemic and hematological agents, sequela*/
,'T458X6D'  /*Underdosing of other primarily systemic and hematological agents, subsequent encounter*/
,'T458X6S'  /*Underdosing of other primarily systemic and hematological agents, sequela*/
,'T4591XD'  /*Poisoning by unspecified primarily systemic and hematological agent, accidental (unintentional), subsequent encounter*/
,'T4591XS'  /*Poisoning by unspecified primarily systemic and hematological agent, accidental (unintentional), sequela*/
,'T4592XD'  /*Poisoning by unspecified primarily systemic and hematological agent, intentional self-harm, subsequent encounter*/
,'T4592XS'  /*Poisoning by unspecified primarily systemic and hematological agent, intentional self-harm, sequela*/
,'T4593XD'  /*Poisoning by unspecified primarily systemic and hematological agent, assault, subsequent encounter*/
,'T4593XS'  /*Poisoning by unspecified primarily systemic and hematological agent, assault, sequela*/
,'T4594XD'  /*Poisoning by unspecified primarily systemic and hematological agent, undetermined, subsequent encounter*/
,'T4594XS'  /*Poisoning by unspecified primarily systemic and hematological agent, undetermined, sequela*/
,'T4595XD'  /*Adverse effect of unspecified primarily systemic and hematological agent, subsequent encounter*/
,'T4595XS'  /*Adverse effect of unspecified primarily systemic and hematological agent, sequela*/
,'T4596XD'  /*Underdosing of unspecified primarily systemic and hematological agent, subsequent encounter*/
,'T4596XS'  /*Underdosing of unspecified primarily systemic and hematological agent, sequela*/
,'T460X1D'  /*Poisoning by cardiac-stimulant glycosides and drugs of similar action, accidental (unintentional), subsequent encounter*/
,'T460X1S'  /*Poisoning by cardiac-stimulant glycosides and drugs of similar action, accidental (unintentional), sequela*/
,'T460X2D'  /*Poisoning by cardiac-stimulant glycosides and drugs of similar action, intentional self-harm, subsequent encounter*/
,'T460X2S'  /*Poisoning by cardiac-stimulant glycosides and drugs of similar action, intentional self-harm, sequela*/
,'T460X3D'  /*Poisoning by cardiac-stimulant glycosides and drugs of similar action, assault, subsequent encounter*/
,'T460X3S'  /*Poisoning by cardiac-stimulant glycosides and drugs of similar action, assault, sequela*/
,'T460X4D'  /*Poisoning by cardiac-stimulant glycosides and drugs of similar action, undetermined, subsequent encounter*/
,'T460X4S'  /*Poisoning by cardiac-stimulant glycosides and drugs of similar action, undetermined, sequela*/
,'T460X5D'  /*Adverse effect of cardiac-stimulant glycosides and drugs of similar action, subsequent encounter*/
,'T460X5S'  /*Adverse effect of cardiac-stimulant glycosides and drugs of similar action, sequela*/
,'T460X6D'  /*Underdosing of cardiac-stimulant glycosides and drugs of similar action, subsequent encounter*/
,'T460X6S'  /*Underdosing of cardiac-stimulant glycosides and drugs of similar action, sequela*/
,'T461X1D'  /*Poisoning by calcium-channel blockers, accidental (unintentional), subsequent encounter*/
,'T461X1S'  /*Poisoning by calcium-channel blockers, accidental (unintentional), sequela*/
,'T461X2D'  /*Poisoning by calcium-channel blockers, intentional self-harm, subsequent encounter*/
,'T461X2S'  /*Poisoning by calcium-channel blockers, intentional self-harm, sequela*/
,'T461X3D'  /*Poisoning by calcium-channel blockers, assault, subsequent encounter*/
,'T461X3S'  /*Poisoning by calcium-channel blockers, assault, sequela*/
,'T461X4D'  /*Poisoning by calcium-channel blockers, undetermined, subsequent encounter*/
,'T461X4S'  /*Poisoning by calcium-channel blockers, undetermined, sequela*/
,'T461X5D'  /*Adverse effect of calcium-channel blockers, subsequent encounter*/
,'T461X5S'  /*Adverse effect of calcium-channel blockers, sequela*/
,'T461X6D'  /*Underdosing of calcium-channel blockers, subsequent encounter*/
,'T461X6S'  /*Underdosing of calcium-channel blockers, sequela*/
,'T462X1D'  /*Poisoning by other antidysrhythmic drugs, accidental (unintentional), subsequent encounter*/
,'T462X1S'  /*Poisoning by other antidysrhythmic drugs, accidental (unintentional), sequela*/
,'T462X2D'  /*Poisoning by other antidysrhythmic drugs, intentional self-harm, subsequent encounter*/
,'T462X2S'  /*Poisoning by other antidysrhythmic drugs, intentional self-harm, sequela*/
,'T462X3D'  /*Poisoning by other antidysrhythmic drugs, assault, subsequent encounter*/
,'T462X3S'  /*Poisoning by other antidysrhythmic drugs, assault, sequela*/
,'T462X4D'  /*Poisoning by other antidysrhythmic drugs, undetermined, subsequent encounter*/
,'T462X4S'  /*Poisoning by other antidysrhythmic drugs, undetermined, sequela*/
,'T462X5D'  /*Adverse effect of other antidysrhythmic drugs, subsequent encounter*/
,'T462X5S'  /*Adverse effect of other antidysrhythmic drugs, sequela*/
,'T462X6D'  /*Underdosing of other antidysrhythmic drugs, subsequent encounter*/
,'T462X6S'  /*Underdosing of other antidysrhythmic drugs, sequela*/
,'T463X1D'  /*Poisoning by coronary vasodilators, accidental (unintentional), subsequent encounter*/
,'T463X1S'  /*Poisoning by coronary vasodilators, accidental (unintentional), sequela*/
,'T463X2D'  /*Poisoning by coronary vasodilators, intentional self-harm, subsequent encounter*/
,'T463X2S'  /*Poisoning by coronary vasodilators, intentional self-harm, sequela*/
,'T463X3D'  /*Poisoning by coronary vasodilators, assault, subsequent encounter*/
,'T463X3S'  /*Poisoning by coronary vasodilators, assault, sequela*/
,'T463X4D'  /*Poisoning by coronary vasodilators, undetermined, subsequent encounter*/
,'T463X4S'  /*Poisoning by coronary vasodilators, undetermined, sequela*/
,'T463X5D'  /*Adverse effect of coronary vasodilators, subsequent encounter*/
,'T463X5S'  /*Adverse effect of coronary vasodilators, sequela*/
,'T463X6D'  /*Underdosing of coronary vasodilators, subsequent encounter*/
,'T463X6S'  /*Underdosing of coronary vasodilators, sequela*/
,'T464X1D'  /*Poisoning by angiotensin-converting-enzyme inhibitors, accidental (unintentional), subsequent encounter*/
,'T464X1S'  /*Poisoning by angiotensin-converting-enzyme inhibitors, accidental (unintentional), sequela*/
,'T464X2D'  /*Poisoning by angiotensin-converting-enzyme inhibitors, intentional self-harm, subsequent encounter*/
,'T464X2S'  /*Poisoning by angiotensin-converting-enzyme inhibitors, intentional self-harm, sequela*/
,'T464X3D'  /*Poisoning by angiotensin-converting-enzyme inhibitors, assault, subsequent encounter*/
,'T464X3S'  /*Poisoning by angiotensin-converting-enzyme inhibitors, assault, sequela*/
,'T464X4D'  /*Poisoning by angiotensin-converting-enzyme inhibitors, undetermined, subsequent encounter*/
,'T464X4S'  /*Poisoning by angiotensin-converting-enzyme inhibitors, undetermined, sequela*/
,'T464X5D'  /*Adverse effect of angiotensin-converting-enzyme inhibitors, subsequent encounter*/
,'T464X5S'  /*Adverse effect of angiotensin-converting-enzyme inhibitors, sequela*/
,'T464X6D'  /*Underdosing of angiotensin-converting-enzyme inhibitors, subsequent encounter*/
,'T464X6S'  /*Underdosing of angiotensin-converting-enzyme inhibitors, sequela*/
,'T465X1D'  /*Poisoning by other antihypertensive drugs, accidental (unintentional), subsequent encounter*/
,'T465X1S'  /*Poisoning by other antihypertensive drugs, accidental (unintentional), sequela*/
,'T465X2D'  /*Poisoning by other antihypertensive drugs, intentional self-harm, subsequent encounter*/
,'T465X2S'  /*Poisoning by other antihypertensive drugs, intentional self-harm, sequela*/
,'T465X3D'  /*Poisoning by other antihypertensive drugs, assault, subsequent encounter*/
,'T465X3S'  /*Poisoning by other antihypertensive drugs, assault, sequela*/
,'T465X4D'  /*Poisoning by other antihypertensive drugs, undetermined, subsequent encounter*/
,'T465X4S'  /*Poisoning by other antihypertensive drugs, undetermined, sequela*/
,'T465X5D'  /*Adverse effect of other antihypertensive drugs, subsequent encounter*/
,'T465X5S'  /*Adverse effect of other antihypertensive drugs, sequela*/
,'T465X6D'  /*Underdosing of other antihypertensive drugs, subsequent encounter*/
,'T465X6S'  /*Underdosing of other antihypertensive drugs, sequela*/
,'T466X1D'  /*Poisoning by antihyperlipidemic and antiarteriosclerotic drugs, accidental (unintentional), subsequent encounter*/
,'T466X1S'  /*Poisoning by antihyperlipidemic and antiarteriosclerotic drugs, accidental (unintentional), sequela*/
,'T466X2D'  /*Poisoning by antihyperlipidemic and antiarteriosclerotic drugs, intentional self-harm, subsequent encounter*/
,'T466X2S'  /*Poisoning by antihyperlipidemic and antiarteriosclerotic drugs, intentional self-harm, sequela*/
,'T466X3D'  /*Poisoning by antihyperlipidemic and antiarteriosclerotic drugs, assault, subsequent encounter*/
,'T466X3S'  /*Poisoning by antihyperlipidemic and antiarteriosclerotic drugs, assault, sequela*/
,'T466X4D'  /*Poisoning by antihyperlipidemic and antiarteriosclerotic drugs, undetermined, subsequent encounter*/
,'T466X4S'  /*Poisoning by antihyperlipidemic and antiarteriosclerotic drugs, undetermined, sequela*/
,'T466X5D'  /*Adverse effect of antihyperlipidemic and antiarteriosclerotic drugs, subsequent encounter*/
,'T466X5S'  /*Adverse effect of antihyperlipidemic and antiarteriosclerotic drugs, sequela*/
,'T466X6D'  /*Underdosing of antihyperlipidemic and antiarteriosclerotic drugs, subsequent encounter*/
,'T466X6S'  /*Underdosing of antihyperlipidemic and antiarteriosclerotic drugs, sequela*/
,'T467X1D'  /*Poisoning by peripheral vasodilators, accidental (unintentional), subsequent encounter*/
,'T467X1S'  /*Poisoning by peripheral vasodilators, accidental (unintentional), sequela*/
,'T467X2D'  /*Poisoning by peripheral vasodilators, intentional self-harm, subsequent encounter*/
,'T467X2S'  /*Poisoning by peripheral vasodilators, intentional self-harm, sequela*/
,'T467X3D'  /*Poisoning by peripheral vasodilators, assault, subsequent encounter*/
,'T467X3S'  /*Poisoning by peripheral vasodilators, assault, sequela*/
,'T467X4D'  /*Poisoning by peripheral vasodilators, undetermined, subsequent encounter*/
,'T467X4S'  /*Poisoning by peripheral vasodilators, undetermined, sequela*/
,'T467X5D'  /*Adverse effect of peripheral vasodilators, subsequent encounter*/
,'T467X5S'  /*Adverse effect of peripheral vasodilators, sequela*/
,'T467X6D'  /*Underdosing of peripheral vasodilators, subsequent encounter*/
,'T467X6S'  /*Underdosing of peripheral vasodilators, sequela*/
,'T468X1D'  /*Poisoning by antivaricose drugs, including sclerosing agents, accidental (unintentional), subsequent encounter*/
,'T468X1S'  /*Poisoning by antivaricose drugs, including sclerosing agents, accidental (unintentional), sequela*/
,'T468X2D'  /*Poisoning by antivaricose drugs, including sclerosing agents, intentional self-harm, subsequent encounter*/
,'T468X2S'  /*Poisoning by antivaricose drugs, including sclerosing agents, intentional self-harm, sequela*/
,'T468X3D'  /*Poisoning by antivaricose drugs, including sclerosing agents, assault, subsequent encounter*/
,'T468X3S'  /*Poisoning by antivaricose drugs, including sclerosing agents, assault, sequela*/
,'T468X4D'  /*Poisoning by antivaricose drugs, including sclerosing agents, undetermined, subsequent encounter*/
,'T468X4S'  /*Poisoning by antivaricose drugs, including sclerosing agents, undetermined, sequela*/
,'T468X5D'  /*Adverse effect of antivaricose drugs, including sclerosing agents, subsequent encounter*/
,'T468X5S'  /*Adverse effect of antivaricose drugs, including sclerosing agents, sequela*/
,'T468X6D'  /*Underdosing of antivaricose drugs, including sclerosing agents, subsequent encounter*/
,'T468X6S'  /*Underdosing of antivaricose drugs, including sclerosing agents, sequela*/
,'T46901D'  /*Poisoning by unspecified agents primarily affecting the cardiovascular system, accidental (unintentional), subsequent encounter*/
,'T46901S'  /*Poisoning by unspecified agents primarily affecting the cardiovascular system, accidental (unintentional), sequela*/
,'T46902D'  /*Poisoning by unspecified agents primarily affecting the cardiovascular system, intentional self-harm, subsequent encounter*/
,'T46902S'  /*Poisoning by unspecified agents primarily affecting the cardiovascular system, intentional self-harm, sequela*/
,'T46903D'  /*Poisoning by unspecified agents primarily affecting the cardiovascular system, assault, subsequent encounter*/
,'T46903S'  /*Poisoning by unspecified agents primarily affecting the cardiovascular system, assault, sequela*/
,'T46904D'  /*Poisoning by unspecified agents primarily affecting the cardiovascular system, undetermined, subsequent encounter*/
,'T46904S'  /*Poisoning by unspecified agents primarily affecting the cardiovascular system, undetermined, sequela*/
,'T46905D'  /*Adverse effect of unspecified agents primarily affecting the cardiovascular system, subsequent encounter*/
,'T46905S'  /*Adverse effect of unspecified agents primarily affecting the cardiovascular system, sequela*/
,'T46906D'  /*Underdosing of unspecified agents primarily affecting the cardiovascular system, subsequent encounter*/
,'T46906S'  /*Underdosing of unspecified agents primarily affecting the cardiovascular system, sequela*/
,'T46991D'  /*Poisoning by other agents primarily affecting the cardiovascular system, accidental (unintentional), subsequent encounter*/
,'T46991S'  /*Poisoning by other agents primarily affecting the cardiovascular system, accidental (unintentional), sequela*/
,'T46992D'  /*Poisoning by other agents primarily affecting the cardiovascular system, intentional self-harm, subsequent encounter*/
,'T46992S'  /*Poisoning by other agents primarily affecting the cardiovascular system, intentional self-harm, sequela*/
,'T46993D'  /*Poisoning by other agents primarily affecting the cardiovascular system, assault, subsequent encounter*/
,'T46993S'  /*Poisoning by other agents primarily affecting the cardiovascular system, assault, sequela*/
,'T46994D'  /*Poisoning by other agents primarily affecting the cardiovascular system, undetermined, subsequent encounter*/
,'T46994S'  /*Poisoning by other agents primarily affecting the cardiovascular system, undetermined, sequela*/
,'T46995D'  /*Adverse effect of other agents primarily affecting the cardiovascular system, subsequent encounter*/
,'T46995S'  /*Adverse effect of other agents primarily affecting the cardiovascular system, sequela*/
,'T46996D'  /*Underdosing of other agents primarily affecting the cardiovascular system, subsequent encounter*/
,'T46996S'  /*Underdosing of other agents primarily affecting the cardiovascular system, sequela*/
,'T470X1D'  /*Poisoning by histamine H2-receptor blockers, accidental (unintentional), subsequent encounter*/
,'T470X1S'  /*Poisoning by histamine H2-receptor blockers, accidental (unintentional), sequela*/
,'T470X2D'  /*Poisoning by histamine H2-receptor blockers, intentional self-harm, subsequent encounter*/
,'T470X2S'  /*Poisoning by histamine H2-receptor blockers, intentional self-harm, sequela*/
,'T470X3D'  /*Poisoning by histamine H2-receptor blockers, assault, subsequent encounter*/
,'T470X3S'  /*Poisoning by histamine H2-receptor blockers, assault, sequela*/
,'T470X4D'  /*Poisoning by histamine H2-receptor blockers, undetermined, subsequent encounter*/
,'T470X4S'  /*Poisoning by histamine H2-receptor blockers, undetermined, sequela*/
,'T470X5D'  /*Adverse effect of histamine H2-receptor blockers, subsequent encounter*/
,'T470X5S'  /*Adverse effect of histamine H2-receptor blockers, sequela*/
,'T470X6D'  /*Underdosing of histamine H2-receptor blockers, subsequent encounter*/
,'T470X6S'  /*Underdosing of histamine H2-receptor blockers, sequela*/
,'T471X1D'  /*Poisoning by other antacids and anti-gastric-secretion drugs, accidental (unintentional), subsequent encounter*/
,'T471X1S'  /*Poisoning by other antacids and anti-gastric-secretion drugs, accidental (unintentional), sequela*/
,'T471X2D'  /*Poisoning by other antacids and anti-gastric-secretion drugs, intentional self-harm, subsequent encounter*/
,'T471X2S'  /*Poisoning by other antacids and anti-gastric-secretion drugs, intentional self-harm, sequela*/
,'T471X3D'  /*Poisoning by other antacids and anti-gastric-secretion drugs, assault, subsequent encounter*/
,'T471X3S'  /*Poisoning by other antacids and anti-gastric-secretion drugs, assault, sequela*/
,'T471X4D'  /*Poisoning by other antacids and anti-gastric-secretion drugs, undetermined, subsequent encounter*/
,'T471X4S'  /*Poisoning by other antacids and anti-gastric-secretion drugs, undetermined, sequela*/
,'T471X5D'  /*Adverse effect of other antacids and anti-gastric-secretion drugs, subsequent encounter*/
,'T471X5S'  /*Adverse effect of other antacids and anti-gastric-secretion drugs, sequela*/
,'T471X6D'  /*Underdosing of other antacids and anti-gastric-secretion drugs, subsequent encounter*/
,'T471X6S'  /*Underdosing of other antacids and anti-gastric-secretion drugs, sequela*/
,'T472X1D'  /*Poisoning by stimulant laxatives, accidental (unintentional), subsequent encounter*/
,'T472X1S'  /*Poisoning by stimulant laxatives, accidental (unintentional), sequela*/
,'T472X2D'  /*Poisoning by stimulant laxatives, intentional self-harm, subsequent encounter*/
,'T472X2S'  /*Poisoning by stimulant laxatives, intentional self-harm, sequela*/
,'T472X3D'  /*Poisoning by stimulant laxatives, assault, subsequent encounter*/
,'T472X3S'  /*Poisoning by stimulant laxatives, assault, sequela*/
,'T472X4D'  /*Poisoning by stimulant laxatives, undetermined, subsequent encounter*/
,'T472X4S'  /*Poisoning by stimulant laxatives, undetermined, sequela*/
,'T472X5D'  /*Adverse effect of stimulant laxatives, subsequent encounter*/
,'T472X5S'  /*Adverse effect of stimulant laxatives, sequela*/
,'T472X6D'  /*Underdosing of stimulant laxatives, subsequent encounter*/
,'T472X6S'  /*Underdosing of stimulant laxatives, sequela*/
,'T473X1D'  /*Poisoning by saline and osmotic laxatives, accidental (unintentional), subsequent encounter*/
,'T473X1S'  /*Poisoning by saline and osmotic laxatives, accidental (unintentional), sequela*/
,'T473X2D'  /*Poisoning by saline and osmotic laxatives, intentional self-harm, subsequent encounter*/
,'T473X2S'  /*Poisoning by saline and osmotic laxatives, intentional self-harm, sequela*/
,'T473X3D'  /*Poisoning by saline and osmotic laxatives, assault, subsequent encounter*/
,'T473X3S'  /*Poisoning by saline and osmotic laxatives, assault, sequela*/
,'T473X4D'  /*Poisoning by saline and osmotic laxatives, undetermined, subsequent encounter*/
,'T473X4S'  /*Poisoning by saline and osmotic laxatives, undetermined, sequela*/
,'T473X5D'  /*Adverse effect of saline and osmotic laxatives, subsequent encounter*/
,'T473X5S'  /*Adverse effect of saline and osmotic laxatives, sequela*/
,'T473X6D'  /*Underdosing of saline and osmotic laxatives, subsequent encounter*/
,'T473X6S'  /*Underdosing of saline and osmotic laxatives, sequela*/
,'T474X1D'  /*Poisoning by other laxatives, accidental (unintentional), subsequent encounter*/
,'T474X1S'  /*Poisoning by other laxatives, accidental (unintentional), sequela*/
,'T474X2D'  /*Poisoning by other laxatives, intentional self-harm, subsequent encounter*/
,'T474X2S'  /*Poisoning by other laxatives, intentional self-harm, sequela*/
,'T474X3D'  /*Poisoning by other laxatives, assault, subsequent encounter*/
,'T474X3S'  /*Poisoning by other laxatives, assault, sequela*/
,'T474X4D'  /*Poisoning by other laxatives, undetermined, subsequent encounter*/
,'T474X4S'  /*Poisoning by other laxatives, undetermined, sequela*/
,'T474X5D'  /*Adverse effect of other laxatives, subsequent encounter*/
,'T474X5S'  /*Adverse effect of other laxatives, sequela*/
,'T474X6D'  /*Underdosing of other laxatives, subsequent encounter*/
,'T474X6S'  /*Underdosing of other laxatives, sequela*/
,'T475X1D'  /*Poisoning by digestants, accidental (unintentional), subsequent encounter*/
,'T475X1S'  /*Poisoning by digestants, accidental (unintentional), sequela*/
,'T475X2D'  /*Poisoning by digestants, intentional self-harm, subsequent encounter*/
,'T475X2S'  /*Poisoning by digestants, intentional self-harm, sequela*/
,'T475X3D'  /*Poisoning by digestants, assault, subsequent encounter*/
,'T475X3S'  /*Poisoning by digestants, assault, sequela*/
,'T475X4D'  /*Poisoning by digestants, undetermined, subsequent encounter*/
,'T475X4S'  /*Poisoning by digestants, undetermined, sequela*/
,'T475X5D'  /*Adverse effect of digestants, subsequent encounter*/
,'T475X5S'  /*Adverse effect of digestants, sequela*/
,'T475X6D'  /*Underdosing of digestants, subsequent encounter*/
,'T475X6S'  /*Underdosing of digestants, sequela*/
,'T476X1D'  /*Poisoning by antidiarrheal drugs, accidental (unintentional), subsequent encounter*/
,'T476X1S'  /*Poisoning by antidiarrheal drugs, accidental (unintentional), sequela*/
,'T476X2D'  /*Poisoning by antidiarrheal drugs, intentional self-harm, subsequent encounter*/
,'T476X2S'  /*Poisoning by antidiarrheal drugs, intentional self-harm, sequela*/
,'T476X3D'  /*Poisoning by antidiarrheal drugs, assault, subsequent encounter*/
,'T476X3S'  /*Poisoning by antidiarrheal drugs, assault, sequela*/
,'T476X4D'  /*Poisoning by antidiarrheal drugs, undetermined, subsequent encounter*/
,'T476X4S'  /*Poisoning by antidiarrheal drugs, undetermined, sequela*/
,'T476X5D'  /*Adverse effect of antidiarrheal drugs, subsequent encounter*/
,'T476X5S'  /*Adverse effect of antidiarrheal drugs, sequela*/
,'T476X6D'  /*Underdosing of antidiarrheal drugs, subsequent encounter*/
,'T476X6S'  /*Underdosing of antidiarrheal drugs, sequela*/
,'T477X1D'  /*Poisoning by emetics, accidental (unintentional), subsequent encounter*/
,'T477X1S'  /*Poisoning by emetics, accidental (unintentional), sequela*/
,'T477X2D'  /*Poisoning by emetics, intentional self-harm, subsequent encounter*/
,'T477X2S'  /*Poisoning by emetics, intentional self-harm, sequela*/
,'T477X3D'  /*Poisoning by emetics, assault, subsequent encounter*/
,'T477X3S'  /*Poisoning by emetics, assault, sequela*/
,'T477X4D'  /*Poisoning by emetics, undetermined, subsequent encounter*/
,'T477X4S'  /*Poisoning by emetics, undetermined, sequela*/
,'T477X5D'  /*Adverse effect of emetics, subsequent encounter*/
,'T477X5S'  /*Adverse effect of emetics, sequela*/
,'T477X6D'  /*Underdosing of emetics, subsequent encounter*/
,'T477X6S'  /*Underdosing of emetics, sequela*/
,'T478X1D'  /*Poisoning by other agents primarily affecting gastrointestinal system, accidental (unintentional), subsequent encounter*/
,'T478X1S'  /*Poisoning by other agents primarily affecting gastrointestinal system, accidental (unintentional), sequela*/
,'T478X2D'  /*Poisoning by other agents primarily affecting gastrointestinal system, intentional self-harm, subsequent encounter*/
,'T478X2S'  /*Poisoning by other agents primarily affecting gastrointestinal system, intentional self-harm, sequela*/
,'T478X3D'  /*Poisoning by other agents primarily affecting gastrointestinal system, assault, subsequent encounter*/
,'T478X3S'  /*Poisoning by other agents primarily affecting gastrointestinal system, assault, sequela*/
,'T478X4D'  /*Poisoning by other agents primarily affecting gastrointestinal system, undetermined, subsequent encounter*/
,'T478X4S'  /*Poisoning by other agents primarily affecting gastrointestinal system, undetermined, sequela*/
,'T478X5D'  /*Adverse effect of other agents primarily affecting gastrointestinal system, subsequent encounter*/
,'T478X5S'  /*Adverse effect of other agents primarily affecting gastrointestinal system, sequela*/
,'T478X6D'  /*Underdosing of other agents primarily affecting gastrointestinal system, subsequent encounter*/
,'T478X6S'  /*Underdosing of other agents primarily affecting gastrointestinal system, sequela*/
,'T4791XD'  /*Poisoning by unspecified agents primarily affecting the gastrointestinal system, accidental (unintentional), subsequent encounter*/
,'T4791XS'  /*Poisoning by unspecified agents primarily affecting the gastrointestinal system, accidental (unintentional), sequela*/
,'T4792XD'  /*Poisoning by unspecified agents primarily affecting the gastrointestinal system, intentional self-harm, subsequent encounter*/
,'T4792XS'  /*Poisoning by unspecified agents primarily affecting the gastrointestinal system, intentional self-harm, sequela*/
,'T4793XD'  /*Poisoning by unspecified agents primarily affecting the gastrointestinal system, assault, subsequent encounter*/
,'T4793XS'  /*Poisoning by unspecified agents primarily affecting the gastrointestinal system, assault, sequela*/
,'T4794XD'  /*Poisoning by unspecified agents primarily affecting the gastrointestinal system, undetermined, subsequent encounter*/
,'T4794XS'  /*Poisoning by unspecified agents primarily affecting the gastrointestinal system, undetermined, sequela*/
,'T4795XD'  /*Adverse effect of unspecified agents primarily affecting the gastrointestinal system, subsequent encounter*/
,'T4795XS'  /*Adverse effect of unspecified agents primarily affecting the gastrointestinal system, sequela*/
,'T4796XD'  /*Underdosing of unspecified agents primarily affecting the gastrointestinal system, subsequent encounter*/
,'T4796XS'  /*Underdosing of unspecified agents primarily affecting the gastrointestinal system, sequela*/
,'T480X1D'  /*Poisoning by oxytocic drugs, accidental (unintentional), subsequent encounter*/
,'T480X1S'  /*Poisoning by oxytocic drugs, accidental (unintentional), sequela*/
,'T480X2D'  /*Poisoning by oxytocic drugs, intentional self-harm, subsequent encounter*/
,'T480X2S'  /*Poisoning by oxytocic drugs, intentional self-harm, sequela*/
,'T480X3D'  /*Poisoning by oxytocic drugs, assault, subsequent encounter*/
,'T480X3S'  /*Poisoning by oxytocic drugs, assault, sequela*/
,'T480X4D'  /*Poisoning by oxytocic drugs, undetermined, subsequent encounter*/
,'T480X4S'  /*Poisoning by oxytocic drugs, undetermined, sequela*/
,'T480X5D'  /*Adverse effect of oxytocic drugs, subsequent encounter*/
,'T480X5S'  /*Adverse effect of oxytocic drugs, sequela*/
,'T480X6D'  /*Underdosing of oxytocic drugs, subsequent encounter*/
,'T480X6S'  /*Underdosing of oxytocic drugs, sequela*/
,'T481X1D'  /*Poisoning by skeletal muscle relaxants [neuromuscular blocking agents], accidental (unintentional), subsequent encounter*/
,'T481X1S'  /*Poisoning by skeletal muscle relaxants [neuromuscular blocking agents], accidental (unintentional), sequela*/
,'T481X2D'  /*Poisoning by skeletal muscle relaxants [neuromuscular blocking agents], intentional self-harm, subsequent encounter*/
,'T481X2S'  /*Poisoning by skeletal muscle relaxants [neuromuscular blocking agents], intentional self-harm, sequela*/
,'T481X3D'  /*Poisoning by skeletal muscle relaxants [neuromuscular blocking agents], assault, subsequent encounter*/
,'T481X3S'  /*Poisoning by skeletal muscle relaxants [neuromuscular blocking agents], assault, sequela*/
,'T481X4D'  /*Poisoning by skeletal muscle relaxants [neuromuscular blocking agents], undetermined, subsequent encounter*/
,'T481X4S'  /*Poisoning by skeletal muscle relaxants [neuromuscular blocking agents], undetermined, sequela*/
,'T481X5D'  /*Adverse effect of skeletal muscle relaxants [neuromuscular blocking agents], subsequent encounter*/
,'T481X5S'  /*Adverse effect of skeletal muscle relaxants [neuromuscular blocking agents], sequela*/
,'T481X6D'  /*Underdosing of skeletal muscle relaxants [neuromuscular blocking agents], subsequent encounter*/
,'T481X6S'  /*Underdosing of skeletal muscle relaxants [neuromuscular blocking agents], sequela*/
,'T48201D'  /*Poisoning by unspecified drugs acting on muscles, accidental (unintentional), subsequent encounter*/
,'T48201S'  /*Poisoning by unspecified drugs acting on muscles, accidental (unintentional), sequela*/
,'T48202D'  /*Poisoning by unspecified drugs acting on muscles, intentional self-harm, subsequent encounter*/
,'T48202S'  /*Poisoning by unspecified drugs acting on muscles, intentional self-harm, sequela*/
,'T48203D'  /*Poisoning by unspecified drugs acting on muscles, assault, subsequent encounter*/
,'T48203S'  /*Poisoning by unspecified drugs acting on muscles, assault, sequela*/
,'T48204D'  /*Poisoning by unspecified drugs acting on muscles, undetermined, subsequent encounter*/
,'T48204S'  /*Poisoning by unspecified drugs acting on muscles, undetermined, sequela*/
,'T48205D'  /*Adverse effect of unspecified drugs acting on muscles, subsequent encounter*/
,'T48205S'  /*Adverse effect of unspecified drugs acting on muscles, sequela*/
,'T48206D'  /*Underdosing of unspecified drugs acting on muscles, subsequent encounter*/
,'T48206S'  /*Underdosing of unspecified drugs acting on muscles, sequela*/
,'T48291D'  /*Poisoning by other drugs acting on muscles, accidental (unintentional), subsequent encounter*/
,'T48291S'  /*Poisoning by other drugs acting on muscles, accidental (unintentional), sequela*/
,'T48292D'  /*Poisoning by other drugs acting on muscles, intentional self-harm, subsequent encounter*/
,'T48292S'  /*Poisoning by other drugs acting on muscles, intentional self-harm, sequela*/
,'T48293D'  /*Poisoning by other drugs acting on muscles, assault, subsequent encounter*/
,'T48293S'  /*Poisoning by other drugs acting on muscles, assault, sequela*/
,'T48294D'  /*Poisoning by other drugs acting on muscles, undetermined, subsequent encounter*/
,'T48294S'  /*Poisoning by other drugs acting on muscles, undetermined, sequela*/
,'T48295D'  /*Adverse effect of other drugs acting on muscles, subsequent encounter*/
,'T48295S'  /*Adverse effect of other drugs acting on muscles, sequela*/
,'T48296D'  /*Underdosing of other drugs acting on muscles, subsequent encounter*/
,'T48296S'  /*Underdosing of other drugs acting on muscles, sequela*/
,'T483X1D'  /*Poisoning by antitussives, accidental (unintentional), subsequent encounter*/
,'T483X1S'  /*Poisoning by antitussives, accidental (unintentional), sequela*/
,'T483X2D'  /*Poisoning by antitussives, intentional self-harm, subsequent encounter*/
,'T483X2S'  /*Poisoning by antitussives, intentional self-harm, sequela*/
,'T483X3D'  /*Poisoning by antitussives, assault, subsequent encounter*/
,'T483X3S'  /*Poisoning by antitussives, assault, sequela*/
,'T483X4D'  /*Poisoning by antitussives, undetermined, subsequent encounter*/
,'T483X4S'  /*Poisoning by antitussives, undetermined, sequela*/
,'T483X5D'  /*Adverse effect of antitussives, subsequent encounter*/
,'T483X5S'  /*Adverse effect of antitussives, sequela*/
,'T483X6D'  /*Underdosing of antitussives, subsequent encounter*/
,'T483X6S'  /*Underdosing of antitussives, sequela*/
,'T484X1D'  /*Poisoning by expectorants, accidental (unintentional), subsequent encounter*/
,'T484X1S'  /*Poisoning by expectorants, accidental (unintentional), sequela*/
,'T484X2D'  /*Poisoning by expectorants, intentional self-harm, subsequent encounter*/
,'T484X2S'  /*Poisoning by expectorants, intentional self-harm, sequela*/
,'T484X3D'  /*Poisoning by expectorants, assault, subsequent encounter*/
,'T484X3S'  /*Poisoning by expectorants, assault, sequela*/
,'T484X4D'  /*Poisoning by expectorants, undetermined, subsequent encounter*/
,'T484X4S'  /*Poisoning by expectorants, undetermined, sequela*/
,'T484X5D'  /*Adverse effect of expectorants, subsequent encounter*/
,'T484X5S'  /*Adverse effect of expectorants, sequela*/
,'T484X6D'  /*Underdosing of expectorants, subsequent encounter*/
,'T484X6S'  /*Underdosing of expectorants, sequela*/
,'T485X1D'  /*Poisoning by other anti-common-cold drugs, accidental (unintentional), subsequent encounter*/
,'T485X1S'  /*Poisoning by other anti-common-cold drugs, accidental (unintentional), sequela*/
,'T485X2D'  /*Poisoning by other anti-common-cold drugs, intentional self-harm, subsequent encounter*/
,'T485X2S'  /*Poisoning by other anti-common-cold drugs, intentional self-harm, sequela*/
,'T485X3D'  /*Poisoning by other anti-common-cold drugs, assault, subsequent encounter*/
,'T485X3S'  /*Poisoning by other anti-common-cold drugs, assault, sequela*/
,'T485X4D'  /*Poisoning by other anti-common-cold drugs, undetermined, subsequent encounter*/
,'T485X4S'  /*Poisoning by other anti-common-cold drugs, undetermined, sequela*/
,'T485X5D'  /*Adverse effect of other anti-common-cold drugs, subsequent encounter*/
,'T485X5S'  /*Adverse effect of other anti-common-cold drugs, sequela*/
,'T485X6D'  /*Underdosing of other anti-common-cold drugs, subsequent encounter*/
,'T485X6S'  /*Underdosing of other anti-common-cold drugs, sequela*/
,'T486X1D'  /*Poisoning by antiasthmatics, accidental (unintentional), subsequent encounter*/
,'T486X1S'  /*Poisoning by antiasthmatics, accidental (unintentional), sequela*/
,'T486X2D'  /*Poisoning by antiasthmatics, intentional self-harm, subsequent encounter*/
,'T486X2S'  /*Poisoning by antiasthmatics, intentional self-harm, sequela*/
,'T486X3D'  /*Poisoning by antiasthmatics, assault, subsequent encounter*/
,'T486X3S'  /*Poisoning by antiasthmatics, assault, sequela*/
,'T486X4D'  /*Poisoning by antiasthmatics, undetermined, subsequent encounter*/
,'T486X4S'  /*Poisoning by antiasthmatics, undetermined, sequela*/
,'T486X5D'  /*Adverse effect of antiasthmatics, subsequent encounter*/
,'T486X5S'  /*Adverse effect of antiasthmatics, sequela*/
,'T486X6D'  /*Underdosing of antiasthmatics, subsequent encounter*/
,'T486X6S'  /*Underdosing of antiasthmatics, sequela*/
,'T48901D'  /*Poisoning by unspecified agents primarily acting on the respiratory system, accidental (unintentional), subsequent encounter*/
,'T48901S'  /*Poisoning by unspecified agents primarily acting on the respiratory system, accidental (unintentional), sequela*/
,'T48902D'  /*Poisoning by unspecified agents primarily acting on the respiratory system, intentional self-harm, subsequent encounter*/
,'T48902S'  /*Poisoning by unspecified agents primarily acting on the respiratory system, intentional self-harm, sequela*/
,'T48903D'  /*Poisoning by unspecified agents primarily acting on the respiratory system, assault, subsequent encounter*/
,'T48903S'  /*Poisoning by unspecified agents primarily acting on the respiratory system, assault, sequela*/
,'T48904D'  /*Poisoning by unspecified agents primarily acting on the respiratory system, undetermined, subsequent encounter*/
,'T48904S'  /*Poisoning by unspecified agents primarily acting on the respiratory system, undetermined, sequela*/
,'T48905D'  /*Adverse effect of unspecified agents primarily acting on the respiratory system, subsequent encounter*/
,'T48905S'  /*Adverse effect of unspecified agents primarily acting on the respiratory system, sequela*/
,'T48906D'  /*Underdosing of unspecified agents primarily acting on the respiratory system, subsequent encounter*/
,'T48906S'  /*Underdosing of unspecified agents primarily acting on the respiratory system, sequela*/
,'T48991D'  /*Poisoning by other agents primarily acting on the respiratory system, accidental (unintentional), subsequent encounter*/
,'T48991S'  /*Poisoning by other agents primarily acting on the respiratory system, accidental (unintentional), sequela*/
,'T48992D'  /*Poisoning by other agents primarily acting on the respiratory system, intentional self-harm, subsequent encounter*/
,'T48992S'  /*Poisoning by other agents primarily acting on the respiratory system, intentional self-harm, sequela*/
,'T48993D'  /*Poisoning by other agents primarily acting on the respiratory system, assault, subsequent encounter*/
,'T48993S'  /*Poisoning by other agents primarily acting on the respiratory system, assault, sequela*/
,'T48994D'  /*Poisoning by other agents primarily acting on the respiratory system, undetermined, subsequent encounter*/
,'T48994S'  /*Poisoning by other agents primarily acting on the respiratory system, undetermined, sequela*/
,'T48995D'  /*Adverse effect of other agents primarily acting on the respiratory system, subsequent encounter*/
,'T48995S'  /*Adverse effect of other agents primarily acting on the respiratory system, sequela*/
,'T48996D'  /*Underdosing of other agents primarily acting on the respiratory system, subsequent encounter*/
,'T48996S'  /*Underdosing of other agents primarily acting on the respiratory system, sequela*/
,'T490X1D'  /*Poisoning by local antifungal, anti-infective and anti-inflammatory drugs, accidental (unintentional), subsequent encounter*/
,'T490X1S'  /*Poisoning by local antifungal, anti-infective and anti-inflammatory drugs, accidental (unintentional), sequela*/
,'T490X2D'  /*Poisoning by local antifungal, anti-infective and anti-inflammatory drugs, intentional self-harm, subsequent encounter*/
,'T490X2S'  /*Poisoning by local antifungal, anti-infective and anti-inflammatory drugs, intentional self-harm, sequela*/
,'T490X3D'  /*Poisoning by local antifungal, anti-infective and anti-inflammatory drugs, assault, subsequent encounter*/
,'T490X3S'  /*Poisoning by local antifungal, anti-infective and anti-inflammatory drugs, assault, sequela*/
,'T490X4D'  /*Poisoning by local antifungal, anti-infective and anti-inflammatory drugs, undetermined, subsequent encounter*/
,'T490X4S'  /*Poisoning by local antifungal, anti-infective and anti-inflammatory drugs, undetermined, sequela*/
,'T490X5D'  /*Adverse effect of local antifungal, anti-infective and anti-inflammatory drugs, subsequent encounter*/
,'T490X5S'  /*Adverse effect of local antifungal, anti-infective and anti-inflammatory drugs, sequela*/
,'T490X6D'  /*Underdosing of local antifungal, anti-infective and anti-inflammatory drugs, subsequent encounter*/
,'T490X6S'  /*Underdosing of local antifungal, anti-infective and anti-inflammatory drugs, sequela*/
,'T491X1D'  /*Poisoning by antipruritics, accidental (unintentional), subsequent encounter*/
,'T491X1S'  /*Poisoning by antipruritics, accidental (unintentional), sequela*/
,'T491X2D'  /*Poisoning by antipruritics, intentional self-harm, subsequent encounter*/
,'T491X2S'  /*Poisoning by antipruritics, intentional self-harm, sequela*/
,'T491X3D'  /*Poisoning by antipruritics, assault, subsequent encounter*/
,'T491X3S'  /*Poisoning by antipruritics, assault, sequela*/
,'T491X4D'  /*Poisoning by antipruritics, undetermined, subsequent encounter*/
,'T491X4S'  /*Poisoning by antipruritics, undetermined, sequela*/
,'T491X5D'  /*Adverse effect of antipruritics, subsequent encounter*/
,'T491X5S'  /*Adverse effect of antipruritics, sequela*/
,'T491X6D'  /*Underdosing of antipruritics, subsequent encounter*/
,'T491X6S'  /*Underdosing of antipruritics, sequela*/
,'T492X1D'  /*Poisoning by local astringents and local detergents, accidental (unintentional), subsequent encounter*/
,'T492X1S'  /*Poisoning by local astringents and local detergents, accidental (unintentional), sequela*/
,'T492X2D'  /*Poisoning by local astringents and local detergents, intentional self-harm, subsequent encounter*/
,'T492X2S'  /*Poisoning by local astringents and local detergents, intentional self-harm, sequela*/
,'T492X3D'  /*Poisoning by local astringents and local detergents, assault, subsequent encounter*/
,'T492X3S'  /*Poisoning by local astringents and local detergents, assault, sequela*/
,'T492X4D'  /*Poisoning by local astringents and local detergents, undetermined, subsequent encounter*/
,'T492X4S'  /*Poisoning by local astringents and local detergents, undetermined, sequela*/
,'T492X5D'  /*Adverse effect of local astringents and local detergents, subsequent encounter*/
,'T492X5S'  /*Adverse effect of local astringents and local detergents, sequela*/
,'T492X6D'  /*Underdosing of local astringents and local detergents, subsequent encounter*/
,'T492X6S'  /*Underdosing of local astringents and local detergents, sequela*/
,'T493X1D'  /*Poisoning by emollients, demulcents and protectants, accidental (unintentional), subsequent encounter*/
,'T493X1S'  /*Poisoning by emollients, demulcents and protectants, accidental (unintentional), sequela*/
,'T493X2D'  /*Poisoning by emollients, demulcents and protectants, intentional self-harm, subsequent encounter*/
,'T493X2S'  /*Poisoning by emollients, demulcents and protectants, intentional self-harm, sequela*/
,'T493X3D'  /*Poisoning by emollients, demulcents and protectants, assault, subsequent encounter*/
,'T493X3S'  /*Poisoning by emollients, demulcents and protectants, assault, sequela*/
,'T493X4D'  /*Poisoning by emollients, demulcents and protectants, undetermined, subsequent encounter*/
,'T493X4S'  /*Poisoning by emollients, demulcents and protectants, undetermined, sequela*/
,'T493X5D'  /*Adverse effect of emollients, demulcents and protectants, subsequent encounter*/
,'T493X5S'  /*Adverse effect of emollients, demulcents and protectants, sequela*/
,'T493X6D'  /*Underdosing of emollients, demulcents and protectants, subsequent encounter*/
,'T493X6S'  /*Underdosing of emollients, demulcents and protectants, sequela*/
,'T494X1D'  /*Poisoning by keratolytics, keratoplastics, and other hair treatment drugs and preparations, accidental (unintentional), subsequent encounter*/
,'T494X1S'  /*Poisoning by keratolytics, keratoplastics, and other hair treatment drugs and preparations, accidental (unintentional), sequela*/
,'T494X2D'  /*Poisoning by keratolytics, keratoplastics, and other hair treatment drugs and preparations, intentional self-harm, subsequent encounter*/
,'T494X2S'  /*Poisoning by keratolytics, keratoplastics, and other hair treatment drugs and preparations, intentional self-harm, sequela*/
,'T494X3D'  /*Poisoning by keratolytics, keratoplastics, and other hair treatment drugs and preparations, assault, subsequent encounter*/
,'T494X3S'  /*Poisoning by keratolytics, keratoplastics, and other hair treatment drugs and preparations, assault, sequela*/
,'T494X4D'  /*Poisoning by keratolytics, keratoplastics, and other hair treatment drugs and preparations, undetermined, subsequent encounter*/
,'T494X4S'  /*Poisoning by keratolytics, keratoplastics, and other hair treatment drugs and preparations, undetermined, sequela*/
,'T494X5D'  /*Adverse effect of keratolytics, keratoplastics, and other hair treatment drugs and preparations, subsequent encounter*/
,'T494X5S'  /*Adverse effect of keratolytics, keratoplastics, and other hair treatment drugs and preparations, sequela*/
,'T494X6D'  /*Underdosing of keratolytics, keratoplastics, and other hair treatment drugs and preparations, subsequent encounter*/
,'T494X6S'  /*Underdosing of keratolytics, keratoplastics, and other hair treatment drugs and preparations, sequela*/
,'T495X1D'  /*Poisoning by ophthalmological drugs and preparations, accidental (unintentional), subsequent encounter*/
,'T495X1S'  /*Poisoning by ophthalmological drugs and preparations, accidental (unintentional), sequela*/
,'T495X2D'  /*Poisoning by ophthalmological drugs and preparations, intentional self-harm, subsequent encounter*/
,'T495X2S'  /*Poisoning by ophthalmological drugs and preparations, intentional self-harm, sequela*/
,'T495X3D'  /*Poisoning by ophthalmological drugs and preparations, assault, subsequent encounter*/
,'T495X3S'  /*Poisoning by ophthalmological drugs and preparations, assault, sequela*/
,'T495X4D'  /*Poisoning by ophthalmological drugs and preparations, undetermined, subsequent encounter*/
,'T495X4S'  /*Poisoning by ophthalmological drugs and preparations, undetermined, sequela*/
,'T495X5D'  /*Adverse effect of ophthalmological drugs and preparations, subsequent encounter*/
,'T495X5S'  /*Adverse effect of ophthalmological drugs and preparations, sequela*/
,'T495X6D'  /*Underdosing of ophthalmological drugs and preparations, subsequent encounter*/
,'T495X6S'  /*Underdosing of ophthalmological drugs and preparations, sequela*/
,'T496X1D'  /*Poisoning by otorhinolaryngological drugs and preparations, accidental (unintentional), subsequent encounter*/
,'T496X1S'  /*Poisoning by otorhinolaryngological drugs and preparations, accidental (unintentional), sequela*/
,'T496X2D'  /*Poisoning by otorhinolaryngological drugs and preparations, intentional self-harm, subsequent encounter*/
,'T496X2S'  /*Poisoning by otorhinolaryngological drugs and preparations, intentional self-harm, sequela*/
,'T496X3D'  /*Poisoning by otorhinolaryngological drugs and preparations, assault, subsequent encounter*/
,'T496X3S'  /*Poisoning by otorhinolaryngological drugs and preparations, assault, sequela*/
,'T496X4D'  /*Poisoning by otorhinolaryngological drugs and preparations, undetermined, subsequent encounter*/
,'T496X4S'  /*Poisoning by otorhinolaryngological drugs and preparations, undetermined, sequela*/
,'T496X5D'  /*Adverse effect of otorhinolaryngological drugs and preparations, subsequent encounter*/
,'T496X5S'  /*Adverse effect of otorhinolaryngological drugs and preparations, sequela*/
,'T496X6D'  /*Underdosing of otorhinolaryngological drugs and preparations, subsequent encounter*/
,'T496X6S'  /*Underdosing of otorhinolaryngological drugs and preparations, sequela*/
,'T497X1D'  /*Poisoning by dental drugs, topically applied, accidental (unintentional), subsequent encounter*/
,'T497X1S'  /*Poisoning by dental drugs, topically applied, accidental (unintentional), sequela*/
,'T497X2D'  /*Poisoning by dental drugs, topically applied, intentional self-harm, subsequent encounter*/
,'T497X2S'  /*Poisoning by dental drugs, topically applied, intentional self-harm, sequela*/
,'T497X3D'  /*Poisoning by dental drugs, topically applied, assault, subsequent encounter*/
,'T497X3S'  /*Poisoning by dental drugs, topically applied, assault, sequela*/
,'T497X4D'  /*Poisoning by dental drugs, topically applied, undetermined, subsequent encounter*/
,'T497X4S'  /*Poisoning by dental drugs, topically applied, undetermined, sequela*/
,'T497X5D'  /*Adverse effect of dental drugs, topically applied, subsequent encounter*/
,'T497X5S'  /*Adverse effect of dental drugs, topically applied, sequela*/
,'T497X6D'  /*Underdosing of dental drugs, topically applied, subsequent encounter*/
,'T497X6S'  /*Underdosing of dental drugs, topically applied, sequela*/
,'T498X1D'  /*Poisoning by other topical agents, accidental (unintentional), subsequent encounter*/
,'T498X1S'  /*Poisoning by other topical agents, accidental (unintentional), sequela*/
,'T498X2D'  /*Poisoning by other topical agents, intentional self-harm, subsequent encounter*/
,'T498X2S'  /*Poisoning by other topical agents, intentional self-harm, sequela*/
,'T498X3D'  /*Poisoning by other topical agents, assault, subsequent encounter*/
,'T498X3S'  /*Poisoning by other topical agents, assault, sequela*/
,'T498X4D'  /*Poisoning by other topical agents, undetermined, subsequent encounter*/
,'T498X4S'  /*Poisoning by other topical agents, undetermined, sequela*/
,'T498X5D'  /*Adverse effect of other topical agents, subsequent encounter*/
,'T498X5S'  /*Adverse effect of other topical agents, sequela*/
,'T498X6D'  /*Underdosing of other topical agents, subsequent encounter*/
,'T498X6S'  /*Underdosing of other topical agents, sequela*/
,'T4991XD'  /*Poisoning by unspecified topical agent, accidental (unintentional), subsequent encounter*/
,'T4991XS'  /*Poisoning by unspecified topical agent, accidental (unintentional), sequela*/
,'T4992XD'  /*Poisoning by unspecified topical agent, intentional self-harm, subsequent encounter*/
,'T4992XS'  /*Poisoning by unspecified topical agent, intentional self-harm, sequela*/
,'T4993XD'  /*Poisoning by unspecified topical agent, assault, subsequent encounter*/
,'T4993XS'  /*Poisoning by unspecified topical agent, assault, sequela*/
,'T4994XD'  /*Poisoning by unspecified topical agent, undetermined, subsequent encounter*/
,'T4994XS'  /*Poisoning by unspecified topical agent, undetermined, sequela*/
,'T4995XD'  /*Adverse effect of unspecified topical agent, subsequent encounter*/
,'T4995XS'  /*Adverse effect of unspecified topical agent, sequela*/
,'T4996XD'  /*Underdosing of unspecified topical agent, subsequent encounter*/
,'T4996XS'  /*Underdosing of unspecified topical agent, sequela*/
,'T500X1D'  /*Poisoning by mineralocorticoids and their antagonists, accidental (unintentional), subsequent encounter*/
,'T500X1S'  /*Poisoning by mineralocorticoids and their antagonists, accidental (unintentional), sequela*/
,'T500X2D'  /*Poisoning by mineralocorticoids and their antagonists, intentional self-harm, subsequent encounter*/
,'T500X2S'  /*Poisoning by mineralocorticoids and their antagonists, intentional self-harm, sequela*/
,'T500X3D'  /*Poisoning by mineralocorticoids and their antagonists, assault, subsequent encounter*/
,'T500X3S'  /*Poisoning by mineralocorticoids and their antagonists, assault, sequela*/
,'T500X4D'  /*Poisoning by mineralocorticoids and their antagonists, undetermined, subsequent encounter*/
,'T500X4S'  /*Poisoning by mineralocorticoids and their antagonists, undetermined, sequela*/
,'T500X5D'  /*Adverse effect of mineralocorticoids and their antagonists, subsequent encounter*/
,'T500X5S'  /*Adverse effect of mineralocorticoids and their antagonists, sequela*/
,'T500X6D'  /*Underdosing of mineralocorticoids and their antagonists, subsequent encounter*/
,'T500X6S'  /*Underdosing of mineralocorticoids and their antagonists, sequela*/
,'T501X1D'  /*Poisoning by loop [high-ceiling] diuretics, accidental (unintentional), subsequent encounter*/
,'T501X1S'  /*Poisoning by loop [high-ceiling] diuretics, accidental (unintentional), sequela*/
,'T501X2D'  /*Poisoning by loop [high-ceiling] diuretics, intentional self-harm, subsequent encounter*/
,'T501X2S'  /*Poisoning by loop [high-ceiling] diuretics, intentional self-harm, sequela*/
,'T501X3D'  /*Poisoning by loop [high-ceiling] diuretics, assault, subsequent encounter*/
,'T501X3S'  /*Poisoning by loop [high-ceiling] diuretics, assault, sequela*/
,'T501X4D'  /*Poisoning by loop [high-ceiling] diuretics, undetermined, subsequent encounter*/
,'T501X4S'  /*Poisoning by loop [high-ceiling] diuretics, undetermined, sequela*/
,'T501X5D'  /*Adverse effect of loop [high-ceiling] diuretics, subsequent encounter*/
,'T501X5S'  /*Adverse effect of loop [high-ceiling] diuretics, sequela*/
,'T501X6D'  /*Underdosing of loop [high-ceiling] diuretics, subsequent encounter*/
,'T501X6S'  /*Underdosing of loop [high-ceiling] diuretics, sequela*/
,'T502X1D'  /*Poisoning by carbonic-anhydrase inhibitors, benzothiadiazides and other diuretics, accidental (unintentional), subsequent encounter*/
,'T502X1S'  /*Poisoning by carbonic-anhydrase inhibitors, benzothiadiazides and other diuretics, accidental (unintentional), sequela*/
,'T502X2D'  /*Poisoning by carbonic-anhydrase inhibitors, benzothiadiazides and other diuretics, intentional self-harm, subsequent encounter*/
,'T502X2S'  /*Poisoning by carbonic-anhydrase inhibitors, benzothiadiazides and other diuretics, intentional self-harm, sequela*/
,'T502X3D'  /*Poisoning by carbonic-anhydrase inhibitors, benzothiadiazides and other diuretics, assault, subsequent encounter*/
,'T502X3S'  /*Poisoning by carbonic-anhydrase inhibitors, benzothiadiazides and other diuretics, assault, sequela*/
,'T502X4D'  /*Poisoning by carbonic-anhydrase inhibitors, benzothiadiazides and other diuretics, undetermined, subsequent encounter*/
,'T502X4S'  /*Poisoning by carbonic-anhydrase inhibitors, benzothiadiazides and other diuretics, undetermined, sequela*/
,'T502X5D'  /*Adverse effect of carbonic-anhydrase inhibitors, benzothiadiazides and other diuretics, subsequent encounter*/
,'T502X5S'  /*Adverse effect of carbonic-anhydrase inhibitors, benzothiadiazides and other diuretics, sequela*/
,'T502X6D'  /*Underdosing of carbonic-anhydrase inhibitors, benzothiadiazides and other diuretics, subsequent encounter*/
,'T502X6S'  /*Underdosing of carbonic-anhydrase inhibitors, benzothiadiazides and other diuretics, sequela*/
,'T503X1D'  /*Poisoning by electrolytic, caloric and water-balance agents, accidental (unintentional), subsequent encounter*/
,'T503X1S'  /*Poisoning by electrolytic, caloric and water-balance agents, accidental (unintentional), sequela*/
,'T503X2D'  /*Poisoning by electrolytic, caloric and water-balance agents, intentional self-harm, subsequent encounter*/
,'T503X2S'  /*Poisoning by electrolytic, caloric and water-balance agents, intentional self-harm, sequela*/
,'T503X3D'  /*Poisoning by electrolytic, caloric and water-balance agents, assault, subsequent encounter*/
,'T503X3S'  /*Poisoning by electrolytic, caloric and water-balance agents, assault, sequela*/
,'T503X4D'  /*Poisoning by electrolytic, caloric and water-balance agents, undetermined, subsequent encounter*/
,'T503X4S'  /*Poisoning by electrolytic, caloric and water-balance agents, undetermined, sequela*/
,'T503X5D'  /*Adverse effect of electrolytic, caloric and water-balance agents, subsequent encounter*/
,'T503X5S'  /*Adverse effect of electrolytic, caloric and water-balance agents, sequela*/
,'T503X6D'  /*Underdosing of electrolytic, caloric and water-balance agents, subsequent encounter*/
,'T503X6S'  /*Underdosing of electrolytic, caloric and water-balance agents, sequela*/
,'T504X1D'  /*Poisoning by drugs affecting uric acid metabolism, accidental (unintentional), subsequent encounter*/
,'T504X1S'  /*Poisoning by drugs affecting uric acid metabolism, accidental (unintentional), sequela*/
,'T504X2D'  /*Poisoning by drugs affecting uric acid metabolism, intentional self-harm, subsequent encounter*/
,'T504X2S'  /*Poisoning by drugs affecting uric acid metabolism, intentional self-harm, sequela*/
,'T504X3D'  /*Poisoning by drugs affecting uric acid metabolism, assault, subsequent encounter*/
,'T504X3S'  /*Poisoning by drugs affecting uric acid metabolism, assault, sequela*/
,'T504X4D'  /*Poisoning by drugs affecting uric acid metabolism, undetermined, subsequent encounter*/
,'T504X4S'  /*Poisoning by drugs affecting uric acid metabolism, undetermined, sequela*/
,'T504X5D'  /*Adverse effect of drugs affecting uric acid metabolism, subsequent encounter*/
,'T504X5S'  /*Adverse effect of drugs affecting uric acid metabolism, sequela*/
,'T504X6D'  /*Underdosing of drugs affecting uric acid metabolism, subsequent encounter*/
,'T504X6S'  /*Underdosing of drugs affecting uric acid metabolism, sequela*/
,'T505X1D'  /*Poisoning by appetite depressants, accidental (unintentional), subsequent encounter*/
,'T505X1S'  /*Poisoning by appetite depressants, accidental (unintentional), sequela*/
,'T505X2D'  /*Poisoning by appetite depressants, intentional self-harm, subsequent encounter*/
,'T505X2S'  /*Poisoning by appetite depressants, intentional self-harm, sequela*/
,'T505X3D'  /*Poisoning by appetite depressants, assault, subsequent encounter*/
,'T505X3S'  /*Poisoning by appetite depressants, assault, sequela*/
,'T505X4D'  /*Poisoning by appetite depressants, undetermined, subsequent encounter*/
,'T505X4S'  /*Poisoning by appetite depressants, undetermined, sequela*/
,'T505X5D'  /*Adverse effect of appetite depressants, subsequent encounter*/
,'T505X5S'  /*Adverse effect of appetite depressants, sequela*/
,'T505X6D'  /*Underdosing of appetite depressants, subsequent encounter*/
,'T505X6S'  /*Underdosing of appetite depressants, sequela*/
,'T506X1D'  /*Poisoning by antidotes and chelating agents, accidental (unintentional), subsequent encounter*/
,'T506X1S'  /*Poisoning by antidotes and chelating agents, accidental (unintentional), sequela*/
,'T506X2D'  /*Poisoning by antidotes and chelating agents, intentional self-harm, subsequent encounter*/
,'T506X2S'  /*Poisoning by antidotes and chelating agents, intentional self-harm, sequela*/
,'T506X3D'  /*Poisoning by antidotes and chelating agents, assault, subsequent encounter*/
,'T506X3S'  /*Poisoning by antidotes and chelating agents, assault, sequela*/
,'T506X4D'  /*Poisoning by antidotes and chelating agents, undetermined, subsequent encounter*/
,'T506X4S'  /*Poisoning by antidotes and chelating agents, undetermined, sequela*/
,'T506X5D'  /*Adverse effect of antidotes and chelating agents, subsequent encounter*/
,'T506X5S'  /*Adverse effect of antidotes and chelating agents, sequela*/
,'T506X6D'  /*Underdosing of antidotes and chelating agents, subsequent encounter*/
,'T506X6S'  /*Underdosing of antidotes and chelating agents, sequela*/
,'T507X1D'  /*Poisoning by analeptics and opioid receptor antagonists, accidental (unintentional), subsequent encounter*/
,'T507X1S'  /*Poisoning by analeptics and opioid receptor antagonists, accidental (unintentional), sequela*/
,'T507X2D'  /*Poisoning by analeptics and opioid receptor antagonists, intentional self-harm, subsequent encounter*/
,'T507X2S'  /*Poisoning by analeptics and opioid receptor antagonists, intentional self-harm, sequela*/
,'T507X3D'  /*Poisoning by analeptics and opioid receptor antagonists, assault, subsequent encounter*/
,'T507X3S'  /*Poisoning by analeptics and opioid receptor antagonists, assault, sequela*/
,'T507X4D'  /*Poisoning by analeptics and opioid receptor antagonists, undetermined, subsequent encounter*/
,'T507X4S'  /*Poisoning by analeptics and opioid receptor antagonists, undetermined, sequela*/
,'T507X5D'  /*Adverse effect of analeptics and opioid receptor antagonists, subsequent encounter*/
,'T507X5S'  /*Adverse effect of analeptics and opioid receptor antagonists, sequela*/
,'T507X6D'  /*Underdosing of analeptics and opioid receptor antagonists, subsequent encounter*/
,'T507X6S'  /*Underdosing of analeptics and opioid receptor antagonists, sequela*/
,'T508X1D'  /*Poisoning by diagnostic agents, accidental (unintentional), subsequent encounter*/
,'T508X1S'  /*Poisoning by diagnostic agents, accidental (unintentional), sequela*/
,'T508X2D'  /*Poisoning by diagnostic agents, intentional self-harm, subsequent encounter*/
,'T508X2S'  /*Poisoning by diagnostic agents, intentional self-harm, sequela*/
,'T508X3D'  /*Poisoning by diagnostic agents, assault, subsequent encounter*/
,'T508X3S'  /*Poisoning by diagnostic agents, assault, sequela*/
,'T508X4D'  /*Poisoning by diagnostic agents, undetermined, subsequent encounter*/
,'T508X4S'  /*Poisoning by diagnostic agents, undetermined, sequela*/
,'T508X5D'  /*Adverse effect of diagnostic agents, subsequent encounter*/
,'T508X5S'  /*Adverse effect of diagnostic agents, sequela*/
,'T508X6D'  /*Underdosing of diagnostic agents, subsequent encounter*/
,'T508X6S'  /*Underdosing of diagnostic agents, sequela*/
,'T50A11D'  /*Poisoning by pertussis vaccine, including combinations with a pertussis component, accidental (unintentional), subsequent encounter*/
,'T50A11S'  /*Poisoning by pertussis vaccine, including combinations with a pertussis component, accidental (unintentional), sequela*/
,'T50A12D'  /*Poisoning by pertussis vaccine, including combinations with a pertussis component, intentional self-harm, subsequent encounter*/
,'T50A12S'  /*Poisoning by pertussis vaccine, including combinations with a pertussis component, intentional self-harm, sequela*/
,'T50A13D'  /*Poisoning by pertussis vaccine, including combinations with a pertussis component, assault, subsequent encounter*/
,'T50A13S'  /*Poisoning by pertussis vaccine, including combinations with a pertussis component, assault, sequela*/
,'T50A14D'  /*Poisoning by pertussis vaccine, including combinations with a pertussis component, undetermined, subsequent encounter*/
,'T50A14S'  /*Poisoning by pertussis vaccine, including combinations with a pertussis component, undetermined, sequela*/
,'T50A15D'  /*Adverse effect of pertussis vaccine, including combinations with a pertussis component, subsequent encounter*/
,'T50A15S'  /*Adverse effect of pertussis vaccine, including combinations with a pertussis component, sequela*/
,'T50A16D'  /*Underdosing of pertussis vaccine, including combinations with a pertussis component, subsequent encounter*/
,'T50A16S'  /*Underdosing of pertussis vaccine, including combinations with a pertussis component, sequela*/
,'T50A21D'  /*Poisoning by mixed bacterial vaccines without a pertussis component, accidental (unintentional), subsequent encounter*/
,'T50A21S'  /*Poisoning by mixed bacterial vaccines without a pertussis component, accidental (unintentional), sequela*/
,'T50A22D'  /*Poisoning by mixed bacterial vaccines without a pertussis component, intentional self-harm, subsequent encounter*/
,'T50A22S'  /*Poisoning by mixed bacterial vaccines without a pertussis component, intentional self-harm, sequela*/
,'T50A23D'  /*Poisoning by mixed bacterial vaccines without a pertussis component, assault, subsequent encounter*/
,'T50A23S'  /*Poisoning by mixed bacterial vaccines without a pertussis component, assault, sequela*/
,'T50A24D'  /*Poisoning by mixed bacterial vaccines without a pertussis component, undetermined, subsequent encounter*/
,'T50A24S'  /*Poisoning by mixed bacterial vaccines without a pertussis component, undetermined, sequela*/
,'T50A25D'  /*Adverse effect of mixed bacterial vaccines without a pertussis component, subsequent encounter*/
,'T50A25S'  /*Adverse effect of mixed bacterial vaccines without a pertussis component, sequela*/
,'T50A26D'  /*Underdosing of mixed bacterial vaccines without a pertussis component, subsequent encounter*/
,'T50A26S'  /*Underdosing of mixed bacterial vaccines without a pertussis component, sequela*/
,'T50A91D'  /*Poisoning by other bacterial vaccines, accidental (unintentional), subsequent encounter*/
,'T50A91S'  /*Poisoning by other bacterial vaccines, accidental (unintentional), sequela*/
,'T50A92D'  /*Poisoning by other bacterial vaccines, intentional self-harm, subsequent encounter*/
,'T50A92S'  /*Poisoning by other bacterial vaccines, intentional self-harm, sequela*/
,'T50A93D'  /*Poisoning by other bacterial vaccines, assault, subsequent encounter*/
,'T50A93S'  /*Poisoning by other bacterial vaccines, assault, sequela*/
,'T50A94D'  /*Poisoning by other bacterial vaccines, undetermined, subsequent encounter*/
,'T50A94S'  /*Poisoning by other bacterial vaccines, undetermined, sequela*/
,'T50A95D'  /*Adverse effect of other bacterial vaccines, subsequent encounter*/
,'T50A95S'  /*Adverse effect of other bacterial vaccines, sequela*/
,'T50A96D'  /*Underdosing of other bacterial vaccines, subsequent encounter*/
,'T50A96S'  /*Underdosing of other bacterial vaccines, sequela*/
,'T50B11D'  /*Poisoning by smallpox vaccines, accidental (unintentional), subsequent encounter*/
,'T50B11S'  /*Poisoning by smallpox vaccines, accidental (unintentional), sequela*/
,'T50B12D'  /*Poisoning by smallpox vaccines, intentional self-harm, subsequent encounter*/
,'T50B12S'  /*Poisoning by smallpox vaccines, intentional self-harm, sequela*/
,'T50B13D'  /*Poisoning by smallpox vaccines, assault, subsequent encounter*/
,'T50B13S'  /*Poisoning by smallpox vaccines, assault, sequela*/
,'T50B14D'  /*Poisoning by smallpox vaccines, undetermined, subsequent encounter*/
,'T50B14S'  /*Poisoning by smallpox vaccines, undetermined, sequela*/
,'T50B15D'  /*Adverse effect of smallpox vaccines, subsequent encounter*/
,'T50B15S'  /*Adverse effect of smallpox vaccines, sequela*/
,'T50B16D'  /*Underdosing of smallpox vaccines, subsequent encounter*/
,'T50B16S'  /*Underdosing of smallpox vaccines, sequela*/
,'T50B91D'  /*Poisoning by other viral vaccines, accidental (unintentional), subsequent encounter*/
,'T50B91S'  /*Poisoning by other viral vaccines, accidental (unintentional), sequela*/
,'T50B92D'  /*Poisoning by other viral vaccines, intentional self-harm, subsequent encounter*/
,'T50B92S'  /*Poisoning by other viral vaccines, intentional self-harm, sequela*/
,'T50B93D'  /*Poisoning by other viral vaccines, assault, subsequent encounter*/
,'T50B93S'  /*Poisoning by other viral vaccines, assault, sequela*/
,'T50B94D'  /*Poisoning by other viral vaccines, undetermined, subsequent encounter*/
,'T50B94S'  /*Poisoning by other viral vaccines, undetermined, sequela*/
,'T50B95D'  /*Adverse effect of other viral vaccines, subsequent encounter*/
,'T50B95S'  /*Adverse effect of other viral vaccines, sequela*/
,'T50B96D'  /*Underdosing of other viral vaccines, subsequent encounter*/
,'T50B96S'  /*Underdosing of other viral vaccines, sequela*/
,'T50Z11D'  /*Poisoning by immunoglobulin, accidental (unintentional), subsequent encounter*/
,'T50Z11S'  /*Poisoning by immunoglobulin, accidental (unintentional), sequela*/
,'T50Z12D'  /*Poisoning by immunoglobulin, intentional self-harm, subsequent encounter*/
,'T50Z12S'  /*Poisoning by immunoglobulin, intentional self-harm, sequela*/
,'T50Z13D'  /*Poisoning by immunoglobulin, assault, subsequent encounter*/
,'T50Z13S'  /*Poisoning by immunoglobulin, assault, sequela*/
,'T50Z14D'  /*Poisoning by immunoglobulin, undetermined, subsequent encounter*/
,'T50Z14S'  /*Poisoning by immunoglobulin, undetermined, sequela*/
,'T50Z15D'  /*Adverse effect of immunoglobulin, subsequent encounter*/
,'T50Z15S'  /*Adverse effect of immunoglobulin, sequela*/
,'T50Z16D'  /*Underdosing of immunoglobulin, subsequent encounter*/
,'T50Z16S'  /*Underdosing of immunoglobulin, sequela*/
,'T50Z91D'  /*Poisoning by other vaccines and biological substances, accidental (unintentional), subsequent encounter*/
,'T50Z91S'  /*Poisoning by other vaccines and biological substances, accidental (unintentional), sequela*/
,'T50Z92D'  /*Poisoning by other vaccines and biological substances, intentional self-harm, subsequent encounter*/
,'T50Z92S'  /*Poisoning by other vaccines and biological substances, intentional self-harm, sequela*/
,'T50Z93D'  /*Poisoning by other vaccines and biological substances, assault, subsequent encounter*/
,'T50Z93S'  /*Poisoning by other vaccines and biological substances, assault, sequela*/
,'T50Z94D'  /*Poisoning by other vaccines and biological substances, undetermined, subsequent encounter*/
,'T50Z94S'  /*Poisoning by other vaccines and biological substances, undetermined, sequela*/
,'T50Z95D'  /*Adverse effect of other vaccines and biological substances, subsequent encounter*/
,'T50Z95S'  /*Adverse effect of other vaccines and biological substances, sequela*/
,'T50Z96D'  /*Underdosing of other vaccines and biological substances, subsequent encounter*/
,'T50Z96S'  /*Underdosing of other vaccines and biological substances, sequela*/
,'T50901D'  /*Poisoning by unspecified drugs, medicaments and biological substances, accidental (unintentional), subsequent encounter*/
,'T50901S'  /*Poisoning by unspecified drugs, medicaments and biological substances, accidental (unintentional), sequela*/
,'T50902D'  /*Poisoning by unspecified drugs, medicaments and biological substances, intentional self-harm, subsequent encounter*/
,'T50902S'  /*Poisoning by unspecified drugs, medicaments and biological substances, intentional self-harm, sequela*/
,'T50903D'  /*Poisoning by unspecified drugs, medicaments and biological substances, assault, subsequent encounter*/
,'T50903S'  /*Poisoning by unspecified drugs, medicaments and biological substances, assault, sequela*/
,'T50904D'  /*Poisoning by unspecified drugs, medicaments and biological substances, undetermined, subsequent encounter*/
,'T50904S'  /*Poisoning by unspecified drugs, medicaments and biological substances, undetermined, sequela*/
,'T50905D'  /*Adverse effect of unspecified drugs, medicaments and biological substances, subsequent encounter*/
,'T50905S'  /*Adverse effect of unspecified drugs, medicaments and biological substances, sequela*/
,'T50906D'  /*Underdosing of unspecified drugs, medicaments and biological substances, subsequent encounter*/
,'T50906S'  /*Underdosing of unspecified drugs, medicaments and biological substances, sequela*/
,'T50991D'  /*Poisoning by other drugs, medicaments and biological substances, accidental (unintentional), subsequent encounter*/
,'T50991S'  /*Poisoning by other drugs, medicaments and biological substances, accidental (unintentional), sequela*/
,'T50992D'  /*Poisoning by other drugs, medicaments and biological substances, intentional self-harm, subsequent encounter*/
,'T50992S'  /*Poisoning by other drugs, medicaments and biological substances, intentional self-harm, sequela*/
,'T50993D'  /*Poisoning by other drugs, medicaments and biological substances, assault, subsequent encounter*/
,'T50993S'  /*Poisoning by other drugs, medicaments and biological substances, assault, sequela*/
,'T50994D'  /*Poisoning by other drugs, medicaments and biological substances, undetermined, subsequent encounter*/
,'T50994S'  /*Poisoning by other drugs, medicaments and biological substances, undetermined, sequela*/
,'T50995D'  /*Adverse effect of other drugs, medicaments and biological substances, subsequent encounter*/
,'T50995S'  /*Adverse effect of other drugs, medicaments and biological substances, sequela*/
,'T50996D'  /*Underdosing of other drugs, medicaments and biological substances, subsequent encounter*/
,'T50996S'  /*Underdosing of other drugs, medicaments and biological substances, sequela*/
,'T510X1D'  /*Toxic effect of ethanol, accidental (unintentional), subsequent encounter*/
,'T510X1S'  /*Toxic effect of ethanol, accidental (unintentional), sequela*/
,'T510X2D'  /*Toxic effect of ethanol, intentional self-harm, subsequent encounter*/
,'T510X2S'  /*Toxic effect of ethanol, intentional self-harm, sequela*/
,'T510X3D'  /*Toxic effect of ethanol, assault, subsequent encounter*/
,'T510X3S'  /*Toxic effect of ethanol, assault, sequela*/
,'T510X4D'  /*Toxic effect of ethanol, undetermined, subsequent encounter*/
,'T510X4S'  /*Toxic effect of ethanol, undetermined, sequela*/
,'T511X1D'  /*Toxic effect of methanol, accidental (unintentional), subsequent encounter*/
,'T511X1S'  /*Toxic effect of methanol, accidental (unintentional), sequela*/
,'T511X2D'  /*Toxic effect of methanol, intentional self-harm, subsequent encounter*/
,'T511X2S'  /*Toxic effect of methanol, intentional self-harm, sequela*/
,'T511X3D'  /*Toxic effect of methanol, assault, subsequent encounter*/
,'T511X3S'  /*Toxic effect of methanol, assault, sequela*/
,'T511X4D'  /*Toxic effect of methanol, undetermined, subsequent encounter*/
,'T511X4S'  /*Toxic effect of methanol, undetermined, sequela*/
,'T512X1D'  /*Toxic effect of 2-Propanol, accidental (unintentional), subsequent encounter*/
,'T512X1S'  /*Toxic effect of 2-Propanol, accidental (unintentional), sequela*/
,'T512X2D'  /*Toxic effect of 2-Propanol, intentional self-harm, subsequent encounter*/
,'T512X2S'  /*Toxic effect of 2-Propanol, intentional self-harm, sequela*/
,'T512X3D'  /*Toxic effect of 2-Propanol, assault, subsequent encounter*/
,'T512X3S'  /*Toxic effect of 2-Propanol, assault, sequela*/
,'T512X4D'  /*Toxic effect of 2-Propanol, undetermined, subsequent encounter*/
,'T512X4S'  /*Toxic effect of 2-Propanol, undetermined, sequela*/
,'T513X1D'  /*Toxic effect of fusel oil, accidental (unintentional), subsequent encounter*/
,'T513X1S'  /*Toxic effect of fusel oil, accidental (unintentional), sequela*/
,'T513X2D'  /*Toxic effect of fusel oil, intentional self-harm, subsequent encounter*/
,'T513X2S'  /*Toxic effect of fusel oil, intentional self-harm, sequela*/
,'T513X3D'  /*Toxic effect of fusel oil, assault, subsequent encounter*/
,'T513X3S'  /*Toxic effect of fusel oil, assault, sequela*/
,'T513X4D'  /*Toxic effect of fusel oil, undetermined, subsequent encounter*/
,'T513X4S'  /*Toxic effect of fusel oil, undetermined, sequela*/
,'T518X1D'  /*Toxic effect of other alcohols, accidental (unintentional), subsequent encounter*/
,'T518X1S'  /*Toxic effect of other alcohols, accidental (unintentional), sequela*/
,'T518X2D'  /*Toxic effect of other alcohols, intentional self-harm, subsequent encounter*/
,'T518X2S'  /*Toxic effect of other alcohols, intentional self-harm, sequela*/
,'T518X3D'  /*Toxic effect of other alcohols, assault, subsequent encounter*/
,'T518X3S'  /*Toxic effect of other alcohols, assault, sequela*/
,'T518X4D'  /*Toxic effect of other alcohols, undetermined, subsequent encounter*/
,'T518X4S'  /*Toxic effect of other alcohols, undetermined, sequela*/
,'T5191XD'  /*Toxic effect of unspecified alcohol, accidental (unintentional), subsequent encounter*/
,'T5191XS'  /*Toxic effect of unspecified alcohol, accidental (unintentional), sequela*/
,'T5192XD'  /*Toxic effect of unspecified alcohol, intentional self-harm, subsequent encounter*/
,'T5192XS'  /*Toxic effect of unspecified alcohol, intentional self-harm, sequela*/
,'T5193XD'  /*Toxic effect of unspecified alcohol, assault, subsequent encounter*/
,'T5193XS'  /*Toxic effect of unspecified alcohol, assault, sequela*/
,'T5194XD'  /*Toxic effect of unspecified alcohol, undetermined, subsequent encounter*/
,'T5194XS'  /*Toxic effect of unspecified alcohol, undetermined, sequela*/
,'T520X1D'  /*Toxic effect of petroleum products, accidental (unintentional), subsequent encounter*/
,'T520X1S'  /*Toxic effect of petroleum products, accidental (unintentional), sequela*/
,'T520X2D'  /*Toxic effect of petroleum products, intentional self-harm, subsequent encounter*/
,'T520X2S'  /*Toxic effect of petroleum products, intentional self-harm, sequela*/
,'T520X3D'  /*Toxic effect of petroleum products, assault, subsequent encounter*/
,'T520X3S'  /*Toxic effect of petroleum products, assault, sequela*/
,'T520X4D'  /*Toxic effect of petroleum products, undetermined, subsequent encounter*/
,'T520X4S'  /*Toxic effect of petroleum products, undetermined, sequela*/
,'T521X1D'  /*Toxic effect of benzene, accidental (unintentional), subsequent encounter*/
,'T521X1S'  /*Toxic effect of benzene, accidental (unintentional), sequela*/
,'T521X2D'  /*Toxic effect of benzene, intentional self-harm, subsequent encounter*/
,'T521X2S'  /*Toxic effect of benzene, intentional self-harm, sequela*/
,'T521X3D'  /*Toxic effect of benzene, assault, subsequent encounter*/
,'T521X3S'  /*Toxic effect of benzene, assault, sequela*/
,'T521X4D'  /*Toxic effect of benzene, undetermined, subsequent encounter*/
,'T521X4S'  /*Toxic effect of benzene, undetermined, sequela*/
,'T522X1D'  /*Toxic effect of homologues of benzene, accidental (unintentional), subsequent encounter*/
,'T522X1S'  /*Toxic effect of homologues of benzene, accidental (unintentional), sequela*/
,'T522X2D'  /*Toxic effect of homologues of benzene, intentional self-harm, subsequent encounter*/
,'T522X2S'  /*Toxic effect of homologues of benzene, intentional self-harm, sequela*/
,'T522X3D'  /*Toxic effect of homologues of benzene, assault, subsequent encounter*/
,'T522X3S'  /*Toxic effect of homologues of benzene, assault, sequela*/
,'T522X4D'  /*Toxic effect of homologues of benzene, undetermined, subsequent encounter*/
,'T522X4S'  /*Toxic effect of homologues of benzene, undetermined, sequela*/
,'T523X1D'  /*Toxic effect of glycols, accidental (unintentional), subsequent encounter*/
,'T523X1S'  /*Toxic effect of glycols, accidental (unintentional), sequela*/
,'T523X2D'  /*Toxic effect of glycols, intentional self-harm, subsequent encounter*/
,'T523X2S'  /*Toxic effect of glycols, intentional self-harm, sequela*/
,'T523X3D'  /*Toxic effect of glycols, assault, subsequent encounter*/
,'T523X3S'  /*Toxic effect of glycols, assault, sequela*/
,'T523X4D'  /*Toxic effect of glycols, undetermined, subsequent encounter*/
,'T523X4S'  /*Toxic effect of glycols, undetermined, sequela*/
,'T524X1D'  /*Toxic effect of ketones, accidental (unintentional), subsequent encounter*/
,'T524X1S'  /*Toxic effect of ketones, accidental (unintentional), sequela*/
,'T524X2D'  /*Toxic effect of ketones, intentional self-harm, subsequent encounter*/
,'T524X2S'  /*Toxic effect of ketones, intentional self-harm, sequela*/
,'T524X3D'  /*Toxic effect of ketones, assault, subsequent encounter*/
,'T524X3S'  /*Toxic effect of ketones, assault, sequela*/
,'T524X4D'  /*Toxic effect of ketones, undetermined, subsequent encounter*/
,'T524X4S'  /*Toxic effect of ketones, undetermined, sequela*/
,'T528X1D'  /*Toxic effect of other organic solvents, accidental (unintentional), subsequent encounter*/
,'T528X1S'  /*Toxic effect of other organic solvents, accidental (unintentional), sequela*/
,'T528X2D'  /*Toxic effect of other organic solvents, intentional self-harm, subsequent encounter*/
,'T528X2S'  /*Toxic effect of other organic solvents, intentional self-harm, sequela*/
,'T528X3D'  /*Toxic effect of other organic solvents, assault, subsequent encounter*/
,'T528X3S'  /*Toxic effect of other organic solvents, assault, sequela*/
,'T528X4D'  /*Toxic effect of other organic solvents, undetermined, subsequent encounter*/
,'T528X4S'  /*Toxic effect of other organic solvents, undetermined, sequela*/
,'T5291XD'  /*Toxic effect of unspecified organic solvent, accidental (unintentional), subsequent encounter*/
,'T5291XS'  /*Toxic effect of unspecified organic solvent, accidental (unintentional), sequela*/
,'T5292XD'  /*Toxic effect of unspecified organic solvent, intentional self-harm, subsequent encounter*/
,'T5292XS'  /*Toxic effect of unspecified organic solvent, intentional self-harm, sequela*/
,'T5293XD'  /*Toxic effect of unspecified organic solvent, assault, subsequent encounter*/
,'T5293XS'  /*Toxic effect of unspecified organic solvent, assault, sequela*/
,'T5294XD'  /*Toxic effect of unspecified organic solvent, undetermined, subsequent encounter*/
,'T5294XS'  /*Toxic effect of unspecified organic solvent, undetermined, sequela*/
,'T530X1D'  /*Toxic effect of carbon tetrachloride, accidental (unintentional), subsequent encounter*/
,'T530X1S'  /*Toxic effect of carbon tetrachloride, accidental (unintentional), sequela*/
,'T530X2D'  /*Toxic effect of carbon tetrachloride, intentional self-harm, subsequent encounter*/
,'T530X2S'  /*Toxic effect of carbon tetrachloride, intentional self-harm, sequela*/
,'T530X3D'  /*Toxic effect of carbon tetrachloride, assault, subsequent encounter*/
,'T530X3S'  /*Toxic effect of carbon tetrachloride, assault, sequela*/
,'T530X4D'  /*Toxic effect of carbon tetrachloride, undetermined, subsequent encounter*/
,'T530X4S'  /*Toxic effect of carbon tetrachloride, undetermined, sequela*/
,'T531X1D'  /*Toxic effect of chloroform, accidental (unintentional), subsequent encounter*/
,'T531X1S'  /*Toxic effect of chloroform, accidental (unintentional), sequela*/
,'T531X2D'  /*Toxic effect of chloroform, intentional self-harm, subsequent encounter*/
,'T531X2S'  /*Toxic effect of chloroform, intentional self-harm, sequela*/
,'T531X3D'  /*Toxic effect of chloroform, assault, subsequent encounter*/
,'T531X3S'  /*Toxic effect of chloroform, assault, sequela*/
,'T531X4D'  /*Toxic effect of chloroform, undetermined, subsequent encounter*/
,'T531X4S'  /*Toxic effect of chloroform, undetermined, sequela*/
,'T532X1D'  /*Toxic effect of trichloroethylene, accidental (unintentional), subsequent encounter*/
,'T532X1S'  /*Toxic effect of trichloroethylene, accidental (unintentional), sequela*/
,'T532X2D'  /*Toxic effect of trichloroethylene, intentional self-harm, subsequent encounter*/
,'T532X2S'  /*Toxic effect of trichloroethylene, intentional self-harm, sequela*/
,'T532X3D'  /*Toxic effect of trichloroethylene, assault, subsequent encounter*/
,'T532X3S'  /*Toxic effect of trichloroethylene, assault, sequela*/
,'T532X4D'  /*Toxic effect of trichloroethylene, undetermined, subsequent encounter*/
,'T532X4S'  /*Toxic effect of trichloroethylene, undetermined, sequela*/
,'T533X1D'  /*Toxic effect of tetrachloroethylene, accidental (unintentional), subsequent encounter*/
,'T533X1S'  /*Toxic effect of tetrachloroethylene, accidental (unintentional), sequela*/
,'T533X2D'  /*Toxic effect of tetrachloroethylene, intentional self-harm, subsequent encounter*/
,'T533X2S'  /*Toxic effect of tetrachloroethylene, intentional self-harm, sequela*/
,'T533X3D'  /*Toxic effect of tetrachloroethylene, assault, subsequent encounter*/
,'T533X3S'  /*Toxic effect of tetrachloroethylene, assault, sequela*/
,'T533X4D'  /*Toxic effect of tetrachloroethylene, undetermined, subsequent encounter*/
,'T533X4S'  /*Toxic effect of tetrachloroethylene, undetermined, sequela*/
,'T534X1D'  /*Toxic effect of dichloromethane, accidental (unintentional), subsequent encounter*/
,'T534X1S'  /*Toxic effect of dichloromethane, accidental (unintentional), sequela*/
,'T534X2D'  /*Toxic effect of dichloromethane, intentional self-harm, subsequent encounter*/
,'T534X2S'  /*Toxic effect of dichloromethane, intentional self-harm, sequela*/
,'T534X3D'  /*Toxic effect of dichloromethane, assault, subsequent encounter*/
,'T534X3S'  /*Toxic effect of dichloromethane, assault, sequela*/
,'T534X4D'  /*Toxic effect of dichloromethane, undetermined, subsequent encounter*/
,'T534X4S'  /*Toxic effect of dichloromethane, undetermined, sequela*/
,'T535X1D'  /*Toxic effect of chlorofluorocarbons, accidental (unintentional), subsequent encounter*/
,'T535X1S'  /*Toxic effect of chlorofluorocarbons, accidental (unintentional), sequela*/
,'T535X2D'  /*Toxic effect of chlorofluorocarbons, intentional self-harm, subsequent encounter*/
,'T535X2S'  /*Toxic effect of chlorofluorocarbons, intentional self-harm, sequela*/
,'T535X3D'  /*Toxic effect of chlorofluorocarbons, assault, subsequent encounter*/
,'T535X3S'  /*Toxic effect of chlorofluorocarbons, assault, sequela*/
,'T535X4D'  /*Toxic effect of chlorofluorocarbons, undetermined, subsequent encounter*/
,'T535X4S'  /*Toxic effect of chlorofluorocarbons, undetermined, sequela*/
,'T536X1D'  /*Toxic effect of other halogen derivatives of aliphatic hydrocarbons, accidental (unintentional), subsequent encounter*/
,'T536X1S'  /*Toxic effect of other halogen derivatives of aliphatic hydrocarbons, accidental (unintentional), sequela*/
,'T536X2D'  /*Toxic effect of other halogen derivatives of aliphatic hydrocarbons, intentional self-harm, subsequent encounter*/
,'T536X2S'  /*Toxic effect of other halogen derivatives of aliphatic hydrocarbons, intentional self-harm, sequela*/
,'T536X3D'  /*Toxic effect of other halogen derivatives of aliphatic hydrocarbons, assault, subsequent encounter*/
,'T536X3S'  /*Toxic effect of other halogen derivatives of aliphatic hydrocarbons, assault, sequela*/
,'T536X4D'  /*Toxic effect of other halogen derivatives of aliphatic hydrocarbons, undetermined, subsequent encounter*/
,'T536X4S'  /*Toxic effect of other halogen derivatives of aliphatic hydrocarbons, undetermined, sequela*/
,'T537X1D'  /*Toxic effect of other halogen derivatives of aromatic hydrocarbons, accidental (unintentional), subsequent encounter*/
,'T537X1S'  /*Toxic effect of other halogen derivatives of aromatic hydrocarbons, accidental (unintentional), sequela*/
,'T537X2D'  /*Toxic effect of other halogen derivatives of aromatic hydrocarbons, intentional self-harm, subsequent encounter*/
,'T537X2S'  /*Toxic effect of other halogen derivatives of aromatic hydrocarbons, intentional self-harm, sequela*/
,'T537X3D'  /*Toxic effect of other halogen derivatives of aromatic hydrocarbons, assault, subsequent encounter*/
,'T537X3S'  /*Toxic effect of other halogen derivatives of aromatic hydrocarbons, assault, sequela*/
,'T537X4D'  /*Toxic effect of other halogen derivatives of aromatic hydrocarbons, undetermined, subsequent encounter*/
,'T537X4S'  /*Toxic effect of other halogen derivatives of aromatic hydrocarbons, undetermined, sequela*/
,'T5391XD'  /*Toxic effect of unspecified halogen derivatives of aliphatic and aromatic hydrocarbons, accidental (unintentional), subsequent encounter*/
,'T5391XS'  /*Toxic effect of unspecified halogen derivatives of aliphatic and aromatic hydrocarbons, accidental (unintentional), sequela*/
,'T5392XD'  /*Toxic effect of unspecified halogen derivatives of aliphatic and aromatic hydrocarbons, intentional self-harm, subsequent encounter*/
,'T5392XS'  /*Toxic effect of unspecified halogen derivatives of aliphatic and aromatic hydrocarbons, intentional self-harm, sequela*/
,'T5393XD'  /*Toxic effect of unspecified halogen derivatives of aliphatic and aromatic hydrocarbons, assault, subsequent encounter*/
,'T5393XS'  /*Toxic effect of unspecified halogen derivatives of aliphatic and aromatic hydrocarbons, assault, sequela*/
,'T5394XD'  /*Toxic effect of unspecified halogen derivatives of aliphatic and aromatic hydrocarbons, undetermined, subsequent encounter*/
,'T5394XS'  /*Toxic effect of unspecified halogen derivatives of aliphatic and aromatic hydrocarbons, undetermined, sequela*/
,'T540X1D'  /*Toxic effect of phenol and phenol homologues, accidental (unintentional), subsequent encounter*/
,'T540X1S'  /*Toxic effect of phenol and phenol homologues, accidental (unintentional), sequela*/
,'T540X2D'  /*Toxic effect of phenol and phenol homologues, intentional self-harm, subsequent encounter*/
,'T540X2S'  /*Toxic effect of phenol and phenol homologues, intentional self-harm, sequela*/
,'T540X3D'  /*Toxic effect of phenol and phenol homologues, assault, subsequent encounter*/
,'T540X3S'  /*Toxic effect of phenol and phenol homologues, assault, sequela*/
,'T540X4D'  /*Toxic effect of phenol and phenol homologues, undetermined, subsequent encounter*/
,'T540X4S'  /*Toxic effect of phenol and phenol homologues, undetermined, sequela*/
,'T541X1D'  /*Toxic effect of other corrosive organic compounds, accidental (unintentional), subsequent encounter*/
,'T541X1S'  /*Toxic effect of other corrosive organic compounds, accidental (unintentional), sequela*/
,'T541X2D'  /*Toxic effect of other corrosive organic compounds, intentional self-harm, subsequent encounter*/
,'T541X2S'  /*Toxic effect of other corrosive organic compounds, intentional self-harm, sequela*/
,'T541X3D'  /*Toxic effect of other corrosive organic compounds, assault, subsequent encounter*/
,'T541X3S'  /*Toxic effect of other corrosive organic compounds, assault, sequela*/
,'T541X4D'  /*Toxic effect of other corrosive organic compounds, undetermined, subsequent encounter*/
,'T541X4S'  /*Toxic effect of other corrosive organic compounds, undetermined, sequela*/
,'T542X1D'  /*Toxic effect of corrosive acids and acid-like substances, accidental (unintentional), subsequent encounter*/
,'T542X1S'  /*Toxic effect of corrosive acids and acid-like substances, accidental (unintentional), sequela*/
,'T542X2D'  /*Toxic effect of corrosive acids and acid-like substances, intentional self-harm, subsequent encounter*/
,'T542X2S'  /*Toxic effect of corrosive acids and acid-like substances, intentional self-harm, sequela*/
,'T542X3D'  /*Toxic effect of corrosive acids and acid-like substances, assault, subsequent encounter*/
,'T542X3S'  /*Toxic effect of corrosive acids and acid-like substances, assault, sequela*/
,'T542X4D'  /*Toxic effect of corrosive acids and acid-like substances, undetermined, subsequent encounter*/
,'T542X4S'  /*Toxic effect of corrosive acids and acid-like substances, undetermined, sequela*/
,'T543X1D'  /*Toxic effect of corrosive alkalis and alkali-like substances, accidental (unintentional), subsequent encounter*/
,'T543X1S'  /*Toxic effect of corrosive alkalis and alkali-like substances, accidental (unintentional), sequela*/
,'T543X2D'  /*Toxic effect of corrosive alkalis and alkali-like substances, intentional self-harm, subsequent encounter*/
,'T543X2S'  /*Toxic effect of corrosive alkalis and alkali-like substances, intentional self-harm, sequela*/
,'T543X3D'  /*Toxic effect of corrosive alkalis and alkali-like substances, assault, subsequent encounter*/
,'T543X3S'  /*Toxic effect of corrosive alkalis and alkali-like substances, assault, sequela*/
,'T543X4D'  /*Toxic effect of corrosive alkalis and alkali-like substances, undetermined, subsequent encounter*/
,'T543X4S'  /*Toxic effect of corrosive alkalis and alkali-like substances, undetermined, sequela*/
,'T5491XD'  /*Toxic effect of unspecified corrosive substance, accidental (unintentional), subsequent encounter*/
,'T5491XS'  /*Toxic effect of unspecified corrosive substance, accidental (unintentional), sequela*/
,'T5492XD'  /*Toxic effect of unspecified corrosive substance, intentional self-harm, subsequent encounter*/
,'T5492XS'  /*Toxic effect of unspecified corrosive substance, intentional self-harm, sequela*/
,'T5493XD'  /*Toxic effect of unspecified corrosive substance, assault, subsequent encounter*/
,'T5493XS'  /*Toxic effect of unspecified corrosive substance, assault, sequela*/
,'T5494XD'  /*Toxic effect of unspecified corrosive substance, undetermined, subsequent encounter*/
,'T5494XS'  /*Toxic effect of unspecified corrosive substance, undetermined, sequela*/
,'T550X1D'  /*Toxic effect of soaps, accidental (unintentional), subsequent encounter*/
,'T550X1S'  /*Toxic effect of soaps, accidental (unintentional), sequela*/
,'T550X2D'  /*Toxic effect of soaps, intentional self-harm, subsequent encounter*/
,'T550X2S'  /*Toxic effect of soaps, intentional self-harm, sequela*/
,'T550X3D'  /*Toxic effect of soaps, assault, subsequent encounter*/
,'T550X3S'  /*Toxic effect of soaps, assault, sequela*/
,'T550X4D'  /*Toxic effect of soaps, undetermined, subsequent encounter*/
,'T550X4S'  /*Toxic effect of soaps, undetermined, sequela*/
,'T551X1D'  /*Toxic effect of detergents, accidental (unintentional), subsequent encounter*/
,'T551X1S'  /*Toxic effect of detergents, accidental (unintentional), sequela*/
,'T551X2D'  /*Toxic effect of detergents, intentional self-harm, subsequent encounter*/
,'T551X2S'  /*Toxic effect of detergents, intentional self-harm, sequela*/
,'T551X3D'  /*Toxic effect of detergents, assault, subsequent encounter*/
,'T551X3S'  /*Toxic effect of detergents, assault, sequela*/
,'T551X4D'  /*Toxic effect of detergents, undetermined, subsequent encounter*/
,'T551X4S'  /*Toxic effect of detergents, undetermined, sequela*/
,'T560X1D'  /*Toxic effect of lead and its compounds, accidental (unintentional), subsequent encounter*/
,'T560X1S'  /*Toxic effect of lead and its compounds, accidental (unintentional), sequela*/
,'T560X2D'  /*Toxic effect of lead and its compounds, intentional self-harm, subsequent encounter*/
,'T560X2S'  /*Toxic effect of lead and its compounds, intentional self-harm, sequela*/
,'T560X3D'  /*Toxic effect of lead and its compounds, assault, subsequent encounter*/
,'T560X3S'  /*Toxic effect of lead and its compounds, assault, sequela*/
,'T560X4D'  /*Toxic effect of lead and its compounds, undetermined, subsequent encounter*/
,'T560X4S'  /*Toxic effect of lead and its compounds, undetermined, sequela*/
,'T561X1D'  /*Toxic effect of mercury and its compounds, accidental (unintentional), subsequent encounter*/
,'T561X1S'  /*Toxic effect of mercury and its compounds, accidental (unintentional), sequela*/
,'T561X2D'  /*Toxic effect of mercury and its compounds, intentional self-harm, subsequent encounter*/
,'T561X2S'  /*Toxic effect of mercury and its compounds, intentional self-harm, sequela*/
,'T561X3D'  /*Toxic effect of mercury and its compounds, assault, subsequent encounter*/
,'T561X3S'  /*Toxic effect of mercury and its compounds, assault, sequela*/
,'T561X4D'  /*Toxic effect of mercury and its compounds, undetermined, subsequent encounter*/
,'T561X4S'  /*Toxic effect of mercury and its compounds, undetermined, sequela*/
,'T562X1D'  /*Toxic effect of chromium and its compounds, accidental (unintentional), subsequent encounter*/
,'T562X1S'  /*Toxic effect of chromium and its compounds, accidental (unintentional), sequela*/
,'T562X2D'  /*Toxic effect of chromium and its compounds, intentional self-harm, subsequent encounter*/
,'T562X2S'  /*Toxic effect of chromium and its compounds, intentional self-harm, sequela*/
,'T562X3D'  /*Toxic effect of chromium and its compounds, assault, subsequent encounter*/
,'T562X3S'  /*Toxic effect of chromium and its compounds, assault, sequela*/
,'T562X4D'  /*Toxic effect of chromium and its compounds, undetermined, subsequent encounter*/
,'T562X4S'  /*Toxic effect of chromium and its compounds, undetermined, sequela*/
,'T563X1D'  /*Toxic effect of cadmium and its compounds, accidental (unintentional), subsequent encounter*/
,'T563X1S'  /*Toxic effect of cadmium and its compounds, accidental (unintentional), sequela*/
,'T563X2D'  /*Toxic effect of cadmium and its compounds, intentional self-harm, subsequent encounter*/
,'T563X2S'  /*Toxic effect of cadmium and its compounds, intentional self-harm, sequela*/
,'T563X3D'  /*Toxic effect of cadmium and its compounds, assault, subsequent encounter*/
,'T563X3S'  /*Toxic effect of cadmium and its compounds, assault, sequela*/
,'T563X4D'  /*Toxic effect of cadmium and its compounds, undetermined, subsequent encounter*/
,'T563X4S'  /*Toxic effect of cadmium and its compounds, undetermined, sequela*/
,'T564X1D'  /*Toxic effect of copper and its compounds, accidental (unintentional), subsequent encounter*/
,'T564X1S'  /*Toxic effect of copper and its compounds, accidental (unintentional), sequela*/
,'T564X2D'  /*Toxic effect of copper and its compounds, intentional self-harm, subsequent encounter*/
,'T564X2S'  /*Toxic effect of copper and its compounds, intentional self-harm, sequela*/
,'T564X3D'  /*Toxic effect of copper and its compounds, assault, subsequent encounter*/
,'T564X3S'  /*Toxic effect of copper and its compounds, assault, sequela*/
,'T564X4D'  /*Toxic effect of copper and its compounds, undetermined, subsequent encounter*/
,'T564X4S'  /*Toxic effect of copper and its compounds, undetermined, sequela*/
,'T565X1D'  /*Toxic effect of zinc and its compounds, accidental (unintentional), subsequent encounter*/
,'T565X1S'  /*Toxic effect of zinc and its compounds, accidental (unintentional), sequela*/
,'T565X2D'  /*Toxic effect of zinc and its compounds, intentional self-harm, subsequent encounter*/
,'T565X2S'  /*Toxic effect of zinc and its compounds, intentional self-harm, sequela*/
,'T565X3D'  /*Toxic effect of zinc and its compounds, assault, subsequent encounter*/
,'T565X3S'  /*Toxic effect of zinc and its compounds, assault, sequela*/
,'T565X4D'  /*Toxic effect of zinc and its compounds, undetermined, subsequent encounter*/
,'T565X4S'  /*Toxic effect of zinc and its compounds, undetermined, sequela*/
,'T566X1D'  /*Toxic effect of tin and its compounds, accidental (unintentional), subsequent encounter*/
,'T566X1S'  /*Toxic effect of tin and its compounds, accidental (unintentional), sequela*/
,'T566X2D'  /*Toxic effect of tin and its compounds, intentional self-harm, subsequent encounter*/
,'T566X2S'  /*Toxic effect of tin and its compounds, intentional self-harm, sequela*/
,'T566X3D'  /*Toxic effect of tin and its compounds, assault, subsequent encounter*/
,'T566X3S'  /*Toxic effect of tin and its compounds, assault, sequela*/
,'T566X4D'  /*Toxic effect of tin and its compounds, undetermined, subsequent encounter*/
,'T566X4S'  /*Toxic effect of tin and its compounds, undetermined, sequela*/
,'T567X1D'  /*Toxic effect of beryllium and its compounds, accidental (unintentional), subsequent encounter*/
,'T567X1S'  /*Toxic effect of beryllium and its compounds, accidental (unintentional), sequela*/
,'T567X2D'  /*Toxic effect of beryllium and its compounds, intentional self-harm, subsequent encounter*/
,'T567X2S'  /*Toxic effect of beryllium and its compounds, intentional self-harm, sequela*/
,'T567X3D'  /*Toxic effect of beryllium and its compounds, assault, subsequent encounter*/
,'T567X3S'  /*Toxic effect of beryllium and its compounds, assault, sequela*/
,'T567X4D'  /*Toxic effect of beryllium and its compounds, undetermined, subsequent encounter*/
,'T567X4S'  /*Toxic effect of beryllium and its compounds, undetermined, sequela*/
,'T56811D'  /*Toxic effect of thallium, accidental (unintentional), subsequent encounter*/
,'T56811S'  /*Toxic effect of thallium, accidental (unintentional), sequela*/
,'T56812D'  /*Toxic effect of thallium, intentional self-harm, subsequent encounter*/
,'T56812S'  /*Toxic effect of thallium, intentional self-harm, sequela*/
,'T56813D'  /*Toxic effect of thallium, assault, subsequent encounter*/
,'T56813S'  /*Toxic effect of thallium, assault, sequela*/
,'T56814D'  /*Toxic effect of thallium, undetermined, subsequent encounter*/
,'T56814S'  /*Toxic effect of thallium, undetermined, sequela*/
,'T56891D'  /*Toxic effect of other metals, accidental (unintentional), subsequent encounter*/
,'T56891S'  /*Toxic effect of other metals, accidental (unintentional), sequela*/
,'T56892D'  /*Toxic effect of other metals, intentional self-harm, subsequent encounter*/
,'T56892S'  /*Toxic effect of other metals, intentional self-harm, sequela*/
,'T56893D'  /*Toxic effect of other metals, assault, subsequent encounter*/
,'T56893S'  /*Toxic effect of other metals, assault, sequela*/
,'T56894D'  /*Toxic effect of other metals, undetermined, subsequent encounter*/
,'T56894S'  /*Toxic effect of other metals, undetermined, sequela*/
,'T5691XD'  /*Toxic effect of unspecified metal, accidental (unintentional), subsequent encounter*/
,'T5691XS'  /*Toxic effect of unspecified metal, accidental (unintentional), sequela*/
,'T5692XD'  /*Toxic effect of unspecified metal, intentional self-harm, subsequent encounter*/
,'T5692XS'  /*Toxic effect of unspecified metal, intentional self-harm, sequela*/
,'T5693XD'  /*Toxic effect of unspecified metal, assault, subsequent encounter*/
,'T5693XS'  /*Toxic effect of unspecified metal, assault, sequela*/
,'T5694XD'  /*Toxic effect of unspecified metal, undetermined, subsequent encounter*/
,'T5694XS'  /*Toxic effect of unspecified metal, undetermined, sequela*/
,'T570X1D'  /*Toxic effect of arsenic and its compounds, accidental (unintentional), subsequent encounter*/
,'T570X1S'  /*Toxic effect of arsenic and its compounds, accidental (unintentional), sequela*/
,'T570X2D'  /*Toxic effect of arsenic and its compounds, intentional self-harm, subsequent encounter*/
,'T570X2S'  /*Toxic effect of arsenic and its compounds, intentional self-harm, sequela*/
,'T570X3D'  /*Toxic effect of arsenic and its compounds, assault, subsequent encounter*/
,'T570X3S'  /*Toxic effect of arsenic and its compounds, assault, sequela*/
,'T570X4D'  /*Toxic effect of arsenic and its compounds, undetermined, subsequent encounter*/
,'T570X4S'  /*Toxic effect of arsenic and its compounds, undetermined, sequela*/
,'T571X1D'  /*Toxic effect of phosphorus and its compounds, accidental (unintentional), subsequent encounter*/
,'T571X1S'  /*Toxic effect of phosphorus and its compounds, accidental (unintentional), sequela*/
,'T571X2D'  /*Toxic effect of phosphorus and its compounds, intentional self-harm, subsequent encounter*/
,'T571X2S'  /*Toxic effect of phosphorus and its compounds, intentional self-harm, sequela*/
,'T571X3D'  /*Toxic effect of phosphorus and its compounds, assault, subsequent encounter*/
,'T571X3S'  /*Toxic effect of phosphorus and its compounds, assault, sequela*/
,'T571X4D'  /*Toxic effect of phosphorus and its compounds, undetermined, subsequent encounter*/
,'T571X4S'  /*Toxic effect of phosphorus and its compounds, undetermined, sequela*/
,'T572X1D'  /*Toxic effect of manganese and its compounds, accidental (unintentional), subsequent encounter*/
,'T572X1S'  /*Toxic effect of manganese and its compounds, accidental (unintentional), sequela*/
,'T572X2D'  /*Toxic effect of manganese and its compounds, intentional self-harm, subsequent encounter*/
,'T572X2S'  /*Toxic effect of manganese and its compounds, intentional self-harm, sequela*/
,'T572X3D'  /*Toxic effect of manganese and its compounds, assault, subsequent encounter*/
,'T572X3S'  /*Toxic effect of manganese and its compounds, assault, sequela*/
,'T572X4D'  /*Toxic effect of manganese and its compounds, undetermined, subsequent encounter*/
,'T572X4S'  /*Toxic effect of manganese and its compounds, undetermined, sequela*/
,'T573X1D'  /*Toxic effect of hydrogen cyanide, accidental (unintentional), subsequent encounter*/
,'T573X1S'  /*Toxic effect of hydrogen cyanide, accidental (unintentional), sequela*/
,'T573X2D'  /*Toxic effect of hydrogen cyanide, intentional self-harm, subsequent encounter*/
,'T573X2S'  /*Toxic effect of hydrogen cyanide, intentional self-harm, sequela*/
,'T573X3D'  /*Toxic effect of hydrogen cyanide, assault, subsequent encounter*/
,'T573X3S'  /*Toxic effect of hydrogen cyanide, assault, sequela*/
,'T573X4D'  /*Toxic effect of hydrogen cyanide, undetermined, subsequent encounter*/
,'T573X4S'  /*Toxic effect of hydrogen cyanide, undetermined, sequela*/
,'T578X1D'  /*Toxic effect of other specified inorganic substances, accidental (unintentional), subsequent encounter*/
,'T578X1S'  /*Toxic effect of other specified inorganic substances, accidental (unintentional), sequela*/
,'T578X2D'  /*Toxic effect of other specified inorganic substances, intentional self-harm, subsequent encounter*/
,'T578X2S'  /*Toxic effect of other specified inorganic substances, intentional self-harm, sequela*/
,'T578X3D'  /*Toxic effect of other specified inorganic substances, assault, subsequent encounter*/
,'T578X3S'  /*Toxic effect of other specified inorganic substances, assault, sequela*/
,'T578X4D'  /*Toxic effect of other specified inorganic substances, undetermined, subsequent encounter*/
,'T578X4S'  /*Toxic effect of other specified inorganic substances, undetermined, sequela*/
,'T5791XD'  /*Toxic effect of unspecified inorganic substance, accidental (unintentional), subsequent encounter*/
,'T5791XS'  /*Toxic effect of unspecified inorganic substance, accidental (unintentional), sequela*/
,'T5792XD'  /*Toxic effect of unspecified inorganic substance, intentional self-harm, subsequent encounter*/
,'T5792XS'  /*Toxic effect of unspecified inorganic substance, intentional self-harm, sequela*/
,'T5793XD'  /*Toxic effect of unspecified inorganic substance, assault, subsequent encounter*/
,'T5793XS'  /*Toxic effect of unspecified inorganic substance, assault, sequela*/
,'T5794XD'  /*Toxic effect of unspecified inorganic substance, undetermined, subsequent encounter*/
,'T5794XS'  /*Toxic effect of unspecified inorganic substance, undetermined, sequela*/
,'T5801XD'  /*Toxic effect of carbon monoxide from motor vehicle exhaust, accidental (unintentional), subsequent encounter*/
,'T5801XS'  /*Toxic effect of carbon monoxide from motor vehicle exhaust, accidental (unintentional), sequela*/
,'T5802XD'  /*Toxic effect of carbon monoxide from motor vehicle exhaust, intentional self-harm, subsequent encounter*/
,'T5802XS'  /*Toxic effect of carbon monoxide from motor vehicle exhaust, intentional self-harm, sequela*/
,'T5803XD'  /*Toxic effect of carbon monoxide from motor vehicle exhaust, assault, subsequent encounter*/
,'T5803XS'  /*Toxic effect of carbon monoxide from motor vehicle exhaust, assault, sequela*/
,'T5804XD'  /*Toxic effect of carbon monoxide from motor vehicle exhaust, undetermined, subsequent encounter*/
,'T5804XS'  /*Toxic effect of carbon monoxide from motor vehicle exhaust, undetermined, sequela*/
,'T5811XD'  /*Toxic effect of carbon monoxide from utility gas, accidental (unintentional), subsequent encounter*/
,'T5811XS'  /*Toxic effect of carbon monoxide from utility gas, accidental (unintentional), sequela*/
,'T5812XD'  /*Toxic effect of carbon monoxide from utility gas, intentional self-harm, subsequent encounter*/
,'T5812XS'  /*Toxic effect of carbon monoxide from utility gas, intentional self-harm, sequela*/
,'T5813XD'  /*Toxic effect of carbon monoxide from utility gas, assault, subsequent encounter*/
,'T5813XS'  /*Toxic effect of carbon monoxide from utility gas, assault, sequela*/
,'T5814XD'  /*Toxic effect of carbon monoxide from utility gas, undetermined, subsequent encounter*/
,'T5814XS'  /*Toxic effect of carbon monoxide from utility gas, undetermined, sequela*/
,'T582X1D'  /*Toxic effect of carbon monoxide from incomplete combustion of other domestic fuels, accidental (unintentional), subsequent encounter*/
,'T582X1S'  /*Toxic effect of carbon monoxide from incomplete combustion of other domestic fuels, accidental (unintentional), sequela*/
,'T582X2D'  /*Toxic effect of carbon monoxide from incomplete combustion of other domestic fuels, intentional self-harm, subsequent encounter*/
,'T582X2S'  /*Toxic effect of carbon monoxide from incomplete combustion of other domestic fuels, intentional self-harm, sequela*/
,'T582X3D'  /*Toxic effect of carbon monoxide from incomplete combustion of other domestic fuels, assault, subsequent encounter*/
,'T582X3S'  /*Toxic effect of carbon monoxide from incomplete combustion of other domestic fuels, assault, sequela*/
,'T582X4D'  /*Toxic effect of carbon monoxide from incomplete combustion of other domestic fuels, undetermined, subsequent encounter*/
,'T582X4S'  /*Toxic effect of carbon monoxide from incomplete combustion of other domestic fuels, undetermined, sequela*/
,'T588X1D'  /*Toxic effect of carbon monoxide from other source, accidental (unintentional), subsequent encounter*/
,'T588X1S'  /*Toxic effect of carbon monoxide from other source, accidental (unintentional), sequela*/
,'T588X2D'  /*Toxic effect of carbon monoxide from other source, intentional self-harm, subsequent encounter*/
,'T588X2S'  /*Toxic effect of carbon monoxide from other source, intentional self-harm, sequela*/
,'T588X3D'  /*Toxic effect of carbon monoxide from other source, assault, subsequent encounter*/
,'T588X3S'  /*Toxic effect of carbon monoxide from other source, assault, sequela*/
,'T588X4D'  /*Toxic effect of carbon monoxide from other source, undetermined, subsequent encounter*/
,'T588X4S'  /*Toxic effect of carbon monoxide from other source, undetermined, sequela*/
,'T5891XD'  /*Toxic effect of carbon monoxide from unspecified source, accidental (unintentional), subsequent encounter*/
,'T5891XS'  /*Toxic effect of carbon monoxide from unspecified source, accidental (unintentional), sequela*/
,'T5892XD'  /*Toxic effect of carbon monoxide from unspecified source, intentional self-harm, subsequent encounter*/
,'T5892XS'  /*Toxic effect of carbon monoxide from unspecified source, intentional self-harm, sequela*/
,'T5893XD'  /*Toxic effect of carbon monoxide from unspecified source, assault, subsequent encounter*/
,'T5893XS'  /*Toxic effect of carbon monoxide from unspecified source, assault, sequela*/
,'T5894XD'  /*Toxic effect of carbon monoxide from unspecified source, undetermined, subsequent encounter*/
,'T5894XS'  /*Toxic effect of carbon monoxide from unspecified source, undetermined, sequela*/
,'T590X1D'  /*Toxic effect of nitrogen oxides, accidental (unintentional), subsequent encounter*/
,'T590X1S'  /*Toxic effect of nitrogen oxides, accidental (unintentional), sequela*/
,'T590X2D'  /*Toxic effect of nitrogen oxides, intentional self-harm, subsequent encounter*/
,'T590X2S'  /*Toxic effect of nitrogen oxides, intentional self-harm, sequela*/
,'T590X3D'  /*Toxic effect of nitrogen oxides, assault, subsequent encounter*/
,'T590X3S'  /*Toxic effect of nitrogen oxides, assault, sequela*/
,'T590X4D'  /*Toxic effect of nitrogen oxides, undetermined, subsequent encounter*/
,'T590X4S'  /*Toxic effect of nitrogen oxides, undetermined, sequela*/
,'T591X1D'  /*Toxic effect of sulfur dioxide, accidental (unintentional), subsequent encounter*/
,'T591X1S'  /*Toxic effect of sulfur dioxide, accidental (unintentional), sequela*/
,'T591X2D'  /*Toxic effect of sulfur dioxide, intentional self-harm, subsequent encounter*/
,'T591X2S'  /*Toxic effect of sulfur dioxide, intentional self-harm, sequela*/
,'T591X3D'  /*Toxic effect of sulfur dioxide, assault, subsequent encounter*/
,'T591X3S'  /*Toxic effect of sulfur dioxide, assault, sequela*/
,'T591X4D'  /*Toxic effect of sulfur dioxide, undetermined, subsequent encounter*/
,'T591X4S'  /*Toxic effect of sulfur dioxide, undetermined, sequela*/
,'T592X1D'  /*Toxic effect of formaldehyde, accidental (unintentional), subsequent encounter*/
,'T592X1S'  /*Toxic effect of formaldehyde, accidental (unintentional), sequela*/
,'T592X2D'  /*Toxic effect of formaldehyde, intentional self-harm, subsequent encounter*/
,'T592X2S'  /*Toxic effect of formaldehyde, intentional self-harm, sequela*/
,'T592X3D'  /*Toxic effect of formaldehyde, assault, subsequent encounter*/
,'T592X3S'  /*Toxic effect of formaldehyde, assault, sequela*/
,'T592X4D'  /*Toxic effect of formaldehyde, undetermined, subsequent encounter*/
,'T592X4S'  /*Toxic effect of formaldehyde, undetermined, sequela*/
,'T593X1D'  /*Toxic effect of lacrimogenic gas, accidental (unintentional), subsequent encounter*/
,'T593X1S'  /*Toxic effect of lacrimogenic gas, accidental (unintentional), sequela*/
,'T593X2D'  /*Toxic effect of lacrimogenic gas, intentional self-harm, subsequent encounter*/
,'T593X2S'  /*Toxic effect of lacrimogenic gas, intentional self-harm, sequela*/
,'T593X3D'  /*Toxic effect of lacrimogenic gas, assault, subsequent encounter*/
,'T593X3S'  /*Toxic effect of lacrimogenic gas, assault, sequela*/
,'T593X4D'  /*Toxic effect of lacrimogenic gas, undetermined, subsequent encounter*/
,'T593X4S'  /*Toxic effect of lacrimogenic gas, undetermined, sequela*/
,'T594X1D'  /*Toxic effect of chlorine gas, accidental (unintentional), subsequent encounter*/
,'T594X1S'  /*Toxic effect of chlorine gas, accidental (unintentional), sequela*/
,'T594X2D'  /*Toxic effect of chlorine gas, intentional self-harm, subsequent encounter*/
,'T594X2S'  /*Toxic effect of chlorine gas, intentional self-harm, sequela*/
,'T594X3D'  /*Toxic effect of chlorine gas, assault, subsequent encounter*/
,'T594X3S'  /*Toxic effect of chlorine gas, assault, sequela*/
,'T594X4D'  /*Toxic effect of chlorine gas, undetermined, subsequent encounter*/
,'T594X4S'  /*Toxic effect of chlorine gas, undetermined, sequela*/
,'T595X1D'  /*Toxic effect of fluorine gas and hydrogen fluoride, accidental (unintentional), subsequent encounter*/
,'T595X1S'  /*Toxic effect of fluorine gas and hydrogen fluoride, accidental (unintentional), sequela*/
,'T595X2D'  /*Toxic effect of fluorine gas and hydrogen fluoride, intentional self-harm, subsequent encounter*/
,'T595X2S'  /*Toxic effect of fluorine gas and hydrogen fluoride, intentional self-harm, sequela*/
,'T595X3D'  /*Toxic effect of fluorine gas and hydrogen fluoride, assault, subsequent encounter*/
,'T595X3S'  /*Toxic effect of fluorine gas and hydrogen fluoride, assault, sequela*/
,'T595X4D'  /*Toxic effect of fluorine gas and hydrogen fluoride, undetermined, subsequent encounter*/
,'T595X4S'  /*Toxic effect of fluorine gas and hydrogen fluoride, undetermined, sequela*/
,'T596X1D'  /*Toxic effect of hydrogen sulfide, accidental (unintentional), subsequent encounter*/
,'T596X1S'  /*Toxic effect of hydrogen sulfide, accidental (unintentional), sequela*/
,'T596X2D'  /*Toxic effect of hydrogen sulfide, intentional self-harm, subsequent encounter*/
,'T596X2S'  /*Toxic effect of hydrogen sulfide, intentional self-harm, sequela*/
,'T596X3D'  /*Toxic effect of hydrogen sulfide, assault, subsequent encounter*/
,'T596X3S'  /*Toxic effect of hydrogen sulfide, assault, sequela*/
,'T596X4D'  /*Toxic effect of hydrogen sulfide, undetermined, subsequent encounter*/
,'T596X4S'  /*Toxic effect of hydrogen sulfide, undetermined, sequela*/
,'T597X1D'  /*Toxic effect of carbon dioxide, accidental (unintentional), subsequent encounter*/
,'T597X1S'  /*Toxic effect of carbon dioxide, accidental (unintentional), sequela*/
,'T597X2D'  /*Toxic effect of carbon dioxide, intentional self-harm, subsequent encounter*/
,'T597X2S'  /*Toxic effect of carbon dioxide, intentional self-harm, sequela*/
,'T597X3D'  /*Toxic effect of carbon dioxide, assault, subsequent encounter*/
,'T597X3S'  /*Toxic effect of carbon dioxide, assault, sequela*/
,'T597X4D'  /*Toxic effect of carbon dioxide, undetermined, subsequent encounter*/
,'T597X4S'  /*Toxic effect of carbon dioxide, undetermined, sequela*/
,'T59811D'  /*Toxic effect of smoke, accidental (unintentional), subsequent encounter*/
,'T59811S'  /*Toxic effect of smoke, accidental (unintentional), sequela*/
,'T59812D'  /*Toxic effect of smoke, intentional self-harm, subsequent encounter*/
,'T59812S'  /*Toxic effect of smoke, intentional self-harm, sequela*/
,'T59813D'  /*Toxic effect of smoke, assault, subsequent encounter*/
,'T59813S'  /*Toxic effect of smoke, assault, sequela*/
,'T59814D'  /*Toxic effect of smoke, undetermined, subsequent encounter*/
,'T59814S'  /*Toxic effect of smoke, undetermined, sequela*/
,'T59891D'  /*Toxic effect of other specified gases, fumes and vapors, accidental (unintentional), subsequent encounter*/
,'T59891S'  /*Toxic effect of other specified gases, fumes and vapors, accidental (unintentional), sequela*/
,'T59892D'  /*Toxic effect of other specified gases, fumes and vapors, intentional self-harm, subsequent encounter*/
,'T59892S'  /*Toxic effect of other specified gases, fumes and vapors, intentional self-harm, sequela*/
,'T59893D'  /*Toxic effect of other specified gases, fumes and vapors, assault, subsequent encounter*/
,'T59893S'  /*Toxic effect of other specified gases, fumes and vapors, assault, sequela*/
,'T59894D'  /*Toxic effect of other specified gases, fumes and vapors, undetermined, subsequent encounter*/
,'T59894S'  /*Toxic effect of other specified gases, fumes and vapors, undetermined, sequela*/
,'T5991XD'  /*Toxic effect of unspecified gases, fumes and vapors, accidental (unintentional), subsequent encounter*/
,'T5991XS'  /*Toxic effect of unspecified gases, fumes and vapors, accidental (unintentional), sequela*/
,'T5992XD'  /*Toxic effect of unspecified gases, fumes and vapors, intentional self-harm, subsequent encounter*/
,'T5992XS'  /*Toxic effect of unspecified gases, fumes and vapors, intentional self-harm, sequela*/
,'T5993XD'  /*Toxic effect of unspecified gases, fumes and vapors, assault, subsequent encounter*/
,'T5993XS'  /*Toxic effect of unspecified gases, fumes and vapors, assault, sequela*/
,'T5994XD'  /*Toxic effect of unspecified gases, fumes and vapors, undetermined, subsequent encounter*/
,'T5994XS'  /*Toxic effect of unspecified gases, fumes and vapors, undetermined, sequela*/
,'T600X1D'  /*Toxic effect of organophosphate and carbamate insecticides, accidental (unintentional), subsequent encounter*/
,'T600X1S'  /*Toxic effect of organophosphate and carbamate insecticides, accidental (unintentional), sequela*/
,'T600X2D'  /*Toxic effect of organophosphate and carbamate insecticides, intentional self-harm, subsequent encounter*/
,'T600X2S'  /*Toxic effect of organophosphate and carbamate insecticides, intentional self-harm, sequela*/
,'T600X3D'  /*Toxic effect of organophosphate and carbamate insecticides, assault, subsequent encounter*/
,'T600X3S'  /*Toxic effect of organophosphate and carbamate insecticides, assault, sequela*/
,'T600X4D'  /*Toxic effect of organophosphate and carbamate insecticides, undetermined, subsequent encounter*/
,'T600X4S'  /*Toxic effect of organophosphate and carbamate insecticides, undetermined, sequela*/
,'T601X1D'  /*Toxic effect of halogenated insecticides, accidental (unintentional), subsequent encounter*/
,'T601X1S'  /*Toxic effect of halogenated insecticides, accidental (unintentional), sequela*/
,'T601X2D'  /*Toxic effect of halogenated insecticides, intentional self-harm, subsequent encounter*/
,'T601X2S'  /*Toxic effect of halogenated insecticides, intentional self-harm, sequela*/
,'T601X3D'  /*Toxic effect of halogenated insecticides, assault, subsequent encounter*/
,'T601X3S'  /*Toxic effect of halogenated insecticides, assault, sequela*/
,'T601X4D'  /*Toxic effect of halogenated insecticides, undetermined, subsequent encounter*/
,'T601X4S'  /*Toxic effect of halogenated insecticides, undetermined, sequela*/
,'T602X1D'  /*Toxic effect of other insecticides, accidental (unintentional), subsequent encounter*/
,'T602X1S'  /*Toxic effect of other insecticides, accidental (unintentional), sequela*/
,'T602X2D'  /*Toxic effect of other insecticides, intentional self-harm, subsequent encounter*/
,'T602X2S'  /*Toxic effect of other insecticides, intentional self-harm, sequela*/
,'T602X3D'  /*Toxic effect of other insecticides, assault, subsequent encounter*/
,'T602X3S'  /*Toxic effect of other insecticides, assault, sequela*/
,'T602X4D'  /*Toxic effect of other insecticides, undetermined, subsequent encounter*/
,'T602X4S'  /*Toxic effect of other insecticides, undetermined, sequela*/
,'T603X1D'  /*Toxic effect of herbicides and fungicides, accidental (unintentional), subsequent encounter*/
,'T603X1S'  /*Toxic effect of herbicides and fungicides, accidental (unintentional), sequela*/
,'T603X2D'  /*Toxic effect of herbicides and fungicides, intentional self-harm, subsequent encounter*/
,'T603X2S'  /*Toxic effect of herbicides and fungicides, intentional self-harm, sequela*/
,'T603X3D'  /*Toxic effect of herbicides and fungicides, assault, subsequent encounter*/
,'T603X3S'  /*Toxic effect of herbicides and fungicides, assault, sequela*/
,'T603X4D'  /*Toxic effect of herbicides and fungicides, undetermined, subsequent encounter*/
,'T603X4S'  /*Toxic effect of herbicides and fungicides, undetermined, sequela*/
,'T604X1D'  /*Toxic effect of rodenticides, accidental (unintentional), subsequent encounter*/
,'T604X1S'  /*Toxic effect of rodenticides, accidental (unintentional), sequela*/
,'T604X2D'  /*Toxic effect of rodenticides, intentional self-harm, subsequent encounter*/
,'T604X2S'  /*Toxic effect of rodenticides, intentional self-harm, sequela*/
,'T604X3D'  /*Toxic effect of rodenticides, assault, subsequent encounter*/
,'T604X3S'  /*Toxic effect of rodenticides, assault, sequela*/
,'T604X4D'  /*Toxic effect of rodenticides, undetermined, subsequent encounter*/
,'T604X4S'  /*Toxic effect of rodenticides, undetermined, sequela*/
,'T608X1D'  /*Toxic effect of other pesticides, accidental (unintentional), subsequent encounter*/
,'T608X1S'  /*Toxic effect of other pesticides, accidental (unintentional), sequela*/
,'T608X2D'  /*Toxic effect of other pesticides, intentional self-harm, subsequent encounter*/
,'T608X2S'  /*Toxic effect of other pesticides, intentional self-harm, sequela*/
,'T608X3D'  /*Toxic effect of other pesticides, assault, subsequent encounter*/
,'T608X3S'  /*Toxic effect of other pesticides, assault, sequela*/
,'T608X4D'  /*Toxic effect of other pesticides, undetermined, subsequent encounter*/
,'T608X4S'  /*Toxic effect of other pesticides, undetermined, sequela*/
,'T6091XD'  /*Toxic effect of unspecified pesticide, accidental (unintentional), subsequent encounter*/
,'T6091XS'  /*Toxic effect of unspecified pesticide, accidental (unintentional), sequela*/
,'T6092XD'  /*Toxic effect of unspecified pesticide, intentional self-harm, subsequent encounter*/
,'T6092XS'  /*Toxic effect of unspecified pesticide, intentional self-harm, sequela*/
,'T6093XD'  /*Toxic effect of unspecified pesticide, assault, subsequent encounter*/
,'T6093XS'  /*Toxic effect of unspecified pesticide, assault, sequela*/
,'T6094XD'  /*Toxic effect of unspecified pesticide, undetermined, subsequent encounter*/
,'T6094XS'  /*Toxic effect of unspecified pesticide, undetermined, sequela*/
,'T6101XD'  /*Ciguatera fish poisoning, accidental (unintentional), subsequent encounter*/
,'T6101XS'  /*Ciguatera fish poisoning, accidental (unintentional), sequela*/
,'T6102XD'  /*Ciguatera fish poisoning, intentional self-harm, subsequent encounter*/
,'T6102XS'  /*Ciguatera fish poisoning, intentional self-harm, sequela*/
,'T6103XD'  /*Ciguatera fish poisoning, assault, subsequent encounter*/
,'T6103XS'  /*Ciguatera fish poisoning, assault, sequela*/
,'T6104XD'  /*Ciguatera fish poisoning, undetermined, subsequent encounter*/
,'T6104XS'  /*Ciguatera fish poisoning, undetermined, sequela*/
,'T6111XD'  /*Scombroid fish poisoning, accidental (unintentional), subsequent encounter*/
,'T6111XS'  /*Scombroid fish poisoning, accidental (unintentional), sequela*/
,'T6112XD'  /*Scombroid fish poisoning, intentional self-harm, subsequent encounter*/
,'T6112XS'  /*Scombroid fish poisoning, intentional self-harm, sequela*/
,'T6113XD'  /*Scombroid fish poisoning, assault, subsequent encounter*/
,'T6113XS'  /*Scombroid fish poisoning, assault, sequela*/
,'T6114XD'  /*Scombroid fish poisoning, undetermined, subsequent encounter*/
,'T6114XS'  /*Scombroid fish poisoning, undetermined, sequela*/
,'T61771D'  /*Other fish poisoning, accidental (unintentional), subsequent encounter*/
,'T61771S'  /*Other fish poisoning, accidental (unintentional), sequela*/
,'T61772D'  /*Other fish poisoning, intentional self-harm, subsequent encounter*/
,'T61772S'  /*Other fish poisoning, intentional self-harm, sequela*/
,'T61773D'  /*Other fish poisoning, assault, subsequent encounter*/
,'T61773S'  /*Other fish poisoning, assault, sequela*/
,'T61774D'  /*Other fish poisoning, undetermined, subsequent encounter*/
,'T61774S'  /*Other fish poisoning, undetermined, sequela*/
,'T61781D'  /*Other shellfish poisoning, accidental (unintentional), subsequent encounter*/
,'T61781S'  /*Other shellfish poisoning, accidental (unintentional), sequela*/
,'T61782D'  /*Other shellfish poisoning, intentional self-harm, subsequent encounter*/
,'T61782S'  /*Other shellfish poisoning, intentional self-harm, sequela*/
,'T61783D'  /*Other shellfish poisoning, assault, subsequent encounter*/
,'T61783S'  /*Other shellfish poisoning, assault, sequela*/
,'T61784D'  /*Other shellfish poisoning, undetermined, subsequent encounter*/
,'T61784S'  /*Other shellfish poisoning, undetermined, sequela*/
,'T618X1D'  /*Toxic effect of other seafood, accidental (unintentional), subsequent encounter*/
,'T618X1S'  /*Toxic effect of other seafood, accidental (unintentional), sequela*/
,'T618X2D'  /*Toxic effect of other seafood, intentional self-harm, subsequent encounter*/
,'T618X2S'  /*Toxic effect of other seafood, intentional self-harm, sequela*/
,'T618X3D'  /*Toxic effect of other seafood, assault, subsequent encounter*/
,'T618X3S'  /*Toxic effect of other seafood, assault, sequela*/
,'T618X4D'  /*Toxic effect of other seafood, undetermined, subsequent encounter*/
,'T618X4S'  /*Toxic effect of other seafood, undetermined, sequela*/
,'T6191XD'  /*Toxic effect of unspecified seafood, accidental (unintentional), subsequent encounter*/
,'T6191XS'  /*Toxic effect of unspecified seafood, accidental (unintentional), sequela*/
,'T6192XD'  /*Toxic effect of unspecified seafood, intentional self-harm, subsequent encounter*/
,'T6192XS'  /*Toxic effect of unspecified seafood, intentional self-harm, sequela*/
,'T6193XD'  /*Toxic effect of unspecified seafood, assault, subsequent encounter*/
,'T6193XS'  /*Toxic effect of unspecified seafood, assault, sequela*/
,'T6194XD'  /*Toxic effect of unspecified seafood, undetermined, subsequent encounter*/
,'T6194XS'  /*Toxic effect of unspecified seafood, undetermined, sequela*/
,'T620X1D'  /*Toxic effect of ingested mushrooms, accidental (unintentional), subsequent encounter*/
,'T620X1S'  /*Toxic effect of ingested mushrooms, accidental (unintentional), sequela*/
,'T620X2D'  /*Toxic effect of ingested mushrooms, intentional self-harm, subsequent encounter*/
,'T620X2S'  /*Toxic effect of ingested mushrooms, intentional self-harm, sequela*/
,'T620X3D'  /*Toxic effect of ingested mushrooms, assault, subsequent encounter*/
,'T620X3S'  /*Toxic effect of ingested mushrooms, assault, sequela*/
,'T620X4D'  /*Toxic effect of ingested mushrooms, undetermined, subsequent encounter*/
,'T620X4S'  /*Toxic effect of ingested mushrooms, undetermined, sequela*/
,'T621X1D'  /*Toxic effect of ingested berries, accidental (unintentional), subsequent encounter*/
,'T621X1S'  /*Toxic effect of ingested berries, accidental (unintentional), sequela*/
,'T621X2D'  /*Toxic effect of ingested berries, intentional self-harm, subsequent encounter*/
,'T621X2S'  /*Toxic effect of ingested berries, intentional self-harm, sequela*/
,'T621X3D'  /*Toxic effect of ingested berries, assault, subsequent encounter*/
,'T621X3S'  /*Toxic effect of ingested berries, assault, sequela*/
,'T621X4D'  /*Toxic effect of ingested berries, undetermined, subsequent encounter*/
,'T621X4S'  /*Toxic effect of ingested berries, undetermined, sequela*/
,'T622X1D'  /*Toxic effect of other ingested (parts of) plant(s), accidental (unintentional), subsequent encounter*/
,'T622X1S'  /*Toxic effect of other ingested (parts of) plant(s), accidental (unintentional), sequela*/
,'T622X2D'  /*Toxic effect of other ingested (parts of) plant(s), intentional self-harm, subsequent encounter*/
,'T622X2S'  /*Toxic effect of other ingested (parts of) plant(s), intentional self-harm, sequela*/
,'T622X3D'  /*Toxic effect of other ingested (parts of) plant(s), assault, subsequent encounter*/
,'T622X3S'  /*Toxic effect of other ingested (parts of) plant(s), assault, sequela*/
,'T622X4D'  /*Toxic effect of other ingested (parts of) plant(s), undetermined, subsequent encounter*/
,'T622X4S'  /*Toxic effect of other ingested (parts of) plant(s), undetermined, sequela*/
,'T628X1D'  /*Toxic effect of other specified noxious substances eaten as food, accidental (unintentional), subsequent encounter*/
,'T628X1S'  /*Toxic effect of other specified noxious substances eaten as food, accidental (unintentional), sequela*/
,'T628X2D'  /*Toxic effect of other specified noxious substances eaten as food, intentional self-harm, subsequent encounter*/
,'T628X2S'  /*Toxic effect of other specified noxious substances eaten as food, intentional self-harm, sequela*/
,'T628X3D'  /*Toxic effect of other specified noxious substances eaten as food, assault, subsequent encounter*/
,'T628X3S'  /*Toxic effect of other specified noxious substances eaten as food, assault, sequela*/
,'T628X4D'  /*Toxic effect of other specified noxious substances eaten as food, undetermined, subsequent encounter*/
,'T628X4S'  /*Toxic effect of other specified noxious substances eaten as food, undetermined, sequela*/
,'T6291XD'  /*Toxic effect of unspecified noxious substance eaten as food, accidental (unintentional), subsequent encounter*/
,'T6291XS'  /*Toxic effect of unspecified noxious substance eaten as food, accidental (unintentional), sequela*/
,'T6292XD'  /*Toxic effect of unspecified noxious substance eaten as food, intentional self-harm, subsequent encounter*/
,'T6292XS'  /*Toxic effect of unspecified noxious substance eaten as food, intentional self-harm, sequela*/
,'T6293XD'  /*Toxic effect of unspecified noxious substance eaten as food, assault, subsequent encounter*/
,'T6293XS'  /*Toxic effect of unspecified noxious substance eaten as food, assault, sequela*/
,'T6294XD'  /*Toxic effect of unspecified noxious substance eaten as food, undetermined, subsequent encounter*/
,'T6294XS'  /*Toxic effect of unspecified noxious substance eaten as food, undetermined, sequela*/
,'T63001D'  /*Toxic effect of unspecified snake venom, accidental (unintentional), subsequent encounter*/
,'T63001S'  /*Toxic effect of unspecified snake venom, accidental (unintentional), sequela*/
,'T63002D'  /*Toxic effect of unspecified snake venom, intentional self-harm, subsequent encounter*/
,'T63002S'  /*Toxic effect of unspecified snake venom, intentional self-harm, sequela*/
,'T63003D'  /*Toxic effect of unspecified snake venom, assault, subsequent encounter*/
,'T63003S'  /*Toxic effect of unspecified snake venom, assault, sequela*/
,'T63004D'  /*Toxic effect of unspecified snake venom, undetermined, subsequent encounter*/
,'T63004S'  /*Toxic effect of unspecified snake venom, undetermined, sequela*/
,'T63011D'  /*Toxic effect of rattlesnake venom, accidental (unintentional), subsequent encounter*/
,'T63011S'  /*Toxic effect of rattlesnake venom, accidental (unintentional), sequela*/
,'T63012D'  /*Toxic effect of rattlesnake venom, intentional self-harm, subsequent encounter*/
,'T63012S'  /*Toxic effect of rattlesnake venom, intentional self-harm, sequela*/
,'T63013D'  /*Toxic effect of rattlesnake venom, assault, subsequent encounter*/
,'T63013S'  /*Toxic effect of rattlesnake venom, assault, sequela*/
,'T63014D'  /*Toxic effect of rattlesnake venom, undetermined, subsequent encounter*/
,'T63014S'  /*Toxic effect of rattlesnake venom, undetermined, sequela*/
,'T63021D'  /*Toxic effect of coral snake venom, accidental (unintentional), subsequent encounter*/
,'T63021S'  /*Toxic effect of coral snake venom, accidental (unintentional), sequela*/
,'T63022D'  /*Toxic effect of coral snake venom, intentional self-harm, subsequent encounter*/
,'T63022S'  /*Toxic effect of coral snake venom, intentional self-harm, sequela*/
,'T63023D'  /*Toxic effect of coral snake venom, assault, subsequent encounter*/
,'T63023S'  /*Toxic effect of coral snake venom, assault, sequela*/
,'T63024D'  /*Toxic effect of coral snake venom, undetermined, subsequent encounter*/
,'T63024S'  /*Toxic effect of coral snake venom, undetermined, sequela*/
,'T63031D'  /*Toxic effect of taipan venom, accidental (unintentional), subsequent encounter*/
,'T63031S'  /*Toxic effect of taipan venom, accidental (unintentional), sequela*/
,'T63032D'  /*Toxic effect of taipan venom, intentional self-harm, subsequent encounter*/
,'T63032S'  /*Toxic effect of taipan venom, intentional self-harm, sequela*/
,'T63033D'  /*Toxic effect of taipan venom, assault, subsequent encounter*/
,'T63033S'  /*Toxic effect of taipan venom, assault, sequela*/
,'T63034D'  /*Toxic effect of taipan venom, undetermined, subsequent encounter*/
,'T63034S'  /*Toxic effect of taipan venom, undetermined, sequela*/
,'T63041D'  /*Toxic effect of cobra venom, accidental (unintentional), subsequent encounter*/
,'T63041S'  /*Toxic effect of cobra venom, accidental (unintentional), sequela*/
,'T63042D'  /*Toxic effect of cobra venom, intentional self-harm, subsequent encounter*/
,'T63042S'  /*Toxic effect of cobra venom, intentional self-harm, sequela*/
,'T63043D'  /*Toxic effect of cobra venom, assault, subsequent encounter*/
,'T63043S'  /*Toxic effect of cobra venom, assault, sequela*/
,'T63044D'  /*Toxic effect of cobra venom, undetermined, subsequent encounter*/
,'T63044S'  /*Toxic effect of cobra venom, undetermined, sequela*/
,'T63061D'  /*Toxic effect of venom of other North and South American snake, accidental (unintentional), subsequent encounter*/
,'T63061S'  /*Toxic effect of venom of other North and South American snake, accidental (unintentional), sequela*/
,'T63062D'  /*Toxic effect of venom of other North and South American snake, intentional self-harm, subsequent encounter*/
,'T63062S'  /*Toxic effect of venom of other North and South American snake, intentional self-harm, sequela*/
,'T63063D'  /*Toxic effect of venom of other North and South American snake, assault, subsequent encounter*/
,'T63063S'  /*Toxic effect of venom of other North and South American snake, assault, sequela*/
,'T63064D'  /*Toxic effect of venom of other North and South American snake, undetermined, subsequent encounter*/
,'T63064S'  /*Toxic effect of venom of other North and South American snake, undetermined, sequela*/
,'T63071D'  /*Toxic effect of venom of other Australian snake, accidental (unintentional), subsequent encounter*/
,'T63071S'  /*Toxic effect of venom of other Australian snake, accidental (unintentional), sequela*/
,'T63072D'  /*Toxic effect of venom of other Australian snake, intentional self-harm, subsequent encounter*/
,'T63072S'  /*Toxic effect of venom of other Australian snake, intentional self-harm, sequela*/
,'T63073D'  /*Toxic effect of venom of other Australian snake, assault, subsequent encounter*/
,'T63073S'  /*Toxic effect of venom of other Australian snake, assault, sequela*/
,'T63074D'  /*Toxic effect of venom of other Australian snake, undetermined, subsequent encounter*/
,'T63074S'  /*Toxic effect of venom of other Australian snake, undetermined, sequela*/
,'T63081D'  /*Toxic effect of venom of other African and Asian snake, accidental (unintentional), subsequent encounter*/
,'T63081S'  /*Toxic effect of venom of other African and Asian snake, accidental (unintentional), sequela*/
,'T63082D'  /*Toxic effect of venom of other African and Asian snake, intentional self-harm, subsequent encounter*/
,'T63082S'  /*Toxic effect of venom of other African and Asian snake, intentional self-harm, sequela*/
,'T63083D'  /*Toxic effect of venom of other African and Asian snake, assault, subsequent encounter*/
,'T63083S'  /*Toxic effect of venom of other African and Asian snake, assault, sequela*/
,'T63084D'  /*Toxic effect of venom of other African and Asian snake, undetermined, subsequent encounter*/
,'T63084S'  /*Toxic effect of venom of other African and Asian snake, undetermined, sequela*/
,'T63091D'  /*Toxic effect of venom of other snake, accidental (unintentional), subsequent encounter*/
,'T63091S'  /*Toxic effect of venom of other snake, accidental (unintentional), sequela*/
,'T63092D'  /*Toxic effect of venom of other snake, intentional self-harm, subsequent encounter*/
,'T63092S'  /*Toxic effect of venom of other snake, intentional self-harm, sequela*/
,'T63093D'  /*Toxic effect of venom of other snake, assault, subsequent encounter*/
,'T63093S'  /*Toxic effect of venom of other snake, assault, sequela*/
,'T63094D'  /*Toxic effect of venom of other snake, undetermined, subsequent encounter*/
,'T63094S'  /*Toxic effect of venom of other snake, undetermined, sequela*/
,'T63111D'  /*Toxic effect of venom of gila monster, accidental (unintentional), subsequent encounter*/
,'T63111S'  /*Toxic effect of venom of gila monster, accidental (unintentional), sequela*/
,'T63112D'  /*Toxic effect of venom of gila monster, intentional self-harm, subsequent encounter*/
,'T63112S'  /*Toxic effect of venom of gila monster, intentional self-harm, sequela*/
,'T63113D'  /*Toxic effect of venom of gila monster, assault, subsequent encounter*/
,'T63113S'  /*Toxic effect of venom of gila monster, assault, sequela*/
,'T63114D'  /*Toxic effect of venom of gila monster, undetermined, subsequent encounter*/
,'T63114S'  /*Toxic effect of venom of gila monster, undetermined, sequela*/
,'T63121D'  /*Toxic effect of venom of other venomous lizard, accidental (unintentional), subsequent encounter*/
,'T63121S'  /*Toxic effect of venom of other venomous lizard, accidental (unintentional), sequela*/
,'T63122D'  /*Toxic effect of venom of other venomous lizard, intentional self-harm, subsequent encounter*/
,'T63122S'  /*Toxic effect of venom of other venomous lizard, intentional self-harm, sequela*/
,'T63123D'  /*Toxic effect of venom of other venomous lizard, assault, subsequent encounter*/
,'T63123S'  /*Toxic effect of venom of other venomous lizard, assault, sequela*/
,'T63124D'  /*Toxic effect of venom of other venomous lizard, undetermined, subsequent encounter*/
,'T63124S'  /*Toxic effect of venom of other venomous lizard, undetermined, sequela*/
,'T63191D'  /*Toxic effect of venom of other reptiles, accidental (unintentional), subsequent encounter*/
,'T63191S'  /*Toxic effect of venom of other reptiles, accidental (unintentional), sequela*/
,'T63192D'  /*Toxic effect of venom of other reptiles, intentional self-harm, subsequent encounter*/
,'T63192S'  /*Toxic effect of venom of other reptiles, intentional self-harm, sequela*/
,'T63193D'  /*Toxic effect of venom of other reptiles, assault, subsequent encounter*/
,'T63193S'  /*Toxic effect of venom of other reptiles, assault, sequela*/
,'T63194D'  /*Toxic effect of venom of other reptiles, undetermined, subsequent encounter*/
,'T63194S'  /*Toxic effect of venom of other reptiles, undetermined, sequela*/
,'T632X1D'  /*Toxic effect of venom of scorpion, accidental (unintentional), subsequent encounter*/
,'T632X1S'  /*Toxic effect of venom of scorpion, accidental (unintentional), sequela*/
,'T632X2D'  /*Toxic effect of venom of scorpion, intentional self-harm, subsequent encounter*/
,'T632X2S'  /*Toxic effect of venom of scorpion, intentional self-harm, sequela*/
,'T632X3D'  /*Toxic effect of venom of scorpion, assault, subsequent encounter*/
,'T632X3S'  /*Toxic effect of venom of scorpion, assault, sequela*/
,'T632X4D'  /*Toxic effect of venom of scorpion, undetermined, subsequent encounter*/
,'T632X4S'  /*Toxic effect of venom of scorpion, undetermined, sequela*/
,'T63301D'  /*Toxic effect of unspecified spider venom, accidental (unintentional), subsequent encounter*/
,'T63301S'  /*Toxic effect of unspecified spider venom, accidental (unintentional), sequela*/
,'T63302D'  /*Toxic effect of unspecified spider venom, intentional self-harm, subsequent encounter*/
,'T63302S'  /*Toxic effect of unspecified spider venom, intentional self-harm, sequela*/
,'T63303D'  /*Toxic effect of unspecified spider venom, assault, subsequent encounter*/
,'T63303S'  /*Toxic effect of unspecified spider venom, assault, sequela*/
,'T63304D'  /*Toxic effect of unspecified spider venom, undetermined, subsequent encounter*/
,'T63304S'  /*Toxic effect of unspecified spider venom, undetermined, sequela*/
,'T63311D'  /*Toxic effect of venom of black widow spider, accidental (unintentional), subsequent encounter*/
,'T63311S'  /*Toxic effect of venom of black widow spider, accidental (unintentional), sequela*/
,'T63312D'  /*Toxic effect of venom of black widow spider, intentional self-harm, subsequent encounter*/
,'T63312S'  /*Toxic effect of venom of black widow spider, intentional self-harm, sequela*/
,'T63313D'  /*Toxic effect of venom of black widow spider, assault, subsequent encounter*/
,'T63313S'  /*Toxic effect of venom of black widow spider, assault, sequela*/
,'T63314D'  /*Toxic effect of venom of black widow spider, undetermined, subsequent encounter*/
,'T63314S'  /*Toxic effect of venom of black widow spider, undetermined, sequela*/
,'T63321D'  /*Toxic effect of venom of tarantula, accidental (unintentional), subsequent encounter*/
,'T63321S'  /*Toxic effect of venom of tarantula, accidental (unintentional), sequela*/
,'T63322D'  /*Toxic effect of venom of tarantula, intentional self-harm, subsequent encounter*/
,'T63322S'  /*Toxic effect of venom of tarantula, intentional self-harm, sequela*/
,'T63323D'  /*Toxic effect of venom of tarantula, assault, subsequent encounter*/
,'T63323S'  /*Toxic effect of venom of tarantula, assault, sequela*/
,'T63324D'  /*Toxic effect of venom of tarantula, undetermined, subsequent encounter*/
,'T63324S'  /*Toxic effect of venom of tarantula, undetermined, sequela*/
,'T63331D'  /*Toxic effect of venom of brown recluse spider, accidental (unintentional), subsequent encounter*/
,'T63331S'  /*Toxic effect of venom of brown recluse spider, accidental (unintentional), sequela*/
,'T63332D'  /*Toxic effect of venom of brown recluse spider, intentional self-harm, subsequent encounter*/
,'T63332S'  /*Toxic effect of venom of brown recluse spider, intentional self-harm, sequela*/
,'T63333D'  /*Toxic effect of venom of brown recluse spider, assault, subsequent encounter*/
,'T63333S'  /*Toxic effect of venom of brown recluse spider, assault, sequela*/
,'T63334D'  /*Toxic effect of venom of brown recluse spider, undetermined, subsequent encounter*/
,'T63334S'  /*Toxic effect of venom of brown recluse spider, undetermined, sequela*/
,'T63391D'  /*Toxic effect of venom of other spider, accidental (unintentional), subsequent encounter*/
,'T63391S'  /*Toxic effect of venom of other spider, accidental (unintentional), sequela*/
,'T63392D'  /*Toxic effect of venom of other spider, intentional self-harm, subsequent encounter*/
,'T63392S'  /*Toxic effect of venom of other spider, intentional self-harm, sequela*/
,'T63393D'  /*Toxic effect of venom of other spider, assault, subsequent encounter*/
,'T63393S'  /*Toxic effect of venom of other spider, assault, sequela*/
,'T63394D'  /*Toxic effect of venom of other spider, undetermined, subsequent encounter*/
,'T63394S'  /*Toxic effect of venom of other spider, undetermined, sequela*/
,'T63411D'  /*Toxic effect of venom of centipedes and venomous millipedes, accidental (unintentional), subsequent encounter*/
,'T63411S'  /*Toxic effect of venom of centipedes and venomous millipedes, accidental (unintentional), sequela*/
,'T63412D'  /*Toxic effect of venom of centipedes and venomous millipedes, intentional self-harm, subsequent encounter*/
,'T63412S'  /*Toxic effect of venom of centipedes and venomous millipedes, intentional self-harm, sequela*/
,'T63413D'  /*Toxic effect of venom of centipedes and venomous millipedes, assault, subsequent encounter*/
,'T63413S'  /*Toxic effect of venom of centipedes and venomous millipedes, assault, sequela*/
,'T63414D'  /*Toxic effect of venom of centipedes and venomous millipedes, undetermined, subsequent encounter*/
,'T63414S'  /*Toxic effect of venom of centipedes and venomous millipedes, undetermined, sequela*/
,'T63421D'  /*Toxic effect of venom of ants, accidental (unintentional), subsequent encounter*/
,'T63421S'  /*Toxic effect of venom of ants, accidental (unintentional), sequela*/
,'T63422D'  /*Toxic effect of venom of ants, intentional self-harm, subsequent encounter*/
,'T63422S'  /*Toxic effect of venom of ants, intentional self-harm, sequela*/
,'T63423D'  /*Toxic effect of venom of ants, assault, subsequent encounter*/
,'T63423S'  /*Toxic effect of venom of ants, assault, sequela*/
,'T63424D'  /*Toxic effect of venom of ants, undetermined, subsequent encounter*/
,'T63424S'  /*Toxic effect of venom of ants, undetermined, sequela*/
,'T63431D'  /*Toxic effect of venom of caterpillars, accidental (unintentional), subsequent encounter*/
,'T63431S'  /*Toxic effect of venom of caterpillars, accidental (unintentional), sequela*/
,'T63432D'  /*Toxic effect of venom of caterpillars, intentional self-harm, subsequent encounter*/
,'T63432S'  /*Toxic effect of venom of caterpillars, intentional self-harm, sequela*/
,'T63433D'  /*Toxic effect of venom of caterpillars, assault, subsequent encounter*/
,'T63433S'  /*Toxic effect of venom of caterpillars, assault, sequela*/
,'T63434D'  /*Toxic effect of venom of caterpillars, undetermined, subsequent encounter*/
,'T63434S'  /*Toxic effect of venom of caterpillars, undetermined, sequela*/
,'T63441D'  /*Toxic effect of venom of bees, accidental (unintentional), subsequent encounter*/
,'T63441S'  /*Toxic effect of venom of bees, accidental (unintentional), sequela*/
,'T63442D'  /*Toxic effect of venom of bees, intentional self-harm, subsequent encounter*/
,'T63442S'  /*Toxic effect of venom of bees, intentional self-harm, sequela*/
,'T63443D'  /*Toxic effect of venom of bees, assault, subsequent encounter*/
,'T63443S'  /*Toxic effect of venom of bees, assault, sequela*/
,'T63444D'  /*Toxic effect of venom of bees, undetermined, subsequent encounter*/
,'T63444S'  /*Toxic effect of venom of bees, undetermined, sequela*/
,'T63451D'  /*Toxic effect of venom of hornets, accidental (unintentional), subsequent encounter*/
,'T63451S'  /*Toxic effect of venom of hornets, accidental (unintentional), sequela*/
,'T63452D'  /*Toxic effect of venom of hornets, intentional self-harm, subsequent encounter*/
,'T63452S'  /*Toxic effect of venom of hornets, intentional self-harm, sequela*/
,'T63453D'  /*Toxic effect of venom of hornets, assault, subsequent encounter*/
,'T63453S'  /*Toxic effect of venom of hornets, assault, sequela*/
,'T63454D'  /*Toxic effect of venom of hornets, undetermined, subsequent encounter*/
,'T63454S'  /*Toxic effect of venom of hornets, undetermined, sequela*/
,'T63461D'  /*Toxic effect of venom of wasps, accidental (unintentional), subsequent encounter*/
,'T63461S'  /*Toxic effect of venom of wasps, accidental (unintentional), sequela*/
,'T63462D'  /*Toxic effect of venom of wasps, intentional self-harm, subsequent encounter*/
,'T63462S'  /*Toxic effect of venom of wasps, intentional self-harm, sequela*/
,'T63463D'  /*Toxic effect of venom of wasps, assault, subsequent encounter*/
,'T63463S'  /*Toxic effect of venom of wasps, assault, sequela*/
,'T63464D'  /*Toxic effect of venom of wasps, undetermined, subsequent encounter*/
,'T63464S'  /*Toxic effect of venom of wasps, undetermined, sequela*/
,'T63481D'  /*Toxic effect of venom of other arthropod, accidental (unintentional), subsequent encounter*/
,'T63481S'  /*Toxic effect of venom of other arthropod, accidental (unintentional), sequela*/
,'T63482D'  /*Toxic effect of venom of other arthropod, intentional self-harm, subsequent encounter*/
,'T63482S'  /*Toxic effect of venom of other arthropod, intentional self-harm, sequela*/
,'T63483D'  /*Toxic effect of venom of other arthropod, assault, subsequent encounter*/
,'T63483S'  /*Toxic effect of venom of other arthropod, assault, sequela*/
,'T63484D'  /*Toxic effect of venom of other arthropod, undetermined, subsequent encounter*/
,'T63484S'  /*Toxic effect of venom of other arthropod, undetermined, sequela*/
,'T63511D'  /*Toxic effect of contact with stingray, accidental (unintentional), subsequent encounter*/
,'T63511S'  /*Toxic effect of contact with stingray, accidental (unintentional), sequela*/
,'T63512D'  /*Toxic effect of contact with stingray, intentional self-harm, subsequent encounter*/
,'T63512S'  /*Toxic effect of contact with stingray, intentional self-harm, sequela*/
,'T63513D'  /*Toxic effect of contact with stingray, assault, subsequent encounter*/
,'T63513S'  /*Toxic effect of contact with stingray, assault, sequela*/
,'T63514D'  /*Toxic effect of contact with stingray, undetermined, subsequent encounter*/
,'T63514S'  /*Toxic effect of contact with stingray, undetermined, sequela*/
,'T63591D'  /*Toxic effect of contact with other venomous fish, accidental (unintentional), subsequent encounter*/
,'T63591S'  /*Toxic effect of contact with other venomous fish, accidental (unintentional), sequela*/
,'T63592D'  /*Toxic effect of contact with other venomous fish, intentional self-harm, subsequent encounter*/
,'T63592S'  /*Toxic effect of contact with other venomous fish, intentional self-harm, sequela*/
,'T63593D'  /*Toxic effect of contact with other venomous fish, assault, subsequent encounter*/
,'T63593S'  /*Toxic effect of contact with other venomous fish, assault, sequela*/
,'T63594D'  /*Toxic effect of contact with other venomous fish, undetermined, subsequent encounter*/
,'T63594S'  /*Toxic effect of contact with other venomous fish, undetermined, sequela*/
,'T63611D'  /*Toxic effect of contact with Portugese Man-o-war, accidental (unintentional), subsequent encounter*/
,'T63611S'  /*Toxic effect of contact with Portugese Man-o-war, accidental (unintentional), sequela*/
,'T63612D'  /*Toxic effect of contact with Portugese Man-o-war, intentional self-harm, subsequent encounter*/
,'T63612S'  /*Toxic effect of contact with Portugese Man-o-war, intentional self-harm, sequela*/
,'T63613D'  /*Toxic effect of contact with Portugese Man-o-war, assault, subsequent encounter*/
,'T63613S'  /*Toxic effect of contact with Portugese Man-o-war, assault, sequela*/
,'T63614D'  /*Toxic effect of contact with Portugese Man-o-war, undetermined, subsequent encounter*/
,'T63614S'  /*Toxic effect of contact with Portugese Man-o-war, undetermined, sequela*/
,'T63621D'  /*Toxic effect of contact with other jellyfish, accidental (unintentional), subsequent encounter*/
,'T63621S'  /*Toxic effect of contact with other jellyfish, accidental (unintentional), sequela*/
,'T63622D'  /*Toxic effect of contact with other jellyfish, intentional self-harm, subsequent encounter*/
,'T63622S'  /*Toxic effect of contact with other jellyfish, intentional self-harm, sequela*/
,'T63623D'  /*Toxic effect of contact with other jellyfish, assault, subsequent encounter*/
,'T63623S'  /*Toxic effect of contact with other jellyfish, assault, sequela*/
,'T63624D'  /*Toxic effect of contact with other jellyfish, undetermined, subsequent encounter*/
,'T63624S'  /*Toxic effect of contact with other jellyfish, undetermined, sequela*/
,'T63631D'  /*Toxic effect of contact with sea anemone, accidental (unintentional), subsequent encounter*/
,'T63631S'  /*Toxic effect of contact with sea anemone, accidental (unintentional), sequela*/
,'T63632D'  /*Toxic effect of contact with sea anemone, intentional self-harm, subsequent encounter*/
,'T63632S'  /*Toxic effect of contact with sea anemone, intentional self-harm, sequela*/
,'T63633D'  /*Toxic effect of contact with sea anemone, assault, subsequent encounter*/
,'T63633S'  /*Toxic effect of contact with sea anemone, assault, sequela*/
,'T63634D'  /*Toxic effect of contact with sea anemone, undetermined, subsequent encounter*/
,'T63634S'  /*Toxic effect of contact with sea anemone, undetermined, sequela*/
,'T63691D'  /*Toxic effect of contact with other venomous marine animals, accidental (unintentional), subsequent encounter*/
,'T63691S'  /*Toxic effect of contact with other venomous marine animals, accidental (unintentional), sequela*/
,'T63692D'  /*Toxic effect of contact with other venomous marine animals, intentional self-harm, subsequent encounter*/
,'T63692S'  /*Toxic effect of contact with other venomous marine animals, intentional self-harm, sequela*/
,'T63693D'  /*Toxic effect of contact with other venomous marine animals, assault, subsequent encounter*/
,'T63693S'  /*Toxic effect of contact with other venomous marine animals, assault, sequela*/
,'T63694D'  /*Toxic effect of contact with other venomous marine animals, undetermined, subsequent encounter*/
,'T63694S'  /*Toxic effect of contact with other venomous marine animals, undetermined, sequela*/
,'T63711D'  /*Toxic effect of contact with venomous marine plant, accidental (unintentional), subsequent encounter*/
,'T63711S'  /*Toxic effect of contact with venomous marine plant, accidental (unintentional), sequela*/
,'T63712D'  /*Toxic effect of contact with venomous marine plant, intentional self-harm, subsequent encounter*/
,'T63712S'  /*Toxic effect of contact with venomous marine plant, intentional self-harm, sequela*/
,'T63713D'  /*Toxic effect of contact with venomous marine plant, assault, subsequent encounter*/
,'T63713S'  /*Toxic effect of contact with venomous marine plant, assault, sequela*/
,'T63714D'  /*Toxic effect of contact with venomous marine plant, undetermined, subsequent encounter*/
,'T63714S'  /*Toxic effect of contact with venomous marine plant, undetermined, sequela*/
,'T63791D'  /*Toxic effect of contact with other venomous plant, accidental (unintentional), subsequent encounter*/
,'T63791S'  /*Toxic effect of contact with other venomous plant, accidental (unintentional), sequela*/
,'T63792D'  /*Toxic effect of contact with other venomous plant, intentional self-harm, subsequent encounter*/
,'T63792S'  /*Toxic effect of contact with other venomous plant, intentional self-harm, sequela*/
,'T63793D'  /*Toxic effect of contact with other venomous plant, assault, subsequent encounter*/
,'T63793S'  /*Toxic effect of contact with other venomous plant, assault, sequela*/
,'T63794D'  /*Toxic effect of contact with other venomous plant, undetermined, subsequent encounter*/
,'T63794S'  /*Toxic effect of contact with other venomous plant, undetermined, sequela*/
,'T63811D'  /*Toxic effect of contact with venomous frog, accidental (unintentional), subsequent encounter*/
,'T63811S'  /*Toxic effect of contact with venomous frog, accidental (unintentional), sequela*/
,'T63812D'  /*Toxic effect of contact with venomous frog, intentional self-harm, subsequent encounter*/
,'T63812S'  /*Toxic effect of contact with venomous frog, intentional self-harm, sequela*/
,'T63813D'  /*Toxic effect of contact with venomous frog, assault, subsequent encounter*/
,'T63813S'  /*Toxic effect of contact with venomous frog, assault, sequela*/
,'T63814D'  /*Toxic effect of contact with venomous frog, undetermined, subsequent encounter*/
,'T63814S'  /*Toxic effect of contact with venomous frog, undetermined, sequela*/
,'T63821D'  /*Toxic effect of contact with venomous toad, accidental (unintentional), subsequent encounter*/
,'T63821S'  /*Toxic effect of contact with venomous toad, accidental (unintentional), sequela*/
,'T63822D'  /*Toxic effect of contact with venomous toad, intentional self-harm, subsequent encounter*/
,'T63822S'  /*Toxic effect of contact with venomous toad, intentional self-harm, sequela*/
,'T63823D'  /*Toxic effect of contact with venomous toad, assault, subsequent encounter*/
,'T63823S'  /*Toxic effect of contact with venomous toad, assault, sequela*/
,'T63824D'  /*Toxic effect of contact with venomous toad, undetermined, subsequent encounter*/
,'T63824S'  /*Toxic effect of contact with venomous toad, undetermined, sequela*/
,'T63831D'  /*Toxic effect of contact with other venomous amphibian, accidental (unintentional), subsequent encounter*/
,'T63831S'  /*Toxic effect of contact with other venomous amphibian, accidental (unintentional), sequela*/
,'T63832D'  /*Toxic effect of contact with other venomous amphibian, intentional self-harm, subsequent encounter*/
,'T63832S'  /*Toxic effect of contact with other venomous amphibian, intentional self-harm, sequela*/
,'T63833D'  /*Toxic effect of contact with other venomous amphibian, assault, subsequent encounter*/
,'T63833S'  /*Toxic effect of contact with other venomous amphibian, assault, sequela*/
,'T63834D'  /*Toxic effect of contact with other venomous amphibian, undetermined, subsequent encounter*/
,'T63834S'  /*Toxic effect of contact with other venomous amphibian, undetermined, sequela*/
,'T63891D'  /*Toxic effect of contact with other venomous animals, accidental (unintentional), subsequent encounter*/
,'T63891S'  /*Toxic effect of contact with other venomous animals, accidental (unintentional), sequela*/
,'T63892D'  /*Toxic effect of contact with other venomous animals, intentional self-harm, subsequent encounter*/
,'T63892S'  /*Toxic effect of contact with other venomous animals, intentional self-harm, sequela*/
,'T63893D'  /*Toxic effect of contact with other venomous animals, assault, subsequent encounter*/
,'T63893S'  /*Toxic effect of contact with other venomous animals, assault, sequela*/
,'T63894D'  /*Toxic effect of contact with other venomous animals, undetermined, subsequent encounter*/
,'T63894S'  /*Toxic effect of contact with other venomous animals, undetermined, sequela*/
,'T6391XD'  /*Toxic effect of contact with unspecified venomous animal, accidental (unintentional), subsequent encounter*/
,'T6391XS'  /*Toxic effect of contact with unspecified venomous animal, accidental (unintentional), sequela*/
,'T6392XD'  /*Toxic effect of contact with unspecified venomous animal, intentional self-harm, subsequent encounter*/
,'T6392XS'  /*Toxic effect of contact with unspecified venomous animal, intentional self-harm, sequela*/
,'T6393XD'  /*Toxic effect of contact with unspecified venomous animal, assault, subsequent encounter*/
,'T6393XS'  /*Toxic effect of contact with unspecified venomous animal, assault, sequela*/
,'T6394XD'  /*Toxic effect of contact with unspecified venomous animal, undetermined, subsequent encounter*/
,'T6394XS'  /*Toxic effect of contact with unspecified venomous animal, undetermined, sequela*/
,'T6401XD'  /*Toxic effect of aflatoxin, accidental (unintentional), subsequent encounter*/
,'T6401XS'  /*Toxic effect of aflatoxin, accidental (unintentional), sequela*/
,'T6402XD'  /*Toxic effect of aflatoxin, intentional self-harm, subsequent encounter*/
,'T6402XS'  /*Toxic effect of aflatoxin, intentional self-harm, sequela*/
,'T6403XD'  /*Toxic effect of aflatoxin, assault, subsequent encounter*/
,'T6403XS'  /*Toxic effect of aflatoxin, assault, sequela*/
,'T6404XD'  /*Toxic effect of aflatoxin, undetermined, subsequent encounter*/
,'T6404XS'  /*Toxic effect of aflatoxin, undetermined, sequela*/
,'T6481XD'  /*Toxic effect of other mycotoxin food contaminants, accidental (unintentional), subsequent encounter*/
,'T6481XS'  /*Toxic effect of other mycotoxin food contaminants, accidental (unintentional), sequela*/
,'T6482XD'  /*Toxic effect of other mycotoxin food contaminants, intentional self-harm, subsequent encounter*/
,'T6482XS'  /*Toxic effect of other mycotoxin food contaminants, intentional self-harm, sequela*/
,'T6483XD'  /*Toxic effect of other mycotoxin food contaminants, assault, subsequent encounter*/
,'T6483XS'  /*Toxic effect of other mycotoxin food contaminants, assault, sequela*/
,'T6484XD'  /*Toxic effect of other mycotoxin food contaminants, undetermined, subsequent encounter*/
,'T6484XS'  /*Toxic effect of other mycotoxin food contaminants, undetermined, sequela*/
,'T650X1D'  /*Toxic effect of cyanides, accidental (unintentional), subsequent encounter*/
,'T650X1S'  /*Toxic effect of cyanides, accidental (unintentional), sequela*/
,'T650X2D'  /*Toxic effect of cyanides, intentional self-harm, subsequent encounter*/
,'T650X2S'  /*Toxic effect of cyanides, intentional self-harm, sequela*/
,'T650X3D'  /*Toxic effect of cyanides, assault, subsequent encounter*/
,'T650X3S'  /*Toxic effect of cyanides, assault, sequela*/
,'T650X4D'  /*Toxic effect of cyanides, undetermined, subsequent encounter*/
,'T650X4S'  /*Toxic effect of cyanides, undetermined, sequela*/
,'T651X1D'  /*Toxic effect of strychnine and its salts, accidental (unintentional), subsequent encounter*/
,'T651X1S'  /*Toxic effect of strychnine and its salts, accidental (unintentional), sequela*/
,'T651X2D'  /*Toxic effect of strychnine and its salts, intentional self-harm, subsequent encounter*/
,'T651X2S'  /*Toxic effect of strychnine and its salts, intentional self-harm, sequela*/
,'T651X3D'  /*Toxic effect of strychnine and its salts, assault, subsequent encounter*/
,'T651X3S'  /*Toxic effect of strychnine and its salts, assault, sequela*/
,'T651X4D'  /*Toxic effect of strychnine and its salts, undetermined, subsequent encounter*/
,'T651X4S'  /*Toxic effect of strychnine and its salts, undetermined, sequela*/
,'T65211D'  /*Toxic effect of chewing tobacco, accidental (unintentional), subsequent encounter*/
,'T65211S'  /*Toxic effect of chewing tobacco, accidental (unintentional), sequela*/
,'T65212D'  /*Toxic effect of chewing tobacco, intentional self-harm, subsequent encounter*/
,'T65212S'  /*Toxic effect of chewing tobacco, intentional self-harm, sequela*/
,'T65213D'  /*Toxic effect of chewing tobacco, assault, subsequent encounter*/
,'T65213S'  /*Toxic effect of chewing tobacco, assault, sequela*/
,'T65214D'  /*Toxic effect of chewing tobacco, undetermined, subsequent encounter*/
,'T65214S'  /*Toxic effect of chewing tobacco, undetermined, sequela*/
,'T65221D'  /*Toxic effect of tobacco cigarettes, accidental (unintentional), subsequent encounter*/
,'T65221S'  /*Toxic effect of tobacco cigarettes, accidental (unintentional), sequela*/
,'T65222D'  /*Toxic effect of tobacco cigarettes, intentional self-harm, subsequent encounter*/
,'T65222S'  /*Toxic effect of tobacco cigarettes, intentional self-harm, sequela*/
,'T65223D'  /*Toxic effect of tobacco cigarettes, assault, subsequent encounter*/
,'T65223S'  /*Toxic effect of tobacco cigarettes, assault, sequela*/
,'T65224D'  /*Toxic effect of tobacco cigarettes, undetermined, subsequent encounter*/
,'T65224S'  /*Toxic effect of tobacco cigarettes, undetermined, sequela*/
,'T65291D'  /*Toxic effect of other tobacco and nicotine, accidental (unintentional), subsequent encounter*/
,'T65291S'  /*Toxic effect of other tobacco and nicotine, accidental (unintentional), sequela*/
,'T65292D'  /*Toxic effect of other tobacco and nicotine, intentional self-harm, subsequent encounter*/
,'T65292S'  /*Toxic effect of other tobacco and nicotine, intentional self-harm, sequela*/
,'T65293D'  /*Toxic effect of other tobacco and nicotine, assault, subsequent encounter*/
,'T65293S'  /*Toxic effect of other tobacco and nicotine, assault, sequela*/
,'T65294D'  /*Toxic effect of other tobacco and nicotine, undetermined, subsequent encounter*/
,'T65294S'  /*Toxic effect of other tobacco and nicotine, undetermined, sequela*/
,'T653X1D'  /*Toxic effect of nitroderivatives and aminoderivatives of benzene and its homologues, accidental (unintentional), subsequent encounter*/
,'T653X1S'  /*Toxic effect of nitroderivatives and aminoderivatives of benzene and its homologues, accidental (unintentional), sequela*/
,'T653X2D'  /*Toxic effect of nitroderivatives and aminoderivatives of benzene and its homologues, intentional self-harm, subsequent encounter*/
,'T653X2S'  /*Toxic effect of nitroderivatives and aminoderivatives of benzene and its homologues, intentional self-harm, sequela*/
,'T653X3D'  /*Toxic effect of nitroderivatives and aminoderivatives of benzene and its homologues, assault, subsequent encounter*/
,'T653X3S'  /*Toxic effect of nitroderivatives and aminoderivatives of benzene and its homologues, assault, sequela*/
,'T653X4D'  /*Toxic effect of nitroderivatives and aminoderivatives of benzene and its homologues, undetermined, subsequent encounter*/
,'T653X4S'  /*Toxic effect of nitroderivatives and aminoderivatives of benzene and its homologues, undetermined, sequela*/
,'T654X1D'  /*Toxic effect of carbon disulfide, accidental (unintentional), subsequent encounter*/
,'T654X1S'  /*Toxic effect of carbon disulfide, accidental (unintentional), sequela*/
,'T654X2D'  /*Toxic effect of carbon disulfide, intentional self-harm, subsequent encounter*/
,'T654X2S'  /*Toxic effect of carbon disulfide, intentional self-harm, sequela*/
,'T654X3D'  /*Toxic effect of carbon disulfide, assault, subsequent encounter*/
,'T654X3S'  /*Toxic effect of carbon disulfide, assault, sequela*/
,'T654X4D'  /*Toxic effect of carbon disulfide, undetermined, subsequent encounter*/
,'T654X4S'  /*Toxic effect of carbon disulfide, undetermined, sequela*/
,'T655X1D'  /*Toxic effect of nitroglycerin and other nitric acids and esters, accidental (unintentional), subsequent encounter*/
,'T655X1S'  /*Toxic effect of nitroglycerin and other nitric acids and esters, accidental (unintentional), sequela*/
,'T655X2D'  /*Toxic effect of nitroglycerin and other nitric acids and esters, intentional self-harm, subsequent encounter*/
,'T655X2S'  /*Toxic effect of nitroglycerin and other nitric acids and esters, intentional self-harm, sequela*/
,'T655X3D'  /*Toxic effect of nitroglycerin and other nitric acids and esters, assault, subsequent encounter*/
,'T655X3S'  /*Toxic effect of nitroglycerin and other nitric acids and esters, assault, sequela*/
,'T655X4D'  /*Toxic effect of nitroglycerin and other nitric acids and esters, undetermined, subsequent encounter*/
,'T655X4S'  /*Toxic effect of nitroglycerin and other nitric acids and esters, undetermined, sequela*/
,'T656X1D'  /*Toxic effect of paints and dyes, not elsewhere classified, accidental (unintentional), subsequent encounter*/
,'T656X1S'  /*Toxic effect of paints and dyes, not elsewhere classified, accidental (unintentional), sequela*/
,'T656X2D'  /*Toxic effect of paints and dyes, not elsewhere classified, intentional self-harm, subsequent encounter*/
,'T656X2S'  /*Toxic effect of paints and dyes, not elsewhere classified, intentional self-harm, sequela*/
,'T656X3D'  /*Toxic effect of paints and dyes, not elsewhere classified, assault, subsequent encounter*/
,'T656X3S'  /*Toxic effect of paints and dyes, not elsewhere classified, assault, sequela*/
,'T656X4D'  /*Toxic effect of paints and dyes, not elsewhere classified, undetermined, subsequent encounter*/
,'T656X4S'  /*Toxic effect of paints and dyes, not elsewhere classified, undetermined, sequela*/
,'T65811D'  /*Toxic effect of latex, accidental (unintentional), subsequent encounter*/
,'T65811S'  /*Toxic effect of latex, accidental (unintentional), sequela*/
,'T65812D'  /*Toxic effect of latex, intentional self-harm, subsequent encounter*/
,'T65812S'  /*Toxic effect of latex, intentional self-harm, sequela*/
,'T65813D'  /*Toxic effect of latex, assault, subsequent encounter*/
,'T65813S'  /*Toxic effect of latex, assault, sequela*/
,'T65814D'  /*Toxic effect of latex, undetermined, subsequent encounter*/
,'T65814S'  /*Toxic effect of latex, undetermined, sequela*/
,'T65821D'  /*Toxic effect of harmful algae and algae toxins, accidental (unintentional), subsequent encounter*/
,'T65821S'  /*Toxic effect of harmful algae and algae toxins, accidental (unintentional), sequela*/
,'T65822D'  /*Toxic effect of harmful algae and algae toxins, intentional self-harm, subsequent encounter*/
,'T65822S'  /*Toxic effect of harmful algae and algae toxins, intentional self-harm, sequela*/
,'T65823D'  /*Toxic effect of harmful algae and algae toxins, assault, subsequent encounter*/
,'T65823S'  /*Toxic effect of harmful algae and algae toxins, assault, sequela*/
,'T65824D'  /*Toxic effect of harmful algae and algae toxins, undetermined, subsequent encounter*/
,'T65824S'  /*Toxic effect of harmful algae and algae toxins, undetermined, sequela*/
,'T65831D'  /*Toxic effect of fiberglass, accidental (unintentional), subsequent encounter*/
,'T65831S'  /*Toxic effect of fiberglass, accidental (unintentional), sequela*/
,'T65832D'  /*Toxic effect of fiberglass, intentional self-harm, subsequent encounter*/
,'T65832S'  /*Toxic effect of fiberglass, intentional self-harm, sequela*/
,'T65833D'  /*Toxic effect of fiberglass, assault, subsequent encounter*/
,'T65833S'  /*Toxic effect of fiberglass, assault, sequela*/
,'T65834D'  /*Toxic effect of fiberglass, undetermined, subsequent encounter*/
,'T65834S'  /*Toxic effect of fiberglass, undetermined, sequela*/
,'T65891D'  /*Toxic effect of other specified substances, accidental (unintentional), subsequent encounter*/
,'T65891S'  /*Toxic effect of other specified substances, accidental (unintentional), sequela*/
,'T65892D'  /*Toxic effect of other specified substances, intentional self-harm, subsequent encounter*/
,'T65892S'  /*Toxic effect of other specified substances, intentional self-harm, sequela*/
,'T65893D'  /*Toxic effect of other specified substances, assault, subsequent encounter*/
,'T65893S'  /*Toxic effect of other specified substances, assault, sequela*/
,'T65894D'  /*Toxic effect of other specified substances, undetermined, subsequent encounter*/
,'T65894S'  /*Toxic effect of other specified substances, undetermined, sequela*/
,'T6591XD'  /*Toxic effect of unspecified substance, accidental (unintentional), subsequent encounter*/
,'T6591XS'  /*Toxic effect of unspecified substance, accidental (unintentional), sequela*/
,'T6592XD'  /*Toxic effect of unspecified substance, intentional self-harm, subsequent encounter*/
,'T6592XS'  /*Toxic effect of unspecified substance, intentional self-harm, sequela*/
,'T6593XD'  /*Toxic effect of unspecified substance, assault, subsequent encounter*/
,'T6593XS'  /*Toxic effect of unspecified substance, assault, sequela*/
,'T6594XD'  /*Toxic effect of unspecified substance, undetermined, subsequent encounter*/
,'T6594XS'  /*Toxic effect of unspecified substance, undetermined, sequela*/
,'T66XXXD'  /*Radiation sickness, unspecified, subsequent encounter*/
,'T66XXXS'  /*Radiation sickness, unspecified, sequela*/
,'T670XXD'  /*Heatstroke and sunstroke, subsequent encounter*/
,'T670XXS'  /*Heatstroke and sunstroke, sequela*/
,'T671XXD'  /*Heat syncope, subsequent encounter*/
,'T671XXS'  /*Heat syncope, sequela*/
,'T672XXD'  /*Heat cramp, subsequent encounter*/
,'T672XXS'  /*Heat cramp, sequela*/
,'T673XXD'  /*Heat exhaustion, anhydrotic, subsequent encounter*/
,'T673XXS'  /*Heat exhaustion, anhydrotic, sequela*/
,'T674XXD'  /*Heat exhaustion due to salt depletion, subsequent encounter*/
,'T674XXS'  /*Heat exhaustion due to salt depletion, sequela*/
,'T675XXD'  /*Heat exhaustion, unspecified, subsequent encounter*/
,'T675XXS'  /*Heat exhaustion, unspecified, sequela*/
,'T676XXD'  /*Heat fatigue, transient, subsequent encounter*/
,'T676XXS'  /*Heat fatigue, transient, sequela*/
,'T677XXD'  /*Heat edema, subsequent encounter*/
,'T677XXS'  /*Heat edema, sequela*/
,'T678XXD'  /*Other effects of heat and light, subsequent encounter*/
,'T678XXS'  /*Other effects of heat and light, sequela*/
,'T679XXD'  /*Effect of heat and light, unspecified, subsequent encounter*/
,'T679XXS'  /*Effect of heat and light, unspecified, sequela*/
,'T68XXXD'  /*Hypothermia, subsequent encounter*/
,'T68XXXS'  /*Hypothermia, sequela*/
,'T69011D'  /*Immersion hand, right hand, subsequent encounter*/
,'T69011S'  /*Immersion hand, right hand, sequela*/
,'T69012D'  /*Immersion hand, left hand, subsequent encounter*/
,'T69012S'  /*Immersion hand, left hand, sequela*/
,'T69019D'  /*Immersion hand, unspecified hand, subsequent encounter*/
,'T69019S'  /*Immersion hand, unspecified hand, sequela*/
,'T69021D'  /*Immersion foot, right foot, subsequent encounter*/
,'T69021S'  /*Immersion foot, right foot, sequela*/
,'T69022D'  /*Immersion foot, left foot, subsequent encounter*/
,'T69022S'  /*Immersion foot, left foot, sequela*/
,'T69029D'  /*Immersion foot, unspecified foot, subsequent encounter*/
,'T69029S'  /*Immersion foot, unspecified foot, sequela*/
,'T691XXD'  /*Chilblains, subsequent encounter*/
,'T691XXS'  /*Chilblains, sequela*/
,'T698XXD'  /*Other specified effects of reduced temperature, subsequent encounter*/
,'T698XXS'  /*Other specified effects of reduced temperature, sequela*/
,'T699XXD'  /*Effect of reduced temperature, unspecified, subsequent encounter*/
,'T699XXS'  /*Effect of reduced temperature, unspecified, sequela*/
,'T700XXD'  /*Otitic barotrauma, subsequent encounter*/
,'T700XXS'  /*Otitic barotrauma, sequela*/
,'T701XXD'  /*Sinus barotrauma, subsequent encounter*/
,'T701XXS'  /*Sinus barotrauma, sequela*/
,'T7020XD'  /*Unspecified effects of high altitude, subsequent encounter*/
,'T7020XS'  /*Unspecified effects of high altitude, sequela*/
,'T7029XD'  /*Other effects of high altitude, subsequent encounter*/
,'T7029XS'  /*Other effects of high altitude, sequela*/
,'T703XXD'  /*Caisson disease [decompression sickness], subsequent encounter*/
,'T703XXS'  /*Caisson disease [decompression sickness], sequela*/
,'T704XXD'  /*Effects of high-pressure fluids, subsequent encounter*/
,'T704XXS'  /*Effects of high-pressure fluids, sequela*/
,'T708XXD'  /*Other effects of air pressure and water pressure, subsequent encounter*/
,'T708XXS'  /*Other effects of air pressure and water pressure, sequela*/
,'T709XXD'  /*Effect of air pressure and water pressure, unspecified, subsequent encounter*/
,'T709XXS'  /*Effect of air pressure and water pressure, unspecified, sequela*/
,'T71111D'  /*Asphyxiation due to smothering under pillow, accidental, subsequent encounter*/
,'T71111S'  /*Asphyxiation due to smothering under pillow, accidental, sequela*/
,'T71112D'  /*Asphyxiation due to smothering under pillow, intentional self-harm, subsequent encounter*/
,'T71112S'  /*Asphyxiation due to smothering under pillow, intentional self-harm, sequela*/
,'T71113D'  /*Asphyxiation due to smothering under pillow, assault, subsequent encounter*/
,'T71113S'  /*Asphyxiation due to smothering under pillow, assault, sequela*/
,'T71114D'  /*Asphyxiation due to smothering under pillow, undetermined, subsequent encounter*/
,'T71114S'  /*Asphyxiation due to smothering under pillow, undetermined, sequela*/
,'T71121D'  /*Asphyxiation due to plastic bag, accidental, subsequent encounter*/
,'T71121S'  /*Asphyxiation due to plastic bag, accidental, sequela*/
,'T71122D'  /*Asphyxiation due to plastic bag, intentional self-harm, subsequent encounter*/
,'T71122S'  /*Asphyxiation due to plastic bag, intentional self-harm, sequela*/
,'T71123D'  /*Asphyxiation due to plastic bag, assault, subsequent encounter*/
,'T71123S'  /*Asphyxiation due to plastic bag, assault, sequela*/
,'T71124D'  /*Asphyxiation due to plastic bag, undetermined, subsequent encounter*/
,'T71124S'  /*Asphyxiation due to plastic bag, undetermined, sequela*/
,'T71131D'  /*Asphyxiation due to being trapped in bed linens, accidental, subsequent encounter*/
,'T71131S'  /*Asphyxiation due to being trapped in bed linens, accidental, sequela*/
,'T71132D'  /*Asphyxiation due to being trapped in bed linens, intentional self-harm, subsequent encounter*/
,'T71132S'  /*Asphyxiation due to being trapped in bed linens, intentional self-harm, sequela*/
,'T71133D'  /*Asphyxiation due to being trapped in bed linens, assault, subsequent encounter*/
,'T71133S'  /*Asphyxiation due to being trapped in bed linens, assault, sequela*/
,'T71134D'  /*Asphyxiation due to being trapped in bed linens, undetermined, subsequent encounter*/
,'T71134S'  /*Asphyxiation due to being trapped in bed linens, undetermined, sequela*/
,'T71141D'  /*Asphyxiation due to smothering under another person's body (in bed), accidental, subsequent encounter*/
,'T71141S'  /*Asphyxiation due to smothering under another person's body (in bed), accidental, sequela*/
,'T71143D'  /*Asphyxiation due to smothering under another person's body (in bed), assault, subsequent encounter*/
,'T71143S'  /*Asphyxiation due to smothering under another person's body (in bed), assault, sequela*/
,'T71144D'  /*Asphyxiation due to smothering under another person's body (in bed), undetermined, subsequent encounter*/
,'T71144S'  /*Asphyxiation due to smothering under another person's body (in bed), undetermined, sequela*/
,'T71151D'  /*Asphyxiation due to smothering in furniture, accidental, subsequent encounter*/
,'T71151S'  /*Asphyxiation due to smothering in furniture, accidental, sequela*/
,'T71152D'  /*Asphyxiation due to smothering in furniture, intentional self-harm, subsequent encounter*/
,'T71152S'  /*Asphyxiation due to smothering in furniture, intentional self-harm, sequela*/
,'T71153D'  /*Asphyxiation due to smothering in furniture, assault, subsequent encounter*/
,'T71153S'  /*Asphyxiation due to smothering in furniture, assault, sequela*/
,'T71154D'  /*Asphyxiation due to smothering in furniture, undetermined, subsequent encounter*/
,'T71154S'  /*Asphyxiation due to smothering in furniture, undetermined, sequela*/
,'T71161D'  /*Asphyxiation due to hanging, accidental, subsequent encounter*/
,'T71161S'  /*Asphyxiation due to hanging, accidental, sequela*/
,'T71162D'  /*Asphyxiation due to hanging, intentional self-harm, subsequent encounter*/
,'T71162S'  /*Asphyxiation due to hanging, intentional self-harm, sequela*/
,'T71163D'  /*Asphyxiation due to hanging, assault, subsequent encounter*/
,'T71163S'  /*Asphyxiation due to hanging, assault, sequela*/
,'T71164D'  /*Asphyxiation due to hanging, undetermined, subsequent encounter*/
,'T71164S'  /*Asphyxiation due to hanging, undetermined, sequela*/
,'T71191D'  /*Asphyxiation due to mechanical threat to breathing due to other causes, accidental, subsequent encounter*/
,'T71191S'  /*Asphyxiation due to mechanical threat to breathing due to other causes, accidental, sequela*/
,'T71192D'  /*Asphyxiation due to mechanical threat to breathing due to other causes, intentional self-harm, subsequent encounter*/
,'T71192S'  /*Asphyxiation due to mechanical threat to breathing due to other causes, intentional self-harm, sequela*/
,'T71193D'  /*Asphyxiation due to mechanical threat to breathing due to other causes, assault, subsequent encounter*/
,'T71193S'  /*Asphyxiation due to mechanical threat to breathing due to other causes, assault, sequela*/
,'T71194D'  /*Asphyxiation due to mechanical threat to breathing due to other causes, undetermined, subsequent encounter*/
,'T71194S'  /*Asphyxiation due to mechanical threat to breathing due to other causes, undetermined, sequela*/
,'T7120XD'  /*Asphyxiation due to systemic oxygen deficiency due to low oxygen content in ambient air due to unspecified cause, subsequent encounter*/
,'T7120XS'  /*Asphyxiation due to systemic oxygen deficiency due to low oxygen content in ambient air due to unspecified cause, sequela*/
,'T7121XD'  /*Asphyxiation due to cave-in or falling earth, subsequent encounter*/
,'T7121XS'  /*Asphyxiation due to cave-in or falling earth, sequela*/
,'T71221D'  /*Asphyxiation due to being trapped in a car trunk, accidental, subsequent encounter*/
,'T71221S'  /*Asphyxiation due to being trapped in a car trunk, accidental, sequela*/
,'T71222D'  /*Asphyxiation due to being trapped in a car trunk, intentional self-harm, subsequent encounter*/
,'T71222S'  /*Asphyxiation due to being trapped in a car trunk, intentional self-harm, sequela*/
,'T71223D'  /*Asphyxiation due to being trapped in a car trunk, assault, subsequent encounter*/
,'T71223S'  /*Asphyxiation due to being trapped in a car trunk, assault, sequela*/
,'T71224D'  /*Asphyxiation due to being trapped in a car trunk, undetermined, subsequent encounter*/
,'T71224S'  /*Asphyxiation due to being trapped in a car trunk, undetermined, sequela*/
,'T71231D'  /*Asphyxiation due to being trapped in a (discarded) refrigerator, accidental, subsequent encounter*/
,'T71231S'  /*Asphyxiation due to being trapped in a (discarded) refrigerator, accidental, sequela*/
,'T71232D'  /*Asphyxiation due to being trapped in a (discarded) refrigerator, intentional self-harm, subsequent encounter*/
,'T71232S'  /*Asphyxiation due to being trapped in a (discarded) refrigerator, intentional self-harm, sequela*/
,'T71233D'  /*Asphyxiation due to being trapped in a (discarded) refrigerator, assault, subsequent encounter*/
,'T71233S'  /*Asphyxiation due to being trapped in a (discarded) refrigerator, assault, sequela*/
,'T71234D'  /*Asphyxiation due to being trapped in a (discarded) refrigerator, undetermined, subsequent encounter*/
,'T71234S'  /*Asphyxiation due to being trapped in a (discarded) refrigerator, undetermined, sequela*/
,'T7129XD'  /*Asphyxiation due to being trapped in other low oxygen environment, subsequent encounter*/
,'T7129XS'  /*Asphyxiation due to being trapped in other low oxygen environment, sequela*/
,'T719XXD'  /*Asphyxiation due to unspecified cause, subsequent encounter*/
,'T719XXS'  /*Asphyxiation due to unspecified cause, sequela*/
,'T730XXD'  /*Starvation, subsequent encounter*/
,'T730XXS'  /*Starvation, sequela*/
,'T731XXD'  /*Deprivation of water, subsequent encounter*/
,'T731XXS'  /*Deprivation of water, sequela*/
,'T732XXD'  /*Exhaustion due to exposure, subsequent encounter*/
,'T732XXS'  /*Exhaustion due to exposure, sequela*/
,'T733XXD'  /*Exhaustion due to excessive exertion, subsequent encounter*/
,'T733XXS'  /*Exhaustion due to excessive exertion, sequela*/
,'T738XXD'  /*Other effects of deprivation, subsequent encounter*/
,'T738XXS'  /*Other effects of deprivation, sequela*/
,'T739XXD'  /*Effect of deprivation, unspecified, subsequent encounter*/
,'T739XXS'  /*Effect of deprivation, unspecified, sequela*/
,'T7401XD'  /*Adult neglect or abandonment, confirmed, subsequent encounter*/
,'T7401XS'  /*Adult neglect or abandonment, confirmed, sequela*/
,'T7402XD'  /*Child neglect or abandonment, confirmed, subsequent encounter*/
,'T7402XS'  /*Child neglect or abandonment, confirmed, sequela*/
,'T7411XD'  /*Adult physical abuse, confirmed, subsequent encounter*/
,'T7411XS'  /*Adult physical abuse, confirmed, sequela*/
,'T7412XD'  /*Child physical abuse, confirmed, subsequent encounter*/
,'T7412XS'  /*Child physical abuse, confirmed, sequela*/
,'T7421XD'  /*Adult sexual abuse, confirmed, subsequent encounter*/
,'T7421XS'  /*Adult sexual abuse, confirmed, sequela*/
,'T7422XD'  /*Child sexual abuse, confirmed, subsequent encounter*/
,'T7422XS'  /*Child sexual abuse, confirmed, sequela*/
,'T7431XD'  /*Adult psychological abuse, confirmed, subsequent encounter*/
,'T7431XS'  /*Adult psychological abuse, confirmed, sequela*/
,'T7432XD'  /*Child psychological abuse, confirmed, subsequent encounter*/
,'T7432XS'  /*Child psychological abuse, confirmed, sequela*/
,'T744XXD'  /*Shaken infant syndrome, subsequent encounter*/
,'T744XXS'  /*Shaken infant syndrome, sequela*/
,'T7491XD'  /*Unspecified adult maltreatment, confirmed, subsequent encounter*/
,'T7491XS'  /*Unspecified adult maltreatment, confirmed, sequela*/
,'T7492XD'  /*Unspecified child maltreatment, confirmed, subsequent encounter*/
,'T7492XS'  /*Unspecified child maltreatment, confirmed, sequela*/
,'T7500XD'  /*Unspecified effects of lightning, subsequent encounter*/
,'T7500XS'  /*Unspecified effects of lightning, sequela*/
,'T7501XD'  /*Shock due to being struck by lightning, subsequent encounter*/
,'T7501XS'  /*Shock due to being struck by lightning, sequela*/
,'T7509XD'  /*Other effects of lightning, subsequent encounter*/
,'T7509XS'  /*Other effects of lightning, sequela*/
,'T751XXD'  /*Unspecified effects of drowning and nonfatal submersion, subsequent encounter*/
,'T751XXS'  /*Unspecified effects of drowning and nonfatal submersion, sequela*/
,'T7520XD'  /*Unspecified effects of vibration, subsequent encounter*/
,'T7520XS'  /*Unspecified effects of vibration, sequela*/
,'T7521XD'  /*Pneumatic hammer syndrome, subsequent encounter*/
,'T7521XS'  /*Pneumatic hammer syndrome, sequela*/
,'T7522XD'  /*Traumatic vasospastic syndrome, subsequent encounter*/
,'T7522XS'  /*Traumatic vasospastic syndrome, sequela*/
,'T7523XD'  /*Vertigo from infrasound, subsequent encounter*/
,'T7523XS'  /*Vertigo from infrasound, sequela*/
,'T7529XD'  /*Other effects of vibration, subsequent encounter*/
,'T7529XS'  /*Other effects of vibration, sequela*/
,'T753XXD'  /*Motion sickness, subsequent encounter*/
,'T753XXS'  /*Motion sickness, sequela*/
,'T754XXD'  /*Electrocution, subsequent encounter*/
,'T754XXS'  /*Electrocution, sequela*/
,'T7581XD'  /*Effects of abnormal gravitation [G] forces, subsequent encounter*/
,'T7581XS'  /*Effects of abnormal gravitation [G] forces, sequela*/
,'T7582XD'  /*Effects of weightlessness, subsequent encounter*/
,'T7582XS'  /*Effects of weightlessness, sequela*/
,'T7589XD'  /*Other specified effects of external causes, subsequent encounter*/
,'T7589XS'  /*Other specified effects of external causes, sequela*/
,'T7601XD'  /*Adult neglect or abandonment, suspected, subsequent encounter*/
,'T7601XS'  /*Adult neglect or abandonment, suspected, sequela*/
,'T7602XD'  /*Child neglect or abandonment, suspected, subsequent encounter*/
,'T7602XS'  /*Child neglect or abandonment, suspected, sequela*/
,'T7611XD'  /*Adult physical abuse, suspected, subsequent encounter*/
,'T7611XS'  /*Adult physical abuse, suspected, sequela*/
,'T7612XD'  /*Child physical abuse, suspected, subsequent encounter*/
,'T7612XS'  /*Child physical abuse, suspected, sequela*/
,'T7621XD'  /*Adult sexual abuse, suspected, subsequent encounter*/
,'T7621XS'  /*Adult sexual abuse, suspected, sequela*/
,'T7622XD'  /*Child sexual abuse, suspected, subsequent encounter*/
,'T7622XS'  /*Child sexual abuse, suspected, sequela*/
,'T7631XD'  /*Adult psychological abuse, suspected, subsequent encounter*/
,'T7631XS'  /*Adult psychological abuse, suspected, sequela*/
,'T7632XD'  /*Child psychological abuse, suspected, subsequent encounter*/
,'T7632XS'  /*Child psychological abuse, suspected, sequela*/
,'T7691XD'  /*Unspecified adult maltreatment, suspected, subsequent encounter*/
,'T7691XS'  /*Unspecified adult maltreatment, suspected, sequela*/
,'T7692XD'  /*Unspecified child maltreatment, suspected, subsequent encounter*/
,'T7692XS'  /*Unspecified child maltreatment, suspected, sequela*/
,'T7800XD'  /*Anaphylactic reaction due to unspecified food, subsequent encounter*/
,'T7800XS'  /*Anaphylactic reaction due to unspecified food, sequela*/
,'T7801XD'  /*Anaphylactic reaction due to peanuts, subsequent encounter*/
,'T7801XS'  /*Anaphylactic reaction due to peanuts, sequela*/
,'T7802XD'  /*Anaphylactic reaction due to shellfish (crustaceans), subsequent encounter*/
,'T7802XS'  /*Anaphylactic reaction due to shellfish (crustaceans), sequela*/
,'T7803XD'  /*Anaphylactic reaction due to other fish, subsequent encounter*/
,'T7803XS'  /*Anaphylactic reaction due to other fish, sequela*/
,'T7804XD'  /*Anaphylactic reaction due to fruits and vegetables, subsequent encounter*/
,'T7804XS'  /*Anaphylactic reaction due to fruits and vegetables, sequela*/
,'T7805XD'  /*Anaphylactic reaction due to tree nuts and seeds, subsequent encounter*/
,'T7805XS'  /*Anaphylactic reaction due to tree nuts and seeds, sequela*/
,'T7806XD'  /*Anaphylactic reaction due to food additives, subsequent encounter*/
,'T7806XS'  /*Anaphylactic reaction due to food additives, sequela*/
,'T7807XD'  /*Anaphylactic reaction due to milk and dairy products, subsequent encounter*/
,'T7807XS'  /*Anaphylactic reaction due to milk and dairy products, sequela*/
,'T7808XD'  /*Anaphylactic reaction due to eggs, subsequent encounter*/
,'T7808XS'  /*Anaphylactic reaction due to eggs, sequela*/
,'T7809XD'  /*Anaphylactic reaction due to other food products, subsequent encounter*/
,'T7809XS'  /*Anaphylactic reaction due to other food products, sequela*/
,'T781XXD'  /*Other adverse food reactions, not elsewhere classified, subsequent encounter*/
,'T781XXS'  /*Other adverse food reactions, not elsewhere classified, sequela*/
,'T782XXD'  /*Anaphylactic shock, unspecified, subsequent encounter*/
,'T782XXS'  /*Anaphylactic shock, unspecified, sequela*/
,'T783XXD'  /*Angioneurotic edema, subsequent encounter*/
,'T783XXS'  /*Angioneurotic edema, sequela*/
,'T7840XD'  /*Allergy, unspecified, subsequent encounter*/
,'T7840XS'  /*Allergy, unspecified, sequela*/
,'T7841XD'  /*Arthus phenomenon, subsequent encounter*/
,'T7841XS'  /*Arthus phenomenon, sequela*/
,'T7849XD'  /*Other allergy, subsequent encounter*/
,'T7849XS'  /*Other allergy, sequela*/
,'T788XXD'  /*Other adverse effects, not elsewhere classified, subsequent encounter*/
,'T788XXS'  /*Other adverse effects, not elsewhere classified, sequela*/
,'T790XXD'  /*Air embolism (traumatic), subsequent encounter*/
,'T790XXS'  /*Air embolism (traumatic), sequela*/
,'T791XXD'  /*Fat embolism (traumatic), subsequent encounter*/
,'T791XXS'  /*Fat embolism (traumatic), sequela*/
,'T792XXD'  /*Traumatic secondary and recurrent hemorrhage and seroma, subsequent encounter*/
,'T792XXS'  /*Traumatic secondary and recurrent hemorrhage and seroma, sequela*/
,'T794XXD'  /*Traumatic shock, subsequent encounter*/
,'T794XXS'  /*Traumatic shock, sequela*/
,'T795XXD'  /*Traumatic anuria, subsequent encounter*/
,'T795XXS'  /*Traumatic anuria, sequela*/
,'T796XXD'  /*Traumatic ischemia of muscle, subsequent encounter*/
,'T796XXS'  /*Traumatic ischemia of muscle, sequela*/
,'T797XXD'  /*Traumatic subcutaneous emphysema, subsequent encounter*/
,'T797XXS'  /*Traumatic subcutaneous emphysema, sequela*/
,'T79A0XD'  /*Compartment syndrome, unspecified, subsequent encounter*/
,'T79A0XS'  /*Compartment syndrome, unspecified, sequela*/
,'T79A11D'  /*Traumatic compartment syndrome of right upper extremity, subsequent encounter*/
,'T79A11S'  /*Traumatic compartment syndrome of right upper extremity, sequela*/
,'T79A12D'  /*Traumatic compartment syndrome of left upper extremity, subsequent encounter*/
,'T79A12S'  /*Traumatic compartment syndrome of left upper extremity, sequela*/
,'T79A19D'  /*Traumatic compartment syndrome of unspecified upper extremity, subsequent encounter*/
,'T79A19S'  /*Traumatic compartment syndrome of unspecified upper extremity, sequela*/
,'T79A21D'  /*Traumatic compartment syndrome of right lower extremity, subsequent encounter*/
,'T79A21S'  /*Traumatic compartment syndrome of right lower extremity, sequela*/
,'T79A22D'  /*Traumatic compartment syndrome of left lower extremity, subsequent encounter*/
,'T79A22S'  /*Traumatic compartment syndrome of left lower extremity, sequela*/
,'T79A29D'  /*Traumatic compartment syndrome of unspecified lower extremity, subsequent encounter*/
,'T79A29S'  /*Traumatic compartment syndrome of unspecified lower extremity, sequela*/
,'T79A3XD'  /*Traumatic compartment syndrome of abdomen, subsequent encounter*/
,'T79A3XS'  /*Traumatic compartment syndrome of abdomen, sequela*/
,'T79A9XD'  /*Traumatic compartment syndrome of other sites, subsequent encounter*/
,'T79A9XS'  /*Traumatic compartment syndrome of other sites, sequela*/
,'T798XXD'  /*Other early complications of trauma, subsequent encounter*/
,'T798XXS'  /*Other early complications of trauma, sequela*/
,'T799XXD'  /*Unspecified early complication of trauma, subsequent encounter*/
,'T799XXS'  /*Unspecified early complication of trauma, sequela*/
,'T800XXD'  /*Air embolism following infusion, transfusion and therapeutic injection, subsequent encounter*/
,'T800XXS'  /*Air embolism following infusion, transfusion and therapeutic injection, sequela*/
,'T801XXD'  /*Vascular complications following infusion, transfusion and therapeutic injection, subsequent encounter*/
,'T801XXS'  /*Vascular complications following infusion, transfusion and therapeutic injection, sequela*/
,'T80211D'  /*Bloodstream infection due to central venous catheter, subsequent encounter*/
,'T80211S'  /*Bloodstream infection due to central venous catheter, sequela*/
,'T80212D'  /*Local infection due to central venous catheter, subsequent encounter*/
,'T80212S'  /*Local infection due to central venous catheter, sequela*/
,'T80218D'  /*Other infection due to central venous catheter, subsequent encounter*/
,'T80218S'  /*Other infection due to central venous catheter, sequela*/
,'T80219D'  /*Unspecified infection due to central venous catheter, subsequent encounter*/
,'T80219S'  /*Unspecified infection due to central venous catheter, sequela*/
,'T8022XD'  /*Acute infection following transfusion, infusion, or injection of blood and blood products, subsequent encounter*/
,'T8022XS'  /*Acute infection following transfusion, infusion, or injection of blood and blood products, sequela*/
,'T8029XD'  /*Infection following other infusion, transfusion and therapeutic injection, subsequent encounter*/
,'T8029XS'  /*Infection following other infusion, transfusion and therapeutic injection, sequela*/
,'T8030XD'  /*ABO incompatibility reaction due to transfusion of blood or blood products, unspecified, subsequent encounter*/
,'T8030XS'  /*ABO incompatibility reaction due to transfusion of blood or blood products, unspecified, sequela*/
,'T80310D'  /*ABO incompatibility with acute hemolytic transfusion reaction, subsequent encounter*/
,'T80310S'  /*ABO incompatibility with acute hemolytic transfusion reaction, sequela*/
,'T80311D'  /*ABO incompatibility with delayed hemolytic transfusion reaction, subsequent encounter*/
,'T80311S'  /*ABO incompatibility with delayed hemolytic transfusion reaction, sequela*/
,'T80319D'  /*ABO incompatibility with hemolytic transfusion reaction, unspecified, subsequent encounter*/
,'T80319S'  /*ABO incompatibility with hemolytic transfusion reaction, unspecified, sequela*/
,'T8039XD'  /*Other ABO incompatibility reaction due to transfusion of blood or blood products, subsequent encounter*/
,'T8039XS'  /*Other ABO incompatibility reaction due to transfusion of blood or blood products, sequela*/
,'T8040XD'  /*Rh incompatibility reaction due to transfusion of blood or blood products, unspecified, subsequent encounter*/
,'T8040XS'  /*Rh incompatibility reaction due to transfusion of blood or blood products, unspecified, sequela*/
,'T80410D'  /*Rh incompatibility with acute hemolytic transfusion reaction, subsequent encounter*/
,'T80410S'  /*Rh incompatibility with acute hemolytic transfusion reaction, sequela*/
,'T80411D'  /*Rh incompatibility with delayed hemolytic transfusion reaction, subsequent encounter*/
,'T80411S'  /*Rh incompatibility with delayed hemolytic transfusion reaction, sequela*/
,'T80419D'  /*Rh incompatibility with hemolytic transfusion reaction, unspecified, subsequent encounter*/
,'T80419S'  /*Rh incompatibility with hemolytic transfusion reaction, unspecified, sequela*/
,'T8049XD'  /*Other Rh incompatibility reaction due to transfusion of blood or blood products, subsequent encounter*/
,'T8049XS'  /*Other Rh incompatibility reaction due to transfusion of blood or blood products, sequela*/
,'T80A0XD'  /*Non-ABO incompatibility reaction due to transfusion of blood or blood products, unspecified, subsequent encounter*/
,'T80A0XS'  /*Non-ABO incompatibility reaction due to transfusion of blood or blood products, unspecified, sequela*/
,'T80A10D'  /*Non-ABO incompatibility with acute hemolytic transfusion reaction, subsequent encounter*/
,'T80A10S'  /*Non-ABO incompatibility with acute hemolytic transfusion reaction, sequela*/
,'T80A11D'  /*Non-ABO incompatibility with delayed hemolytic transfusion reaction, subsequent encounter*/
,'T80A11S'  /*Non-ABO incompatibility with delayed hemolytic transfusion reaction, sequela*/
,'T80A19D'  /*Non-ABO incompatibility with hemolytic transfusion reaction, unspecified, subsequent encounter*/
,'T80A19S'  /*Non-ABO incompatibility with hemolytic transfusion reaction, unspecified, sequela*/
,'T80A9XD'  /*Other non-ABO incompatibility reaction due to transfusion of blood or blood products, subsequent encounter*/
,'T80A9XS'  /*Other non-ABO incompatibility reaction due to transfusion of blood or blood products, sequela*/
,'T8051XD'  /*Anaphylactic reaction due to administration of blood and blood products, subsequent encounter*/
,'T8051XS'  /*Anaphylactic reaction due to administration of blood and blood products, sequela*/
,'T8052XD'  /*Anaphylactic reaction due to vaccination, subsequent encounter*/
,'T8052XS'  /*Anaphylactic reaction due to vaccination, sequela*/
,'T8059XD'  /*Anaphylactic reaction due to other serum, subsequent encounter*/
,'T8059XS'  /*Anaphylactic reaction due to other serum, sequela*/
,'T8061XD'  /*Other serum reaction due to administration of blood and blood products, subsequent encounter*/
,'T8061XS'  /*Other serum reaction due to administration of blood and blood products, sequela*/
,'T8062XD'  /*Other serum reaction due to vaccination, subsequent encounter*/
,'T8062XS'  /*Other serum reaction due to vaccination, sequela*/
,'T8069XD'  /*Other serum reaction due to other serum, subsequent encounter*/
,'T8069XS'  /*Other serum reaction due to other serum, sequela*/
,'T80810D'  /*Extravasation of vesicant antineoplastic chemotherapy, subsequent encounter*/
,'T80810S'  /*Extravasation of vesicant antineoplastic chemotherapy, sequela*/
,'T80818D'  /*Extravasation of other vesicant agent, subsequent encounter*/
,'T80818S'  /*Extravasation of other vesicant agent, sequela*/
,'T8089XD'  /*Other complications following infusion, transfusion and therapeutic injection, subsequent encounter*/
,'T8089XS'  /*Other complications following infusion, transfusion and therapeutic injection, sequela*/
,'T8090XD'  /*Unspecified complication following infusion and therapeutic injection, subsequent encounter*/
,'T8090XS'  /*Unspecified complication following infusion and therapeutic injection, sequela*/
,'T80910D'  /*Acute hemolytic transfusion reaction, unspecified incompatibility, subsequent encounter*/
,'T80910S'  /*Acute hemolytic transfusion reaction, unspecified incompatibility, sequela*/
,'T80911D'  /*Delayed hemolytic transfusion reaction, unspecified incompatibility, subsequent encounter*/
,'T80911S'  /*Delayed hemolytic transfusion reaction, unspecified incompatibility, sequela*/
,'T80919D'  /*Hemolytic transfusion reaction, unspecified incompatibility, unspecified as acute or delayed, subsequent encounter*/
,'T80919S'  /*Hemolytic transfusion reaction, unspecified incompatibility, unspecified as acute or delayed, sequela*/
,'T8092XD'  /*Unspecified transfusion reaction, subsequent encounter*/
,'T8092XS'  /*Unspecified transfusion reaction, sequela*/
,'T8110XD'  /*Postprocedural shock unspecified, subsequent encounter*/
,'T8110XS'  /*Postprocedural shock unspecified, sequela*/
,'T8111XD'  /*Postprocedural cardiogenic shock, subsequent encounter*/
,'T8111XS'  /*Postprocedural cardiogenic shock, sequela*/
,'T8112XD'  /*Postprocedural septic shock, subsequent encounter*/
,'T8112XS'  /*Postprocedural septic shock, sequela*/
,'T8119XD'  /*Other postprocedural shock, subsequent encounter*/
,'T8119XS'  /*Other postprocedural shock, sequela*/
,'T8130XD'  /*Disruption of wound, unspecified, subsequent encounter*/
,'T8130XS'  /*Disruption of wound, unspecified, sequela*/
,'T8131XD'  /*Disruption of external operation (surgical) wound, not elsewhere classified, subsequent encounter*/
,'T8131XS'  /*Disruption of external operation (surgical) wound, not elsewhere classified, sequela*/
,'T8132XD'  /*Disruption of internal operation (surgical) wound, not elsewhere classified, subsequent encounter*/
,'T8132XS'  /*Disruption of internal operation (surgical) wound, not elsewhere classified, sequela*/
,'T8133XD'  /*Disruption of traumatic injury wound repair, subsequent encounter*/
,'T8133XS'  /*Disruption of traumatic injury wound repair, sequela*/
,'T814XXD'  /*Infection following a procedure, subsequent encounter*/
,'T814XXS'  /*Infection following a procedure, sequela*/
,'T81500D'  /*Unspecified complication of foreign body accidentally left in body following surgical operation, subsequent encounter*/
,'T81500S'  /*Unspecified complication of foreign body accidentally left in body following surgical operation, sequela*/
,'T81501D'  /*Unspecified complication of foreign body accidentally left in body following infusion or transfusion, subsequent encounter*/
,'T81501S'  /*Unspecified complication of foreign body accidentally left in body following infusion or transfusion, sequela*/
,'T81502D'  /*Unspecified complication of foreign body accidentally left in body following kidney dialysis, subsequent encounter*/
,'T81502S'  /*Unspecified complication of foreign body accidentally left in body following kidney dialysis, sequela*/
,'T81503D'  /*Unspecified complication of foreign body accidentally left in body following injection or immunization, subsequent encounter*/
,'T81503S'  /*Unspecified complication of foreign body accidentally left in body following injection or immunization, sequela*/
,'T81504D'  /*Unspecified complication of foreign body accidentally left in body following endoscopic examination, subsequent encounter*/
,'T81504S'  /*Unspecified complication of foreign body accidentally left in body following endoscopic examination, sequela*/
,'T81505D'  /*Unspecified complication of foreign body accidentally left in body following heart catheterization, subsequent encounter*/
,'T81505S'  /*Unspecified complication of foreign body accidentally left in body following heart catheterization, sequela*/
,'T81506D'  /*Unspecified complication of foreign body accidentally left in body following aspiration, puncture or other catheterization, subsequent encounter*/
,'T81506S'  /*Unspecified complication of foreign body accidentally left in body following aspiration, puncture or other catheterization, sequela*/
,'T81507D'  /*Unspecified complication of foreign body accidentally left in body following removal of catheter or packing, subsequent encounter*/
,'T81507S'  /*Unspecified complication of foreign body accidentally left in body following removal of catheter or packing, sequela*/
,'T81508D'  /*Unspecified complication of foreign body accidentally left in body following other procedure, subsequent encounter*/
,'T81508S'  /*Unspecified complication of foreign body accidentally left in body following other procedure, sequela*/
,'T81509D'  /*Unspecified complication of foreign body accidentally left in body following unspecified procedure, subsequent encounter*/
,'T81509S'  /*Unspecified complication of foreign body accidentally left in body following unspecified procedure, sequela*/
,'T81510D'  /*Adhesions due to foreign body accidentally left in body following surgical operation, subsequent encounter*/
,'T81510S'  /*Adhesions due to foreign body accidentally left in body following surgical operation, sequela*/
,'T81511D'  /*Adhesions due to foreign body accidentally left in body following infusion or transfusion, subsequent encounter*/
,'T81511S'  /*Adhesions due to foreign body accidentally left in body following infusion or transfusion, sequela*/
,'T81512D'  /*Adhesions due to foreign body accidentally left in body following kidney dialysis, subsequent encounter*/
,'T81512S'  /*Adhesions due to foreign body accidentally left in body following kidney dialysis, sequela*/
,'T81513D'  /*Adhesions due to foreign body accidentally left in body following injection or immunization, subsequent encounter*/
,'T81513S'  /*Adhesions due to foreign body accidentally left in body following injection or immunization, sequela*/
,'T81514D'  /*Adhesions due to foreign body accidentally left in body following endoscopic examination, subsequent encounter*/
,'T81514S'  /*Adhesions due to foreign body accidentally left in body following endoscopic examination, sequela*/
,'T81515D'  /*Adhesions due to foreign body accidentally left in body following heart catheterization, subsequent encounter*/
,'T81515S'  /*Adhesions due to foreign body accidentally left in body following heart catheterization, sequela*/
,'T81516D'  /*Adhesions due to foreign body accidentally left in body following aspiration, puncture or other catheterization, subsequent encounter*/
,'T81516S'  /*Adhesions due to foreign body accidentally left in body following aspiration, puncture or other catheterization, sequela*/
,'T81517D'  /*Adhesions due to foreign body accidentally left in body following removal of catheter or packing, subsequent encounter*/
,'T81517S'  /*Adhesions due to foreign body accidentally left in body following removal of catheter or packing, sequela*/
,'T81518D'  /*Adhesions due to foreign body accidentally left in body following other procedure, subsequent encounter*/
,'T81518S'  /*Adhesions due to foreign body accidentally left in body following other procedure, sequela*/
,'T81519D'  /*Adhesions due to foreign body accidentally left in body following unspecified procedure, subsequent encounter*/
,'T81519S'  /*Adhesions due to foreign body accidentally left in body following unspecified procedure, sequela*/
,'T81520D'  /*Obstruction due to foreign body accidentally left in body following surgical operation, subsequent encounter*/
,'T81520S'  /*Obstruction due to foreign body accidentally left in body following surgical operation, sequela*/
,'T81521D'  /*Obstruction due to foreign body accidentally left in body following infusion or transfusion, subsequent encounter*/
,'T81521S'  /*Obstruction due to foreign body accidentally left in body following infusion or transfusion, sequela*/
,'T81522D'  /*Obstruction due to foreign body accidentally left in body following kidney dialysis, subsequent encounter*/
,'T81522S'  /*Obstruction due to foreign body accidentally left in body following kidney dialysis, sequela*/
,'T81523D'  /*Obstruction due to foreign body accidentally left in body following injection or immunization, subsequent encounter*/
,'T81523S'  /*Obstruction due to foreign body accidentally left in body following injection or immunization, sequela*/
,'T81524D'  /*Obstruction due to foreign body accidentally left in body following endoscopic examination, subsequent encounter*/
,'T81524S'  /*Obstruction due to foreign body accidentally left in body following endoscopic examination, sequela*/
,'T81525D'  /*Obstruction due to foreign body accidentally left in body following heart catheterization, subsequent encounter*/
,'T81525S'  /*Obstruction due to foreign body accidentally left in body following heart catheterization, sequela*/
,'T81526D'  /*Obstruction due to foreign body accidentally left in body following aspiration, puncture or other catheterization, subsequent encounter*/
,'T81526S'  /*Obstruction due to foreign body accidentally left in body following aspiration, puncture or other catheterization, sequela*/
,'T81527D'  /*Obstruction due to foreign body accidentally left in body following removal of catheter or packing, subsequent encounter*/
,'T81527S'  /*Obstruction due to foreign body accidentally left in body following removal of catheter or packing, sequela*/
,'T81528D'  /*Obstruction due to foreign body accidentally left in body following other procedure, subsequent encounter*/
,'T81528S'  /*Obstruction due to foreign body accidentally left in body following other procedure, sequela*/
,'T81529D'  /*Obstruction due to foreign body accidentally left in body following unspecified procedure, subsequent encounter*/
,'T81529S'  /*Obstruction due to foreign body accidentally left in body following unspecified procedure, sequela*/
,'T81530D'  /*Perforation due to foreign body accidentally left in body following surgical operation, subsequent encounter*/
,'T81530S'  /*Perforation due to foreign body accidentally left in body following surgical operation, sequela*/
,'T81531D'  /*Perforation due to foreign body accidentally left in body following infusion or transfusion, subsequent encounter*/
,'T81531S'  /*Perforation due to foreign body accidentally left in body following infusion or transfusion, sequela*/
,'T81532D'  /*Perforation due to foreign body accidentally left in body following kidney dialysis, subsequent encounter*/
,'T81532S'  /*Perforation due to foreign body accidentally left in body following kidney dialysis, sequela*/
,'T81533D'  /*Perforation due to foreign body accidentally left in body following injection or immunization, subsequent encounter*/
,'T81533S'  /*Perforation due to foreign body accidentally left in body following injection or immunization, sequela*/
,'T81534D'  /*Perforation due to foreign body accidentally left in body following endoscopic examination, subsequent encounter*/
,'T81534S'  /*Perforation due to foreign body accidentally left in body following endoscopic examination, sequela*/
,'T81535D'  /*Perforation due to foreign body accidentally left in body following heart catheterization, subsequent encounter*/
,'T81535S'  /*Perforation due to foreign body accidentally left in body following heart catheterization, sequela*/
,'T81536D'  /*Perforation due to foreign body accidentally left in body following aspiration, puncture or other catheterization, subsequent encounter*/
,'T81536S'  /*Perforation due to foreign body accidentally left in body following aspiration, puncture or other catheterization, sequela*/
,'T81537D'  /*Perforation due to foreign body accidentally left in body following removal of catheter or packing, subsequent encounter*/
,'T81537S'  /*Perforation due to foreign body accidentally left in body following removal of catheter or packing, sequela*/
,'T81538D'  /*Perforation due to foreign body accidentally left in body following other procedure, subsequent encounter*/
,'T81538S'  /*Perforation due to foreign body accidentally left in body following other procedure, sequela*/
,'T81539D'  /*Perforation due to foreign body accidentally left in body following unspecified procedure, subsequent encounter*/
,'T81539S'  /*Perforation due to foreign body accidentally left in body following unspecified procedure, sequela*/
,'T81590D'  /*Other complications of foreign body accidentally left in body following surgical operation, subsequent encounter*/
,'T81590S'  /*Other complications of foreign body accidentally left in body following surgical operation, sequela*/
,'T81591D'  /*Other complications of foreign body accidentally left in body following infusion or transfusion, subsequent encounter*/
,'T81591S'  /*Other complications of foreign body accidentally left in body following infusion or transfusion, sequela*/
,'T81592D'  /*Other complications of foreign body accidentally left in body following kidney dialysis, subsequent encounter*/
,'T81592S'  /*Other complications of foreign body accidentally left in body following kidney dialysis, sequela*/
,'T81593D'  /*Other complications of foreign body accidentally left in body following injection or immunization, subsequent encounter*/
,'T81593S'  /*Other complications of foreign body accidentally left in body following injection or immunization, sequela*/
,'T81594D'  /*Other complications of foreign body accidentally left in body following endoscopic examination, subsequent encounter*/
,'T81594S'  /*Other complications of foreign body accidentally left in body following endoscopic examination, sequela*/
,'T81595D'  /*Other complications of foreign body accidentally left in body following heart catheterization, subsequent encounter*/
,'T81595S'  /*Other complications of foreign body accidentally left in body following heart catheterization, sequela*/
,'T81596D'  /*Other complications of foreign body accidentally left in body following aspiration, puncture or other catheterization, subsequent encounter*/
,'T81596S'  /*Other complications of foreign body accidentally left in body following aspiration, puncture or other catheterization, sequela*/
,'T81597D'  /*Other complications of foreign body accidentally left in body following removal of catheter or packing, subsequent encounter*/
,'T81597S'  /*Other complications of foreign body accidentally left in body following removal of catheter or packing, sequela*/
,'T81598D'  /*Other complications of foreign body accidentally left in body following other procedure, subsequent encounter*/
,'T81598S'  /*Other complications of foreign body accidentally left in body following other procedure, sequela*/
,'T81599D'  /*Other complications of foreign body accidentally left in body following unspecified procedure, subsequent encounter*/
,'T81599S'  /*Other complications of foreign body accidentally left in body following unspecified procedure, sequela*/
,'T8160XD'  /*Unspecified acute reaction to foreign substance accidentally left during a procedure, subsequent encounter*/
,'T8160XS'  /*Unspecified acute reaction to foreign substance accidentally left during a procedure, sequela*/
,'T8161XD'  /*Aseptic peritonitis due to foreign substance accidentally left during a procedure, subsequent encounter*/
,'T8161XS'  /*Aseptic peritonitis due to foreign substance accidentally left during a procedure, sequela*/
,'T8169XD'  /*Other acute reaction to foreign substance accidentally left during a procedure, subsequent encounter*/
,'T8169XS'  /*Other acute reaction to foreign substance accidentally left during a procedure, sequela*/
,'T81710D'  /*Complication of mesenteric artery following a procedure, not elsewhere classified, subsequent encounter*/
,'T81710S'  /*Complication of mesenteric artery following a procedure, not elsewhere classified, sequela*/
,'T81711D'  /*Complication of renal artery following a procedure, not elsewhere classified, subsequent encounter*/
,'T81711S'  /*Complication of renal artery following a procedure, not elsewhere classified, sequela*/
,'T81718D'  /*Complication of other artery following a procedure, not elsewhere classified, subsequent encounter*/
,'T81718S'  /*Complication of other artery following a procedure, not elsewhere classified, sequela*/
,'T81719D'  /*Complication of unspecified artery following a procedure, not elsewhere classified, subsequent encounter*/
,'T81719S'  /*Complication of unspecified artery following a procedure, not elsewhere classified, sequela*/
,'T8172XD'  /*Complication of vein following a procedure, not elsewhere classified, subsequent encounter*/
,'T8172XS'  /*Complication of vein following a procedure, not elsewhere classified, sequela*/
,'T8181XD'  /*Complication of inhalation therapy, subsequent encounter*/
,'T8181XS'  /*Complication of inhalation therapy, sequela*/
,'T8182XD'  /*Emphysema (subcutaneous) resulting from a procedure, subsequent encounter*/
,'T8182XS'  /*Emphysema (subcutaneous) resulting from a procedure, sequela*/
,'T8183XD'  /*Persistent postprocedural fistula, subsequent encounter*/
,'T8183XS'  /*Persistent postprocedural fistula, sequela*/
,'T8189XD'  /*Other complications of procedures, not elsewhere classified, subsequent encounter*/
,'T8189XS'  /*Other complications of procedures, not elsewhere classified, sequela*/
,'T819XXD'  /*Unspecified complication of procedure, subsequent encounter*/
,'T819XXS'  /*Unspecified complication of procedure, sequela*/
,'T8201XD'  /*Breakdown (mechanical) of heart valve prosthesis, subsequent encounter*/
,'T8201XS'  /*Breakdown (mechanical) of heart valve prosthesis, sequela*/
,'T8202XD'  /*Displacement of heart valve prosthesis, subsequent encounter*/
,'T8202XS'  /*Displacement of heart valve prosthesis, sequela*/
,'T8203XD'  /*Leakage of heart valve prosthesis, subsequent encounter*/
,'T8203XS'  /*Leakage of heart valve prosthesis, sequela*/
,'T8209XD'  /*Other mechanical complication of heart valve prosthesis, subsequent encounter*/
,'T8209XS'  /*Other mechanical complication of heart valve prosthesis, sequela*/
,'T82110D'  /*Breakdown (mechanical) of cardiac electrode, subsequent encounter*/
,'T82110S'  /*Breakdown (mechanical) of cardiac electrode, sequela*/
,'T82111D'  /*Breakdown (mechanical) of cardiac pulse generator (battery), subsequent encounter*/
,'T82111S'  /*Breakdown (mechanical) of cardiac pulse generator (battery), sequela*/
,'T82118D'  /*Breakdown (mechanical) of other cardiac electronic device, subsequent encounter*/
,'T82118S'  /*Breakdown (mechanical) of other cardiac electronic device, sequela*/
,'T82119D'  /*Breakdown (mechanical) of unspecified cardiac electronic device, subsequent encounter*/
,'T82119S'  /*Breakdown (mechanical) of unspecified cardiac electronic device, sequela*/
,'T82120D'  /*Displacement of cardiac electrode, subsequent encounter*/
,'T82120S'  /*Displacement of cardiac electrode, sequela*/
,'T82121D'  /*Displacement of cardiac pulse generator (battery), subsequent encounter*/
,'T82121S'  /*Displacement of cardiac pulse generator (battery), sequela*/
,'T82128D'  /*Displacement of other cardiac electronic device, subsequent encounter*/
,'T82128S'  /*Displacement of other cardiac electronic device, sequela*/
,'T82129D'  /*Displacement of unspecified cardiac electronic device, subsequent encounter*/
,'T82129S'  /*Displacement of unspecified cardiac electronic device, sequela*/
,'T82190D'  /*Other mechanical complication of cardiac electrode, subsequent encounter*/
,'T82190S'  /*Other mechanical complication of cardiac electrode, sequela*/
,'T82191D'  /*Other mechanical complication of cardiac pulse generator (battery), subsequent encounter*/
,'T82191S'  /*Other mechanical complication of cardiac pulse generator (battery), sequela*/
,'T82198D'  /*Other mechanical complication of other cardiac electronic device, subsequent encounter*/
,'T82198S'  /*Other mechanical complication of other cardiac electronic device, sequela*/
,'T82199D'  /*Other mechanical complication of unspecified cardiac device, subsequent encounter*/
,'T82199S'  /*Other mechanical complication of unspecified cardiac device, sequela*/
,'T82211D'  /*Breakdown (mechanical) of coronary artery bypass graft, subsequent encounter*/
,'T82211S'  /*Breakdown (mechanical) of coronary artery bypass graft, sequela*/
,'T82212D'  /*Displacement of coronary artery bypass graft, subsequent encounter*/
,'T82212S'  /*Displacement of coronary artery bypass graft, sequela*/
,'T82213D'  /*Leakage of coronary artery bypass graft, subsequent encounter*/
,'T82213S'  /*Leakage of coronary artery bypass graft, sequela*/
,'T82218D'  /*Other mechanical complication of coronary artery bypass graft, subsequent encounter*/
,'T82218S'  /*Other mechanical complication of coronary artery bypass graft, sequela*/
,'T82221D'  /*Breakdown (mechanical) of biological heart valve graft, subsequent encounter*/
,'T82221S'  /*Breakdown (mechanical) of biological heart valve graft, sequela*/
,'T82222D'  /*Displacement of biological heart valve graft, subsequent encounter*/
,'T82222S'  /*Displacement of biological heart valve graft, sequela*/
,'T82223D'  /*Leakage of biological heart valve graft, subsequent encounter*/
,'T82223S'  /*Leakage of biological heart valve graft, sequela*/
,'T82228D'  /*Other mechanical complication of biological heart valve graft, subsequent encounter*/
,'T82228S'  /*Other mechanical complication of biological heart valve graft, sequela*/
,'T82310D'  /*Breakdown (mechanical) of aortic (bifurcation) graft (replacement), subsequent encounter*/
,'T82310S'  /*Breakdown (mechanical) of aortic (bifurcation) graft (replacement), sequela*/
,'T82311D'  /*Breakdown (mechanical) of carotid arterial graft (bypass), subsequent encounter*/
,'T82311S'  /*Breakdown (mechanical) of carotid arterial graft (bypass), sequela*/
,'T82312D'  /*Breakdown (mechanical) of femoral arterial graft (bypass), subsequent encounter*/
,'T82312S'  /*Breakdown (mechanical) of femoral arterial graft (bypass), sequela*/
,'T82318D'  /*Breakdown (mechanical) of other vascular grafts, subsequent encounter*/
,'T82318S'  /*Breakdown (mechanical) of other vascular grafts, sequela*/
,'T82319D'  /*Breakdown (mechanical) of unspecified vascular grafts, subsequent encounter*/
,'T82319S'  /*Breakdown (mechanical) of unspecified vascular grafts, sequela*/
,'T82320D'  /*Displacement of aortic (bifurcation) graft (replacement), subsequent encounter*/
,'T82320S'  /*Displacement of aortic (bifurcation) graft (replacement), sequela*/
,'T82321D'  /*Displacement of carotid arterial graft (bypass), subsequent encounter*/
,'T82321S'  /*Displacement of carotid arterial graft (bypass), sequela*/
,'T82322D'  /*Displacement of femoral arterial graft (bypass), subsequent encounter*/
,'T82322S'  /*Displacement of femoral arterial graft (bypass), sequela*/
,'T82328D'  /*Displacement of other vascular grafts, subsequent encounter*/
,'T82328S'  /*Displacement of other vascular grafts, sequela*/
,'T82329D'  /*Displacement of unspecified vascular grafts, subsequent encounter*/
,'T82329S'  /*Displacement of unspecified vascular grafts, sequela*/
,'T82330D'  /*Leakage of aortic (bifurcation) graft (replacement), subsequent encounter*/
,'T82330S'  /*Leakage of aortic (bifurcation) graft (replacement), sequela*/
,'T82331D'  /*Leakage of carotid arterial graft (bypass), subsequent encounter*/
,'T82331S'  /*Leakage of carotid arterial graft (bypass), sequela*/
,'T82332D'  /*Leakage of femoral arterial graft (bypass), subsequent encounter*/
,'T82332S'  /*Leakage of femoral arterial graft (bypass), sequela*/
,'T82338D'  /*Leakage of other vascular grafts, subsequent encounter*/
,'T82338S'  /*Leakage of other vascular grafts, sequela*/
,'T82339D'  /*Leakage of unspecified vascular graft, subsequent encounter*/
,'T82339S'  /*Leakage of unspecified vascular graft, sequela*/
,'T82390D'  /*Other mechanical complication of aortic (bifurcation) graft (replacement), subsequent encounter*/
,'T82390S'  /*Other mechanical complication of aortic (bifurcation) graft (replacement), sequela*/
,'T82391D'  /*Other mechanical complication of carotid arterial graft (bypass), subsequent encounter*/
,'T82391S'  /*Other mechanical complication of carotid arterial graft (bypass), sequela*/
,'T82392D'  /*Other mechanical complication of femoral arterial graft (bypass), subsequent encounter*/
,'T82392S'  /*Other mechanical complication of femoral arterial graft (bypass), sequela*/
,'T82398D'  /*Other mechanical complication of other vascular grafts, subsequent encounter*/
,'T82398S'  /*Other mechanical complication of other vascular grafts, sequela*/
,'T82399D'  /*Other mechanical complication of unspecified vascular grafts, subsequent encounter*/
,'T82399S'  /*Other mechanical complication of unspecified vascular grafts, sequela*/
,'T8241XD'  /*Breakdown (mechanical) of vascular dialysis catheter, subsequent encounter*/
,'T8241XS'  /*Breakdown (mechanical) of vascular dialysis catheter, sequela*/
,'T8242XD'  /*Displacement of vascular dialysis catheter, subsequent encounter*/
,'T8242XS'  /*Displacement of vascular dialysis catheter, sequela*/
,'T8243XD'  /*Leakage of vascular dialysis catheter, subsequent encounter*/
,'T8243XS'  /*Leakage of vascular dialysis catheter, sequela*/
,'T8249XD'  /*Other complication of vascular dialysis catheter, subsequent encounter*/
,'T8249XS'  /*Other complication of vascular dialysis catheter, sequela*/
,'T82510D'  /*Breakdown (mechanical) of surgically created arteriovenous fistula, subsequent encounter*/
,'T82510S'  /*Breakdown (mechanical) of surgically created arteriovenous fistula, sequela*/
,'T82511D'  /*Breakdown (mechanical) of surgically created arteriovenous shunt, subsequent encounter*/
,'T82511S'  /*Breakdown (mechanical) of surgically created arteriovenous shunt, sequela*/
,'T82512D'  /*Breakdown (mechanical) of artificial heart, subsequent encounter*/
,'T82512S'  /*Breakdown (mechanical) of artificial heart, sequela*/
,'T82513D'  /*Breakdown (mechanical) of balloon (counterpulsation) device, subsequent encounter*/
,'T82513S'  /*Breakdown (mechanical) of balloon (counterpulsation) device, sequela*/
,'T82514D'  /*Breakdown (mechanical) of infusion catheter, subsequent encounter*/
,'T82514S'  /*Breakdown (mechanical) of infusion catheter, sequela*/
,'T82515D'  /*Breakdown (mechanical) of umbrella device, subsequent encounter*/
,'T82515S'  /*Breakdown (mechanical) of umbrella device, sequela*/
,'T82518D'  /*Breakdown (mechanical) of other cardiac and vascular devices and implants, subsequent encounter*/
,'T82518S'  /*Breakdown (mechanical) of other cardiac and vascular devices and implants, sequela*/
,'T82519D'  /*Breakdown (mechanical) of unspecified cardiac and vascular devices and implants, subsequent encounter*/
,'T82519S'  /*Breakdown (mechanical) of unspecified cardiac and vascular devices and implants, sequela*/
,'T82520D'  /*Displacement of surgically created arteriovenous fistula, subsequent encounter*/
,'T82520S'  /*Displacement of surgically created arteriovenous fistula, sequela*/
,'T82521D'  /*Displacement of surgically created arteriovenous shunt, subsequent encounter*/
,'T82521S'  /*Displacement of surgically created arteriovenous shunt, sequela*/
,'T82522D'  /*Displacement of artificial heart, subsequent encounter*/
,'T82522S'  /*Displacement of artificial heart, sequela*/
,'T82523D'  /*Displacement of balloon (counterpulsation) device, subsequent encounter*/
,'T82523S'  /*Displacement of balloon (counterpulsation) device, sequela*/
,'T82524D'  /*Displacement of infusion catheter, subsequent encounter*/
,'T82524S'  /*Displacement of infusion catheter, sequela*/
,'T82525D'  /*Displacement of umbrella device, subsequent encounter*/
,'T82525S'  /*Displacement of umbrella device, sequela*/
,'T82528D'  /*Displacement of other cardiac and vascular devices and implants, subsequent encounter*/
,'T82528S'  /*Displacement of other cardiac and vascular devices and implants, sequela*/
,'T82529D'  /*Displacement of unspecified cardiac and vascular devices and implants, subsequent encounter*/
,'T82529S'  /*Displacement of unspecified cardiac and vascular devices and implants, sequela*/
,'T82530D'  /*Leakage of surgically created arteriovenous fistula, subsequent encounter*/
,'T82530S'  /*Leakage of surgically created arteriovenous fistula, sequela*/
,'T82531D'  /*Leakage of surgically created arteriovenous shunt, subsequent encounter*/
,'T82531S'  /*Leakage of surgically created arteriovenous shunt, sequela*/
,'T82532D'  /*Leakage of artificial heart, subsequent encounter*/
,'T82532S'  /*Leakage of artificial heart, sequela*/
,'T82533D'  /*Leakage of balloon (counterpulsation) device, subsequent encounter*/
,'T82533S'  /*Leakage of balloon (counterpulsation) device, sequela*/
,'T82534D'  /*Leakage of infusion catheter, subsequent encounter*/
,'T82534S'  /*Leakage of infusion catheter, sequela*/
,'T82535D'  /*Leakage of umbrella device, subsequent encounter*/
,'T82535S'  /*Leakage of umbrella device, sequela*/
,'T82538D'  /*Leakage of other cardiac and vascular devices and implants, subsequent encounter*/
,'T82538S'  /*Leakage of other cardiac and vascular devices and implants, sequela*/
,'T82539D'  /*Leakage of unspecified cardiac and vascular devices and implants, subsequent encounter*/
,'T82539S'  /*Leakage of unspecified cardiac and vascular devices and implants, sequela*/
,'T82590D'  /*Other mechanical complication of surgically created arteriovenous fistula, subsequent encounter*/
,'T82590S'  /*Other mechanical complication of surgically created arteriovenous fistula, sequela*/
,'T82591D'  /*Other mechanical complication of surgically created arteriovenous shunt, subsequent encounter*/
,'T82591S'  /*Other mechanical complication of surgically created arteriovenous shunt, sequela*/
,'T82592D'  /*Other mechanical complication of artificial heart, subsequent encounter*/
,'T82592S'  /*Other mechanical complication of artificial heart, sequela*/
,'T82593D'  /*Other mechanical complication of balloon (counterpulsation) device, subsequent encounter*/
,'T82593S'  /*Other mechanical complication of balloon (counterpulsation) device, sequela*/
,'T82594D'  /*Other mechanical complication of infusion catheter, subsequent encounter*/
,'T82594S'  /*Other mechanical complication of infusion catheter, sequela*/
,'T82595D'  /*Other mechanical complication of umbrella device, subsequent encounter*/
,'T82595S'  /*Other mechanical complication of umbrella device, sequela*/
,'T82598D'  /*Other mechanical complication of other cardiac and vascular devices and implants, subsequent encounter*/
,'T82598S'  /*Other mechanical complication of other cardiac and vascular devices and implants, sequela*/
,'T82599D'  /*Other mechanical complication of unspecified cardiac and vascular devices and implants, subsequent encounter*/
,'T82599S'  /*Other mechanical complication of unspecified cardiac and vascular devices and implants, sequela*/
,'T826XXD'  /*Infection and inflammatory reaction due to cardiac valve prosthesis, subsequent encounter*/
,'T826XXS'  /*Infection and inflammatory reaction due to cardiac valve prosthesis, sequela*/
,'T827XXD'  /*Infection and inflammatory reaction due to other cardiac and vascular devices, implants and grafts, subsequent encounter*/
,'T827XXS'  /*Infection and inflammatory reaction due to other cardiac and vascular devices, implants and grafts, sequela*/
,'T82817D'  /*Embolism due to cardiac prosthetic devices, implants and grafts, subsequent encounter*/
,'T82817S'  /*Embolism due to cardiac prosthetic devices, implants and grafts, sequela*/
,'T82818D'  /*Embolism due to vascular prosthetic devices, implants and grafts, subsequent encounter*/
,'T82818S'  /*Embolism due to vascular prosthetic devices, implants and grafts, sequela*/
,'T82827D'  /*Fibrosis due to cardiac prosthetic devices, implants and grafts, subsequent encounter*/
,'T82827S'  /*Fibrosis due to cardiac prosthetic devices, implants and grafts, sequela*/
,'T82828D'  /*Fibrosis due to vascular prosthetic devices, implants and grafts, subsequent encounter*/
,'T82828S'  /*Fibrosis due to vascular prosthetic devices, implants and grafts, sequela*/
,'T82837D'  /*Hemorrhage due to cardiac prosthetic devices, implants and grafts, subsequent encounter*/
,'T82837S'  /*Hemorrhage due to cardiac prosthetic devices, implants and grafts, sequela*/
,'T82838D'  /*Hemorrhage due to vascular prosthetic devices, implants and grafts, subsequent encounter*/
,'T82838S'  /*Hemorrhage due to vascular prosthetic devices, implants and grafts, sequela*/
,'T82847D'  /*Pain due to cardiac prosthetic devices, implants and grafts, subsequent encounter*/
,'T82847S'  /*Pain due to cardiac prosthetic devices, implants and grafts, sequela*/
,'T82848D'  /*Pain due to vascular prosthetic devices, implants and grafts, subsequent encounter*/
,'T82848S'  /*Pain due to vascular prosthetic devices, implants and grafts, sequela*/
,'T82855D'  /*Stenosis of coronary artery stent, subsequent encounter*/
,'T82855S'  /*Stenosis of coronary artery stent, sequela*/
,'T82856D'  /*Stenosis of peripheral vascular stent, subsequent encounter*/
,'T82856S'  /*Stenosis of peripheral vascular stent, sequela*/
,'T82857D'  /*Stenosis of other cardiac prosthetic, subsequent encounter*/
,'T82857S'  /*Stenosis of other cardiac prosthetic, sequela*/
,'T82858D'  /*Stenosis of other vascular prosthetic, subsequent encounter*/
,'T82858S'  /*Stenosis of other vascular prosthetic, sequela*/
,'T82867D'  /*Thrombosis due to cardiac prosthetic devices, implants and grafts, subsequent encounter*/
,'T82867S'  /*Thrombosis due to cardiac prosthetic devices, implants and grafts, sequela*/
,'T82868D'  /*Thrombosis due to vascular prosthetic devices, implants and grafts, subsequent encounter*/
,'T82868S'  /*Thrombosis due to vascular prosthetic devices, implants and grafts, sequela*/
,'T82897D'  /*Other specified complication of cardiac prosthetic devices, implants and grafts, subsequent encounter*/
,'T82897S'  /*Other specified complication of cardiac prosthetic devices, implants and grafts, sequela*/
,'T82898D'  /*Other specified complication of vascular prosthetic devices, implants and grafts, subsequent encounter*/
,'T82898S'  /*Other specified complication of vascular prosthetic devices, implants and grafts, sequela*/
,'T829XXD'  /*Unspecified complication of cardiac and vascular prosthetic device, implant and graft, subsequent encounter*/
,'T829XXS'  /*Unspecified complication of cardiac and vascular prosthetic device, implant and graft, sequela*/
,'T83010D'  /*Breakdown (mechanical) of cystostomy catheter, subsequent encounter*/
,'T83010S'  /*Breakdown (mechanical) of cystostomy catheter, sequela*/
,'T83011D'  /*Breakdown (mechanical) of indwelling urethral catheter, subsequent encounter*/
,'T83011S'  /*Breakdown (mechanical) of indwelling urethral catheter, sequela*/
,'T83012D'  /*Breakdown (mechanical) of nephrostomy catheter, subsequent encounter*/
,'T83012S'  /*Breakdown (mechanical) of nephrostomy catheter, sequela*/
,'T83018D'  /*Breakdown (mechanical) of other urinary catheter, subsequent encounter*/
,'T83018S'  /*Breakdown (mechanical) of other urinary catheter, sequela*/
,'T83020D'  /*Displacement of cystostomy catheter, subsequent encounter*/
,'T83020S'  /*Displacement of cystostomy catheter, sequela*/
,'T83021D'  /*Displacement of indwelling urethral catheter, subsequent encounter*/
,'T83021S'  /*Displacement of indwelling urethral catheter, sequela*/
,'T83022D'  /*Displacement of nephrostomy catheter, subsequent encounter*/
,'T83022S'  /*Displacement of nephrostomy catheter, sequela*/
,'T83028D'  /*Displacement of other urinary catheter, subsequent encounter*/
,'T83028S'  /*Displacement of other urinary catheter, sequela*/
,'T83030D'  /*Leakage of cystostomy catheter, subsequent encounter*/
,'T83030S'  /*Leakage of cystostomy catheter, sequela*/
,'T83031D'  /*Leakage of indwelling urethral catheter, subsequent encounter*/
,'T83031S'  /*Leakage of indwelling urethral catheter, sequela*/
,'T83032D'  /*Leakage of nephrostomy catheter, subsequent encounter*/
,'T83032S'  /*Leakage of nephrostomy catheter, sequela*/
,'T83038D'  /*Leakage of other urinary catheter, subsequent encounter*/
,'T83038S'  /*Leakage of other urinary catheter, sequela*/
,'T83090D'  /*Other mechanical complication of cystostomy catheter, subsequent encounter*/
,'T83090S'  /*Other mechanical complication of cystostomy catheter, sequela*/
,'T83091D'  /*Other mechanical complication of indwelling urethral catheter, subsequent encounter*/
,'T83091S'  /*Other mechanical complication of indwelling urethral catheter, sequela*/
,'T83092D'  /*Other mechanical complication of nephrostomy catheter, subsequent encounter*/
,'T83092S'  /*Other mechanical complication of nephrostomy catheter, sequela*/
,'T83098D'  /*Other mechanical complication of other urinary catheter, subsequent encounter*/
,'T83098S'  /*Other mechanical complication of other urinary catheter, sequela*/
,'T83110D'  /*Breakdown (mechanical) of urinary electronic stimulator device, subsequent encounter*/
,'T83110S'  /*Breakdown (mechanical) of urinary electronic stimulator device, sequela*/
,'T83111D'  /*Breakdown (mechanical) of implanted urinary sphincter, subsequent encounter*/
,'T83111S'  /*Breakdown (mechanical) of implanted urinary sphincter, sequela*/
,'T83112D'  /*Breakdown (mechanical) of indwelling ureteral stent, subsequent encounter*/
,'T83112S'  /*Breakdown (mechanical) of indwelling ureteral stent, sequela*/
,'T83118D'  /*Breakdown (mechanical) of other urinary devices and implants, subsequent encounter*/
,'T83118S'  /*Breakdown (mechanical) of other urinary devices and implants, sequela*/
,'T83120D'  /*Displacement of urinary electronic stimulator device, subsequent encounter*/
,'T83120S'  /*Displacement of urinary electronic stimulator device, sequela*/
,'T83121D'  /*Displacement of implanted urinary sphincter, subsequent encounter*/
,'T83121S'  /*Displacement of implanted urinary sphincter, sequela*/
,'T83122D'  /*Displacement of indwelling ureteral stent, subsequent encounter*/
,'T83122S'  /*Displacement of indwelling ureteral stent, sequela*/
,'T83128D'  /*Displacement of other urinary devices and implants, subsequent encounter*/
,'T83128S'  /*Displacement of other urinary devices and implants, sequela*/
,'T83190D'  /*Other mechanical complication of urinary electronic stimulator device, subsequent encounter*/
,'T83190S'  /*Other mechanical complication of urinary electronic stimulator device, sequela*/
,'T83191D'  /*Other mechanical complication of implanted urinary sphincter, subsequent encounter*/
,'T83191S'  /*Other mechanical complication of implanted urinary sphincter, sequela*/
,'T83192D'  /*Other mechanical complication of indwelling ureteral stent, subsequent encounter*/
,'T83192S'  /*Other mechanical complication of indwelling ureteral stent, sequela*/
,'T83193D'  /*Other mechanical complication of other urinary stent, subsequent encounter*/
,'T83193S'  /*Other mechanical complication of other urinary stent, sequela*/
,'T83198D'  /*Other mechanical complication of other urinary devices and implants, subsequent encounter*/
,'T83198S'  /*Other mechanical complication of other urinary devices and implants, sequela*/
,'T8321XD'  /*Breakdown (mechanical) of graft of urinary organ, subsequent encounter*/
,'T8321XS'  /*Breakdown (mechanical) of graft of urinary organ, sequela*/
,'T8322XD'  /*Displacement of graft of urinary organ, subsequent encounter*/
,'T8322XS'  /*Displacement of graft of urinary organ, sequela*/
,'T8323XD'  /*Leakage of graft of urinary organ, subsequent encounter*/
,'T8323XS'  /*Leakage of graft of urinary organ, sequela*/
,'T8324XD'  /*Erosion of graft of urinary organ, subsequent encounter*/
,'T8324XS'  /*Erosion of graft of urinary organ, sequela*/
,'T8325XD'  /*Exposure of graft of urinary organ, subsequent encounter*/
,'T8325XS'  /*Exposure of graft of urinary organ, sequela*/
,'T8329XD'  /*Other mechanical complication of graft of urinary organ, subsequent encounter*/
,'T8329XS'  /*Other mechanical complication of graft of urinary organ, sequela*/
,'T8331XD'  /*Breakdown (mechanical) of intrauterine contraceptive device, subsequent encounter*/
,'T8331XS'  /*Breakdown (mechanical) of intrauterine contraceptive device, sequela*/
,'T8332XD'  /*Displacement of intrauterine contraceptive device, subsequent encounter*/
,'T8332XS'  /*Displacement of intrauterine contraceptive device, sequela*/
,'T8339XD'  /*Other mechanical complication of intrauterine contraceptive device, subsequent encounter*/
,'T8339XS'  /*Other mechanical complication of intrauterine contraceptive device, sequela*/
,'T83410D'  /*Breakdown (mechanical) of implanted penile prosthesis, subsequent encounter*/
,'T83410S'  /*Breakdown (mechanical) of implanted penile prosthesis, sequela*/
,'T83411D'  /*Breakdown (mechanical) of implanted testicular prosthesis, subsequent encounter*/
,'T83411S'  /*Breakdown (mechanical) of implanted testicular prosthesis, sequela*/
,'T83418D'  /*Breakdown (mechanical) of other prosthetic devices, implants and grafts of genital tract, subsequent encounter*/
,'T83418S'  /*Breakdown (mechanical) of other prosthetic devices, implants and grafts of genital tract, sequela*/
,'T83420D'  /*Displacement of implanted penile prosthesis, subsequent encounter*/
,'T83420S'  /*Displacement of implanted penile prosthesis, sequela*/
,'T83421D'  /*Displacement of implanted testicular prosthesis, subsequent encounter*/
,'T83421S'  /*Displacement of implanted testicular prosthesis, sequela*/
,'T83428D'  /*Displacement of other prosthetic devices, implants and grafts of genital tract, subsequent encounter*/
,'T83428S'  /*Displacement of other prosthetic devices, implants and grafts of genital tract, sequela*/
,'T83490D'  /*Other mechanical complication of implanted penile prosthesis, subsequent encounter*/
,'T83490S'  /*Other mechanical complication of implanted penile prosthesis, sequela*/
,'T83491D'  /*Other mechanical complication of implanted testicular prosthesis, subsequent encounter*/
,'T83491S'  /*Other mechanical complication of implanted testicular prosthesis, sequela*/
,'T83498D'  /*Other mechanical complication of other prosthetic devices, implants and grafts of genital tract, subsequent encounter*/
,'T83498S'  /*Other mechanical complication of other prosthetic devices, implants and grafts of genital tract, sequela*/
,'T83510D'  /*Infection and inflammatory reaction due to cystostomy catheter, subsequent encounter*/
,'T83510S'  /*Infection and inflammatory reaction due to cystostomy catheter, sequela*/
,'T83511D'  /*Infection and inflammatory reaction due to indwelling urethral catheter, subsequent encounter*/
,'T83511S'  /*Infection and inflammatory reaction due to indwelling urethral catheter, sequela*/
,'T83512D'  /*Infection and inflammatory reaction due to nephrostomy catheter, subsequent encounter*/
,'T83512S'  /*Infection and inflammatory reaction due to nephrostomy catheter, sequela*/
,'T83518D'  /*Infection and inflammatory reaction due to other urinary catheter, subsequent encounter*/
,'T83518S'  /*Infection and inflammatory reaction due to other urinary catheter, sequela*/
,'T83590D'  /*Infection and inflammatory reaction due to implanted urinary neurostimulation device, subsequent encounter*/
,'T83590S'  /*Infection and inflammatory reaction due to implanted urinary neurostimulation device, sequela*/
,'T83591D'  /*Infection and inflammatory reaction due to implanted urinary sphincter, subsequent encounter*/
,'T83591S'  /*Infection and inflammatory reaction due to implanted urinary sphincter, sequela*/
,'T83592D'  /*Infection and inflammatory reaction due to indwelling ureteral stent, subsequent encounter*/
,'T83592S'  /*Infection and inflammatory reaction due to indwelling ureteral stent, sequela*/
,'T83593D'  /*Infection and inflammatory reaction due to other urinary stents, subsequent encounter*/
,'T83593S'  /*Infection and inflammatory reaction due to other urinary stents, sequela*/
,'T83598D'  /*Infection and inflammatory reaction due to other prosthetic device, implant and graft in urinary system, subsequent encounter*/
,'T83598S'  /*Infection and inflammatory reaction due to other prosthetic device, implant and graft in urinary system, sequela*/
,'T8361XD'  /*Infection and inflammatory reaction due to implanted penile prosthesis, subsequent encounter*/
,'T8361XS'  /*Infection and inflammatory reaction due to implanted penile prosthesis, sequela*/
,'T8362XD'  /*Infection and inflammatory reaction due to implanted testicular prosthesis, subsequent encounter*/
,'T8362XS'  /*Infection and inflammatory reaction due to implanted testicular prosthesis, sequela*/
,'T8369XD'  /*Infection and inflammatory reaction due to other prosthetic device, implant and graft in genital tract, subsequent encounter*/
,'T8369XS'  /*Infection and inflammatory reaction due to other prosthetic device, implant and graft in genital tract, sequela*/
,'T83711D'  /*Erosion of implanted vaginal mesh to surrounding organ or tissue, subsequent encounter*/
,'T83711S'  /*Erosion of implanted vaginal mesh to surrounding organ or tissue, sequela*/
,'T83712D'  /*Erosion of implanted urethral mesh to surrounding organ or tissue, subsequent encounter*/
,'T83712S'  /*Erosion of implanted urethral mesh to surrounding organ or tissue, sequela*/
,'T83713D'  /*Erosion of implanted urethral bulking agent to surrounding organ or tissue, subsequent encounter*/
,'T83713S'  /*Erosion of implanted urethral bulking agent to surrounding organ or tissue, sequela*/
,'T83714D'  /*Erosion of implanted ureteral bulking agent to surrounding organ or tissue, subsequent encounter*/
,'T83714S'  /*Erosion of implanted ureteral bulking agent to surrounding organ or tissue, sequela*/
,'T83718D'  /*Erosion of other implanted mesh to organ or tissue, subsequent encounter*/
,'T83718S'  /*Erosion of other implanted mesh to organ or tissue, sequela*/
,'T83719D'  /*Erosion of other prosthetic materials to surrounding organ or tissue, subsequent encounter*/
,'T83719S'  /*Erosion of other prosthetic materials to surrounding organ or tissue, sequela*/
,'T83721D'  /*Exposure of implanted vaginal mesh into vagina, subsequent encounter*/
,'T83721S'  /*Exposure of implanted vaginal mesh into vagina, sequela*/
,'T83722D'  /*Exposure of implanted urethral mesh into urethra, subsequent encounter*/
,'T83722S'  /*Exposure of implanted urethral mesh into urethra, sequela*/
,'T83723D'  /*Exposure of implanted urethral bulking agent into urethra, subsequent encounter*/
,'T83723S'  /*Exposure of implanted urethral bulking agent into urethra, sequela*/
,'T83724D'  /*Exposure of implanted ureteral bulking agent into ureter, subsequent encounter*/
,'T83724S'  /*Exposure of implanted ureteral bulking agent into ureter, sequela*/
,'T83728D'  /*Exposure of other implanted mesh into organ or tissue, subsequent encounter*/
,'T83728S'  /*Exposure of other implanted mesh into organ or tissue, sequela*/
,'T83729D'  /*Exposure of other prosthetic materials into organ or tissue, subsequent encounter*/
,'T83729S'  /*Exposure of other prosthetic materials into organ or tissue, sequela*/
,'T8379XD'  /*Other specified complications due to other prosthetic materials, subsequent encounter*/
,'T8379XS'  /*Other specified complications due to other prosthetic materials, sequela*/
,'T8381XD'  /*Embolism due to genitourinary prosthetic devices, implants and grafts, subsequent encounter*/
,'T8381XS'  /*Embolism due to genitourinary prosthetic devices, implants and grafts, sequela*/
,'T8382XD'  /*Fibrosis due to genitourinary prosthetic devices, implants and grafts, subsequent encounter*/
,'T8382XS'  /*Fibrosis due to genitourinary prosthetic devices, implants and grafts, sequela*/
,'T8383XD'  /*Hemorrhage due to genitourinary prosthetic devices, implants and grafts, subsequent encounter*/
,'T8383XS'  /*Hemorrhage due to genitourinary prosthetic devices, implants and grafts, sequela*/
,'T8384XD'  /*Pain due to genitourinary prosthetic devices, implants and grafts, subsequent encounter*/
,'T8384XS'  /*Pain due to genitourinary prosthetic devices, implants and grafts, sequela*/
,'T8385XD'  /*Stenosis due to genitourinary prosthetic devices, implants and grafts, subsequent encounter*/
,'T8385XS'  /*Stenosis due to genitourinary prosthetic devices, implants and grafts, sequela*/
,'T8386XD'  /*Thrombosis due to genitourinary prosthetic devices, implants and grafts, subsequent encounter*/
,'T8386XS'  /*Thrombosis due to genitourinary prosthetic devices, implants and grafts, sequela*/
,'T8389XD'  /*Other specified complication of genitourinary prosthetic devices, implants and grafts, subsequent encounter*/
,'T8389XS'  /*Other specified complication of genitourinary prosthetic devices, implants and grafts, sequela*/
,'T839XXD'  /*Unspecified complication of genitourinary prosthetic device, implant and graft, subsequent encounter*/
,'T839XXS'  /*Unspecified complication of genitourinary prosthetic device, implant and graft, sequela*/
,'T84010D'  /*Broken internal right hip prosthesis, subsequent encounter*/
,'T84010S'  /*Broken internal right hip prosthesis, sequela*/
,'T84011D'  /*Broken internal left hip prosthesis, subsequent encounter*/
,'T84011S'  /*Broken internal left hip prosthesis, sequela*/
,'T84012D'  /*Broken internal right knee prosthesis, subsequent encounter*/
,'T84012S'  /*Broken internal right knee prosthesis, sequela*/
,'T84013D'  /*Broken internal left knee prosthesis, subsequent encounter*/
,'T84013S'  /*Broken internal left knee prosthesis, sequela*/
,'T84018D'  /*Broken internal joint prosthesis, other site, subsequent encounter*/
,'T84018S'  /*Broken internal joint prosthesis, other site, sequela*/
,'T84019D'  /*Broken internal joint prosthesis, unspecified site, subsequent encounter*/
,'T84019S'  /*Broken internal joint prosthesis, unspecified site, sequela*/
,'T84020D'  /*Dislocation of internal right hip prosthesis, subsequent encounter*/
,'T84020S'  /*Dislocation of internal right hip prosthesis, sequela*/
,'T84021D'  /*Dislocation of internal left hip prosthesis, subsequent encounter*/
,'T84021S'  /*Dislocation of internal left hip prosthesis, sequela*/
,'T84022D'  /*Instability of internal right knee prosthesis, subsequent encounter*/
,'T84022S'  /*Instability of internal right knee prosthesis, sequela*/
,'T84023D'  /*Instability of internal left knee prosthesis, subsequent encounter*/
,'T84023S'  /*Instability of internal left knee prosthesis, sequela*/
,'T84028D'  /*Dislocation of other internal joint prosthesis, subsequent encounter*/
,'T84028S'  /*Dislocation of other internal joint prosthesis, sequela*/
,'T84029D'  /*Dislocation of unspecified internal joint prosthesis, subsequent encounter*/
,'T84029S'  /*Dislocation of unspecified internal joint prosthesis, sequela*/
,'T84030D'  /*Mechanical loosening of internal right hip prosthetic joint, subsequent encounter*/
,'T84030S'  /*Mechanical loosening of internal right hip prosthetic joint, sequela*/
,'T84031D'  /*Mechanical loosening of internal left hip prosthetic joint, subsequent encounter*/
,'T84031S'  /*Mechanical loosening of internal left hip prosthetic joint, sequela*/
,'T84032D'  /*Mechanical loosening of internal right knee prosthetic joint, subsequent encounter*/
,'T84032S'  /*Mechanical loosening of internal right knee prosthetic joint, sequela*/
,'T84033D'  /*Mechanical loosening of internal left knee prosthetic joint, subsequent encounter*/
,'T84033S'  /*Mechanical loosening of internal left knee prosthetic joint, sequela*/
,'T84038D'  /*Mechanical loosening of other internal prosthetic joint, subsequent encounter*/
,'T84038S'  /*Mechanical loosening of other internal prosthetic joint, sequela*/
,'T84039D'  /*Mechanical loosening of unspecified internal prosthetic joint, subsequent encounter*/
,'T84039S'  /*Mechanical loosening of unspecified internal prosthetic joint, sequela*/
,'T84050D'  /*Periprosthetic osteolysis of internal prosthetic right hip joint, subsequent encounter*/
,'T84050S'  /*Periprosthetic osteolysis of internal prosthetic right hip joint, sequela*/
,'T84051D'  /*Periprosthetic osteolysis of internal prosthetic left hip joint, subsequent encounter*/
,'T84051S'  /*Periprosthetic osteolysis of internal prosthetic left hip joint, sequela*/
,'T84052D'  /*Periprosthetic osteolysis of internal prosthetic right knee joint, subsequent encounter*/
,'T84052S'  /*Periprosthetic osteolysis of internal prosthetic right knee joint, sequela*/
,'T84053D'  /*Periprosthetic osteolysis of internal prosthetic left knee joint, subsequent encounter*/
,'T84053S'  /*Periprosthetic osteolysis of internal prosthetic left knee joint, sequela*/
,'T84058D'  /*Periprosthetic osteolysis of other internal prosthetic joint, subsequent encounter*/
,'T84058S'  /*Periprosthetic osteolysis of other internal prosthetic joint, sequela*/
,'T84059D'  /*Periprosthetic osteolysis of unspecified internal prosthetic joint, subsequent encounter*/
,'T84059S'  /*Periprosthetic osteolysis of unspecified internal prosthetic joint, sequela*/
,'T84060D'  /*Wear of articular bearing surface of internal prosthetic right hip joint, subsequent encounter*/
,'T84060S'  /*Wear of articular bearing surface of internal prosthetic right hip joint, sequela*/
,'T84061D'  /*Wear of articular bearing surface of internal prosthetic left hip joint, subsequent encounter*/
,'T84061S'  /*Wear of articular bearing surface of internal prosthetic left hip joint, sequela*/
,'T84062D'  /*Wear of articular bearing surface of internal prosthetic right knee joint, subsequent encounter*/
,'T84062S'  /*Wear of articular bearing surface of internal prosthetic right knee joint, sequela*/
,'T84063D'  /*Wear of articular bearing surface of internal prosthetic left knee joint, subsequent encounter*/
,'T84063S'  /*Wear of articular bearing surface of internal prosthetic left knee joint, sequela*/
,'T84068D'  /*Wear of articular bearing surface of other internal prosthetic joint, subsequent encounter*/
,'T84068S'  /*Wear of articular bearing surface of other internal prosthetic joint, sequela*/
,'T84069D'  /*Wear of articular bearing surface of unspecified internal prosthetic joint, subsequent encounter*/
,'T84069S'  /*Wear of articular bearing surface of unspecified internal prosthetic joint, sequela*/
,'T84090D'  /*Other mechanical complication of internal right hip prosthesis, subsequent encounter*/
,'T84090S'  /*Other mechanical complication of internal right hip prosthesis, sequela*/
,'T84091D'  /*Other mechanical complication of internal left hip prosthesis, subsequent encounter*/
,'T84091S'  /*Other mechanical complication of internal left hip prosthesis, sequela*/
,'T84092D'  /*Other mechanical complication of internal right knee prosthesis, subsequent encounter*/
,'T84092S'  /*Other mechanical complication of internal right knee prosthesis, sequela*/
,'T84093D'  /*Other mechanical complication of internal left knee prosthesis, subsequent encounter*/
,'T84093S'  /*Other mechanical complication of internal left knee prosthesis, sequela*/
,'T84098D'  /*Other mechanical complication of other internal joint prosthesis, subsequent encounter*/
,'T84098S'  /*Other mechanical complication of other internal joint prosthesis, sequela*/
,'T84099D'  /*Other mechanical complication of unspecified internal joint prosthesis, subsequent encounter*/
,'T84099S'  /*Other mechanical complication of unspecified internal joint prosthesis, sequela*/
,'T84110D'  /*Breakdown (mechanical) of internal fixation device of right humerus, subsequent encounter*/
,'T84110S'  /*Breakdown (mechanical) of internal fixation device of right humerus, sequela*/
,'T84111D'  /*Breakdown (mechanical) of internal fixation device of left humerus, subsequent encounter*/
,'T84111S'  /*Breakdown (mechanical) of internal fixation device of left humerus, sequela*/
,'T84112D'  /*Breakdown (mechanical) of internal fixation device of bone of right forearm, subsequent encounter*/
,'T84112S'  /*Breakdown (mechanical) of internal fixation device of bone of right forearm, sequela*/
,'T84113D'  /*Breakdown (mechanical) of internal fixation device of bone of left forearm, subsequent encounter*/
,'T84113S'  /*Breakdown (mechanical) of internal fixation device of bone of left forearm, sequela*/
,'T84114D'  /*Breakdown (mechanical) of internal fixation device of right femur, subsequent encounter*/
,'T84114S'  /*Breakdown (mechanical) of internal fixation device of right femur, sequela*/
,'T84115D'  /*Breakdown (mechanical) of internal fixation device of left femur, subsequent encounter*/
,'T84115S'  /*Breakdown (mechanical) of internal fixation device of left femur, sequela*/
,'T84116D'  /*Breakdown (mechanical) of internal fixation device of bone of right lower leg, subsequent encounter*/
,'T84116S'  /*Breakdown (mechanical) of internal fixation device of bone of right lower leg, sequela*/
,'T84117D'  /*Breakdown (mechanical) of internal fixation device of bone of left lower leg, subsequent encounter*/
,'T84117S'  /*Breakdown (mechanical) of internal fixation device of bone of left lower leg, sequela*/
,'T84119D'  /*Breakdown (mechanical) of internal fixation device of unspecified bone of limb, subsequent encounter*/
,'T84119S'  /*Breakdown (mechanical) of internal fixation device of unspecified bone of limb, sequela*/
,'T84120D'  /*Displacement of internal fixation device of right humerus, subsequent encounter*/
,'T84120S'  /*Displacement of internal fixation device of right humerus, sequela*/
,'T84121D'  /*Displacement of internal fixation device of left humerus, subsequent encounter*/
,'T84121S'  /*Displacement of internal fixation device of left humerus, sequela*/
,'T84122D'  /*Displacement of internal fixation device of bone of right forearm, subsequent encounter*/
,'T84122S'  /*Displacement of internal fixation device of bone of right forearm, sequela*/
,'T84123D'  /*Displacement of internal fixation device of bone of left forearm, subsequent encounter*/
,'T84123S'  /*Displacement of internal fixation device of bone of left forearm, sequela*/
,'T84124D'  /*Displacement of internal fixation device of right femur, subsequent encounter*/
,'T84124S'  /*Displacement of internal fixation device of right femur, sequela*/
,'T84125D'  /*Displacement of internal fixation device of left femur, subsequent encounter*/
,'T84125S'  /*Displacement of internal fixation device of left femur, sequela*/
,'T84126D'  /*Displacement of internal fixation device of bone of right lower leg, subsequent encounter*/
,'T84126S'  /*Displacement of internal fixation device of bone of right lower leg, sequela*/
,'T84127D'  /*Displacement of internal fixation device of bone of left lower leg, subsequent encounter*/
,'T84127S'  /*Displacement of internal fixation device of bone of left lower leg, sequela*/
,'T84129D'  /*Displacement of internal fixation device of unspecified bone of limb, subsequent encounter*/
,'T84129S'  /*Displacement of internal fixation device of unspecified bone of limb, sequela*/
,'T84190D'  /*Other mechanical complication of internal fixation device of right humerus, subsequent encounter*/
,'T84190S'  /*Other mechanical complication of internal fixation device of right humerus, sequela*/
,'T84191D'  /*Other mechanical complication of internal fixation device of left humerus, subsequent encounter*/
,'T84191S'  /*Other mechanical complication of internal fixation device of left humerus, sequela*/
,'T84192D'  /*Other mechanical complication of internal fixation device of bone of right forearm, subsequent encounter*/
,'T84192S'  /*Other mechanical complication of internal fixation device of bone of right forearm, sequela*/
,'T84193D'  /*Other mechanical complication of internal fixation device of bone of left forearm, subsequent encounter*/
,'T84193S'  /*Other mechanical complication of internal fixation device of bone of left forearm, sequela*/
,'T84194D'  /*Other mechanical complication of internal fixation device of right femur, subsequent encounter*/
,'T84194S'  /*Other mechanical complication of internal fixation device of right femur, sequela*/
,'T84195D'  /*Other mechanical complication of internal fixation device of left femur, subsequent encounter*/
,'T84195S'  /*Other mechanical complication of internal fixation device of left femur, sequela*/
,'T84196D'  /*Other mechanical complication of internal fixation device of bone of right lower leg, subsequent encounter*/
,'T84196S'  /*Other mechanical complication of internal fixation device of bone of right lower leg, sequela*/
,'T84197D'  /*Other mechanical complication of internal fixation device of bone of left lower leg, subsequent encounter*/
,'T84197S'  /*Other mechanical complication of internal fixation device of bone of left lower leg, sequela*/
,'T84199D'  /*Other mechanical complication of internal fixation device of unspecified bone of limb, subsequent encounter*/
,'T84199S'  /*Other mechanical complication of internal fixation device of unspecified bone of limb, sequela*/
,'T84210D'  /*Breakdown (mechanical) of internal fixation device of bones of hand and fingers, subsequent encounter*/
,'T84210S'  /*Breakdown (mechanical) of internal fixation device of bones of hand and fingers, sequela*/
,'T84213D'  /*Breakdown (mechanical) of internal fixation device of bones of foot and toes, subsequent encounter*/
,'T84213S'  /*Breakdown (mechanical) of internal fixation device of bones of foot and toes, sequela*/
,'T84216D'  /*Breakdown (mechanical) of internal fixation device of vertebrae, subsequent encounter*/
,'T84216S'  /*Breakdown (mechanical) of internal fixation device of vertebrae, sequela*/
,'T84218D'  /*Breakdown (mechanical) of internal fixation device of other bones, subsequent encounter*/
,'T84218S'  /*Breakdown (mechanical) of internal fixation device of other bones, sequela*/
,'T84220D'  /*Displacement of internal fixation device of bones of hand and fingers, subsequent encounter*/
,'T84220S'  /*Displacement of internal fixation device of bones of hand and fingers, sequela*/
,'T84223D'  /*Displacement of internal fixation device of bones of foot and toes, subsequent encounter*/
,'T84223S'  /*Displacement of internal fixation device of bones of foot and toes, sequela*/
,'T84226D'  /*Displacement of internal fixation device of vertebrae, subsequent encounter*/
,'T84226S'  /*Displacement of internal fixation device of vertebrae, sequela*/
,'T84228D'  /*Displacement of internal fixation device of other bones, subsequent encounter*/
,'T84228S'  /*Displacement of internal fixation device of other bones, sequela*/
,'T84290D'  /*Other mechanical complication of internal fixation device of bones of hand and fingers, subsequent encounter*/
,'T84290S'  /*Other mechanical complication of internal fixation device of bones of hand and fingers, sequela*/
,'T84293D'  /*Other mechanical complication of internal fixation device of bones of foot and toes, subsequent encounter*/
,'T84293S'  /*Other mechanical complication of internal fixation device of bones of foot and toes, sequela*/
,'T84296D'  /*Other mechanical complication of internal fixation device of vertebrae, subsequent encounter*/
,'T84296S'  /*Other mechanical complication of internal fixation device of vertebrae, sequela*/
,'T84298D'  /*Other mechanical complication of internal fixation device of other bones, subsequent encounter*/
,'T84298S'  /*Other mechanical complication of internal fixation device of other bones, sequela*/
,'T84310D'  /*Breakdown (mechanical) of electronic bone stimulator, subsequent encounter*/
,'T84310S'  /*Breakdown (mechanical) of electronic bone stimulator, sequela*/
,'T84318D'  /*Breakdown (mechanical) of other bone devices, implants and grafts, subsequent encounter*/
,'T84318S'  /*Breakdown (mechanical) of other bone devices, implants and grafts, sequela*/
,'T84320D'  /*Displacement of electronic bone stimulator, subsequent encounter*/
,'T84320S'  /*Displacement of electronic bone stimulator, sequela*/
,'T84328D'  /*Displacement of other bone devices, implants and grafts, subsequent encounter*/
,'T84328S'  /*Displacement of other bone devices, implants and grafts, sequela*/
,'T84390D'  /*Other mechanical complication of electronic bone stimulator, subsequent encounter*/
,'T84390S'  /*Other mechanical complication of electronic bone stimulator, sequela*/
,'T84398D'  /*Other mechanical complication of other bone devices, implants and grafts, subsequent encounter*/
,'T84398S'  /*Other mechanical complication of other bone devices, implants and grafts, sequela*/
,'T84410D'  /*Breakdown (mechanical) of muscle and tendon graft, subsequent encounter*/
,'T84410S'  /*Breakdown (mechanical) of muscle and tendon graft, sequela*/
,'T84418D'  /*Breakdown (mechanical) of other internal orthopedic devices, implants and grafts, subsequent encounter*/
,'T84418S'  /*Breakdown (mechanical) of other internal orthopedic devices, implants and grafts, sequela*/
,'T84420D'  /*Displacement of muscle and tendon graft, subsequent encounter*/
,'T84420S'  /*Displacement of muscle and tendon graft, sequela*/
,'T84428D'  /*Displacement of other internal orthopedic devices, implants and grafts, subsequent encounter*/
,'T84428S'  /*Displacement of other internal orthopedic devices, implants and grafts, sequela*/
,'T84490D'  /*Other mechanical complication of muscle and tendon graft, subsequent encounter*/
,'T84490S'  /*Other mechanical complication of muscle and tendon graft, sequela*/
,'T84498D'  /*Other mechanical complication of other internal orthopedic devices, implants and grafts, subsequent encounter*/
,'T84498S'  /*Other mechanical complication of other internal orthopedic devices, implants and grafts, sequela*/
,'T8450XD'  /*Infection and inflammatory reaction due to unspecified internal joint prosthesis, subsequent encounter*/
,'T8450XS'  /*Infection and inflammatory reaction due to unspecified internal joint prosthesis, sequela*/
,'T8451XD'  /*Infection and inflammatory reaction due to internal right hip prosthesis, subsequent encounter*/
,'T8451XS'  /*Infection and inflammatory reaction due to internal right hip prosthesis, sequela*/
,'T8452XD'  /*Infection and inflammatory reaction due to internal left hip prosthesis, subsequent encounter*/
,'T8452XS'  /*Infection and inflammatory reaction due to internal left hip prosthesis, sequela*/
,'T8453XD'  /*Infection and inflammatory reaction due to internal right knee prosthesis, subsequent encounter*/
,'T8453XS'  /*Infection and inflammatory reaction due to internal right knee prosthesis, sequela*/
,'T8454XD'  /*Infection and inflammatory reaction due to internal left knee prosthesis, subsequent encounter*/
,'T8454XS'  /*Infection and inflammatory reaction due to internal left knee prosthesis, sequela*/
,'T8459XD'  /*Infection and inflammatory reaction due to other internal joint prosthesis, subsequent encounter*/
,'T8459XS'  /*Infection and inflammatory reaction due to other internal joint prosthesis, sequela*/
,'T8460XD'  /*Infection and inflammatory reaction due to internal fixation device of unspecified site, subsequent encounter*/
,'T8460XS'  /*Infection and inflammatory reaction due to internal fixation device of unspecified site, sequela*/
,'T84610D'  /*Infection and inflammatory reaction due to internal fixation device of right humerus, subsequent encounter*/
,'T84610S'  /*Infection and inflammatory reaction due to internal fixation device of right humerus, sequela*/
,'T84611D'  /*Infection and inflammatory reaction due to internal fixation device of left humerus, subsequent encounter*/
,'T84611S'  /*Infection and inflammatory reaction due to internal fixation device of left humerus, sequela*/
,'T84612D'  /*Infection and inflammatory reaction due to internal fixation device of right radius, subsequent encounter*/
,'T84612S'  /*Infection and inflammatory reaction due to internal fixation device of right radius, sequela*/
,'T84613D'  /*Infection and inflammatory reaction due to internal fixation device of left radius, subsequent encounter*/
,'T84613S'  /*Infection and inflammatory reaction due to internal fixation device of left radius, sequela*/
,'T84614D'  /*Infection and inflammatory reaction due to internal fixation device of right ulna, subsequent encounter*/
,'T84614S'  /*Infection and inflammatory reaction due to internal fixation device of right ulna, sequela*/
,'T84615D'  /*Infection and inflammatory reaction due to internal fixation device of left ulna, subsequent encounter*/
,'T84615S'  /*Infection and inflammatory reaction due to internal fixation device of left ulna, sequela*/
,'T84619D'  /*Infection and inflammatory reaction due to internal fixation device of unspecified bone of arm, subsequent encounter*/
,'T84619S'  /*Infection and inflammatory reaction due to internal fixation device of unspecified bone of arm, sequela*/
,'T84620D'  /*Infection and inflammatory reaction due to internal fixation device of right femur, subsequent encounter*/
,'T84620S'  /*Infection and inflammatory reaction due to internal fixation device of right femur, sequela*/
,'T84621D'  /*Infection and inflammatory reaction due to internal fixation device of left femur, subsequent encounter*/
,'T84621S'  /*Infection and inflammatory reaction due to internal fixation device of left femur, sequela*/
,'T84622D'  /*Infection and inflammatory reaction due to internal fixation device of right tibia, subsequent encounter*/
,'T84622S'  /*Infection and inflammatory reaction due to internal fixation device of right tibia, sequela*/
,'T84623D'  /*Infection and inflammatory reaction due to internal fixation device of left tibia, subsequent encounter*/
,'T84623S'  /*Infection and inflammatory reaction due to internal fixation device of left tibia, sequela*/
,'T84624D'  /*Infection and inflammatory reaction due to internal fixation device of right fibula, subsequent encounter*/
,'T84624S'  /*Infection and inflammatory reaction due to internal fixation device of right fibula, sequela*/
,'T84625D'  /*Infection and inflammatory reaction due to internal fixation device of left fibula, subsequent encounter*/
,'T84625S'  /*Infection and inflammatory reaction due to internal fixation device of left fibula, sequela*/
,'T84629D'  /*Infection and inflammatory reaction due to internal fixation device of unspecified bone of leg, subsequent encounter*/
,'T84629S'  /*Infection and inflammatory reaction due to internal fixation device of unspecified bone of leg, sequela*/
,'T8463XD'  /*Infection and inflammatory reaction due to internal fixation device of spine, subsequent encounter*/
,'T8463XS'  /*Infection and inflammatory reaction due to internal fixation device of spine, sequela*/
,'T8469XD'  /*Infection and inflammatory reaction due to internal fixation device of other site, subsequent encounter*/
,'T8469XS'  /*Infection and inflammatory reaction due to internal fixation device of other site, sequela*/
,'T847XXD'  /*Infection and inflammatory reaction due to other internal orthopedic prosthetic devices, implants and grafts, subsequent encounter*/
,'T847XXS'  /*Infection and inflammatory reaction due to other internal orthopedic prosthetic devices, implants and grafts, sequela*/
,'T8481XD'  /*Embolism due to internal orthopedic prosthetic devices, implants and grafts, subsequent encounter*/
,'T8481XS'  /*Embolism due to internal orthopedic prosthetic devices, implants and grafts, sequela*/
,'T8482XD'  /*Fibrosis due to internal orthopedic prosthetic devices, implants and grafts, subsequent encounter*/
,'T8482XS'  /*Fibrosis due to internal orthopedic prosthetic devices, implants and grafts, sequela*/
,'T8483XD'  /*Hemorrhage due to internal orthopedic prosthetic devices, implants and grafts, subsequent encounter*/
,'T8483XS'  /*Hemorrhage due to internal orthopedic prosthetic devices, implants and grafts, sequela*/
,'T8484XD'  /*Pain due to internal orthopedic prosthetic devices, implants and grafts, subsequent encounter*/
,'T8484XS'  /*Pain due to internal orthopedic prosthetic devices, implants and grafts, sequela*/
,'T8485XD'  /*Stenosis due to internal orthopedic prosthetic devices, implants and grafts, subsequent encounter*/
,'T8485XS'  /*Stenosis due to internal orthopedic prosthetic devices, implants and grafts, sequela*/
,'T8486XD'  /*Thrombosis due to internal orthopedic prosthetic devices, implants and grafts, subsequent encounter*/
,'T8486XS'  /*Thrombosis due to internal orthopedic prosthetic devices, implants and grafts, sequela*/
,'T8489XD'  /*Other specified complication of internal orthopedic prosthetic devices, implants and grafts, subsequent encounter*/
,'T8489XS'  /*Other specified complication of internal orthopedic prosthetic devices, implants and grafts, sequela*/
,'T849XXD'  /*Unspecified complication of internal orthopedic prosthetic device, implant and graft, subsequent encounter*/
,'T849XXS'  /*Unspecified complication of internal orthopedic prosthetic device, implant and graft, sequela*/
,'T8501XD'  /*Breakdown (mechanical) of ventricular intracranial (communicating) shunt, subsequent encounter*/
,'T8501XS'  /*Breakdown (mechanical) of ventricular intracranial (communicating) shunt, sequela*/
,'T8502XD'  /*Displacement of ventricular intracranial (communicating) shunt, subsequent encounter*/
,'T8502XS'  /*Displacement of ventricular intracranial (communicating) shunt, sequela*/
,'T8503XD'  /*Leakage of ventricular intracranial (communicating) shunt, subsequent encounter*/
,'T8503XS'  /*Leakage of ventricular intracranial (communicating) shunt, sequela*/
,'T8509XD'  /*Other mechanical complication of ventricular intracranial (communicating) shunt, subsequent encounter*/
,'T8509XS'  /*Other mechanical complication of ventricular intracranial (communicating) shunt, sequela*/
,'T85110D'  /*Breakdown (mechanical) of implanted electronic neurostimulator of brain, electrode (lead), subsequent encounter*/
,'T85110S'  /*Breakdown (mechanical) of implanted electronic neurostimulator of brain, electrode (lead), sequela*/
,'T85111D'  /*Breakdown (mechanical) of implanted electronic neurostimulator of peripheral nerve, electrode (lead), subsequent encounter*/
,'T85111S'  /*Breakdown (mechanical) of implanted electronic neurostimulator of peripheral nerve, electrode (lead), sequela*/
,'T85112D'  /*Breakdown (mechanical) of implanted electronic neurostimulator of spinal cord, electrode (lead), subsequent encounter*/
,'T85112S'  /*Breakdown (mechanical) of implanted electronic neurostimulator of spinal cord, electrode (lead), sequela*/
,'T85113D'  /*Breakdown (mechanical) of implanted electronic neurostimulator, generator, subsequent encounter*/
,'T85113S'  /*Breakdown (mechanical) of implanted electronic neurostimulator, generator, sequela*/
,'T85118D'  /*Breakdown (mechanical) of other implanted electronic stimulator of nervous system, subsequent encounter*/
,'T85118S'  /*Breakdown (mechanical) of other implanted electronic stimulator of nervous system, sequela*/
,'T85120D'  /*Displacement of implanted electronic neurostimulator of brain, electrode (lead), subsequent encounter*/
,'T85120S'  /*Displacement of implanted electronic neurostimulator of brain, electrode (lead), sequela*/
,'T85121D'  /*Displacement of implanted electronic neurostimulator of peripheral nerve, electrode (lead), subsequent encounter*/
,'T85121S'  /*Displacement of implanted electronic neurostimulator of peripheral nerve, electrode (lead), sequela*/
,'T85122D'  /*Displacement of implanted electronic neurostimulator of spinal cord, electrode (lead), subsequent encounter*/
,'T85122S'  /*Displacement of implanted electronic neurostimulator of spinal cord, electrode (lead), sequela*/
,'T85123D'  /*Displacement of implanted electronic neurostimulator, generator, subsequent encounter*/
,'T85123S'  /*Displacement of implanted electronic neurostimulator, generator, sequela*/
,'T85128D'  /*Displacement of other implanted electronic stimulator of nervous system, subsequent encounter*/
,'T85128S'  /*Displacement of other implanted electronic stimulator of nervous system, sequela*/
,'T85190D'  /*Other mechanical complication of implanted electronic neurostimulator of brain, electrode (lead), subsequent encounter*/
,'T85190S'  /*Other mechanical complication of implanted electronic neurostimulator of brain, electrode (lead), sequela*/
,'T85191D'  /*Other mechanical complication of implanted electronic neurostimulator of peripheral nerve, electrode (lead), subsequent encounter*/
,'T85191S'  /*Other mechanical complication of implanted electronic neurostimulator of peripheral nerve, electrode (lead), sequela*/
,'T85192D'  /*Other mechanical complication of implanted electronic neurostimulator of spinal cord, electrode (lead), subsequent encounter*/
,'T85192S'  /*Other mechanical complication of implanted electronic neurostimulator of spinal cord, electrode (lead), sequela*/
,'T85193D'  /*Other mechanical complication of implanted electronic neurostimulator, generator, subsequent encounter*/
,'T85193S'  /*Other mechanical complication of implanted electronic neurostimulator, generator, sequela*/
,'T85199D'  /*Other mechanical complication of other implanted electronic stimulator of nervous system, subsequent encounter*/
,'T85199S'  /*Other mechanical complication of other implanted electronic stimulator of nervous system, sequela*/
,'T8521XD'  /*Breakdown (mechanical) of intraocular lens, subsequent encounter*/
,'T8521XS'  /*Breakdown (mechanical) of intraocular lens, sequela*/
,'T8522XD'  /*Displacement of intraocular lens, subsequent encounter*/
,'T8522XS'  /*Displacement of intraocular lens, sequela*/
,'T8529XD'  /*Other mechanical complication of intraocular lens, subsequent encounter*/
,'T8529XS'  /*Other mechanical complication of intraocular lens, sequela*/
,'T85310D'  /*Breakdown (mechanical) of prosthetic orbit of right eye, subsequent encounter*/
,'T85310S'  /*Breakdown (mechanical) of prosthetic orbit of right eye, sequela*/
,'T85311D'  /*Breakdown (mechanical) of prosthetic orbit of left eye, subsequent encounter*/
,'T85311S'  /*Breakdown (mechanical) of prosthetic orbit of left eye, sequela*/
,'T85318D'  /*Breakdown (mechanical) of other ocular prosthetic devices, implants and grafts, subsequent encounter*/
,'T85318S'  /*Breakdown (mechanical) of other ocular prosthetic devices, implants and grafts, sequela*/
,'T85320D'  /*Displacement of prosthetic orbit of right eye, subsequent encounter*/
,'T85320S'  /*Displacement of prosthetic orbit of right eye, sequela*/
,'T85321D'  /*Displacement of prosthetic orbit of left eye, subsequent encounter*/
,'T85321S'  /*Displacement of prosthetic orbit of left eye, sequela*/
,'T85328D'  /*Displacement of other ocular prosthetic devices, implants and grafts, subsequent encounter*/
,'T85328S'  /*Displacement of other ocular prosthetic devices, implants and grafts, sequela*/
,'T85390D'  /*Other mechanical complication of prosthetic orbit of right eye, subsequent encounter*/
,'T85390S'  /*Other mechanical complication of prosthetic orbit of right eye, sequela*/
,'T85391D'  /*Other mechanical complication of prosthetic orbit of left eye, subsequent encounter*/
,'T85391S'  /*Other mechanical complication of prosthetic orbit of left eye, sequela*/
,'T85398D'  /*Other mechanical complication of other ocular prosthetic devices, implants and grafts, subsequent encounter*/
,'T85398S'  /*Other mechanical complication of other ocular prosthetic devices, implants and grafts, sequela*/
,'T8541XD'  /*Breakdown (mechanical) of breast prosthesis and implant, subsequent encounter*/
,'T8541XS'  /*Breakdown (mechanical) of breast prosthesis and implant, sequela*/
,'T8542XD'  /*Displacement of breast prosthesis and implant, subsequent encounter*/
,'T8542XS'  /*Displacement of breast prosthesis and implant, sequela*/
,'T8543XD'  /*Leakage of breast prosthesis and implant, subsequent encounter*/
,'T8543XS'  /*Leakage of breast prosthesis and implant, sequela*/
,'T8544XD'  /*Capsular contracture of breast implant, subsequent encounter*/
,'T8544XS'  /*Capsular contracture of breast implant, sequela*/
,'T8549XD'  /*Other mechanical complication of breast prosthesis and implant, subsequent encounter*/
,'T8549XS'  /*Other mechanical complication of breast prosthesis and implant, sequela*/
,'T85510D'  /*Breakdown (mechanical) of bile duct prosthesis, subsequent encounter*/
,'T85510S'  /*Breakdown (mechanical) of bile duct prosthesis, sequela*/
,'T85511D'  /*Breakdown (mechanical) of esophageal anti-reflux device, subsequent encounter*/
,'T85511S'  /*Breakdown (mechanical) of esophageal anti-reflux device, sequela*/
,'T85518D'  /*Breakdown (mechanical) of other gastrointestinal prosthetic devices, implants and grafts, subsequent encounter*/
,'T85518S'  /*Breakdown (mechanical) of other gastrointestinal prosthetic devices, implants and grafts, sequela*/
,'T85520D'  /*Displacement of bile duct prosthesis, subsequent encounter*/
,'T85520S'  /*Displacement of bile duct prosthesis, sequela*/
,'T85521D'  /*Displacement of esophageal anti-reflux device, subsequent encounter*/
,'T85521S'  /*Displacement of esophageal anti-reflux device, sequela*/
,'T85528D'  /*Displacement of other gastrointestinal prosthetic devices, implants and grafts, subsequent encounter*/
,'T85528S'  /*Displacement of other gastrointestinal prosthetic devices, implants and grafts, sequela*/
,'T85590D'  /*Other mechanical complication of bile duct prosthesis, subsequent encounter*/
,'T85590S'  /*Other mechanical complication of bile duct prosthesis, sequela*/
,'T85591D'  /*Other mechanical complication of esophageal anti-reflux device, subsequent encounter*/
,'T85591S'  /*Other mechanical complication of esophageal anti-reflux device, sequela*/
,'T85598D'  /*Other mechanical complication of other gastrointestinal prosthetic devices, implants and grafts, subsequent encounter*/
,'T85598S'  /*Other mechanical complication of other gastrointestinal prosthetic devices, implants and grafts, sequela*/
,'T85610D'  /*Breakdown (mechanical) of cranial or spinal infusion catheter, subsequent encounter*/
,'T85610S'  /*Breakdown (mechanical) of cranial or spinal infusion catheter, sequela*/
,'T85611D'  /*Breakdown (mechanical) of intraperitoneal dialysis catheter, subsequent encounter*/
,'T85611S'  /*Breakdown (mechanical) of intraperitoneal dialysis catheter, sequela*/
,'T85612D'  /*Breakdown (mechanical) of permanent sutures, subsequent encounter*/
,'T85612S'  /*Breakdown (mechanical) of permanent sutures, sequela*/
,'T85613D'  /*Breakdown (mechanical) of artificial skin graft and decellularized allodermis, subsequent encounter*/
,'T85613S'  /*Breakdown (mechanical) of artificial skin graft and decellularized allodermis, sequela*/
,'T85614D'  /*Breakdown (mechanical) of insulin pump, subsequent encounter*/
,'T85614S'  /*Breakdown (mechanical) of insulin pump, sequela*/
,'T85615D'  /*Breakdown (mechanical) of other nervous system device, implant or graft, subsequent encounter*/
,'T85615S'  /*Breakdown (mechanical) of other nervous system device, implant or graft, sequela*/
,'T85618D'  /*Breakdown (mechanical) of other specified internal prosthetic devices, implants and grafts, subsequent encounter*/
,'T85618S'  /*Breakdown (mechanical) of other specified internal prosthetic devices, implants and grafts, sequela*/
,'T85620D'  /*Displacement of cranial or spinal infusion catheter, subsequent encounter*/
,'T85620S'  /*Displacement of cranial or spinal infusion catheter, sequela*/
,'T85621D'  /*Displacement of intraperitoneal dialysis catheter, subsequent encounter*/
,'T85621S'  /*Displacement of intraperitoneal dialysis catheter, sequela*/
,'T85622D'  /*Displacement of permanent sutures, subsequent encounter*/
,'T85622S'  /*Displacement of permanent sutures, sequela*/
,'T85623D'  /*Displacement of artificial skin graft and decellularized allodermis, subsequent encounter*/
,'T85623S'  /*Displacement of artificial skin graft and decellularized allodermis, sequela*/
,'T85624D'  /*Displacement of insulin pump, subsequent encounter*/
,'T85624S'  /*Displacement of insulin pump, sequela*/
,'T85625D'  /*Displacement of other nervous system device, implant or graft, subsequent encounter*/
,'T85625S'  /*Displacement of other nervous system device, implant or graft, sequela*/
,'T85628D'  /*Displacement of other specified internal prosthetic devices, implants and grafts, subsequent encounter*/
,'T85628S'  /*Displacement of other specified internal prosthetic devices, implants and grafts, sequela*/
,'T85630D'  /*Leakage of cranial or spinal infusion catheter, subsequent encounter*/
,'T85630S'  /*Leakage of cranial or spinal infusion catheter, sequela*/
,'T85631D'  /*Leakage of intraperitoneal dialysis catheter, subsequent encounter*/
,'T85631S'  /*Leakage of intraperitoneal dialysis catheter, sequela*/
,'T85633D'  /*Leakage of insulin pump, subsequent encounter*/
,'T85633S'  /*Leakage of insulin pump, sequela*/
,'T85635D'  /*Leakage of other nervous system device, implant or graft, subsequent encounter*/
,'T85635S'  /*Leakage of other nervous system device, implant or graft, sequela*/
,'T85638D'  /*Leakage of other specified internal prosthetic devices, implants and grafts, subsequent encounter*/
,'T85638S'  /*Leakage of other specified internal prosthetic devices, implants and grafts, sequela*/
,'T85690D'  /*Other mechanical complication of cranial or spinal infusion catheter, subsequent encounter*/
,'T85690S'  /*Other mechanical complication of cranial or spinal infusion catheter, sequela*/
,'T85691D'  /*Other mechanical complication of intraperitoneal dialysis catheter, subsequent encounter*/
,'T85691S'  /*Other mechanical complication of intraperitoneal dialysis catheter, sequela*/
,'T85692D'  /*Other mechanical complication of permanent sutures, subsequent encounter*/
,'T85692S'  /*Other mechanical complication of permanent sutures, sequela*/
,'T85693D'  /*Other mechanical complication of artificial skin graft and decellularized allodermis, subsequent encounter*/
,'T85693S'  /*Other mechanical complication of artificial skin graft and decellularized allodermis, sequela*/
,'T85694D'  /*Other mechanical complication of insulin pump, subsequent encounter*/
,'T85694S'  /*Other mechanical complication of insulin pump, sequela*/
,'T85695D'  /*Other mechanical complication of other nervous system device, implant or graft, subsequent encounter*/
,'T85695S'  /*Other mechanical complication of other nervous system device, implant or graft, sequela*/
,'T85698D'  /*Other mechanical complication of other specified internal prosthetic devices, implants and grafts, subsequent encounter*/
,'T85698S'  /*Other mechanical complication of other specified internal prosthetic devices, implants and grafts, sequela*/
,'T8571XD'  /*Infection and inflammatory reaction due to peritoneal dialysis catheter, subsequent encounter*/
,'T8571XS'  /*Infection and inflammatory reaction due to peritoneal dialysis catheter, sequela*/
,'T8572XD'  /*Infection and inflammatory reaction due to insulin pump, subsequent encounter*/
,'T8572XS'  /*Infection and inflammatory reaction due to insulin pump, sequela*/
,'T85730D'  /*Infection and inflammatory reaction due to ventricular intracranial (communicating) shunt, subsequent encounter*/
,'T85730S'  /*Infection and inflammatory reaction due to ventricular intracranial (communicating) shunt, sequela*/
,'T85731D'  /*Infection and inflammatory reaction due to implanted electronic neurostimulator of brain, electrode (lead), subsequent encounter*/
,'T85731S'  /*Infection and inflammatory reaction due to implanted electronic neurostimulator of brain, electrode (lead), sequela*/
,'T85732D'  /*Infection and inflammatory reaction due to implanted electronic neurostimulator of peripheral nerve, electrode (lead), subsequent encounter*/
,'T85732S'  /*Infection and inflammatory reaction due to implanted electronic neurostimulator of peripheral nerve, electrode (lead), sequela*/
,'T85733D'  /*Infection and inflammatory reaction due to implanted electronic neurostimulator of spinal cord, electrode (lead), subsequent encounter*/
,'T85733S'  /*Infection and inflammatory reaction due to implanted electronic neurostimulator of spinal cord, electrode (lead), sequela*/
,'T85734D'  /*Infection and inflammatory reaction due to implanted electronic neurostimulator, generator, subsequent encounter*/
,'T85734S'  /*Infection and inflammatory reaction due to implanted electronic neurostimulator, generator, sequela*/
,'T85735D'  /*Infection and inflammatory reaction due to cranial or spinal infusion catheter, subsequent encounter*/
,'T85735S'  /*Infection and inflammatory reaction due to cranial or spinal infusion catheter, sequela*/
,'T85738D'  /*Infection and inflammatory reaction due to other nervous system device, implant or graft, subsequent encounter*/
,'T85738S'  /*Infection and inflammatory reaction due to other nervous system device, implant or graft, sequela*/
,'T8579XD'  /*Infection and inflammatory reaction due to other internal prosthetic devices, implants and grafts, subsequent encounter*/
,'T8579XS'  /*Infection and inflammatory reaction due to other internal prosthetic devices, implants and grafts, sequela*/
,'T85810D'  /*Embolism due to nervous system prosthetic devices, implants and grafts, subsequent encounter*/
,'T85810S'  /*Embolism due to nervous system prosthetic devices, implants and grafts, sequela*/
,'T85818D'  /*Embolism due to other internal prosthetic devices, implants and grafts, subsequent encounter*/
,'T85818S'  /*Embolism due to other internal prosthetic devices, implants and grafts, sequela*/
,'T85820D'  /*Fibrosis due to nervous system prosthetic devices, implants and grafts, subsequent encounter*/
,'T85820S'  /*Fibrosis due to nervous system prosthetic devices, implants and grafts, sequela*/
,'T85828D'  /*Fibrosis due to other internal prosthetic devices, implants and grafts, subsequent encounter*/
,'T85828S'  /*Fibrosis due to other internal prosthetic devices, implants and grafts, sequela*/
,'T85830D'  /*Hemorrhage due to nervous system prosthetic devices, implants and grafts, subsequent encounter*/
,'T85830S'  /*Hemorrhage due to nervous system prosthetic devices, implants and grafts, sequela*/
,'T85838D'  /*Hemorrhage due to other internal prosthetic devices, implants and grafts, subsequent encounter*/
,'T85838S'  /*Hemorrhage due to other internal prosthetic devices, implants and grafts, sequela*/
,'T85840D'  /*Pain due to nervous system prosthetic devices, implants and grafts, subsequent encounter*/
,'T85840S'  /*Pain due to nervous system prosthetic devices, implants and grafts, sequela*/
,'T85848D'  /*Pain due to other internal prosthetic devices, implants and grafts, subsequent encounter*/
,'T85848S'  /*Pain due to other internal prosthetic devices, implants and grafts, sequela*/
,'T85850D'  /*Stenosis due to nervous system prosthetic devices, implants and grafts, subsequent encounter*/
,'T85850S'  /*Stenosis due to nervous system prosthetic devices, implants and grafts, sequela*/
,'T85858D'  /*Stenosis due to other internal prosthetic devices, implants and grafts, subsequent encounter*/
,'T85858S'  /*Stenosis due to other internal prosthetic devices, implants and grafts, sequela*/
,'T85860D'  /*Thrombosis due to nervous system prosthetic devices, implants and grafts, subsequent encounter*/
,'T85860S'  /*Thrombosis due to nervous system prosthetic devices, implants and grafts, sequela*/
,'T85868D'  /*Thrombosis due to other internal prosthetic devices, implants and grafts, subsequent encounter*/
,'T85868S'  /*Thrombosis due to other internal prosthetic devices, implants and grafts, sequela*/
,'T85890D'  /*Other specified complication of nervous system prosthetic devices, implants and grafts, subsequent encounter*/
,'T85890S'  /*Other specified complication of nervous system prosthetic devices, implants and grafts, sequela*/
,'T85898D'  /*Other specified complication of other internal prosthetic devices, implants and grafts, subsequent encounter*/
,'T85898S'  /*Other specified complication of other internal prosthetic devices, implants and grafts, sequela*/
,'T859XXD'  /*Unspecified complication of internal prosthetic device, implant and graft, subsequent encounter*/
,'T859XXS'  /*Unspecified complication of internal prosthetic device, implant and graft, sequela*/
,'T880XXD'  /*Infection following immunization, subsequent encounter*/
,'T880XXS'  /*Infection following immunization, sequela*/
,'T881XXD'  /*Other complications following immunization, not elsewhere classified, subsequent encounter*/
,'T881XXS'  /*Other complications following immunization, not elsewhere classified, sequela*/
,'T882XXD'  /*Shock due to anesthesia, subsequent encounter*/
,'T882XXS'  /*Shock due to anesthesia, sequela*/
,'T883XXD'  /*Malignant hyperthermia due to anesthesia, subsequent encounter*/
,'T883XXS'  /*Malignant hyperthermia due to anesthesia, sequela*/
,'T884XXD'  /*Failed or difficult intubation, subsequent encounter*/
,'T884XXS'  /*Failed or difficult intubation, sequela*/
,'T8851XD'  /*Hypothermia following anesthesia, subsequent encounter*/
,'T8851XS'  /*Hypothermia following anesthesia, sequela*/
,'T8852XD'  /*Failed moderate sedation during procedure, subsequent encounter*/
,'T8852XS'  /*Failed moderate sedation during procedure, sequela*/
,'T8853XD'  /*Unintended awareness under general anesthesia during procedure, subsequent encounter*/
,'T8853XS'  /*Unintended awareness under general anesthesia during procedure, sequela*/
,'T8859XD'  /*Other complications of anesthesia, subsequent encounter*/
,'T8859XS'  /*Other complications of anesthesia, sequela*/
,'T886XXD'  /*Anaphylactic reaction due to adverse effect of correct drug or medicament properly administered, subsequent encounter*/
,'T886XXS'  /*Anaphylactic reaction due to adverse effect of correct drug or medicament properly administered, sequela*/
,'T887XXD'  /*Unspecified adverse effect of drug or medicament, subsequent encounter*/
,'T887XXS'  /*Unspecified adverse effect of drug or medicament, sequela*/
,'T888XXD'  /*Other specified complications of surgical and medical care, not elsewhere classified, subsequent encounter*/
,'T888XXS'  /*Other specified complications of surgical and medical care, not elsewhere classified, sequela*/
,'T889XXD'  /*Complication of surgical and medical care, unspecified, subsequent encounter*/
,'T889XXS'  /*Complication of surgical and medical care, unspecified, sequela*/
,'V0001XA'  /*Pedestrian on foot injured in collision with roller-skater, initial encounter*/
,'V0001XD'  /*Pedestrian on foot injured in collision with roller-skater, subsequent encounter*/
,'V0001XS'  /*Pedestrian on foot injured in collision with roller-skater, sequela*/
,'V0002XA'  /*Pedestrian on foot injured in collision with skateboarder, initial encounter*/
,'V0002XD'  /*Pedestrian on foot injured in collision with skateboarder, subsequent encounter*/
,'V0002XS'  /*Pedestrian on foot injured in collision with skateboarder, sequela*/
,'V0009XA'  /*Pedestrian on foot injured in collision with other pedestrian conveyance, initial encounter*/
,'V0009XD'  /*Pedestrian on foot injured in collision with other pedestrian conveyance, subsequent encounter*/
,'V0009XS'  /*Pedestrian on foot injured in collision with other pedestrian conveyance, sequela*/
,'V00111A'  /*Fall from in-line roller-skates, initial encounter*/
,'V00111D'  /*Fall from in-line roller-skates, subsequent encounter*/
,'V00111S'  /*Fall from in-line roller-skates, sequela*/
,'V00112A'  /*In-line roller-skater colliding with stationary object, initial encounter*/
,'V00112D'  /*In-line roller-skater colliding with stationary object, subsequent encounter*/
,'V00112S'  /*In-line roller-skater colliding with stationary object, sequela*/
,'V00118A'  /*Other in-line roller-skate accident, initial encounter*/
,'V00118D'  /*Other in-line roller-skate accident, subsequent encounter*/
,'V00118S'  /*Other in-line roller-skate accident, sequela*/
,'V00121A'  /*Fall from non-in-line roller-skates, initial encounter*/
,'V00121D'  /*Fall from non-in-line roller-skates, subsequent encounter*/
,'V00121S'  /*Fall from non-in-line roller-skates, sequela*/
,'V00122A'  /*Non-in-line roller-skater colliding with stationary object, initial encounter*/
,'V00122D'  /*Non-in-line roller-skater colliding with stationary object, subsequent encounter*/
,'V00122S'  /*Non-in-line roller-skater colliding with stationary object, sequela*/
,'V00128A'  /*Other non-in-line roller-skating accident, initial encounter*/
,'V00128D'  /*Other non-in-line roller-skating accident, subsequent encounter*/
,'V00128S'  /*Other non-in-line roller-skating accident, sequela*/
,'V00131A'  /*Fall from skateboard, initial encounter*/
,'V00131D'  /*Fall from skateboard, subsequent encounter*/
,'V00131S'  /*Fall from skateboard, sequela*/
,'V00132A'  /*Skateboarder colliding with stationary object, initial encounter*/
,'V00132D'  /*Skateboarder colliding with stationary object, subsequent encounter*/
,'V00132S'  /*Skateboarder colliding with stationary object, sequela*/
,'V00138A'  /*Other skateboard accident, initial encounter*/
,'V00138D'  /*Other skateboard accident, subsequent encounter*/
,'V00138S'  /*Other skateboard accident, sequela*/
,'V00141A'  /*Fall from scooter (nonmotorized), initial encounter*/
,'V00141D'  /*Fall from scooter (nonmotorized), subsequent encounter*/
,'V00141S'  /*Fall from scooter (nonmotorized), sequela*/
,'V00142A'  /*Scooter (nonmotorized) colliding with stationary object, initial encounter*/
,'V00142D'  /*Scooter (nonmotorized) colliding with stationary object, subsequent encounter*/
,'V00142S'  /*Scooter (nonmotorized) colliding with stationary object, sequela*/
,'V00148A'  /*Other scooter (nonmotorized) accident, initial encounter*/
,'V00148D'  /*Other scooter (nonmotorized) accident, subsequent encounter*/
,'V00148S'  /*Other scooter (nonmotorized) accident, sequela*/
,'V00151A'  /*Fall from heelies, initial encounter*/
,'V00151D'  /*Fall from heelies, subsequent encounter*/
,'V00151S'  /*Fall from heelies, sequela*/
,'V00152A'  /*Heelies colliding with stationary object, initial encounter*/
,'V00152D'  /*Heelies colliding with stationary object, subsequent encounter*/
,'V00152S'  /*Heelies colliding with stationary object, sequela*/
,'V00158A'  /*Other heelies accident, initial encounter*/
,'V00158D'  /*Other heelies accident, subsequent encounter*/
,'V00158S'  /*Other heelies accident, sequela*/
,'V00181A'  /*Fall from other rolling-type pedestrian conveyance, initial encounter*/
,'V00181D'  /*Fall from other rolling-type pedestrian conveyance, subsequent encounter*/
,'V00181S'  /*Fall from other rolling-type pedestrian conveyance, sequela*/
,'V00182A'  /*Pedestrian on other rolling-type pedestrian conveyance colliding with stationary object, initial encounter*/
,'V00182D'  /*Pedestrian on other rolling-type pedestrian conveyance colliding with stationary object, subsequent encounter*/
,'V00182S'  /*Pedestrian on other rolling-type pedestrian conveyance colliding with stationary object, sequela*/
,'V00188A'  /*Other accident on other rolling-type pedestrian conveyance, initial encounter*/
,'V00188D'  /*Other accident on other rolling-type pedestrian conveyance, subsequent encounter*/
,'V00188S'  /*Other accident on other rolling-type pedestrian conveyance, sequela*/
,'V00211A'  /*Fall from ice-skates, initial encounter*/
,'V00211D'  /*Fall from ice-skates, subsequent encounter*/
,'V00211S'  /*Fall from ice-skates, sequela*/
,'V00212A'  /*Ice-skater colliding with stationary object, initial encounter*/
,'V00212D'  /*Ice-skater colliding with stationary object, subsequent encounter*/
,'V00212S'  /*Ice-skater colliding with stationary object, sequela*/
,'V00218A'  /*Other ice-skates accident, initial encounter*/
,'V00218D'  /*Other ice-skates accident, subsequent encounter*/
,'V00218S'  /*Other ice-skates accident, sequela*/
,'V00221A'  /*Fall from sled, initial encounter*/
,'V00221D'  /*Fall from sled, subsequent encounter*/
,'V00221S'  /*Fall from sled, sequela*/
,'V00222A'  /*Sledder colliding with stationary object, initial encounter*/
,'V00222D'  /*Sledder colliding with stationary object, subsequent encounter*/
,'V00222S'  /*Sledder colliding with stationary object, sequela*/
,'V00228A'  /*Other sled accident, initial encounter*/
,'V00228D'  /*Other sled accident, subsequent encounter*/
,'V00228S'  /*Other sled accident, sequela*/
,'V00281A'  /*Fall from other gliding-type pedestrian conveyance, initial encounter*/
,'V00281D'  /*Fall from other gliding-type pedestrian conveyance, subsequent encounter*/
,'V00281S'  /*Fall from other gliding-type pedestrian conveyance, sequela*/
,'V00282A'  /*Pedestrian on other gliding-type pedestrian conveyance colliding with stationary object, initial encounter*/
,'V00282D'  /*Pedestrian on other gliding-type pedestrian conveyance colliding with stationary object, subsequent encounter*/
,'V00282S'  /*Pedestrian on other gliding-type pedestrian conveyance colliding with stationary object, sequela*/
,'V00288A'  /*Other accident on other gliding-type pedestrian conveyance, initial encounter*/
,'V00288D'  /*Other accident on other gliding-type pedestrian conveyance, subsequent encounter*/
,'V00288S'  /*Other accident on other gliding-type pedestrian conveyance, sequela*/
,'V00311A'  /*Fall from snowboard, initial encounter*/
,'V00311D'  /*Fall from snowboard, subsequent encounter*/
,'V00311S'  /*Fall from snowboard, sequela*/
,'V00312A'  /*Snowboarder colliding with stationary object, initial encounter*/
,'V00312D'  /*Snowboarder colliding with stationary object, subsequent encounter*/
,'V00312S'  /*Snowboarder colliding with stationary object, sequela*/
,'V00318A'  /*Other snowboard accident, initial encounter*/
,'V00318D'  /*Other snowboard accident, subsequent encounter*/
,'V00318S'  /*Other snowboard accident, sequela*/
,'V00321A'  /*Fall from snow-skis, initial encounter*/
,'V00321D'  /*Fall from snow-skis, subsequent encounter*/
,'V00321S'  /*Fall from snow-skis, sequela*/
,'V00322A'  /*Snow-skier colliding with stationary object, initial encounter*/
,'V00322D'  /*Snow-skier colliding with stationary object, subsequent encounter*/
,'V00322S'  /*Snow-skier colliding with stationary object, sequela*/
,'V00328A'  /*Other snow-ski accident, initial encounter*/
,'V00328D'  /*Other snow-ski accident, subsequent encounter*/
,'V00328S'  /*Other snow-ski accident, sequela*/
,'V00381A'  /*Fall from other flat-bottomed pedestrian conveyance, initial encounter*/
,'V00381D'  /*Fall from other flat-bottomed pedestrian conveyance, subsequent encounter*/
,'V00381S'  /*Fall from other flat-bottomed pedestrian conveyance, sequela*/
,'V00382A'  /*Pedestrian on other flat-bottomed pedestrian conveyance colliding with stationary object, initial encounter*/
,'V00382D'  /*Pedestrian on other flat-bottomed pedestrian conveyance colliding with stationary object, subsequent encounter*/
,'V00382S'  /*Pedestrian on other flat-bottomed pedestrian conveyance colliding with stationary object, sequela*/
,'V00388A'  /*Other accident on other flat-bottomed pedestrian conveyance, initial encounter*/
,'V00388D'  /*Other accident on other flat-bottomed pedestrian conveyance, subsequent encounter*/
,'V00388S'  /*Other accident on other flat-bottomed pedestrian conveyance, sequela*/
,'V00821A'  /*Fall from babystroller, initial encounter*/
,'V00821D'  /*Fall from babystroller, subsequent encounter*/
,'V00821S'  /*Fall from babystroller, sequela*/
,'V00822D'  /*Babystroller colliding with stationary object, subsequent encounter*/
,'V00822S'  /*Babystroller colliding with stationary object, sequela*/
,'V00828D'  /*Other accident with babystroller, subsequent encounter*/
,'V00828S'  /*Other accident with babystroller, sequela*/
,'V00891A'  /*Fall from other pedestrian conveyance, initial encounter*/
,'V00891D'  /*Fall from other pedestrian conveyance, subsequent encounter*/
,'V00891S'  /*Fall from other pedestrian conveyance, sequela*/
,'V00892A'  /*Pedestrian on other pedestrian conveyance colliding with stationary object, initial encounter*/
,'V00892D'  /*Pedestrian on other pedestrian conveyance colliding with stationary object, subsequent encounter*/
,'V00892S'  /*Pedestrian on other pedestrian conveyance colliding with stationary object, sequela*/
,'V00898A'  /*Other accident on other pedestrian conveyance, initial encounter*/
,'V00898D'  /*Other accident on other pedestrian conveyance, subsequent encounter*/
,'V00898S'  /*Other accident on other pedestrian conveyance, sequela*/
,'V0100XA'  /*Pedestrian on foot injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V0100XD'  /*Pedestrian on foot injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V0100XS'  /*Pedestrian on foot injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V0101XA'  /*Pedestrian on roller-skates injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V0101XD'  /*Pedestrian on roller-skates injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V0101XS'  /*Pedestrian on roller-skates injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V0102XA'  /*Pedestrian on skateboard injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V0102XD'  /*Pedestrian on skateboard injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V0102XS'  /*Pedestrian on skateboard injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V0109XA'  /*Pedestrian with other conveyance injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V0109XD'  /*Pedestrian with other conveyance injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V0109XS'  /*Pedestrian with other conveyance injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V0110XA'  /*Pedestrian on foot injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V0110XD'  /*Pedestrian on foot injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V0110XS'  /*Pedestrian on foot injured in collision with pedal cycle in traffic accident, sequela*/
,'V0111XA'  /*Pedestrian on roller-skates injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V0111XD'  /*Pedestrian on roller-skates injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V0111XS'  /*Pedestrian on roller-skates injured in collision with pedal cycle in traffic accident, sequela*/
,'V0112XA'  /*Pedestrian on skateboard injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V0112XD'  /*Pedestrian on skateboard injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V0112XS'  /*Pedestrian on skateboard injured in collision with pedal cycle in traffic accident, sequela*/
,'V0119XA'  /*Pedestrian with other conveyance injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V0119XD'  /*Pedestrian with other conveyance injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V0119XS'  /*Pedestrian with other conveyance injured in collision with pedal cycle in traffic accident, sequela*/
,'V0190XA'  /*Pedestrian on foot injured in collision with pedal cycle, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0190XD'  /*Pedestrian on foot injured in collision with pedal cycle, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0190XS'  /*Pedestrian on foot injured in collision with pedal cycle, unspecified whether traffic or nontraffic accident, sequela*/
,'V0191XA'  /*Pedestrian on roller-skates injured in collision with pedal cycle, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0191XD'  /*Pedestrian on roller-skates injured in collision with pedal cycle, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0191XS'  /*Pedestrian on roller-skates injured in collision with pedal cycle, unspecified whether traffic or nontraffic accident, sequela*/
,'V0192XA'  /*Pedestrian on skateboard injured in collision with pedal cycle, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0192XD'  /*Pedestrian on skateboard injured in collision with pedal cycle, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0192XS'  /*Pedestrian on skateboard injured in collision with pedal cycle, unspecified whether traffic or nontraffic accident, sequela*/
,'V0199XA'  /*Pedestrian with other conveyance injured in collision with pedal cycle, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0199XD'  /*Pedestrian with other conveyance injured in collision with pedal cycle, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0199XS'  /*Pedestrian with other conveyance injured in collision with pedal cycle, unspecified whether traffic or nontraffic accident, sequela*/
,'V0200XA'  /*Pedestrian on foot injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V0200XD'  /*Pedestrian on foot injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V0200XS'  /*Pedestrian on foot injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V0201XA'  /*Pedestrian on roller-skates injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V0201XD'  /*Pedestrian on roller-skates injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V0201XS'  /*Pedestrian on roller-skates injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V0202XA'  /*Pedestrian on skateboard injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V0202XD'  /*Pedestrian on skateboard injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V0202XS'  /*Pedestrian on skateboard injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V0209XA'  /*Pedestrian with other conveyance injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V0209XD'  /*Pedestrian with other conveyance injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V0209XS'  /*Pedestrian with other conveyance injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V0210XA'  /*Pedestrian on foot injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V0210XD'  /*Pedestrian on foot injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V0210XS'  /*Pedestrian on foot injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V0211XA'  /*Pedestrian on roller-skates injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V0211XD'  /*Pedestrian on roller-skates injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V0211XS'  /*Pedestrian on roller-skates injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V0212XA'  /*Pedestrian on skateboard injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V0212XD'  /*Pedestrian on skateboard injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V0212XS'  /*Pedestrian on skateboard injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V0219XA'  /*Pedestrian with other conveyance injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V0219XD'  /*Pedestrian with other conveyance injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V0219XS'  /*Pedestrian with other conveyance injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V0290XA'  /*Pedestrian on foot injured in collision with two- or three-wheeled motor vehicle, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0290XD'  /*Pedestrian on foot injured in collision with two- or three-wheeled motor vehicle, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0290XS'  /*Pedestrian on foot injured in collision with two- or three-wheeled motor vehicle, unspecified whether traffic or nontraffic accident, sequela*/
,'V0291XA'  /*Pedestrian on roller-skates injured in collision with two- or three-wheeled motor vehicle, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0291XD'  /*Pedestrian on roller-skates injured in collision with two- or three-wheeled motor vehicle, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0291XS'  /*Pedestrian on roller-skates injured in collision with two- or three-wheeled motor vehicle, unspecified whether traffic or nontraffic accident, sequela*/
,'V0292XA'  /*Pedestrian on skateboard injured in collision with two- or three-wheeled motor vehicle, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0292XD'  /*Pedestrian on skateboard injured in collision with two- or three-wheeled motor vehicle, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0292XS'  /*Pedestrian on skateboard injured in collision with two- or three-wheeled motor vehicle, unspecified whether traffic or nontraffic accident, sequela*/
,'V0299XA'  /*Pedestrian with other conveyance injured in collision with two- or three-wheeled motor vehicle, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0299XD'  /*Pedestrian with other conveyance injured in collision with two- or three-wheeled motor vehicle, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0299XS'  /*Pedestrian with other conveyance injured in collision with two- or three-wheeled motor vehicle, unspecified whether traffic or nontraffic accident, sequela*/
,'V0300XA'  /*Pedestrian on foot injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V0300XD'  /*Pedestrian on foot injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V0300XS'  /*Pedestrian on foot injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V0301XA'  /*Pedestrian on roller-skates injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V0301XD'  /*Pedestrian on roller-skates injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V0301XS'  /*Pedestrian on roller-skates injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V0302XA'  /*Pedestrian on skateboard injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V0302XD'  /*Pedestrian on skateboard injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V0302XS'  /*Pedestrian on skateboard injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V0309XA'  /*Pedestrian with other conveyance injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V0309XD'  /*Pedestrian with other conveyance injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V0309XS'  /*Pedestrian with other conveyance injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V0310XA'  /*Pedestrian on foot injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V0310XD'  /*Pedestrian on foot injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V0310XS'  /*Pedestrian on foot injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V0311XA'  /*Pedestrian on roller-skates injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V0311XD'  /*Pedestrian on roller-skates injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V0311XS'  /*Pedestrian on roller-skates injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V0312XA'  /*Pedestrian on skateboard injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V0312XD'  /*Pedestrian on skateboard injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V0312XS'  /*Pedestrian on skateboard injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V0319XA'  /*Pedestrian with other conveyance injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V0319XD'  /*Pedestrian with other conveyance injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V0319XS'  /*Pedestrian with other conveyance injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V0390XA'  /*Pedestrian on foot injured in collision with car, pick-up truck or van, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0390XD'  /*Pedestrian on foot injured in collision with car, pick-up truck or van, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0390XS'  /*Pedestrian on foot injured in collision with car, pick-up truck or van, unspecified whether traffic or nontraffic accident, sequela*/
,'V0391XA'  /*Pedestrian on roller-skates injured in collision with car, pick-up truck or van, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0391XD'  /*Pedestrian on roller-skates injured in collision with car, pick-up truck or van, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0391XS'  /*Pedestrian on roller-skates injured in collision with car, pick-up truck or van, unspecified whether traffic or nontraffic accident, sequela*/
,'V0392XA'  /*Pedestrian on skateboard injured in collision with car, pick-up truck or van, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0392XD'  /*Pedestrian on skateboard injured in collision with car, pick-up truck or van, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0392XS'  /*Pedestrian on skateboard injured in collision with car, pick-up truck or van, unspecified whether traffic or nontraffic accident, sequela*/
,'V0399XA'  /*Pedestrian with other conveyance injured in collision with car, pick-up truck or van, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0399XD'  /*Pedestrian with other conveyance injured in collision with car, pick-up truck or van, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0399XS'  /*Pedestrian with other conveyance injured in collision with car, pick-up truck or van, unspecified whether traffic or nontraffic accident, sequela*/
,'V0400XA'  /*Pedestrian on foot injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V0400XD'  /*Pedestrian on foot injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V0400XS'  /*Pedestrian on foot injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V0401XA'  /*Pedestrian on roller-skates injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V0401XD'  /*Pedestrian on roller-skates injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V0401XS'  /*Pedestrian on roller-skates injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V0402XA'  /*Pedestrian on skateboard injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V0402XD'  /*Pedestrian on skateboard injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V0402XS'  /*Pedestrian on skateboard injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V0409XA'  /*Pedestrian with other conveyance injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V0409XD'  /*Pedestrian with other conveyance injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V0409XS'  /*Pedestrian with other conveyance injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V0410XA'  /*Pedestrian on foot injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V0410XD'  /*Pedestrian on foot injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V0410XS'  /*Pedestrian on foot injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V0411XA'  /*Pedestrian on roller-skates injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V0411XD'  /*Pedestrian on roller-skates injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V0411XS'  /*Pedestrian on roller-skates injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V0412XA'  /*Pedestrian on skateboard injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V0412XD'  /*Pedestrian on skateboard injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V0412XS'  /*Pedestrian on skateboard injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V0419XA'  /*Pedestrian with other conveyance injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V0419XD'  /*Pedestrian with other conveyance injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V0419XS'  /*Pedestrian with other conveyance injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V0490XA'  /*Pedestrian on foot injured in collision with heavy transport vehicle or bus, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0490XD'  /*Pedestrian on foot injured in collision with heavy transport vehicle or bus, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0490XS'  /*Pedestrian on foot injured in collision with heavy transport vehicle or bus, unspecified whether traffic or nontraffic accident, sequela*/
,'V0491XA'  /*Pedestrian on roller-skates injured in collision with heavy transport vehicle or bus, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0491XD'  /*Pedestrian on roller-skates injured in collision with heavy transport vehicle or bus, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0491XS'  /*Pedestrian on roller-skates injured in collision with heavy transport vehicle or bus, unspecified whether traffic or nontraffic accident, sequela*/
,'V0492XA'  /*Pedestrian on skateboard injured in collision with heavy transport vehicle or bus, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0492XD'  /*Pedestrian on skateboard injured in collision with heavy transport vehicle or bus, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0492XS'  /*Pedestrian on skateboard injured in collision with heavy transport vehicle or bus, unspecified whether traffic or nontraffic accident, sequela*/
,'V0499XA'  /*Pedestrian with other conveyance injured in collision with heavy transport vehicle or bus, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0499XD'  /*Pedestrian with other conveyance injured in collision with heavy transport vehicle or bus, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0499XS'  /*Pedestrian with other conveyance injured in collision with heavy transport vehicle or bus, unspecified whether traffic or nontraffic accident, sequela*/
,'V0500XA'  /*Pedestrian on foot injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V0500XD'  /*Pedestrian on foot injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V0500XS'  /*Pedestrian on foot injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V0501XA'  /*Pedestrian on roller-skates injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V0501XD'  /*Pedestrian on roller-skates injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V0501XS'  /*Pedestrian on roller-skates injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V0502XA'  /*Pedestrian on skateboard injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V0502XD'  /*Pedestrian on skateboard injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V0502XS'  /*Pedestrian on skateboard injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V0509XA'  /*Pedestrian with other conveyance injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V0509XD'  /*Pedestrian with other conveyance injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V0509XS'  /*Pedestrian with other conveyance injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V0510XA'  /*Pedestrian on foot injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V0510XD'  /*Pedestrian on foot injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V0510XS'  /*Pedestrian on foot injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V0511XA'  /*Pedestrian on roller-skates injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V0511XD'  /*Pedestrian on roller-skates injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V0511XS'  /*Pedestrian on roller-skates injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V0512XA'  /*Pedestrian on skateboard injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V0512XD'  /*Pedestrian on skateboard injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V0512XS'  /*Pedestrian on skateboard injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V0519XA'  /*Pedestrian with other conveyance injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V0519XD'  /*Pedestrian with other conveyance injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V0519XS'  /*Pedestrian with other conveyance injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V0590XA'  /*Pedestrian on foot injured in collision with railway train or railway vehicle, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0590XD'  /*Pedestrian on foot injured in collision with railway train or railway vehicle, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0590XS'  /*Pedestrian on foot injured in collision with railway train or railway vehicle, unspecified whether traffic or nontraffic accident, sequela*/
,'V0591XA'  /*Pedestrian on roller-skates injured in collision with railway train or railway vehicle, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0591XD'  /*Pedestrian on roller-skates injured in collision with railway train or railway vehicle, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0591XS'  /*Pedestrian on roller-skates injured in collision with railway train or railway vehicle, unspecified whether traffic or nontraffic accident, sequela*/
,'V0592XA'  /*Pedestrian on skateboard injured in collision with railway train or railway vehicle, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0592XD'  /*Pedestrian on skateboard injured in collision with railway train or railway vehicle, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0592XS'  /*Pedestrian on skateboard injured in collision with railway train or railway vehicle, unspecified whether traffic or nontraffic accident, sequela*/
,'V0599XA'  /*Pedestrian with other conveyance injured in collision with railway train or railway vehicle, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0599XD'  /*Pedestrian with other conveyance injured in collision with railway train or railway vehicle, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0599XS'  /*Pedestrian with other conveyance injured in collision with railway train or railway vehicle, unspecified whether traffic or nontraffic accident, sequela*/
,'V0600XA'  /*Pedestrian on foot injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V0600XD'  /*Pedestrian on foot injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V0600XS'  /*Pedestrian on foot injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V0601XA'  /*Pedestrian on roller-skates injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V0601XD'  /*Pedestrian on roller-skates injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V0601XS'  /*Pedestrian on roller-skates injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V0602XA'  /*Pedestrian on skateboard injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V0602XD'  /*Pedestrian on skateboard injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V0602XS'  /*Pedestrian on skateboard injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V0609XA'  /*Pedestrian with other conveyance injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V0609XD'  /*Pedestrian with other conveyance injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V0609XS'  /*Pedestrian with other conveyance injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V0610XA'  /*Pedestrian on foot injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V0610XD'  /*Pedestrian on foot injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V0610XS'  /*Pedestrian on foot injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V0611XA'  /*Pedestrian on roller-skates injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V0611XD'  /*Pedestrian on roller-skates injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V0611XS'  /*Pedestrian on roller-skates injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V0612XA'  /*Pedestrian on skateboard injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V0612XD'  /*Pedestrian on skateboard injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V0612XS'  /*Pedestrian on skateboard injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V0619XA'  /*Pedestrian with other conveyance injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V0619XD'  /*Pedestrian with other conveyance injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V0619XS'  /*Pedestrian with other conveyance injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V0690XA'  /*Pedestrian on foot injured in collision with other nonmotor vehicle, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0690XD'  /*Pedestrian on foot injured in collision with other nonmotor vehicle, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0690XS'  /*Pedestrian on foot injured in collision with other nonmotor vehicle, unspecified whether traffic or nontraffic accident, sequela*/
,'V0691XA'  /*Pedestrian on roller-skates injured in collision with other nonmotor vehicle, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0691XD'  /*Pedestrian on roller-skates injured in collision with other nonmotor vehicle, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0691XS'  /*Pedestrian on roller-skates injured in collision with other nonmotor vehicle, unspecified whether traffic or nontraffic accident, sequela*/
,'V0692XA'  /*Pedestrian on skateboard injured in collision with other nonmotor vehicle, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0692XD'  /*Pedestrian on skateboard injured in collision with other nonmotor vehicle, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0692XS'  /*Pedestrian on skateboard injured in collision with other nonmotor vehicle, unspecified whether traffic or nontraffic accident, sequela*/
,'V0699XA'  /*Pedestrian with other conveyance injured in collision with other nonmotor vehicle, unspecified whether traffic or nontraffic accident, initial encounter*/
,'V0699XD'  /*Pedestrian with other conveyance injured in collision with other nonmotor vehicle, unspecified whether traffic or nontraffic accident, subsequent encounter*/
,'V0699XS'  /*Pedestrian with other conveyance injured in collision with other nonmotor vehicle, unspecified whether traffic or nontraffic accident, sequela*/
,'V0900XA'  /*Pedestrian injured in nontraffic accident involving unspecified motor vehicles, initial encounter*/
,'V0900XD'  /*Pedestrian injured in nontraffic accident involving unspecified motor vehicles, subsequent encounter*/
,'V0900XS'  /*Pedestrian injured in nontraffic accident involving unspecified motor vehicles, sequela*/
,'V0901XA'  /*Pedestrian injured in nontraffic accident involving military vehicle, initial encounter*/
,'V0901XD'  /*Pedestrian injured in nontraffic accident involving military vehicle, subsequent encounter*/
,'V0901XS'  /*Pedestrian injured in nontraffic accident involving military vehicle, sequela*/
,'V0909XA'  /*Pedestrian injured in nontraffic accident involving other motor vehicles, initial encounter*/
,'V0909XD'  /*Pedestrian injured in nontraffic accident involving other motor vehicles, subsequent encounter*/
,'V0909XS'  /*Pedestrian injured in nontraffic accident involving other motor vehicles, sequela*/
,'V091XXA'  /*Pedestrian injured in unspecified nontraffic accident, initial encounter*/
,'V091XXD'  /*Pedestrian injured in unspecified nontraffic accident, subsequent encounter*/
,'V091XXS'  /*Pedestrian injured in unspecified nontraffic accident, sequela*/
,'V0920XA'  /*Pedestrian injured in traffic accident involving unspecified motor vehicles, initial encounter*/
,'V0920XD'  /*Pedestrian injured in traffic accident involving unspecified motor vehicles, subsequent encounter*/
,'V0920XS'  /*Pedestrian injured in traffic accident involving unspecified motor vehicles, sequela*/
,'V0921XA'  /*Pedestrian injured in traffic accident involving military vehicle, initial encounter*/
,'V0921XD'  /*Pedestrian injured in traffic accident involving military vehicle, subsequent encounter*/
,'V0921XS'  /*Pedestrian injured in traffic accident involving military vehicle, sequela*/
,'V0929XA'  /*Pedestrian injured in traffic accident involving other motor vehicles, initial encounter*/
,'V0929XD'  /*Pedestrian injured in traffic accident involving other motor vehicles, subsequent encounter*/
,'V0929XS'  /*Pedestrian injured in traffic accident involving other motor vehicles, sequela*/
,'V093XXA'  /*Pedestrian injured in unspecified traffic accident, initial encounter*/
,'V093XXD'  /*Pedestrian injured in unspecified traffic accident, subsequent encounter*/
,'V093XXS'  /*Pedestrian injured in unspecified traffic accident, sequela*/
,'V099XXA'  /*Pedestrian injured in unspecified transport accident, initial encounter*/
,'V099XXD'  /*Pedestrian injured in unspecified transport accident, subsequent encounter*/
,'V099XXS'  /*Pedestrian injured in unspecified transport accident, sequela*/
,'V100XXA'  /*Pedal cycle driver injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V100XXD'  /*Pedal cycle driver injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V100XXS'  /*Pedal cycle driver injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V101XXA'  /*Pedal cycle passenger injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V101XXD'  /*Pedal cycle passenger injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V101XXS'  /*Pedal cycle passenger injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V102XXA'  /*Unspecified pedal cyclist injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V102XXD'  /*Unspecified pedal cyclist injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V102XXS'  /*Unspecified pedal cyclist injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V103XXA'  /*Person boarding or alighting a pedal cycle injured in collision with pedestrian or animal, initial encounter*/
,'V103XXD'  /*Person boarding or alighting a pedal cycle injured in collision with pedestrian or animal, subsequent encounter*/
,'V103XXS'  /*Person boarding or alighting a pedal cycle injured in collision with pedestrian or animal, sequela*/
,'V104XXA'  /*Pedal cycle driver injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V104XXD'  /*Pedal cycle driver injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V104XXS'  /*Pedal cycle driver injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V105XXA'  /*Pedal cycle passenger injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V105XXD'  /*Pedal cycle passenger injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V105XXS'  /*Pedal cycle passenger injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V109XXA'  /*Unspecified pedal cyclist injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V109XXD'  /*Unspecified pedal cyclist injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V109XXS'  /*Unspecified pedal cyclist injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V110XXA'  /*Pedal cycle driver injured in collision with other pedal cycle in nontraffic accident, initial encounter*/
,'V110XXD'  /*Pedal cycle driver injured in collision with other pedal cycle in nontraffic accident, subsequent encounter*/
,'V110XXS'  /*Pedal cycle driver injured in collision with other pedal cycle in nontraffic accident, sequela*/
,'V111XXA'  /*Pedal cycle passenger injured in collision with other pedal cycle in nontraffic accident, initial encounter*/
,'V111XXD'  /*Pedal cycle passenger injured in collision with other pedal cycle in nontraffic accident, subsequent encounter*/
,'V111XXS'  /*Pedal cycle passenger injured in collision with other pedal cycle in nontraffic accident, sequela*/
,'V112XXA'  /*Unspecified pedal cyclist injured in collision with other pedal cycle in nontraffic accident, initial encounter*/
,'V112XXD'  /*Unspecified pedal cyclist injured in collision with other pedal cycle in nontraffic accident, subsequent encounter*/
,'V112XXS'  /*Unspecified pedal cyclist injured in collision with other pedal cycle in nontraffic accident, sequela*/
,'V113XXA'  /*Person boarding or alighting a pedal cycle injured in collision with other pedal cycle, initial encounter*/
,'V113XXD'  /*Person boarding or alighting a pedal cycle injured in collision with other pedal cycle, subsequent encounter*/
,'V113XXS'  /*Person boarding or alighting a pedal cycle injured in collision with other pedal cycle, sequela*/
,'V114XXA'  /*Pedal cycle driver injured in collision with other pedal cycle in traffic accident, initial encounter*/
,'V114XXD'  /*Pedal cycle driver injured in collision with other pedal cycle in traffic accident, subsequent encounter*/
,'V114XXS'  /*Pedal cycle driver injured in collision with other pedal cycle in traffic accident, sequela*/
,'V115XXA'  /*Pedal cycle passenger injured in collision with other pedal cycle in traffic accident, initial encounter*/
,'V115XXD'  /*Pedal cycle passenger injured in collision with other pedal cycle in traffic accident, subsequent encounter*/
,'V115XXS'  /*Pedal cycle passenger injured in collision with other pedal cycle in traffic accident, sequela*/
,'V119XXA'  /*Unspecified pedal cyclist injured in collision with other pedal cycle in traffic accident, initial encounter*/
,'V119XXD'  /*Unspecified pedal cyclist injured in collision with other pedal cycle in traffic accident, subsequent encounter*/
,'V119XXS'  /*Unspecified pedal cyclist injured in collision with other pedal cycle in traffic accident, sequela*/
,'V120XXA'  /*Pedal cycle driver injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V120XXD'  /*Pedal cycle driver injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V120XXS'  /*Pedal cycle driver injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V121XXA'  /*Pedal cycle passenger injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V121XXD'  /*Pedal cycle passenger injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V121XXS'  /*Pedal cycle passenger injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V122XXA'  /*Unspecified pedal cyclist injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V122XXD'  /*Unspecified pedal cyclist injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V122XXS'  /*Unspecified pedal cyclist injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V123XXA'  /*Person boarding or alighting a pedal cycle injured in collision with two- or three-wheeled motor vehicle, initial encounter*/
,'V123XXD'  /*Person boarding or alighting a pedal cycle injured in collision with two- or three-wheeled motor vehicle, subsequent encounter*/
,'V123XXS'  /*Person boarding or alighting a pedal cycle injured in collision with two- or three-wheeled motor vehicle, sequela*/
,'V124XXA'  /*Pedal cycle driver injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V124XXD'  /*Pedal cycle driver injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V124XXS'  /*Pedal cycle driver injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V125XXA'  /*Pedal cycle passenger injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V125XXD'  /*Pedal cycle passenger injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V125XXS'  /*Pedal cycle passenger injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V129XXA'  /*Unspecified pedal cyclist injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V129XXD'  /*Unspecified pedal cyclist injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V129XXS'  /*Unspecified pedal cyclist injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V130XXA'  /*Pedal cycle driver injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V130XXD'  /*Pedal cycle driver injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V130XXS'  /*Pedal cycle driver injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V131XXA'  /*Pedal cycle passenger injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V131XXD'  /*Pedal cycle passenger injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V131XXS'  /*Pedal cycle passenger injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V132XXA'  /*Unspecified pedal cyclist injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V132XXD'  /*Unspecified pedal cyclist injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V132XXS'  /*Unspecified pedal cyclist injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V133XXA'  /*Person boarding or alighting a pedal cycle injured in collision with car, pick-up truck or van, initial encounter*/
,'V133XXD'  /*Person boarding or alighting a pedal cycle injured in collision with car, pick-up truck or van, subsequent encounter*/
,'V133XXS'  /*Person boarding or alighting a pedal cycle injured in collision with car, pick-up truck or van, sequela*/
,'V134XXA'  /*Pedal cycle driver injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V134XXD'  /*Pedal cycle driver injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V134XXS'  /*Pedal cycle driver injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V135XXA'  /*Pedal cycle passenger injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V135XXD'  /*Pedal cycle passenger injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V135XXS'  /*Pedal cycle passenger injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V139XXA'  /*Unspecified pedal cyclist injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V139XXD'  /*Unspecified pedal cyclist injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V139XXS'  /*Unspecified pedal cyclist injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V140XXA'  /*Pedal cycle driver injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V140XXD'  /*Pedal cycle driver injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V140XXS'  /*Pedal cycle driver injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V141XXA'  /*Pedal cycle passenger injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V141XXD'  /*Pedal cycle passenger injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V141XXS'  /*Pedal cycle passenger injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V142XXA'  /*Unspecified pedal cyclist injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V142XXD'  /*Unspecified pedal cyclist injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V142XXS'  /*Unspecified pedal cyclist injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V143XXA'  /*Person boarding or alighting a pedal cycle injured in collision with heavy transport vehicle or bus, initial encounter*/
,'V143XXD'  /*Person boarding or alighting a pedal cycle injured in collision with heavy transport vehicle or bus, subsequent encounter*/
,'V143XXS'  /*Person boarding or alighting a pedal cycle injured in collision with heavy transport vehicle or bus, sequela*/
,'V144XXA'  /*Pedal cycle driver injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V144XXD'  /*Pedal cycle driver injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V144XXS'  /*Pedal cycle driver injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V145XXA'  /*Pedal cycle passenger injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V145XXD'  /*Pedal cycle passenger injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V145XXS'  /*Pedal cycle passenger injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V149XXA'  /*Unspecified pedal cyclist injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V149XXD'  /*Unspecified pedal cyclist injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V149XXS'  /*Unspecified pedal cyclist injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V150XXA'  /*Pedal cycle driver injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V150XXD'  /*Pedal cycle driver injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V150XXS'  /*Pedal cycle driver injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V151XXA'  /*Pedal cycle passenger injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V151XXD'  /*Pedal cycle passenger injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V151XXS'  /*Pedal cycle passenger injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V152XXA'  /*Unspecified pedal cyclist injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V152XXD'  /*Unspecified pedal cyclist injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V152XXS'  /*Unspecified pedal cyclist injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V153XXA'  /*Person boarding or alighting a pedal cycle injured in collision with railway train or railway vehicle, initial encounter*/
,'V153XXD'  /*Person boarding or alighting a pedal cycle injured in collision with railway train or railway vehicle, subsequent encounter*/
,'V153XXS'  /*Person boarding or alighting a pedal cycle injured in collision with railway train or railway vehicle, sequela*/
,'V154XXA'  /*Pedal cycle driver injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V154XXD'  /*Pedal cycle driver injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V154XXS'  /*Pedal cycle driver injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V155XXA'  /*Pedal cycle passenger injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V155XXD'  /*Pedal cycle passenger injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V155XXS'  /*Pedal cycle passenger injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V159XXA'  /*Unspecified pedal cyclist injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V159XXD'  /*Unspecified pedal cyclist injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V159XXS'  /*Unspecified pedal cyclist injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V160XXA'  /*Pedal cycle driver injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V160XXD'  /*Pedal cycle driver injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V160XXS'  /*Pedal cycle driver injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V161XXA'  /*Pedal cycle passenger injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V161XXD'  /*Pedal cycle passenger injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V161XXS'  /*Pedal cycle passenger injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V162XXA'  /*Unspecified pedal cyclist injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V162XXD'  /*Unspecified pedal cyclist injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V162XXS'  /*Unspecified pedal cyclist injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V163XXA'  /*Person boarding or alighting a pedal cycle injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V163XXD'  /*Person boarding or alighting a pedal cycle injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V163XXS'  /*Person boarding or alighting a pedal cycle injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V164XXA'  /*Pedal cycle driver injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V164XXD'  /*Pedal cycle driver injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V164XXS'  /*Pedal cycle driver injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V165XXA'  /*Pedal cycle passenger injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V165XXD'  /*Pedal cycle passenger injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V165XXS'  /*Pedal cycle passenger injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V169XXA'  /*Unspecified pedal cyclist injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V169XXD'  /*Unspecified pedal cyclist injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V169XXS'  /*Unspecified pedal cyclist injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V170XXA'  /*Pedal cycle driver injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V170XXD'  /*Pedal cycle driver injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V170XXS'  /*Pedal cycle driver injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V171XXA'  /*Pedal cycle passenger injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V171XXD'  /*Pedal cycle passenger injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V171XXS'  /*Pedal cycle passenger injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V172XXA'  /*Unspecified pedal cyclist injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V172XXD'  /*Unspecified pedal cyclist injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V172XXS'  /*Unspecified pedal cyclist injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V173XXA'  /*Person boarding or alighting a pedal cycle injured in collision with fixed or stationary object, initial encounter*/
,'V173XXD'  /*Person boarding or alighting a pedal cycle injured in collision with fixed or stationary object, subsequent encounter*/
,'V173XXS'  /*Person boarding or alighting a pedal cycle injured in collision with fixed or stationary object, sequela*/
,'V174XXA'  /*Pedal cycle driver injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V174XXD'  /*Pedal cycle driver injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V174XXS'  /*Pedal cycle driver injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V175XXA'  /*Pedal cycle passenger injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V175XXD'  /*Pedal cycle passenger injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V175XXS'  /*Pedal cycle passenger injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V179XXA'  /*Unspecified pedal cyclist injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V179XXD'  /*Unspecified pedal cyclist injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V179XXS'  /*Unspecified pedal cyclist injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V180XXA'  /*Pedal cycle driver injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V180XXD'  /*Pedal cycle driver injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V180XXS'  /*Pedal cycle driver injured in noncollision transport accident in nontraffic accident, sequela*/
,'V181XXA'  /*Pedal cycle passenger injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V181XXD'  /*Pedal cycle passenger injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V181XXS'  /*Pedal cycle passenger injured in noncollision transport accident in nontraffic accident, sequela*/
,'V182XXA'  /*Unspecified pedal cyclist injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V182XXD'  /*Unspecified pedal cyclist injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V182XXS'  /*Unspecified pedal cyclist injured in noncollision transport accident in nontraffic accident, sequela*/
,'V183XXA'  /*Person boarding or alighting a pedal cycle injured in noncollision transport accident, initial encounter*/
,'V183XXD'  /*Person boarding or alighting a pedal cycle injured in noncollision transport accident, subsequent encounter*/
,'V183XXS'  /*Person boarding or alighting a pedal cycle injured in noncollision transport accident, sequela*/
,'V184XXA'  /*Pedal cycle driver injured in noncollision transport accident in traffic accident, initial encounter*/
,'V184XXD'  /*Pedal cycle driver injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V184XXS'  /*Pedal cycle driver injured in noncollision transport accident in traffic accident, sequela*/
,'V185XXA'  /*Pedal cycle passenger injured in noncollision transport accident in traffic accident, initial encounter*/
,'V185XXD'  /*Pedal cycle passenger injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V185XXS'  /*Pedal cycle passenger injured in noncollision transport accident in traffic accident, sequela*/
,'V189XXA'  /*Unspecified pedal cyclist injured in noncollision transport accident in traffic accident, initial encounter*/
,'V189XXD'  /*Unspecified pedal cyclist injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V189XXS'  /*Unspecified pedal cyclist injured in noncollision transport accident in traffic accident, sequela*/
,'V1900XA'  /*Pedal cycle driver injured in collision with unspecified motor vehicles in nontraffic accident, initial encounter*/
,'V1900XD'  /*Pedal cycle driver injured in collision with unspecified motor vehicles in nontraffic accident, subsequent encounter*/
,'V1900XS'  /*Pedal cycle driver injured in collision with unspecified motor vehicles in nontraffic accident, sequela*/
,'V1909XA'  /*Pedal cycle driver injured in collision with other motor vehicles in nontraffic accident, initial encounter*/
,'V1909XD'  /*Pedal cycle driver injured in collision with other motor vehicles in nontraffic accident, subsequent encounter*/
,'V1909XS'  /*Pedal cycle driver injured in collision with other motor vehicles in nontraffic accident, sequela*/
,'V1910XA'  /*Pedal cycle passenger injured in collision with unspecified motor vehicles in nontraffic accident, initial encounter*/
,'V1910XD'  /*Pedal cycle passenger injured in collision with unspecified motor vehicles in nontraffic accident, subsequent encounter*/
,'V1910XS'  /*Pedal cycle passenger injured in collision with unspecified motor vehicles in nontraffic accident, sequela*/
,'V1919XA'  /*Pedal cycle passenger injured in collision with other motor vehicles in nontraffic accident, initial encounter*/
,'V1919XD'  /*Pedal cycle passenger injured in collision with other motor vehicles in nontraffic accident, subsequent encounter*/
,'V1919XS'  /*Pedal cycle passenger injured in collision with other motor vehicles in nontraffic accident, sequela*/
,'V1920XA'  /*Unspecified pedal cyclist injured in collision with unspecified motor vehicles in nontraffic accident, initial encounter*/
,'V1920XD'  /*Unspecified pedal cyclist injured in collision with unspecified motor vehicles in nontraffic accident, subsequent encounter*/
,'V1920XS'  /*Unspecified pedal cyclist injured in collision with unspecified motor vehicles in nontraffic accident, sequela*/
,'V1929XA'  /*Unspecified pedal cyclist injured in collision with other motor vehicles in nontraffic accident, initial encounter*/
,'V1929XD'  /*Unspecified pedal cyclist injured in collision with other motor vehicles in nontraffic accident, subsequent encounter*/
,'V1929XS'  /*Unspecified pedal cyclist injured in collision with other motor vehicles in nontraffic accident, sequela*/
,'V193XXA'  /*Pedal cyclist (driver) (passenger) injured in unspecified nontraffic accident, initial encounter*/
,'V193XXD'  /*Pedal cyclist (driver) (passenger) injured in unspecified nontraffic accident, subsequent encounter*/
,'V193XXS'  /*Pedal cyclist (driver) (passenger) injured in unspecified nontraffic accident, sequela*/
,'V1940XA'  /*Pedal cycle driver injured in collision with unspecified motor vehicles in traffic accident, initial encounter*/
,'V1940XD'  /*Pedal cycle driver injured in collision with unspecified motor vehicles in traffic accident, subsequent encounter*/
,'V1940XS'  /*Pedal cycle driver injured in collision with unspecified motor vehicles in traffic accident, sequela*/
,'V1949XA'  /*Pedal cycle driver injured in collision with other motor vehicles in traffic accident, initial encounter*/
,'V1949XD'  /*Pedal cycle driver injured in collision with other motor vehicles in traffic accident, subsequent encounter*/
,'V1949XS'  /*Pedal cycle driver injured in collision with other motor vehicles in traffic accident, sequela*/
,'V1950XA'  /*Pedal cycle passenger injured in collision with unspecified motor vehicles in traffic accident, initial encounter*/
,'V1950XD'  /*Pedal cycle passenger injured in collision with unspecified motor vehicles in traffic accident, subsequent encounter*/
,'V1950XS'  /*Pedal cycle passenger injured in collision with unspecified motor vehicles in traffic accident, sequela*/
,'V1959XA'  /*Pedal cycle passenger injured in collision with other motor vehicles in traffic accident, initial encounter*/
,'V1959XD'  /*Pedal cycle passenger injured in collision with other motor vehicles in traffic accident, subsequent encounter*/
,'V1959XS'  /*Pedal cycle passenger injured in collision with other motor vehicles in traffic accident, sequela*/
,'V1960XA'  /*Unspecified pedal cyclist injured in collision with unspecified motor vehicles in traffic accident, initial encounter*/
,'V1960XD'  /*Unspecified pedal cyclist injured in collision with unspecified motor vehicles in traffic accident, subsequent encounter*/
,'V1960XS'  /*Unspecified pedal cyclist injured in collision with unspecified motor vehicles in traffic accident, sequela*/
,'V1969XA'  /*Unspecified pedal cyclist injured in collision with other motor vehicles in traffic accident, initial encounter*/
,'V1969XD'  /*Unspecified pedal cyclist injured in collision with other motor vehicles in traffic accident, subsequent encounter*/
,'V1969XS'  /*Unspecified pedal cyclist injured in collision with other motor vehicles in traffic accident, sequela*/
,'V1981XA'  /*Pedal cyclist (driver) (passenger) injured in transport accident with military vehicle, initial encounter*/
,'V1981XD'  /*Pedal cyclist (driver) (passenger) injured in transport accident with military vehicle, subsequent encounter*/
,'V1981XS'  /*Pedal cyclist (driver) (passenger) injured in transport accident with military vehicle, sequela*/
,'V1988XA'  /*Pedal cyclist (driver) (passenger) injured in other specified transport accidents, initial encounter*/
,'V1988XD'  /*Pedal cyclist (driver) (passenger) injured in other specified transport accidents, subsequent encounter*/
,'V1988XS'  /*Pedal cyclist (driver) (passenger) injured in other specified transport accidents, sequela*/
,'V199XXA'  /*Pedal cyclist (driver) (passenger) injured in unspecified traffic accident, initial encounter*/
,'V199XXD'  /*Pedal cyclist (driver) (passenger) injured in unspecified traffic accident, subsequent encounter*/
,'V199XXS'  /*Pedal cyclist (driver) (passenger) injured in unspecified traffic accident, sequela*/
,'V200XXA'  /*Motorcycle driver injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V200XXD'  /*Motorcycle driver injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V200XXS'  /*Motorcycle driver injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V201XXA'  /*Motorcycle passenger injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V201XXD'  /*Motorcycle passenger injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V201XXS'  /*Motorcycle passenger injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V202XXA'  /*Unspecified motorcycle rider injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V202XXD'  /*Unspecified motorcycle rider injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V202XXS'  /*Unspecified motorcycle rider injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V203XXA'  /*Person boarding or alighting a motorcycle injured in collision with pedestrian or animal, initial encounter*/
,'V203XXD'  /*Person boarding or alighting a motorcycle injured in collision with pedestrian or animal, subsequent encounter*/
,'V203XXS'  /*Person boarding or alighting a motorcycle injured in collision with pedestrian or animal, sequela*/
,'V204XXA'  /*Motorcycle driver injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V204XXD'  /*Motorcycle driver injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V204XXS'  /*Motorcycle driver injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V205XXA'  /*Motorcycle passenger injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V205XXD'  /*Motorcycle passenger injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V205XXS'  /*Motorcycle passenger injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V209XXA'  /*Unspecified motorcycle rider injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V209XXD'  /*Unspecified motorcycle rider injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V209XXS'  /*Unspecified motorcycle rider injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V210XXA'  /*Motorcycle driver injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V210XXD'  /*Motorcycle driver injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V210XXS'  /*Motorcycle driver injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V211XXA'  /*Motorcycle passenger injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V211XXD'  /*Motorcycle passenger injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V211XXS'  /*Motorcycle passenger injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V212XXA'  /*Unspecified motorcycle rider injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V212XXD'  /*Unspecified motorcycle rider injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V212XXS'  /*Unspecified motorcycle rider injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V213XXA'  /*Person boarding or alighting a motorcycle injured in collision with pedal cycle, initial encounter*/
,'V213XXD'  /*Person boarding or alighting a motorcycle injured in collision with pedal cycle, subsequent encounter*/
,'V213XXS'  /*Person boarding or alighting a motorcycle injured in collision with pedal cycle, sequela*/
,'V214XXA'  /*Motorcycle driver injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V214XXD'  /*Motorcycle driver injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V214XXS'  /*Motorcycle driver injured in collision with pedal cycle in traffic accident, sequela*/
,'V215XXA'  /*Motorcycle passenger injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V215XXD'  /*Motorcycle passenger injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V215XXS'  /*Motorcycle passenger injured in collision with pedal cycle in traffic accident, sequela*/
,'V219XXA'  /*Unspecified motorcycle rider injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V219XXD'  /*Unspecified motorcycle rider injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V219XXS'  /*Unspecified motorcycle rider injured in collision with pedal cycle in traffic accident, sequela*/
,'V220XXA'  /*Motorcycle driver injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V220XXD'  /*Motorcycle driver injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V220XXS'  /*Motorcycle driver injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V221XXA'  /*Motorcycle passenger injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V221XXD'  /*Motorcycle passenger injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V221XXS'  /*Motorcycle passenger injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V222XXA'  /*Unspecified motorcycle rider injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V222XXD'  /*Unspecified motorcycle rider injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V222XXS'  /*Unspecified motorcycle rider injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V223XXA'  /*Person boarding or alighting a motorcycle injured in collision with two- or three-wheeled motor vehicle, initial encounter*/
,'V223XXD'  /*Person boarding or alighting a motorcycle injured in collision with two- or three-wheeled motor vehicle, subsequent encounter*/
,'V223XXS'  /*Person boarding or alighting a motorcycle injured in collision with two- or three-wheeled motor vehicle, sequela*/
,'V224XXA'  /*Motorcycle driver injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V224XXD'  /*Motorcycle driver injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V224XXS'  /*Motorcycle driver injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V225XXA'  /*Motorcycle passenger injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V225XXD'  /*Motorcycle passenger injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V225XXS'  /*Motorcycle passenger injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V229XXA'  /*Unspecified motorcycle rider injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V229XXD'  /*Unspecified motorcycle rider injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V229XXS'  /*Unspecified motorcycle rider injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V230XXA'  /*Motorcycle driver injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V230XXD'  /*Motorcycle driver injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V230XXS'  /*Motorcycle driver injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V231XXA'  /*Motorcycle passenger injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V231XXD'  /*Motorcycle passenger injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V231XXS'  /*Motorcycle passenger injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V232XXA'  /*Unspecified motorcycle rider injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V232XXD'  /*Unspecified motorcycle rider injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V232XXS'  /*Unspecified motorcycle rider injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V233XXA'  /*Person boarding or alighting a motorcycle injured in collision with car, pick-up truck or van, initial encounter*/
,'V233XXD'  /*Person boarding or alighting a motorcycle injured in collision with car, pick-up truck or van, subsequent encounter*/
,'V233XXS'  /*Person boarding or alighting a motorcycle injured in collision with car, pick-up truck or van, sequela*/
,'V234XXA'  /*Motorcycle driver injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V234XXD'  /*Motorcycle driver injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V234XXS'  /*Motorcycle driver injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V235XXA'  /*Motorcycle passenger injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V235XXD'  /*Motorcycle passenger injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V235XXS'  /*Motorcycle passenger injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V239XXA'  /*Unspecified motorcycle rider injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V239XXD'  /*Unspecified motorcycle rider injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V239XXS'  /*Unspecified motorcycle rider injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V240XXA'  /*Motorcycle driver injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V240XXD'  /*Motorcycle driver injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V240XXS'  /*Motorcycle driver injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V241XXA'  /*Motorcycle passenger injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V241XXD'  /*Motorcycle passenger injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V241XXS'  /*Motorcycle passenger injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V242XXA'  /*Unspecified motorcycle rider injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V242XXD'  /*Unspecified motorcycle rider injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V242XXS'  /*Unspecified motorcycle rider injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V243XXA'  /*Person boarding or alighting a motorcycle injured in collision with heavy transport vehicle or bus, initial encounter*/
,'V243XXD'  /*Person boarding or alighting a motorcycle injured in collision with heavy transport vehicle or bus, subsequent encounter*/
,'V243XXS'  /*Person boarding or alighting a motorcycle injured in collision with heavy transport vehicle or bus, sequela*/
,'V244XXA'  /*Motorcycle driver injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V244XXD'  /*Motorcycle driver injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V244XXS'  /*Motorcycle driver injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V245XXA'  /*Motorcycle passenger injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V245XXD'  /*Motorcycle passenger injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V245XXS'  /*Motorcycle passenger injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V249XXA'  /*Unspecified motorcycle rider injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V249XXD'  /*Unspecified motorcycle rider injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V249XXS'  /*Unspecified motorcycle rider injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V250XXA'  /*Motorcycle driver injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V250XXD'  /*Motorcycle driver injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V250XXS'  /*Motorcycle driver injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V251XXA'  /*Motorcycle passenger injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V251XXD'  /*Motorcycle passenger injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V251XXS'  /*Motorcycle passenger injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V252XXA'  /*Unspecified motorcycle rider injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V252XXD'  /*Unspecified motorcycle rider injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V252XXS'  /*Unspecified motorcycle rider injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V253XXA'  /*Person boarding or alighting a motorcycle injured in collision with railway train or railway vehicle, initial encounter*/
,'V253XXD'  /*Person boarding or alighting a motorcycle injured in collision with railway train or railway vehicle, subsequent encounter*/
,'V253XXS'  /*Person boarding or alighting a motorcycle injured in collision with railway train or railway vehicle, sequela*/
,'V254XXA'  /*Motorcycle driver injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V254XXD'  /*Motorcycle driver injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V254XXS'  /*Motorcycle driver injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V255XXA'  /*Motorcycle passenger injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V255XXD'  /*Motorcycle passenger injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V255XXS'  /*Motorcycle passenger injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V259XXA'  /*Unspecified motorcycle rider injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V259XXD'  /*Unspecified motorcycle rider injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V259XXS'  /*Unspecified motorcycle rider injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V260XXA'  /*Motorcycle driver injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V260XXD'  /*Motorcycle driver injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V260XXS'  /*Motorcycle driver injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V261XXA'  /*Motorcycle passenger injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V261XXD'  /*Motorcycle passenger injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V261XXS'  /*Motorcycle passenger injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V262XXA'  /*Unspecified motorcycle rider injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V262XXD'  /*Unspecified motorcycle rider injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V262XXS'  /*Unspecified motorcycle rider injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V263XXA'  /*Person boarding or alighting a motorcycle injured in collision with other nonmotor vehicle, initial encounter*/
,'V263XXD'  /*Person boarding or alighting a motorcycle injured in collision with other nonmotor vehicle, subsequent encounter*/
,'V263XXS'  /*Person boarding or alighting a motorcycle injured in collision with other nonmotor vehicle, sequela*/
,'V264XXA'  /*Motorcycle driver injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V264XXD'  /*Motorcycle driver injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V264XXS'  /*Motorcycle driver injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V265XXA'  /*Motorcycle passenger injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V265XXD'  /*Motorcycle passenger injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V265XXS'  /*Motorcycle passenger injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V269XXA'  /*Unspecified motorcycle rider injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V269XXD'  /*Unspecified motorcycle rider injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V269XXS'  /*Unspecified motorcycle rider injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V270XXA'  /*Motorcycle driver injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V270XXD'  /*Motorcycle driver injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V270XXS'  /*Motorcycle driver injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V271XXA'  /*Motorcycle passenger injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V271XXD'  /*Motorcycle passenger injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V271XXS'  /*Motorcycle passenger injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V272XXA'  /*Unspecified motorcycle rider injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V272XXD'  /*Unspecified motorcycle rider injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V272XXS'  /*Unspecified motorcycle rider injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V273XXA'  /*Person boarding or alighting a motorcycle injured in collision with fixed or stationary object, initial encounter*/
,'V273XXD'  /*Person boarding or alighting a motorcycle injured in collision with fixed or stationary object, subsequent encounter*/
,'V273XXS'  /*Person boarding or alighting a motorcycle injured in collision with fixed or stationary object, sequela*/
,'V274XXA'  /*Motorcycle driver injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V274XXD'  /*Motorcycle driver injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V274XXS'  /*Motorcycle driver injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V275XXA'  /*Motorcycle passenger injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V275XXD'  /*Motorcycle passenger injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V275XXS'  /*Motorcycle passenger injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V279XXA'  /*Unspecified motorcycle rider injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V279XXD'  /*Unspecified motorcycle rider injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V279XXS'  /*Unspecified motorcycle rider injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V280XXA'  /*Motorcycle driver injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V280XXD'  /*Motorcycle driver injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V280XXS'  /*Motorcycle driver injured in noncollision transport accident in nontraffic accident, sequela*/
,'V281XXA'  /*Motorcycle passenger injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V281XXD'  /*Motorcycle passenger injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V281XXS'  /*Motorcycle passenger injured in noncollision transport accident in nontraffic accident, sequela*/
,'V282XXA'  /*Unspecified motorcycle rider injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V282XXD'  /*Unspecified motorcycle rider injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V282XXS'  /*Unspecified motorcycle rider injured in noncollision transport accident in nontraffic accident, sequela*/
,'V283XXA'  /*Person boarding or alighting a motorcycle injured in noncollision transport accident, initial encounter*/
,'V283XXD'  /*Person boarding or alighting a motorcycle injured in noncollision transport accident, subsequent encounter*/
,'V283XXS'  /*Person boarding or alighting a motorcycle injured in noncollision transport accident, sequela*/
,'V284XXA'  /*Motorcycle driver injured in noncollision transport accident in traffic accident, initial encounter*/
,'V284XXD'  /*Motorcycle driver injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V284XXS'  /*Motorcycle driver injured in noncollision transport accident in traffic accident, sequela*/
,'V285XXA'  /*Motorcycle passenger injured in noncollision transport accident in traffic accident, initial encounter*/
,'V285XXD'  /*Motorcycle passenger injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V285XXS'  /*Motorcycle passenger injured in noncollision transport accident in traffic accident, sequela*/
,'V289XXA'  /*Unspecified motorcycle rider injured in noncollision transport accident in traffic accident, initial encounter*/
,'V289XXD'  /*Unspecified motorcycle rider injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V289XXS'  /*Unspecified motorcycle rider injured in noncollision transport accident in traffic accident, sequela*/
,'V2900XA'  /*Motorcycle driver injured in collision with unspecified motor vehicles in nontraffic accident, initial encounter*/
,'V2900XD'  /*Motorcycle driver injured in collision with unspecified motor vehicles in nontraffic accident, subsequent encounter*/
,'V2900XS'  /*Motorcycle driver injured in collision with unspecified motor vehicles in nontraffic accident, sequela*/
,'V2909XA'  /*Motorcycle driver injured in collision with other motor vehicles in nontraffic accident, initial encounter*/
,'V2909XD'  /*Motorcycle driver injured in collision with other motor vehicles in nontraffic accident, subsequent encounter*/
,'V2909XS'  /*Motorcycle driver injured in collision with other motor vehicles in nontraffic accident, sequela*/
,'V2910XA'  /*Motorcycle passenger injured in collision with unspecified motor vehicles in nontraffic accident, initial encounter*/
,'V2910XD'  /*Motorcycle passenger injured in collision with unspecified motor vehicles in nontraffic accident, subsequent encounter*/
,'V2910XS'  /*Motorcycle passenger injured in collision with unspecified motor vehicles in nontraffic accident, sequela*/
,'V2919XA'  /*Motorcycle passenger injured in collision with other motor vehicles in nontraffic accident, initial encounter*/
,'V2919XD'  /*Motorcycle passenger injured in collision with other motor vehicles in nontraffic accident, subsequent encounter*/
,'V2919XS'  /*Motorcycle passenger injured in collision with other motor vehicles in nontraffic accident, sequela*/
,'V2920XA'  /*Unspecified motorcycle rider injured in collision with unspecified motor vehicles in nontraffic accident, initial encounter*/
,'V2920XD'  /*Unspecified motorcycle rider injured in collision with unspecified motor vehicles in nontraffic accident, subsequent encounter*/
,'V2920XS'  /*Unspecified motorcycle rider injured in collision with unspecified motor vehicles in nontraffic accident, sequela*/
,'V2929XA'  /*Unspecified motorcycle rider injured in collision with other motor vehicles in nontraffic accident, initial encounter*/
,'V2929XD'  /*Unspecified motorcycle rider injured in collision with other motor vehicles in nontraffic accident, subsequent encounter*/
,'V2929XS'  /*Unspecified motorcycle rider injured in collision with other motor vehicles in nontraffic accident, sequela*/
,'V293XXA'  /*Motorcycle rider (driver) (passenger) injured in unspecified nontraffic accident, initial encounter*/
,'V293XXD'  /*Motorcycle rider (driver) (passenger) injured in unspecified nontraffic accident, subsequent encounter*/
,'V293XXS'  /*Motorcycle rider (driver) (passenger) injured in unspecified nontraffic accident, sequela*/
,'V2940XA'  /*Motorcycle driver injured in collision with unspecified motor vehicles in traffic accident, initial encounter*/
,'V2940XD'  /*Motorcycle driver injured in collision with unspecified motor vehicles in traffic accident, subsequent encounter*/
,'V2940XS'  /*Motorcycle driver injured in collision with unspecified motor vehicles in traffic accident, sequela*/
,'V2949XA'  /*Motorcycle driver injured in collision with other motor vehicles in traffic accident, initial encounter*/
,'V2949XD'  /*Motorcycle driver injured in collision with other motor vehicles in traffic accident, subsequent encounter*/
,'V2949XS'  /*Motorcycle driver injured in collision with other motor vehicles in traffic accident, sequela*/
,'V2950XA'  /*Motorcycle passenger injured in collision with unspecified motor vehicles in traffic accident, initial encounter*/
,'V2950XD'  /*Motorcycle passenger injured in collision with unspecified motor vehicles in traffic accident, subsequent encounter*/
,'V2950XS'  /*Motorcycle passenger injured in collision with unspecified motor vehicles in traffic accident, sequela*/
,'V2959XA'  /*Motorcycle passenger injured in collision with other motor vehicles in traffic accident, initial encounter*/
,'V2959XD'  /*Motorcycle passenger injured in collision with other motor vehicles in traffic accident, subsequent encounter*/
,'V2959XS'  /*Motorcycle passenger injured in collision with other motor vehicles in traffic accident, sequela*/
,'V2960XA'  /*Unspecified motorcycle rider injured in collision with unspecified motor vehicles in traffic accident, initial encounter*/
,'V2960XD'  /*Unspecified motorcycle rider injured in collision with unspecified motor vehicles in traffic accident, subsequent encounter*/
,'V2960XS'  /*Unspecified motorcycle rider injured in collision with unspecified motor vehicles in traffic accident, sequela*/
,'V2969XA'  /*Unspecified motorcycle rider injured in collision with other motor vehicles in traffic accident, initial encounter*/
,'V2969XD'  /*Unspecified motorcycle rider injured in collision with other motor vehicles in traffic accident, subsequent encounter*/
,'V2969XS'  /*Unspecified motorcycle rider injured in collision with other motor vehicles in traffic accident, sequela*/
,'V2981XA'  /*Motorcycle rider (driver) (passenger) injured in transport accident with military vehicle, initial encounter*/
,'V2981XD'  /*Motorcycle rider (driver) (passenger) injured in transport accident with military vehicle, subsequent encounter*/
,'V2981XS'  /*Motorcycle rider (driver) (passenger) injured in transport accident with military vehicle, sequela*/
,'V2988XA'  /*Motorcycle rider (driver) (passenger) injured in other specified transport accidents, initial encounter*/
,'V2988XD'  /*Motorcycle rider (driver) (passenger) injured in other specified transport accidents, subsequent encounter*/
,'V2988XS'  /*Motorcycle rider (driver) (passenger) injured in other specified transport accidents, sequela*/
,'V299XXA'  /*Motorcycle rider (driver) (passenger) injured in unspecified traffic accident, initial encounter*/
,'V299XXD'  /*Motorcycle rider (driver) (passenger) injured in unspecified traffic accident, subsequent encounter*/
,'V299XXS'  /*Motorcycle rider (driver) (passenger) injured in unspecified traffic accident, sequela*/
,'V300XXA'  /*Driver of three-wheeled motor vehicle injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V300XXD'  /*Driver of three-wheeled motor vehicle injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V300XXS'  /*Driver of three-wheeled motor vehicle injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V301XXA'  /*Passenger in three-wheeled motor vehicle injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V301XXD'  /*Passenger in three-wheeled motor vehicle injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V301XXS'  /*Passenger in three-wheeled motor vehicle injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V302XXA'  /*Person on outside of three-wheeled motor vehicle injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V302XXD'  /*Person on outside of three-wheeled motor vehicle injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V302XXS'  /*Person on outside of three-wheeled motor vehicle injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V303XXA'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V303XXD'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V303XXS'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V304XXA'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with pedestrian or animal, initial encounter*/
,'V304XXD'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with pedestrian or animal, subsequent encounter*/
,'V304XXS'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with pedestrian or animal, sequela*/
,'V305XXA'  /*Driver of three-wheeled motor vehicle injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V305XXD'  /*Driver of three-wheeled motor vehicle injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V305XXS'  /*Driver of three-wheeled motor vehicle injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V306XXA'  /*Passenger in three-wheeled motor vehicle injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V306XXD'  /*Passenger in three-wheeled motor vehicle injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V306XXS'  /*Passenger in three-wheeled motor vehicle injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V307XXA'  /*Person on outside of three-wheeled motor vehicle injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V307XXD'  /*Person on outside of three-wheeled motor vehicle injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V307XXS'  /*Person on outside of three-wheeled motor vehicle injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V309XXA'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V309XXD'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V309XXS'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V310XXA'  /*Driver of three-wheeled motor vehicle injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V310XXD'  /*Driver of three-wheeled motor vehicle injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V310XXS'  /*Driver of three-wheeled motor vehicle injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V311XXA'  /*Passenger in three-wheeled motor vehicle injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V311XXD'  /*Passenger in three-wheeled motor vehicle injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V311XXS'  /*Passenger in three-wheeled motor vehicle injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V312XXA'  /*Person on outside of three-wheeled motor vehicle injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V312XXD'  /*Person on outside of three-wheeled motor vehicle injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V312XXS'  /*Person on outside of three-wheeled motor vehicle injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V313XXA'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V313XXD'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V313XXS'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V314XXA'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with pedal cycle, initial encounter*/
,'V314XXD'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with pedal cycle, subsequent encounter*/
,'V314XXS'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with pedal cycle, sequela*/
,'V315XXA'  /*Driver of three-wheeled motor vehicle injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V315XXD'  /*Driver of three-wheeled motor vehicle injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V315XXS'  /*Driver of three-wheeled motor vehicle injured in collision with pedal cycle in traffic accident, sequela*/
,'V316XXA'  /*Passenger in three-wheeled motor vehicle injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V316XXD'  /*Passenger in three-wheeled motor vehicle injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V316XXS'  /*Passenger in three-wheeled motor vehicle injured in collision with pedal cycle in traffic accident, sequela*/
,'V317XXA'  /*Person on outside of three-wheeled motor vehicle injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V317XXD'  /*Person on outside of three-wheeled motor vehicle injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V317XXS'  /*Person on outside of three-wheeled motor vehicle injured in collision with pedal cycle in traffic accident, sequela*/
,'V319XXA'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V319XXD'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V319XXS'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with pedal cycle in traffic accident, sequela*/
,'V320XXA'  /*Driver of three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V320XXD'  /*Driver of three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V320XXS'  /*Driver of three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V321XXA'  /*Passenger in three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V321XXD'  /*Passenger in three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V321XXS'  /*Passenger in three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V322XXA'  /*Person on outside of three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V322XXD'  /*Person on outside of three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V322XXS'  /*Person on outside of three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V323XXA'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V323XXD'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V323XXS'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V324XXA'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle, initial encounter*/
,'V324XXD'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle, subsequent encounter*/
,'V324XXS'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle, sequela*/
,'V325XXA'  /*Driver of three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V325XXD'  /*Driver of three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V325XXS'  /*Driver of three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V326XXA'  /*Passenger in three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V326XXD'  /*Passenger in three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V326XXS'  /*Passenger in three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V327XXA'  /*Person on outside of three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V327XXD'  /*Person on outside of three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V327XXS'  /*Person on outside of three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V329XXA'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V329XXD'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V329XXS'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V330XXA'  /*Driver of three-wheeled motor vehicle injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V330XXD'  /*Driver of three-wheeled motor vehicle injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V330XXS'  /*Driver of three-wheeled motor vehicle injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V331XXA'  /*Passenger in three-wheeled motor vehicle injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V331XXD'  /*Passenger in three-wheeled motor vehicle injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V331XXS'  /*Passenger in three-wheeled motor vehicle injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V332XXA'  /*Person on outside of three-wheeled motor vehicle injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V332XXD'  /*Person on outside of three-wheeled motor vehicle injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V332XXS'  /*Person on outside of three-wheeled motor vehicle injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V333XXA'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V333XXD'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V333XXS'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V334XXA'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with car, pick-up truck or van, initial encounter*/
,'V334XXD'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with car, pick-up truck or van, subsequent encounter*/
,'V334XXS'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with car, pick-up truck or van, sequela*/
,'V335XXA'  /*Driver of three-wheeled motor vehicle injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V335XXD'  /*Driver of three-wheeled motor vehicle injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V335XXS'  /*Driver of three-wheeled motor vehicle injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V336XXA'  /*Passenger in three-wheeled motor vehicle injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V336XXD'  /*Passenger in three-wheeled motor vehicle injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V336XXS'  /*Passenger in three-wheeled motor vehicle injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V337XXA'  /*Person on outside of three-wheeled motor vehicle injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V337XXD'  /*Person on outside of three-wheeled motor vehicle injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V337XXS'  /*Person on outside of three-wheeled motor vehicle injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V339XXA'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V339XXD'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V339XXS'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V340XXA'  /*Driver of three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V340XXD'  /*Driver of three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V340XXS'  /*Driver of three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V341XXA'  /*Passenger in three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V341XXD'  /*Passenger in three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V341XXS'  /*Passenger in three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V342XXA'  /*Person on outside of three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V342XXD'  /*Person on outside of three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V342XXS'  /*Person on outside of three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V343XXA'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V343XXD'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V343XXS'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V344XXA'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus, initial encounter*/
,'V344XXD'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus, subsequent encounter*/
,'V344XXS'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus, sequela*/
,'V345XXA'  /*Driver of three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V345XXD'  /*Driver of three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V345XXS'  /*Driver of three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V346XXA'  /*Passenger in three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V346XXD'  /*Passenger in three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V346XXS'  /*Passenger in three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V347XXA'  /*Person on outside of three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V347XXD'  /*Person on outside of three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V347XXS'  /*Person on outside of three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V349XXA'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V349XXD'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V349XXS'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V350XXA'  /*Driver of three-wheeled motor vehicle injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V350XXD'  /*Driver of three-wheeled motor vehicle injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V350XXS'  /*Driver of three-wheeled motor vehicle injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V351XXA'  /*Passenger in three-wheeled motor vehicle injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V351XXD'  /*Passenger in three-wheeled motor vehicle injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V351XXS'  /*Passenger in three-wheeled motor vehicle injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V352XXA'  /*Person on outside of three-wheeled motor vehicle injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V352XXD'  /*Person on outside of three-wheeled motor vehicle injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V352XXS'  /*Person on outside of three-wheeled motor vehicle injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V353XXA'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V353XXD'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V353XXS'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V354XXA'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with railway train or railway vehicle, initial encounter*/
,'V354XXD'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with railway train or railway vehicle, subsequent encounter*/
,'V354XXS'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with railway train or railway vehicle, sequela*/
,'V355XXA'  /*Driver of three-wheeled motor vehicle injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V355XXD'  /*Driver of three-wheeled motor vehicle injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V355XXS'  /*Driver of three-wheeled motor vehicle injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V356XXA'  /*Passenger in three-wheeled motor vehicle injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V356XXD'  /*Passenger in three-wheeled motor vehicle injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V356XXS'  /*Passenger in three-wheeled motor vehicle injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V357XXA'  /*Person on outside of three-wheeled motor vehicle injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V357XXD'  /*Person on outside of three-wheeled motor vehicle injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V357XXS'  /*Person on outside of three-wheeled motor vehicle injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V359XXA'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V359XXD'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V359XXS'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V360XXA'  /*Driver of three-wheeled motor vehicle injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V360XXD'  /*Driver of three-wheeled motor vehicle injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V360XXS'  /*Driver of three-wheeled motor vehicle injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V361XXA'  /*Passenger in three-wheeled motor vehicle injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V361XXD'  /*Passenger in three-wheeled motor vehicle injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V361XXS'  /*Passenger in three-wheeled motor vehicle injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V362XXA'  /*Person on outside of three-wheeled motor vehicle injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V362XXD'  /*Person on outside of three-wheeled motor vehicle injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V362XXS'  /*Person on outside of three-wheeled motor vehicle injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V363XXA'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V363XXD'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V363XXS'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V364XXA'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with other nonmotor vehicle, initial encounter*/
,'V364XXD'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with other nonmotor vehicle, subsequent encounter*/
,'V364XXS'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with other nonmotor vehicle, sequela*/
,'V365XXA'  /*Driver of three-wheeled motor vehicle injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V365XXD'  /*Driver of three-wheeled motor vehicle injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V365XXS'  /*Driver of three-wheeled motor vehicle injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V366XXA'  /*Passenger in three-wheeled motor vehicle injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V366XXD'  /*Passenger in three-wheeled motor vehicle injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V366XXS'  /*Passenger in three-wheeled motor vehicle injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V367XXA'  /*Person on outside of three-wheeled motor vehicle injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V367XXD'  /*Person on outside of three-wheeled motor vehicle injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V367XXS'  /*Person on outside of three-wheeled motor vehicle injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V369XXA'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V369XXD'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V369XXS'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V370XXA'  /*Driver of three-wheeled motor vehicle injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V370XXD'  /*Driver of three-wheeled motor vehicle injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V370XXS'  /*Driver of three-wheeled motor vehicle injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V371XXA'  /*Passenger in three-wheeled motor vehicle injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V371XXD'  /*Passenger in three-wheeled motor vehicle injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V371XXS'  /*Passenger in three-wheeled motor vehicle injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V372XXA'  /*Person on outside of three-wheeled motor vehicle injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V372XXD'  /*Person on outside of three-wheeled motor vehicle injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V372XXS'  /*Person on outside of three-wheeled motor vehicle injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V373XXA'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V373XXD'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V373XXS'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V374XXA'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with fixed or stationary object, initial encounter*/
,'V374XXD'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with fixed or stationary object, subsequent encounter*/
,'V374XXS'  /*Person boarding or alighting a three-wheeled motor vehicle injured in collision with fixed or stationary object, sequela*/
,'V375XXA'  /*Driver of three-wheeled motor vehicle injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V375XXD'  /*Driver of three-wheeled motor vehicle injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V375XXS'  /*Driver of three-wheeled motor vehicle injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V376XXA'  /*Passenger in three-wheeled motor vehicle injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V376XXD'  /*Passenger in three-wheeled motor vehicle injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V376XXS'  /*Passenger in three-wheeled motor vehicle injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V377XXA'  /*Person on outside of three-wheeled motor vehicle injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V377XXD'  /*Person on outside of three-wheeled motor vehicle injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V377XXS'  /*Person on outside of three-wheeled motor vehicle injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V379XXA'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V379XXD'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V379XXS'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V380XXA'  /*Driver of three-wheeled motor vehicle injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V380XXD'  /*Driver of three-wheeled motor vehicle injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V380XXS'  /*Driver of three-wheeled motor vehicle injured in noncollision transport accident in nontraffic accident, sequela*/
,'V381XXA'  /*Passenger in three-wheeled motor vehicle injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V381XXD'  /*Passenger in three-wheeled motor vehicle injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V381XXS'  /*Passenger in three-wheeled motor vehicle injured in noncollision transport accident in nontraffic accident, sequela*/
,'V382XXA'  /*Person on outside of three-wheeled motor vehicle injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V382XXD'  /*Person on outside of three-wheeled motor vehicle injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V382XXS'  /*Person on outside of three-wheeled motor vehicle injured in noncollision transport accident in nontraffic accident, sequela*/
,'V383XXA'  /*Unspecified occupant of three-wheeled motor vehicle injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V383XXD'  /*Unspecified occupant of three-wheeled motor vehicle injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V383XXS'  /*Unspecified occupant of three-wheeled motor vehicle injured in noncollision transport accident in nontraffic accident, sequela*/
,'V384XXA'  /*Person boarding or alighting a three-wheeled motor vehicle injured in noncollision transport accident, initial encounter*/
,'V384XXD'  /*Person boarding or alighting a three-wheeled motor vehicle injured in noncollision transport accident, subsequent encounter*/
,'V384XXS'  /*Person boarding or alighting a three-wheeled motor vehicle injured in noncollision transport accident, sequela*/
,'V385XXA'  /*Driver of three-wheeled motor vehicle injured in noncollision transport accident in traffic accident, initial encounter*/
,'V385XXD'  /*Driver of three-wheeled motor vehicle injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V385XXS'  /*Driver of three-wheeled motor vehicle injured in noncollision transport accident in traffic accident, sequela*/
,'V386XXA'  /*Passenger in three-wheeled motor vehicle injured in noncollision transport accident in traffic accident, initial encounter*/
,'V386XXD'  /*Passenger in three-wheeled motor vehicle injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V386XXS'  /*Passenger in three-wheeled motor vehicle injured in noncollision transport accident in traffic accident, sequela*/
,'V387XXA'  /*Person on outside of three-wheeled motor vehicle injured in noncollision transport accident in traffic accident, initial encounter*/
,'V387XXD'  /*Person on outside of three-wheeled motor vehicle injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V387XXS'  /*Person on outside of three-wheeled motor vehicle injured in noncollision transport accident in traffic accident, sequela*/
,'V389XXA'  /*Unspecified occupant of three-wheeled motor vehicle injured in noncollision transport accident in traffic accident, initial encounter*/
,'V389XXD'  /*Unspecified occupant of three-wheeled motor vehicle injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V389XXS'  /*Unspecified occupant of three-wheeled motor vehicle injured in noncollision transport accident in traffic accident, sequela*/
,'V3900XA'  /*Driver of three-wheeled motor vehicle injured in collision with unspecified motor vehicles in nontraffic accident, initial encounter*/
,'V3900XD'  /*Driver of three-wheeled motor vehicle injured in collision with unspecified motor vehicles in nontraffic accident, subsequent encounter*/
,'V3900XS'  /*Driver of three-wheeled motor vehicle injured in collision with unspecified motor vehicles in nontraffic accident, sequela*/
,'V3909XA'  /*Driver of three-wheeled motor vehicle injured in collision with other motor vehicles in nontraffic accident, initial encounter*/
,'V3909XD'  /*Driver of three-wheeled motor vehicle injured in collision with other motor vehicles in nontraffic accident, subsequent encounter*/
,'V3909XS'  /*Driver of three-wheeled motor vehicle injured in collision with other motor vehicles in nontraffic accident, sequela*/
,'V3910XA'  /*Passenger in three-wheeled motor vehicle injured in collision with unspecified motor vehicles in nontraffic accident, initial encounter*/
,'V3910XD'  /*Passenger in three-wheeled motor vehicle injured in collision with unspecified motor vehicles in nontraffic accident, subsequent encounter*/
,'V3910XS'  /*Passenger in three-wheeled motor vehicle injured in collision with unspecified motor vehicles in nontraffic accident, sequela*/
,'V3919XA'  /*Passenger in three-wheeled motor vehicle injured in collision with other motor vehicles in nontraffic accident, initial encounter*/
,'V3919XD'  /*Passenger in three-wheeled motor vehicle injured in collision with other motor vehicles in nontraffic accident, subsequent encounter*/
,'V3919XS'  /*Passenger in three-wheeled motor vehicle injured in collision with other motor vehicles in nontraffic accident, sequela*/
,'V3920XA'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with unspecified motor vehicles in nontraffic accident, initial encounter*/
,'V3920XD'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with unspecified motor vehicles in nontraffic accident, subsequent encounter*/
,'V3920XS'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with unspecified motor vehicles in nontraffic accident, sequela*/
,'V3929XA'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with other motor vehicles in nontraffic accident, initial encounter*/
,'V3929XD'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with other motor vehicles in nontraffic accident, subsequent encounter*/
,'V3929XS'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with other motor vehicles in nontraffic accident, sequela*/
,'V393XXA'  /*Occupant (driver) (passenger) of three-wheeled motor vehicle injured in unspecified nontraffic accident, initial encounter*/
,'V393XXD'  /*Occupant (driver) (passenger) of three-wheeled motor vehicle injured in unspecified nontraffic accident, subsequent encounter*/
,'V393XXS'  /*Occupant (driver) (passenger) of three-wheeled motor vehicle injured in unspecified nontraffic accident, sequela*/
,'V3940XA'  /*Driver of three-wheeled motor vehicle injured in collision with unspecified motor vehicles in traffic accident, initial encounter*/
,'V3940XD'  /*Driver of three-wheeled motor vehicle injured in collision with unspecified motor vehicles in traffic accident, subsequent encounter*/
,'V3940XS'  /*Driver of three-wheeled motor vehicle injured in collision with unspecified motor vehicles in traffic accident, sequela*/
,'V3949XA'  /*Driver of three-wheeled motor vehicle injured in collision with other motor vehicles in traffic accident, initial encounter*/
,'V3949XD'  /*Driver of three-wheeled motor vehicle injured in collision with other motor vehicles in traffic accident, subsequent encounter*/
,'V3949XS'  /*Driver of three-wheeled motor vehicle injured in collision with other motor vehicles in traffic accident, sequela*/
,'V3950XA'  /*Passenger in three-wheeled motor vehicle injured in collision with unspecified motor vehicles in traffic accident, initial encounter*/
,'V3950XD'  /*Passenger in three-wheeled motor vehicle injured in collision with unspecified motor vehicles in traffic accident, subsequent encounter*/
,'V3950XS'  /*Passenger in three-wheeled motor vehicle injured in collision with unspecified motor vehicles in traffic accident, sequela*/
,'V3959XA'  /*Passenger in three-wheeled motor vehicle injured in collision with other motor vehicles in traffic accident, initial encounter*/
,'V3959XD'  /*Passenger in three-wheeled motor vehicle injured in collision with other motor vehicles in traffic accident, subsequent encounter*/
,'V3959XS'  /*Passenger in three-wheeled motor vehicle injured in collision with other motor vehicles in traffic accident, sequela*/
,'V3960XA'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with unspecified motor vehicles in traffic accident, initial encounter*/
,'V3960XD'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with unspecified motor vehicles in traffic accident, subsequent encounter*/
,'V3960XS'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with unspecified motor vehicles in traffic accident, sequela*/
,'V3969XA'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with other motor vehicles in traffic accident, initial encounter*/
,'V3969XD'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with other motor vehicles in traffic accident, subsequent encounter*/
,'V3969XS'  /*Unspecified occupant of three-wheeled motor vehicle injured in collision with other motor vehicles in traffic accident, sequela*/
,'V3981XA'  /*Occupant (driver) (passenger) of three-wheeled motor vehicle injured in transport accident with military vehicle, initial encounter*/
,'V3981XD'  /*Occupant (driver) (passenger) of three-wheeled motor vehicle injured in transport accident with military vehicle, subsequent encounter*/
,'V3981XS'  /*Occupant (driver) (passenger) of three-wheeled motor vehicle injured in transport accident with military vehicle, sequela*/
,'V3989XA'  /*Occupant (driver) (passenger) of three-wheeled motor vehicle injured in other specified transport accidents, initial encounter*/
,'V3989XD'  /*Occupant (driver) (passenger) of three-wheeled motor vehicle injured in other specified transport accidents, subsequent encounter*/
,'V3989XS'  /*Occupant (driver) (passenger) of three-wheeled motor vehicle injured in other specified transport accidents, sequela*/
,'V399XXA'  /*Occupant (driver) (passenger) of three-wheeled motor vehicle injured in unspecified traffic accident, initial encounter*/
,'V399XXD'  /*Occupant (driver) (passenger) of three-wheeled motor vehicle injured in unspecified traffic accident, subsequent encounter*/
,'V399XXS'  /*Occupant (driver) (passenger) of three-wheeled motor vehicle injured in unspecified traffic accident, sequela*/
,'V400XXA'  /*Car driver injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V400XXD'  /*Car driver injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V400XXS'  /*Car driver injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V401XXA'  /*Car passenger injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V401XXD'  /*Car passenger injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V401XXS'  /*Car passenger injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V402XXA'  /*Person on outside of car injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V402XXD'  /*Person on outside of car injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V402XXS'  /*Person on outside of car injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V403XXA'  /*Unspecified car occupant injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V403XXD'  /*Unspecified car occupant injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V403XXS'  /*Unspecified car occupant injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V404XXA'  /*Person boarding or alighting a car injured in collision with pedestrian or animal, initial encounter*/
,'V404XXD'  /*Person boarding or alighting a car injured in collision with pedestrian or animal, subsequent encounter*/
,'V404XXS'  /*Person boarding or alighting a car injured in collision with pedestrian or animal, sequela*/
,'V405XXA'  /*Car driver injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V405XXD'  /*Car driver injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V405XXS'  /*Car driver injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V406XXA'  /*Car passenger injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V406XXD'  /*Car passenger injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V406XXS'  /*Car passenger injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V407XXA'  /*Person on outside of car injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V407XXD'  /*Person on outside of car injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V407XXS'  /*Person on outside of car injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V409XXA'  /*Unspecified car occupant injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V409XXD'  /*Unspecified car occupant injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V409XXS'  /*Unspecified car occupant injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V410XXA'  /*Car driver injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V410XXD'  /*Car driver injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V410XXS'  /*Car driver injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V411XXA'  /*Car passenger injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V411XXD'  /*Car passenger injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V411XXS'  /*Car passenger injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V412XXA'  /*Person on outside of car injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V412XXD'  /*Person on outside of car injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V412XXS'  /*Person on outside of car injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V413XXA'  /*Unspecified car occupant injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V413XXD'  /*Unspecified car occupant injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V413XXS'  /*Unspecified car occupant injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V414XXA'  /*Person boarding or alighting a car injured in collision with pedal cycle, initial encounter*/
,'V414XXD'  /*Person boarding or alighting a car injured in collision with pedal cycle, subsequent encounter*/
,'V414XXS'  /*Person boarding or alighting a car injured in collision with pedal cycle, sequela*/
,'V415XXA'  /*Car driver injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V415XXD'  /*Car driver injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V415XXS'  /*Car driver injured in collision with pedal cycle in traffic accident, sequela*/
,'V416XXA'  /*Car passenger injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V416XXD'  /*Car passenger injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V416XXS'  /*Car passenger injured in collision with pedal cycle in traffic accident, sequela*/
,'V417XXA'  /*Person on outside of car injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V417XXD'  /*Person on outside of car injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V417XXS'  /*Person on outside of car injured in collision with pedal cycle in traffic accident, sequela*/
,'V419XXA'  /*Unspecified car occupant injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V419XXD'  /*Unspecified car occupant injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V419XXS'  /*Unspecified car occupant injured in collision with pedal cycle in traffic accident, sequela*/
,'V420XXA'  /*Car driver injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V420XXD'  /*Car driver injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V420XXS'  /*Car driver injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V421XXA'  /*Car passenger injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V421XXD'  /*Car passenger injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V421XXS'  /*Car passenger injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V422XXA'  /*Person on outside of car injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V422XXD'  /*Person on outside of car injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V422XXS'  /*Person on outside of car injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V423XXA'  /*Unspecified car occupant injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V423XXD'  /*Unspecified car occupant injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V423XXS'  /*Unspecified car occupant injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V424XXA'  /*Person boarding or alighting a car injured in collision with two- or three-wheeled motor vehicle, initial encounter*/
,'V424XXD'  /*Person boarding or alighting a car injured in collision with two- or three-wheeled motor vehicle, subsequent encounter*/
,'V424XXS'  /*Person boarding or alighting a car injured in collision with two- or three-wheeled motor vehicle, sequela*/
,'V425XXA'  /*Car driver injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V425XXD'  /*Car driver injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V425XXS'  /*Car driver injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V426XXA'  /*Car passenger injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V426XXD'  /*Car passenger injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V426XXS'  /*Car passenger injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V427XXA'  /*Person on outside of car injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V427XXD'  /*Person on outside of car injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V427XXS'  /*Person on outside of car injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V429XXA'  /*Unspecified car occupant injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V429XXD'  /*Unspecified car occupant injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V429XXS'  /*Unspecified car occupant injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V4301XA'  /*Car driver injured in collision with sport utility vehicle in nontraffic accident, initial encounter*/
,'V4301XD'  /*Car driver injured in collision with sport utility vehicle in nontraffic accident, subsequent encounter*/
,'V4301XS'  /*Car driver injured in collision with sport utility vehicle in nontraffic accident, sequela*/
,'V4302XA'  /*Car driver injured in collision with other type car in nontraffic accident, initial encounter*/
,'V4302XD'  /*Car driver injured in collision with other type car in nontraffic accident, subsequent encounter*/
,'V4302XS'  /*Car driver injured in collision with other type car in nontraffic accident, sequela*/
,'V4303XA'  /*Car driver injured in collision with pick-up truck in nontraffic accident, initial encounter*/
,'V4303XD'  /*Car driver injured in collision with pick-up truck in nontraffic accident, subsequent encounter*/
,'V4303XS'  /*Car driver injured in collision with pick-up truck in nontraffic accident, sequela*/
,'V4304XA'  /*Car driver injured in collision with van in nontraffic accident, initial encounter*/
,'V4304XD'  /*Car driver injured in collision with van in nontraffic accident, subsequent encounter*/
,'V4304XS'  /*Car driver injured in collision with van in nontraffic accident, sequela*/
,'V4311XA'  /*Car passenger injured in collision with sport utility vehicle in nontraffic accident, initial encounter*/
,'V4311XD'  /*Car passenger injured in collision with sport utility vehicle in nontraffic accident, subsequent encounter*/
,'V4311XS'  /*Car passenger injured in collision with sport utility vehicle in nontraffic accident, sequela*/
,'V4312XA'  /*Car passenger injured in collision with other type car in nontraffic accident, initial encounter*/
,'V4312XD'  /*Car passenger injured in collision with other type car in nontraffic accident, subsequent encounter*/
,'V4312XS'  /*Car passenger injured in collision with other type car in nontraffic accident, sequela*/
,'V4313XA'  /*Car passenger injured in collision with pick-up in nontraffic accident, initial encounter*/
,'V4313XD'  /*Car passenger injured in collision with pick-up in nontraffic accident, subsequent encounter*/
,'V4313XS'  /*Car passenger injured in collision with pick-up in nontraffic accident, sequela*/
,'V4314XA'  /*Car passenger injured in collision with van in nontraffic accident, initial encounter*/
,'V4314XD'  /*Car passenger injured in collision with van in nontraffic accident, subsequent encounter*/
,'V4314XS'  /*Car passenger injured in collision with van in nontraffic accident, sequela*/
,'V4321XA'  /*Person on outside of car injured in collision with sport utility vehicle in nontraffic accident, initial encounter*/
,'V4321XD'  /*Person on outside of car injured in collision with sport utility vehicle in nontraffic accident, subsequent encounter*/
,'V4321XS'  /*Person on outside of car injured in collision with sport utility vehicle in nontraffic accident, sequela*/
,'V4322XA'  /*Person on outside of car injured in collision with other type car in nontraffic accident, initial encounter*/
,'V4322XD'  /*Person on outside of car injured in collision with other type car in nontraffic accident, subsequent encounter*/
,'V4322XS'  /*Person on outside of car injured in collision with other type car in nontraffic accident, sequela*/
,'V4323XA'  /*Person on outside of car injured in collision with pick-up truck in nontraffic accident, initial encounter*/
,'V4323XD'  /*Person on outside of car injured in collision with pick-up truck in nontraffic accident, subsequent encounter*/
,'V4323XS'  /*Person on outside of car injured in collision with pick-up truck in nontraffic accident, sequela*/
,'V4324XA'  /*Person on outside of car injured in collision with van in nontraffic accident, initial encounter*/
,'V4324XD'  /*Person on outside of car injured in collision with van in nontraffic accident, subsequent encounter*/
,'V4324XS'  /*Person on outside of car injured in collision with van in nontraffic accident, sequela*/
,'V4331XA'  /*Unspecified car occupant injured in collision with sport utility vehicle in nontraffic accident, initial encounter*/
,'V4331XD'  /*Unspecified car occupant injured in collision with sport utility vehicle in nontraffic accident, subsequent encounter*/
,'V4331XS'  /*Unspecified car occupant injured in collision with sport utility vehicle in nontraffic accident, sequela*/
,'V4332XA'  /*Unspecified car occupant injured in collision with other type car in nontraffic accident, initial encounter*/
,'V4332XD'  /*Unspecified car occupant injured in collision with other type car in nontraffic accident, subsequent encounter*/
,'V4332XS'  /*Unspecified car occupant injured in collision with other type car in nontraffic accident, sequela*/
,'V4333XA'  /*Unspecified car occupant injured in collision with pick-up truck in nontraffic accident, initial encounter*/
,'V4333XD'  /*Unspecified car occupant injured in collision with pick-up truck in nontraffic accident, subsequent encounter*/
,'V4333XS'  /*Unspecified car occupant injured in collision with pick-up truck in nontraffic accident, sequela*/
,'V4334XA'  /*Unspecified car occupant injured in collision with van in nontraffic accident, initial encounter*/
,'V4334XD'  /*Unspecified car occupant injured in collision with van in nontraffic accident, subsequent encounter*/
,'V4334XS'  /*Unspecified car occupant injured in collision with van in nontraffic accident, sequela*/
,'V4341XA'  /*Person boarding or alighting a car injured in collision with sport utility vehicle, initial encounter*/
,'V4341XD'  /*Person boarding or alighting a car injured in collision with sport utility vehicle, subsequent encounter*/
,'V4341XS'  /*Person boarding or alighting a car injured in collision with sport utility vehicle, sequela*/
,'V4342XA'  /*Person boarding or alighting a car injured in collision with other type car, initial encounter*/
,'V4342XD'  /*Person boarding or alighting a car injured in collision with other type car, subsequent encounter*/
,'V4342XS'  /*Person boarding or alighting a car injured in collision with other type car, sequela*/
,'V4343XA'  /*Person boarding or alighting a car injured in collision with pick-up truck, initial encounter*/
,'V4343XD'  /*Person boarding or alighting a car injured in collision with pick-up truck, subsequent encounter*/
,'V4343XS'  /*Person boarding or alighting a car injured in collision with pick-up truck, sequela*/
,'V4344XA'  /*Person boarding or alighting a car injured in collision with van, initial encounter*/
,'V4344XD'  /*Person boarding or alighting a car injured in collision with van, subsequent encounter*/
,'V4344XS'  /*Person boarding or alighting a car injured in collision with van, sequela*/
,'V4351XA'  /*Car driver injured in collision with sport utility vehicle in traffic accident, initial encounter*/
,'V4351XD'  /*Car driver injured in collision with sport utility vehicle in traffic accident, subsequent encounter*/
,'V4351XS'  /*Car driver injured in collision with sport utility vehicle in traffic accident, sequela*/
,'V4352XA'  /*Car driver injured in collision with other type car in traffic accident, initial encounter*/
,'V4352XD'  /*Car driver injured in collision with other type car in traffic accident, subsequent encounter*/
,'V4352XS'  /*Car driver injured in collision with other type car in traffic accident, sequela*/
,'V4353XA'  /*Car driver injured in collision with pick-up truck in traffic accident, initial encounter*/
,'V4353XD'  /*Car driver injured in collision with pick-up truck in traffic accident, subsequent encounter*/
,'V4353XS'  /*Car driver injured in collision with pick-up truck in traffic accident, sequela*/
,'V4354XA'  /*Car driver injured in collision with van in traffic accident, initial encounter*/
,'V4354XD'  /*Car driver injured in collision with van in traffic accident, subsequent encounter*/
,'V4354XS'  /*Car driver injured in collision with van in traffic accident, sequela*/
,'V4361XA'  /*Car passenger injured in collision with sport utility vehicle in traffic accident, initial encounter*/
,'V4361XD'  /*Car passenger injured in collision with sport utility vehicle in traffic accident, subsequent encounter*/
,'V4361XS'  /*Car passenger injured in collision with sport utility vehicle in traffic accident, sequela*/
,'V4362XA'  /*Car passenger injured in collision with other type car in traffic accident, initial encounter*/
,'V4362XD'  /*Car passenger injured in collision with other type car in traffic accident, subsequent encounter*/
,'V4362XS'  /*Car passenger injured in collision with other type car in traffic accident, sequela*/
,'V4363XA'  /*Car passenger injured in collision with pick-up truck in traffic accident, initial encounter*/
,'V4363XD'  /*Car passenger injured in collision with pick-up truck in traffic accident, subsequent encounter*/
,'V4363XS'  /*Car passenger injured in collision with pick-up truck in traffic accident, sequela*/
,'V4364XA'  /*Car passenger injured in collision with van in traffic accident, initial encounter*/
,'V4364XD'  /*Car passenger injured in collision with van in traffic accident, subsequent encounter*/
,'V4364XS'  /*Car passenger injured in collision with van in traffic accident, sequela*/
,'V4371XA'  /*Person on outside of car injured in collision with sport utility vehicle in traffic accident, initial encounter*/
,'V4371XD'  /*Person on outside of car injured in collision with sport utility vehicle in traffic accident, subsequent encounter*/
,'V4371XS'  /*Person on outside of car injured in collision with sport utility vehicle in traffic accident, sequela*/
,'V4372XA'  /*Person on outside of car injured in collision with other type car in traffic accident, initial encounter*/
,'V4372XD'  /*Person on outside of car injured in collision with other type car in traffic accident, subsequent encounter*/
,'V4372XS'  /*Person on outside of car injured in collision with other type car in traffic accident, sequela*/
,'V4373XA'  /*Person on outside of car injured in collision with pick-up truck in traffic accident, initial encounter*/
,'V4373XD'  /*Person on outside of car injured in collision with pick-up truck in traffic accident, subsequent encounter*/
,'V4373XS'  /*Person on outside of car injured in collision with pick-up truck in traffic accident, sequela*/
,'V4374XA'  /*Person on outside of car injured in collision with van in traffic accident, initial encounter*/
,'V4374XD'  /*Person on outside of car injured in collision with van in traffic accident, subsequent encounter*/
,'V4374XS'  /*Person on outside of car injured in collision with van in traffic accident, sequela*/
,'V4391XA'  /*Unspecified car occupant injured in collision with sport utility vehicle in traffic accident, initial encounter*/
,'V4391XD'  /*Unspecified car occupant injured in collision with sport utility vehicle in traffic accident, subsequent encounter*/
,'V4391XS'  /*Unspecified car occupant injured in collision with sport utility vehicle in traffic accident, sequela*/
,'V4392XA'  /*Unspecified car occupant injured in collision with other type car in traffic accident, initial encounter*/
,'V4392XD'  /*Unspecified car occupant injured in collision with other type car in traffic accident, subsequent encounter*/
,'V4392XS'  /*Unspecified car occupant injured in collision with other type car in traffic accident, sequela*/
,'V4393XA'  /*Unspecified car occupant injured in collision with pick-up truck in traffic accident, initial encounter*/
,'V4393XD'  /*Unspecified car occupant injured in collision with pick-up truck in traffic accident, subsequent encounter*/
,'V4393XS'  /*Unspecified car occupant injured in collision with pick-up truck in traffic accident, sequela*/
,'V4394XA'  /*Unspecified car occupant injured in collision with van in traffic accident, initial encounter*/
,'V4394XD'  /*Unspecified car occupant injured in collision with van in traffic accident, subsequent encounter*/
,'V4394XS'  /*Unspecified car occupant injured in collision with van in traffic accident, sequela*/
,'V440XXA'  /*Car driver injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V440XXD'  /*Car driver injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V440XXS'  /*Car driver injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V441XXA'  /*Car passenger injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V441XXD'  /*Car passenger injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V441XXS'  /*Car passenger injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V442XXA'  /*Person on outside of car injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V442XXD'  /*Person on outside of car injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V442XXS'  /*Person on outside of car injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V443XXA'  /*Unspecified car occupant injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V443XXD'  /*Unspecified car occupant injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V443XXS'  /*Unspecified car occupant injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V444XXA'  /*Person boarding or alighting a car injured in collision with heavy transport vehicle or bus, initial encounter*/
,'V444XXD'  /*Person boarding or alighting a car injured in collision with heavy transport vehicle or bus, subsequent encounter*/
,'V444XXS'  /*Person boarding or alighting a car injured in collision with heavy transport vehicle or bus, sequela*/
,'V445XXA'  /*Car driver injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V445XXD'  /*Car driver injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V445XXS'  /*Car driver injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V446XXA'  /*Car passenger injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V446XXD'  /*Car passenger injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V446XXS'  /*Car passenger injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V447XXA'  /*Person on outside of car injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V447XXD'  /*Person on outside of car injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V447XXS'  /*Person on outside of car injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V449XXA'  /*Unspecified car occupant injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V449XXD'  /*Unspecified car occupant injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V449XXS'  /*Unspecified car occupant injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V450XXA'  /*Car driver injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V450XXD'  /*Car driver injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V450XXS'  /*Car driver injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V451XXA'  /*Car passenger injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V451XXD'  /*Car passenger injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V451XXS'  /*Car passenger injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V452XXA'  /*Person on outside of car injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V452XXD'  /*Person on outside of car injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V452XXS'  /*Person on outside of car injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V453XXA'  /*Unspecified car occupant injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V453XXD'  /*Unspecified car occupant injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V453XXS'  /*Unspecified car occupant injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V454XXA'  /*Person boarding or alighting a car injured in collision with railway train or railway vehicle, initial encounter*/
,'V454XXD'  /*Person boarding or alighting a car injured in collision with railway train or railway vehicle, subsequent encounter*/
,'V454XXS'  /*Person boarding or alighting a car injured in collision with railway train or railway vehicle, sequela*/
,'V455XXA'  /*Car driver injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V455XXD'  /*Car driver injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V455XXS'  /*Car driver injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V456XXA'  /*Car passenger injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V456XXD'  /*Car passenger injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V456XXS'  /*Car passenger injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V457XXA'  /*Person on outside of car injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V457XXD'  /*Person on outside of car injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V457XXS'  /*Person on outside of car injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V459XXA'  /*Unspecified car occupant injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V459XXD'  /*Unspecified car occupant injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V459XXS'  /*Unspecified car occupant injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V460XXA'  /*Car driver injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V460XXD'  /*Car driver injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V460XXS'  /*Car driver injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V461XXA'  /*Car passenger injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V461XXD'  /*Car passenger injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V461XXS'  /*Car passenger injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V462XXA'  /*Person on outside of car injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V462XXD'  /*Person on outside of car injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V462XXS'  /*Person on outside of car injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V463XXA'  /*Unspecified car occupant injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V463XXD'  /*Unspecified car occupant injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V463XXS'  /*Unspecified car occupant injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V464XXA'  /*Person boarding or alighting a car injured in collision with other nonmotor vehicle, initial encounter*/
,'V464XXD'  /*Person boarding or alighting a car injured in collision with other nonmotor vehicle, subsequent encounter*/
,'V464XXS'  /*Person boarding or alighting a car injured in collision with other nonmotor vehicle, sequela*/
,'V465XXA'  /*Car driver injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V465XXD'  /*Car driver injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V465XXS'  /*Car driver injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V466XXA'  /*Car passenger injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V466XXD'  /*Car passenger injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V466XXS'  /*Car passenger injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V467XXA'  /*Person on outside of car injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V467XXD'  /*Person on outside of car injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V467XXS'  /*Person on outside of car injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V469XXA'  /*Unspecified car occupant injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V469XXD'  /*Unspecified car occupant injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V469XXS'  /*Unspecified car occupant injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V470XXA'  /*Car driver injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V470XXD'  /*Car driver injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V470XXS'  /*Car driver injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V471XXA'  /*Car passenger injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V471XXD'  /*Car passenger injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V471XXS'  /*Car passenger injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V472XXA'  /*Person on outside of car injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V472XXD'  /*Person on outside of car injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V472XXS'  /*Person on outside of car injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V473XXA'  /*Unspecified car occupant injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V473XXD'  /*Unspecified car occupant injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V473XXS'  /*Unspecified car occupant injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V474XXA'  /*Person boarding or alighting a car injured in collision with fixed or stationary object, initial encounter*/
,'V474XXD'  /*Person boarding or alighting a car injured in collision with fixed or stationary object, subsequent encounter*/
,'V474XXS'  /*Person boarding or alighting a car injured in collision with fixed or stationary object, sequela*/
,'V475XXA'  /*Car driver injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V475XXD'  /*Car driver injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V475XXS'  /*Car driver injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V476XXA'  /*Car passenger injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V476XXD'  /*Car passenger injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V476XXS'  /*Car passenger injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V477XXA'  /*Person on outside of car injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V477XXD'  /*Person on outside of car injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V477XXS'  /*Person on outside of car injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V479XXA'  /*Unspecified car occupant injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V479XXD'  /*Unspecified car occupant injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V479XXS'  /*Unspecified car occupant injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V480XXA'  /*Car driver injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V480XXD'  /*Car driver injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V480XXS'  /*Car driver injured in noncollision transport accident in nontraffic accident, sequela*/
,'V481XXA'  /*Car passenger injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V481XXD'  /*Car passenger injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V481XXS'  /*Car passenger injured in noncollision transport accident in nontraffic accident, sequela*/
,'V482XXA'  /*Person on outside of car injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V482XXD'  /*Person on outside of car injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V482XXS'  /*Person on outside of car injured in noncollision transport accident in nontraffic accident, sequela*/
,'V483XXA'  /*Unspecified car occupant injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V483XXD'  /*Unspecified car occupant injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V483XXS'  /*Unspecified car occupant injured in noncollision transport accident in nontraffic accident, sequela*/
,'V484XXA'  /*Person boarding or alighting a car injured in noncollision transport accident, initial encounter*/
,'V484XXD'  /*Person boarding or alighting a car injured in noncollision transport accident, subsequent encounter*/
,'V484XXS'  /*Person boarding or alighting a car injured in noncollision transport accident, sequela*/
,'V485XXA'  /*Car driver injured in noncollision transport accident in traffic accident, initial encounter*/
,'V485XXD'  /*Car driver injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V485XXS'  /*Car driver injured in noncollision transport accident in traffic accident, sequela*/
,'V486XXA'  /*Car passenger injured in noncollision transport accident in traffic accident, initial encounter*/
,'V486XXD'  /*Car passenger injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V486XXS'  /*Car passenger injured in noncollision transport accident in traffic accident, sequela*/
,'V487XXA'  /*Person on outside of car injured in noncollision transport accident in traffic accident, initial encounter*/
,'V487XXD'  /*Person on outside of car injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V487XXS'  /*Person on outside of car injured in noncollision transport accident in traffic accident, sequela*/
,'V489XXA'  /*Unspecified car occupant injured in noncollision transport accident in traffic accident, initial encounter*/
,'V489XXD'  /*Unspecified car occupant injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V489XXS'  /*Unspecified car occupant injured in noncollision transport accident in traffic accident, sequela*/
,'V4900XA'  /*Driver injured in collision with unspecified motor vehicles in nontraffic accident, initial encounter*/
,'V4900XD'  /*Driver injured in collision with unspecified motor vehicles in nontraffic accident, subsequent encounter*/
,'V4900XS'  /*Driver injured in collision with unspecified motor vehicles in nontraffic accident, sequela*/
,'V4909XA'  /*Driver injured in collision with other motor vehicles in nontraffic accident, initial encounter*/
,'V4909XD'  /*Driver injured in collision with other motor vehicles in nontraffic accident, subsequent encounter*/
,'V4909XS'  /*Driver injured in collision with other motor vehicles in nontraffic accident, sequela*/
,'V4910XA'  /*Passenger injured in collision with unspecified motor vehicles in nontraffic accident, initial encounter*/
,'V4910XD'  /*Passenger injured in collision with unspecified motor vehicles in nontraffic accident, subsequent encounter*/
,'V4910XS'  /*Passenger injured in collision with unspecified motor vehicles in nontraffic accident, sequela*/
,'V4919XA'  /*Passenger injured in collision with other motor vehicles in nontraffic accident, initial encounter*/
,'V4919XD'  /*Passenger injured in collision with other motor vehicles in nontraffic accident, subsequent encounter*/
,'V4919XS'  /*Passenger injured in collision with other motor vehicles in nontraffic accident, sequela*/
,'V4920XA'  /*Unspecified car occupant injured in collision with unspecified motor vehicles in nontraffic accident, initial encounter*/
,'V4920XD'  /*Unspecified car occupant injured in collision with unspecified motor vehicles in nontraffic accident, subsequent encounter*/
,'V4920XS'  /*Unspecified car occupant injured in collision with unspecified motor vehicles in nontraffic accident, sequela*/
,'V4929XA'  /*Unspecified car occupant injured in collision with other motor vehicles in nontraffic accident, initial encounter*/
,'V4929XD'  /*Unspecified car occupant injured in collision with other motor vehicles in nontraffic accident, subsequent encounter*/
,'V4929XS'  /*Unspecified car occupant injured in collision with other motor vehicles in nontraffic accident, sequela*/
,'V493XXA'  /*Car occupant (driver) (passenger) injured in unspecified nontraffic accident, initial encounter*/
,'V493XXD'  /*Car occupant (driver) (passenger) injured in unspecified nontraffic accident, subsequent encounter*/
,'V493XXS'  /*Car occupant (driver) (passenger) injured in unspecified nontraffic accident, sequela*/
,'V4940XA'  /*Driver injured in collision with unspecified motor vehicles in traffic accident, initial encounter*/
,'V4940XD'  /*Driver injured in collision with unspecified motor vehicles in traffic accident, subsequent encounter*/
,'V4940XS'  /*Driver injured in collision with unspecified motor vehicles in traffic accident, sequela*/
,'V4949XA'  /*Driver injured in collision with other motor vehicles in traffic accident, initial encounter*/
,'V4949XD'  /*Driver injured in collision with other motor vehicles in traffic accident, subsequent encounter*/
,'V4949XS'  /*Driver injured in collision with other motor vehicles in traffic accident, sequela*/
,'V4950XA'  /*Passenger injured in collision with unspecified motor vehicles in traffic accident, initial encounter*/
,'V4950XD'  /*Passenger injured in collision with unspecified motor vehicles in traffic accident, subsequent encounter*/
,'V4950XS'  /*Passenger injured in collision with unspecified motor vehicles in traffic accident, sequela*/
,'V4959XA'  /*Passenger injured in collision with other motor vehicles in traffic accident, initial encounter*/
,'V4959XD'  /*Passenger injured in collision with other motor vehicles in traffic accident, subsequent encounter*/
,'V4959XS'  /*Passenger injured in collision with other motor vehicles in traffic accident, sequela*/
,'V4960XA'  /*Unspecified car occupant injured in collision with unspecified motor vehicles in traffic accident, initial encounter*/
,'V4960XD'  /*Unspecified car occupant injured in collision with unspecified motor vehicles in traffic accident, subsequent encounter*/
,'V4960XS'  /*Unspecified car occupant injured in collision with unspecified motor vehicles in traffic accident, sequela*/
,'V4969XA'  /*Unspecified car occupant injured in collision with other motor vehicles in traffic accident, initial encounter*/
,'V4969XD'  /*Unspecified car occupant injured in collision with other motor vehicles in traffic accident, subsequent encounter*/
,'V4969XS'  /*Unspecified car occupant injured in collision with other motor vehicles in traffic accident, sequela*/
,'V4981XA'  /*Car occupant (driver) (passenger) injured in transport accident with military vehicle, initial encounter*/
,'V4981XD'  /*Car occupant (driver) (passenger) injured in transport accident with military vehicle, subsequent encounter*/
,'V4981XS'  /*Car occupant (driver) (passenger) injured in transport accident with military vehicle, sequela*/
,'V4988XA'  /*Car occupant (driver) (passenger) injured in other specified transport accidents, initial encounter*/
,'V4988XD'  /*Car occupant (driver) (passenger) injured in other specified transport accidents, subsequent encounter*/
,'V4988XS'  /*Car occupant (driver) (passenger) injured in other specified transport accidents, sequela*/
,'V499XXA'  /*Car occupant (driver) (passenger) injured in unspecified traffic accident, initial encounter*/
,'V499XXD'  /*Car occupant (driver) (passenger) injured in unspecified traffic accident, subsequent encounter*/
,'V499XXS'  /*Car occupant (driver) (passenger) injured in unspecified traffic accident, sequela*/
,'V500XXA'  /*Driver of pick-up truck or van injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V500XXD'  /*Driver of pick-up truck or van injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V500XXS'  /*Driver of pick-up truck or van injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V501XXA'  /*Passenger in pick-up truck or van injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V501XXD'  /*Passenger in pick-up truck or van injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V501XXS'  /*Passenger in pick-up truck or van injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V502XXA'  /*Person on outside of pick-up truck or van injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V502XXD'  /*Person on outside of pick-up truck or van injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V502XXS'  /*Person on outside of pick-up truck or van injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V503XXA'  /*Unspecified occupant of pick-up truck or van injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V503XXD'  /*Unspecified occupant of pick-up truck or van injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V503XXS'  /*Unspecified occupant of pick-up truck or van injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V504XXA'  /*Person boarding or alighting a pick-up truck or van injured in collision with pedestrian or animal, initial encounter*/
,'V504XXD'  /*Person boarding or alighting a pick-up truck or van injured in collision with pedestrian or animal, subsequent encounter*/
,'V504XXS'  /*Person boarding or alighting a pick-up truck or van injured in collision with pedestrian or animal, sequela*/
,'V505XXA'  /*Driver of pick-up truck or van injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V505XXD'  /*Driver of pick-up truck or van injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V505XXS'  /*Driver of pick-up truck or van injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V506XXA'  /*Passenger in pick-up truck or van injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V506XXD'  /*Passenger in pick-up truck or van injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V506XXS'  /*Passenger in pick-up truck or van injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V507XXA'  /*Person on outside of pick-up truck or van injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V507XXD'  /*Person on outside of pick-up truck or van injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V507XXS'  /*Person on outside of pick-up truck or van injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V509XXA'  /*Unspecified occupant of pick-up truck or van injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V509XXD'  /*Unspecified occupant of pick-up truck or van injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V509XXS'  /*Unspecified occupant of pick-up truck or van injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V510XXA'  /*Driver of pick-up truck or van injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V510XXD'  /*Driver of pick-up truck or van injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V510XXS'  /*Driver of pick-up truck or van injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V511XXA'  /*Passenger in pick-up truck or van injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V511XXD'  /*Passenger in pick-up truck or van injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V511XXS'  /*Passenger in pick-up truck or van injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V512XXA'  /*Person on outside of pick-up truck or van injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V512XXD'  /*Person on outside of pick-up truck or van injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V512XXS'  /*Person on outside of pick-up truck or van injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V513XXA'  /*Unspecified occupant of pick-up truck or van injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V513XXD'  /*Unspecified occupant of pick-up truck or van injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V513XXS'  /*Unspecified occupant of pick-up truck or van injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V514XXA'  /*Person boarding or alighting a pick-up truck or van injured in collision with pedal cycle, initial encounter*/
,'V514XXD'  /*Person boarding or alighting a pick-up truck or van injured in collision with pedal cycle, subsequent encounter*/
,'V514XXS'  /*Person boarding or alighting a pick-up truck or van injured in collision with pedal cycle, sequela*/
,'V515XXA'  /*Driver of pick-up truck or van injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V515XXD'  /*Driver of pick-up truck or van injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V515XXS'  /*Driver of pick-up truck or van injured in collision with pedal cycle in traffic accident, sequela*/
,'V516XXA'  /*Passenger in pick-up truck or van injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V516XXD'  /*Passenger in pick-up truck or van injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V516XXS'  /*Passenger in pick-up truck or van injured in collision with pedal cycle in traffic accident, sequela*/
,'V517XXA'  /*Person on outside of pick-up truck or van injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V517XXD'  /*Person on outside of pick-up truck or van injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V517XXS'  /*Person on outside of pick-up truck or van injured in collision with pedal cycle in traffic accident, sequela*/
,'V519XXA'  /*Unspecified occupant of pick-up truck or van injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V519XXD'  /*Unspecified occupant of pick-up truck or van injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V519XXS'  /*Unspecified occupant of pick-up truck or van injured in collision with pedal cycle in traffic accident, sequela*/
,'V520XXA'  /*Driver of pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V520XXD'  /*Driver of pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V520XXS'  /*Driver of pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V521XXA'  /*Passenger in pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V521XXD'  /*Passenger in pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V521XXS'  /*Passenger in pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V522XXA'  /*Person on outside of pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V522XXD'  /*Person on outside of pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V522XXS'  /*Person on outside of pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V523XXA'  /*Unspecified occupant of pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V523XXD'  /*Unspecified occupant of pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V523XXS'  /*Unspecified occupant of pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V524XXA'  /*Person boarding or alighting a pick-up truck or van injured in collision with two- or three-wheeled motor vehicle, initial encounter*/
,'V524XXD'  /*Person boarding or alighting a pick-up truck or van injured in collision with two- or three-wheeled motor vehicle, subsequent encounter*/
,'V524XXS'  /*Person boarding or alighting a pick-up truck or van injured in collision with two- or three-wheeled motor vehicle, sequela*/
,'V525XXA'  /*Driver of pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V525XXD'  /*Driver of pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V525XXS'  /*Driver of pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V526XXA'  /*Passenger in pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V526XXD'  /*Passenger in pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V526XXS'  /*Passenger in pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V527XXA'  /*Person on outside of pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V527XXD'  /*Person on outside of pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V527XXS'  /*Person on outside of pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V529XXA'  /*Unspecified occupant of pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V529XXD'  /*Unspecified occupant of pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V529XXS'  /*Unspecified occupant of pick-up truck or van injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V530XXA'  /*Driver of pick-up truck or van injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V530XXD'  /*Driver of pick-up truck or van injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V530XXS'  /*Driver of pick-up truck or van injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V531XXA'  /*Passenger in pick-up truck or van injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V531XXD'  /*Passenger in pick-up truck or van injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V531XXS'  /*Passenger in pick-up truck or van injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V532XXA'  /*Person on outside of pick-up truck or van injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V532XXD'  /*Person on outside of pick-up truck or van injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V532XXS'  /*Person on outside of pick-up truck or van injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V533XXA'  /*Unspecified occupant of pick-up truck or van injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V533XXD'  /*Unspecified occupant of pick-up truck or van injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V533XXS'  /*Unspecified occupant of pick-up truck or van injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V534XXA'  /*Person boarding or alighting a pick-up truck or van injured in collision with car, pick-up truck or van, initial encounter*/
,'V534XXD'  /*Person boarding or alighting a pick-up truck or van injured in collision with car, pick-up truck or van, subsequent encounter*/
,'V534XXS'  /*Person boarding or alighting a pick-up truck or van injured in collision with car, pick-up truck or van, sequela*/
,'V535XXA'  /*Driver of pick-up truck or van injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V535XXD'  /*Driver of pick-up truck or van injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V535XXS'  /*Driver of pick-up truck or van injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V536XXA'  /*Passenger in pick-up truck or van injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V536XXD'  /*Passenger in pick-up truck or van injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V536XXS'  /*Passenger in pick-up truck or van injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V537XXA'  /*Person on outside of pick-up truck or van injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V537XXD'  /*Person on outside of pick-up truck or van injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V537XXS'  /*Person on outside of pick-up truck or van injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V539XXA'  /*Unspecified occupant of pick-up truck or van injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V539XXD'  /*Unspecified occupant of pick-up truck or van injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V539XXS'  /*Unspecified occupant of pick-up truck or van injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V540XXA'  /*Driver of pick-up truck or van injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V540XXD'  /*Driver of pick-up truck or van injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V540XXS'  /*Driver of pick-up truck or van injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V541XXA'  /*Passenger in pick-up truck or van injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V541XXD'  /*Passenger in pick-up truck or van injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V541XXS'  /*Passenger in pick-up truck or van injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V542XXA'  /*Person on outside of pick-up truck or van injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V542XXD'  /*Person on outside of pick-up truck or van injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V542XXS'  /*Person on outside of pick-up truck or van injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V543XXA'  /*Unspecified occupant of pick-up truck or van injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V543XXD'  /*Unspecified occupant of pick-up truck or van injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V543XXS'  /*Unspecified occupant of pick-up truck or van injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V544XXA'  /*Person boarding or alighting a pick-up truck or van injured in collision with heavy transport vehicle or bus, initial encounter*/
,'V544XXD'  /*Person boarding or alighting a pick-up truck or van injured in collision with heavy transport vehicle or bus, subsequent encounter*/
,'V544XXS'  /*Person boarding or alighting a pick-up truck or van injured in collision with heavy transport vehicle or bus, sequela*/
,'V545XXA'  /*Driver of pick-up truck or van injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V545XXD'  /*Driver of pick-up truck or van injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V545XXS'  /*Driver of pick-up truck or van injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V546XXA'  /*Passenger in pick-up truck or van injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V546XXD'  /*Passenger in pick-up truck or van injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V546XXS'  /*Passenger in pick-up truck or van injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V547XXA'  /*Person on outside of pick-up truck or van injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V547XXD'  /*Person on outside of pick-up truck or van injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V547XXS'  /*Person on outside of pick-up truck or van injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V549XXA'  /*Unspecified occupant of pick-up truck or van injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V549XXD'  /*Unspecified occupant of pick-up truck or van injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V549XXS'  /*Unspecified occupant of pick-up truck or van injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V550XXA'  /*Driver of pick-up truck or van injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V550XXD'  /*Driver of pick-up truck or van injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V550XXS'  /*Driver of pick-up truck or van injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V551XXA'  /*Passenger in pick-up truck or van injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V551XXD'  /*Passenger in pick-up truck or van injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V551XXS'  /*Passenger in pick-up truck or van injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V552XXA'  /*Person on outside of pick-up truck or van injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V552XXD'  /*Person on outside of pick-up truck or van injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V552XXS'  /*Person on outside of pick-up truck or van injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V553XXA'  /*Unspecified occupant of pick-up truck or van injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V553XXD'  /*Unspecified occupant of pick-up truck or van injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V553XXS'  /*Unspecified occupant of pick-up truck or van injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V554XXA'  /*Person boarding or alighting a pick-up truck or van injured in collision with railway train or railway vehicle, initial encounter*/
,'V554XXD'  /*Person boarding or alighting a pick-up truck or van injured in collision with railway train or railway vehicle, subsequent encounter*/
,'V554XXS'  /*Person boarding or alighting a pick-up truck or van injured in collision with railway train or railway vehicle, sequela*/
,'V555XXA'  /*Driver of pick-up truck or van injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V555XXD'  /*Driver of pick-up truck or van injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V555XXS'  /*Driver of pick-up truck or van injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V556XXA'  /*Passenger in pick-up truck or van injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V556XXD'  /*Passenger in pick-up truck or van injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V556XXS'  /*Passenger in pick-up truck or van injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V557XXA'  /*Person on outside of pick-up truck or van injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V557XXD'  /*Person on outside of pick-up truck or van injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V557XXS'  /*Person on outside of pick-up truck or van injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V559XXA'  /*Unspecified occupant of pick-up truck or van injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V559XXD'  /*Unspecified occupant of pick-up truck or van injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V559XXS'  /*Unspecified occupant of pick-up truck or van injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V560XXA'  /*Driver of pick-up truck or van injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V560XXD'  /*Driver of pick-up truck or van injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V560XXS'  /*Driver of pick-up truck or van injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V561XXA'  /*Passenger in pick-up truck or van injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V561XXD'  /*Passenger in pick-up truck or van injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V561XXS'  /*Passenger in pick-up truck or van injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V562XXA'  /*Person on outside of pick-up truck or van injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V562XXD'  /*Person on outside of pick-up truck or van injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V562XXS'  /*Person on outside of pick-up truck or van injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V563XXA'  /*Unspecified occupant of pick-up truck or van injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V563XXD'  /*Unspecified occupant of pick-up truck or van injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V563XXS'  /*Unspecified occupant of pick-up truck or van injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V564XXA'  /*Person boarding or alighting a pick-up truck or van injured in collision with other nonmotor vehicle, initial encounter*/
,'V564XXD'  /*Person boarding or alighting a pick-up truck or van injured in collision with other nonmotor vehicle, subsequent encounter*/
,'V564XXS'  /*Person boarding or alighting a pick-up truck or van injured in collision with other nonmotor vehicle, sequela*/
,'V565XXA'  /*Driver of pick-up truck or van injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V565XXD'  /*Driver of pick-up truck or van injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V565XXS'  /*Driver of pick-up truck or van injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V566XXA'  /*Passenger in pick-up truck or van injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V566XXD'  /*Passenger in pick-up truck or van injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V566XXS'  /*Passenger in pick-up truck or van injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V567XXA'  /*Person on outside of pick-up truck or van injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V567XXD'  /*Person on outside of pick-up truck or van injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V567XXS'  /*Person on outside of pick-up truck or van injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V569XXA'  /*Unspecified occupant of pick-up truck or van injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V569XXD'  /*Unspecified occupant of pick-up truck or van injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V569XXS'  /*Unspecified occupant of pick-up truck or van injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V570XXA'  /*Driver of pick-up truck or van injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V570XXD'  /*Driver of pick-up truck or van injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V570XXS'  /*Driver of pick-up truck or van injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V571XXA'  /*Passenger in pick-up truck or van injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V571XXD'  /*Passenger in pick-up truck or van injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V571XXS'  /*Passenger in pick-up truck or van injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V572XXA'  /*Person on outside of pick-up truck or van injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V572XXD'  /*Person on outside of pick-up truck or van injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V572XXS'  /*Person on outside of pick-up truck or van injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V573XXA'  /*Unspecified occupant of pick-up truck or van injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V573XXD'  /*Unspecified occupant of pick-up truck or van injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V573XXS'  /*Unspecified occupant of pick-up truck or van injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V574XXA'  /*Person boarding or alighting a pick-up truck or van injured in collision with fixed or stationary object, initial encounter*/
,'V574XXD'  /*Person boarding or alighting a pick-up truck or van injured in collision with fixed or stationary object, subsequent encounter*/
,'V574XXS'  /*Person boarding or alighting a pick-up truck or van injured in collision with fixed or stationary object, sequela*/
,'V575XXA'  /*Driver of pick-up truck or van injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V575XXD'  /*Driver of pick-up truck or van injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V575XXS'  /*Driver of pick-up truck or van injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V576XXA'  /*Passenger in pick-up truck or van injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V576XXD'  /*Passenger in pick-up truck or van injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V576XXS'  /*Passenger in pick-up truck or van injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V577XXA'  /*Person on outside of pick-up truck or van injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V577XXD'  /*Person on outside of pick-up truck or van injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V577XXS'  /*Person on outside of pick-up truck or van injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V579XXA'  /*Unspecified occupant of pick-up truck or van injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V579XXD'  /*Unspecified occupant of pick-up truck or van injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V579XXS'  /*Unspecified occupant of pick-up truck or van injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V580XXA'  /*Driver of pick-up truck or van injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V580XXD'  /*Driver of pick-up truck or van injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V580XXS'  /*Driver of pick-up truck or van injured in noncollision transport accident in nontraffic accident, sequela*/
,'V581XXA'  /*Passenger in pick-up truck or van injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V581XXD'  /*Passenger in pick-up truck or van injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V581XXS'  /*Passenger in pick-up truck or van injured in noncollision transport accident in nontraffic accident, sequela*/
,'V582XXA'  /*Person on outside of pick-up truck or van injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V582XXD'  /*Person on outside of pick-up truck or van injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V582XXS'  /*Person on outside of pick-up truck or van injured in noncollision transport accident in nontraffic accident, sequela*/
,'V583XXA'  /*Unspecified occupant of pick-up truck or van injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V583XXD'  /*Unspecified occupant of pick-up truck or van injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V583XXS'  /*Unspecified occupant of pick-up truck or van injured in noncollision transport accident in nontraffic accident, sequela*/
,'V584XXA'  /*Person boarding or alighting a pick-up truck or van injured in noncollision transport accident, initial encounter*/
,'V584XXD'  /*Person boarding or alighting a pick-up truck or van injured in noncollision transport accident, subsequent encounter*/
,'V584XXS'  /*Person boarding or alighting a pick-up truck or van injured in noncollision transport accident, sequela*/
,'V585XXA'  /*Driver of pick-up truck or van injured in noncollision transport accident in traffic accident, initial encounter*/
,'V585XXD'  /*Driver of pick-up truck or van injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V585XXS'  /*Driver of pick-up truck or van injured in noncollision transport accident in traffic accident, sequela*/
,'V586XXA'  /*Passenger in pick-up truck or van injured in noncollision transport accident in traffic accident, initial encounter*/
,'V586XXD'  /*Passenger in pick-up truck or van injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V586XXS'  /*Passenger in pick-up truck or van injured in noncollision transport accident in traffic accident, sequela*/
,'V587XXA'  /*Person on outside of pick-up truck or van injured in noncollision transport accident in traffic accident, initial encounter*/
,'V587XXD'  /*Person on outside of pick-up truck or van injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V587XXS'  /*Person on outside of pick-up truck or van injured in noncollision transport accident in traffic accident, sequela*/
,'V589XXA'  /*Unspecified occupant of pick-up truck or van injured in noncollision transport accident in traffic accident, initial encounter*/
,'V589XXD'  /*Unspecified occupant of pick-up truck or van injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V589XXS'  /*Unspecified occupant of pick-up truck or van injured in noncollision transport accident in traffic accident, sequela*/
,'V5900XA'  /*Driver of pick-up truck or van injured in collision with unspecified motor vehicles in nontraffic accident, initial encounter*/
,'V5900XD'  /*Driver of pick-up truck or van injured in collision with unspecified motor vehicles in nontraffic accident, subsequent encounter*/
,'V5900XS'  /*Driver of pick-up truck or van injured in collision with unspecified motor vehicles in nontraffic accident, sequela*/
,'V5909XA'  /*Driver of pick-up truck or van injured in collision with other motor vehicles in nontraffic accident, initial encounter*/
,'V5909XD'  /*Driver of pick-up truck or van injured in collision with other motor vehicles in nontraffic accident, subsequent encounter*/
,'V5909XS'  /*Driver of pick-up truck or van injured in collision with other motor vehicles in nontraffic accident, sequela*/
,'V5910XA'  /*Passenger in pick-up truck or van injured in collision with unspecified motor vehicles in nontraffic accident, initial encounter*/
,'V5910XD'  /*Passenger in pick-up truck or van injured in collision with unspecified motor vehicles in nontraffic accident, subsequent encounter*/
,'V5910XS'  /*Passenger in pick-up truck or van injured in collision with unspecified motor vehicles in nontraffic accident, sequela*/
,'V5919XA'  /*Passenger in pick-up truck or van injured in collision with other motor vehicles in nontraffic accident, initial encounter*/
,'V5919XD'  /*Passenger in pick-up truck or van injured in collision with other motor vehicles in nontraffic accident, subsequent encounter*/
,'V5919XS'  /*Passenger in pick-up truck or van injured in collision with other motor vehicles in nontraffic accident, sequela*/
,'V5920XA'  /*Unspecified occupant of pick-up truck or van injured in collision with unspecified motor vehicles in nontraffic accident, initial encounter*/
,'V5920XD'  /*Unspecified occupant of pick-up truck or van injured in collision with unspecified motor vehicles in nontraffic accident, subsequent encounter*/
,'V5920XS'  /*Unspecified occupant of pick-up truck or van injured in collision with unspecified motor vehicles in nontraffic accident, sequela*/
,'V5929XA'  /*Unspecified occupant of pick-up truck or van injured in collision with other motor vehicles in nontraffic accident, initial encounter*/
,'V5929XD'  /*Unspecified occupant of pick-up truck or van injured in collision with other motor vehicles in nontraffic accident, subsequent encounter*/
,'V5929XS'  /*Unspecified occupant of pick-up truck or van injured in collision with other motor vehicles in nontraffic accident, sequela*/
,'V593XXA'  /*Occupant (driver) (passenger) of pick-up truck or van injured in unspecified nontraffic accident, initial encounter*/
,'V593XXD'  /*Occupant (driver) (passenger) of pick-up truck or van injured in unspecified nontraffic accident, subsequent encounter*/
,'V593XXS'  /*Occupant (driver) (passenger) of pick-up truck or van injured in unspecified nontraffic accident, sequela*/
,'V5940XA'  /*Driver of pick-up truck or van injured in collision with unspecified motor vehicles in traffic accident, initial encounter*/
,'V5940XD'  /*Driver of pick-up truck or van injured in collision with unspecified motor vehicles in traffic accident, subsequent encounter*/
,'V5940XS'  /*Driver of pick-up truck or van injured in collision with unspecified motor vehicles in traffic accident, sequela*/
,'V5949XA'  /*Driver of pick-up truck or van injured in collision with other motor vehicles in traffic accident, initial encounter*/
,'V5949XD'  /*Driver of pick-up truck or van injured in collision with other motor vehicles in traffic accident, subsequent encounter*/
,'V5949XS'  /*Driver of pick-up truck or van injured in collision with other motor vehicles in traffic accident, sequela*/
,'V5950XA'  /*Passenger in pick-up truck or van injured in collision with unspecified motor vehicles in traffic accident, initial encounter*/
,'V5950XD'  /*Passenger in pick-up truck or van injured in collision with unspecified motor vehicles in traffic accident, subsequent encounter*/
,'V5950XS'  /*Passenger in pick-up truck or van injured in collision with unspecified motor vehicles in traffic accident, sequela*/
,'V5959XA'  /*Passenger in pick-up truck or van injured in collision with other motor vehicles in traffic accident, initial encounter*/
,'V5959XD'  /*Passenger in pick-up truck or van injured in collision with other motor vehicles in traffic accident, subsequent encounter*/
,'V5959XS'  /*Passenger in pick-up truck or van injured in collision with other motor vehicles in traffic accident, sequela*/
,'V5960XA'  /*Unspecified occupant of pick-up truck or van injured in collision with unspecified motor vehicles in traffic accident, initial encounter*/
,'V5960XD'  /*Unspecified occupant of pick-up truck or van injured in collision with unspecified motor vehicles in traffic accident, subsequent encounter*/
,'V5960XS'  /*Unspecified occupant of pick-up truck or van injured in collision with unspecified motor vehicles in traffic accident, sequela*/
,'V5969XA'  /*Unspecified occupant of pick-up truck or van injured in collision with other motor vehicles in traffic accident, initial encounter*/
,'V5969XD'  /*Unspecified occupant of pick-up truck or van injured in collision with other motor vehicles in traffic accident, subsequent encounter*/
,'V5969XS'  /*Unspecified occupant of pick-up truck or van injured in collision with other motor vehicles in traffic accident, sequela*/
,'V5981XA'  /*Occupant (driver) (passenger) of pick-up truck or van injured in transport accident with military vehicle, initial encounter*/
,'V5981XD'  /*Occupant (driver) (passenger) of pick-up truck or van injured in transport accident with military vehicle, subsequent encounter*/
,'V5981XS'  /*Occupant (driver) (passenger) of pick-up truck or van injured in transport accident with military vehicle, sequela*/
,'V5988XA'  /*Occupant (driver) (passenger) of pick-up truck or van injured in other specified transport accidents, initial encounter*/
,'V5988XD'  /*Occupant (driver) (passenger) of pick-up truck or van injured in other specified transport accidents, subsequent encounter*/
,'V5988XS'  /*Occupant (driver) (passenger) of pick-up truck or van injured in other specified transport accidents, sequela*/
,'V599XXA'  /*Occupant (driver) (passenger) of pick-up truck or van injured in unspecified traffic accident, initial encounter*/
,'V599XXD'  /*Occupant (driver) (passenger) of pick-up truck or van injured in unspecified traffic accident, subsequent encounter*/
,'V599XXS'  /*Occupant (driver) (passenger) of pick-up truck or van injured in unspecified traffic accident, sequela*/
,'V600XXA'  /*Driver of heavy transport vehicle injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V600XXD'  /*Driver of heavy transport vehicle injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V600XXS'  /*Driver of heavy transport vehicle injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V601XXA'  /*Passenger in heavy transport vehicle injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V601XXD'  /*Passenger in heavy transport vehicle injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V601XXS'  /*Passenger in heavy transport vehicle injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V602XXA'  /*Person on outside of heavy transport vehicle injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V602XXD'  /*Person on outside of heavy transport vehicle injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V602XXS'  /*Person on outside of heavy transport vehicle injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V603XXA'  /*Unspecified occupant of heavy transport vehicle injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V603XXD'  /*Unspecified occupant of heavy transport vehicle injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V603XXS'  /*Unspecified occupant of heavy transport vehicle injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V604XXA'  /*Person boarding or alighting a heavy transport vehicle injured in collision with pedestrian or animal, initial encounter*/
,'V604XXD'  /*Person boarding or alighting a heavy transport vehicle injured in collision with pedestrian or animal, subsequent encounter*/
,'V604XXS'  /*Person boarding or alighting a heavy transport vehicle injured in collision with pedestrian or animal, sequela*/
,'V605XXA'  /*Driver of heavy transport vehicle injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V605XXD'  /*Driver of heavy transport vehicle injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V605XXS'  /*Driver of heavy transport vehicle injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V606XXA'  /*Passenger in heavy transport vehicle injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V606XXD'  /*Passenger in heavy transport vehicle injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V606XXS'  /*Passenger in heavy transport vehicle injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V607XXA'  /*Person on outside of heavy transport vehicle injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V607XXD'  /*Person on outside of heavy transport vehicle injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V607XXS'  /*Person on outside of heavy transport vehicle injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V609XXA'  /*Unspecified occupant of heavy transport vehicle injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V609XXD'  /*Unspecified occupant of heavy transport vehicle injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V609XXS'  /*Unspecified occupant of heavy transport vehicle injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V610XXA'  /*Driver of heavy transport vehicle injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V610XXD'  /*Driver of heavy transport vehicle injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V610XXS'  /*Driver of heavy transport vehicle injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V611XXA'  /*Passenger in heavy transport vehicle injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V611XXD'  /*Passenger in heavy transport vehicle injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V611XXS'  /*Passenger in heavy transport vehicle injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V612XXA'  /*Person on outside of heavy transport vehicle injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V612XXD'  /*Person on outside of heavy transport vehicle injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V612XXS'  /*Person on outside of heavy transport vehicle injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V613XXA'  /*Unspecified occupant of heavy transport vehicle injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V613XXD'  /*Unspecified occupant of heavy transport vehicle injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V613XXS'  /*Unspecified occupant of heavy transport vehicle injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V614XXA'  /*Person boarding or alighting a heavy transport vehicle injured in collision with pedal cycle while boarding or alighting, initial encounter*/
,'V614XXD'  /*Person boarding or alighting a heavy transport vehicle injured in collision with pedal cycle while boarding or alighting, subsequent encounter*/
,'V614XXS'  /*Person boarding or alighting a heavy transport vehicle injured in collision with pedal cycle while boarding or alighting, sequela*/
,'V615XXA'  /*Driver of heavy transport vehicle injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V615XXD'  /*Driver of heavy transport vehicle injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V615XXS'  /*Driver of heavy transport vehicle injured in collision with pedal cycle in traffic accident, sequela*/
,'V616XXA'  /*Passenger in heavy transport vehicle injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V616XXD'  /*Passenger in heavy transport vehicle injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V616XXS'  /*Passenger in heavy transport vehicle injured in collision with pedal cycle in traffic accident, sequela*/
,'V617XXA'  /*Person on outside of heavy transport vehicle injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V617XXD'  /*Person on outside of heavy transport vehicle injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V617XXS'  /*Person on outside of heavy transport vehicle injured in collision with pedal cycle in traffic accident, sequela*/
,'V619XXA'  /*Unspecified occupant of heavy transport vehicle injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V619XXD'  /*Unspecified occupant of heavy transport vehicle injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V619XXS'  /*Unspecified occupant of heavy transport vehicle injured in collision with pedal cycle in traffic accident, sequela*/
,'V620XXA'  /*Driver of heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V620XXD'  /*Driver of heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V620XXS'  /*Driver of heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V621XXA'  /*Passenger in heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V621XXD'  /*Passenger in heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V621XXS'  /*Passenger in heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V622XXA'  /*Person on outside of heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V622XXD'  /*Person on outside of heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V622XXS'  /*Person on outside of heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V623XXA'  /*Unspecified occupant of heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V623XXD'  /*Unspecified occupant of heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V623XXS'  /*Unspecified occupant of heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V624XXA'  /*Person boarding or alighting a heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle, initial encounter*/
,'V624XXD'  /*Person boarding or alighting a heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle, subsequent encounter*/
,'V624XXS'  /*Person boarding or alighting a heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle, sequela*/
,'V625XXA'  /*Driver of heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V625XXD'  /*Driver of heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V625XXS'  /*Driver of heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V626XXA'  /*Passenger in heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V626XXD'  /*Passenger in heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V626XXS'  /*Passenger in heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V627XXA'  /*Person on outside of heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V627XXD'  /*Person on outside of heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V627XXS'  /*Person on outside of heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V629XXA'  /*Unspecified occupant of heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V629XXD'  /*Unspecified occupant of heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V629XXS'  /*Unspecified occupant of heavy transport vehicle injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V630XXA'  /*Driver of heavy transport vehicle injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V630XXD'  /*Driver of heavy transport vehicle injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V630XXS'  /*Driver of heavy transport vehicle injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V631XXA'  /*Passenger in heavy transport vehicle injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V631XXD'  /*Passenger in heavy transport vehicle injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V631XXS'  /*Passenger in heavy transport vehicle injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V632XXA'  /*Person on outside of heavy transport vehicle injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V632XXD'  /*Person on outside of heavy transport vehicle injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V632XXS'  /*Person on outside of heavy transport vehicle injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V633XXA'  /*Unspecified occupant of heavy transport vehicle injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V633XXD'  /*Unspecified occupant of heavy transport vehicle injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V633XXS'  /*Unspecified occupant of heavy transport vehicle injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V634XXA'  /*Person boarding or alighting a heavy transport vehicle injured in collision with car, pick-up truck or van, initial encounter*/
,'V634XXD'  /*Person boarding or alighting a heavy transport vehicle injured in collision with car, pick-up truck or van, subsequent encounter*/
,'V634XXS'  /*Person boarding or alighting a heavy transport vehicle injured in collision with car, pick-up truck or van, sequela*/
,'V635XXA'  /*Driver of heavy transport vehicle injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V635XXD'  /*Driver of heavy transport vehicle injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V635XXS'  /*Driver of heavy transport vehicle injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V636XXA'  /*Passenger in heavy transport vehicle injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V636XXD'  /*Passenger in heavy transport vehicle injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V636XXS'  /*Passenger in heavy transport vehicle injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V637XXA'  /*Person on outside of heavy transport vehicle injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V637XXD'  /*Person on outside of heavy transport vehicle injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V637XXS'  /*Person on outside of heavy transport vehicle injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V639XXA'  /*Unspecified occupant of heavy transport vehicle injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V639XXD'  /*Unspecified occupant of heavy transport vehicle injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V639XXS'  /*Unspecified occupant of heavy transport vehicle injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V640XXA'  /*Driver of heavy transport vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V640XXD'  /*Driver of heavy transport vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V640XXS'  /*Driver of heavy transport vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V641XXA'  /*Passenger in heavy transport vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V641XXD'  /*Passenger in heavy transport vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V641XXS'  /*Passenger in heavy transport vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V642XXA'  /*Person on outside of heavy transport vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V642XXD'  /*Person on outside of heavy transport vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V642XXS'  /*Person on outside of heavy transport vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V643XXA'  /*Unspecified occupant of heavy transport vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V643XXD'  /*Unspecified occupant of heavy transport vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V643XXS'  /*Unspecified occupant of heavy transport vehicle injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V644XXA'  /*Person boarding or alighting a heavy transport vehicle injured in collision with heavy transport vehicle or bus while boarding or alighting, initial encounter*/
,'V644XXD'  /*Person boarding or alighting a heavy transport vehicle injured in collision with heavy transport vehicle or bus while boarding or alighting, subsequent encounter*/
,'V644XXS'  /*Person boarding or alighting a heavy transport vehicle injured in collision with heavy transport vehicle or bus while boarding or alighting, sequela*/
,'V645XXA'  /*Driver of heavy transport vehicle injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V645XXD'  /*Driver of heavy transport vehicle injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V645XXS'  /*Driver of heavy transport vehicle injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V646XXA'  /*Passenger in heavy transport vehicle injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V646XXD'  /*Passenger in heavy transport vehicle injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V646XXS'  /*Passenger in heavy transport vehicle injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V647XXA'  /*Person on outside of heavy transport vehicle injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V647XXD'  /*Person on outside of heavy transport vehicle injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V647XXS'  /*Person on outside of heavy transport vehicle injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V649XXA'  /*Unspecified occupant of heavy transport vehicle injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V649XXD'  /*Unspecified occupant of heavy transport vehicle injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V649XXS'  /*Unspecified occupant of heavy transport vehicle injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V650XXA'  /*Driver of heavy transport vehicle injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V650XXD'  /*Driver of heavy transport vehicle injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V650XXS'  /*Driver of heavy transport vehicle injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V651XXA'  /*Passenger in heavy transport vehicle injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V651XXD'  /*Passenger in heavy transport vehicle injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V651XXS'  /*Passenger in heavy transport vehicle injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V652XXA'  /*Person on outside of heavy transport vehicle injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V652XXD'  /*Person on outside of heavy transport vehicle injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V652XXS'  /*Person on outside of heavy transport vehicle injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V653XXA'  /*Unspecified occupant of heavy transport vehicle injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V653XXD'  /*Unspecified occupant of heavy transport vehicle injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V653XXS'  /*Unspecified occupant of heavy transport vehicle injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V654XXA'  /*Person boarding or alighting a heavy transport vehicle injured in collision with railway train or railway vehicle, initial encounter*/
,'V654XXD'  /*Person boarding or alighting a heavy transport vehicle injured in collision with railway train or railway vehicle, subsequent encounter*/
,'V654XXS'  /*Person boarding or alighting a heavy transport vehicle injured in collision with railway train or railway vehicle, sequela*/
,'V655XXA'  /*Driver of heavy transport vehicle injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V655XXD'  /*Driver of heavy transport vehicle injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V655XXS'  /*Driver of heavy transport vehicle injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V656XXA'  /*Passenger in heavy transport vehicle injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V656XXD'  /*Passenger in heavy transport vehicle injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V656XXS'  /*Passenger in heavy transport vehicle injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V657XXA'  /*Person on outside of heavy transport vehicle injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V657XXD'  /*Person on outside of heavy transport vehicle injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V657XXS'  /*Person on outside of heavy transport vehicle injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V659XXA'  /*Unspecified occupant of heavy transport vehicle injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V659XXD'  /*Unspecified occupant of heavy transport vehicle injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V659XXS'  /*Unspecified occupant of heavy transport vehicle injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V660XXA'  /*Driver of heavy transport vehicle injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V660XXD'  /*Driver of heavy transport vehicle injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V660XXS'  /*Driver of heavy transport vehicle injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V661XXA'  /*Passenger in heavy transport vehicle injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V661XXD'  /*Passenger in heavy transport vehicle injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V661XXS'  /*Passenger in heavy transport vehicle injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V662XXA'  /*Person on outside of heavy transport vehicle injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V662XXD'  /*Person on outside of heavy transport vehicle injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V662XXS'  /*Person on outside of heavy transport vehicle injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V663XXA'  /*Unspecified occupant of heavy transport vehicle injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V663XXD'  /*Unspecified occupant of heavy transport vehicle injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V663XXS'  /*Unspecified occupant of heavy transport vehicle injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V664XXA'  /*Person boarding or alighting a heavy transport vehicle injured in collision with other nonmotor vehicle, initial encounter*/
,'V664XXD'  /*Person boarding or alighting a heavy transport vehicle injured in collision with other nonmotor vehicle, subsequent encounter*/
,'V664XXS'  /*Person boarding or alighting a heavy transport vehicle injured in collision with other nonmotor vehicle, sequela*/
,'V665XXA'  /*Driver of heavy transport vehicle injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V665XXD'  /*Driver of heavy transport vehicle injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V665XXS'  /*Driver of heavy transport vehicle injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V666XXA'  /*Passenger in heavy transport vehicle injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V666XXD'  /*Passenger in heavy transport vehicle injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V666XXS'  /*Passenger in heavy transport vehicle injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V667XXA'  /*Person on outside of heavy transport vehicle injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V667XXD'  /*Person on outside of heavy transport vehicle injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V667XXS'  /*Person on outside of heavy transport vehicle injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V669XXA'  /*Unspecified occupant of heavy transport vehicle injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V669XXD'  /*Unspecified occupant of heavy transport vehicle injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V669XXS'  /*Unspecified occupant of heavy transport vehicle injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V670XXA'  /*Driver of heavy transport vehicle injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V670XXD'  /*Driver of heavy transport vehicle injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V670XXS'  /*Driver of heavy transport vehicle injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V671XXA'  /*Passenger in heavy transport vehicle injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V671XXD'  /*Passenger in heavy transport vehicle injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V671XXS'  /*Passenger in heavy transport vehicle injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V672XXA'  /*Person on outside of heavy transport vehicle injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V672XXD'  /*Person on outside of heavy transport vehicle injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V672XXS'  /*Person on outside of heavy transport vehicle injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V673XXA'  /*Unspecified occupant of heavy transport vehicle injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V673XXD'  /*Unspecified occupant of heavy transport vehicle injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V673XXS'  /*Unspecified occupant of heavy transport vehicle injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V674XXA'  /*Person boarding or alighting a heavy transport vehicle injured in collision with fixed or stationary object, initial encounter*/
,'V674XXD'  /*Person boarding or alighting a heavy transport vehicle injured in collision with fixed or stationary object, subsequent encounter*/
,'V674XXS'  /*Person boarding or alighting a heavy transport vehicle injured in collision with fixed or stationary object, sequela*/
,'V675XXA'  /*Driver of heavy transport vehicle injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V675XXD'  /*Driver of heavy transport vehicle injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V675XXS'  /*Driver of heavy transport vehicle injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V676XXA'  /*Passenger in heavy transport vehicle injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V676XXD'  /*Passenger in heavy transport vehicle injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V676XXS'  /*Passenger in heavy transport vehicle injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V677XXA'  /*Person on outside of heavy transport vehicle injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V677XXD'  /*Person on outside of heavy transport vehicle injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V677XXS'  /*Person on outside of heavy transport vehicle injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V679XXA'  /*Unspecified occupant of heavy transport vehicle injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V679XXD'  /*Unspecified occupant of heavy transport vehicle injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V679XXS'  /*Unspecified occupant of heavy transport vehicle injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V680XXA'  /*Driver of heavy transport vehicle injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V680XXD'  /*Driver of heavy transport vehicle injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V680XXS'  /*Driver of heavy transport vehicle injured in noncollision transport accident in nontraffic accident, sequela*/
,'V681XXA'  /*Passenger in heavy transport vehicle injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V681XXD'  /*Passenger in heavy transport vehicle injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V681XXS'  /*Passenger in heavy transport vehicle injured in noncollision transport accident in nontraffic accident, sequela*/
,'V682XXA'  /*Person on outside of heavy transport vehicle injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V682XXD'  /*Person on outside of heavy transport vehicle injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V682XXS'  /*Person on outside of heavy transport vehicle injured in noncollision transport accident in nontraffic accident, sequela*/
,'V683XXA'  /*Unspecified occupant of heavy transport vehicle injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V683XXD'  /*Unspecified occupant of heavy transport vehicle injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V683XXS'  /*Unspecified occupant of heavy transport vehicle injured in noncollision transport accident in nontraffic accident, sequela*/
,'V684XXA'  /*Person boarding or alighting a heavy transport vehicle injured in noncollision transport accident, initial encounter*/
,'V684XXD'  /*Person boarding or alighting a heavy transport vehicle injured in noncollision transport accident, subsequent encounter*/
,'V684XXS'  /*Person boarding or alighting a heavy transport vehicle injured in noncollision transport accident, sequela*/
,'V685XXA'  /*Driver of heavy transport vehicle injured in noncollision transport accident in traffic accident, initial encounter*/
,'V685XXD'  /*Driver of heavy transport vehicle injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V685XXS'  /*Driver of heavy transport vehicle injured in noncollision transport accident in traffic accident, sequela*/
,'V686XXA'  /*Passenger in heavy transport vehicle injured in noncollision transport accident in traffic accident, initial encounter*/
,'V686XXD'  /*Passenger in heavy transport vehicle injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V686XXS'  /*Passenger in heavy transport vehicle injured in noncollision transport accident in traffic accident, sequela*/
,'V687XXA'  /*Person on outside of heavy transport vehicle injured in noncollision transport accident in traffic accident, initial encounter*/
,'V687XXD'  /*Person on outside of heavy transport vehicle injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V687XXS'  /*Person on outside of heavy transport vehicle injured in noncollision transport accident in traffic accident, sequela*/
,'V689XXA'  /*Unspecified occupant of heavy transport vehicle injured in noncollision transport accident in traffic accident, initial encounter*/
,'V689XXD'  /*Unspecified occupant of heavy transport vehicle injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V689XXS'  /*Unspecified occupant of heavy transport vehicle injured in noncollision transport accident in traffic accident, sequela*/
,'V6900XA'  /*Driver of heavy transport vehicle injured in collision with unspecified motor vehicles in nontraffic accident, initial encounter*/
,'V6900XD'  /*Driver of heavy transport vehicle injured in collision with unspecified motor vehicles in nontraffic accident, subsequent encounter*/
,'V6900XS'  /*Driver of heavy transport vehicle injured in collision with unspecified motor vehicles in nontraffic accident, sequela*/
,'V6909XA'  /*Driver of heavy transport vehicle injured in collision with other motor vehicles in nontraffic accident, initial encounter*/
,'V6909XD'  /*Driver of heavy transport vehicle injured in collision with other motor vehicles in nontraffic accident, subsequent encounter*/
,'V6909XS'  /*Driver of heavy transport vehicle injured in collision with other motor vehicles in nontraffic accident, sequela*/
,'V6910XA'  /*Passenger in heavy transport vehicle injured in collision with unspecified motor vehicles in nontraffic accident, initial encounter*/
,'V6910XD'  /*Passenger in heavy transport vehicle injured in collision with unspecified motor vehicles in nontraffic accident, subsequent encounter*/
,'V6910XS'  /*Passenger in heavy transport vehicle injured in collision with unspecified motor vehicles in nontraffic accident, sequela*/
,'V6919XA'  /*Passenger in heavy transport vehicle injured in collision with other motor vehicles in nontraffic accident, initial encounter*/
,'V6919XD'  /*Passenger in heavy transport vehicle injured in collision with other motor vehicles in nontraffic accident, subsequent encounter*/
,'V6919XS'  /*Passenger in heavy transport vehicle injured in collision with other motor vehicles in nontraffic accident, sequela*/
,'V6920XA'  /*Unspecified occupant of heavy transport vehicle injured in collision with unspecified motor vehicles in nontraffic accident, initial encounter*/
,'V6920XD'  /*Unspecified occupant of heavy transport vehicle injured in collision with unspecified motor vehicles in nontraffic accident, subsequent encounter*/
,'V6920XS'  /*Unspecified occupant of heavy transport vehicle injured in collision with unspecified motor vehicles in nontraffic accident, sequela*/
,'V6929XA'  /*Unspecified occupant of heavy transport vehicle injured in collision with other motor vehicles in nontraffic accident, initial encounter*/
,'V6929XD'  /*Unspecified occupant of heavy transport vehicle injured in collision with other motor vehicles in nontraffic accident, subsequent encounter*/
,'V6929XS'  /*Unspecified occupant of heavy transport vehicle injured in collision with other motor vehicles in nontraffic accident, sequela*/
,'V693XXA'  /*Occupant (driver) (passenger) of heavy transport vehicle injured in unspecified nontraffic accident, initial encounter*/
,'V693XXD'  /*Occupant (driver) (passenger) of heavy transport vehicle injured in unspecified nontraffic accident, subsequent encounter*/
,'V693XXS'  /*Occupant (driver) (passenger) of heavy transport vehicle injured in unspecified nontraffic accident, sequela*/
,'V6940XA'  /*Driver of heavy transport vehicle injured in collision with unspecified motor vehicles in traffic accident, initial encounter*/
,'V6940XD'  /*Driver of heavy transport vehicle injured in collision with unspecified motor vehicles in traffic accident, subsequent encounter*/
,'V6940XS'  /*Driver of heavy transport vehicle injured in collision with unspecified motor vehicles in traffic accident, sequela*/
,'V6949XA'  /*Driver of heavy transport vehicle injured in collision with other motor vehicles in traffic accident, initial encounter*/
,'V6949XD'  /*Driver of heavy transport vehicle injured in collision with other motor vehicles in traffic accident, subsequent encounter*/
,'V6949XS'  /*Driver of heavy transport vehicle injured in collision with other motor vehicles in traffic accident, sequela*/
,'V6950XA'  /*Passenger in heavy transport vehicle injured in collision with unspecified motor vehicles in traffic accident, initial encounter*/
,'V6950XD'  /*Passenger in heavy transport vehicle injured in collision with unspecified motor vehicles in traffic accident, subsequent encounter*/
,'V6950XS'  /*Passenger in heavy transport vehicle injured in collision with unspecified motor vehicles in traffic accident, sequela*/
,'V6959XA'  /*Passenger in heavy transport vehicle injured in collision with other motor vehicles in traffic accident, initial encounter*/
,'V6959XD'  /*Passenger in heavy transport vehicle injured in collision with other motor vehicles in traffic accident, subsequent encounter*/
,'V6959XS'  /*Passenger in heavy transport vehicle injured in collision with other motor vehicles in traffic accident, sequela*/
,'V6960XA'  /*Unspecified occupant of heavy transport vehicle injured in collision with unspecified motor vehicles in traffic accident, initial encounter*/
,'V6960XD'  /*Unspecified occupant of heavy transport vehicle injured in collision with unspecified motor vehicles in traffic accident, subsequent encounter*/
,'V6960XS'  /*Unspecified occupant of heavy transport vehicle injured in collision with unspecified motor vehicles in traffic accident, sequela*/
,'V6969XA'  /*Unspecified occupant of heavy transport vehicle injured in collision with other motor vehicles in traffic accident, initial encounter*/
,'V6969XD'  /*Unspecified occupant of heavy transport vehicle injured in collision with other motor vehicles in traffic accident, subsequent encounter*/
,'V6969XS'  /*Unspecified occupant of heavy transport vehicle injured in collision with other motor vehicles in traffic accident, sequela*/
,'V6981XA'  /*Occupant (driver) (passenger) of heavy transport vehicle injured in transport accidents with military vehicle, initial encounter*/
,'V6981XD'  /*Occupant (driver) (passenger) of heavy transport vehicle injured in transport accidents with military vehicle, subsequent encounter*/
,'V6981XS'  /*Occupant (driver) (passenger) of heavy transport vehicle injured in transport accidents with military vehicle, sequela*/
,'V6988XA'  /*Occupant (driver) (passenger) of heavy transport vehicle injured in other specified transport accidents, initial encounter*/
,'V6988XD'  /*Occupant (driver) (passenger) of heavy transport vehicle injured in other specified transport accidents, subsequent encounter*/
,'V6988XS'  /*Occupant (driver) (passenger) of heavy transport vehicle injured in other specified transport accidents, sequela*/
,'V699XXA'  /*Occupant (driver) (passenger) of heavy transport vehicle injured in unspecified traffic accident, initial encounter*/
,'V699XXD'  /*Occupant (driver) (passenger) of heavy transport vehicle injured in unspecified traffic accident, subsequent encounter*/
,'V699XXS'  /*Occupant (driver) (passenger) of heavy transport vehicle injured in unspecified traffic accident, sequela*/
,'V700XXA'  /*Driver of bus injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V700XXD'  /*Driver of bus injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V700XXS'  /*Driver of bus injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V701XXA'  /*Passenger on bus injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V701XXD'  /*Passenger on bus injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V701XXS'  /*Passenger on bus injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V702XXA'  /*Person on outside of bus injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V702XXD'  /*Person on outside of bus injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V702XXS'  /*Person on outside of bus injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V703XXA'  /*Unspecified occupant of bus injured in collision with pedestrian or animal in nontraffic accident, initial encounter*/
,'V703XXD'  /*Unspecified occupant of bus injured in collision with pedestrian or animal in nontraffic accident, subsequent encounter*/
,'V703XXS'  /*Unspecified occupant of bus injured in collision with pedestrian or animal in nontraffic accident, sequela*/
,'V704XXA'  /*Person boarding or alighting from bus injured in collision with pedestrian or animal, initial encounter*/
,'V704XXD'  /*Person boarding or alighting from bus injured in collision with pedestrian or animal, subsequent encounter*/
,'V704XXS'  /*Person boarding or alighting from bus injured in collision with pedestrian or animal, sequela*/
,'V705XXA'  /*Driver of bus injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V705XXD'  /*Driver of bus injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V705XXS'  /*Driver of bus injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V706XXA'  /*Passenger on bus injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V706XXD'  /*Passenger on bus injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V706XXS'  /*Passenger on bus injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V707XXA'  /*Person on outside of bus injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V707XXD'  /*Person on outside of bus injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V707XXS'  /*Person on outside of bus injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V709XXA'  /*Unspecified occupant of bus injured in collision with pedestrian or animal in traffic accident, initial encounter*/
,'V709XXD'  /*Unspecified occupant of bus injured in collision with pedestrian or animal in traffic accident, subsequent encounter*/
,'V709XXS'  /*Unspecified occupant of bus injured in collision with pedestrian or animal in traffic accident, sequela*/
,'V710XXA'  /*Driver of bus injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V710XXD'  /*Driver of bus injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V710XXS'  /*Driver of bus injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V711XXA'  /*Passenger on bus injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V711XXD'  /*Passenger on bus injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V711XXS'  /*Passenger on bus injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V712XXA'  /*Person on outside of bus injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V712XXD'  /*Person on outside of bus injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V712XXS'  /*Person on outside of bus injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V713XXA'  /*Unspecified occupant of bus injured in collision with pedal cycle in nontraffic accident, initial encounter*/
,'V713XXD'  /*Unspecified occupant of bus injured in collision with pedal cycle in nontraffic accident, subsequent encounter*/
,'V713XXS'  /*Unspecified occupant of bus injured in collision with pedal cycle in nontraffic accident, sequela*/
,'V714XXA'  /*Person boarding or alighting from bus injured in collision with pedal cycle, initial encounter*/
,'V714XXD'  /*Person boarding or alighting from bus injured in collision with pedal cycle, subsequent encounter*/
,'V714XXS'  /*Person boarding or alighting from bus injured in collision with pedal cycle, sequela*/
,'V715XXA'  /*Driver of bus injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V715XXD'  /*Driver of bus injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V715XXS'  /*Driver of bus injured in collision with pedal cycle in traffic accident, sequela*/
,'V716XXA'  /*Passenger on bus injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V716XXD'  /*Passenger on bus injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V716XXS'  /*Passenger on bus injured in collision with pedal cycle in traffic accident, sequela*/
,'V717XXA'  /*Person on outside of bus injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V717XXD'  /*Person on outside of bus injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V717XXS'  /*Person on outside of bus injured in collision with pedal cycle in traffic accident, sequela*/
,'V719XXA'  /*Unspecified occupant of bus injured in collision with pedal cycle in traffic accident, initial encounter*/
,'V719XXD'  /*Unspecified occupant of bus injured in collision with pedal cycle in traffic accident, subsequent encounter*/
,'V719XXS'  /*Unspecified occupant of bus injured in collision with pedal cycle in traffic accident, sequela*/
,'V720XXA'  /*Driver of bus injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V720XXD'  /*Driver of bus injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V720XXS'  /*Driver of bus injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V721XXA'  /*Passenger on bus injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V721XXD'  /*Passenger on bus injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V721XXS'  /*Passenger on bus injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V722XXA'  /*Person on outside of bus injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V722XXD'  /*Person on outside of bus injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V722XXS'  /*Person on outside of bus injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V723XXA'  /*Unspecified occupant of bus injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, initial encounter*/
,'V723XXD'  /*Unspecified occupant of bus injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, subsequent encounter*/
,'V723XXS'  /*Unspecified occupant of bus injured in collision with two- or three-wheeled motor vehicle in nontraffic accident, sequela*/
,'V724XXA'  /*Person boarding or alighting from bus injured in collision with two- or three-wheeled motor vehicle, initial encounter*/
,'V724XXD'  /*Person boarding or alighting from bus injured in collision with two- or three-wheeled motor vehicle, subsequent encounter*/
,'V724XXS'  /*Person boarding or alighting from bus injured in collision with two- or three-wheeled motor vehicle, sequela*/
,'V725XXA'  /*Driver of bus injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V725XXD'  /*Driver of bus injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V725XXS'  /*Driver of bus injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V726XXA'  /*Passenger on bus injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V726XXD'  /*Passenger on bus injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V726XXS'  /*Passenger on bus injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V727XXA'  /*Person on outside of bus injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V727XXD'  /*Person on outside of bus injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V727XXS'  /*Person on outside of bus injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V729XXA'  /*Unspecified occupant of bus injured in collision with two- or three-wheeled motor vehicle in traffic accident, initial encounter*/
,'V729XXD'  /*Unspecified occupant of bus injured in collision with two- or three-wheeled motor vehicle in traffic accident, subsequent encounter*/
,'V729XXS'  /*Unspecified occupant of bus injured in collision with two- or three-wheeled motor vehicle in traffic accident, sequela*/
,'V730XXA'  /*Driver of bus injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V730XXD'  /*Driver of bus injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V730XXS'  /*Driver of bus injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V731XXA'  /*Passenger on bus injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V731XXD'  /*Passenger on bus injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V731XXS'  /*Passenger on bus injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V732XXA'  /*Person on outside of bus injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V732XXD'  /*Person on outside of bus injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V732XXS'  /*Person on outside of bus injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V733XXA'  /*Unspecified occupant of bus injured in collision with car, pick-up truck or van in nontraffic accident, initial encounter*/
,'V733XXD'  /*Unspecified occupant of bus injured in collision with car, pick-up truck or van in nontraffic accident, subsequent encounter*/
,'V733XXS'  /*Unspecified occupant of bus injured in collision with car, pick-up truck or van in nontraffic accident, sequela*/
,'V734XXA'  /*Person boarding or alighting from bus injured in collision with car, pick-up truck or van, initial encounter*/
,'V734XXD'  /*Person boarding or alighting from bus injured in collision with car, pick-up truck or van, subsequent encounter*/
,'V734XXS'  /*Person boarding or alighting from bus injured in collision with car, pick-up truck or van, sequela*/
,'V735XXA'  /*Driver of bus injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V735XXD'  /*Driver of bus injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V735XXS'  /*Driver of bus injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V736XXA'  /*Passenger on bus injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V736XXD'  /*Passenger on bus injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V736XXS'  /*Passenger on bus injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V737XXA'  /*Person on outside of bus injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V737XXD'  /*Person on outside of bus injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V737XXS'  /*Person on outside of bus injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V739XXA'  /*Unspecified occupant of bus injured in collision with car, pick-up truck or van in traffic accident, initial encounter*/
,'V739XXD'  /*Unspecified occupant of bus injured in collision with car, pick-up truck or van in traffic accident, subsequent encounter*/
,'V739XXS'  /*Unspecified occupant of bus injured in collision with car, pick-up truck or van in traffic accident, sequela*/
,'V740XXA'  /*Driver of bus injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V740XXD'  /*Driver of bus injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V740XXS'  /*Driver of bus injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V741XXA'  /*Passenger on bus injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V741XXD'  /*Passenger on bus injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V741XXS'  /*Passenger on bus injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V742XXA'  /*Person on outside of bus injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V742XXD'  /*Person on outside of bus injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V742XXS'  /*Person on outside of bus injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V743XXA'  /*Unspecified occupant of bus injured in collision with heavy transport vehicle or bus in nontraffic accident, initial encounter*/
,'V743XXD'  /*Unspecified occupant of bus injured in collision with heavy transport vehicle or bus in nontraffic accident, subsequent encounter*/
,'V743XXS'  /*Unspecified occupant of bus injured in collision with heavy transport vehicle or bus in nontraffic accident, sequela*/
,'V744XXA'  /*Person boarding or alighting from bus injured in collision with heavy transport vehicle or bus, initial encounter*/
,'V744XXD'  /*Person boarding or alighting from bus injured in collision with heavy transport vehicle or bus, subsequent encounter*/
,'V744XXS'  /*Person boarding or alighting from bus injured in collision with heavy transport vehicle or bus, sequela*/
,'V745XXA'  /*Driver of bus injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V745XXD'  /*Driver of bus injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V745XXS'  /*Driver of bus injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V746XXA'  /*Passenger on bus injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V746XXD'  /*Passenger on bus injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V746XXS'  /*Passenger on bus injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V747XXA'  /*Person on outside of bus injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V747XXD'  /*Person on outside of bus injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V747XXS'  /*Person on outside of bus injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V749XXA'  /*Unspecified occupant of bus injured in collision with heavy transport vehicle or bus in traffic accident, initial encounter*/
,'V749XXD'  /*Unspecified occupant of bus injured in collision with heavy transport vehicle or bus in traffic accident, subsequent encounter*/
,'V749XXS'  /*Unspecified occupant of bus injured in collision with heavy transport vehicle or bus in traffic accident, sequela*/
,'V750XXA'  /*Driver of bus injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V750XXD'  /*Driver of bus injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V750XXS'  /*Driver of bus injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V751XXA'  /*Passenger on bus injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V751XXD'  /*Passenger on bus injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V751XXS'  /*Passenger on bus injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V752XXA'  /*Person on outside of bus injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V752XXD'  /*Person on outside of bus injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V752XXS'  /*Person on outside of bus injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V753XXA'  /*Unspecified occupant of bus injured in collision with railway train or railway vehicle in nontraffic accident, initial encounter*/
,'V753XXD'  /*Unspecified occupant of bus injured in collision with railway train or railway vehicle in nontraffic accident, subsequent encounter*/
,'V753XXS'  /*Unspecified occupant of bus injured in collision with railway train or railway vehicle in nontraffic accident, sequela*/
,'V754XXA'  /*Person boarding or alighting from bus injured in collision with railway train or railway vehicle, initial encounter*/
,'V754XXD'  /*Person boarding or alighting from bus injured in collision with railway train or railway vehicle, subsequent encounter*/
,'V754XXS'  /*Person boarding or alighting from bus injured in collision with railway train or railway vehicle, sequela*/
,'V755XXA'  /*Driver of bus injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V755XXD'  /*Driver of bus injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V755XXS'  /*Driver of bus injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V756XXA'  /*Passenger on bus injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V756XXD'  /*Passenger on bus injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V756XXS'  /*Passenger on bus injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V757XXA'  /*Person on outside of bus injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V757XXD'  /*Person on outside of bus injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V757XXS'  /*Person on outside of bus injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V759XXA'  /*Unspecified occupant of bus injured in collision with railway train or railway vehicle in traffic accident, initial encounter*/
,'V759XXD'  /*Unspecified occupant of bus injured in collision with railway train or railway vehicle in traffic accident, subsequent encounter*/
,'V759XXS'  /*Unspecified occupant of bus injured in collision with railway train or railway vehicle in traffic accident, sequela*/
,'V760XXA'  /*Driver of bus injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V760XXD'  /*Driver of bus injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V760XXS'  /*Driver of bus injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V761XXA'  /*Passenger on bus injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V761XXD'  /*Passenger on bus injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V761XXS'  /*Passenger on bus injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V762XXA'  /*Person on outside of bus injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V762XXD'  /*Person on outside of bus injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V762XXS'  /*Person on outside of bus injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V763XXA'  /*Unspecified occupant of bus injured in collision with other nonmotor vehicle in nontraffic accident, initial encounter*/
,'V763XXD'  /*Unspecified occupant of bus injured in collision with other nonmotor vehicle in nontraffic accident, subsequent encounter*/
,'V763XXS'  /*Unspecified occupant of bus injured in collision with other nonmotor vehicle in nontraffic accident, sequela*/
,'V764XXA'  /*Person boarding or alighting from bus injured in collision with other nonmotor vehicle, initial encounter*/
,'V764XXD'  /*Person boarding or alighting from bus injured in collision with other nonmotor vehicle, subsequent encounter*/
,'V764XXS'  /*Person boarding or alighting from bus injured in collision with other nonmotor vehicle, sequela*/
,'V765XXA'  /*Driver of bus injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V765XXD'  /*Driver of bus injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V765XXS'  /*Driver of bus injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V766XXA'  /*Passenger on bus injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V766XXD'  /*Passenger on bus injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V766XXS'  /*Passenger on bus injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V767XXA'  /*Person on outside of bus injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V767XXD'  /*Person on outside of bus injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V767XXS'  /*Person on outside of bus injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V769XXA'  /*Unspecified occupant of bus injured in collision with other nonmotor vehicle in traffic accident, initial encounter*/
,'V769XXD'  /*Unspecified occupant of bus injured in collision with other nonmotor vehicle in traffic accident, subsequent encounter*/
,'V769XXS'  /*Unspecified occupant of bus injured in collision with other nonmotor vehicle in traffic accident, sequela*/
,'V770XXA'  /*Driver of bus injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V770XXD'  /*Driver of bus injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V770XXS'  /*Driver of bus injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V771XXA'  /*Passenger on bus injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V771XXD'  /*Passenger on bus injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V771XXS'  /*Passenger on bus injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V772XXA'  /*Person on outside of bus injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V772XXD'  /*Person on outside of bus injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V772XXS'  /*Person on outside of bus injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V773XXA'  /*Unspecified occupant of bus injured in collision with fixed or stationary object in nontraffic accident, initial encounter*/
,'V773XXD'  /*Unspecified occupant of bus injured in collision with fixed or stationary object in nontraffic accident, subsequent encounter*/
,'V773XXS'  /*Unspecified occupant of bus injured in collision with fixed or stationary object in nontraffic accident, sequela*/
,'V774XXA'  /*Person boarding or alighting from bus injured in collision with fixed or stationary object, initial encounter*/
,'V774XXD'  /*Person boarding or alighting from bus injured in collision with fixed or stationary object, subsequent encounter*/
,'V774XXS'  /*Person boarding or alighting from bus injured in collision with fixed or stationary object, sequela*/
,'V775XXA'  /*Driver of bus injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V775XXD'  /*Driver of bus injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V775XXS'  /*Driver of bus injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V776XXA'  /*Passenger on bus injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V776XXD'  /*Passenger on bus injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V776XXS'  /*Passenger on bus injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V777XXA'  /*Person on outside of bus injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V777XXD'  /*Person on outside of bus injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V777XXS'  /*Person on outside of bus injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V779XXA'  /*Unspecified occupant of bus injured in collision with fixed or stationary object in traffic accident, initial encounter*/
,'V779XXD'  /*Unspecified occupant of bus injured in collision with fixed or stationary object in traffic accident, subsequent encounter*/
,'V779XXS'  /*Unspecified occupant of bus injured in collision with fixed or stationary object in traffic accident, sequela*/
,'V780XXA'  /*Driver of bus injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V780XXD'  /*Driver of bus injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V780XXS'  /*Driver of bus injured in noncollision transport accident in nontraffic accident, sequela*/
,'V781XXA'  /*Passenger on bus injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V781XXD'  /*Passenger on bus injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V781XXS'  /*Passenger on bus injured in noncollision transport accident in nontraffic accident, sequela*/
,'V782XXA'  /*Person on outside of bus injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V782XXD'  /*Person on outside of bus injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V782XXS'  /*Person on outside of bus injured in noncollision transport accident in nontraffic accident, sequela*/
,'V783XXA'  /*Unspecified occupant of bus injured in noncollision transport accident in nontraffic accident, initial encounter*/
,'V783XXD'  /*Unspecified occupant of bus injured in noncollision transport accident in nontraffic accident, subsequent encounter*/
,'V783XXS'  /*Unspecified occupant of bus injured in noncollision transport accident in nontraffic accident, sequela*/
,'V784XXA'  /*Person boarding or alighting from bus injured in noncollision transport accident, initial encounter*/
,'V784XXD'  /*Person boarding or alighting from bus injured in noncollision transport accident, subsequent encounter*/
,'V784XXS'  /*Person boarding or alighting from bus injured in noncollision transport accident, sequela*/
,'V785XXA'  /*Driver of bus injured in noncollision transport accident in traffic accident, initial encounter*/
,'V785XXD'  /*Driver of bus injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V785XXS'  /*Driver of bus injured in noncollision transport accident in traffic accident, sequela*/
,'V786XXA'  /*Passenger on bus injured in noncollision transport accident in traffic accident, initial encounter*/
,'V786XXD'  /*Passenger on bus injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V786XXS'  /*Passenger on bus injured in noncollision transport accident in traffic accident, sequela*/
,'V787XXA'  /*Person on outside of bus injured in noncollision transport accident in traffic accident, initial encounter*/
,'V787XXD'  /*Person on outside of bus injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V787XXS'  /*Person on outside of bus injured in noncollision transport accident in traffic accident, sequela*/
,'V789XXA'  /*Unspecified occupant of bus injured in noncollision transport accident in traffic accident, initial encounter*/
,'V789XXD'  /*Unspecified occupant of bus injured in noncollision transport accident in traffic accident, subsequent encounter*/
,'V789XXS'  /*Unspecified occupant of bus injured in noncollision transport accident in traffic accident, sequela*/
,'V7900XA'  /*Driver of bus injured in collision with unspecified motor vehicles in nontraffic accident, initial encounter*/
,'V7900XD'  /*Driver of bus injured in collision with unspecified motor vehicles in nontraffic accident, subsequent encounter*/
,'V7900XS'  /*Driver of bus injured in collision with unspecified motor vehicles in nontraffic accident, sequela*/
,'V7909XA'  /*Driver of bus injured in collision with other motor vehicles in nontraffic accident, initial encounter*/
,'V7909XD'  /*Driver of bus injured in collision with other motor vehicles in nontraffic accident, subsequent encounter*/
,'V7909XS'  /*Driver of bus injured in collision with other motor vehicles in nontraffic accident, sequela*/
,'V7910XA'  /*Passenger on bus injured in collision with unspecified motor vehicles in nontraffic accident, initial encounter*/
,'V7910XD'  /*Passenger on bus injured in collision with unspecified motor vehicles in nontraffic accident, subsequent encounter*/
,'V7910XS'  /*Passenger on bus injured in collision with unspecified motor vehicles in nontraffic accident, sequela*/
,'V7919XA'  /*Passenger on bus injured in collision with other motor vehicles in nontraffic accident, initial encounter*/
,'V7919XD'  /*Passenger on bus injured in collision with other motor vehicles in nontraffic accident, subsequent encounter*/
,'V7919XS'  /*Passenger on bus injured in collision with other motor vehicles in nontraffic accident, sequela*/
,'V7920XA'  /*Unspecified bus occupant injured in collision with unspecified motor vehicles in nontraffic accident, initial encounter*/
,'V7920XD'  /*Unspecified bus occupant injured in collision with unspecified motor vehicles in nontraffic accident, subsequent encounter*/
,'V7920XS'  /*Unspecified bus occupant injured in collision with unspecified motor vehicles in nontraffic accident, sequela*/
,'V7929XA'  /*Unspecified bus occupant injured in collision with other motor vehicles in nontraffic accident, initial encounter*/
,'V7929XD'  /*Unspecified bus occupant injured in collision with other motor vehicles in nontraffic accident, subsequent encounter*/
,'V7929XS'  /*Unspecified bus occupant injured in collision with other motor vehicles in nontraffic accident, sequela*/
,'V793XXA'  /*Bus occupant (driver) (passenger) injured in unspecified nontraffic accident, initial encounter*/
,'V793XXD'  /*Bus occupant (driver) (passenger) injured in unspecified nontraffic accident, subsequent encounter*/
,'V793XXS'  /*Bus occupant (driver) (passenger) injured in unspecified nontraffic accident, sequela*/
,'V7940XA'  /*Driver of bus injured in collision with unspecified motor vehicles in traffic accident, initial encounter*/
,'V7940XD'  /*Driver of bus injured in collision with unspecified motor vehicles in traffic accident, subsequent encounter*/
,'V7940XS'  /*Driver of bus injured in collision with unspecified motor vehicles in traffic accident, sequela*/
,'V7949XA'  /*Driver of bus injured in collision with other motor vehicles in traffic accident, initial encounter*/
,'V7949XD'  /*Driver of bus injured in collision with other motor vehicles in traffic accident, subsequent encounter*/
,'V7949XS'  /*Driver of bus injured in collision with other motor vehicles in traffic accident, sequela*/
,'V7950XA'  /*Passenger on bus injured in collision with unspecified motor vehicles in traffic accident, initial encounter*/
,'V7950XD'  /*Passenger on bus injured in collision with unspecified motor vehicles in traffic accident, subsequent encounter*/
,'V7950XS'  /*Passenger on bus injured in collision with unspecified motor vehicles in traffic accident, sequela*/
,'V7959XA'  /*Passenger on bus injured in collision with other motor vehicles in traffic accident, initial encounter*/
,'V7959XD'  /*Passenger on bus injured in collision with other motor vehicles in traffic accident, subsequent encounter*/
,'V7959XS'  /*Passenger on bus injured in collision with other motor vehicles in traffic accident, sequela*/
,'V7960XA'  /*Unspecified bus occupant injured in collision with unspecified motor vehicles in traffic accident, initial encounter*/
,'V7960XD'  /*Unspecified bus occupant injured in collision with unspecified motor vehicles in traffic accident, subsequent encounter*/
,'V7960XS'  /*Unspecified bus occupant injured in collision with unspecified motor vehicles in traffic accident, sequela*/
,'V7969XA'  /*Unspecified bus occupant injured in collision with other motor vehicles in traffic accident, initial encounter*/
,'V7969XD'  /*Unspecified bus occupant injured in collision with other motor vehicles in traffic accident, subsequent encounter*/
,'V7969XS'  /*Unspecified bus occupant injured in collision with other motor vehicles in traffic accident, sequela*/
,'V7981XA'  /*Bus occupant (driver) (passenger) injured in transport accidents with military vehicle, initial encounter*/
,'V7981XD'  /*Bus occupant (driver) (passenger) injured in transport accidents with military vehicle, subsequent encounter*/
,'V7981XS'  /*Bus occupant (driver) (passenger) injured in transport accidents with military vehicle, sequela*/
,'V7988XA'  /*Bus occupant (driver) (passenger) injured in other specified transport accidents, initial encounter*/
,'V7988XD'  /*Bus occupant (driver) (passenger) injured in other specified transport accidents, subsequent encounter*/
,'V7988XS'  /*Bus occupant (driver) (passenger) injured in other specified transport accidents, sequela*/
,'V799XXA'  /*Bus occupant (driver) (passenger) injured in unspecified traffic accident, initial encounter*/
,'V799XXD'  /*Bus occupant (driver) (passenger) injured in unspecified traffic accident, subsequent encounter*/
,'V799XXS'  /*Bus occupant (driver) (passenger) injured in unspecified traffic accident, sequela*/
,'V80010A'  /*Animal-rider injured by fall from or being thrown from horse in noncollision accident, initial encounter*/
,'V80010D'  /*Animal-rider injured by fall from or being thrown from horse in noncollision accident, subsequent encounter*/
,'V80010S'  /*Animal-rider injured by fall from or being thrown from horse in noncollision accident, sequela*/
,'V80018A'  /*Animal-rider injured by fall from or being thrown from other animal in noncollision accident, initial encounter*/
,'V80018D'  /*Animal-rider injured by fall from or being thrown from other animal in noncollision accident, subsequent encounter*/
,'V80018S'  /*Animal-rider injured by fall from or being thrown from other animal in noncollision accident, sequela*/
,'V8002XA'  /*Occupant of animal-drawn vehicle injured by fall from or being thrown from animal-drawn vehicle in noncollision accident, initial encounter*/
,'V8002XD'  /*Occupant of animal-drawn vehicle injured by fall from or being thrown from animal-drawn vehicle in noncollision accident, subsequent encounter*/
,'V8002XS'  /*Occupant of animal-drawn vehicle injured by fall from or being thrown from animal-drawn vehicle in noncollision accident, sequela*/
,'V8011XA'  /*Animal-rider injured in collision with pedestrian or animal, initial encounter*/
,'V8011XD'  /*Animal-rider injured in collision with pedestrian or animal, subsequent encounter*/
,'V8011XS'  /*Animal-rider injured in collision with pedestrian or animal, sequela*/
,'V8012XA'  /*Occupant of animal-drawn vehicle injured in collision with pedestrian or animal, initial encounter*/
,'V8012XD'  /*Occupant of animal-drawn vehicle injured in collision with pedestrian or animal, subsequent encounter*/
,'V8012XS'  /*Occupant of animal-drawn vehicle injured in collision with pedestrian or animal, sequela*/
,'V8021XA'  /*Animal-rider injured in collision with pedal cycle, initial encounter*/
,'V8021XD'  /*Animal-rider injured in collision with pedal cycle, subsequent encounter*/
,'V8021XS'  /*Animal-rider injured in collision with pedal cycle, sequela*/
,'V8022XA'  /*Occupant of animal-drawn vehicle injured in collision with pedal cycle, initial encounter*/
,'V8022XD'  /*Occupant of animal-drawn vehicle injured in collision with pedal cycle, subsequent encounter*/
,'V8022XS'  /*Occupant of animal-drawn vehicle injured in collision with pedal cycle, sequela*/
,'V8031XA'  /*Animal-rider injured in collision with two- or three-wheeled motor vehicle, initial encounter*/
,'V8031XD'  /*Animal-rider injured in collision with two- or three-wheeled motor vehicle, subsequent encounter*/
,'V8031XS'  /*Animal-rider injured in collision with two- or three-wheeled motor vehicle, sequela*/
,'V8032XA'  /*Occupant of animal-drawn vehicle injured in collision with two- or three-wheeled motor vehicle, initial encounter*/
,'V8032XD'  /*Occupant of animal-drawn vehicle injured in collision with two- or three-wheeled motor vehicle, subsequent encounter*/
,'V8032XS'  /*Occupant of animal-drawn vehicle injured in collision with two- or three-wheeled motor vehicle, sequela*/
,'V8041XA'  /*Animal-rider injured in collision with car, pick-up truck, van, heavy transport vehicle or bus, initial encounter*/
,'V8041XD'  /*Animal-rider injured in collision with car, pick-up truck, van, heavy transport vehicle or bus, subsequent encounter*/
,'V8041XS'  /*Animal-rider injured in collision with car, pick-up truck, van, heavy transport vehicle or bus, sequela*/
,'V8042XA'  /*Occupant of animal-drawn vehicle injured in collision with car, pick-up truck, van, heavy transport vehicle or bus, initial encounter*/
,'V8042XD'  /*Occupant of animal-drawn vehicle injured in collision with car, pick-up truck, van, heavy transport vehicle or bus, subsequent encounter*/
,'V8042XS'  /*Occupant of animal-drawn vehicle injured in collision with car, pick-up truck, van, heavy transport vehicle or bus, sequela*/
,'V8051XA'  /*Animal-rider injured in collision with other specified motor vehicle, initial encounter*/
,'V8051XD'  /*Animal-rider injured in collision with other specified motor vehicle, subsequent encounter*/
,'V8051XS'  /*Animal-rider injured in collision with other specified motor vehicle, sequela*/
,'V8052XA'  /*Occupant of animal-drawn vehicle injured in collision with other specified motor vehicle, initial encounter*/
,'V8052XD'  /*Occupant of animal-drawn vehicle injured in collision with other specified motor vehicle, subsequent encounter*/
,'V8052XS'  /*Occupant of animal-drawn vehicle injured in collision with other specified motor vehicle, sequela*/
,'V8061XA'  /*Animal-rider injured in collision with railway train or railway vehicle, initial encounter*/
,'V8061XD'  /*Animal-rider injured in collision with railway train or railway vehicle, subsequent encounter*/
,'V8061XS'  /*Animal-rider injured in collision with railway train or railway vehicle, sequela*/
,'V8062XA'  /*Occupant of animal-drawn vehicle injured in collision with railway train or railway vehicle, initial encounter*/
,'V8062XD'  /*Occupant of animal-drawn vehicle injured in collision with railway train or railway vehicle, subsequent encounter*/
,'V8062XS'  /*Occupant of animal-drawn vehicle injured in collision with railway train or railway vehicle, sequela*/
,'V80710A'  /*Animal-rider injured in collision with other animal being ridden, initial encounter*/
,'V80710D'  /*Animal-rider injured in collision with other animal being ridden, subsequent encounter*/
,'V80710S'  /*Animal-rider injured in collision with other animal being ridden, sequela*/
,'V80711A'  /*Occupant of animal-drawn vehicle injured in collision with animal being ridden, initial encounter*/
,'V80711D'  /*Occupant of animal-drawn vehicle injured in collision with animal being ridden, subsequent encounter*/
,'V80711S'  /*Occupant of animal-drawn vehicle injured in collision with animal being ridden, sequela*/
,'V80720A'  /*Animal-rider injured in collision with animal-drawn vehicle, initial encounter*/
,'V80720D'  /*Animal-rider injured in collision with animal-drawn vehicle, subsequent encounter*/
,'V80720S'  /*Animal-rider injured in collision with animal-drawn vehicle, sequela*/
,'V80721A'  /*Occupant of animal-drawn vehicle injured in collision with other animal-drawn vehicle, initial encounter*/
,'V80721D'  /*Occupant of animal-drawn vehicle injured in collision with other animal-drawn vehicle, subsequent encounter*/
,'V80721S'  /*Occupant of animal-drawn vehicle injured in collision with other animal-drawn vehicle, sequela*/
,'V80730A'  /*Animal-rider injured in collision with streetcar, initial encounter*/
,'V80730D'  /*Animal-rider injured in collision with streetcar, subsequent encounter*/
,'V80730S'  /*Animal-rider injured in collision with streetcar, sequela*/
,'V80731A'  /*Occupant of animal-drawn vehicle injured in collision with streetcar, initial encounter*/
,'V80731D'  /*Occupant of animal-drawn vehicle injured in collision with streetcar, subsequent encounter*/
,'V80731S'  /*Occupant of animal-drawn vehicle injured in collision with streetcar, sequela*/
,'V80790A'  /*Animal-rider injured in collision with other nonmotor vehicles, initial encounter*/
,'V80790D'  /*Animal-rider injured in collision with other nonmotor vehicles, subsequent encounter*/
,'V80790S'  /*Animal-rider injured in collision with other nonmotor vehicles, sequela*/
,'V80791A'  /*Occupant of animal-drawn vehicle injured in collision with other nonmotor vehicles, initial encounter*/
,'V80791D'  /*Occupant of animal-drawn vehicle injured in collision with other nonmotor vehicles, subsequent encounter*/
,'V80791S'  /*Occupant of animal-drawn vehicle injured in collision with other nonmotor vehicles, sequela*/
,'V8081XA'  /*Animal-rider injured in collision with fixed or stationary object, initial encounter*/
,'V8081XD'  /*Animal-rider injured in collision with fixed or stationary object, subsequent encounter*/
,'V8081XS'  /*Animal-rider injured in collision with fixed or stationary object, sequela*/
,'V8082XA'  /*Occupant of animal-drawn vehicle injured in collision with fixed or stationary object, initial encounter*/
,'V8082XD'  /*Occupant of animal-drawn vehicle injured in collision with fixed or stationary object, subsequent encounter*/
,'V8082XS'  /*Occupant of animal-drawn vehicle injured in collision with fixed or stationary object, sequela*/
,'V80910A'  /*Animal-rider injured in transport accident with military vehicle, initial encounter*/
,'V80910D'  /*Animal-rider injured in transport accident with military vehicle, subsequent encounter*/
,'V80910S'  /*Animal-rider injured in transport accident with military vehicle, sequela*/
,'V80918A'  /*Animal-rider injured in other transport accident, initial encounter*/
,'V80918D'  /*Animal-rider injured in other transport accident, subsequent encounter*/
,'V80918S'  /*Animal-rider injured in other transport accident, sequela*/
,'V80919A'  /*Animal-rider injured in unspecified transport accident, initial encounter*/
,'V80919D'  /*Animal-rider injured in unspecified transport accident, subsequent encounter*/
,'V80919S'  /*Animal-rider injured in unspecified transport accident, sequela*/
,'V80920A'  /*Occupant of animal-drawn vehicle injured in transport accident with military vehicle, initial encounter*/
,'V80920D'  /*Occupant of animal-drawn vehicle injured in transport accident with military vehicle, subsequent encounter*/
,'V80920S'  /*Occupant of animal-drawn vehicle injured in transport accident with military vehicle, sequela*/
,'V80928A'  /*Occupant of animal-drawn vehicle injured in other transport accident, initial encounter*/
,'V80928D'  /*Occupant of animal-drawn vehicle injured in other transport accident, subsequent encounter*/
,'V80928S'  /*Occupant of animal-drawn vehicle injured in other transport accident, sequela*/
,'V80929A'  /*Occupant of animal-drawn vehicle injured in unspecified transport accident, initial encounter*/
,'V80929D'  /*Occupant of animal-drawn vehicle injured in unspecified transport accident, subsequent encounter*/
,'V80929S'  /*Occupant of animal-drawn vehicle injured in unspecified transport accident, sequela*/
,'V810XXA'  /*Occupant of railway train or railway vehicle injured in collision with motor vehicle in nontraffic accident, initial encounter*/
,'V810XXD'  /*Occupant of railway train or railway vehicle injured in collision with motor vehicle in nontraffic accident, subsequent encounter*/
,'V810XXS'  /*Occupant of railway train or railway vehicle injured in collision with motor vehicle in nontraffic accident, sequela*/
,'V811XXA'  /*Occupant of railway train or railway vehicle injured in collision with motor vehicle in traffic accident, initial encounter*/
,'V811XXD'  /*Occupant of railway train or railway vehicle injured in collision with motor vehicle in traffic accident, subsequent encounter*/
,'V811XXS'  /*Occupant of railway train or railway vehicle injured in collision with motor vehicle in traffic accident, sequela*/
,'V812XXA'  /*Occupant of railway train or railway vehicle injured in collision with or hit by rolling stock, initial encounter*/
,'V812XXD'  /*Occupant of railway train or railway vehicle injured in collision with or hit by rolling stock, subsequent encounter*/
,'V812XXS'  /*Occupant of railway train or railway vehicle injured in collision with or hit by rolling stock, sequela*/
,'V813XXA'  /*Occupant of railway train or railway vehicle injured in collision with other object, initial encounter*/
,'V813XXD'  /*Occupant of railway train or railway vehicle injured in collision with other object, subsequent encounter*/
,'V813XXS'  /*Occupant of railway train or railway vehicle injured in collision with other object, sequela*/
,'V814XXA'  /*Person injured while boarding or alighting from railway train or railway vehicle, initial encounter*/
,'V814XXD'  /*Person injured while boarding or alighting from railway train or railway vehicle, subsequent encounter*/
,'V814XXS'  /*Person injured while boarding or alighting from railway train or railway vehicle, sequela*/
,'V815XXA'  /*Occupant of railway train or railway vehicle injured by fall in railway train or railway vehicle, initial encounter*/
,'V815XXD'  /*Occupant of railway train or railway vehicle injured by fall in railway train or railway vehicle, subsequent encounter*/
,'V815XXS'  /*Occupant of railway train or railway vehicle injured by fall in railway train or railway vehicle, sequela*/
,'V816XXA'  /*Occupant of railway train or railway vehicle injured by fall from railway train or railway vehicle, initial encounter*/
,'V816XXD'  /*Occupant of railway train or railway vehicle injured by fall from railway train or railway vehicle, subsequent encounter*/
,'V816XXS'  /*Occupant of railway train or railway vehicle injured by fall from railway train or railway vehicle, sequela*/
,'V817XXA'  /*Occupant of railway train or railway vehicle injured in derailment without antecedent collision, initial encounter*/
,'V817XXD'  /*Occupant of railway train or railway vehicle injured in derailment without antecedent collision, subsequent encounter*/
,'V817XXS'  /*Occupant of railway train or railway vehicle injured in derailment without antecedent collision, sequela*/
,'V8181XA'  /*Occupant of railway train or railway vehicle injured due to explosion or fire on train, initial encounter*/
,'V8181XD'  /*Occupant of railway train or railway vehicle injured due to explosion or fire on train, subsequent encounter*/
,'V8181XS'  /*Occupant of railway train or railway vehicle injured due to explosion or fire on train, sequela*/
,'V8182XA'  /*Occupant of railway train or railway vehicle injured due to object falling onto train, initial encounter*/
,'V8182XD'  /*Occupant of railway train or railway vehicle injured due to object falling onto train, subsequent encounter*/
,'V8182XS'  /*Occupant of railway train or railway vehicle injured due to object falling onto train, sequela*/
,'V8183XA'  /*Occupant of railway train or railway vehicle injured due to collision with military vehicle, initial encounter*/
,'V8183XD'  /*Occupant of railway train or railway vehicle injured due to collision with military vehicle, subsequent encounter*/
,'V8183XS'  /*Occupant of railway train or railway vehicle injured due to collision with military vehicle, sequela*/
,'V8189XA'  /*Occupant of railway train or railway vehicle injured due to other specified railway accident, initial encounter*/
,'V8189XD'  /*Occupant of railway train or railway vehicle injured due to other specified railway accident, subsequent encounter*/
,'V8189XS'  /*Occupant of railway train or railway vehicle injured due to other specified railway accident, sequela*/
,'V819XXA'  /*Occupant of railway train or railway vehicle injured in unspecified railway accident, initial encounter*/
,'V819XXD'  /*Occupant of railway train or railway vehicle injured in unspecified railway accident, subsequent encounter*/
,'V819XXS'  /*Occupant of railway train or railway vehicle injured in unspecified railway accident, sequela*/
,'V820XXA'  /*Occupant of streetcar injured in collision with motor vehicle in nontraffic accident, initial encounter*/
,'V820XXD'  /*Occupant of streetcar injured in collision with motor vehicle in nontraffic accident, subsequent encounter*/
,'V820XXS'  /*Occupant of streetcar injured in collision with motor vehicle in nontraffic accident, sequela*/
,'V821XXA'  /*Occupant of streetcar injured in collision with motor vehicle in traffic accident, initial encounter*/
,'V821XXD'  /*Occupant of streetcar injured in collision with motor vehicle in traffic accident, subsequent encounter*/
,'V821XXS'  /*Occupant of streetcar injured in collision with motor vehicle in traffic accident, sequela*/
,'V822XXA'  /*Occupant of streetcar injured in collision with or hit by rolling stock, initial encounter*/
,'V822XXD'  /*Occupant of streetcar injured in collision with or hit by rolling stock, subsequent encounter*/
,'V822XXS'  /*Occupant of streetcar injured in collision with or hit by rolling stock, sequela*/
,'V823XXA'  /*Occupant of streetcar injured in collision with other object, initial encounter*/
,'V823XXD'  /*Occupant of streetcar injured in collision with other object, subsequent encounter*/
,'V823XXS'  /*Occupant of streetcar injured in collision with other object, sequela*/
,'V824XXA'  /*Person injured while boarding or alighting from streetcar, initial encounter*/
,'V824XXD'  /*Person injured while boarding or alighting from streetcar, subsequent encounter*/
,'V824XXS'  /*Person injured while boarding or alighting from streetcar, sequela*/
,'V825XXA'  /*Occupant of streetcar injured by fall in streetcar, initial encounter*/
,'V825XXD'  /*Occupant of streetcar injured by fall in streetcar, subsequent encounter*/
,'V825XXS'  /*Occupant of streetcar injured by fall in streetcar, sequela*/
,'V826XXA'  /*Occupant of streetcar injured by fall from streetcar, initial encounter*/
,'V826XXD'  /*Occupant of streetcar injured by fall from streetcar, subsequent encounter*/
,'V826XXS'  /*Occupant of streetcar injured by fall from streetcar, sequela*/
,'V827XXA'  /*Occupant of streetcar injured in derailment without antecedent collision, initial encounter*/
,'V827XXD'  /*Occupant of streetcar injured in derailment without antecedent collision, subsequent encounter*/
,'V827XXS'  /*Occupant of streetcar injured in derailment without antecedent collision, sequela*/
,'V828XXA'  /*Occupant of streetcar injured in other specified transport accidents, initial encounter*/
,'V828XXD'  /*Occupant of streetcar injured in other specified transport accidents, subsequent encounter*/
,'V828XXS'  /*Occupant of streetcar injured in other specified transport accidents, sequela*/
,'V829XXA'  /*Occupant of streetcar injured in unspecified traffic accident, initial encounter*/
,'V829XXD'  /*Occupant of streetcar injured in unspecified traffic accident, subsequent encounter*/
,'V829XXS'  /*Occupant of streetcar injured in unspecified traffic accident, sequela*/
,'V830XXA'  /*Driver of special industrial vehicle injured in traffic accident, initial encounter*/
,'V830XXD'  /*Driver of special industrial vehicle injured in traffic accident, subsequent encounter*/
,'V830XXS'  /*Driver of special industrial vehicle injured in traffic accident, sequela*/
,'V831XXA'  /*Passenger of special industrial vehicle injured in traffic accident, initial encounter*/
,'V831XXD'  /*Passenger of special industrial vehicle injured in traffic accident, subsequent encounter*/
,'V831XXS'  /*Passenger of special industrial vehicle injured in traffic accident, sequela*/
,'V832XXA'  /*Person on outside of special industrial vehicle injured in traffic accident, initial encounter*/
,'V832XXD'  /*Person on outside of special industrial vehicle injured in traffic accident, subsequent encounter*/
,'V832XXS'  /*Person on outside of special industrial vehicle injured in traffic accident, sequela*/
,'V833XXA'  /*Unspecified occupant of special industrial vehicle injured in traffic accident, initial encounter*/
,'V833XXD'  /*Unspecified occupant of special industrial vehicle injured in traffic accident, subsequent encounter*/
,'V833XXS'  /*Unspecified occupant of special industrial vehicle injured in traffic accident, sequela*/
,'V834XXA'  /*Person injured while boarding or alighting from special industrial vehicle, initial encounter*/
,'V834XXD'  /*Person injured while boarding or alighting from special industrial vehicle, subsequent encounter*/
,'V834XXS'  /*Person injured while boarding or alighting from special industrial vehicle, sequela*/
,'V835XXA'  /*Driver of special industrial vehicle injured in nontraffic accident, initial encounter*/
,'V835XXD'  /*Driver of special industrial vehicle injured in nontraffic accident, subsequent encounter*/
,'V835XXS'  /*Driver of special industrial vehicle injured in nontraffic accident, sequela*/
,'V836XXA'  /*Passenger of special industrial vehicle injured in nontraffic accident, initial encounter*/
,'V836XXD'  /*Passenger of special industrial vehicle injured in nontraffic accident, subsequent encounter*/
,'V836XXS'  /*Passenger of special industrial vehicle injured in nontraffic accident, sequela*/
,'V837XXA'  /*Person on outside of special industrial vehicle injured in nontraffic accident, initial encounter*/
,'V837XXD'  /*Person on outside of special industrial vehicle injured in nontraffic accident, subsequent encounter*/
,'V837XXS'  /*Person on outside of special industrial vehicle injured in nontraffic accident, sequela*/
,'V839XXA'  /*Unspecified occupant of special industrial vehicle injured in nontraffic accident, initial encounter*/
,'V839XXD'  /*Unspecified occupant of special industrial vehicle injured in nontraffic accident, subsequent encounter*/
,'V839XXS'  /*Unspecified occupant of special industrial vehicle injured in nontraffic accident, sequela*/
,'V840XXA'  /*Driver of special agricultural vehicle injured in traffic accident, initial encounter*/
,'V840XXD'  /*Driver of special agricultural vehicle injured in traffic accident, subsequent encounter*/
,'V840XXS'  /*Driver of special agricultural vehicle injured in traffic accident, sequela*/
,'V841XXA'  /*Passenger of special agricultural vehicle injured in traffic accident, initial encounter*/
,'V841XXD'  /*Passenger of special agricultural vehicle injured in traffic accident, subsequent encounter*/
,'V841XXS'  /*Passenger of special agricultural vehicle injured in traffic accident, sequela*/
,'V842XXA'  /*Person on outside of special agricultural vehicle injured in traffic accident, initial encounter*/
,'V842XXD'  /*Person on outside of special agricultural vehicle injured in traffic accident, subsequent encounter*/
,'V842XXS'  /*Person on outside of special agricultural vehicle injured in traffic accident, sequela*/
,'V843XXA'  /*Unspecified occupant of special agricultural vehicle injured in traffic accident, initial encounter*/
,'V843XXD'  /*Unspecified occupant of special agricultural vehicle injured in traffic accident, subsequent encounter*/
,'V843XXS'  /*Unspecified occupant of special agricultural vehicle injured in traffic accident, sequela*/
,'V844XXA'  /*Person injured while boarding or alighting from special agricultural vehicle, initial encounter*/
,'V844XXD'  /*Person injured while boarding or alighting from special agricultural vehicle, subsequent encounter*/
,'V844XXS'  /*Person injured while boarding or alighting from special agricultural vehicle, sequela*/
,'V845XXA'  /*Driver of special agricultural vehicle injured in nontraffic accident, initial encounter*/
,'V845XXD'  /*Driver of special agricultural vehicle injured in nontraffic accident, subsequent encounter*/
,'V845XXS'  /*Driver of special agricultural vehicle injured in nontraffic accident, sequela*/
,'V846XXA'  /*Passenger of special agricultural vehicle injured in nontraffic accident, initial encounter*/
,'V846XXD'  /*Passenger of special agricultural vehicle injured in nontraffic accident, subsequent encounter*/
,'V846XXS'  /*Passenger of special agricultural vehicle injured in nontraffic accident, sequela*/
,'V847XXA'  /*Person on outside of special agricultural vehicle injured in nontraffic accident, initial encounter*/
,'V847XXD'  /*Person on outside of special agricultural vehicle injured in nontraffic accident, subsequent encounter*/
,'V847XXS'  /*Person on outside of special agricultural vehicle injured in nontraffic accident, sequela*/
,'V849XXA'  /*Unspecified occupant of special agricultural vehicle injured in nontraffic accident, initial encounter*/
,'V849XXD'  /*Unspecified occupant of special agricultural vehicle injured in nontraffic accident, subsequent encounter*/
,'V849XXS'  /*Unspecified occupant of special agricultural vehicle injured in nontraffic accident, sequela*/
,'V850XXA'  /*Driver of special construction vehicle injured in traffic accident, initial encounter*/
,'V850XXD'  /*Driver of special construction vehicle injured in traffic accident, subsequent encounter*/
,'V850XXS'  /*Driver of special construction vehicle injured in traffic accident, sequela*/
,'V851XXA'  /*Passenger of special construction vehicle injured in traffic accident, initial encounter*/
,'V851XXD'  /*Passenger of special construction vehicle injured in traffic accident, subsequent encounter*/
,'V851XXS'  /*Passenger of special construction vehicle injured in traffic accident, sequela*/
,'V852XXA'  /*Person on outside of special construction vehicle injured in traffic accident, initial encounter*/
,'V852XXD'  /*Person on outside of special construction vehicle injured in traffic accident, subsequent encounter*/
,'V852XXS'  /*Person on outside of special construction vehicle injured in traffic accident, sequela*/
,'V853XXA'  /*Unspecified occupant of special construction vehicle injured in traffic accident, initial encounter*/
,'V853XXD'  /*Unspecified occupant of special construction vehicle injured in traffic accident, subsequent encounter*/
,'V853XXS'  /*Unspecified occupant of special construction vehicle injured in traffic accident, sequela*/
,'V854XXA'  /*Person injured while boarding or alighting from special construction vehicle, initial encounter*/
,'V854XXD'  /*Person injured while boarding or alighting from special construction vehicle, subsequent encounter*/
,'V854XXS'  /*Person injured while boarding or alighting from special construction vehicle, sequela*/
,'V855XXA'  /*Driver of special construction vehicle injured in nontraffic accident, initial encounter*/
,'V855XXD'  /*Driver of special construction vehicle injured in nontraffic accident, subsequent encounter*/
,'V855XXS'  /*Driver of special construction vehicle injured in nontraffic accident, sequela*/
,'V856XXA'  /*Passenger of special construction vehicle injured in nontraffic accident, initial encounter*/
,'V856XXD'  /*Passenger of special construction vehicle injured in nontraffic accident, subsequent encounter*/
,'V856XXS'  /*Passenger of special construction vehicle injured in nontraffic accident, sequela*/
,'V857XXA'  /*Person on outside of special construction vehicle injured in nontraffic accident, initial encounter*/
,'V857XXD'  /*Person on outside of special construction vehicle injured in nontraffic accident, subsequent encounter*/
,'V857XXS'  /*Person on outside of special construction vehicle injured in nontraffic accident, sequela*/
,'V859XXA'  /*Unspecified occupant of special construction vehicle injured in nontraffic accident, initial encounter*/
,'V859XXD'  /*Unspecified occupant of special construction vehicle injured in nontraffic accident, subsequent encounter*/
,'V859XXS'  /*Unspecified occupant of special construction vehicle injured in nontraffic accident, sequela*/
,'V8601XA'  /*Driver of ambulance or fire engine injured in traffic accident, initial encounter*/
,'V8601XD'  /*Driver of ambulance or fire engine injured in traffic accident, subsequent encounter*/
,'V8601XS'  /*Driver of ambulance or fire engine injured in traffic accident, sequela*/
,'V8602XA'  /*Driver of snowmobile injured in traffic accident, initial encounter*/
,'V8602XD'  /*Driver of snowmobile injured in traffic accident, subsequent encounter*/
,'V8602XS'  /*Driver of snowmobile injured in traffic accident, sequela*/
,'V8603XA'  /*Driver of dune buggy injured in traffic accident, initial encounter*/
,'V8603XD'  /*Driver of dune buggy injured in traffic accident, subsequent encounter*/
,'V8603XS'  /*Driver of dune buggy injured in traffic accident, sequela*/
,'V8604XA'  /*Driver of military vehicle injured in traffic accident, initial encounter*/
,'V8604XD'  /*Driver of military vehicle injured in traffic accident, subsequent encounter*/
,'V8604XS'  /*Driver of military vehicle injured in traffic accident, sequela*/
,'V8609XA'  /*Driver of other special all-terrain or other off-road motor vehicle injured in traffic accident, initial encounter*/
,'V8609XD'  /*Driver of other special all-terrain or other off-road motor vehicle injured in traffic accident, subsequent encounter*/
,'V8609XS'  /*Driver of other special all-terrain or other off-road motor vehicle injured in traffic accident, sequela*/
,'V8611XA'  /*Passenger of ambulance or fire engine injured in traffic accident, initial encounter*/
,'V8611XD'  /*Passenger of ambulance or fire engine injured in traffic accident, subsequent encounter*/
,'V8611XS'  /*Passenger of ambulance or fire engine injured in traffic accident, sequela*/
,'V8612XA'  /*Passenger of snowmobile injured in traffic accident, initial encounter*/
,'V8612XD'  /*Passenger of snowmobile injured in traffic accident, subsequent encounter*/
,'V8612XS'  /*Passenger of snowmobile injured in traffic accident, sequela*/
,'V8613XA'  /*Passenger of dune buggy injured in traffic accident, initial encounter*/
,'V8613XD'  /*Passenger of dune buggy injured in traffic accident, subsequent encounter*/
,'V8613XS'  /*Passenger of dune buggy injured in traffic accident, sequela*/
,'V8614XA'  /*Passenger of military vehicle injured in traffic accident, initial encounter*/
,'V8614XD'  /*Passenger of military vehicle injured in traffic accident, subsequent encounter*/
,'V8614XS'  /*Passenger of military vehicle injured in traffic accident, sequela*/
,'V8619XA'  /*Passenger of other special all-terrain or other off-road motor vehicle injured in traffic accident, initial encounter*/
,'V8619XD'  /*Passenger of other special all-terrain or other off-road motor vehicle injured in traffic accident, subsequent encounter*/
,'V8619XS'  /*Passenger of other special all-terrain or other off-road motor vehicle injured in traffic accident, sequela*/
,'V8621XA'  /*Person on outside of ambulance or fire engine injured in traffic accident, initial encounter*/
,'V8621XD'  /*Person on outside of ambulance or fire engine injured in traffic accident, subsequent encounter*/
,'V8621XS'  /*Person on outside of ambulance or fire engine injured in traffic accident, sequela*/
,'V8622XA'  /*Person on outside of snowmobile injured in traffic accident, initial encounter*/
,'V8622XD'  /*Person on outside of snowmobile injured in traffic accident, subsequent encounter*/
,'V8622XS'  /*Person on outside of snowmobile injured in traffic accident, sequela*/
,'V8623XA'  /*Person on outside of dune buggy injured in traffic accident, initial encounter*/
,'V8623XD'  /*Person on outside of dune buggy injured in traffic accident, subsequent encounter*/
,'V8623XS'  /*Person on outside of dune buggy injured in traffic accident, sequela*/
,'V8624XA'  /*Person on outside of military vehicle injured in traffic accident, initial encounter*/
,'V8624XD'  /*Person on outside of military vehicle injured in traffic accident, subsequent encounter*/
,'V8624XS'  /*Person on outside of military vehicle injured in traffic accident, sequela*/
,'V8629XA'  /*Person on outside of other special all-terrain or other off-road motor vehicle injured in traffic accident, initial encounter*/
,'V8629XD'  /*Person on outside of other special all-terrain or other off-road motor vehicle injured in traffic accident, subsequent encounter*/
,'V8629XS'  /*Person on outside of other special all-terrain or other off-road motor vehicle injured in traffic accident, sequela*/
,'V8631XA'  /*Unspecified occupant of ambulance or fire engine injured in traffic accident, initial encounter*/
,'V8631XD'  /*Unspecified occupant of ambulance or fire engine injured in traffic accident, subsequent encounter*/
,'V8631XS'  /*Unspecified occupant of ambulance or fire engine injured in traffic accident, sequela*/
,'V8632XA'  /*Unspecified occupant of snowmobile injured in traffic accident, initial encounter*/
,'V8632XD'  /*Unspecified occupant of snowmobile injured in traffic accident, subsequent encounter*/
,'V8632XS'  /*Unspecified occupant of snowmobile injured in traffic accident, sequela*/
,'V8633XA'  /*Unspecified occupant of dune buggy injured in traffic accident, initial encounter*/
,'V8633XD'  /*Unspecified occupant of dune buggy injured in traffic accident, subsequent encounter*/
,'V8633XS'  /*Unspecified occupant of dune buggy injured in traffic accident, sequela*/
,'V8634XA'  /*Unspecified occupant of military vehicle injured in traffic accident, initial encounter*/
,'V8634XD'  /*Unspecified occupant of military vehicle injured in traffic accident, subsequent encounter*/
,'V8634XS'  /*Unspecified occupant of military vehicle injured in traffic accident, sequela*/
,'V8639XA'  /*Unspecified occupant of other special all-terrain or other off-road motor vehicle injured in traffic accident, initial encounter*/
,'V8639XD'  /*Unspecified occupant of other special all-terrain or other off-road motor vehicle injured in traffic accident, subsequent encounter*/
,'V8639XS'  /*Unspecified occupant of other special all-terrain or other off-road motor vehicle injured in traffic accident, sequela*/
,'V8641XA'  /*Person injured while boarding or alighting from ambulance or fire engine, initial encounter*/
,'V8641XD'  /*Person injured while boarding or alighting from ambulance or fire engine, subsequent encounter*/
,'V8641XS'  /*Person injured while boarding or alighting from ambulance or fire engine, sequela*/
,'V8642XA'  /*Person injured while boarding or alighting from snowmobile, initial encounter*/
,'V8642XD'  /*Person injured while boarding or alighting from snowmobile, subsequent encounter*/
,'V8642XS'  /*Person injured while boarding or alighting from snowmobile, sequela*/
,'V8643XA'  /*Person injured while boarding or alighting from dune buggy, initial encounter*/
,'V8643XD'  /*Person injured while boarding or alighting from dune buggy, subsequent encounter*/
,'V8643XS'  /*Person injured while boarding or alighting from dune buggy, sequela*/
,'V8644XA'  /*Person injured while boarding or alighting from military vehicle, initial encounter*/
,'V8644XD'  /*Person injured while boarding or alighting from military vehicle, subsequent encounter*/
,'V8644XS'  /*Person injured while boarding or alighting from military vehicle, sequela*/
,'V8649XA'  /*Person injured while boarding or alighting from other special all-terrain or other off-road motor vehicle, initial encounter*/
,'V8649XD'  /*Person injured while boarding or alighting from other special all-terrain or other off-road motor vehicle, subsequent encounter*/
,'V8649XS'  /*Person injured while boarding or alighting from other special all-terrain or other off-road motor vehicle, sequela*/
,'V8651XA'  /*Driver of ambulance or fire engine injured in nontraffic accident, initial encounter*/
,'V8651XD'  /*Driver of ambulance or fire engine injured in nontraffic accident, subsequent encounter*/
,'V8651XS'  /*Driver of ambulance or fire engine injured in nontraffic accident, sequela*/
,'V8652XA'  /*Driver of snowmobile injured in nontraffic accident, initial encounter*/
,'V8652XD'  /*Driver of snowmobile injured in nontraffic accident, subsequent encounter*/
,'V8652XS'  /*Driver of snowmobile injured in nontraffic accident, sequela*/
,'V8653XA'  /*Driver of dune buggy injured in nontraffic accident, initial encounter*/
,'V8653XD'  /*Driver of dune buggy injured in nontraffic accident, subsequent encounter*/
,'V8653XS'  /*Driver of dune buggy injured in nontraffic accident, sequela*/
,'V8654XA'  /*Driver of military vehicle injured in nontraffic accident, initial encounter*/
,'V8654XD'  /*Driver of military vehicle injured in nontraffic accident, subsequent encounter*/
,'V8654XS'  /*Driver of military vehicle injured in nontraffic accident, sequela*/
,'V8659XA'  /*Driver of other special all-terrain or other off-road motor vehicle injured in nontraffic accident, initial encounter*/
,'V8659XD'  /*Driver of other special all-terrain or other off-road motor vehicle injured in nontraffic accident, subsequent encounter*/
,'V8659XS'  /*Driver of other special all-terrain or other off-road motor vehicle injured in nontraffic accident, sequela*/
,'V8661XA'  /*Passenger of ambulance or fire engine injured in nontraffic accident, initial encounter*/
,'V8661XD'  /*Passenger of ambulance or fire engine injured in nontraffic accident, subsequent encounter*/
,'V8661XS'  /*Passenger of ambulance or fire engine injured in nontraffic accident, sequela*/
,'V8662XA'  /*Passenger of snowmobile injured in nontraffic accident, initial encounter*/
,'V8662XD'  /*Passenger of snowmobile injured in nontraffic accident, subsequent encounter*/
,'V8662XS'  /*Passenger of snowmobile injured in nontraffic accident, sequela*/
,'V8663XA'  /*Passenger of dune buggy injured in nontraffic accident, initial encounter*/
,'V8663XD'  /*Passenger of dune buggy injured in nontraffic accident, subsequent encounter*/
,'V8663XS'  /*Passenger of dune buggy injured in nontraffic accident, sequela*/
,'V8664XA'  /*Passenger of military vehicle injured in nontraffic accident, initial encounter*/
,'V8664XD'  /*Passenger of military vehicle injured in nontraffic accident, subsequent encounter*/
,'V8664XS'  /*Passenger of military vehicle injured in nontraffic accident, sequela*/
,'V8669XA'  /*Passenger of other special all-terrain or other off-road motor vehicle injured in nontraffic accident, initial encounter*/
,'V8669XD'  /*Passenger of other special all-terrain or other off-road motor vehicle injured in nontraffic accident, subsequent encounter*/
,'V8669XS'  /*Passenger of other special all-terrain or other off-road motor vehicle injured in nontraffic accident, sequela*/
,'V8671XA'  /*Person on outside of ambulance or fire engine injured in nontraffic accident, initial encounter*/
,'V8671XD'  /*Person on outside of ambulance or fire engine injured in nontraffic accident, subsequent encounter*/
,'V8671XS'  /*Person on outside of ambulance or fire engine injured in nontraffic accident, sequela*/
,'V8672XA'  /*Person on outside of snowmobile injured in nontraffic accident, initial encounter*/
,'V8672XD'  /*Person on outside of snowmobile injured in nontraffic accident, subsequent encounter*/
,'V8672XS'  /*Person on outside of snowmobile injured in nontraffic accident, sequela*/
,'V8673XA'  /*Person on outside of dune buggy injured in nontraffic accident, initial encounter*/
,'V8673XD'  /*Person on outside of dune buggy injured in nontraffic accident, subsequent encounter*/
,'V8673XS'  /*Person on outside of dune buggy injured in nontraffic accident, sequela*/
,'V8674XA'  /*Person on outside of military vehicle injured in nontraffic accident, initial encounter*/
,'V8674XD'  /*Person on outside of military vehicle injured in nontraffic accident, subsequent encounter*/
,'V8674XS'  /*Person on outside of military vehicle injured in nontraffic accident, sequela*/
,'V8679XA'  /*Person on outside of other special all-terrain or other off-road motor vehicles injured in nontraffic accident, initial encounter*/
,'V8679XD'  /*Person on outside of other special all-terrain or other off-road motor vehicles injured in nontraffic accident, subsequent encounter*/
,'V8679XS'  /*Person on outside of other special all-terrain or other off-road motor vehicles injured in nontraffic accident, sequela*/
,'V8691XA'  /*Unspecified occupant of ambulance or fire engine injured in nontraffic accident, initial encounter*/
,'V8691XD'  /*Unspecified occupant of ambulance or fire engine injured in nontraffic accident, subsequent encounter*/
,'V8691XS'  /*Unspecified occupant of ambulance or fire engine injured in nontraffic accident, sequela*/
,'V8692XA'  /*Unspecified occupant of snowmobile injured in nontraffic accident, initial encounter*/
,'V8692XD'  /*Unspecified occupant of snowmobile injured in nontraffic accident, subsequent encounter*/
,'V8692XS'  /*Unspecified occupant of snowmobile injured in nontraffic accident, sequela*/
,'V8693XA'  /*Unspecified occupant of dune buggy injured in nontraffic accident, initial encounter*/
,'V8693XD'  /*Unspecified occupant of dune buggy injured in nontraffic accident, subsequent encounter*/
,'V8693XS'  /*Unspecified occupant of dune buggy injured in nontraffic accident, sequela*/
,'V8694XA'  /*Unspecified occupant of military vehicle injured in nontraffic accident, initial encounter*/
,'V8694XD'  /*Unspecified occupant of military vehicle injured in nontraffic accident, subsequent encounter*/
,'V8694XS'  /*Unspecified occupant of military vehicle injured in nontraffic accident, sequela*/
,'V8699XA'  /*Unspecified occupant of other special all-terrain or other off-road motor vehicle injured in nontraffic accident, initial encounter*/
,'V8699XD'  /*Unspecified occupant of other special all-terrain or other off-road motor vehicle injured in nontraffic accident, subsequent encounter*/
,'V8699XS'  /*Unspecified occupant of other special all-terrain or other off-road motor vehicle injured in nontraffic accident, sequela*/
,'V870XXA'  /*Person injured in collision between car and two- or three-wheeled powered vehicle (traffic), initial encounter*/
,'V870XXD'  /*Person injured in collision between car and two- or three-wheeled powered vehicle (traffic), subsequent encounter*/
,'V870XXS'  /*Person injured in collision between car and two- or three-wheeled powered vehicle (traffic), sequela*/
,'V871XXA'  /*Person injured in collision between other motor vehicle and two- or three-wheeled motor vehicle (traffic), initial encounter*/
,'V871XXD'  /*Person injured in collision between other motor vehicle and two- or three-wheeled motor vehicle (traffic), subsequent encounter*/
,'V871XXS'  /*Person injured in collision between other motor vehicle and two- or three-wheeled motor vehicle (traffic), sequela*/
,'V872XXA'  /*Person injured in collision between car and pick-up truck or van (traffic), initial encounter*/
,'V872XXD'  /*Person injured in collision between car and pick-up truck or van (traffic), subsequent encounter*/
,'V872XXS'  /*Person injured in collision between car and pick-up truck or van (traffic), sequela*/
,'V873XXA'  /*Person injured in collision between car and bus (traffic), initial encounter*/
,'V873XXD'  /*Person injured in collision between car and bus (traffic), subsequent encounter*/
,'V873XXS'  /*Person injured in collision between car and bus (traffic), sequela*/
,'V874XXA'  /*Person injured in collision between car and heavy transport vehicle (traffic), initial encounter*/
,'V874XXD'  /*Person injured in collision between car and heavy transport vehicle (traffic), subsequent encounter*/
,'V874XXS'  /*Person injured in collision between car and heavy transport vehicle (traffic), sequela*/
,'V875XXA'  /*Person injured in collision between heavy transport vehicle and bus (traffic), initial encounter*/
,'V875XXD'  /*Person injured in collision between heavy transport vehicle and bus (traffic), subsequent encounter*/
,'V875XXS'  /*Person injured in collision between heavy transport vehicle and bus (traffic), sequela*/
,'V876XXA'  /*Person injured in collision between railway train or railway vehicle and car (traffic), initial encounter*/
,'V876XXD'  /*Person injured in collision between railway train or railway vehicle and car (traffic), subsequent encounter*/
,'V876XXS'  /*Person injured in collision between railway train or railway vehicle and car (traffic), sequela*/
,'V877XXA'  /*Person injured in collision between other specified motor vehicles (traffic), initial encounter*/
,'V877XXD'  /*Person injured in collision between other specified motor vehicles (traffic), subsequent encounter*/
,'V877XXS'  /*Person injured in collision between other specified motor vehicles (traffic), sequela*/
,'V878XXA'  /*Person injured in other specified noncollision transport accidents involving motor vehicle (traffic), initial encounter*/
,'V878XXD'  /*Person injured in other specified noncollision transport accidents involving motor vehicle (traffic), subsequent encounter*/
,'V878XXS'  /*Person injured in other specified noncollision transport accidents involving motor vehicle (traffic), sequela*/
,'V879XXA'  /*Person injured in other specified (collision)(noncollision) transport accidents involving nonmotor vehicle (traffic), initial encounter*/
,'V879XXD'  /*Person injured in other specified (collision)(noncollision) transport accidents involving nonmotor vehicle (traffic), subsequent encounter*/
,'V879XXS'  /*Person injured in other specified (collision)(noncollision) transport accidents involving nonmotor vehicle (traffic), sequela*/
,'V880XXA'  /*Person injured in collision between car and two- or three-wheeled motor vehicle, nontraffic, initial encounter*/
,'V880XXD'  /*Person injured in collision between car and two- or three-wheeled motor vehicle, nontraffic, subsequent encounter*/
,'V880XXS'  /*Person injured in collision between car and two- or three-wheeled motor vehicle, nontraffic, sequela*/
,'V881XXA'  /*Person injured in collision between other motor vehicle and two- or three-wheeled motor vehicle, nontraffic, initial encounter*/
,'V881XXD'  /*Person injured in collision between other motor vehicle and two- or three-wheeled motor vehicle, nontraffic, subsequent encounter*/
,'V881XXS'  /*Person injured in collision between other motor vehicle and two- or three-wheeled motor vehicle, nontraffic, sequela*/
,'V882XXA'  /*Person injured in collision between car and pick-up truck or van, nontraffic, initial encounter*/
,'V882XXD'  /*Person injured in collision between car and pick-up truck or van, nontraffic, subsequent encounter*/
,'V882XXS'  /*Person injured in collision between car and pick-up truck or van, nontraffic, sequela*/
,'V883XXA'  /*Person injured in collision between car and bus, nontraffic, initial encounter*/
,'V883XXD'  /*Person injured in collision between car and bus, nontraffic, subsequent encounter*/
,'V883XXS'  /*Person injured in collision between car and bus, nontraffic, sequela*/
,'V884XXA'  /*Person injured in collision between car and heavy transport vehicle, nontraffic, initial encounter*/
,'V884XXD'  /*Person injured in collision between car and heavy transport vehicle, nontraffic, subsequent encounter*/
,'V884XXS'  /*Person injured in collision between car and heavy transport vehicle, nontraffic, sequela*/
,'V885XXA'  /*Person injured in collision between heavy transport vehicle and bus, nontraffic, initial encounter*/
,'V885XXD'  /*Person injured in collision between heavy transport vehicle and bus, nontraffic, subsequent encounter*/
,'V885XXS'  /*Person injured in collision between heavy transport vehicle and bus, nontraffic, sequela*/
,'V886XXA'  /*Person injured in collision between railway train or railway vehicle and car, nontraffic, initial encounter*/
,'V886XXD'  /*Person injured in collision between railway train or railway vehicle and car, nontraffic, subsequent encounter*/
,'V886XXS'  /*Person injured in collision between railway train or railway vehicle and car, nontraffic, sequela*/
,'V887XXA'  /*Person injured in collision between other specified motor vehicle, nontraffic, initial encounter*/
,'V887XXD'  /*Person injured in collision between other specified motor vehicle, nontraffic, subsequent encounter*/
,'V887XXS'  /*Person injured in collision between other specified motor vehicle, nontraffic, sequela*/
,'V888XXA'  /*Person injured in other specified noncollision transport accidents involving motor vehicle, nontraffic, initial encounter*/
,'V888XXD'  /*Person injured in other specified noncollision transport accidents involving motor vehicle, nontraffic, subsequent encounter*/
,'V888XXS'  /*Person injured in other specified noncollision transport accidents involving motor vehicle, nontraffic, sequela*/
,'V889XXA'  /*Person injured in other specified (collision)(noncollision) transport accidents involving nonmotor vehicle, nontraffic, initial encounter*/
,'V889XXD'  /*Person injured in other specified (collision)(noncollision) transport accidents involving nonmotor vehicle, nontraffic, subsequent encounter*/
,'V889XXS'  /*Person injured in other specified (collision)(noncollision) transport accidents involving nonmotor vehicle, nontraffic, sequela*/
,'V890XXA'  /*Person injured in unspecified motor-vehicle accident, nontraffic, initial encounter*/
,'V890XXD'  /*Person injured in unspecified motor-vehicle accident, nontraffic, subsequent encounter*/
,'V890XXS'  /*Person injured in unspecified motor-vehicle accident, nontraffic, sequela*/
,'V891XXA'  /*Person injured in unspecified nonmotor-vehicle accident, nontraffic, initial encounter*/
,'V891XXD'  /*Person injured in unspecified nonmotor-vehicle accident, nontraffic, subsequent encounter*/
,'V891XXS'  /*Person injured in unspecified nonmotor-vehicle accident, nontraffic, sequela*/
,'V892XXA'  /*Person injured in unspecified motor-vehicle accident, traffic, initial encounter*/
,'V892XXD'  /*Person injured in unspecified motor-vehicle accident, traffic, subsequent encounter*/
,'V892XXS'  /*Person injured in unspecified motor-vehicle accident, traffic, sequela*/
,'V893XXA'  /*Person injured in unspecified nonmotor-vehicle accident, traffic, initial encounter*/
,'V893XXD'  /*Person injured in unspecified nonmotor-vehicle accident, traffic, subsequent encounter*/
,'V893XXS'  /*Person injured in unspecified nonmotor-vehicle accident, traffic, sequela*/
,'V899XXA'  /*Person injured in unspecified vehicle accident, initial encounter*/
,'V899XXD'  /*Person injured in unspecified vehicle accident, subsequent encounter*/
,'V899XXS'  /*Person injured in unspecified vehicle accident, sequela*/
,'V9000XA'  /*Drowning and submersion due to merchant ship overturning, initial encounter*/
,'V9000XD'  /*Drowning and submersion due to merchant ship overturning, subsequent encounter*/
,'V9000XS'  /*Drowning and submersion due to merchant ship overturning, sequela*/
,'V9001XA'  /*Drowning and submersion due to passenger ship overturning, initial encounter*/
,'V9001XD'  /*Drowning and submersion due to passenger ship overturning, subsequent encounter*/
,'V9001XS'  /*Drowning and submersion due to passenger ship overturning, sequela*/
,'V9002XA'  /*Drowning and submersion due to fishing boat overturning, initial encounter*/
,'V9002XD'  /*Drowning and submersion due to fishing boat overturning, subsequent encounter*/
,'V9002XS'  /*Drowning and submersion due to fishing boat overturning, sequela*/
,'V9003XA'  /*Drowning and submersion due to other powered watercraft overturning, initial encounter*/
,'V9003XD'  /*Drowning and submersion due to other powered watercraft overturning, subsequent encounter*/
,'V9003XS'  /*Drowning and submersion due to other powered watercraft overturning, sequela*/
,'V9004XA'  /*Drowning and submersion due to sailboat overturning, initial encounter*/
,'V9004XD'  /*Drowning and submersion due to sailboat overturning, subsequent encounter*/
,'V9004XS'  /*Drowning and submersion due to sailboat overturning, sequela*/
,'V9005XA'  /*Drowning and submersion due to canoe or kayak overturning, initial encounter*/
,'V9005XD'  /*Drowning and submersion due to canoe or kayak overturning, subsequent encounter*/
,'V9005XS'  /*Drowning and submersion due to canoe or kayak overturning, sequela*/
,'V9006XA'  /*Drowning and submersion due to (nonpowered) inflatable craft overturning, initial encounter*/
,'V9006XD'  /*Drowning and submersion due to (nonpowered) inflatable craft overturning, subsequent encounter*/
,'V9006XS'  /*Drowning and submersion due to (nonpowered) inflatable craft overturning, sequela*/
,'V9008XA'  /*Drowning and submersion due to other unpowered watercraft overturning, initial encounter*/
,'V9008XD'  /*Drowning and submersion due to other unpowered watercraft overturning, subsequent encounter*/
,'V9008XS'  /*Drowning and submersion due to other unpowered watercraft overturning, sequela*/
,'V9009XA'  /*Drowning and submersion due to unspecified watercraft overturning, initial encounter*/
,'V9009XD'  /*Drowning and submersion due to unspecified watercraft overturning, subsequent encounter*/
,'V9009XS'  /*Drowning and submersion due to unspecified watercraft overturning, sequela*/
,'V9010XA'  /*Drowning and submersion due to merchant ship sinking, initial encounter*/
,'V9010XD'  /*Drowning and submersion due to merchant ship sinking, subsequent encounter*/
,'V9010XS'  /*Drowning and submersion due to merchant ship sinking, sequela*/
,'V9011XA'  /*Drowning and submersion due to passenger ship sinking, initial encounter*/
,'V9011XD'  /*Drowning and submersion due to passenger ship sinking, subsequent encounter*/
,'V9011XS'  /*Drowning and submersion due to passenger ship sinking, sequela*/
,'V9012XA'  /*Drowning and submersion due to fishing boat sinking, initial encounter*/
,'V9012XD'  /*Drowning and submersion due to fishing boat sinking, subsequent encounter*/
,'V9012XS'  /*Drowning and submersion due to fishing boat sinking, sequela*/
,'V9013XA'  /*Drowning and submersion due to other powered watercraft sinking, initial encounter*/
,'V9013XD'  /*Drowning and submersion due to other powered watercraft sinking, subsequent encounter*/
,'V9013XS'  /*Drowning and submersion due to other powered watercraft sinking, sequela*/
,'V9014XA'  /*Drowning and submersion due to sailboat sinking, initial encounter*/
,'V9014XD'  /*Drowning and submersion due to sailboat sinking, subsequent encounter*/
,'V9014XS'  /*Drowning and submersion due to sailboat sinking, sequela*/
,'V9015XA'  /*Drowning and submersion due to canoe or kayak sinking, initial encounter*/
,'V9015XD'  /*Drowning and submersion due to canoe or kayak sinking, subsequent encounter*/
,'V9015XS'  /*Drowning and submersion due to canoe or kayak sinking, sequela*/
,'V9016XA'  /*Drowning and submersion due to (nonpowered) inflatable craft sinking, initial encounter*/
,'V9016XD'  /*Drowning and submersion due to (nonpowered) inflatable craft sinking, subsequent encounter*/
,'V9016XS'  /*Drowning and submersion due to (nonpowered) inflatable craft sinking, sequela*/
,'V9018XA'  /*Drowning and submersion due to other unpowered watercraft sinking, initial encounter*/
,'V9018XD'  /*Drowning and submersion due to other unpowered watercraft sinking, subsequent encounter*/
,'V9018XS'  /*Drowning and submersion due to other unpowered watercraft sinking, sequela*/
,'V9019XA'  /*Drowning and submersion due to unspecified watercraft sinking, initial encounter*/
,'V9019XD'  /*Drowning and submersion due to unspecified watercraft sinking, subsequent encounter*/
,'V9019XS'  /*Drowning and submersion due to unspecified watercraft sinking, sequela*/
,'V9020XA'  /*Drowning and submersion due to falling or jumping from burning merchant ship, initial encounter*/
,'V9020XD'  /*Drowning and submersion due to falling or jumping from burning merchant ship, subsequent encounter*/
,'V9020XS'  /*Drowning and submersion due to falling or jumping from burning merchant ship, sequela*/
,'V9021XA'  /*Drowning and submersion due to falling or jumping from burning passenger ship, initial encounter*/
,'V9021XD'  /*Drowning and submersion due to falling or jumping from burning passenger ship, subsequent encounter*/
,'V9021XS'  /*Drowning and submersion due to falling or jumping from burning passenger ship, sequela*/
,'V9022XA'  /*Drowning and submersion due to falling or jumping from burning fishing boat, initial encounter*/
,'V9022XD'  /*Drowning and submersion due to falling or jumping from burning fishing boat, subsequent encounter*/
,'V9022XS'  /*Drowning and submersion due to falling or jumping from burning fishing boat, sequela*/
,'V9023XA'  /*Drowning and submersion due to falling or jumping from other burning powered watercraft, initial encounter*/
,'V9023XD'  /*Drowning and submersion due to falling or jumping from other burning powered watercraft, subsequent encounter*/
,'V9023XS'  /*Drowning and submersion due to falling or jumping from other burning powered watercraft, sequela*/
,'V9024XA'  /*Drowning and submersion due to falling or jumping from burning sailboat, initial encounter*/
,'V9024XD'  /*Drowning and submersion due to falling or jumping from burning sailboat, subsequent encounter*/
,'V9024XS'  /*Drowning and submersion due to falling or jumping from burning sailboat, sequela*/
,'V9025XA'  /*Drowning and submersion due to falling or jumping from burning canoe or kayak, initial encounter*/
,'V9025XD'  /*Drowning and submersion due to falling or jumping from burning canoe or kayak, subsequent encounter*/
,'V9025XS'  /*Drowning and submersion due to falling or jumping from burning canoe or kayak, sequela*/
,'V9026XA'  /*Drowning and submersion due to falling or jumping from burning (nonpowered) inflatable craft, initial encounter*/
,'V9026XD'  /*Drowning and submersion due to falling or jumping from burning (nonpowered) inflatable craft, subsequent encounter*/
,'V9026XS'  /*Drowning and submersion due to falling or jumping from burning (nonpowered) inflatable craft, sequela*/
,'V9027XA'  /*Drowning and submersion due to falling or jumping from burning water-skis, initial encounter*/
,'V9027XD'  /*Drowning and submersion due to falling or jumping from burning water-skis, subsequent encounter*/
,'V9027XS'  /*Drowning and submersion due to falling or jumping from burning water-skis, sequela*/
,'V9028XA'  /*Drowning and submersion due to falling or jumping from other burning unpowered watercraft, initial encounter*/
,'V9028XD'  /*Drowning and submersion due to falling or jumping from other burning unpowered watercraft, subsequent encounter*/
,'V9028XS'  /*Drowning and submersion due to falling or jumping from other burning unpowered watercraft, sequela*/
,'V9029XA'  /*Drowning and submersion due to falling or jumping from unspecified burning watercraft, initial encounter*/
,'V9029XD'  /*Drowning and submersion due to falling or jumping from unspecified burning watercraft, subsequent encounter*/
,'V9029XS'  /*Drowning and submersion due to falling or jumping from unspecified burning watercraft, sequela*/
,'V9030XA'  /*Drowning and submersion due to falling or jumping from crushed merchant ship, initial encounter*/
,'V9030XD'  /*Drowning and submersion due to falling or jumping from crushed merchant ship, subsequent encounter*/
,'V9030XS'  /*Drowning and submersion due to falling or jumping from crushed merchant ship, sequela*/
,'V9031XA'  /*Drowning and submersion due to falling or jumping from crushed passenger ship, initial encounter*/
,'V9031XD'  /*Drowning and submersion due to falling or jumping from crushed passenger ship, subsequent encounter*/
,'V9031XS'  /*Drowning and submersion due to falling or jumping from crushed passenger ship, sequela*/
,'V9032XA'  /*Drowning and submersion due to falling or jumping from crushed fishing boat, initial encounter*/
,'V9032XD'  /*Drowning and submersion due to falling or jumping from crushed fishing boat, subsequent encounter*/
,'V9032XS'  /*Drowning and submersion due to falling or jumping from crushed fishing boat, sequela*/
,'V9033XA'  /*Drowning and submersion due to falling or jumping from other crushed powered watercraft, initial encounter*/
,'V9033XD'  /*Drowning and submersion due to falling or jumping from other crushed powered watercraft, subsequent encounter*/
,'V9033XS'  /*Drowning and submersion due to falling or jumping from other crushed powered watercraft, sequela*/
,'V9034XA'  /*Drowning and submersion due to falling or jumping from crushed sailboat, initial encounter*/
,'V9034XD'  /*Drowning and submersion due to falling or jumping from crushed sailboat, subsequent encounter*/
,'V9034XS'  /*Drowning and submersion due to falling or jumping from crushed sailboat, sequela*/
,'V9035XA'  /*Drowning and submersion due to falling or jumping from crushed canoe or kayak, initial encounter*/
,'V9035XD'  /*Drowning and submersion due to falling or jumping from crushed canoe or kayak, subsequent encounter*/
,'V9035XS'  /*Drowning and submersion due to falling or jumping from crushed canoe or kayak, sequela*/
,'V9036XA'  /*Drowning and submersion due to falling or jumping from crushed (nonpowered) inflatable craft, initial encounter*/
,'V9036XD'  /*Drowning and submersion due to falling or jumping from crushed (nonpowered) inflatable craft, subsequent encounter*/
,'V9036XS'  /*Drowning and submersion due to falling or jumping from crushed (nonpowered) inflatable craft, sequela*/
,'V9037XA'  /*Drowning and submersion due to falling or jumping from crushed water-skis, initial encounter*/
,'V9037XD'  /*Drowning and submersion due to falling or jumping from crushed water-skis, subsequent encounter*/
,'V9037XS'  /*Drowning and submersion due to falling or jumping from crushed water-skis, sequela*/
,'V9038XA'  /*Drowning and submersion due to falling or jumping from other crushed unpowered watercraft, initial encounter*/
,'V9038XD'  /*Drowning and submersion due to falling or jumping from other crushed unpowered watercraft, subsequent encounter*/
,'V9038XS'  /*Drowning and submersion due to falling or jumping from other crushed unpowered watercraft, sequela*/
,'V9039XA'  /*Drowning and submersion due to falling or jumping from crushed unspecified watercraft, initial encounter*/
,'V9039XD'  /*Drowning and submersion due to falling or jumping from crushed unspecified watercraft, subsequent encounter*/
,'V9039XS'  /*Drowning and submersion due to falling or jumping from crushed unspecified watercraft, sequela*/
,'V9080XA'  /*Drowning and submersion due to other accident to merchant ship, initial encounter*/
,'V9080XD'  /*Drowning and submersion due to other accident to merchant ship, subsequent encounter*/
,'V9080XS'  /*Drowning and submersion due to other accident to merchant ship, sequela*/
,'V9081XA'  /*Drowning and submersion due to other accident to passenger ship, initial encounter*/
,'V9081XD'  /*Drowning and submersion due to other accident to passenger ship, subsequent encounter*/
,'V9081XS'  /*Drowning and submersion due to other accident to passenger ship, sequela*/
,'V9082XA'  /*Drowning and submersion due to other accident to fishing boat, initial encounter*/
,'V9082XD'  /*Drowning and submersion due to other accident to fishing boat, subsequent encounter*/
,'V9082XS'  /*Drowning and submersion due to other accident to fishing boat, sequela*/
,'V9083XA'  /*Drowning and submersion due to other accident to other powered watercraft, initial encounter*/
,'V9083XD'  /*Drowning and submersion due to other accident to other powered watercraft, subsequent encounter*/
,'V9083XS'  /*Drowning and submersion due to other accident to other powered watercraft, sequela*/
,'V9084XA'  /*Drowning and submersion due to other accident to sailboat, initial encounter*/
,'V9084XD'  /*Drowning and submersion due to other accident to sailboat, subsequent encounter*/
,'V9084XS'  /*Drowning and submersion due to other accident to sailboat, sequela*/
,'V9085XA'  /*Drowning and submersion due to other accident to canoe or kayak, initial encounter*/
,'V9085XD'  /*Drowning and submersion due to other accident to canoe or kayak, subsequent encounter*/
,'V9085XS'  /*Drowning and submersion due to other accident to canoe or kayak, sequela*/
,'V9086XA'  /*Drowning and submersion due to other accident to (nonpowered) inflatable craft, initial encounter*/
,'V9086XD'  /*Drowning and submersion due to other accident to (nonpowered) inflatable craft, subsequent encounter*/
,'V9086XS'  /*Drowning and submersion due to other accident to (nonpowered) inflatable craft, sequela*/
,'V9087XA'  /*Drowning and submersion due to other accident to water-skis, initial encounter*/
,'V9087XD'  /*Drowning and submersion due to other accident to water-skis, subsequent encounter*/
,'V9087XS'  /*Drowning and submersion due to other accident to water-skis, sequela*/
,'V9088XA'  /*Drowning and submersion due to other accident to other unpowered watercraft, initial encounter*/
,'V9088XD'  /*Drowning and submersion due to other accident to other unpowered watercraft, subsequent encounter*/
,'V9088XS'  /*Drowning and submersion due to other accident to other unpowered watercraft, sequela*/
,'V9089XA'  /*Drowning and submersion due to other accident to unspecified watercraft, initial encounter*/
,'V9089XD'  /*Drowning and submersion due to other accident to unspecified watercraft, subsequent encounter*/
,'V9089XS'  /*Drowning and submersion due to other accident to unspecified watercraft, sequela*/
,'V9100XA'  /*Burn due to merchant ship on fire, initial encounter*/
,'V9100XD'  /*Burn due to merchant ship on fire, subsequent encounter*/
,'V9100XS'  /*Burn due to merchant ship on fire, sequela*/
,'V9101XA'  /*Burn due to passenger ship on fire, initial encounter*/
,'V9101XD'  /*Burn due to passenger ship on fire, subsequent encounter*/
,'V9101XS'  /*Burn due to passenger ship on fire, sequela*/
,'V9102XA'  /*Burn due to fishing boat on fire, initial encounter*/
,'V9102XD'  /*Burn due to fishing boat on fire, subsequent encounter*/
,'V9102XS'  /*Burn due to fishing boat on fire, sequela*/
,'V9103XA'  /*Burn due to other powered watercraft on fire, initial encounter*/
,'V9103XD'  /*Burn due to other powered watercraft on fire, subsequent encounter*/
,'V9103XS'  /*Burn due to other powered watercraft on fire, sequela*/
,'V9104XA'  /*Burn due to sailboat on fire, initial encounter*/
,'V9104XD'  /*Burn due to sailboat on fire, subsequent encounter*/
,'V9104XS'  /*Burn due to sailboat on fire, sequela*/
,'V9105XA'  /*Burn due to canoe or kayak on fire, initial encounter*/
,'V9105XD'  /*Burn due to canoe or kayak on fire, subsequent encounter*/
,'V9105XS'  /*Burn due to canoe or kayak on fire, sequela*/
,'V9106XA'  /*Burn due to (nonpowered) inflatable craft on fire, initial encounter*/
,'V9106XD'  /*Burn due to (nonpowered) inflatable craft on fire, subsequent encounter*/
,'V9106XS'  /*Burn due to (nonpowered) inflatable craft on fire, sequela*/
,'V9107XA'  /*Burn due to water-skis on fire, initial encounter*/
,'V9107XD'  /*Burn due to water-skis on fire, subsequent encounter*/
,'V9107XS'  /*Burn due to water-skis on fire, sequela*/
,'V9108XA'  /*Burn due to other unpowered watercraft on fire, initial encounter*/
,'V9108XD'  /*Burn due to other unpowered watercraft on fire, subsequent encounter*/
,'V9108XS'  /*Burn due to other unpowered watercraft on fire, sequela*/
,'V9109XA'  /*Burn due to unspecified watercraft on fire, initial encounter*/
,'V9109XD'  /*Burn due to unspecified watercraft on fire, subsequent encounter*/
,'V9109XS'  /*Burn due to unspecified watercraft on fire, sequela*/
,'V9110XA'  /*Crushed between merchant ship and other watercraft or other object due to collision, initial encounter*/
,'V9110XD'  /*Crushed between merchant ship and other watercraft or other object due to collision, subsequent encounter*/
,'V9110XS'  /*Crushed between merchant ship and other watercraft or other object due to collision, sequela*/
,'V9111XA'  /*Crushed between passenger ship and other watercraft or other object due to collision, initial encounter*/
,'V9111XD'  /*Crushed between passenger ship and other watercraft or other object due to collision, subsequent encounter*/
,'V9111XS'  /*Crushed between passenger ship and other watercraft or other object due to collision, sequela*/
,'V9112XA'  /*Crushed between fishing boat and other watercraft or other object due to collision, initial encounter*/
,'V9112XD'  /*Crushed between fishing boat and other watercraft or other object due to collision, subsequent encounter*/
,'V9112XS'  /*Crushed between fishing boat and other watercraft or other object due to collision, sequela*/
,'V9113XA'  /*Crushed between other powered watercraft and other watercraft or other object due to collision, initial encounter*/
,'V9113XD'  /*Crushed between other powered watercraft and other watercraft or other object due to collision, subsequent encounter*/
,'V9113XS'  /*Crushed between other powered watercraft and other watercraft or other object due to collision, sequela*/
,'V9114XA'  /*Crushed between sailboat and other watercraft or other object due to collision, initial encounter*/
,'V9114XD'  /*Crushed between sailboat and other watercraft or other object due to collision, subsequent encounter*/
,'V9114XS'  /*Crushed between sailboat and other watercraft or other object due to collision, sequela*/
,'V9115XA'  /*Crushed between canoe or kayak and other watercraft or other object due to collision, initial encounter*/
,'V9115XD'  /*Crushed between canoe or kayak and other watercraft or other object due to collision, subsequent encounter*/
,'V9115XS'  /*Crushed between canoe or kayak and other watercraft or other object due to collision, sequela*/
,'V9116XA'  /*Crushed between (nonpowered) inflatable craft and other watercraft or other object due to collision, initial encounter*/
,'V9116XD'  /*Crushed between (nonpowered) inflatable craft and other watercraft or other object due to collision, subsequent encounter*/
,'V9116XS'  /*Crushed between (nonpowered) inflatable craft and other watercraft or other object due to collision, sequela*/
,'V9118XA'  /*Crushed between other unpowered watercraft and other watercraft or other object due to collision, initial encounter*/
,'V9118XD'  /*Crushed between other unpowered watercraft and other watercraft or other object due to collision, subsequent encounter*/
,'V9118XS'  /*Crushed between other unpowered watercraft and other watercraft or other object due to collision, sequela*/
,'V9119XA'  /*Crushed between unspecified watercraft and other watercraft or other object due to collision, initial encounter*/
,'V9119XD'  /*Crushed between unspecified watercraft and other watercraft or other object due to collision, subsequent encounter*/
,'V9119XS'  /*Crushed between unspecified watercraft and other watercraft or other object due to collision, sequela*/
,'V9120XA'  /*Fall due to collision between merchant ship and other watercraft or other object, initial encounter*/
,'V9120XD'  /*Fall due to collision between merchant ship and other watercraft or other object, subsequent encounter*/
,'V9120XS'  /*Fall due to collision between merchant ship and other watercraft or other object, sequela*/
,'V9121XA'  /*Fall due to collision between passenger ship and other watercraft or other object, initial encounter*/
,'V9121XD'  /*Fall due to collision between passenger ship and other watercraft or other object, subsequent encounter*/
,'V9121XS'  /*Fall due to collision between passenger ship and other watercraft or other object, sequela*/
,'V9122XA'  /*Fall due to collision between fishing boat and other watercraft or other object, initial encounter*/
,'V9122XD'  /*Fall due to collision between fishing boat and other watercraft or other object, subsequent encounter*/
,'V9122XS'  /*Fall due to collision between fishing boat and other watercraft or other object, sequela*/
,'V9123XA'  /*Fall due to collision between other powered watercraft and other watercraft or other object, initial encounter*/
,'V9123XD'  /*Fall due to collision between other powered watercraft and other watercraft or other object, subsequent encounter*/
,'V9123XS'  /*Fall due to collision between other powered watercraft and other watercraft or other object, sequela*/
,'V9124XA'  /*Fall due to collision between sailboat and other watercraft or other object, initial encounter*/
,'V9124XD'  /*Fall due to collision between sailboat and other watercraft or other object, subsequent encounter*/
,'V9124XS'  /*Fall due to collision between sailboat and other watercraft or other object, sequela*/
,'V9125XA'  /*Fall due to collision between canoe or kayak and other watercraft or other object, initial encounter*/
,'V9125XD'  /*Fall due to collision between canoe or kayak and other watercraft or other object, subsequent encounter*/
,'V9125XS'  /*Fall due to collision between canoe or kayak and other watercraft or other object, sequela*/
,'V9126XA'  /*Fall due to collision between (nonpowered) inflatable craft and other watercraft or other object, initial encounter*/
,'V9126XD'  /*Fall due to collision between (nonpowered) inflatable craft and other watercraft or other object, subsequent encounter*/
,'V9126XS'  /*Fall due to collision between (nonpowered) inflatable craft and other watercraft or other object, sequela*/
,'V9129XA'  /*Fall due to collision between unspecified watercraft and other watercraft or other object, initial encounter*/
,'V9129XD'  /*Fall due to collision between unspecified watercraft and other watercraft or other object, subsequent encounter*/
,'V9129XS'  /*Fall due to collision between unspecified watercraft and other watercraft or other object, sequela*/
,'V9130XA'  /*Hit or struck by falling object due to accident to merchant ship, initial encounter*/
,'V9130XD'  /*Hit or struck by falling object due to accident to merchant ship, subsequent encounter*/
,'V9130XS'  /*Hit or struck by falling object due to accident to merchant ship, sequela*/
,'V9131XA'  /*Hit or struck by falling object due to accident to passenger ship, initial encounter*/
,'V9131XD'  /*Hit or struck by falling object due to accident to passenger ship, subsequent encounter*/
,'V9131XS'  /*Hit or struck by falling object due to accident to passenger ship, sequela*/
,'V9132XA'  /*Hit or struck by falling object due to accident to fishing boat, initial encounter*/
,'V9132XD'  /*Hit or struck by falling object due to accident to fishing boat, subsequent encounter*/
,'V9132XS'  /*Hit or struck by falling object due to accident to fishing boat, sequela*/
,'V9133XA'  /*Hit or struck by falling object due to accident to other powered watercraft, initial encounter*/
,'V9133XD'  /*Hit or struck by falling object due to accident to other powered watercraft, subsequent encounter*/
,'V9133XS'  /*Hit or struck by falling object due to accident to other powered watercraft, sequela*/
,'V9134XA'  /*Hit or struck by falling object due to accident to sailboat, initial encounter*/
,'V9134XD'  /*Hit or struck by falling object due to accident to sailboat, subsequent encounter*/
,'V9134XS'  /*Hit or struck by falling object due to accident to sailboat, sequela*/
,'V9135XA'  /*Hit or struck by falling object due to accident to canoe or kayak, initial encounter*/
,'V9135XD'  /*Hit or struck by falling object due to accident to canoe or kayak, subsequent encounter*/
,'V9135XS'  /*Hit or struck by falling object due to accident to canoe or kayak, sequela*/
,'V9136XA'  /*Hit or struck by falling object due to accident to (nonpowered) inflatable craft, initial encounter*/
,'V9136XD'  /*Hit or struck by falling object due to accident to (nonpowered) inflatable craft, subsequent encounter*/
,'V9136XS'  /*Hit or struck by falling object due to accident to (nonpowered) inflatable craft, sequela*/
,'V9137XA'  /*Hit or struck by falling object due to accident to water-skis, initial encounter*/
,'V9137XD'  /*Hit or struck by falling object due to accident to water-skis, subsequent encounter*/
,'V9137XS'  /*Hit or struck by falling object due to accident to water-skis, sequela*/
,'V9138XA'  /*Hit or struck by falling object due to accident to other unpowered watercraft, initial encounter*/
,'V9138XD'  /*Hit or struck by falling object due to accident to other unpowered watercraft, subsequent encounter*/
,'V9138XS'  /*Hit or struck by falling object due to accident to other unpowered watercraft, sequela*/
,'V9139XA'  /*Hit or struck by falling object due to accident to unspecified watercraft, initial encounter*/
,'V9139XD'  /*Hit or struck by falling object due to accident to unspecified watercraft, subsequent encounter*/
,'V9139XS'  /*Hit or struck by falling object due to accident to unspecified watercraft, sequela*/
,'V9180XA'  /*Other injury due to other accident to merchant ship, initial encounter*/
,'V9180XD'  /*Other injury due to other accident to merchant ship, subsequent encounter*/
,'V9180XS'  /*Other injury due to other accident to merchant ship, sequela*/
,'V9181XA'  /*Other injury due to other accident to passenger ship, initial encounter*/
,'V9181XD'  /*Other injury due to other accident to passenger ship, subsequent encounter*/
,'V9181XS'  /*Other injury due to other accident to passenger ship, sequela*/
,'V9182XA'  /*Other injury due to other accident to fishing boat, initial encounter*/
,'V9182XD'  /*Other injury due to other accident to fishing boat, subsequent encounter*/
,'V9182XS'  /*Other injury due to other accident to fishing boat, sequela*/
,'V9183XA'  /*Other injury due to other accident to other powered watercraft, initial encounter*/
,'V9183XD'  /*Other injury due to other accident to other powered watercraft, subsequent encounter*/
,'V9183XS'  /*Other injury due to other accident to other powered watercraft, sequela*/
,'V9184XA'  /*Other injury due to other accident to sailboat, initial encounter*/
,'V9184XD'  /*Other injury due to other accident to sailboat, subsequent encounter*/
,'V9184XS'  /*Other injury due to other accident to sailboat, sequela*/
,'V9185XA'  /*Other injury due to other accident to canoe or kayak, initial encounter*/
,'V9185XD'  /*Other injury due to other accident to canoe or kayak, subsequent encounter*/
,'V9185XS'  /*Other injury due to other accident to canoe or kayak, sequela*/
,'V9186XA'  /*Other injury due to other accident to (nonpowered) inflatable craft, initial encounter*/
,'V9186XD'  /*Other injury due to other accident to (nonpowered) inflatable craft, subsequent encounter*/
,'V9186XS'  /*Other injury due to other accident to (nonpowered) inflatable craft, sequela*/
,'V9187XA'  /*Other injury due to other accident to water-skis, initial encounter*/
,'V9187XD'  /*Other injury due to other accident to water-skis, subsequent encounter*/
,'V9187XS'  /*Other injury due to other accident to water-skis, sequela*/
,'V9188XA'  /*Other injury due to other accident to other unpowered watercraft, initial encounter*/
,'V9188XD'  /*Other injury due to other accident to other unpowered watercraft, subsequent encounter*/
,'V9188XS'  /*Other injury due to other accident to other unpowered watercraft, sequela*/
,'V9189XA'  /*Other injury due to other accident to unspecified watercraft, initial encounter*/
,'V9189XD'  /*Other injury due to other accident to unspecified watercraft, subsequent encounter*/
,'V9189XS'  /*Other injury due to other accident to unspecified watercraft, sequela*/
,'V9200XA'  /*Drowning and submersion due to fall off merchant ship, initial encounter*/
,'V9200XD'  /*Drowning and submersion due to fall off merchant ship, subsequent encounter*/
,'V9200XS'  /*Drowning and submersion due to fall off merchant ship, sequela*/
,'V9201XA'  /*Drowning and submersion due to fall off passenger ship, initial encounter*/
,'V9201XD'  /*Drowning and submersion due to fall off passenger ship, subsequent encounter*/
,'V9201XS'  /*Drowning and submersion due to fall off passenger ship, sequela*/
,'V9202XA'  /*Drowning and submersion due to fall off fishing boat, initial encounter*/
,'V9202XD'  /*Drowning and submersion due to fall off fishing boat, subsequent encounter*/
,'V9202XS'  /*Drowning and submersion due to fall off fishing boat, sequela*/
,'V9203XA'  /*Drowning and submersion due to fall off other powered watercraft, initial encounter*/
,'V9203XD'  /*Drowning and submersion due to fall off other powered watercraft, subsequent encounter*/
,'V9203XS'  /*Drowning and submersion due to fall off other powered watercraft, sequela*/
,'V9204XA'  /*Drowning and submersion due to fall off sailboat, initial encounter*/
,'V9204XD'  /*Drowning and submersion due to fall off sailboat, subsequent encounter*/
,'V9204XS'  /*Drowning and submersion due to fall off sailboat, sequela*/
,'V9205XA'  /*Drowning and submersion due to fall off canoe or kayak, initial encounter*/
,'V9205XD'  /*Drowning and submersion due to fall off canoe or kayak, subsequent encounter*/
,'V9205XS'  /*Drowning and submersion due to fall off canoe or kayak, sequela*/
,'V9206XA'  /*Drowning and submersion due to fall off (nonpowered) inflatable craft, initial encounter*/
,'V9206XD'  /*Drowning and submersion due to fall off (nonpowered) inflatable craft, subsequent encounter*/
,'V9206XS'  /*Drowning and submersion due to fall off (nonpowered) inflatable craft, sequela*/
,'V9207XA'  /*Drowning and submersion due to fall off water-skis, initial encounter*/
,'V9207XD'  /*Drowning and submersion due to fall off water-skis, subsequent encounter*/
,'V9207XS'  /*Drowning and submersion due to fall off water-skis, sequela*/
,'V9208XA'  /*Drowning and submersion due to fall off other unpowered watercraft, initial encounter*/
,'V9208XD'  /*Drowning and submersion due to fall off other unpowered watercraft, subsequent encounter*/
,'V9208XS'  /*Drowning and submersion due to fall off other unpowered watercraft, sequela*/
,'V9209XA'  /*Drowning and submersion due to fall off unspecified watercraft, initial encounter*/
,'V9209XD'  /*Drowning and submersion due to fall off unspecified watercraft, subsequent encounter*/
,'V9209XS'  /*Drowning and submersion due to fall off unspecified watercraft, sequela*/
,'V9210XA'  /*Drowning and submersion due to being thrown overboard by motion of merchant ship, initial encounter*/
,'V9210XD'  /*Drowning and submersion due to being thrown overboard by motion of merchant ship, subsequent encounter*/
,'V9210XS'  /*Drowning and submersion due to being thrown overboard by motion of merchant ship, sequela*/
,'V9211XA'  /*Drowning and submersion due to being thrown overboard by motion of passenger ship, initial encounter*/
,'V9211XD'  /*Drowning and submersion due to being thrown overboard by motion of passenger ship, subsequent encounter*/
,'V9211XS'  /*Drowning and submersion due to being thrown overboard by motion of passenger ship, sequela*/
,'V9212XA'  /*Drowning and submersion due to being thrown overboard by motion of fishing boat, initial encounter*/
,'V9212XD'  /*Drowning and submersion due to being thrown overboard by motion of fishing boat, subsequent encounter*/
,'V9212XS'  /*Drowning and submersion due to being thrown overboard by motion of fishing boat, sequela*/
,'V9213XA'  /*Drowning and submersion due to being thrown overboard by motion of other powered watercraft, initial encounter*/
,'V9213XD'  /*Drowning and submersion due to being thrown overboard by motion of other powered watercraft, subsequent encounter*/
,'V9213XS'  /*Drowning and submersion due to being thrown overboard by motion of other powered watercraft, sequela*/
,'V9214XA'  /*Drowning and submersion due to being thrown overboard by motion of sailboat, initial encounter*/
,'V9214XD'  /*Drowning and submersion due to being thrown overboard by motion of sailboat, subsequent encounter*/
,'V9214XS'  /*Drowning and submersion due to being thrown overboard by motion of sailboat, sequela*/
,'V9215XA'  /*Drowning and submersion due to being thrown overboard by motion of canoe or kayak, initial encounter*/
,'V9215XD'  /*Drowning and submersion due to being thrown overboard by motion of canoe or kayak, subsequent encounter*/
,'V9215XS'  /*Drowning and submersion due to being thrown overboard by motion of canoe or kayak, sequela*/
,'V9216XA'  /*Drowning and submersion due to being thrown overboard by motion of (nonpowered) inflatable craft, initial encounter*/
,'V9216XD'  /*Drowning and submersion due to being thrown overboard by motion of (nonpowered) inflatable craft, subsequent encounter*/
,'V9216XS'  /*Drowning and submersion due to being thrown overboard by motion of (nonpowered) inflatable craft, sequela*/
,'V9219XA'  /*Drowning and submersion due to being thrown overboard by motion of unspecified watercraft, initial encounter*/
,'V9219XD'  /*Drowning and submersion due to being thrown overboard by motion of unspecified watercraft, subsequent encounter*/
,'V9219XS'  /*Drowning and submersion due to being thrown overboard by motion of unspecified watercraft, sequela*/
,'V9220XA'  /*Drowning and submersion due to being washed overboard from merchant ship, initial encounter*/
,'V9220XD'  /*Drowning and submersion due to being washed overboard from merchant ship, subsequent encounter*/
,'V9220XS'  /*Drowning and submersion due to being washed overboard from merchant ship, sequela*/
,'V9221XA'  /*Drowning and submersion due to being washed overboard from passenger ship, initial encounter*/
,'V9221XD'  /*Drowning and submersion due to being washed overboard from passenger ship, subsequent encounter*/
,'V9221XS'  /*Drowning and submersion due to being washed overboard from passenger ship, sequela*/
,'V9222XA'  /*Drowning and submersion due to being washed overboard from fishing boat, initial encounter*/
,'V9222XD'  /*Drowning and submersion due to being washed overboard from fishing boat, subsequent encounter*/
,'V9222XS'  /*Drowning and submersion due to being washed overboard from fishing boat, sequela*/
,'V9223XA'  /*Drowning and submersion due to being washed overboard from other powered watercraft, initial encounter*/
,'V9223XD'  /*Drowning and submersion due to being washed overboard from other powered watercraft, subsequent encounter*/
,'V9223XS'  /*Drowning and submersion due to being washed overboard from other powered watercraft, sequela*/
,'V9224XA'  /*Drowning and submersion due to being washed overboard from sailboat, initial encounter*/
,'V9224XD'  /*Drowning and submersion due to being washed overboard from sailboat, subsequent encounter*/
,'V9224XS'  /*Drowning and submersion due to being washed overboard from sailboat, sequela*/
,'V9225XA'  /*Drowning and submersion due to being washed overboard from canoe or kayak, initial encounter*/
,'V9225XD'  /*Drowning and submersion due to being washed overboard from canoe or kayak, subsequent encounter*/
,'V9225XS'  /*Drowning and submersion due to being washed overboard from canoe or kayak, sequela*/
,'V9226XA'  /*Drowning and submersion due to being washed overboard from (nonpowered) inflatable craft, initial encounter*/
,'V9226XD'  /*Drowning and submersion due to being washed overboard from (nonpowered) inflatable craft, subsequent encounter*/
,'V9226XS'  /*Drowning and submersion due to being washed overboard from (nonpowered) inflatable craft, sequela*/
,'V9227XA'  /*Drowning and submersion due to being washed overboard from water-skis, initial encounter*/
,'V9227XD'  /*Drowning and submersion due to being washed overboard from water-skis, subsequent encounter*/
,'V9227XS'  /*Drowning and submersion due to being washed overboard from water-skis, sequela*/
,'V9228XA'  /*Drowning and submersion due to being washed overboard from other unpowered watercraft, initial encounter*/
,'V9228XD'  /*Drowning and submersion due to being washed overboard from other unpowered watercraft, subsequent encounter*/
,'V9228XS'  /*Drowning and submersion due to being washed overboard from other unpowered watercraft, sequela*/
,'V9229XA'  /*Drowning and submersion due to being washed overboard from unspecified watercraft, initial encounter*/
,'V9229XD'  /*Drowning and submersion due to being washed overboard from unspecified watercraft, subsequent encounter*/
,'V9229XS'  /*Drowning and submersion due to being washed overboard from unspecified watercraft, sequela*/
,'V9300XA'  /*Burn due to localized fire on board merchant vessel, initial encounter*/
,'V9300XD'  /*Burn due to localized fire on board merchant vessel, subsequent encounter*/
,'V9300XS'  /*Burn due to localized fire on board merchant vessel, sequela*/
,'V9301XA'  /*Burn due to localized fire on board passenger vessel, initial encounter*/
,'V9301XD'  /*Burn due to localized fire on board passenger vessel, subsequent encounter*/
,'V9301XS'  /*Burn due to localized fire on board passenger vessel, sequela*/
,'V9302XA'  /*Burn due to localized fire on board fishing boat, initial encounter*/
,'V9302XD'  /*Burn due to localized fire on board fishing boat, subsequent encounter*/
,'V9302XS'  /*Burn due to localized fire on board fishing boat, sequela*/
,'V9303XA'  /*Burn due to localized fire on board other powered watercraft, initial encounter*/
,'V9303XD'  /*Burn due to localized fire on board other powered watercraft, subsequent encounter*/
,'V9303XS'  /*Burn due to localized fire on board other powered watercraft, sequela*/
,'V9304XA'  /*Burn due to localized fire on board sailboat, initial encounter*/
,'V9304XD'  /*Burn due to localized fire on board sailboat, subsequent encounter*/
,'V9304XS'  /*Burn due to localized fire on board sailboat, sequela*/
,'V9309XA'  /*Burn due to localized fire on board unspecified watercraft, initial encounter*/
,'V9309XD'  /*Burn due to localized fire on board unspecified watercraft, subsequent encounter*/
,'V9309XS'  /*Burn due to localized fire on board unspecified watercraft, sequela*/
,'V9310XA'  /*Other burn on board merchant vessel, initial encounter*/
,'V9310XD'  /*Other burn on board merchant vessel, subsequent encounter*/
,'V9310XS'  /*Other burn on board merchant vessel, sequela*/
,'V9311XA'  /*Other burn on board passenger vessel, initial encounter*/
,'V9311XD'  /*Other burn on board passenger vessel, subsequent encounter*/
,'V9311XS'  /*Other burn on board passenger vessel, sequela*/
,'V9312XA'  /*Other burn on board fishing boat, initial encounter*/
,'V9312XD'  /*Other burn on board fishing boat, subsequent encounter*/
,'V9312XS'  /*Other burn on board fishing boat, sequela*/
,'V9313XA'  /*Other burn on board other powered watercraft, initial encounter*/
,'V9313XD'  /*Other burn on board other powered watercraft, subsequent encounter*/
,'V9313XS'  /*Other burn on board other powered watercraft, sequela*/
,'V9314XA'  /*Other burn on board sailboat, initial encounter*/
,'V9314XD'  /*Other burn on board sailboat, subsequent encounter*/
,'V9314XS'  /*Other burn on board sailboat, sequela*/
,'V9319XA'  /*Other burn on board unspecified watercraft, initial encounter*/
,'V9319XD'  /*Other burn on board unspecified watercraft, subsequent encounter*/
,'V9319XS'  /*Other burn on board unspecified watercraft, sequela*/
,'V9320XA'  /*Heat exposure on board merchant ship, initial encounter*/
,'V9320XD'  /*Heat exposure on board merchant ship, subsequent encounter*/
,'V9320XS'  /*Heat exposure on board merchant ship, sequela*/
,'V9321XA'  /*Heat exposure on board passenger ship, initial encounter*/
,'V9321XD'  /*Heat exposure on board passenger ship, subsequent encounter*/
,'V9321XS'  /*Heat exposure on board passenger ship, sequela*/
,'V9322XA'  /*Heat exposure on board fishing boat, initial encounter*/
,'V9322XD'  /*Heat exposure on board fishing boat, subsequent encounter*/
,'V9322XS'  /*Heat exposure on board fishing boat, sequela*/
,'V9323XA'  /*Heat exposure on board other powered watercraft, initial encounter*/
,'V9323XD'  /*Heat exposure on board other powered watercraft, subsequent encounter*/
,'V9323XS'  /*Heat exposure on board other powered watercraft, sequela*/
,'V9324XA'  /*Heat exposure on board sailboat, initial encounter*/
,'V9324XD'  /*Heat exposure on board sailboat, subsequent encounter*/
,'V9324XS'  /*Heat exposure on board sailboat, sequela*/
,'V9329XA'  /*Heat exposure on board unspecified watercraft, initial encounter*/
,'V9329XD'  /*Heat exposure on board unspecified watercraft, subsequent encounter*/
,'V9329XS'  /*Heat exposure on board unspecified watercraft, sequela*/
,'V9330XA'  /*Fall on board merchant ship, initial encounter*/
,'V9330XD'  /*Fall on board merchant ship, subsequent encounter*/
,'V9330XS'  /*Fall on board merchant ship, sequela*/
,'V9331XA'  /*Fall on board passenger ship, initial encounter*/
,'V9331XD'  /*Fall on board passenger ship, subsequent encounter*/
,'V9331XS'  /*Fall on board passenger ship, sequela*/
,'V9332XA'  /*Fall on board fishing boat, initial encounter*/
,'V9332XD'  /*Fall on board fishing boat, subsequent encounter*/
,'V9332XS'  /*Fall on board fishing boat, sequela*/
,'V9333XA'  /*Fall on board other powered watercraft, initial encounter*/
,'V9333XD'  /*Fall on board other powered watercraft, subsequent encounter*/
,'V9333XS'  /*Fall on board other powered watercraft, sequela*/
,'V9334XA'  /*Fall on board sailboat, initial encounter*/
,'V9334XD'  /*Fall on board sailboat, subsequent encounter*/
,'V9334XS'  /*Fall on board sailboat, sequela*/
,'V9335XA'  /*Fall on board canoe or kayak, initial encounter*/
,'V9335XD'  /*Fall on board canoe or kayak, subsequent encounter*/
,'V9335XS'  /*Fall on board canoe or kayak, sequela*/
,'V9336XA'  /*Fall on board (nonpowered) inflatable craft, initial encounter*/
,'V9336XD'  /*Fall on board (nonpowered) inflatable craft, subsequent encounter*/
,'V9336XS'  /*Fall on board (nonpowered) inflatable craft, sequela*/
,'V9338XA'  /*Fall on board other unpowered watercraft, initial encounter*/
,'V9338XD'  /*Fall on board other unpowered watercraft, subsequent encounter*/
,'V9338XS'  /*Fall on board other unpowered watercraft, sequela*/
,'V9339XA'  /*Fall on board unspecified watercraft, initial encounter*/
,'V9339XD'  /*Fall on board unspecified watercraft, subsequent encounter*/
,'V9339XS'  /*Fall on board unspecified watercraft, sequela*/
,'V9340XA'  /*Struck by falling object on merchant ship, initial encounter*/
,'V9340XD'  /*Struck by falling object on merchant ship, subsequent encounter*/
,'V9340XS'  /*Struck by falling object on merchant ship, sequela*/
,'V9341XA'  /*Struck by falling object on passenger ship, initial encounter*/
,'V9341XD'  /*Struck by falling object on passenger ship, subsequent encounter*/
,'V9341XS'  /*Struck by falling object on passenger ship, sequela*/
,'V9342XA'  /*Struck by falling object on fishing boat, initial encounter*/
,'V9342XD'  /*Struck by falling object on fishing boat, subsequent encounter*/
,'V9342XS'  /*Struck by falling object on fishing boat, sequela*/
,'V9343XA'  /*Struck by falling object on other powered watercraft, initial encounter*/
,'V9343XD'  /*Struck by falling object on other powered watercraft, subsequent encounter*/
,'V9343XS'  /*Struck by falling object on other powered watercraft, sequela*/
,'V9344XA'  /*Struck by falling object on sailboat, initial encounter*/
,'V9344XD'  /*Struck by falling object on sailboat, subsequent encounter*/
,'V9344XS'  /*Struck by falling object on sailboat, sequela*/
,'V9348XA'  /*Struck by falling object on other unpowered watercraft, initial encounter*/
,'V9348XD'  /*Struck by falling object on other unpowered watercraft, subsequent encounter*/
,'V9348XS'  /*Struck by falling object on other unpowered watercraft, sequela*/
,'V9349XA'  /*Struck by falling object on unspecified watercraft, initial encounter*/
,'V9349XD'  /*Struck by falling object on unspecified watercraft, subsequent encounter*/
,'V9349XS'  /*Struck by falling object on unspecified watercraft, sequela*/
,'V9350XA'  /*Explosion on board merchant ship, initial encounter*/
,'V9350XD'  /*Explosion on board merchant ship, subsequent encounter*/
,'V9350XS'  /*Explosion on board merchant ship, sequela*/
,'V9351XA'  /*Explosion on board passenger ship, initial encounter*/
,'V9351XD'  /*Explosion on board passenger ship, subsequent encounter*/
,'V9351XS'  /*Explosion on board passenger ship, sequela*/
,'V9352XA'  /*Explosion on board fishing boat, initial encounter*/
,'V9352XD'  /*Explosion on board fishing boat, subsequent encounter*/
,'V9352XS'  /*Explosion on board fishing boat, sequela*/
,'V9353XA'  /*Explosion on board other powered watercraft, initial encounter*/
,'V9353XD'  /*Explosion on board other powered watercraft, subsequent encounter*/
,'V9353XS'  /*Explosion on board other powered watercraft, sequela*/
,'V9354XA'  /*Explosion on board sailboat, initial encounter*/
,'V9354XD'  /*Explosion on board sailboat, subsequent encounter*/
,'V9354XS'  /*Explosion on board sailboat, sequela*/
,'V9359XA'  /*Explosion on board unspecified watercraft, initial encounter*/
,'V9359XD'  /*Explosion on board unspecified watercraft, subsequent encounter*/
,'V9359XS'  /*Explosion on board unspecified watercraft, sequela*/
,'V9360XA'  /*Machinery accident on board merchant ship, initial encounter*/
,'V9360XD'  /*Machinery accident on board merchant ship, subsequent encounter*/
,'V9360XS'  /*Machinery accident on board merchant ship, sequela*/
,'V9361XA'  /*Machinery accident on board passenger ship, initial encounter*/
,'V9361XD'  /*Machinery accident on board passenger ship, subsequent encounter*/
,'V9361XS'  /*Machinery accident on board passenger ship, sequela*/
,'V9362XA'  /*Machinery accident on board fishing boat, initial encounter*/
,'V9362XD'  /*Machinery accident on board fishing boat, subsequent encounter*/
,'V9362XS'  /*Machinery accident on board fishing boat, sequela*/
,'V9363XA'  /*Machinery accident on board other powered watercraft, initial encounter*/
,'V9363XD'  /*Machinery accident on board other powered watercraft, subsequent encounter*/
,'V9363XS'  /*Machinery accident on board other powered watercraft, sequela*/
,'V9364XA'  /*Machinery accident on board sailboat, initial encounter*/
,'V9364XD'  /*Machinery accident on board sailboat, subsequent encounter*/
,'V9364XS'  /*Machinery accident on board sailboat, sequela*/
,'V9369XA'  /*Machinery accident on board unspecified watercraft, initial encounter*/
,'V9369XD'  /*Machinery accident on board unspecified watercraft, subsequent encounter*/
,'V9369XS'  /*Machinery accident on board unspecified watercraft, sequela*/
,'V9380XA'  /*Other injury due to other accident on board merchant ship, initial encounter*/
,'V9380XD'  /*Other injury due to other accident on board merchant ship, subsequent encounter*/
,'V9380XS'  /*Other injury due to other accident on board merchant ship, sequela*/
,'V9381XA'  /*Other injury due to other accident on board passenger ship, initial encounter*/
,'V9381XD'  /*Other injury due to other accident on board passenger ship, subsequent encounter*/
,'V9381XS'  /*Other injury due to other accident on board passenger ship, sequela*/
,'V9382XA'  /*Other injury due to other accident on board fishing boat, initial encounter*/
,'V9382XD'  /*Other injury due to other accident on board fishing boat, subsequent encounter*/
,'V9382XS'  /*Other injury due to other accident on board fishing boat, sequela*/
,'V9383XA'  /*Other injury due to other accident on board other powered watercraft, initial encounter*/
,'V9383XD'  /*Other injury due to other accident on board other powered watercraft, subsequent encounter*/
,'V9383XS'  /*Other injury due to other accident on board other powered watercraft, sequela*/
,'V9384XA'  /*Other injury due to other accident on board sailboat, initial encounter*/
,'V9384XD'  /*Other injury due to other accident on board sailboat, subsequent encounter*/
,'V9384XS'  /*Other injury due to other accident on board sailboat, sequela*/
,'V9385XA'  /*Other injury due to other accident on board canoe or kayak, initial encounter*/
,'V9385XD'  /*Other injury due to other accident on board canoe or kayak, subsequent encounter*/
,'V9385XS'  /*Other injury due to other accident on board canoe or kayak, sequela*/
,'V9386XA'  /*Other injury due to other accident on board (nonpowered) inflatable craft, initial encounter*/
,'V9386XD'  /*Other injury due to other accident on board (nonpowered) inflatable craft, subsequent encounter*/
,'V9386XS'  /*Other injury due to other accident on board (nonpowered) inflatable craft, sequela*/
,'V9387XA'  /*Other injury due to other accident on board water-skis, initial encounter*/
,'V9387XD'  /*Other injury due to other accident on board water-skis, subsequent encounter*/
,'V9387XS'  /*Other injury due to other accident on board water-skis, sequela*/
,'V9388XA'  /*Other injury due to other accident on board other unpowered watercraft, initial encounter*/
,'V9388XD'  /*Other injury due to other accident on board other unpowered watercraft, subsequent encounter*/
,'V9388XS'  /*Other injury due to other accident on board other unpowered watercraft, sequela*/
,'V9389XA'  /*Other injury due to other accident on board unspecified watercraft, initial encounter*/
,'V9389XD'  /*Other injury due to other accident on board unspecified watercraft, subsequent encounter*/
,'V9389XS'  /*Other injury due to other accident on board unspecified watercraft, sequela*/
,'V940XXA'  /*Hitting object or bottom of body of water due to fall from watercraft, initial encounter*/
,'V940XXD'  /*Hitting object or bottom of body of water due to fall from watercraft, subsequent encounter*/
,'V940XXS'  /*Hitting object or bottom of body of water due to fall from watercraft, sequela*/
,'V9411XA'  /*Bather struck by powered watercraft, initial encounter*/
,'V9411XD'  /*Bather struck by powered watercraft, subsequent encounter*/
,'V9411XS'  /*Bather struck by powered watercraft, sequela*/
,'V9412XA'  /*Bather struck by nonpowered watercraft, initial encounter*/
,'V9412XD'  /*Bather struck by nonpowered watercraft, subsequent encounter*/
,'V9412XS'  /*Bather struck by nonpowered watercraft, sequela*/
,'V9421XA'  /*Rider of nonpowered watercraft struck by other nonpowered watercraft, initial encounter*/
,'V9421XD'  /*Rider of nonpowered watercraft struck by other nonpowered watercraft, subsequent encounter*/
,'V9421XS'  /*Rider of nonpowered watercraft struck by other nonpowered watercraft, sequela*/
,'V9422XA'  /*Rider of nonpowered watercraft struck by powered watercraft, initial encounter*/
,'V9422XD'  /*Rider of nonpowered watercraft struck by powered watercraft, subsequent encounter*/
,'V9422XS'  /*Rider of nonpowered watercraft struck by powered watercraft, sequela*/
,'V9431XA'  /*Injury to rider of (inflatable) recreational watercraft being pulled behind other watercraft, initial encounter*/
,'V9431XD'  /*Injury to rider of (inflatable) recreational watercraft being pulled behind other watercraft, subsequent encounter*/
,'V9431XS'  /*Injury to rider of (inflatable) recreational watercraft being pulled behind other watercraft, sequela*/
,'V9432XA'  /*Injury to rider of non-recreational watercraft being pulled behind other watercraft, initial encounter*/
,'V9432XD'  /*Injury to rider of non-recreational watercraft being pulled behind other watercraft, subsequent encounter*/
,'V9432XS'  /*Injury to rider of non-recreational watercraft being pulled behind other watercraft, sequela*/
,'V944XXA'  /*Injury to barefoot water-skier, initial encounter*/
,'V944XXD'  /*Injury to barefoot water-skier, subsequent encounter*/
,'V944XXS'  /*Injury to barefoot water-skier, sequela*/
,'V94810A'  /*Civilian watercraft involved in water transport accident with military watercraft, initial encounter*/
,'V94810D'  /*Civilian watercraft involved in water transport accident with military watercraft, subsequent encounter*/
,'V94810S'  /*Civilian watercraft involved in water transport accident with military watercraft, sequela*/
,'V94811A'  /*Civilian in water injured by military watercraft, initial encounter*/
,'V94811D'  /*Civilian in water injured by military watercraft, subsequent encounter*/
,'V94811S'  /*Civilian in water injured by military watercraft, sequela*/
,'V94818A'  /*Other water transport accident involving military watercraft, initial encounter*/
,'V94818D'  /*Other water transport accident involving military watercraft, subsequent encounter*/
,'V94818S'  /*Other water transport accident involving military watercraft, sequela*/
,'V9489XA'  /*Other water transport accident, initial encounter*/
,'V9489XD'  /*Other water transport accident, subsequent encounter*/
,'V9489XS'  /*Other water transport accident, sequela*/
,'V949XXA'  /*Unspecified water transport accident, initial encounter*/
,'V949XXD'  /*Unspecified water transport accident, subsequent encounter*/
,'V949XXS'  /*Unspecified water transport accident, sequela*/
,'V9500XA'  /*Unspecified helicopter accident injuring occupant, initial encounter*/
,'V9500XD'  /*Unspecified helicopter accident injuring occupant, subsequent encounter*/
,'V9500XS'  /*Unspecified helicopter accident injuring occupant, sequela*/
,'V9501XA'  /*Helicopter crash injuring occupant, initial encounter*/
,'V9501XD'  /*Helicopter crash injuring occupant, subsequent encounter*/
,'V9501XS'  /*Helicopter crash injuring occupant, sequela*/
,'V9502XA'  /*Forced landing of helicopter injuring occupant, initial encounter*/
,'V9502XD'  /*Forced landing of helicopter injuring occupant, subsequent encounter*/
,'V9502XS'  /*Forced landing of helicopter injuring occupant, sequela*/
,'V9503XA'  /*Helicopter collision injuring occupant, initial encounter*/
,'V9503XD'  /*Helicopter collision injuring occupant, subsequent encounter*/
,'V9503XS'  /*Helicopter collision injuring occupant, sequela*/
,'V9504XA'  /*Helicopter fire injuring occupant, initial encounter*/
,'V9504XD'  /*Helicopter fire injuring occupant, subsequent encounter*/
,'V9504XS'  /*Helicopter fire injuring occupant, sequela*/
,'V9505XA'  /*Helicopter explosion injuring occupant, initial encounter*/
,'V9505XD'  /*Helicopter explosion injuring occupant, subsequent encounter*/
,'V9505XS'  /*Helicopter explosion injuring occupant, sequela*/
,'V9509XA'  /*Other helicopter accident injuring occupant, initial encounter*/
,'V9509XD'  /*Other helicopter accident injuring occupant, subsequent encounter*/
,'V9509XS'  /*Other helicopter accident injuring occupant, sequela*/
,'V9510XA'  /*Unspecified ultralight, microlight or powered-glider accident injuring occupant, initial encounter*/
,'V9510XD'  /*Unspecified ultralight, microlight or powered-glider accident injuring occupant, subsequent encounter*/
,'V9510XS'  /*Unspecified ultralight, microlight or powered-glider accident injuring occupant, sequela*/
,'V9511XA'  /*Ultralight, microlight or powered-glider crash injuring occupant, initial encounter*/
,'V9511XD'  /*Ultralight, microlight or powered-glider crash injuring occupant, subsequent encounter*/
,'V9511XS'  /*Ultralight, microlight or powered-glider crash injuring occupant, sequela*/
,'V9512XA'  /*Forced landing of ultralight, microlight or powered-glider injuring occupant, initial encounter*/
,'V9512XD'  /*Forced landing of ultralight, microlight or powered-glider injuring occupant, subsequent encounter*/
,'V9512XS'  /*Forced landing of ultralight, microlight or powered-glider injuring occupant, sequela*/
,'V9513XA'  /*Ultralight, microlight or powered-glider collision injuring occupant, initial encounter*/
,'V9513XD'  /*Ultralight, microlight or powered-glider collision injuring occupant, subsequent encounter*/
,'V9513XS'  /*Ultralight, microlight or powered-glider collision injuring occupant, sequela*/
,'V9514XA'  /*Ultralight, microlight or powered-glider fire injuring occupant, initial encounter*/
,'V9514XD'  /*Ultralight, microlight or powered-glider fire injuring occupant, subsequent encounter*/
,'V9514XS'  /*Ultralight, microlight or powered-glider fire injuring occupant, sequela*/
,'V9515XA'  /*Ultralight, microlight or powered-glider explosion injuring occupant, initial encounter*/
,'V9515XD'  /*Ultralight, microlight or powered-glider explosion injuring occupant, subsequent encounter*/
,'V9515XS'  /*Ultralight, microlight or powered-glider explosion injuring occupant, sequela*/
,'V9519XA'  /*Other ultralight, microlight or powered-glider accident injuring occupant, initial encounter*/
,'V9519XD'  /*Other ultralight, microlight or powered-glider accident injuring occupant, subsequent encounter*/
,'V9519XS'  /*Other ultralight, microlight or powered-glider accident injuring occupant, sequela*/
,'V9520XA'  /*Unspecified accident to other private fixed-wing aircraft, injuring occupant, initial encounter*/
,'V9520XD'  /*Unspecified accident to other private fixed-wing aircraft, injuring occupant, subsequent encounter*/
,'V9520XS'  /*Unspecified accident to other private fixed-wing aircraft, injuring occupant, sequela*/
,'V9521XA'  /*Other private fixed-wing aircraft crash injuring occupant, initial encounter*/
,'V9521XD'  /*Other private fixed-wing aircraft crash injuring occupant, subsequent encounter*/
,'V9521XS'  /*Other private fixed-wing aircraft crash injuring occupant, sequela*/
,'V9522XA'  /*Forced landing of other private fixed-wing aircraft injuring occupant, initial encounter*/
,'V9522XD'  /*Forced landing of other private fixed-wing aircraft injuring occupant, subsequent encounter*/
,'V9522XS'  /*Forced landing of other private fixed-wing aircraft injuring occupant, sequela*/
,'V9523XA'  /*Other private fixed-wing aircraft collision injuring occupant, initial encounter*/
,'V9523XD'  /*Other private fixed-wing aircraft collision injuring occupant, subsequent encounter*/
,'V9523XS'  /*Other private fixed-wing aircraft collision injuring occupant, sequela*/
,'V9524XA'  /*Other private fixed-wing aircraft fire injuring occupant, initial encounter*/
,'V9524XD'  /*Other private fixed-wing aircraft fire injuring occupant, subsequent encounter*/
,'V9524XS'  /*Other private fixed-wing aircraft fire injuring occupant, sequela*/
,'V9525XA'  /*Other private fixed-wing aircraft explosion injuring occupant, initial encounter*/
,'V9525XD'  /*Other private fixed-wing aircraft explosion injuring occupant, subsequent encounter*/
,'V9525XS'  /*Other private fixed-wing aircraft explosion injuring occupant, sequela*/
,'V9529XA'  /*Other accident to other private fixed-wing aircraft injuring occupant, initial encounter*/
,'V9529XD'  /*Other accident to other private fixed-wing aircraft injuring occupant, subsequent encounter*/
,'V9529XS'  /*Other accident to other private fixed-wing aircraft injuring occupant, sequela*/
,'V9530XA'  /*Unspecified accident to commercial fixed-wing aircraft injuring occupant, initial encounter*/
,'V9530XD'  /*Unspecified accident to commercial fixed-wing aircraft injuring occupant, subsequent encounter*/
,'V9530XS'  /*Unspecified accident to commercial fixed-wing aircraft injuring occupant, sequela*/
,'V9531XA'  /*Commercial fixed-wing aircraft crash injuring occupant, initial encounter*/
,'V9531XD'  /*Commercial fixed-wing aircraft crash injuring occupant, subsequent encounter*/
,'V9531XS'  /*Commercial fixed-wing aircraft crash injuring occupant, sequela*/
,'V9532XA'  /*Forced landing of commercial fixed-wing aircraft injuring occupant, initial encounter*/
,'V9532XD'  /*Forced landing of commercial fixed-wing aircraft injuring occupant, subsequent encounter*/
,'V9532XS'  /*Forced landing of commercial fixed-wing aircraft injuring occupant, sequela*/
,'V9533XA'  /*Commercial fixed-wing aircraft collision injuring occupant, initial encounter*/
,'V9533XD'  /*Commercial fixed-wing aircraft collision injuring occupant, subsequent encounter*/
,'V9533XS'  /*Commercial fixed-wing aircraft collision injuring occupant, sequela*/
,'V9534XA'  /*Commercial fixed-wing aircraft fire injuring occupant, initial encounter*/
,'V9534XD'  /*Commercial fixed-wing aircraft fire injuring occupant, subsequent encounter*/
,'V9534XS'  /*Commercial fixed-wing aircraft fire injuring occupant, sequela*/
,'V9535XA'  /*Commercial fixed-wing aircraft explosion injuring occupant, initial encounter*/
,'V9535XD'  /*Commercial fixed-wing aircraft explosion injuring occupant, subsequent encounter*/
,'V9535XS'  /*Commercial fixed-wing aircraft explosion injuring occupant, sequela*/
,'V9539XA'  /*Other accident to commercial fixed-wing aircraft injuring occupant, initial encounter*/
,'V9539XD'  /*Other accident to commercial fixed-wing aircraft injuring occupant, subsequent encounter*/
,'V9539XS'  /*Other accident to commercial fixed-wing aircraft injuring occupant, sequela*/
,'V9540XA'  /*Unspecified spacecraft accident injuring occupant, initial encounter*/
,'V9540XD'  /*Unspecified spacecraft accident injuring occupant, subsequent encounter*/
,'V9540XS'  /*Unspecified spacecraft accident injuring occupant, sequela*/
,'V9541XA'  /*Spacecraft crash injuring occupant, initial encounter*/
,'V9541XD'  /*Spacecraft crash injuring occupant, subsequent encounter*/
,'V9541XS'  /*Spacecraft crash injuring occupant, sequela*/
,'V9542XA'  /*Forced landing of spacecraft injuring occupant, initial encounter*/
,'V9542XD'  /*Forced landing of spacecraft injuring occupant, subsequent encounter*/
,'V9542XS'  /*Forced landing of spacecraft injuring occupant, sequela*/
,'V9543XA'  /*Spacecraft collision injuring occupant, initial encounter*/
,'V9543XD'  /*Spacecraft collision injuring occupant, subsequent encounter*/
,'V9543XS'  /*Spacecraft collision injuring occupant, sequela*/
,'V9544XA'  /*Spacecraft fire injuring occupant, initial encounter*/
,'V9544XD'  /*Spacecraft fire injuring occupant, subsequent encounter*/
,'V9544XS'  /*Spacecraft fire injuring occupant, sequela*/
,'V9545XA'  /*Spacecraft explosion injuring occupant, initial encounter*/
,'V9545XD'  /*Spacecraft explosion injuring occupant, subsequent encounter*/
,'V9545XS'  /*Spacecraft explosion injuring occupant, sequela*/
,'V9549XA'  /*Other spacecraft accident injuring occupant, initial encounter*/
,'V9549XD'  /*Other spacecraft accident injuring occupant, subsequent encounter*/
,'V9549XS'  /*Other spacecraft accident injuring occupant, sequela*/
,'V958XXA'  /*Other powered aircraft accidents injuring occupant, initial encounter*/
,'V958XXD'  /*Other powered aircraft accidents injuring occupant, subsequent encounter*/
,'V958XXS'  /*Other powered aircraft accidents injuring occupant, sequela*/
,'V959XXA'  /*Unspecified aircraft accident injuring occupant, initial encounter*/
,'V959XXD'  /*Unspecified aircraft accident injuring occupant, subsequent encounter*/
,'V959XXS'  /*Unspecified aircraft accident injuring occupant, sequela*/
,'V9600XA'  /*Unspecified balloon accident injuring occupant, initial encounter*/
,'V9600XD'  /*Unspecified balloon accident injuring occupant, subsequent encounter*/
,'V9600XS'  /*Unspecified balloon accident injuring occupant, sequela*/
,'V9601XA'  /*Balloon crash injuring occupant, initial encounter*/
,'V9601XD'  /*Balloon crash injuring occupant, subsequent encounter*/
,'V9601XS'  /*Balloon crash injuring occupant, sequela*/
,'V9602XA'  /*Forced landing of balloon injuring occupant, initial encounter*/
,'V9602XD'  /*Forced landing of balloon injuring occupant, subsequent encounter*/
,'V9602XS'  /*Forced landing of balloon injuring occupant, sequela*/
,'V9603XA'  /*Balloon collision injuring occupant, initial encounter*/
,'V9603XD'  /*Balloon collision injuring occupant, subsequent encounter*/
,'V9603XS'  /*Balloon collision injuring occupant, sequela*/
,'V9604XA'  /*Balloon fire injuring occupant, initial encounter*/
,'V9604XD'  /*Balloon fire injuring occupant, subsequent encounter*/
,'V9604XS'  /*Balloon fire injuring occupant, sequela*/
,'V9605XA'  /*Balloon explosion injuring occupant, initial encounter*/
,'V9605XD'  /*Balloon explosion injuring occupant, subsequent encounter*/
,'V9605XS'  /*Balloon explosion injuring occupant, sequela*/
,'V9609XA'  /*Other balloon accident injuring occupant, initial encounter*/
,'V9609XD'  /*Other balloon accident injuring occupant, subsequent encounter*/
,'V9609XS'  /*Other balloon accident injuring occupant, sequela*/
,'V9610XA'  /*Unspecified hang-glider accident injuring occupant, initial encounter*/
,'V9610XD'  /*Unspecified hang-glider accident injuring occupant, subsequent encounter*/
,'V9610XS'  /*Unspecified hang-glider accident injuring occupant, sequela*/
,'V9611XA'  /*Hang-glider crash injuring occupant, initial encounter*/
,'V9611XD'  /*Hang-glider crash injuring occupant, subsequent encounter*/
,'V9611XS'  /*Hang-glider crash injuring occupant, sequela*/
,'V9612XA'  /*Forced landing of hang-glider injuring occupant, initial encounter*/
,'V9612XD'  /*Forced landing of hang-glider injuring occupant, subsequent encounter*/
,'V9612XS'  /*Forced landing of hang-glider injuring occupant, sequela*/
,'V9613XA'  /*Hang-glider collision injuring occupant, initial encounter*/
,'V9613XD'  /*Hang-glider collision injuring occupant, subsequent encounter*/
,'V9613XS'  /*Hang-glider collision injuring occupant, sequela*/
,'V9614XA'  /*Hang-glider fire injuring occupant, initial encounter*/
,'V9614XD'  /*Hang-glider fire injuring occupant, subsequent encounter*/
,'V9614XS'  /*Hang-glider fire injuring occupant, sequela*/
,'V9615XA'  /*Hang-glider explosion injuring occupant, initial encounter*/
,'V9615XD'  /*Hang-glider explosion injuring occupant, subsequent encounter*/
,'V9615XS'  /*Hang-glider explosion injuring occupant, sequela*/
,'V9619XA'  /*Other hang-glider accident injuring occupant, initial encounter*/
,'V9619XD'  /*Other hang-glider accident injuring occupant, subsequent encounter*/
,'V9619XS'  /*Other hang-glider accident injuring occupant, sequela*/
,'V9620XA'  /*Unspecified glider (nonpowered) accident injuring occupant, initial encounter*/
,'V9620XD'  /*Unspecified glider (nonpowered) accident injuring occupant, subsequent encounter*/
,'V9620XS'  /*Unspecified glider (nonpowered) accident injuring occupant, sequela*/
,'V9621XA'  /*Glider (nonpowered) crash injuring occupant, initial encounter*/
,'V9621XD'  /*Glider (nonpowered) crash injuring occupant, subsequent encounter*/
,'V9621XS'  /*Glider (nonpowered) crash injuring occupant, sequela*/
,'V9622XA'  /*Forced landing of glider (nonpowered) injuring occupant, initial encounter*/
,'V9622XD'  /*Forced landing of glider (nonpowered) injuring occupant, subsequent encounter*/
,'V9622XS'  /*Forced landing of glider (nonpowered) injuring occupant, sequela*/
,'V9623XA'  /*Glider (nonpowered) collision injuring occupant, initial encounter*/
,'V9623XD'  /*Glider (nonpowered) collision injuring occupant, subsequent encounter*/
,'V9623XS'  /*Glider (nonpowered) collision injuring occupant, sequela*/
,'V9624XA'  /*Glider (nonpowered) fire injuring occupant, initial encounter*/
,'V9624XD'  /*Glider (nonpowered) fire injuring occupant, subsequent encounter*/
,'V9624XS'  /*Glider (nonpowered) fire injuring occupant, sequela*/
,'V9625XA'  /*Glider (nonpowered) explosion injuring occupant, initial encounter*/
,'V9625XD'  /*Glider (nonpowered) explosion injuring occupant, subsequent encounter*/
,'V9625XS'  /*Glider (nonpowered) explosion injuring occupant, sequela*/
,'V9629XA'  /*Other glider (nonpowered) accident injuring occupant, initial encounter*/
,'V9629XD'  /*Other glider (nonpowered) accident injuring occupant, subsequent encounter*/
,'V9629XS'  /*Other glider (nonpowered) accident injuring occupant, sequela*/
,'V968XXA'  /*Other nonpowered-aircraft accidents injuring occupant, initial encounter*/
,'V968XXD'  /*Other nonpowered-aircraft accidents injuring occupant, subsequent encounter*/
,'V968XXS'  /*Other nonpowered-aircraft accidents injuring occupant, sequela*/
,'V969XXA'  /*Unspecified nonpowered-aircraft accident injuring occupant, initial encounter*/
,'V969XXD'  /*Unspecified nonpowered-aircraft accident injuring occupant, subsequent encounter*/
,'V969XXS'  /*Unspecified nonpowered-aircraft accident injuring occupant, sequela*/
,'V970XXA'  /*Occupant of aircraft injured in other specified air transport accidents, initial encounter*/
,'V970XXD'  /*Occupant of aircraft injured in other specified air transport accidents, subsequent encounter*/
,'V970XXS'  /*Occupant of aircraft injured in other specified air transport accidents, sequela*/
,'V971XXA'  /*Person injured while boarding or alighting from aircraft, initial encounter*/
,'V971XXD'  /*Person injured while boarding or alighting from aircraft, subsequent encounter*/
,'V971XXS'  /*Person injured while boarding or alighting from aircraft, sequela*/
,'V9721XA'  /*Parachutist entangled in object, initial encounter*/
,'V9721XD'  /*Parachutist entangled in object, subsequent encounter*/
,'V9721XS'  /*Parachutist entangled in object, sequela*/
,'V9722XA'  /*Parachutist injured on landing, initial encounter*/
,'V9722XD'  /*Parachutist injured on landing, subsequent encounter*/
,'V9722XS'  /*Parachutist injured on landing, sequela*/
,'V9729XA'  /*Other parachutist accident, initial encounter*/
,'V9729XD'  /*Other parachutist accident, subsequent encounter*/
,'V9729XS'  /*Other parachutist accident, sequela*/
,'V9731XA'  /*Hit by object falling from aircraft, initial encounter*/
,'V9731XD'  /*Hit by object falling from aircraft, subsequent encounter*/
,'V9731XS'  /*Hit by object falling from aircraft, sequela*/
,'V9732XA'  /*Injured by rotating propeller, initial encounter*/
,'V9732XD'  /*Injured by rotating propeller, subsequent encounter*/
,'V9732XS'  /*Injured by rotating propeller, sequela*/
,'V9733XA'  /*Sucked into jet engine, initial encounter*/
,'V9733XD'  /*Sucked into jet engine, subsequent encounter*/
,'V9733XS'  /*Sucked into jet engine, sequela*/
,'V9739XA'  /*Other injury to person on ground due to air transport accident, initial encounter*/
,'V9739XD'  /*Other injury to person on ground due to air transport accident, subsequent encounter*/
,'V9739XS'  /*Other injury to person on ground due to air transport accident, sequela*/
,'V97810A'  /*Civilian aircraft involved in air transport accident with military aircraft, initial encounter*/
,'V97810D'  /*Civilian aircraft involved in air transport accident with military aircraft, subsequent encounter*/
,'V97810S'  /*Civilian aircraft involved in air transport accident with military aircraft, sequela*/
,'V97811A'  /*Civilian injured by military aircraft, initial encounter*/
,'V97811D'  /*Civilian injured by military aircraft, subsequent encounter*/
,'V97811S'  /*Civilian injured by military aircraft, sequela*/
,'V97818A'  /*Other air transport accident involving military aircraft, initial encounter*/
,'V97818D'  /*Other air transport accident involving military aircraft, subsequent encounter*/
,'V97818S'  /*Other air transport accident involving military aircraft, sequela*/
,'V9789XA'  /*Other air transport accidents, not elsewhere classified, initial encounter*/
,'V9789XD'  /*Other air transport accidents, not elsewhere classified, subsequent encounter*/
,'V9789XS'  /*Other air transport accidents, not elsewhere classified, sequela*/
,'V980XXA'  /*Accident to, on or involving cable-car, not on rails, initial encounter*/
,'V980XXD'  /*Accident to, on or involving cable-car, not on rails, subsequent encounter*/
,'V980XXS'  /*Accident to, on or involving cable-car, not on rails, sequela*/
,'V981XXA'  /*Accident to, on or involving land-yacht, initial encounter*/
,'V981XXD'  /*Accident to, on or involving land-yacht, subsequent encounter*/
,'V981XXS'  /*Accident to, on or involving land-yacht, sequela*/
,'V982XXA'  /*Accident to, on or involving ice yacht, initial encounter*/
,'V982XXD'  /*Accident to, on or involving ice yacht, subsequent encounter*/
,'V982XXS'  /*Accident to, on or involving ice yacht, sequela*/
,'V983XXA'  /*Accident to, on or involving ski lift, initial encounter*/
,'V983XXD'  /*Accident to, on or involving ski lift, subsequent encounter*/
,'V983XXS'  /*Accident to, on or involving ski lift, sequela*/
,'V988XXA'  /*Other specified transport accidents, initial encounter*/
,'V988XXD'  /*Other specified transport accidents, subsequent encounter*/
,'V988XXS'  /*Other specified transport accidents, sequela*/
,'V99XXXA'  /*Unspecified transport accident, initial encounter*/
,'V99XXXD'  /*Unspecified transport accident, subsequent encounter*/
,'V99XXXS'  /*Unspecified transport accident, sequela*/
,'W090XXD'  /*Fall on or from playground slide, subsequent encounter*/
,'W090XXS'  /*Fall on or from playground slide, sequela*/
,'W091XXD'  /*Fall from playground swing, subsequent encounter*/
,'W091XXS'  /*Fall from playground swing, sequela*/
,'W092XXD'  /*Fall on or from jungle gym, subsequent encounter*/
,'W092XXS'  /*Fall on or from jungle gym, sequela*/
,'W098XXD'  /*Fall on or from other playground equipment, subsequent encounter*/
,'W098XXS'  /*Fall on or from other playground equipment, sequela*/
,'W14XXXA'  /*Fall from tree, initial encounter*/
,'W14XXXD'  /*Fall from tree, subsequent encounter*/
,'W14XXXS'  /*Fall from tree, sequela*/
,'W15XXXA'  /*Fall from cliff, initial encounter*/
,'W15XXXD'  /*Fall from cliff, subsequent encounter*/
,'W15XXXS'  /*Fall from cliff, sequela*/
,'W16011D'  /*Fall into swimming pool striking water surface causing drowning and submersion, subsequent encounter*/
,'W16011S'  /*Fall into swimming pool striking water surface causing drowning and submersion, sequela*/
,'W16012D'  /*Fall into swimming pool striking water surface causing other injury, subsequent encounter*/
,'W16012S'  /*Fall into swimming pool striking water surface causing other injury, sequela*/
,'W16021D'  /*Fall into swimming pool striking bottom causing drowning and submersion, subsequent encounter*/
,'W16021S'  /*Fall into swimming pool striking bottom causing drowning and submersion, sequela*/
,'W16022D'  /*Fall into swimming pool striking bottom causing other injury, subsequent encounter*/
,'W16022S'  /*Fall into swimming pool striking bottom causing other injury, sequela*/
,'W16031D'  /*Fall into swimming pool striking wall causing drowning and submersion, subsequent encounter*/
,'W16031S'  /*Fall into swimming pool striking wall causing drowning and submersion, sequela*/
,'W16032D'  /*Fall into swimming pool striking wall causing other injury, subsequent encounter*/
,'W16032S'  /*Fall into swimming pool striking wall causing other injury, sequela*/
,'W16111D'  /*Fall into natural body of water striking water surface causing drowning and submersion, subsequent encounter*/
,'W16111S'  /*Fall into natural body of water striking water surface causing drowning and submersion, sequela*/
,'W16112D'  /*Fall into natural body of water striking water surface causing other injury, subsequent encounter*/
,'W16112S'  /*Fall into natural body of water striking water surface causing other injury, sequela*/
,'W16121D'  /*Fall into natural body of water striking bottom causing drowning and submersion, subsequent encounter*/
,'W16121S'  /*Fall into natural body of water striking bottom causing drowning and submersion, sequela*/
,'W16122D'  /*Fall into natural body of water striking bottom causing other injury, subsequent encounter*/
,'W16122S'  /*Fall into natural body of water striking bottom causing other injury, sequela*/
,'W16131D'  /*Fall into natural body of water striking side causing drowning and submersion, subsequent encounter*/
,'W16131S'  /*Fall into natural body of water striking side causing drowning and submersion, sequela*/
,'W16132D'  /*Fall into natural body of water striking side causing other injury, subsequent encounter*/
,'W16132S'  /*Fall into natural body of water striking side causing other injury, sequela*/
,'W16211D'  /*Fall in (into) filled bathtub causing drowning and submersion, subsequent encounter*/
,'W16211S'  /*Fall in (into) filled bathtub causing drowning and submersion, sequela*/
,'W16212D'  /*Fall in (into) filled bathtub causing other injury, subsequent encounter*/
,'W16212S'  /*Fall in (into) filled bathtub causing other injury, sequela*/
,'W16221D'  /*Fall in (into) bucket of water causing drowning and submersion, subsequent encounter*/
,'W16221S'  /*Fall in (into) bucket of water causing drowning and submersion, sequela*/
,'W16222D'  /*Fall in (into) bucket of water causing other injury, subsequent encounter*/
,'W16222S'  /*Fall in (into) bucket of water causing other injury, sequela*/
,'W16311D'  /*Fall into other water striking water surface causing drowning and submersion, subsequent encounter*/
,'W16311S'  /*Fall into other water striking water surface causing drowning and submersion, sequela*/
,'W16312D'  /*Fall into other water striking water surface causing other injury, subsequent encounter*/
,'W16312S'  /*Fall into other water striking water surface causing other injury, sequela*/
,'W16321D'  /*Fall into other water striking bottom causing drowning and submersion, subsequent encounter*/
,'W16321S'  /*Fall into other water striking bottom causing drowning and submersion, sequela*/
,'W16322S'  /*Fall into other water striking bottom causing other injury, sequela*/
,'W16331D'  /*Fall into other water striking wall causing drowning and submersion, subsequent encounter*/
,'W16331S'  /*Fall into other water striking wall causing drowning and submersion, sequela*/
,'W16332D'  /*Fall into other water striking wall causing other injury, subsequent encounter*/
,'W16332S'  /*Fall into other water striking wall causing other injury, sequela*/
,'W1641XD'  /*Fall into unspecified water causing drowning and submersion, subsequent encounter*/
,'W1641XS'  /*Fall into unspecified water causing drowning and submersion, sequela*/
,'W1642XD'  /*Fall into unspecified water causing other injury, subsequent encounter*/
,'W1642XS'  /*Fall into unspecified water causing other injury, sequela*/
,'W16511D'  /*Jumping or diving into swimming pool striking water surface causing drowning and submersion, subsequent encounter*/
,'W16511S'  /*Jumping or diving into swimming pool striking water surface causing drowning and submersion, sequela*/
,'W16512D'  /*Jumping or diving into swimming pool striking water surface causing other injury, subsequent encounter*/
,'W16512S'  /*Jumping or diving into swimming pool striking water surface causing other injury, sequela*/
,'W16521D'  /*Jumping or diving into swimming pool striking bottom causing drowning and submersion, subsequent encounter*/
,'W16521S'  /*Jumping or diving into swimming pool striking bottom causing drowning and submersion, sequela*/
,'W16522D'  /*Jumping or diving into swimming pool striking bottom causing other injury, subsequent encounter*/
,'W16522S'  /*Jumping or diving into swimming pool striking bottom causing other injury, sequela*/
,'W16531D'  /*Jumping or diving into swimming pool striking wall causing drowning and submersion, subsequent encounter*/
,'W16531S'  /*Jumping or diving into swimming pool striking wall causing drowning and submersion, sequela*/
,'W16532D'  /*Jumping or diving into swimming pool striking wall causing other injury, subsequent encounter*/
,'W16532S'  /*Jumping or diving into swimming pool striking wall causing other injury, sequela*/
,'W16611D'  /*Jumping or diving into natural body of water striking water surface causing drowning and submersion, subsequent encounter*/
,'W16611S'  /*Jumping or diving into natural body of water striking water surface causing drowning and submersion, sequela*/
,'W16612D'  /*Jumping or diving into natural body of water striking water surface causing other injury, subsequent encounter*/
,'W16612S'  /*Jumping or diving into natural body of water striking water surface causing other injury, sequela*/
,'W16621D'  /*Jumping or diving into natural body of water striking bottom causing drowning and submersion, subsequent encounter*/
,'W16621S'  /*Jumping or diving into natural body of water striking bottom causing drowning and submersion, sequela*/
,'W16622D'  /*Jumping or diving into natural body of water striking bottom causing other injury, subsequent encounter*/
,'W16622S'  /*Jumping or diving into natural body of water striking bottom causing other injury, sequela*/
,'W16711A'  /*Jumping or diving from boat striking water surface causing drowning and submersion, initial encounter*/
,'W16711D'  /*Jumping or diving from boat striking water surface causing drowning and submersion, subsequent encounter*/
,'W16711S'  /*Jumping or diving from boat striking water surface causing drowning and submersion, sequela*/
,'W16712A'  /*Jumping or diving from boat striking water surface causing other injury, initial encounter*/
,'W16712D'  /*Jumping or diving from boat striking water surface causing other injury, subsequent encounter*/
,'W16712S'  /*Jumping or diving from boat striking water surface causing other injury, sequela*/
,'W16721A'  /*Jumping or diving from boat striking bottom causing drowning and submersion, initial encounter*/
,'W16721D'  /*Jumping or diving from boat striking bottom causing drowning and submersion, subsequent encounter*/
,'W16721S'  /*Jumping or diving from boat striking bottom causing drowning and submersion, sequela*/
,'W16722A'  /*Jumping or diving from boat striking bottom causing other injury, initial encounter*/
,'W16722D'  /*Jumping or diving from boat striking bottom causing other injury, subsequent encounter*/
,'W16722S'  /*Jumping or diving from boat striking bottom causing other injury, sequela*/
,'W16811A'  /*Jumping or diving into other water striking water surface causing drowning and submersion, initial encounter*/
,'W16811D'  /*Jumping or diving into other water striking water surface causing drowning and submersion, subsequent encounter*/
,'W16811S'  /*Jumping or diving into other water striking water surface causing drowning and submersion, sequela*/
,'W16812A'  /*Jumping or diving into other water striking water surface causing other injury, initial encounter*/
,'W16812D'  /*Jumping or diving into other water striking water surface causing other injury, subsequent encounter*/
,'W16812S'  /*Jumping or diving into other water striking water surface causing other injury, sequela*/
,'W16821A'  /*Jumping or diving into other water striking bottom causing drowning and submersion, initial encounter*/
,'W16821D'  /*Jumping or diving into other water striking bottom causing drowning and submersion, subsequent encounter*/
,'W16821S'  /*Jumping or diving into other water striking bottom causing drowning and submersion, sequela*/
,'W16822A'  /*Jumping or diving into other water striking bottom causing other injury, initial encounter*/
,'W16822D'  /*Jumping or diving into other water striking bottom causing other injury, subsequent encounter*/
,'W16822S'  /*Jumping or diving into other water striking bottom causing other injury, sequela*/
,'W16831A'  /*Jumping or diving into other water striking wall causing drowning and submersion, initial encounter*/
,'W16831D'  /*Jumping or diving into other water striking wall causing drowning and submersion, subsequent encounter*/
,'W16831S'  /*Jumping or diving into other water striking wall causing drowning and submersion, sequela*/
,'W16832A'  /*Jumping or diving into other water striking wall causing other injury, initial encounter*/
,'W16832D'  /*Jumping or diving into other water striking wall causing other injury, subsequent encounter*/
,'W16832S'  /*Jumping or diving into other water striking wall causing other injury, sequela*/
,'W1691XA'  /*Jumping or diving into unspecified water causing drowning and submersion, initial encounter*/
,'W1691XD'  /*Jumping or diving into unspecified water causing drowning and submersion, subsequent encounter*/
,'W1691XS'  /*Jumping or diving into unspecified water causing drowning and submersion, sequela*/
,'W1692XA'  /*Jumping or diving into unspecified water causing other injury, initial encounter*/
,'W1692XD'  /*Jumping or diving into unspecified water causing other injury, subsequent encounter*/
,'W1692XS'  /*Jumping or diving into unspecified water causing other injury, sequela*/
,'W170XXA'  /*Fall into well, initial encounter*/
,'W170XXD'  /*Fall into well, subsequent encounter*/
,'W170XXS'  /*Fall into well, sequela*/
,'W171XXA'  /*Fall into storm drain or manhole, initial encounter*/
,'W171XXD'  /*Fall into storm drain or manhole, subsequent encounter*/
,'W171XXS'  /*Fall into storm drain or manhole, sequela*/
,'W173XXA'  /*Fall into empty swimming pool, initial encounter*/
,'W173XXD'  /*Fall into empty swimming pool, subsequent encounter*/
,'W173XXS'  /*Fall into empty swimming pool, sequela*/
,'W174XXA'  /*Fall from dock, initial encounter*/
,'W174XXD'  /*Fall from dock, subsequent encounter*/
,'W174XXS'  /*Fall from dock, sequela*/
,'W1781XA'  /*Fall down embankment (hill), initial encounter*/
,'W1781XD'  /*Fall down embankment (hill), subsequent encounter*/
,'W1781XS'  /*Fall down embankment (hill), sequela*/
,'W1782XA'  /*Fall from (out of) grocery cart, initial encounter*/
,'W1782XD'  /*Fall from (out of) grocery cart, subsequent encounter*/
,'W1782XS'  /*Fall from (out of) grocery cart, sequela*/
,'W1789XD'  /*Other fall from one level to another, subsequent encounter*/
,'W1789XS'  /*Other fall from one level to another, sequela*/
,'W1800XD'  /*Striking against unspecified object with subsequent fall, subsequent encounter*/
,'W1800XS'  /*Striking against unspecified object with subsequent fall, sequela*/
,'W1801XA'  /*Striking against sports equipment with subsequent fall, initial encounter*/
,'W1801XD'  /*Striking against sports equipment with subsequent fall, subsequent encounter*/
,'W1801XS'  /*Striking against sports equipment with subsequent fall, sequela*/
,'W1802XD'  /*Striking against glass with subsequent fall, subsequent encounter*/
,'W1802XS'  /*Striking against glass with subsequent fall, sequela*/
,'W1809XD'  /*Striking against other object with subsequent fall, subsequent encounter*/
,'W1809XS'  /*Striking against other object with subsequent fall, sequela*/
,'W1811XD'  /*Fall from or off toilet without subsequent striking against object, subsequent encounter*/
,'W1811XS'  /*Fall from or off toilet without subsequent striking against object, sequela*/
,'W1812XD'  /*Fall from or off toilet with subsequent striking against object, subsequent encounter*/
,'W1812XS'  /*Fall from or off toilet with subsequent striking against object, sequela*/
,'W182XXD'  /*Fall in (into) shower or empty bathtub, subsequent encounter*/
,'W182XXS'  /*Fall in (into) shower or empty bathtub, sequela*/
,'W1830XD'  /*Fall on same level, unspecified, subsequent encounter*/
,'W1830XS'  /*Fall on same level, unspecified, sequela*/
,'W1831XD'  /*Fall on same level due to stepping on an object, subsequent encounter*/
,'W1831XS'  /*Fall on same level due to stepping on an object, sequela*/
,'W1839XD'  /*Other fall on same level, subsequent encounter*/
,'W1839XS'  /*Other fall on same level, sequela*/
,'W1840XD'  /*Slipping, tripping and stumbling without falling, unspecified, subsequent encounter*/
,'W1840XS'  /*Slipping, tripping and stumbling without falling, unspecified, sequela*/
,'W1841XD'  /*Slipping, tripping and stumbling without falling due to stepping on object, subsequent encounter*/
,'W1841XS'  /*Slipping, tripping and stumbling without falling due to stepping on object, sequela*/
,'W1842XD'  /*Slipping, tripping and stumbling without falling due to stepping into hole or opening, subsequent encounter*/
,'W1842XS'  /*Slipping, tripping and stumbling without falling due to stepping into hole or opening, sequela*/
,'W1843XD'  /*Slipping, tripping and stumbling without falling due to stepping from one level to another, subsequent encounter*/
,'W1843XS'  /*Slipping, tripping and stumbling without falling due to stepping from one level to another, sequela*/
,'W1849XD'  /*Other slipping, tripping and stumbling without falling, subsequent encounter*/
,'W1849XS'  /*Other slipping, tripping and stumbling without falling, sequela*/
,'W2100XA'  /*Struck by hit or thrown ball, unspecified type, initial encounter*/
,'W2100XD'  /*Struck by hit or thrown ball, unspecified type, subsequent encounter*/
,'W2100XS'  /*Struck by hit or thrown ball, unspecified type, sequela*/
,'W2101XA'  /*Struck by football, initial encounter*/
,'W2101XD'  /*Struck by football, subsequent encounter*/
,'W2101XS'  /*Struck by football, sequela*/
,'W2102XA'  /*Struck by soccer ball, initial encounter*/
,'W2102XD'  /*Struck by soccer ball, subsequent encounter*/
,'W2102XS'  /*Struck by soccer ball, sequela*/
,'W2103XA'  /*Struck by baseball, initial encounter*/
,'W2103XD'  /*Struck by baseball, subsequent encounter*/
,'W2103XS'  /*Struck by baseball, sequela*/
,'W2104XA'  /*Struck by golf ball, initial encounter*/
,'W2104XD'  /*Struck by golf ball, subsequent encounter*/
,'W2104XS'  /*Struck by golf ball, sequela*/
,'W2105XA'  /*Struck by basketball, initial encounter*/
,'W2105XD'  /*Struck by basketball, subsequent encounter*/
,'W2105XS'  /*Struck by basketball, sequela*/
,'W2106XA'  /*Struck by volleyball, initial encounter*/
,'W2106XD'  /*Struck by volleyball, subsequent encounter*/
,'W2106XS'  /*Struck by volleyball, sequela*/
,'W2107XA'  /*Struck by softball, initial encounter*/
,'W2107XD'  /*Struck by softball, subsequent encounter*/
,'W2107XS'  /*Struck by softball, sequela*/
,'W2109XA'  /*Struck by other hit or thrown ball, initial encounter*/
,'W2109XD'  /*Struck by other hit or thrown ball, subsequent encounter*/
,'W2109XS'  /*Struck by other hit or thrown ball, sequela*/
,'W2111XA'  /*Struck by baseball bat, initial encounter*/
,'W2111XD'  /*Struck by baseball bat, subsequent encounter*/
,'W2111XS'  /*Struck by baseball bat, sequela*/
,'W2112XA'  /*Struck by tennis racquet, initial encounter*/
,'W2112XD'  /*Struck by tennis racquet, subsequent encounter*/
,'W2112XS'  /*Struck by tennis racquet, sequela*/
,'W2113XA'  /*Struck by golf club, initial encounter*/
,'W2113XD'  /*Struck by golf club, subsequent encounter*/
,'W2113XS'  /*Struck by golf club, sequela*/
,'W2119XA'  /*Struck by other bat, racquet or club, initial encounter*/
,'W2119XD'  /*Struck by other bat, racquet or club, subsequent encounter*/
,'W2119XS'  /*Struck by other bat, racquet or club, sequela*/
,'W21210A'  /*Struck by ice hockey stick, initial encounter*/
,'W21210D'  /*Struck by ice hockey stick, subsequent encounter*/
,'W21210S'  /*Struck by ice hockey stick, sequela*/
,'W21211A'  /*Struck by field hockey stick, initial encounter*/
,'W21211D'  /*Struck by field hockey stick, subsequent encounter*/
,'W21211S'  /*Struck by field hockey stick, sequela*/
,'W21220A'  /*Struck by ice hockey puck, initial encounter*/
,'W21220D'  /*Struck by ice hockey puck, subsequent encounter*/
,'W21220S'  /*Struck by ice hockey puck, sequela*/
,'W21221A'  /*Struck by field hockey puck, initial encounter*/
,'W21221D'  /*Struck by field hockey puck, subsequent encounter*/
,'W21221S'  /*Struck by field hockey puck, sequela*/
,'W2131XA'  /*Struck by shoe cleats, initial encounter*/
,'W2131XD'  /*Struck by shoe cleats, subsequent encounter*/
,'W2131XS'  /*Struck by shoe cleats, sequela*/
,'W2132XA'  /*Struck by skate blades, initial encounter*/
,'W2132XD'  /*Struck by skate blades, subsequent encounter*/
,'W2132XS'  /*Struck by skate blades, sequela*/
,'W2139XA'  /*Struck by other sports foot wear, initial encounter*/
,'W2139XD'  /*Struck by other sports foot wear, subsequent encounter*/
,'W2139XS'  /*Struck by other sports foot wear, sequela*/
,'W214XXA'  /*Striking against diving board, initial encounter*/
,'W214XXD'  /*Striking against diving board, subsequent encounter*/
,'W214XXS'  /*Striking against diving board, sequela*/
,'W2181XA'  /*Striking against or struck by football helmet, initial encounter*/
,'W2181XD'  /*Striking against or struck by football helmet, subsequent encounter*/
,'W2181XS'  /*Striking against or struck by football helmet, sequela*/
,'W2189XA'  /*Striking against or struck by other sports equipment, initial encounter*/
,'W2189XD'  /*Striking against or struck by other sports equipment, subsequent encounter*/
,'W2189XS'  /*Striking against or struck by other sports equipment, sequela*/
,'W219XXA'  /*Striking against or struck by unspecified sports equipment, initial encounter*/
,'W219XXD'  /*Striking against or struck by unspecified sports equipment, subsequent encounter*/
,'W219XXS'  /*Striking against or struck by unspecified sports equipment, sequela*/
,'W2201XD'  /*Walked into wall, subsequent encounter*/
,'W2201XS'  /*Walked into wall, sequela*/
,'W2202XA'  /*Walked into lamppost, initial encounter*/
,'W2202XD'  /*Walked into lamppost, subsequent encounter*/
,'W2202XS'  /*Walked into lamppost, sequela*/
,'W2203XD'  /*Walked into furniture, subsequent encounter*/
,'W2203XS'  /*Walked into furniture, sequela*/
,'W22041D'  /*Striking against wall of swimming pool causing drowning and submersion, subsequent encounter*/
,'W22041S'  /*Striking against wall of swimming pool causing drowning and submersion, sequela*/
,'W22042S'  /*Striking against wall of swimming pool causing other injury, sequela*/
,'W2209XD'  /*Striking against other stationary object, subsequent encounter*/
,'W2209XS'  /*Striking against other stationary object, sequela*/
,'W2210XA'  /*Striking against or struck by unspecified automobile airbag, initial encounter*/
,'W2210XD'  /*Striking against or struck by unspecified automobile airbag, subsequent encounter*/
,'W2210XS'  /*Striking against or struck by unspecified automobile airbag, sequela*/
,'W2211XA'  /*Striking against or struck by driver side automobile airbag, initial encounter*/
,'W2211XD'  /*Striking against or struck by driver side automobile airbag, subsequent encounter*/
,'W2211XS'  /*Striking against or struck by driver side automobile airbag, sequela*/
,'W2212XA'  /*Striking against or struck by front passenger side automobile airbag, initial encounter*/
,'W2212XD'  /*Striking against or struck by front passenger side automobile airbag, subsequent encounter*/
,'W2212XS'  /*Striking against or struck by front passenger side automobile airbag, sequela*/
,'W2219XA'  /*Striking against or struck by other automobile airbag, initial encounter*/
,'W2219XD'  /*Striking against or struck by other automobile airbag, subsequent encounter*/
,'W2219XS'  /*Striking against or struck by other automobile airbag, sequela*/
,'W228XXA'  /*Striking against or struck by other objects, initial encounter*/
,'W228XXD'  /*Striking against or struck by other objects, subsequent encounter*/
,'W228XXS'  /*Striking against or struck by other objects, sequela*/
,'W240XXD'  /*Contact with lifting devices, not elsewhere classified, subsequent encounter*/
,'W240XXS'  /*Contact with lifting devices, not elsewhere classified, sequela*/
,'W241XXA'  /*Contact with transmission devices, not elsewhere classified, initial encounter*/
,'W241XXD'  /*Contact with transmission devices, not elsewhere classified, subsequent encounter*/
,'W241XXS'  /*Contact with transmission devices, not elsewhere classified, sequela*/
,'W261XXA'  /*Contact with sword or dagger, initial encounter*/
,'W261XXD'  /*Contact with sword or dagger, subsequent encounter*/
,'W261XXS'  /*Contact with sword or dagger, sequela*/
,'W262XXA'  /*Contact with edge of stiff paper, initial encounter*/
,'W262XXD'  /*Contact with edge of stiff paper, subsequent encounter*/
,'W262XXS'  /*Contact with edge of stiff paper, sequela*/
,'W268XXA'  /*Contact with other sharp object(s), not elsewhere classified, initial encounter*/
,'W268XXD'  /*Contact with other sharp object(s), not elsewhere classified, subsequent encounter*/
,'W268XXS'  /*Contact with other sharp object(s), not elsewhere classified, sequela*/
,'W269XXA'  /*Contact with unspecified sharp object(s), initial encounter*/
,'W269XXD'  /*Contact with unspecified sharp object(s), subsequent encounter*/
,'W269XXS'  /*Contact with unspecified sharp object(s), sequela*/
,'W270XXA'  /*Contact with workbench tool, initial encounter*/
,'W270XXD'  /*Contact with workbench tool, subsequent encounter*/
,'W270XXS'  /*Contact with workbench tool, sequela*/
,'W271XXA'  /*Contact with garden tool, initial encounter*/
,'W271XXD'  /*Contact with garden tool, subsequent encounter*/
,'W271XXS'  /*Contact with garden tool, sequela*/
,'W272XXD'  /*Contact with scissors, subsequent encounter*/
,'W272XXS'  /*Contact with scissors, sequela*/
,'W273XXD'  /*Contact with needle (sewing), subsequent encounter*/
,'W273XXS'  /*Contact with needle (sewing), sequela*/
,'W274XXD'  /*Contact with kitchen utensil, subsequent encounter*/
,'W274XXS'  /*Contact with kitchen utensil, sequela*/
,'W275XXD'  /*Contact with paper-cutter, subsequent encounter*/
,'W275XXS'  /*Contact with paper-cutter, sequela*/
,'W278XXA'  /*Contact with other nonpowered hand tool, initial encounter*/
,'W278XXD'  /*Contact with other nonpowered hand tool, subsequent encounter*/
,'W278XXS'  /*Contact with other nonpowered hand tool, sequela*/
,'W28XXXA'  /*Contact with powered lawn mower, initial encounter*/
,'W28XXXD'  /*Contact with powered lawn mower, subsequent encounter*/
,'W28XXXS'  /*Contact with powered lawn mower, sequela*/
,'W290XXA'  /*Contact with powered kitchen appliance, initial encounter*/
,'W290XXD'  /*Contact with powered kitchen appliance, subsequent encounter*/
,'W290XXS'  /*Contact with powered kitchen appliance, sequela*/
,'W291XXA'  /*Contact with electric knife, initial encounter*/
,'W291XXD'  /*Contact with electric knife, subsequent encounter*/
,'W291XXS'  /*Contact with electric knife, sequela*/
,'W292XXA'  /*Contact with other powered household machinery, initial encounter*/
,'W292XXD'  /*Contact with other powered household machinery, subsequent encounter*/
,'W292XXS'  /*Contact with other powered household machinery, sequela*/
,'W293XXA'  /*Contact with powered garden and outdoor hand tools and machinery, initial encounter*/
,'W293XXD'  /*Contact with powered garden and outdoor hand tools and machinery, subsequent encounter*/
,'W293XXS'  /*Contact with powered garden and outdoor hand tools and machinery, sequela*/
,'W294XXA'  /*Contact with nail gun, initial encounter*/
,'W294XXD'  /*Contact with nail gun, subsequent encounter*/
,'W294XXS'  /*Contact with nail gun, sequela*/
,'W298XXA'  /*Contact with other powered powered hand tools and household machinery, initial encounter*/
,'W298XXD'  /*Contact with other powered powered hand tools and household machinery, subsequent encounter*/
,'W298XXS'  /*Contact with other powered powered hand tools and household machinery, sequela*/
,'W300XXA'  /*Contact with combine harvester, initial encounter*/
,'W300XXD'  /*Contact with combine harvester, subsequent encounter*/
,'W300XXS'  /*Contact with combine harvester, sequela*/
,'W301XXA'  /*Contact with power take-off devices (PTO), initial encounter*/
,'W301XXD'  /*Contact with power take-off devices (PTO), subsequent encounter*/
,'W301XXS'  /*Contact with power take-off devices (PTO), sequela*/
,'W302XXA'  /*Contact with hay derrick, initial encounter*/
,'W302XXD'  /*Contact with hay derrick, subsequent encounter*/
,'W302XXS'  /*Contact with hay derrick, sequela*/
,'W303XXA'  /*Contact with grain storage elevator, initial encounter*/
,'W303XXD'  /*Contact with grain storage elevator, subsequent encounter*/
,'W303XXS'  /*Contact with grain storage elevator, sequela*/
,'W3081XA'  /*Contact with agricultural transport vehicle in stationary use, initial encounter*/
,'W3081XD'  /*Contact with agricultural transport vehicle in stationary use, subsequent encounter*/
,'W3081XS'  /*Contact with agricultural transport vehicle in stationary use, sequela*/
,'W3089XA'  /*Contact with other specified agricultural machinery, initial encounter*/
,'W3089XD'  /*Contact with other specified agricultural machinery, subsequent encounter*/
,'W3089XS'  /*Contact with other specified agricultural machinery, sequela*/
,'W309XXA'  /*Contact with unspecified agricultural machinery, initial encounter*/
,'W309XXD'  /*Contact with unspecified agricultural machinery, subsequent encounter*/
,'W309XXS'  /*Contact with unspecified agricultural machinery, sequela*/
,'W310XXA'  /*Contact with mining and earth-drilling machinery, initial encounter*/
,'W310XXD'  /*Contact with mining and earth-drilling machinery, subsequent encounter*/
,'W310XXS'  /*Contact with mining and earth-drilling machinery, sequela*/
,'W311XXA'  /*Contact with metalworking machines, initial encounter*/
,'W311XXD'  /*Contact with metalworking machines, subsequent encounter*/
,'W311XXS'  /*Contact with metalworking machines, sequela*/
,'W312XXA'  /*Contact with powered woodworking and forming machines, initial encounter*/
,'W312XXD'  /*Contact with powered woodworking and forming machines, subsequent encounter*/
,'W312XXS'  /*Contact with powered woodworking and forming machines, sequela*/
,'W313XXA'  /*Contact with prime movers, initial encounter*/
,'W313XXD'  /*Contact with prime movers, subsequent encounter*/
,'W313XXS'  /*Contact with prime movers, sequela*/
,'W3181XA'  /*Contact with recreational machinery, initial encounter*/
,'W3181XD'  /*Contact with recreational machinery, subsequent encounter*/
,'W3181XS'  /*Contact with recreational machinery, sequela*/
,'W3182XA'  /*Contact with other commercial machinery, initial encounter*/
,'W3182XD'  /*Contact with other commercial machinery, subsequent encounter*/
,'W3182XS'  /*Contact with other commercial machinery, sequela*/
,'W3183XA'  /*Contact with special construction vehicle in stationary use, initial encounter*/
,'W3183XD'  /*Contact with special construction vehicle in stationary use, subsequent encounter*/
,'W3183XS'  /*Contact with special construction vehicle in stationary use, sequela*/
,'W3189XA'  /*Contact with other specified machinery, initial encounter*/
,'W3189XD'  /*Contact with other specified machinery, subsequent encounter*/
,'W3189XS'  /*Contact with other specified machinery, sequela*/
,'W319XXA'  /*Contact with unspecified machinery, initial encounter*/
,'W319XXD'  /*Contact with unspecified machinery, subsequent encounter*/
,'W319XXS'  /*Contact with unspecified machinery, sequela*/
,'W320XXA'  /*Accidental handgun discharge, initial encounter*/
,'W320XXD'  /*Accidental handgun discharge, subsequent encounter*/
,'W320XXS'  /*Accidental handgun discharge, sequela*/
,'W321XXA'  /*Accidental handgun malfunction, initial encounter*/
,'W321XXD'  /*Accidental handgun malfunction, subsequent encounter*/
,'W321XXS'  /*Accidental handgun malfunction, sequela*/
,'W3300XA'  /*Accidental discharge of unspecified larger firearm, initial encounter*/
,'W3300XD'  /*Accidental discharge of unspecified larger firearm, subsequent encounter*/
,'W3300XS'  /*Accidental discharge of unspecified larger firearm, sequela*/
,'W3301XA'  /*Accidental discharge of shotgun, initial encounter*/
,'W3301XD'  /*Accidental discharge of shotgun, subsequent encounter*/
,'W3301XS'  /*Accidental discharge of shotgun, sequela*/
,'W3302XA'  /*Accidental discharge of hunting rifle, initial encounter*/
,'W3302XD'  /*Accidental discharge of hunting rifle, subsequent encounter*/
,'W3302XS'  /*Accidental discharge of hunting rifle, sequela*/
,'W3303XA'  /*Accidental discharge of machine gun, initial encounter*/
,'W3303XD'  /*Accidental discharge of machine gun, subsequent encounter*/
,'W3303XS'  /*Accidental discharge of machine gun, sequela*/
,'W3309XA'  /*Accidental discharge of other larger firearm, initial encounter*/
,'W3309XD'  /*Accidental discharge of other larger firearm, subsequent encounter*/
,'W3309XS'  /*Accidental discharge of other larger firearm, sequela*/
,'W3310XA'  /*Accidental malfunction of unspecified larger firearm, initial encounter*/
,'W3310XD'  /*Accidental malfunction of unspecified larger firearm, subsequent encounter*/
,'W3310XS'  /*Accidental malfunction of unspecified larger firearm, sequela*/
,'W3311XA'  /*Accidental malfunction of shotgun, initial encounter*/
,'W3311XD'  /*Accidental malfunction of shotgun, subsequent encounter*/
,'W3311XS'  /*Accidental malfunction of shotgun, sequela*/
,'W3312XA'  /*Accidental malfunction of hunting rifle, initial encounter*/
,'W3312XD'  /*Accidental malfunction of hunting rifle, subsequent encounter*/
,'W3312XS'  /*Accidental malfunction of hunting rifle, sequela*/
,'W3313XA'  /*Accidental malfunction of machine gun, initial encounter*/
,'W3313XD'  /*Accidental malfunction of machine gun, subsequent encounter*/
,'W3313XS'  /*Accidental malfunction of machine gun, sequela*/
,'W3319XA'  /*Accidental malfunction of other larger firearm, initial encounter*/
,'W3319XD'  /*Accidental malfunction of other larger firearm, subsequent encounter*/
,'W3319XS'  /*Accidental malfunction of other larger firearm, sequela*/
,'W3400XA'  /*Accidental discharge from unspecified firearms or gun, initial encounter*/
,'W3400XD'  /*Accidental discharge from unspecified firearms or gun, subsequent encounter*/
,'W3400XS'  /*Accidental discharge from unspecified firearms or gun, sequela*/
,'W34010A'  /*Accidental discharge of airgun, initial encounter*/
,'W34010D'  /*Accidental discharge of airgun, subsequent encounter*/
,'W34010S'  /*Accidental discharge of airgun, sequela*/
,'W34011A'  /*Accidental discharge of paintball gun, initial encounter*/
,'W34011D'  /*Accidental discharge of paintball gun, subsequent encounter*/
,'W34011S'  /*Accidental discharge of paintball gun, sequela*/
,'W34018A'  /*Accidental discharge of other gas, air or spring-operated gun, initial encounter*/
,'W34018D'  /*Accidental discharge of other gas, air or spring-operated gun, subsequent encounter*/
,'W34018S'  /*Accidental discharge of other gas, air or spring-operated gun, sequela*/
,'W3409XA'  /*Accidental discharge from other specified firearms, initial encounter*/
,'W3409XD'  /*Accidental discharge from other specified firearms, subsequent encounter*/
,'W3409XS'  /*Accidental discharge from other specified firearms, sequela*/
,'W3410XA'  /*Accidental malfunction from unspecified firearms or gun, initial encounter*/
,'W3410XD'  /*Accidental malfunction from unspecified firearms or gun, subsequent encounter*/
,'W3410XS'  /*Accidental malfunction from unspecified firearms or gun, sequela*/
,'W34110A'  /*Accidental malfunction of airgun, initial encounter*/
,'W34110D'  /*Accidental malfunction of airgun, subsequent encounter*/
,'W34110S'  /*Accidental malfunction of airgun, sequela*/
,'W34111A'  /*Accidental malfunction of paintball gun, initial encounter*/
,'W34111D'  /*Accidental malfunction of paintball gun, subsequent encounter*/
,'W34111S'  /*Accidental malfunction of paintball gun, sequela*/
,'W34118A'  /*Accidental malfunction of other gas, air or spring-operated gun, initial encounter*/
,'W34118D'  /*Accidental malfunction of other gas, air or spring-operated gun, subsequent encounter*/
,'W34118S'  /*Accidental malfunction of other gas, air or spring-operated gun, sequela*/
,'W3419XA'  /*Accidental malfunction from other specified firearms, initial encounter*/
,'W3419XD'  /*Accidental malfunction from other specified firearms, subsequent encounter*/
,'W3419XS'  /*Accidental malfunction from other specified firearms, sequela*/
,'W35XXXA'  /*Explosion and rupture of boiler, initial encounter*/
,'W35XXXD'  /*Explosion and rupture of boiler, subsequent encounter*/
,'W35XXXS'  /*Explosion and rupture of boiler, sequela*/
,'W361XXA'  /*Explosion and rupture of aerosol can, initial encounter*/
,'W361XXD'  /*Explosion and rupture of aerosol can, subsequent encounter*/
,'W361XXS'  /*Explosion and rupture of aerosol can, sequela*/
,'W362XXA'  /*Explosion and rupture of air tank, initial encounter*/
,'W362XXD'  /*Explosion and rupture of air tank, subsequent encounter*/
,'W362XXS'  /*Explosion and rupture of air tank, sequela*/
,'W363XXA'  /*Explosion and rupture of pressurized-gas tank, initial encounter*/
,'W363XXD'  /*Explosion and rupture of pressurized-gas tank, subsequent encounter*/
,'W363XXS'  /*Explosion and rupture of pressurized-gas tank, sequela*/
,'W368XXA'  /*Explosion and rupture of other gas cylinder, initial encounter*/
,'W368XXD'  /*Explosion and rupture of other gas cylinder, subsequent encounter*/
,'W368XXS'  /*Explosion and rupture of other gas cylinder, sequela*/
,'W369XXA'  /*Explosion and rupture of unspecified gas cylinder, initial encounter*/
,'W369XXD'  /*Explosion and rupture of unspecified gas cylinder, subsequent encounter*/
,'W369XXS'  /*Explosion and rupture of unspecified gas cylinder, sequela*/
,'W370XXA'  /*Explosion of bicycle tire, initial encounter*/
,'W370XXD'  /*Explosion of bicycle tire, subsequent encounter*/
,'W370XXS'  /*Explosion of bicycle tire, sequela*/
,'W378XXA'  /*Explosion and rupture of other pressurized tire, pipe or hose, initial encounter*/
,'W378XXD'  /*Explosion and rupture of other pressurized tire, pipe or hose, subsequent encounter*/
,'W378XXS'  /*Explosion and rupture of other pressurized tire, pipe or hose, sequela*/
,'W38XXXA'  /*Explosion and rupture of other specified pressurized devices, initial encounter*/
,'W38XXXD'  /*Explosion and rupture of other specified pressurized devices, subsequent encounter*/
,'W38XXXS'  /*Explosion and rupture of other specified pressurized devices, sequela*/
,'W39XXXA'  /*Discharge of firework, initial encounter*/
,'W39XXXD'  /*Discharge of firework, subsequent encounter*/
,'W39XXXS'  /*Discharge of firework, sequela*/
,'W400XXA'  /*Explosion of blasting material, initial encounter*/
,'W400XXD'  /*Explosion of blasting material, subsequent encounter*/
,'W400XXS'  /*Explosion of blasting material, sequela*/
,'W401XXA'  /*Explosion of explosive gases, initial encounter*/
,'W401XXD'  /*Explosion of explosive gases, subsequent encounter*/
,'W401XXS'  /*Explosion of explosive gases, sequela*/
,'W408XXA'  /*Explosion of other specified explosive materials, initial encounter*/
,'W408XXD'  /*Explosion of other specified explosive materials, subsequent encounter*/
,'W408XXS'  /*Explosion of other specified explosive materials, sequela*/
,'W409XXA'  /*Explosion of unspecified explosive materials, initial encounter*/
,'W409XXD'  /*Explosion of unspecified explosive materials, subsequent encounter*/
,'W409XXS'  /*Explosion of unspecified explosive materials, sequela*/
,'W420XXA'  /*Exposure to supersonic waves, initial encounter*/
,'W420XXD'  /*Exposure to supersonic waves, subsequent encounter*/
,'W420XXS'  /*Exposure to supersonic waves, sequela*/
,'W429XXD'  /*Exposure to other noise, subsequent encounter*/
,'W429XXS'  /*Exposure to other noise, sequela*/
,'W450XXA'  /*Nail entering through skin, initial encounter*/
,'W450XXD'  /*Nail entering through skin, subsequent encounter*/
,'W450XXS'  /*Nail entering through skin, sequela*/
,'W4901XD'  /*Hair causing external constriction, subsequent encounter*/
,'W4901XS'  /*Hair causing external constriction, sequela*/
,'W4902XD'  /*String or thread causing external constriction, subsequent encounter*/
,'W4902XS'  /*String or thread causing external constriction, sequela*/
,'W4903XD'  /*Rubber band causing external constriction, subsequent encounter*/
,'W4903XS'  /*Rubber band causing external constriction, sequela*/
,'W4904XD'  /*Ring or other jewelry causing external constriction, subsequent encounter*/
,'W4904XS'  /*Ring or other jewelry causing external constriction, sequela*/
,'W4909XD'  /*Other specified item causing external constriction, subsequent encounter*/
,'W4909XS'  /*Other specified item causing external constriction, sequela*/
,'W499XXD'  /*Exposure to other inanimate mechanical forces, subsequent encounter*/
,'W499XXS'  /*Exposure to other inanimate mechanical forces, sequela*/
,'W52XXXA'  /*Crushed, pushed or stepped on by crowd or human stampede, initial encounter*/
,'W52XXXD'  /*Crushed, pushed or stepped on by crowd or human stampede, subsequent encounter*/
,'W52XXXS'  /*Crushed, pushed or stepped on by crowd or human stampede, sequela*/
,'W5301XA'  /*Bitten by mouse, initial encounter*/
,'W5301XD'  /*Bitten by mouse, subsequent encounter*/
,'W5301XS'  /*Bitten by mouse, sequela*/
,'W5309XA'  /*Other contact with mouse, initial encounter*/
,'W5309XD'  /*Other contact with mouse, subsequent encounter*/
,'W5309XS'  /*Other contact with mouse, sequela*/
,'W5311XA'  /*Bitten by rat, initial encounter*/
,'W5311XD'  /*Bitten by rat, subsequent encounter*/
,'W5311XS'  /*Bitten by rat, sequela*/
,'W5319XA'  /*Other contact with rat, initial encounter*/
,'W5319XD'  /*Other contact with rat, subsequent encounter*/
,'W5319XS'  /*Other contact with rat, sequela*/
,'W5321XA'  /*Bitten by squirrel, initial encounter*/
,'W5321XD'  /*Bitten by squirrel, subsequent encounter*/
,'W5321XS'  /*Bitten by squirrel, sequela*/
,'W5329XA'  /*Other contact with squirrel, initial encounter*/
,'W5329XD'  /*Other contact with squirrel, subsequent encounter*/
,'W5329XS'  /*Other contact with squirrel, sequela*/
,'W5381XA'  /*Bitten by other rodent, initial encounter*/
,'W5381XD'  /*Bitten by other rodent, subsequent encounter*/
,'W5381XS'  /*Bitten by other rodent, sequela*/
,'W5389XA'  /*Other contact with other rodent, initial encounter*/
,'W5389XD'  /*Other contact with other rodent, subsequent encounter*/
,'W5389XS'  /*Other contact with other rodent, sequela*/
,'W540XXA'  /*Bitten by dog, initial encounter*/
,'W540XXD'  /*Bitten by dog, subsequent encounter*/
,'W540XXS'  /*Bitten by dog, sequela*/
,'W541XXA'  /*Struck by dog, initial encounter*/
,'W541XXD'  /*Struck by dog, subsequent encounter*/
,'W541XXS'  /*Struck by dog, sequela*/
,'W548XXA'  /*Other contact with dog, initial encounter*/
,'W548XXD'  /*Other contact with dog, subsequent encounter*/
,'W548XXS'  /*Other contact with dog, sequela*/
,'W5501XA'  /*Bitten by cat, initial encounter*/
,'W5501XD'  /*Bitten by cat, subsequent encounter*/
,'W5501XS'  /*Bitten by cat, sequela*/
,'W5503XA'  /*Scratched by cat, initial encounter*/
,'W5503XD'  /*Scratched by cat, subsequent encounter*/
,'W5503XS'  /*Scratched by cat, sequela*/
,'W5509XA'  /*Other contact with cat, initial encounter*/
,'W5509XD'  /*Other contact with cat, subsequent encounter*/
,'W5509XS'  /*Other contact with cat, sequela*/
,'W5511XA'  /*Bitten by horse, initial encounter*/
,'W5511XD'  /*Bitten by horse, subsequent encounter*/
,'W5511XS'  /*Bitten by horse, sequela*/
,'W5512XA'  /*Struck by horse, initial encounter*/
,'W5512XD'  /*Struck by horse, subsequent encounter*/
,'W5512XS'  /*Struck by horse, sequela*/
,'W5519XA'  /*Other contact with horse, initial encounter*/
,'W5519XD'  /*Other contact with horse, subsequent encounter*/
,'W5519XS'  /*Other contact with horse, sequela*/
,'W5521XA'  /*Bitten by cow, initial encounter*/
,'W5521XD'  /*Bitten by cow, subsequent encounter*/
,'W5521XS'  /*Bitten by cow, sequela*/
,'W5522XA'  /*Struck by cow, initial encounter*/
,'W5522XD'  /*Struck by cow, subsequent encounter*/
,'W5522XS'  /*Struck by cow, sequela*/
,'W5529XA'  /*Other contact with cow, initial encounter*/
,'W5529XD'  /*Other contact with cow, subsequent encounter*/
,'W5529XS'  /*Other contact with cow, sequela*/
,'W5531XA'  /*Bitten by other hoof stock, initial encounter*/
,'W5531XD'  /*Bitten by other hoof stock, subsequent encounter*/
,'W5531XS'  /*Bitten by other hoof stock, sequela*/
,'W5532XA'  /*Struck by other hoof stock, initial encounter*/
,'W5532XD'  /*Struck by other hoof stock, subsequent encounter*/
,'W5532XS'  /*Struck by other hoof stock, sequela*/
,'W5539XA'  /*Other contact with other hoof stock, initial encounter*/
,'W5539XD'  /*Other contact with other hoof stock, subsequent encounter*/
,'W5539XS'  /*Other contact with other hoof stock, sequela*/
,'W5541XA'  /*Bitten by pig, initial encounter*/
,'W5541XD'  /*Bitten by pig, subsequent encounter*/
,'W5541XS'  /*Bitten by pig, sequela*/
,'W5542XA'  /*Struck by pig, initial encounter*/
,'W5542XD'  /*Struck by pig, subsequent encounter*/
,'W5542XS'  /*Struck by pig, sequela*/
,'W5549XA'  /*Other contact with pig, initial encounter*/
,'W5549XD'  /*Other contact with pig, subsequent encounter*/
,'W5549XS'  /*Other contact with pig, sequela*/
,'W5551XA'  /*Bitten by raccoon, initial encounter*/
,'W5551XD'  /*Bitten by raccoon, subsequent encounter*/
,'W5551XS'  /*Bitten by raccoon, sequela*/
,'W5552XA'  /*Struck by raccoon, initial encounter*/
,'W5552XD'  /*Struck by raccoon, subsequent encounter*/
,'W5552XS'  /*Struck by raccoon, sequela*/
,'W5559XA'  /*Other contact with raccoon, initial encounter*/
,'W5559XD'  /*Other contact with raccoon, subsequent encounter*/
,'W5559XS'  /*Other contact with raccoon, sequela*/
,'W5581XA'  /*Bitten by other mammals, initial encounter*/
,'W5581XD'  /*Bitten by other mammals, subsequent encounter*/
,'W5581XS'  /*Bitten by other mammals, sequela*/
,'W5582XA'  /*Struck by other mammals, initial encounter*/
,'W5582XD'  /*Struck by other mammals, subsequent encounter*/
,'W5582XS'  /*Struck by other mammals, sequela*/
,'W5589XA'  /*Other contact with other mammals, initial encounter*/
,'W5589XD'  /*Other contact with other mammals, subsequent encounter*/
,'W5589XS'  /*Other contact with other mammals, sequela*/
,'W5601XA'  /*Bitten by dolphin, initial encounter*/
,'W5601XD'  /*Bitten by dolphin, subsequent encounter*/
,'W5601XS'  /*Bitten by dolphin, sequela*/
,'W5602XA'  /*Struck by dolphin, initial encounter*/
,'W5602XD'  /*Struck by dolphin, subsequent encounter*/
,'W5602XS'  /*Struck by dolphin, sequela*/
,'W5609XA'  /*Other contact with dolphin, initial encounter*/
,'W5609XD'  /*Other contact with dolphin, subsequent encounter*/
,'W5609XS'  /*Other contact with dolphin, sequela*/
,'W5611XA'  /*Bitten by sea lion, initial encounter*/
,'W5611XD'  /*Bitten by sea lion, subsequent encounter*/
,'W5611XS'  /*Bitten by sea lion, sequela*/
,'W5612XA'  /*Struck by sea lion, initial encounter*/
,'W5612XD'  /*Struck by sea lion, subsequent encounter*/
,'W5612XS'  /*Struck by sea lion, sequela*/
,'W5619XA'  /*Other contact with sea lion, initial encounter*/
,'W5619XD'  /*Other contact with sea lion, subsequent encounter*/
,'W5619XS'  /*Other contact with sea lion, sequela*/
,'W5621XA'  /*Bitten by orca, initial encounter*/
,'W5621XD'  /*Bitten by orca, subsequent encounter*/
,'W5621XS'  /*Bitten by orca, sequela*/
,'W5622XA'  /*Struck by orca, initial encounter*/
,'W5622XD'  /*Struck by orca, subsequent encounter*/
,'W5622XS'  /*Struck by orca, sequela*/
,'W5629XA'  /*Other contact with orca, initial encounter*/
,'W5629XD'  /*Other contact with orca, subsequent encounter*/
,'W5629XS'  /*Other contact with orca, sequela*/
,'W5631XA'  /*Bitten by other marine mammals, initial encounter*/
,'W5631XD'  /*Bitten by other marine mammals, subsequent encounter*/
,'W5631XS'  /*Bitten by other marine mammals, sequela*/
,'W5632XA'  /*Struck by other marine mammals, initial encounter*/
,'W5632XD'  /*Struck by other marine mammals, subsequent encounter*/
,'W5632XS'  /*Struck by other marine mammals, sequela*/
,'W5639XA'  /*Other contact with other marine mammals, initial encounter*/
,'W5639XD'  /*Other contact with other marine mammals, subsequent encounter*/
,'W5639XS'  /*Other contact with other marine mammals, sequela*/
,'W5641XA'  /*Bitten by shark, initial encounter*/
,'W5641XD'  /*Bitten by shark, subsequent encounter*/
,'W5641XS'  /*Bitten by shark, sequela*/
,'W5642XA'  /*Struck by shark, initial encounter*/
,'W5642XD'  /*Struck by shark, subsequent encounter*/
,'W5642XS'  /*Struck by shark, sequela*/
,'W5649XA'  /*Other contact with shark, initial encounter*/
,'W5649XD'  /*Other contact with shark, subsequent encounter*/
,'W5649XS'  /*Other contact with shark, sequela*/
,'W5651XA'  /*Bitten by other fish, initial encounter*/
,'W5651XD'  /*Bitten by other fish, subsequent encounter*/
,'W5651XS'  /*Bitten by other fish, sequela*/
,'W5652XA'  /*Struck by other fish, initial encounter*/
,'W5652XD'  /*Struck by other fish, subsequent encounter*/
,'W5652XS'  /*Struck by other fish, sequela*/
,'W5659XA'  /*Other contact with other fish, initial encounter*/
,'W5659XD'  /*Other contact with other fish, subsequent encounter*/
,'W5659XS'  /*Other contact with other fish, sequela*/
,'W5681XA'  /*Bitten by other nonvenomous marine animals, initial encounter*/
,'W5681XD'  /*Bitten by other nonvenomous marine animals, subsequent encounter*/
,'W5681XS'  /*Bitten by other nonvenomous marine animals, sequela*/
,'W5682XA'  /*Struck by other nonvenomous marine animals, initial encounter*/
,'W5682XD'  /*Struck by other nonvenomous marine animals, subsequent encounter*/
,'W5682XS'  /*Struck by other nonvenomous marine animals, sequela*/
,'W5689XA'  /*Other contact with other nonvenomous marine animals, initial encounter*/
,'W5689XD'  /*Other contact with other nonvenomous marine animals, subsequent encounter*/
,'W5689XS'  /*Other contact with other nonvenomous marine animals, sequela*/
,'W57XXXD'  /*Bitten or stung by nonvenomous insect and other nonvenomous arthropods, subsequent encounter*/
,'W57XXXS'  /*Bitten or stung by nonvenomous insect and other nonvenomous arthropods, sequela*/
,'W5801XA'  /*Bitten by alligator, initial encounter*/
,'W5801XD'  /*Bitten by alligator, subsequent encounter*/
,'W5801XS'  /*Bitten by alligator, sequela*/
,'W5802XA'  /*Struck by alligator, initial encounter*/
,'W5802XD'  /*Struck by alligator, subsequent encounter*/
,'W5802XS'  /*Struck by alligator, sequela*/
,'W5803XA'  /*Crushed by alligator, initial encounter*/
,'W5803XD'  /*Crushed by alligator, subsequent encounter*/
,'W5803XS'  /*Crushed by alligator, sequela*/
,'W5809XA'  /*Other contact with alligator, initial encounter*/
,'W5809XD'  /*Other contact with alligator, subsequent encounter*/
,'W5809XS'  /*Other contact with alligator, sequela*/
,'W5811XA'  /*Bitten by crocodile, initial encounter*/
,'W5811XD'  /*Bitten by crocodile, subsequent encounter*/
,'W5811XS'  /*Bitten by crocodile, sequela*/
,'W5812XA'  /*Struck by crocodile, initial encounter*/
,'W5812XD'  /*Struck by crocodile, subsequent encounter*/
,'W5812XS'  /*Struck by crocodile, sequela*/
,'W5813XA'  /*Crushed by crocodile, initial encounter*/
,'W5813XD'  /*Crushed by crocodile, subsequent encounter*/
,'W5813XS'  /*Crushed by crocodile, sequela*/
,'W5819XA'  /*Other contact with crocodile, initial encounter*/
,'W5819XD'  /*Other contact with crocodile, subsequent encounter*/
,'W5819XS'  /*Other contact with crocodile, sequela*/
,'W5901XD'  /*Bitten by nonvenomous lizards, subsequent encounter*/
,'W5901XS'  /*Bitten by nonvenomous lizards, sequela*/
,'W5902XA'  /*Struck by nonvenomous lizards, initial encounter*/
,'W5902XD'  /*Struck by nonvenomous lizards, subsequent encounter*/
,'W5902XS'  /*Struck by nonvenomous lizards, sequela*/
,'W5909XA'  /*Other contact with nonvenomous lizards, initial encounter*/
,'W5909XD'  /*Other contact with nonvenomous lizards, subsequent encounter*/
,'W5909XS'  /*Other contact with nonvenomous lizards, sequela*/
,'W5911XA'  /*Bitten by nonvenomous snake, initial encounter*/
,'W5911XD'  /*Bitten by nonvenomous snake, subsequent encounter*/
,'W5911XS'  /*Bitten by nonvenomous snake, sequela*/
,'W5912XA'  /*Struck by nonvenomous snake, initial encounter*/
,'W5912XD'  /*Struck by nonvenomous snake, subsequent encounter*/
,'W5912XS'  /*Struck by nonvenomous snake, sequela*/
,'W5913XA'  /*Crushed by nonvenomous snake, initial encounter*/
,'W5913XD'  /*Crushed by nonvenomous snake, subsequent encounter*/
,'W5913XS'  /*Crushed by nonvenomous snake, sequela*/
,'W5919XA'  /*Other contact with nonvenomous snake, initial encounter*/
,'W5919XD'  /*Other contact with nonvenomous snake, subsequent encounter*/
,'W5919XS'  /*Other contact with nonvenomous snake, sequela*/
,'W5921XA'  /*Bitten by turtle, initial encounter*/
,'W5921XD'  /*Bitten by turtle, subsequent encounter*/
,'W5921XS'  /*Bitten by turtle, sequela*/
,'W5922XA'  /*Struck by turtle, initial encounter*/
,'W5922XD'  /*Struck by turtle, subsequent encounter*/
,'W5922XS'  /*Struck by turtle, sequela*/
,'W5929XA'  /*Other contact with turtle, initial encounter*/
,'W5929XD'  /*Other contact with turtle, subsequent encounter*/
,'W5929XS'  /*Other contact with turtle, sequela*/
,'W5981XA'  /*Bitten by other nonvenomous reptiles, initial encounter*/
,'W5981XD'  /*Bitten by other nonvenomous reptiles, subsequent encounter*/
,'W5981XS'  /*Bitten by other nonvenomous reptiles, sequela*/
,'W5982XA'  /*Struck by other nonvenomous reptiles, initial encounter*/
,'W5982XD'  /*Struck by other nonvenomous reptiles, subsequent encounter*/
,'W5982XS'  /*Struck by other nonvenomous reptiles, sequela*/
,'W5983XA'  /*Crushed by other nonvenomous reptiles, initial encounter*/
,'W5983XD'  /*Crushed by other nonvenomous reptiles, subsequent encounter*/
,'W5983XS'  /*Crushed by other nonvenomous reptiles, sequela*/
,'W5989XA'  /*Other contact with other nonvenomous reptiles, initial encounter*/
,'W5989XD'  /*Other contact with other nonvenomous reptiles, subsequent encounter*/
,'W5989XS'  /*Other contact with other nonvenomous reptiles, sequela*/
,'W60XXXA'  /*Contact with nonvenomous plant thorns and spines and sharp leaves, initial encounter*/
,'W60XXXD'  /*Contact with nonvenomous plant thorns and spines and sharp leaves, subsequent encounter*/
,'W60XXXS'  /*Contact with nonvenomous plant thorns and spines and sharp leaves, sequela*/
,'W6101XA'  /*Bitten by parrot, initial encounter*/
,'W6101XD'  /*Bitten by parrot, subsequent encounter*/
,'W6101XS'  /*Bitten by parrot, sequela*/
,'W6102XA'  /*Struck by parrot, initial encounter*/
,'W6102XD'  /*Struck by parrot, subsequent encounter*/
,'W6102XS'  /*Struck by parrot, sequela*/
,'W6109XA'  /*Other contact with parrot, initial encounter*/
,'W6109XD'  /*Other contact with parrot, subsequent encounter*/
,'W6109XS'  /*Other contact with parrot, sequela*/
,'W6111XA'  /*Bitten by macaw, initial encounter*/
,'W6111XD'  /*Bitten by macaw, subsequent encounter*/
,'W6111XS'  /*Bitten by macaw, sequela*/
,'W6112XA'  /*Struck by macaw, initial encounter*/
,'W6112XD'  /*Struck by macaw, subsequent encounter*/
,'W6112XS'  /*Struck by macaw, sequela*/
,'W6119XA'  /*Other contact with macaw, initial encounter*/
,'W6119XD'  /*Other contact with macaw, subsequent encounter*/
,'W6119XS'  /*Other contact with macaw, sequela*/
,'W6121XA'  /*Bitten by other psittacines, initial encounter*/
,'W6121XD'  /*Bitten by other psittacines, subsequent encounter*/
,'W6121XS'  /*Bitten by other psittacines, sequela*/
,'W6122XA'  /*Struck by other psittacines, initial encounter*/
,'W6122XD'  /*Struck by other psittacines, subsequent encounter*/
,'W6122XS'  /*Struck by other psittacines, sequela*/
,'W6129XA'  /*Other contact with other psittacines, initial encounter*/
,'W6129XD'  /*Other contact with other psittacines, subsequent encounter*/
,'W6129XS'  /*Other contact with other psittacines, sequela*/
,'W6132XA'  /*Struck by chicken, initial encounter*/
,'W6132XD'  /*Struck by chicken, subsequent encounter*/
,'W6132XS'  /*Struck by chicken, sequela*/
,'W6133XA'  /*Pecked by chicken, initial encounter*/
,'W6133XD'  /*Pecked by chicken, subsequent encounter*/
,'W6133XS'  /*Pecked by chicken, sequela*/
,'W6139XA'  /*Other contact with chicken, initial encounter*/
,'W6139XD'  /*Other contact with chicken, subsequent encounter*/
,'W6139XS'  /*Other contact with chicken, sequela*/
,'W6142XA'  /*Struck by turkey, initial encounter*/
,'W6142XD'  /*Struck by turkey, subsequent encounter*/
,'W6142XS'  /*Struck by turkey, sequela*/
,'W6143XA'  /*Pecked by turkey, initial encounter*/
,'W6143XD'  /*Pecked by turkey, subsequent encounter*/
,'W6143XS'  /*Pecked by turkey, sequela*/
,'W6149XA'  /*Other contact with turkey, initial encounter*/
,'W6149XD'  /*Other contact with turkey, subsequent encounter*/
,'W6149XS'  /*Other contact with turkey, sequela*/
,'W6151XA'  /*Bitten by goose, initial encounter*/
,'W6151XD'  /*Bitten by goose, subsequent encounter*/
,'W6151XS'  /*Bitten by goose, sequela*/
,'W6152XA'  /*Struck by goose, initial encounter*/
,'W6152XD'  /*Struck by goose, subsequent encounter*/
,'W6152XS'  /*Struck by goose, sequela*/
,'W6159XA'  /*Other contact with goose, initial encounter*/
,'W6159XD'  /*Other contact with goose, subsequent encounter*/
,'W6159XS'  /*Other contact with goose, sequela*/
,'W6161XA'  /*Bitten by duck, initial encounter*/
,'W6161XD'  /*Bitten by duck, subsequent encounter*/
,'W6161XS'  /*Bitten by duck, sequela*/
,'W6162XA'  /*Struck by duck, initial encounter*/
,'W6162XD'  /*Struck by duck, subsequent encounter*/
,'W6162XS'  /*Struck by duck, sequela*/
,'W6169XA'  /*Other contact with duck, initial encounter*/
,'W6169XD'  /*Other contact with duck, subsequent encounter*/
,'W6169XS'  /*Other contact with duck, sequela*/
,'W6191XA'  /*Bitten by other birds, initial encounter*/
,'W6191XD'  /*Bitten by other birds, subsequent encounter*/
,'W6191XS'  /*Bitten by other birds, sequela*/
,'W6192XA'  /*Struck by other birds, initial encounter*/
,'W6192XD'  /*Struck by other birds, subsequent encounter*/
,'W6192XS'  /*Struck by other birds, sequela*/
,'W6199XA'  /*Other contact with other birds, initial encounter*/
,'W6199XD'  /*Other contact with other birds, subsequent encounter*/
,'W6199XS'  /*Other contact with other birds, sequela*/
,'W620XXA'  /*Contact with nonvenomous frogs, initial encounter*/
,'W620XXD'  /*Contact with nonvenomous frogs, subsequent encounter*/
,'W620XXS'  /*Contact with nonvenomous frogs, sequela*/
,'W621XXA'  /*Contact with nonvenomous toads, initial encounter*/
,'W621XXD'  /*Contact with nonvenomous toads, subsequent encounter*/
,'W621XXS'  /*Contact with nonvenomous toads, sequela*/
,'W629XXA'  /*Contact with other nonvenomous amphibians, initial encounter*/
,'W629XXD'  /*Contact with other nonvenomous amphibians, subsequent encounter*/
,'W629XXS'  /*Contact with other nonvenomous amphibians, sequela*/
,'W64XXXA'  /*Exposure to other animate mechanical forces, initial encounter*/
,'W64XXXD'  /*Exposure to other animate mechanical forces, subsequent encounter*/
,'W64XXXS'  /*Exposure to other animate mechanical forces, sequela*/
,'W65XXXD'  /*Accidental drowning and submersion while in bath-tub, subsequent encounter*/
,'W65XXXS'  /*Accidental drowning and submersion while in bath-tub, sequela*/
,'W67XXXD'  /*Accidental drowning and submersion while in swimming-pool, subsequent encounter*/
,'W67XXXS'  /*Accidental drowning and submersion while in swimming-pool, sequela*/
,'W69XXXA'  /*Accidental drowning and submersion while in natural water, initial encounter*/
,'W69XXXD'  /*Accidental drowning and submersion while in natural water, subsequent encounter*/
,'W69XXXS'  /*Accidental drowning and submersion while in natural water, sequela*/
,'W73XXXA'  /*Other specified cause of accidental non-transport drowning and submersion, initial encounter*/
,'W73XXXD'  /*Other specified cause of accidental non-transport drowning and submersion, subsequent encounter*/
,'W73XXXS'  /*Other specified cause of accidental non-transport drowning and submersion, sequela*/
,'W74XXXA'  /*Unspecified cause of accidental drowning and submersion, initial encounter*/
,'W74XXXD'  /*Unspecified cause of accidental drowning and submersion, subsequent encounter*/
,'W74XXXS'  /*Unspecified cause of accidental drowning and submersion, sequela*/
,'W85XXXD'  /*Exposure to electric transmission lines, subsequent encounter*/
,'W85XXXS'  /*Exposure to electric transmission lines, sequela*/
,'W860XXD'  /*Exposure to domestic wiring and appliances, subsequent encounter*/
,'W860XXS'  /*Exposure to domestic wiring and appliances, sequela*/
,'W861XXD'  /*Exposure to industrial wiring, appliances and electrical machinery, subsequent encounter*/
,'W861XXS'  /*Exposure to industrial wiring, appliances and electrical machinery, sequela*/
,'W868XXD'  /*Exposure to other electric current, subsequent encounter*/
,'W868XXS'  /*Exposure to other electric current, sequela*/
,'W880XXD'  /*Exposure to X-rays, subsequent encounter*/
,'W880XXS'  /*Exposure to X-rays, sequela*/
,'W881XXD'  /*Exposure to radioactive isotopes, subsequent encounter*/
,'W881XXS'  /*Exposure to radioactive isotopes, sequela*/
,'W888XXD'  /*Exposure to other ionizing radiation, subsequent encounter*/
,'W888XXS'  /*Exposure to other ionizing radiation, sequela*/
,'W890XXA'  /*Exposure to welding light (arc), initial encounter*/
,'W890XXD'  /*Exposure to welding light (arc), subsequent encounter*/
,'W890XXS'  /*Exposure to welding light (arc), sequela*/
,'W891XXA'  /*Exposure to tanning bed, initial encounter*/
,'W891XXD'  /*Exposure to tanning bed, subsequent encounter*/
,'W891XXS'  /*Exposure to tanning bed, sequela*/
,'W898XXA'  /*Exposure to other man-made visible and ultraviolet light, initial encounter*/
,'W898XXD'  /*Exposure to other man-made visible and ultraviolet light, subsequent encounter*/
,'W898XXS'  /*Exposure to other man-made visible and ultraviolet light, sequela*/
,'W899XXA'  /*Exposure to unspecified man-made visible and ultraviolet light, initial encounter*/
,'W899XXD'  /*Exposure to unspecified man-made visible and ultraviolet light, subsequent encounter*/
,'W899XXS'  /*Exposure to unspecified man-made visible and ultraviolet light, sequela*/
,'W900XXD'  /*Exposure to radiofrequency, subsequent encounter*/
,'W900XXS'  /*Exposure to radiofrequency, sequela*/
,'W901XXD'  /*Exposure to infrared radiation, subsequent encounter*/
,'W901XXS'  /*Exposure to infrared radiation, sequela*/
,'W902XXD'  /*Exposure to laser radiation, subsequent encounter*/
,'W902XXS'  /*Exposure to laser radiation, sequela*/
,'W908XXD'  /*Exposure to other nonionizing radiation, subsequent encounter*/
,'W908XXS'  /*Exposure to other nonionizing radiation, sequela*/
,'W92XXXA'  /*Exposure to excessive heat of man-made origin, initial encounter*/
,'W92XXXD'  /*Exposure to excessive heat of man-made origin, subsequent encounter*/
,'W92XXXS'  /*Exposure to excessive heat of man-made origin, sequela*/
,'W9301XA'  /*Contact with dry ice, initial encounter*/
,'W9301XD'  /*Contact with dry ice, subsequent encounter*/
,'W9301XS'  /*Contact with dry ice, sequela*/
,'W9302XA'  /*Inhalation of dry ice, initial encounter*/
,'W9302XD'  /*Inhalation of dry ice, subsequent encounter*/
,'W9302XS'  /*Inhalation of dry ice, sequela*/
,'W9311XA'  /*Contact with liquid air, initial encounter*/
,'W9311XD'  /*Contact with liquid air, subsequent encounter*/
,'W9311XS'  /*Contact with liquid air, sequela*/
,'W9312XA'  /*Inhalation of liquid air, initial encounter*/
,'W9312XD'  /*Inhalation of liquid air, subsequent encounter*/
,'W9312XS'  /*Inhalation of liquid air, sequela*/
,'W932XXA'  /*Prolonged exposure in deep freeze unit or refrigerator, initial encounter*/
,'W932XXD'  /*Prolonged exposure in deep freeze unit or refrigerator, subsequent encounter*/
,'W932XXS'  /*Prolonged exposure in deep freeze unit or refrigerator, sequela*/
,'W938XXA'  /*Exposure to other excessive cold of man-made origin, initial encounter*/
,'W938XXD'  /*Exposure to other excessive cold of man-made origin, subsequent encounter*/
,'W938XXS'  /*Exposure to other excessive cold of man-made origin, sequela*/
,'W940XXA'  /*Exposure to prolonged high air pressure, initial encounter*/
,'W940XXD'  /*Exposure to prolonged high air pressure, subsequent encounter*/
,'W940XXS'  /*Exposure to prolonged high air pressure, sequela*/
,'W9411XA'  /*Exposure to residence or prolonged visit at high altitude, initial encounter*/
,'W9411XD'  /*Exposure to residence or prolonged visit at high altitude, subsequent encounter*/
,'W9411XS'  /*Exposure to residence or prolonged visit at high altitude, sequela*/
,'W9412XA'  /*Exposure to other prolonged low air pressure, initial encounter*/
,'W9412XD'  /*Exposure to other prolonged low air pressure, subsequent encounter*/
,'W9412XS'  /*Exposure to other prolonged low air pressure, sequela*/
,'W9421XA'  /*Exposure to reduction in atmospheric pressure while surfacing from deep-water diving, initial encounter*/
,'W9421XD'  /*Exposure to reduction in atmospheric pressure while surfacing from deep-water diving, subsequent encounter*/
,'W9421XS'  /*Exposure to reduction in atmospheric pressure while surfacing from deep-water diving, sequela*/
,'W9422XA'  /*Exposure to reduction in atmospheric pressure while surfacing from underground, initial encounter*/
,'W9422XD'  /*Exposure to reduction in atmospheric pressure while surfacing from underground, subsequent encounter*/
,'W9422XS'  /*Exposure to reduction in atmospheric pressure while surfacing from underground, sequela*/
,'W9423XA'  /*Exposure to sudden change in air pressure in aircraft during ascent, initial encounter*/
,'W9423XD'  /*Exposure to sudden change in air pressure in aircraft during ascent, subsequent encounter*/
,'W9423XS'  /*Exposure to sudden change in air pressure in aircraft during ascent, sequela*/
,'W9429XA'  /*Exposure to other rapid changes in air pressure during ascent, initial encounter*/
,'W9429XD'  /*Exposure to other rapid changes in air pressure during ascent, subsequent encounter*/
,'W9429XS'  /*Exposure to other rapid changes in air pressure during ascent, sequela*/
,'W9431XA'  /*Exposure to sudden change in air pressure in aircraft during descent, initial encounter*/
,'W9431XD'  /*Exposure to sudden change in air pressure in aircraft during descent, subsequent encounter*/
,'W9431XS'  /*Exposure to sudden change in air pressure in aircraft during descent, sequela*/
,'W9432XA'  /*Exposure to high air pressure from rapid descent in water, initial encounter*/
,'W9432XD'  /*Exposure to high air pressure from rapid descent in water, subsequent encounter*/
,'W9432XS'  /*Exposure to high air pressure from rapid descent in water, sequela*/
,'W9439XA'  /*Exposure to other rapid changes in air pressure during descent, initial encounter*/
,'W9439XD'  /*Exposure to other rapid changes in air pressure during descent, subsequent encounter*/
,'W9439XS'  /*Exposure to other rapid changes in air pressure during descent, sequela*/
,'W99XXXA'  /*Exposure to other man-made environmental factors, initial encounter*/
,'W99XXXD'  /*Exposure to other man-made environmental factors, subsequent encounter*/
,'W99XXXS'  /*Exposure to other man-made environmental factors, sequela*/
,'X020XXD'  /*Exposure to flames in controlled fire in building or structure, subsequent encounter*/
,'X020XXS'  /*Exposure to flames in controlled fire in building or structure, sequela*/
,'X021XXD'  /*Exposure to smoke in controlled fire in building or structure, subsequent encounter*/
,'X021XXS'  /*Exposure to smoke in controlled fire in building or structure, sequela*/
,'X022XXD'  /*Injury due to collapse of burning building or structure in controlled fire, subsequent encounter*/
,'X022XXS'  /*Injury due to collapse of burning building or structure in controlled fire, sequela*/
,'X023XXD'  /*Fall from burning building or structure in controlled fire, subsequent encounter*/
,'X023XXS'  /*Fall from burning building or structure in controlled fire, sequela*/
,'X024XXD'  /*Hit by object from burning building or structure in controlled fire, subsequent encounter*/
,'X024XXS'  /*Hit by object from burning building or structure in controlled fire, sequela*/
,'X025XXD'  /*Jump from burning building or structure in controlled fire, subsequent encounter*/
,'X025XXS'  /*Jump from burning building or structure in controlled fire, sequela*/
,'X028XXD'  /*Other exposure to controlled fire in building or structure, subsequent encounter*/
,'X028XXS'  /*Other exposure to controlled fire in building or structure, sequela*/
,'X030XXD'  /*Exposure to flames in controlled fire, not in building or structure, subsequent encounter*/
,'X030XXS'  /*Exposure to flames in controlled fire, not in building or structure, sequela*/
,'X031XXD'  /*Exposure to smoke in controlled fire, not in building or structure, subsequent encounter*/
,'X031XXS'  /*Exposure to smoke in controlled fire, not in building or structure, sequela*/
,'X033XXD'  /*Fall due to controlled fire, not in building or structure, subsequent encounter*/
,'X033XXS'  /*Fall due to controlled fire, not in building or structure, sequela*/
,'X034XXD'  /*Hit by object due to controlled fire, not in building or structure, subsequent encounter*/
,'X034XXS'  /*Hit by object due to controlled fire, not in building or structure, sequela*/
,'X038XXD'  /*Other exposure to controlled fire, not in building or structure, subsequent encounter*/
,'X038XXS'  /*Other exposure to controlled fire, not in building or structure, sequela*/
,'X04XXXD'  /*Exposure to ignition of highly flammable material, subsequent encounter*/
,'X04XXXS'  /*Exposure to ignition of highly flammable material, sequela*/
,'X30XXXA'  /*Exposure to excessive natural heat, initial encounter*/
,'X30XXXD'  /*Exposure to excessive natural heat, subsequent encounter*/
,'X30XXXS'  /*Exposure to excessive natural heat, sequela*/
,'X31XXXA'  /*Exposure to excessive natural cold, initial encounter*/
,'X31XXXD'  /*Exposure to excessive natural cold, subsequent encounter*/
,'X31XXXS'  /*Exposure to excessive natural cold, sequela*/
,'X32XXXA'  /*Exposure to sunlight, initial encounter*/
,'X32XXXD'  /*Exposure to sunlight, subsequent encounter*/
,'X32XXXS'  /*Exposure to sunlight, sequela*/
,'X34XXXD'  /*Earthquake, subsequent encounter*/
,'X34XXXS'  /*Earthquake, sequela*/
,'X35XXXA'  /*Volcanic eruption, initial encounter*/
,'X35XXXD'  /*Volcanic eruption, subsequent encounter*/
,'X35XXXS'  /*Volcanic eruption, sequela*/
,'X360XXD'  /*Collapse of dam or man-made structure causing earth movement, subsequent encounter*/
,'X360XXS'  /*Collapse of dam or man-made structure causing earth movement, sequela*/
,'X361XXD'  /*Avalanche, landslide, or mudslide, subsequent encounter*/
,'X361XXS'  /*Avalanche, landslide, or mudslide, sequela*/
,'X370XXD'  /*Hurricane, subsequent encounter*/
,'X370XXS'  /*Hurricane, sequela*/
,'X371XXD'  /*Tornado, subsequent encounter*/
,'X371XXS'  /*Tornado, sequela*/
,'X372XXD'  /*Blizzard (snow)(ice), subsequent encounter*/
,'X372XXS'  /*Blizzard (snow)(ice), sequela*/
,'X373XXD'  /*Dust storm, subsequent encounter*/
,'X373XXS'  /*Dust storm, sequela*/
,'X3741XD'  /*Tidal wave due to earthquake or volcanic eruption, subsequent encounter*/
,'X3741XS'  /*Tidal wave due to earthquake or volcanic eruption, sequela*/
,'X3742XD'  /*Tidal wave due to storm, subsequent encounter*/
,'X3742XS'  /*Tidal wave due to storm, sequela*/
,'X3743XD'  /*Tidal wave due to landslide, subsequent encounter*/
,'X3743XS'  /*Tidal wave due to landslide, sequela*/
,'X378XXD'  /*Other cataclysmic storms, subsequent encounter*/
,'X378XXS'  /*Other cataclysmic storms, sequela*/
,'X379XXD'  /*Unspecified cataclysmic storm, subsequent encounter*/
,'X379XXS'  /*Unspecified cataclysmic storm, sequela*/
,'X38XXXD'  /*Flood, subsequent encounter*/
,'X38XXXS'  /*Flood, sequela*/
,'X3901XA'  /*Exposure to radon, initial encounter*/
,'X3901XD'  /*Exposure to radon, subsequent encounter*/
,'X3901XS'  /*Exposure to radon, sequela*/
,'X3908XA'  /*Exposure to other natural radiation, initial encounter*/
,'X3908XD'  /*Exposure to other natural radiation, subsequent encounter*/
,'X3908XS'  /*Exposure to other natural radiation, sequela*/
,'X398XXA'  /*Other exposure to forces of nature, initial encounter*/
,'X398XXD'  /*Other exposure to forces of nature, subsequent encounter*/
,'X398XXS'  /*Other exposure to forces of nature, sequela*/
,'X500XXA'  /*Overexertion from strenuous movement or load, initial encounter*/
,'X500XXD'  /*Overexertion from strenuous movement or load, subsequent encounter*/
,'X500XXS'  /*Overexertion from strenuous movement or load, sequela*/
,'X501XXA'  /*Overexertion from prolonged static or awkward postures, initial encounter*/
,'X501XXD'  /*Overexertion from prolonged static or awkward postures, subsequent encounter*/
,'X501XXS'  /*Overexertion from prolonged static or awkward postures, sequela*/
,'X503XXA'  /*Overexertion from repetitive movements, initial encounter*/
,'X503XXD'  /*Overexertion from repetitive movements, subsequent encounter*/
,'X503XXS'  /*Overexertion from repetitive movements, sequela*/
,'X509XXA'  /*Other and unspecified overexertion or strenuous movements or postures, initial encounter*/
,'X509XXD'  /*Other and unspecified overexertion or strenuous movements or postures, subsequent encounter*/
,'X509XXS'  /*Other and unspecified overexertion or strenuous movements or postures, sequela*/
,'X52XXXA'  /*Prolonged stay in weightless environment, initial encounter*/
,'X52XXXD'  /*Prolonged stay in weightless environment, subsequent encounter*/
,'X52XXXS'  /*Prolonged stay in weightless environment, sequela*/
,'X711XXD'  /*Intentional self-harm by drowning and submersion while in swimming pool, subsequent encounter*/
,'X711XXS'  /*Intentional self-harm by drowning and submersion while in swimming pool, sequela*/
,'X712XXD'  /*Intentional self-harm by drowning and submersion after jump into swimming pool, subsequent encounter*/
,'X712XXS'  /*Intentional self-harm by drowning and submersion after jump into swimming pool, sequela*/
,'X713XXA'  /*Intentional self-harm by drowning and submersion in natural water, initial encounter*/
,'X713XXD'  /*Intentional self-harm by drowning and submersion in natural water, subsequent encounter*/
,'X713XXS'  /*Intentional self-harm by drowning and submersion in natural water, sequela*/
,'X718XXA'  /*Other intentional self-harm by drowning and submersion, initial encounter*/
,'X718XXD'  /*Other intentional self-harm by drowning and submersion, subsequent encounter*/
,'X718XXS'  /*Other intentional self-harm by drowning and submersion, sequela*/
,'X719XXA'  /*Intentional self-harm by drowning and submersion, unspecified, initial encounter*/
,'X719XXD'  /*Intentional self-harm by drowning and submersion, unspecified, subsequent encounter*/
,'X719XXS'  /*Intentional self-harm by drowning and submersion, unspecified, sequela*/
,'X72XXXA'  /*Intentional self-harm by handgun discharge, initial encounter*/
,'X72XXXD'  /*Intentional self-harm by handgun discharge, subsequent encounter*/
,'X72XXXS'  /*Intentional self-harm by handgun discharge, sequela*/
,'X730XXA'  /*Intentional self-harm by shotgun discharge, initial encounter*/
,'X730XXD'  /*Intentional self-harm by shotgun discharge, subsequent encounter*/
,'X730XXS'  /*Intentional self-harm by shotgun discharge, sequela*/
,'X731XXA'  /*Intentional self-harm by hunting rifle discharge, initial encounter*/
,'X731XXD'  /*Intentional self-harm by hunting rifle discharge, subsequent encounter*/
,'X731XXS'  /*Intentional self-harm by hunting rifle discharge, sequela*/
,'X732XXA'  /*Intentional self-harm by machine gun discharge, initial encounter*/
,'X732XXD'  /*Intentional self-harm by machine gun discharge, subsequent encounter*/
,'X732XXS'  /*Intentional self-harm by machine gun discharge, sequela*/
,'X738XXA'  /*Intentional self-harm by other larger firearm discharge, initial encounter*/
,'X738XXD'  /*Intentional self-harm by other larger firearm discharge, subsequent encounter*/
,'X738XXS'  /*Intentional self-harm by other larger firearm discharge, sequela*/
,'X739XXA'  /*Intentional self-harm by unspecified larger firearm discharge, initial encounter*/
,'X739XXD'  /*Intentional self-harm by unspecified larger firearm discharge, subsequent encounter*/
,'X739XXS'  /*Intentional self-harm by unspecified larger firearm discharge, sequela*/
,'X7401XA'  /*Intentional self-harm by airgun, initial encounter*/
,'X7401XD'  /*Intentional self-harm by airgun, subsequent encounter*/
,'X7401XS'  /*Intentional self-harm by airgun, sequela*/
,'X7402XA'  /*Intentional self-harm by paintball gun, initial encounter*/
,'X7402XD'  /*Intentional self-harm by paintball gun, subsequent encounter*/
,'X7402XS'  /*Intentional self-harm by paintball gun, sequela*/
,'X7409XA'  /*Intentional self-harm by other gas, air or spring-operated gun, initial encounter*/
,'X7409XD'  /*Intentional self-harm by other gas, air or spring-operated gun, subsequent encounter*/
,'X7409XS'  /*Intentional self-harm by other gas, air or spring-operated gun, sequela*/
,'X748XXA'  /*Intentional self-harm by other firearm discharge, initial encounter*/
,'X748XXD'  /*Intentional self-harm by other firearm discharge, subsequent encounter*/
,'X748XXS'  /*Intentional self-harm by other firearm discharge, sequela*/
,'X749XXA'  /*Intentional self-harm by unspecified firearm discharge, initial encounter*/
,'X749XXD'  /*Intentional self-harm by unspecified firearm discharge, subsequent encounter*/
,'X749XXS'  /*Intentional self-harm by unspecified firearm discharge, sequela*/
,'X75XXXA'  /*Intentional self-harm by explosive material, initial encounter*/
,'X75XXXD'  /*Intentional self-harm by explosive material, subsequent encounter*/
,'X75XXXS'  /*Intentional self-harm by explosive material, sequela*/
,'X76XXXA'  /*Intentional self-harm by smoke, fire and flames, initial encounter*/
,'X76XXXD'  /*Intentional self-harm by smoke, fire and flames, subsequent encounter*/
,'X76XXXS'  /*Intentional self-harm by smoke, fire and flames, sequela*/
,'X770XXA'  /*Intentional self-harm by steam or hot vapors, initial encounter*/
,'X770XXD'  /*Intentional self-harm by steam or hot vapors, subsequent encounter*/
,'X770XXS'  /*Intentional self-harm by steam or hot vapors, sequela*/
,'X771XXA'  /*Intentional self-harm by hot tap water, initial encounter*/
,'X771XXD'  /*Intentional self-harm by hot tap water, subsequent encounter*/
,'X771XXS'  /*Intentional self-harm by hot tap water, sequela*/
,'X772XXA'  /*Intentional self-harm by other hot fluids, initial encounter*/
,'X772XXD'  /*Intentional self-harm by other hot fluids, subsequent encounter*/
,'X772XXS'  /*Intentional self-harm by other hot fluids, sequela*/
,'X773XXA'  /*Intentional self-harm by hot household appliances, initial encounter*/
,'X773XXD'  /*Intentional self-harm by hot household appliances, subsequent encounter*/
,'X773XXS'  /*Intentional self-harm by hot household appliances, sequela*/
,'X778XXA'  /*Intentional self-harm by other hot objects, initial encounter*/
,'X778XXD'  /*Intentional self-harm by other hot objects, subsequent encounter*/
,'X778XXS'  /*Intentional self-harm by other hot objects, sequela*/
,'X779XXA'  /*Intentional self-harm by unspecified hot objects, initial encounter*/
,'X779XXD'  /*Intentional self-harm by unspecified hot objects, subsequent encounter*/
,'X779XXS'  /*Intentional self-harm by unspecified hot objects, sequela*/
,'X810XXA'  /*Intentional self-harm by jumping or lying in front of motor vehicle, initial encounter*/
,'X810XXD'  /*Intentional self-harm by jumping or lying in front of motor vehicle, subsequent encounter*/
,'X810XXS'  /*Intentional self-harm by jumping or lying in front of motor vehicle, sequela*/
,'X811XXA'  /*Intentional self-harm by jumping or lying in front of (subway) train, initial encounter*/
,'X811XXD'  /*Intentional self-harm by jumping or lying in front of (subway) train, subsequent encounter*/
,'X811XXS'  /*Intentional self-harm by jumping or lying in front of (subway) train, sequela*/
,'X818XXA'  /*Intentional self-harm by jumping or lying in front of other moving object, initial encounter*/
,'X818XXD'  /*Intentional self-harm by jumping or lying in front of other moving object, subsequent encounter*/
,'X818XXS'  /*Intentional self-harm by jumping or lying in front of other moving object, sequela*/
,'X820XXA'  /*Intentional collision of motor vehicle with other motor vehicle, initial encounter*/
,'X820XXD'  /*Intentional collision of motor vehicle with other motor vehicle, subsequent encounter*/
,'X820XXS'  /*Intentional collision of motor vehicle with other motor vehicle, sequela*/
,'X821XXA'  /*Intentional collision of motor vehicle with train, initial encounter*/
,'X821XXD'  /*Intentional collision of motor vehicle with train, subsequent encounter*/
,'X821XXS'  /*Intentional collision of motor vehicle with train, sequela*/
,'X822XXA'  /*Intentional collision of motor vehicle with tree, initial encounter*/
,'X822XXD'  /*Intentional collision of motor vehicle with tree, subsequent encounter*/
,'X822XXS'  /*Intentional collision of motor vehicle with tree, sequela*/
,'X828XXA'  /*Other intentional self-harm by crashing of motor vehicle, initial encounter*/
,'X828XXD'  /*Other intentional self-harm by crashing of motor vehicle, subsequent encounter*/
,'X828XXS'  /*Other intentional self-harm by crashing of motor vehicle, sequela*/
,'X830XXA'  /*Intentional self-harm by crashing of aircraft, initial encounter*/
,'X830XXD'  /*Intentional self-harm by crashing of aircraft, subsequent encounter*/
,'X830XXS'  /*Intentional self-harm by crashing of aircraft, sequela*/
,'X831XXA'  /*Intentional self-harm by electrocution, initial encounter*/
,'X831XXD'  /*Intentional self-harm by electrocution, subsequent encounter*/
,'X831XXS'  /*Intentional self-harm by electrocution, sequela*/
,'X832XXA'  /*Intentional self-harm by exposure to extremes of cold, initial encounter*/
,'X832XXD'  /*Intentional self-harm by exposure to extremes of cold, subsequent encounter*/
,'X832XXS'  /*Intentional self-harm by exposure to extremes of cold, sequela*/
,'X838XXA'  /*Intentional self-harm by other specified means, initial encounter*/
,'X838XXD'  /*Intentional self-harm by other specified means, subsequent encounter*/
,'X838XXS'  /*Intentional self-harm by other specified means, sequela*/
,'X920XXD'  /*Assault by drowning and submersion while in bathtub, subsequent encounter*/
,'X920XXS'  /*Assault by drowning and submersion while in bathtub, sequela*/
,'X921XXD'  /*Assault by drowning and submersion while in swimming pool, subsequent encounter*/
,'X921XXS'  /*Assault by drowning and submersion while in swimming pool, sequela*/
,'X922XXD'  /*Assault by drowning and submersion after push into swimming pool, subsequent encounter*/
,'X922XXS'  /*Assault by drowning and submersion after push into swimming pool, sequela*/
,'X923XXD'  /*Assault by drowning and submersion in natural water, subsequent encounter*/
,'X923XXS'  /*Assault by drowning and submersion in natural water, sequela*/
,'X928XXD'  /*Other assault by drowning and submersion, subsequent encounter*/
,'X928XXS'  /*Other assault by drowning and submersion, sequela*/
,'X929XXD'  /*Assault by drowning and submersion, unspecified, subsequent encounter*/
,'X929XXS'  /*Assault by drowning and submersion, unspecified, sequela*/
,'X93XXXD'  /*Assault by handgun discharge, subsequent encounter*/
,'X93XXXS'  /*Assault by handgun discharge, sequela*/
,'X940XXD'  /*Assault by shotgun, subsequent encounter*/
,'X940XXS'  /*Assault by shotgun, sequela*/
,'X941XXD'  /*Assault by hunting rifle, subsequent encounter*/
,'X941XXS'  /*Assault by hunting rifle, sequela*/
,'X942XXD'  /*Assault by machine gun, subsequent encounter*/
,'X942XXS'  /*Assault by machine gun, sequela*/
,'X948XXD'  /*Assault by other larger firearm discharge, subsequent encounter*/
,'X948XXS'  /*Assault by other larger firearm discharge, sequela*/
,'X949XXD'  /*Assault by unspecified larger firearm discharge, subsequent encounter*/
,'X949XXS'  /*Assault by unspecified larger firearm discharge, sequela*/
,'X9501XD'  /*Assault by airgun discharge, subsequent encounter*/
,'X9501XS'  /*Assault by airgun discharge, sequela*/
,'X9502XD'  /*Assault by paintball gun discharge, subsequent encounter*/
,'X9502XS'  /*Assault by paintball gun discharge, sequela*/
,'X9509XD'  /*Assault by other gas, air or spring-operated gun, subsequent encounter*/
,'X9509XS'  /*Assault by other gas, air or spring-operated gun, sequela*/
,'X958XXD'  /*Assault by other firearm discharge, subsequent encounter*/
,'X958XXS'  /*Assault by other firearm discharge, sequela*/
,'X959XXD'  /*Assault by unspecified firearm discharge, subsequent encounter*/
,'X959XXS'  /*Assault by unspecified firearm discharge, sequela*/
,'X960XXD'  /*Assault by antipersonnel bomb, subsequent encounter*/
,'X960XXS'  /*Assault by antipersonnel bomb, sequela*/
,'X961XXD'  /*Assault by gasoline bomb, subsequent encounter*/
,'X961XXS'  /*Assault by gasoline bomb, sequela*/
,'X962XXD'  /*Assault by letter bomb, subsequent encounter*/
,'X962XXS'  /*Assault by letter bomb, sequela*/
,'X963XXD'  /*Assault by fertilizer bomb, subsequent encounter*/
,'X963XXS'  /*Assault by fertilizer bomb, sequela*/
,'X964XXD'  /*Assault by pipe bomb, subsequent encounter*/
,'X964XXS'  /*Assault by pipe bomb, sequela*/
,'X968XXD'  /*Assault by other specified explosive, subsequent encounter*/
,'X968XXS'  /*Assault by other specified explosive, sequela*/
,'X969XXD'  /*Assault by unspecified explosive, subsequent encounter*/
,'X969XXS'  /*Assault by unspecified explosive, sequela*/
,'X97XXXD'  /*Assault by smoke, fire and flames, subsequent encounter*/
,'X97XXXS'  /*Assault by smoke, fire and flames, sequela*/
,'X980XXA'  /*Assault by steam or hot vapors, initial encounter*/
,'X980XXD'  /*Assault by steam or hot vapors, subsequent encounter*/
,'X980XXS'  /*Assault by steam or hot vapors, sequela*/
,'X981XXD'  /*Assault by hot tap water, subsequent encounter*/
,'X981XXS'  /*Assault by hot tap water, sequela*/
,'X982XXD'  /*Assault by hot fluids, subsequent encounter*/
,'X982XXS'  /*Assault by hot fluids, sequela*/
,'X983XXS'  /*Assault by hot household appliances, sequela*/
,'X988XXD'  /*Assault by other hot objects, subsequent encounter*/
,'X988XXS'  /*Assault by other hot objects, sequela*/
,'X989XXD'  /*Assault by unspecified hot objects, subsequent encounter*/
,'X989XXS'  /*Assault by unspecified hot objects, sequela*/
,'X990XXD'  /*Assault by sharp glass, subsequent encounter*/
,'X990XXS'  /*Assault by sharp glass, sequela*/
,'X991XXD'  /*Assault by knife, subsequent encounter*/
,'X991XXS'  /*Assault by knife, sequela*/
,'X992XXD'  /*Assault by sword or dagger, subsequent encounter*/
,'X992XXS'  /*Assault by sword or dagger, sequela*/
,'X998XXD'  /*Assault by other sharp object, subsequent encounter*/
,'X998XXS'  /*Assault by other sharp object, sequela*/
,'X999XXD'  /*Assault by unspecified sharp object, subsequent encounter*/
,'X999XXS'  /*Assault by unspecified sharp object, sequela*/
,'Y00XXXD'  /*Assault by blunt object, subsequent encounter*/
,'Y00XXXS'  /*Assault by blunt object, sequela*/
,'Y01XXXD'  /*Assault by pushing from high place, subsequent encounter*/
,'Y01XXXS'  /*Assault by pushing from high place, sequela*/
,'Y020XXA'  /*Assault by pushing or placing victim in front of motor vehicle, initial encounter*/
,'Y020XXD'  /*Assault by pushing or placing victim in front of motor vehicle, subsequent encounter*/
,'Y020XXS'  /*Assault by pushing or placing victim in front of motor vehicle, sequela*/
,'Y021XXA'  /*Assault by pushing or placing victim in front of (subway) train, initial encounter*/
,'Y021XXD'  /*Assault by pushing or placing victim in front of (subway) train, subsequent encounter*/
,'Y021XXS'  /*Assault by pushing or placing victim in front of (subway) train, sequela*/
,'Y028XXA'  /*Assault by pushing or placing victim in front of other moving object, initial encounter*/
,'Y028XXD'  /*Assault by pushing or placing victim in front of other moving object, subsequent encounter*/
,'Y028XXS'  /*Assault by pushing or placing victim in front of other moving object, sequela*/
,'Y030XXA'  /*Assault by being hit or run over by motor vehicle, initial encounter*/
,'Y030XXD'  /*Assault by being hit or run over by motor vehicle, subsequent encounter*/
,'Y030XXS'  /*Assault by being hit or run over by motor vehicle, sequela*/
,'Y038XXA'  /*Other assault by crashing of motor vehicle, initial encounter*/
,'Y038XXD'  /*Other assault by crashing of motor vehicle, subsequent encounter*/
,'Y038XXS'  /*Other assault by crashing of motor vehicle, sequela*/
,'Y040XXD'  /*Assault by unarmed brawl or fight, subsequent encounter*/
,'Y040XXS'  /*Assault by unarmed brawl or fight, sequela*/
,'Y041XXD'  /*Assault by human bite, subsequent encounter*/
,'Y041XXS'  /*Assault by human bite, sequela*/
,'Y042XXD'  /*Assault by strike against or bumped into by another person, subsequent encounter*/
,'Y042XXS'  /*Assault by strike against or bumped into by another person, sequela*/
,'Y048XXD'  /*Assault by other bodily force, subsequent encounter*/
,'Y048XXS'  /*Assault by other bodily force, sequela*/
,'Y0701'  /*Husband, perpetrator of maltreatment and neglect*/
,'Y0702'  /*Wife, perpetrator of maltreatment and neglect*/
,'Y0703'  /*Male partner, perpetrator of maltreatment and neglect*/
,'Y0704'  /*Female partner, perpetrator of maltreatment and neglect*/
,'Y0711'  /*Biological father, perpetrator of maltreatment and neglect*/
,'Y0712'  /*Biological mother, perpetrator of maltreatment and neglect*/
,'Y0713'  /*Adoptive father, perpetrator of maltreatment and neglect*/
,'Y0714'  /*Adoptive mother, perpetrator of maltreatment and neglect*/
,'Y07410'  /*Brother, perpetrator of maltreatment and neglect*/
,'Y07411'  /*Sister, perpetrator of maltreatment and neglect*/
,'Y07420'  /*Foster father, perpetrator of maltreatment and neglect*/
,'Y07421'  /*Foster mother, perpetrator of maltreatment and neglect*/
,'Y07430'  /*Stepfather, perpetrator of maltreatment and neglect*/
,'Y07432'  /*Male friend of parent (co-residing in household), perpetrator of maltreatment and neglect*/
,'Y07433'  /*Stepmother, perpetrator of maltreatment and neglect*/
,'Y07434'  /*Female friend of parent (co-residing in household), perpetrator of maltreatment and neglect*/
,'Y07435'  /*Stepbrother, perpetrator or maltreatment and neglect*/
,'Y07436'  /*Stepsister, perpetrator of maltreatment and neglect*/
,'Y07490'  /*Male cousin, perpetrator of maltreatment and neglect*/
,'Y07491'  /*Female cousin, perpetrator of maltreatment and neglect*/
,'Y07499'  /*Other family member, perpetrator of maltreatment and neglect*/
,'Y0750'  /*Unspecified non-family member, perpetrator of maltreatment and neglect*/
,'Y07510'  /*At-home childcare provider, perpetrator of maltreatment and neglect*/
,'Y07511'  /*Daycare center childcare provider, perpetrator of maltreatment and neglect*/
,'Y07512'  /*At-home adultcare provider, perpetrator of maltreatment and neglect*/
,'Y07513'  /*Adultcare center provider, perpetrator of maltreatment and neglect*/
,'Y07519'  /*Unspecified daycare provider, perpetrator of maltreatment and neglect*/
,'Y07521'  /*Mental health provider, perpetrator of maltreatment and neglect*/
,'Y07528'  /*Other therapist or healthcare provider, perpetrator of maltreatment and neglect*/
,'Y07529'  /*Unspecified healthcare provider, perpetrator of maltreatment and neglect*/
,'Y0753'  /*Teacher or instructor, perpetrator of maltreatment and neglect*/
,'Y0759'  /*Other non-family member, perpetrator of maltreatment and neglect*/
,'Y079'  /*Unspecified perpetrator of maltreatment and neglect*/
,'Y0801XA'  /*Assault by strike by hockey stick, initial encounter*/
,'Y0801XD'  /*Assault by strike by hockey stick, subsequent encounter*/
,'Y0801XS'  /*Assault by strike by hockey stick, sequela*/
,'Y0802XA'  /*Assault by strike by baseball bat, initial encounter*/
,'Y0802XD'  /*Assault by strike by baseball bat, subsequent encounter*/
,'Y0802XS'  /*Assault by strike by baseball bat, sequela*/
,'Y0809XA'  /*Assault by strike by other specified type of sport equipment, initial encounter*/
,'Y0809XD'  /*Assault by strike by other specified type of sport equipment, subsequent encounter*/
,'Y0809XS'  /*Assault by strike by other specified type of sport equipment, sequela*/
,'Y0881XA'  /*Assault by crashing of aircraft, initial encounter*/
,'Y0881XD'  /*Assault by crashing of aircraft, subsequent encounter*/
,'Y0881XS'  /*Assault by crashing of aircraft, sequela*/
,'Y0889XA'  /*Assault by other specified means, initial encounter*/
,'Y0889XD'  /*Assault by other specified means, subsequent encounter*/
,'Y0889XS'  /*Assault by other specified means, sequela*/
,'Y210XXA'  /*Drowning and submersion while in bathtub, undetermined intent, initial encounter*/
,'Y210XXD'  /*Drowning and submersion while in bathtub, undetermined intent, subsequent encounter*/
,'Y210XXS'  /*Drowning and submersion while in bathtub, undetermined intent, sequela*/
,'Y211XXA'  /*Drowning and submersion after fall into bathtub, undetermined intent, initial encounter*/
,'Y211XXD'  /*Drowning and submersion after fall into bathtub, undetermined intent, subsequent encounter*/
,'Y211XXS'  /*Drowning and submersion after fall into bathtub, undetermined intent, sequela*/
,'Y212XXA'  /*Drowning and submersion while in swimming pool, undetermined intent, initial encounter*/
,'Y212XXD'  /*Drowning and submersion while in swimming pool, undetermined intent, subsequent encounter*/
,'Y212XXS'  /*Drowning and submersion while in swimming pool, undetermined intent, sequela*/
,'Y213XXA'  /*Drowning and submersion after fall into swimming pool, undetermined intent, initial encounter*/
,'Y213XXD'  /*Drowning and submersion after fall into swimming pool, undetermined intent, subsequent encounter*/
,'Y213XXS'  /*Drowning and submersion after fall into swimming pool, undetermined intent, sequela*/
,'Y214XXA'  /*Drowning and submersion in natural water, undetermined intent, initial encounter*/
,'Y214XXD'  /*Drowning and submersion in natural water, undetermined intent, subsequent encounter*/
,'Y214XXS'  /*Drowning and submersion in natural water, undetermined intent, sequela*/
,'Y218XXA'  /*Other drowning and submersion, undetermined intent, initial encounter*/
,'Y218XXD'  /*Other drowning and submersion, undetermined intent, subsequent encounter*/
,'Y218XXS'  /*Other drowning and submersion, undetermined intent, sequela*/
,'Y219XXA'  /*Unspecified drowning and submersion, undetermined intent, initial encounter*/
,'Y219XXD'  /*Unspecified drowning and submersion, undetermined intent, subsequent encounter*/
,'Y219XXS'  /*Unspecified drowning and submersion, undetermined intent, sequela*/
,'Y22XXXD'  /*Handgun discharge, undetermined intent, subsequent encounter*/
,'Y22XXXS'  /*Handgun discharge, undetermined intent, sequela*/
,'Y230XXD'  /*Shotgun discharge, undetermined intent, subsequent encounter*/
,'Y230XXS'  /*Shotgun discharge, undetermined intent, sequela*/
,'Y231XXD'  /*Hunting rifle discharge, undetermined intent, subsequent encounter*/
,'Y231XXS'  /*Hunting rifle discharge, undetermined intent, sequela*/
,'Y232XXD'  /*Military firearm discharge, undetermined intent, subsequent encounter*/
,'Y233XXA'  /*Machine gun discharge, undetermined intent, initial encounter*/
,'Y233XXD'  /*Machine gun discharge, undetermined intent, subsequent encounter*/
,'Y233XXS'  /*Machine gun discharge, undetermined intent, sequela*/
,'Y238XXD'  /*Other larger firearm discharge, undetermined intent, subsequent encounter*/
,'Y238XXS'  /*Other larger firearm discharge, undetermined intent, sequela*/
,'Y239XXA'  /*Unspecified larger firearm discharge, undetermined intent, initial encounter*/
,'Y239XXD'  /*Unspecified larger firearm discharge, undetermined intent, subsequent encounter*/
,'Y239XXS'  /*Unspecified larger firearm discharge, undetermined intent, sequela*/
,'Y240XXA'  /*Airgun discharge, undetermined intent, initial encounter*/
,'Y240XXD'  /*Airgun discharge, undetermined intent, subsequent encounter*/
,'Y240XXS'  /*Airgun discharge, undetermined intent, sequela*/
,'Y248XXA'  /*Other firearm discharge, undetermined intent, initial encounter*/
,'Y248XXD'  /*Other firearm discharge, undetermined intent, subsequent encounter*/
,'Y248XXS'  /*Other firearm discharge, undetermined intent, sequela*/
,'Y249XXD'  /*Unspecified firearm discharge, undetermined intent, subsequent encounter*/
,'Y249XXS'  /*Unspecified firearm discharge, undetermined intent, sequela*/
,'Y30XXXA'  /*Falling, jumping or pushed from a high place, undetermined intent, initial encounter*/
,'Y30XXXD'  /*Falling, jumping or pushed from a high place, undetermined intent, subsequent encounter*/
,'Y30XXXS'  /*Falling, jumping or pushed from a high place, undetermined intent, sequela*/
,'Y32XXXA'  /*Crashing of motor vehicle, undetermined intent, initial encounter*/
,'Y32XXXD'  /*Crashing of motor vehicle, undetermined intent, subsequent encounter*/
,'Y32XXXS'  /*Crashing of motor vehicle, undetermined intent, sequela*/
,'Y35001D'  /*Legal intervention involving unspecified firearm discharge, law enforcement official injured, subsequent encounter*/
,'Y35001S'  /*Legal intervention involving unspecified firearm discharge, law enforcement official injured, sequela*/
,'Y35002D'  /*Legal intervention involving unspecified firearm discharge, bystander injured, subsequent encounter*/
,'Y35002S'  /*Legal intervention involving unspecified firearm discharge, bystander injured, sequela*/
,'Y35003D'  /*Legal intervention involving unspecified firearm discharge, suspect injured, subsequent encounter*/
,'Y35003S'  /*Legal intervention involving unspecified firearm discharge, suspect injured, sequela*/
,'Y35011D'  /*Legal intervention involving injury by machine gun, law enforcement official injured, subsequent encounter*/
,'Y35011S'  /*Legal intervention involving injury by machine gun, law enforcement official injured, sequela*/
,'Y35012D'  /*Legal intervention involving injury by machine gun, bystander injured, subsequent encounter*/
,'Y35012S'  /*Legal intervention involving injury by machine gun, bystander injured, sequela*/
,'Y35013D'  /*Legal intervention involving injury by machine gun, suspect injured, subsequent encounter*/
,'Y35013S'  /*Legal intervention involving injury by machine gun, suspect injured, sequela*/
,'Y35021D'  /*Legal intervention involving injury by handgun, law enforcement official injured, subsequent encounter*/
,'Y35021S'  /*Legal intervention involving injury by handgun, law enforcement official injured, sequela*/
,'Y35022D'  /*Legal intervention involving injury by handgun, bystander injured, subsequent encounter*/
,'Y35022S'  /*Legal intervention involving injury by handgun, bystander injured, sequela*/
,'Y35023D'  /*Legal intervention involving injury by handgun, suspect injured, subsequent encounter*/
,'Y35023S'  /*Legal intervention involving injury by handgun, suspect injured, sequela*/
,'Y35031D'  /*Legal intervention involving injury by rifle pellet, law enforcement official injured, subsequent encounter*/
,'Y35031S'  /*Legal intervention involving injury by rifle pellet, law enforcement official injured, sequela*/
,'Y35032D'  /*Legal intervention involving injury by rifle pellet, bystander injured, subsequent encounter*/
,'Y35032S'  /*Legal intervention involving injury by rifle pellet, bystander injured, sequela*/
,'Y35033D'  /*Legal intervention involving injury by rifle pellet, suspect injured, subsequent encounter*/
,'Y35033S'  /*Legal intervention involving injury by rifle pellet, suspect injured, sequela*/
,'Y35041D'  /*Legal intervention involving injury by rubber bullet, law enforcement official injured, subsequent encounter*/
,'Y35041S'  /*Legal intervention involving injury by rubber bullet, law enforcement official injured, sequela*/
,'Y35042D'  /*Legal intervention involving injury by rubber bullet, bystander injured, subsequent encounter*/
,'Y35042S'  /*Legal intervention involving injury by rubber bullet, bystander injured, sequela*/
,'Y35043D'  /*Legal intervention involving injury by rubber bullet, suspect injured, subsequent encounter*/
,'Y35043S'  /*Legal intervention involving injury by rubber bullet, suspect injured, sequela*/
,'Y35091D'  /*Legal intervention involving other firearm discharge, law enforcement official injured, subsequent encounter*/
,'Y35091S'  /*Legal intervention involving other firearm discharge, law enforcement official injured, sequela*/
,'Y35092D'  /*Legal intervention involving other firearm discharge, bystander injured, subsequent encounter*/
,'Y35092S'  /*Legal intervention involving other firearm discharge, bystander injured, sequela*/
,'Y35093D'  /*Legal intervention involving other firearm discharge, suspect injured, subsequent encounter*/
,'Y35093S'  /*Legal intervention involving other firearm discharge, suspect injured, sequela*/
,'Y35101D'  /*Legal intervention involving unspecified explosives, law enforcement official injured, subsequent encounter*/
,'Y35101S'  /*Legal intervention involving unspecified explosives, law enforcement official injured, sequela*/
,'Y35102D'  /*Legal intervention involving unspecified explosives, bystander injured, subsequent encounter*/
,'Y35102S'  /*Legal intervention involving unspecified explosives, bystander injured, sequela*/
,'Y35103D'  /*Legal intervention involving unspecified explosives, suspect injured, subsequent encounter*/
,'Y35103S'  /*Legal intervention involving unspecified explosives, suspect injured, sequela*/
,'Y35111D'  /*Legal intervention involving injury by dynamite, law enforcement official injured, subsequent encounter*/
,'Y35111S'  /*Legal intervention involving injury by dynamite, law enforcement official injured, sequela*/
,'Y35112D'  /*Legal intervention involving injury by dynamite, bystander injured, subsequent encounter*/
,'Y35112S'  /*Legal intervention involving injury by dynamite, bystander injured, sequela*/
,'Y35113D'  /*Legal intervention involving injury by dynamite, suspect injured, subsequent encounter*/
,'Y35113S'  /*Legal intervention involving injury by dynamite, suspect injured, sequela*/
,'Y35121D'  /*Legal intervention involving injury by explosive shell, law enforcement official injured, subsequent encounter*/
,'Y35121S'  /*Legal intervention involving injury by explosive shell, law enforcement official injured, sequela*/
,'Y35122D'  /*Legal intervention involving injury by explosive shell, bystander injured, subsequent encounter*/
,'Y35122S'  /*Legal intervention involving injury by explosive shell, bystander injured, sequela*/
,'Y35123D'  /*Legal intervention involving injury by explosive shell, suspect injured, subsequent encounter*/
,'Y35123S'  /*Legal intervention involving injury by explosive shell, suspect injured, sequela*/
,'Y35191D'  /*Legal intervention involving other explosives, law enforcement official injured, subsequent encounter*/
,'Y35191S'  /*Legal intervention involving other explosives, law enforcement official injured, sequela*/
,'Y35192D'  /*Legal intervention involving other explosives, bystander injured, subsequent encounter*/
,'Y35192S'  /*Legal intervention involving other explosives, bystander injured, sequela*/
,'Y35193D'  /*Legal intervention involving other explosives, suspect injured, subsequent encounter*/
,'Y35193S'  /*Legal intervention involving other explosives, suspect injured, sequela*/
,'Y35201D'  /*Legal intervention involving unspecified gas, law enforcement official injured, subsequent encounter*/
,'Y35201S'  /*Legal intervention involving unspecified gas, law enforcement official injured, sequela*/
,'Y35202D'  /*Legal intervention involving unspecified gas, bystander injured, subsequent encounter*/
,'Y35202S'  /*Legal intervention involving unspecified gas, bystander injured, sequela*/
,'Y35203D'  /*Legal intervention involving unspecified gas, suspect injured, subsequent encounter*/
,'Y35203S'  /*Legal intervention involving unspecified gas, suspect injured, sequela*/
,'Y35211D'  /*Legal intervention involving injury by tear gas, law enforcement official injured, subsequent encounter*/
,'Y35211S'  /*Legal intervention involving injury by tear gas, law enforcement official injured, sequela*/
,'Y35212D'  /*Legal intervention involving injury by tear gas, bystander injured, subsequent encounter*/
,'Y35212S'  /*Legal intervention involving injury by tear gas, bystander injured, sequela*/
,'Y35213D'  /*Legal intervention involving injury by tear gas, suspect injured, subsequent encounter*/
,'Y35213S'  /*Legal intervention involving injury by tear gas, suspect injured, sequela*/
,'Y35291D'  /*Legal intervention involving other gas, law enforcement official injured, subsequent encounter*/
,'Y35291S'  /*Legal intervention involving other gas, law enforcement official injured, sequela*/
,'Y35292D'  /*Legal intervention involving other gas, bystander injured, subsequent encounter*/
,'Y35292S'  /*Legal intervention involving other gas, bystander injured, sequela*/
,'Y35293D'  /*Legal intervention involving other gas, suspect injured, subsequent encounter*/
,'Y35293S'  /*Legal intervention involving other gas, suspect injured, sequela*/
,'Y35301D'  /*Legal intervention involving unspecified blunt objects, law enforcement official injured, subsequent encounter*/
,'Y35301S'  /*Legal intervention involving unspecified blunt objects, law enforcement official injured, sequela*/
,'Y35302D'  /*Legal intervention involving unspecified blunt objects, bystander injured, subsequent encounter*/
,'Y35302S'  /*Legal intervention involving unspecified blunt objects, bystander injured, sequela*/
,'Y35303D'  /*Legal intervention involving unspecified blunt objects, suspect injured, subsequent encounter*/
,'Y35303S'  /*Legal intervention involving unspecified blunt objects, suspect injured, sequela*/
,'Y35311D'  /*Legal intervention involving baton, law enforcement official injured, subsequent encounter*/
,'Y35311S'  /*Legal intervention involving baton, law enforcement official injured, sequela*/
,'Y35312D'  /*Legal intervention involving baton, bystander injured, subsequent encounter*/
,'Y35312S'  /*Legal intervention involving baton, bystander injured, sequela*/
,'Y35313D'  /*Legal intervention involving baton, suspect injured, subsequent encounter*/
,'Y35313S'  /*Legal intervention involving baton, suspect injured, sequela*/
,'Y35391D'  /*Legal intervention involving other blunt objects, law enforcement official injured, subsequent encounter*/
,'Y35391S'  /*Legal intervention involving other blunt objects, law enforcement official injured, sequela*/
,'Y35392D'  /*Legal intervention involving other blunt objects, bystander injured, subsequent encounter*/
,'Y35392S'  /*Legal intervention involving other blunt objects, bystander injured, sequela*/
,'Y35393D'  /*Legal intervention involving other blunt objects, suspect injured, subsequent encounter*/
,'Y35393S'  /*Legal intervention involving other blunt objects, suspect injured, sequela*/
,'Y35401D'  /*Legal intervention involving unspecified sharp objects, law enforcement official injured, subsequent encounter*/
,'Y35401S'  /*Legal intervention involving unspecified sharp objects, law enforcement official injured, sequela*/
,'Y35402D'  /*Legal intervention involving unspecified sharp objects, bystander injured, subsequent encounter*/
,'Y35402S'  /*Legal intervention involving unspecified sharp objects, bystander injured, sequela*/
,'Y35403D'  /*Legal intervention involving unspecified sharp objects, suspect injured, subsequent encounter*/
,'Y35403S'  /*Legal intervention involving unspecified sharp objects, suspect injured, sequela*/
,'Y35411D'  /*Legal intervention involving bayonet, law enforcement official injured, subsequent encounter*/
,'Y35411S'  /*Legal intervention involving bayonet, law enforcement official injured, sequela*/
,'Y35412D'  /*Legal intervention involving bayonet, bystander injured, subsequent encounter*/
,'Y35412S'  /*Legal intervention involving bayonet, bystander injured, sequela*/
,'Y35413D'  /*Legal intervention involving bayonet, suspect injured, subsequent encounter*/
,'Y35413S'  /*Legal intervention involving bayonet, suspect injured, sequela*/
,'Y35491D'  /*Legal intervention involving other sharp objects, law enforcement official injured, subsequent encounter*/
,'Y35491S'  /*Legal intervention involving other sharp objects, law enforcement official injured, sequela*/
,'Y35492D'  /*Legal intervention involving other sharp objects, bystander injured, subsequent encounter*/
,'Y35492S'  /*Legal intervention involving other sharp objects, bystander injured, sequela*/
,'Y35493D'  /*Legal intervention involving other sharp objects, suspect injured, subsequent encounter*/
,'Y35493S'  /*Legal intervention involving other sharp objects, suspect injured, sequela*/
,'Y35811D'  /*Legal intervention involving manhandling, law enforcement official injured, subsequent encounter*/
,'Y35811S'  /*Legal intervention involving manhandling, law enforcement official injured, sequela*/
,'Y35812D'  /*Legal intervention involving manhandling, bystander injured, subsequent encounter*/
,'Y35812S'  /*Legal intervention involving manhandling, bystander injured, sequela*/
,'Y35813D'  /*Legal intervention involving manhandling, suspect injured, subsequent encounter*/
,'Y35813S'  /*Legal intervention involving manhandling, suspect injured, sequela*/
,'Y35891D'  /*Legal intervention involving other specified means, law enforcement official injured, subsequent encounter*/
,'Y35891S'  /*Legal intervention involving other specified means, law enforcement official injured, sequela*/
,'Y35892D'  /*Legal intervention involving other specified means, bystander injured, subsequent encounter*/
,'Y35892S'  /*Legal intervention involving other specified means, bystander injured, sequela*/
,'Y35893D'  /*Legal intervention involving other specified means, suspect injured, subsequent encounter*/
,'Y35893S'  /*Legal intervention involving other specified means, suspect injured, sequela*/
,'Y3591XD'  /*Legal intervention, means unspecified, law enforcement official injured, subsequent encounter*/
,'Y3591XS'  /*Legal intervention, means unspecified, law enforcement official injured, sequela*/
,'Y3592XD'  /*Legal intervention, means unspecified, bystander injured, subsequent encounter*/
,'Y3592XS'  /*Legal intervention, means unspecified, bystander injured, sequela*/
,'Y3593XD'  /*Legal intervention, means unspecified, suspect injured, subsequent encounter*/
,'Y3593XS'  /*Legal intervention, means unspecified, suspect injured, sequela*/
,'Y36000A'  /*War operations involving explosion of unspecified marine weapon, military personnel, initial encounter*/
,'Y36000D'  /*War operations involving explosion of unspecified marine weapon, military personnel, subsequent encounter*/
,'Y36000S'  /*War operations involving explosion of unspecified marine weapon, military personnel, sequela*/
,'Y36001A'  /*War operations involving explosion of unspecified marine weapon, civilian, initial encounter*/
,'Y36001D'  /*War operations involving explosion of unspecified marine weapon, civilian, subsequent encounter*/
,'Y36001S'  /*War operations involving explosion of unspecified marine weapon, civilian, sequela*/
,'Y36010A'  /*War operations involving explosion of depth-charge, military personnel, initial encounter*/
,'Y36010D'  /*War operations involving explosion of depth-charge, military personnel, subsequent encounter*/
,'Y36010S'  /*War operations involving explosion of depth-charge, military personnel, sequela*/
,'Y36011A'  /*War operations involving explosion of depth-charge, civilian, initial encounter*/
,'Y36011D'  /*War operations involving explosion of depth-charge, civilian, subsequent encounter*/
,'Y36011S'  /*War operations involving explosion of depth-charge, civilian, sequela*/
,'Y36020A'  /*War operations involving explosion of marine mine, military personnel, initial encounter*/
,'Y36020D'  /*War operations involving explosion of marine mine, military personnel, subsequent encounter*/
,'Y36020S'  /*War operations involving explosion of marine mine, military personnel, sequela*/
,'Y36021A'  /*War operations involving explosion of marine mine, civilian, initial encounter*/
,'Y36021D'  /*War operations involving explosion of marine mine, civilian, subsequent encounter*/
,'Y36021S'  /*War operations involving explosion of marine mine, civilian, sequela*/
,'Y36030A'  /*War operations involving explosion of sea-based artillery shell, military personnel, initial encounter*/
,'Y36030D'  /*War operations involving explosion of sea-based artillery shell, military personnel, subsequent encounter*/
,'Y36030S'  /*War operations involving explosion of sea-based artillery shell, military personnel, sequela*/
,'Y36031A'  /*War operations involving explosion of sea-based artillery shell, civilian, initial encounter*/
,'Y36031D'  /*War operations involving explosion of sea-based artillery shell, civilian, subsequent encounter*/
,'Y36031S'  /*War operations involving explosion of sea-based artillery shell, civilian, sequela*/
,'Y36040A'  /*War operations involving explosion of torpedo, military personnel, initial encounter*/
,'Y36040D'  /*War operations involving explosion of torpedo, military personnel, subsequent encounter*/
,'Y36040S'  /*War operations involving explosion of torpedo, military personnel, sequela*/
,'Y36041A'  /*War operations involving explosion of torpedo, civilian, initial encounter*/
,'Y36041D'  /*War operations involving explosion of torpedo, civilian, subsequent encounter*/
,'Y36041S'  /*War operations involving explosion of torpedo, civilian, sequela*/
,'Y36050A'  /*War operations involving accidental detonation of onboard marine weapons, military personnel, initial encounter*/
,'Y36050D'  /*War operations involving accidental detonation of onboard marine weapons, military personnel, subsequent encounter*/
,'Y36050S'  /*War operations involving accidental detonation of onboard marine weapons, military personnel, sequela*/
,'Y36051A'  /*War operations involving accidental detonation of onboard marine weapons, civilian, initial encounter*/
,'Y36051D'  /*War operations involving accidental detonation of onboard marine weapons, civilian, subsequent encounter*/
,'Y36051S'  /*War operations involving accidental detonation of onboard marine weapons, civilian, sequela*/
,'Y36090A'  /*War operations involving explosion of other marine weapons, military personnel, initial encounter*/
,'Y36090D'  /*War operations involving explosion of other marine weapons, military personnel, subsequent encounter*/
,'Y36090S'  /*War operations involving explosion of other marine weapons, military personnel, sequela*/
,'Y36091A'  /*War operations involving explosion of other marine weapons, civilian, initial encounter*/
,'Y36091D'  /*War operations involving explosion of other marine weapons, civilian, subsequent encounter*/
,'Y36091S'  /*War operations involving explosion of other marine weapons, civilian, sequela*/
,'Y36100A'  /*War operations involving unspecified destruction of aircraft, military personnel, initial encounter*/
,'Y36100D'  /*War operations involving unspecified destruction of aircraft, military personnel, subsequent encounter*/
,'Y36100S'  /*War operations involving unspecified destruction of aircraft, military personnel, sequela*/
,'Y36101A'  /*War operations involving unspecified destruction of aircraft, civilian, initial encounter*/
,'Y36101D'  /*War operations involving unspecified destruction of aircraft, civilian, subsequent encounter*/
,'Y36101S'  /*War operations involving unspecified destruction of aircraft, civilian, sequela*/
,'Y36110A'  /*War operations involving destruction of aircraft due to enemy fire or explosives, military personnel, initial encounter*/
,'Y36110D'  /*War operations involving destruction of aircraft due to enemy fire or explosives, military personnel, subsequent encounter*/
,'Y36110S'  /*War operations involving destruction of aircraft due to enemy fire or explosives, military personnel, sequela*/
,'Y36111A'  /*War operations involving destruction of aircraft due to enemy fire or explosives, civilian, initial encounter*/
,'Y36111D'  /*War operations involving destruction of aircraft due to enemy fire or explosives, civilian, subsequent encounter*/
,'Y36111S'  /*War operations involving destruction of aircraft due to enemy fire or explosives, civilian, sequela*/
,'Y36120A'  /*War operations involving destruction of aircraft due to collision with other aircraft, military personnel, initial encounter*/
,'Y36120D'  /*War operations involving destruction of aircraft due to collision with other aircraft, military personnel, subsequent encounter*/
,'Y36120S'  /*War operations involving destruction of aircraft due to collision with other aircraft, military personnel, sequela*/
,'Y36121A'  /*War operations involving destruction of aircraft due to collision with other aircraft, civilian, initial encounter*/
,'Y36121D'  /*War operations involving destruction of aircraft due to collision with other aircraft, civilian, subsequent encounter*/
,'Y36121S'  /*War operations involving destruction of aircraft due to collision with other aircraft, civilian, sequela*/
,'Y36130A'  /*War operations involving destruction of aircraft due to onboard fire, military personnel, initial encounter*/
,'Y36130D'  /*War operations involving destruction of aircraft due to onboard fire, military personnel, subsequent encounter*/
,'Y36130S'  /*War operations involving destruction of aircraft due to onboard fire, military personnel, sequela*/
,'Y36131A'  /*War operations involving destruction of aircraft due to onboard fire, civilian, initial encounter*/
,'Y36131D'  /*War operations involving destruction of aircraft due to onboard fire, civilian, subsequent encounter*/
,'Y36131S'  /*War operations involving destruction of aircraft due to onboard fire, civilian, sequela*/
,'Y36140A'  /*War operations involving destruction of aircraft due to accidental detonation of onboard munitions and explosives, military personnel, initial encounter*/
,'Y36140D'  /*War operations involving destruction of aircraft due to accidental detonation of onboard munitions and explosives, military personnel, subsequent encounter*/
,'Y36140S'  /*War operations involving destruction of aircraft due to accidental detonation of onboard munitions and explosives, military personnel, sequela*/
,'Y36141A'  /*War operations involving destruction of aircraft due to accidental detonation of onboard munitions and explosives, civilian, initial encounter*/
,'Y36141D'  /*War operations involving destruction of aircraft due to accidental detonation of onboard munitions and explosives, civilian, subsequent encounter*/
,'Y36141S'  /*War operations involving destruction of aircraft due to accidental detonation of onboard munitions and explosives, civilian, sequela*/
,'Y36190A'  /*War operations involving other destruction of aircraft, military personnel, initial encounter*/
,'Y36190D'  /*War operations involving other destruction of aircraft, military personnel, subsequent encounter*/
,'Y36190S'  /*War operations involving other destruction of aircraft, military personnel, sequela*/
,'Y36191A'  /*War operations involving other destruction of aircraft, civilian, initial encounter*/
,'Y36191D'  /*War operations involving other destruction of aircraft, civilian, subsequent encounter*/
,'Y36191S'  /*War operations involving other destruction of aircraft, civilian, sequela*/
,'Y36200A'  /*War operations involving unspecified explosion and fragments, military personnel, initial encounter*/
,'Y36200D'  /*War operations involving unspecified explosion and fragments, military personnel, subsequent encounter*/
,'Y36200S'  /*War operations involving unspecified explosion and fragments, military personnel, sequela*/
,'Y36201A'  /*War operations involving unspecified explosion and fragments, civilian, initial encounter*/
,'Y36201D'  /*War operations involving unspecified explosion and fragments, civilian, subsequent encounter*/
,'Y36201S'  /*War operations involving unspecified explosion and fragments, civilian, sequela*/
,'Y36210A'  /*War operations involving explosion of aerial bomb, military personnel, initial encounter*/
,'Y36210D'  /*War operations involving explosion of aerial bomb, military personnel, subsequent encounter*/
,'Y36210S'  /*War operations involving explosion of aerial bomb, military personnel, sequela*/
,'Y36211A'  /*War operations involving explosion of aerial bomb, civilian, initial encounter*/
,'Y36211D'  /*War operations involving explosion of aerial bomb, civilian, subsequent encounter*/
,'Y36211S'  /*War operations involving explosion of aerial bomb, civilian, sequela*/
,'Y36220A'  /*War operations involving explosion of guided missile, military personnel, initial encounter*/
,'Y36220D'  /*War operations involving explosion of guided missile, military personnel, subsequent encounter*/
,'Y36220S'  /*War operations involving explosion of guided missile, military personnel, sequela*/
,'Y36221A'  /*War operations involving explosion of guided missile, civilian, initial encounter*/
,'Y36221D'  /*War operations involving explosion of guided missile, civilian, subsequent encounter*/
,'Y36221S'  /*War operations involving explosion of guided missile, civilian, sequela*/
,'Y36230A'  /*War operations involving explosion of improvised explosive device [IED], military personnel, initial encounter*/
,'Y36230D'  /*War operations involving explosion of improvised explosive device [IED], military personnel, subsequent encounter*/
,'Y36230S'  /*War operations involving explosion of improvised explosive device [IED], military personnel, sequela*/
,'Y36231A'  /*War operations involving explosion of improvised explosive device [IED], civilian, initial encounter*/
,'Y36231D'  /*War operations involving explosion of improvised explosive device [IED], civilian, subsequent encounter*/
,'Y36231S'  /*War operations involving explosion of improvised explosive device [IED], civilian, sequela*/
,'Y36240A'  /*War operations involving explosion due to accidental detonation and discharge of own munitions or munitions launch device, military personnel, initial encounter*/
,'Y36240D'  /*War operations involving explosion due to accidental detonation and discharge of own munitions or munitions launch device, military personnel, subsequent encounter*/
,'Y36240S'  /*War operations involving explosion due to accidental detonation and discharge of own munitions or munitions launch device, military personnel, sequela*/
,'Y36241A'  /*War operations involving explosion due to accidental detonation and discharge of own munitions or munitions launch device, civilian, initial encounter*/
,'Y36241D'  /*War operations involving explosion due to accidental detonation and discharge of own munitions or munitions launch device, civilian, subsequent encounter*/
,'Y36241S'  /*War operations involving explosion due to accidental detonation and discharge of own munitions or munitions launch device, civilian, sequela*/
,'Y36250A'  /*War operations involving fragments from munitions, military personnel, initial encounter*/
,'Y36250D'  /*War operations involving fragments from munitions, military personnel, subsequent encounter*/
,'Y36250S'  /*War operations involving fragments from munitions, military personnel, sequela*/
,'Y36251A'  /*War operations involving fragments from munitions, civilian, initial encounter*/
,'Y36251D'  /*War operations involving fragments from munitions, civilian, subsequent encounter*/
,'Y36251S'  /*War operations involving fragments from munitions, civilian, sequela*/
,'Y36260A'  /*War operations involving fragments of improvised explosive device [IED], military personnel, initial encounter*/
,'Y36260D'  /*War operations involving fragments of improvised explosive device [IED], military personnel, subsequent encounter*/
,'Y36260S'  /*War operations involving fragments of improvised explosive device [IED], military personnel, sequela*/
,'Y36261A'  /*War operations involving fragments of improvised explosive device [IED], civilian, initial encounter*/
,'Y36261D'  /*War operations involving fragments of improvised explosive device [IED], civilian, subsequent encounter*/
,'Y36261S'  /*War operations involving fragments of improvised explosive device [IED], civilian, sequela*/
,'Y36270A'  /*War operations involving fragments from weapons, military personnel, initial encounter*/
,'Y36270D'  /*War operations involving fragments from weapons, military personnel, subsequent encounter*/
,'Y36270S'  /*War operations involving fragments from weapons, military personnel, sequela*/
,'Y36271A'  /*War operations involving fragments from weapons, civilian, initial encounter*/
,'Y36271D'  /*War operations involving fragments from weapons, civilian, subsequent encounter*/
,'Y36271S'  /*War operations involving fragments from weapons, civilian, sequela*/
,'Y36290A'  /*War operations involving other explosions and fragments, military personnel, initial encounter*/
,'Y36290D'  /*War operations involving other explosions and fragments, military personnel, subsequent encounter*/
,'Y36290S'  /*War operations involving other explosions and fragments, military personnel, sequela*/
,'Y36291A'  /*War operations involving other explosions and fragments, civilian, initial encounter*/
,'Y36291D'  /*War operations involving other explosions and fragments, civilian, subsequent encounter*/
,'Y36291S'  /*War operations involving other explosions and fragments, civilian, sequela*/
,'Y36300A'  /*War operations involving unspecified fire, conflagration and hot substance, military personnel, initial encounter*/
,'Y36300D'  /*War operations involving unspecified fire, conflagration and hot substance, military personnel, subsequent encounter*/
,'Y36300S'  /*War operations involving unspecified fire, conflagration and hot substance, military personnel, sequela*/
,'Y36301A'  /*War operations involving unspecified fire, conflagration and hot substance, civilian, initial encounter*/
,'Y36301D'  /*War operations involving unspecified fire, conflagration and hot substance, civilian, subsequent encounter*/
,'Y36301S'  /*War operations involving unspecified fire, conflagration and hot substance, civilian, sequela*/
,'Y36310A'  /*War operations involving gasoline bomb, military personnel, initial encounter*/
,'Y36310D'  /*War operations involving gasoline bomb, military personnel, subsequent encounter*/
,'Y36310S'  /*War operations involving gasoline bomb, military personnel, sequela*/
,'Y36311A'  /*War operations involving gasoline bomb, civilian, initial encounter*/
,'Y36311D'  /*War operations involving gasoline bomb, civilian, subsequent encounter*/
,'Y36311S'  /*War operations involving gasoline bomb, civilian, sequela*/
,'Y36320A'  /*War operations involving incendiary bullet, military personnel, initial encounter*/
,'Y36320D'  /*War operations involving incendiary bullet, military personnel, subsequent encounter*/
,'Y36320S'  /*War operations involving incendiary bullet, military personnel, sequela*/
,'Y36321A'  /*War operations involving incendiary bullet, civilian, initial encounter*/
,'Y36321D'  /*War operations involving incendiary bullet, civilian, subsequent encounter*/
,'Y36321S'  /*War operations involving incendiary bullet, civilian, sequela*/
,'Y36330A'  /*War operations involving flamethrower, military personnel, initial encounter*/
,'Y36330D'  /*War operations involving flamethrower, military personnel, subsequent encounter*/
,'Y36330S'  /*War operations involving flamethrower, military personnel, sequela*/
,'Y36331A'  /*War operations involving flamethrower, civilian, initial encounter*/
,'Y36331D'  /*War operations involving flamethrower, civilian, subsequent encounter*/
,'Y36331S'  /*War operations involving flamethrower, civilian, sequela*/
,'Y36390A'  /*War operations involving other fires, conflagrations and hot substances, military personnel, initial encounter*/
,'Y36390D'  /*War operations involving other fires, conflagrations and hot substances, military personnel, subsequent encounter*/
,'Y36390S'  /*War operations involving other fires, conflagrations and hot substances, military personnel, sequela*/
,'Y36391A'  /*War operations involving other fires, conflagrations and hot substances, civilian, initial encounter*/
,'Y36391D'  /*War operations involving other fires, conflagrations and hot substances, civilian, subsequent encounter*/
,'Y36391S'  /*War operations involving other fires, conflagrations and hot substances, civilian, sequela*/
,'Y36410A'  /*War operations involving rubber bullets, military personnel, initial encounter*/
,'Y36410D'  /*War operations involving rubber bullets, military personnel, subsequent encounter*/
,'Y36410S'  /*War operations involving rubber bullets, military personnel, sequela*/
,'Y36411A'  /*War operations involving rubber bullets, civilian, initial encounter*/
,'Y36411D'  /*War operations involving rubber bullets, civilian, subsequent encounter*/
,'Y36411S'  /*War operations involving rubber bullets, civilian, sequela*/
,'Y36420A'  /*War operations involving firearms pellets, military personnel, initial encounter*/
,'Y36420D'  /*War operations involving firearms pellets, military personnel, subsequent encounter*/
,'Y36420S'  /*War operations involving firearms pellets, military personnel, sequela*/
,'Y36421A'  /*War operations involving firearms pellets, civilian, initial encounter*/
,'Y36421D'  /*War operations involving firearms pellets, civilian, subsequent encounter*/
,'Y36421S'  /*War operations involving firearms pellets, civilian, sequela*/
,'Y36430A'  /*War operations involving other firearms discharge, military personnel, initial encounter*/
,'Y36430D'  /*War operations involving other firearms discharge, military personnel, subsequent encounter*/
,'Y36430S'  /*War operations involving other firearms discharge, military personnel, sequela*/
,'Y36431A'  /*War operations involving other firearms discharge, civilian, initial encounter*/
,'Y36431D'  /*War operations involving other firearms discharge, civilian, subsequent encounter*/
,'Y36431S'  /*War operations involving other firearms discharge, civilian, sequela*/
,'Y36440A'  /*War operations involving unarmed hand to hand combat, military personnel, initial encounter*/
,'Y36440D'  /*War operations involving unarmed hand to hand combat, military personnel, subsequent encounter*/
,'Y36440S'  /*War operations involving unarmed hand to hand combat, military personnel, sequela*/
,'Y36441A'  /*War operations involving unarmed hand to hand combat, civilian, initial encounter*/
,'Y36441D'  /*War operations involving unarmed hand to hand combat, civilian, subsequent encounter*/
,'Y36441S'  /*War operations involving unarmed hand to hand combat, civilian, sequela*/
,'Y36450A'  /*War operations involving combat using blunt or piercing object, military personnel, initial encounter*/
,'Y36450D'  /*War operations involving combat using blunt or piercing object, military personnel, subsequent encounter*/
,'Y36450S'  /*War operations involving combat using blunt or piercing object, military personnel, sequela*/
,'Y36451A'  /*War operations involving combat using blunt or piercing object, civilian, initial encounter*/
,'Y36451D'  /*War operations involving combat using blunt or piercing object, civilian, subsequent encounter*/
,'Y36451S'  /*War operations involving combat using blunt or piercing object, civilian, sequela*/
,'Y36460A'  /*War operations involving intentional restriction of air and airway, military personnel, initial encounter*/
,'Y36460D'  /*War operations involving intentional restriction of air and airway, military personnel, subsequent encounter*/
,'Y36460S'  /*War operations involving intentional restriction of air and airway, military personnel, sequela*/
,'Y36461A'  /*War operations involving intentional restriction of air and airway, civilian, initial encounter*/
,'Y36461D'  /*War operations involving intentional restriction of air and airway, civilian, subsequent encounter*/
,'Y36461S'  /*War operations involving intentional restriction of air and airway, civilian, sequela*/
,'Y36470A'  /*War operations involving unintentional restriction of air and airway, military personnel, initial encounter*/
,'Y36470D'  /*War operations involving unintentional restriction of air and airway, military personnel, subsequent encounter*/
,'Y36470S'  /*War operations involving unintentional restriction of air and airway, military personnel, sequela*/
,'Y36471A'  /*War operations involving unintentional restriction of air and airway, civilian, initial encounter*/
,'Y36471D'  /*War operations involving unintentional restriction of air and airway, civilian, subsequent encounter*/
,'Y36471S'  /*War operations involving unintentional restriction of air and airway, civilian, sequela*/
,'Y36490A'  /*War operations involving other forms of conventional warfare, military personnel, initial encounter*/
,'Y36490D'  /*War operations involving other forms of conventional warfare, military personnel, subsequent encounter*/
,'Y36490S'  /*War operations involving other forms of conventional warfare, military personnel, sequela*/
,'Y36491A'  /*War operations involving other forms of conventional warfare, civilian, initial encounter*/
,'Y36491D'  /*War operations involving other forms of conventional warfare, civilian, subsequent encounter*/
,'Y36491S'  /*War operations involving other forms of conventional warfare, civilian, sequela*/
,'Y36500A'  /*War operations involving unspecified effect of nuclear weapon, military personnel, initial encounter*/
,'Y36500D'  /*War operations involving unspecified effect of nuclear weapon, military personnel, subsequent encounter*/
,'Y36500S'  /*War operations involving unspecified effect of nuclear weapon, military personnel, sequela*/
,'Y36501A'  /*War operations involving unspecified effect of nuclear weapon, civilian, initial encounter*/
,'Y36501D'  /*War operations involving unspecified effect of nuclear weapon, civilian, subsequent encounter*/
,'Y36501S'  /*War operations involving unspecified effect of nuclear weapon, civilian, sequela*/
,'Y36510A'  /*War operations involving direct blast effect of nuclear weapon, military personnel, initial encounter*/
,'Y36510D'  /*War operations involving direct blast effect of nuclear weapon, military personnel, subsequent encounter*/
,'Y36510S'  /*War operations involving direct blast effect of nuclear weapon, military personnel, sequela*/
,'Y36511A'  /*War operations involving direct blast effect of nuclear weapon, civilian, initial encounter*/
,'Y36511D'  /*War operations involving direct blast effect of nuclear weapon, civilian, subsequent encounter*/
,'Y36511S'  /*War operations involving direct blast effect of nuclear weapon, civilian, sequela*/
,'Y36520A'  /*War operations involving indirect blast effect of nuclear weapon, military personnel, initial encounter*/
,'Y36520D'  /*War operations involving indirect blast effect of nuclear weapon, military personnel, subsequent encounter*/
,'Y36520S'  /*War operations involving indirect blast effect of nuclear weapon, military personnel, sequela*/
,'Y36521A'  /*War operations involving indirect blast effect of nuclear weapon, civilian, initial encounter*/
,'Y36521D'  /*War operations involving indirect blast effect of nuclear weapon, civilian, subsequent encounter*/
,'Y36521S'  /*War operations involving indirect blast effect of nuclear weapon, civilian, sequela*/
,'Y36530A'  /*War operations involving thermal radiation effect of nuclear weapon, military personnel, initial encounter*/
,'Y36530D'  /*War operations involving thermal radiation effect of nuclear weapon, military personnel, subsequent encounter*/
,'Y36530S'  /*War operations involving thermal radiation effect of nuclear weapon, military personnel, sequela*/
,'Y36531A'  /*War operations involving thermal radiation effect of nuclear weapon, civilian, initial encounter*/
,'Y36531D'  /*War operations involving thermal radiation effect of nuclear weapon, civilian, subsequent encounter*/
,'Y36531S'  /*War operations involving thermal radiation effect of nuclear weapon, civilian, sequela*/
,'Y36540A'  /*War operation involving nuclear radiation effects of nuclear weapon, military personnel, initial encounter*/
,'Y36540D'  /*War operation involving nuclear radiation effects of nuclear weapon, military personnel, subsequent encounter*/
,'Y36540S'  /*War operation involving nuclear radiation effects of nuclear weapon, military personnel, sequela*/
,'Y36541A'  /*War operation involving nuclear radiation effects of nuclear weapon, civilian, initial encounter*/
,'Y36541D'  /*War operation involving nuclear radiation effects of nuclear weapon, civilian, subsequent encounter*/
,'Y36541S'  /*War operation involving nuclear radiation effects of nuclear weapon, civilian, sequela*/
,'Y36590A'  /*War operation involving other effects of nuclear weapons, military personnel, initial encounter*/
,'Y36590D'  /*War operation involving other effects of nuclear weapons, military personnel, subsequent encounter*/
,'Y36590S'  /*War operation involving other effects of nuclear weapons, military personnel, sequela*/
,'Y36591A'  /*War operation involving other effects of nuclear weapons, civilian, initial encounter*/
,'Y36591D'  /*War operation involving other effects of nuclear weapons, civilian, subsequent encounter*/
,'Y36591S'  /*War operation involving other effects of nuclear weapons, civilian, sequela*/
,'Y366X0A'  /*War operations involving biological weapons, military personnel, initial encounter*/
,'Y366X0D'  /*War operations involving biological weapons, military personnel, subsequent encounter*/
,'Y366X0S'  /*War operations involving biological weapons, military personnel, sequela*/
,'Y366X1A'  /*War operations involving biological weapons, civilian, initial encounter*/
,'Y366X1D'  /*War operations involving biological weapons, civilian, subsequent encounter*/
,'Y366X1S'  /*War operations involving biological weapons, civilian, sequela*/
,'Y367X0A'  /*War operations involving chemical weapons and other forms of unconventional warfare, military personnel, initial encounter*/
,'Y367X0D'  /*War operations involving chemical weapons and other forms of unconventional warfare, military personnel, subsequent encounter*/
,'Y367X0S'  /*War operations involving chemical weapons and other forms of unconventional warfare, military personnel, sequela*/
,'Y367X1A'  /*War operations involving chemical weapons and other forms of unconventional warfare, civilian, initial encounter*/
,'Y367X1D'  /*War operations involving chemical weapons and other forms of unconventional warfare, civilian, subsequent encounter*/
,'Y367X1S'  /*War operations involving chemical weapons and other forms of unconventional warfare, civilian, sequela*/
,'Y36810A'  /*Explosion of mine placed during war operations but exploding after cessation of hostilities, military personnel, initial encounter*/
,'Y36810D'  /*Explosion of mine placed during war operations but exploding after cessation of hostilities, military personnel, subsequent encounter*/
,'Y36810S'  /*Explosion of mine placed during war operations but exploding after cessation of hostilities, military personnel, sequela*/
,'Y36811A'  /*Explosion of mine placed during war operations but exploding after cessation of hostilities, civilian, initial encounter*/
,'Y36811D'  /*Explosion of mine placed during war operations but exploding after cessation of hostilities, civilian, subsequent encounter*/
,'Y36811S'  /*Explosion of mine placed during war operations but exploding after cessation of hostilities, civilian, sequela*/
,'Y36820A'  /*Explosion of bomb placed during war operations but exploding after cessation of hostilities, military personnel, initial encounter*/
,'Y36820D'  /*Explosion of bomb placed during war operations but exploding after cessation of hostilities, military personnel, subsequent encounter*/
,'Y36820S'  /*Explosion of bomb placed during war operations but exploding after cessation of hostilities, military personnel, sequela*/
,'Y36821A'  /*Explosion of bomb placed during war operations but exploding after cessation of hostilities, civilian, initial encounter*/
,'Y36821D'  /*Explosion of bomb placed during war operations but exploding after cessation of hostilities, civilian, subsequent encounter*/
,'Y36821S'  /*Explosion of bomb placed during war operations but exploding after cessation of hostilities, civilian, sequela*/
,'Y36880A'  /*Other war operations occurring after cessation of hostilities, military personnel, initial encounter*/
,'Y36880D'  /*Other war operations occurring after cessation of hostilities, military personnel, subsequent encounter*/
,'Y36880S'  /*Other war operations occurring after cessation of hostilities, military personnel, sequela*/
,'Y36881A'  /*Other war operations occurring after cessation of hostilities, civilian, initial encounter*/
,'Y36881D'  /*Other war operations occurring after cessation of hostilities, civilian, subsequent encounter*/
,'Y36881S'  /*Other war operations occurring after cessation of hostilities, civilian, sequela*/
,'Y36890A'  /*Unspecified war operations occurring after cessation of hostilities, military personnel, initial encounter*/
,'Y36890D'  /*Unspecified war operations occurring after cessation of hostilities, military personnel, subsequent encounter*/
,'Y36890S'  /*Unspecified war operations occurring after cessation of hostilities, military personnel, sequela*/
,'Y36891A'  /*Unspecified war operations occurring after cessation of hostilities, civilian, initial encounter*/
,'Y36891D'  /*Unspecified war operations occurring after cessation of hostilities, civilian, subsequent encounter*/
,'Y36891S'  /*Unspecified war operations occurring after cessation of hostilities, civilian, sequela*/
,'Y3690XA'  /*War operations, unspecified, initial encounter*/
,'Y3690XD'  /*War operations, unspecified, subsequent encounter*/
,'Y3690XS'  /*War operations, unspecified, sequela*/
,'Y3691XA'  /*War operations involving unspecified weapon of mass destruction [WMD], initial encounter*/
,'Y3691XD'  /*War operations involving unspecified weapon of mass destruction [WMD], subsequent encounter*/
,'Y3691XS'  /*War operations involving unspecified weapon of mass destruction [WMD], sequela*/
,'Y3692XA'  /*War operations involving friendly fire, initial encounter*/
,'Y3692XD'  /*War operations involving friendly fire, subsequent encounter*/
,'Y3692XS'  /*War operations involving friendly fire, sequela*/
,'Y37000A'  /*Military operations involving explosion of unspecified marine weapon, military personnel, initial encounter*/
,'Y37000D'  /*Military operations involving explosion of unspecified marine weapon, military personnel, subsequent encounter*/
,'Y37000S'  /*Military operations involving explosion of unspecified marine weapon, military personnel, sequela*/
,'Y37001A'  /*Military operations involving explosion of unspecified marine weapon, civilian, initial encounter*/
,'Y37001D'  /*Military operations involving explosion of unspecified marine weapon, civilian, subsequent encounter*/
,'Y37001S'  /*Military operations involving explosion of unspecified marine weapon, civilian, sequela*/
,'Y37010A'  /*Military operations involving explosion of depth-charge, military personnel, initial encounter*/
,'Y37010D'  /*Military operations involving explosion of depth-charge, military personnel, subsequent encounter*/
,'Y37010S'  /*Military operations involving explosion of depth-charge, military personnel, sequela*/
,'Y37011A'  /*Military operations involving explosion of depth-charge, civilian, initial encounter*/
,'Y37011D'  /*Military operations involving explosion of depth-charge, civilian, subsequent encounter*/
,'Y37011S'  /*Military operations involving explosion of depth-charge, civilian, sequela*/
,'Y37020A'  /*Military operations involving explosion of marine mine, military personnel, initial encounter*/
,'Y37020D'  /*Military operations involving explosion of marine mine, military personnel, subsequent encounter*/
,'Y37020S'  /*Military operations involving explosion of marine mine, military personnel, sequela*/
,'Y37021A'  /*Military operations involving explosion of marine mine, civilian, initial encounter*/
,'Y37021D'  /*Military operations involving explosion of marine mine, civilian, subsequent encounter*/
,'Y37021S'  /*Military operations involving explosion of marine mine, civilian, sequela*/
,'Y37030A'  /*Military operations involving explosion of sea-based artillery shell, military personnel, initial encounter*/
,'Y37030D'  /*Military operations involving explosion of sea-based artillery shell, military personnel, subsequent encounter*/
,'Y37030S'  /*Military operations involving explosion of sea-based artillery shell, military personnel, sequela*/
,'Y37031A'  /*Military operations involving explosion of sea-based artillery shell, civilian, initial encounter*/
,'Y37031D'  /*Military operations involving explosion of sea-based artillery shell, civilian, subsequent encounter*/
,'Y37031S'  /*Military operations involving explosion of sea-based artillery shell, civilian, sequela*/
,'Y37040A'  /*Military operations involving explosion of torpedo, military personnel, initial encounter*/
,'Y37040D'  /*Military operations involving explosion of torpedo, military personnel, subsequent encounter*/
,'Y37040S'  /*Military operations involving explosion of torpedo, military personnel, sequela*/
,'Y37041A'  /*Military operations involving explosion of torpedo, civilian, initial encounter*/
,'Y37041D'  /*Military operations involving explosion of torpedo, civilian, subsequent encounter*/
,'Y37041S'  /*Military operations involving explosion of torpedo, civilian, sequela*/
,'Y37050A'  /*Military operations involving accidental detonation of onboard marine weapons, military personnel, initial encounter*/
,'Y37050D'  /*Military operations involving accidental detonation of onboard marine weapons, military personnel, subsequent encounter*/
,'Y37050S'  /*Military operations involving accidental detonation of onboard marine weapons, military personnel, sequela*/
,'Y37051A'  /*Military operations involving accidental detonation of onboard marine weapons, civilian, initial encounter*/
,'Y37051D'  /*Military operations involving accidental detonation of onboard marine weapons, civilian, subsequent encounter*/
,'Y37051S'  /*Military operations involving accidental detonation of onboard marine weapons, civilian, sequela*/
,'Y37090A'  /*Military operations involving explosion of other marine weapons, military personnel, initial encounter*/
,'Y37090D'  /*Military operations involving explosion of other marine weapons, military personnel, subsequent encounter*/
,'Y37090S'  /*Military operations involving explosion of other marine weapons, military personnel, sequela*/
,'Y37091A'  /*Military operations involving explosion of other marine weapons, civilian, initial encounter*/
,'Y37091D'  /*Military operations involving explosion of other marine weapons, civilian, subsequent encounter*/
,'Y37091S'  /*Military operations involving explosion of other marine weapons, civilian, sequela*/
,'Y37100A'  /*Military operations involving unspecified destruction of aircraft, military personnel, initial encounter*/
,'Y37100D'  /*Military operations involving unspecified destruction of aircraft, military personnel, subsequent encounter*/
,'Y37100S'  /*Military operations involving unspecified destruction of aircraft, military personnel, sequela*/
,'Y37101A'  /*Military operations involving unspecified destruction of aircraft, civilian, initial encounter*/
,'Y37101D'  /*Military operations involving unspecified destruction of aircraft, civilian, subsequent encounter*/
,'Y37101S'  /*Military operations involving unspecified destruction of aircraft, civilian, sequela*/
,'Y37110A'  /*Military operations involving destruction of aircraft due to enemy fire or explosives, military personnel, initial encounter*/
,'Y37110D'  /*Military operations involving destruction of aircraft due to enemy fire or explosives, military personnel, subsequent encounter*/
,'Y37110S'  /*Military operations involving destruction of aircraft due to enemy fire or explosives, military personnel, sequela*/
,'Y37111A'  /*Military operations involving destruction of aircraft due to enemy fire or explosives, civilian, initial encounter*/
,'Y37111D'  /*Military operations involving destruction of aircraft due to enemy fire or explosives, civilian, subsequent encounter*/
,'Y37111S'  /*Military operations involving destruction of aircraft due to enemy fire or explosives, civilian, sequela*/
,'Y37120A'  /*Military operations involving destruction of aircraft due to collision with other aircraft, military personnel, initial encounter*/
,'Y37120D'  /*Military operations involving destruction of aircraft due to collision with other aircraft, military personnel, subsequent encounter*/
,'Y37120S'  /*Military operations involving destruction of aircraft due to collision with other aircraft, military personnel, sequela*/
,'Y37121A'  /*Military operations involving destruction of aircraft due to collision with other aircraft, civilian, initial encounter*/
,'Y37121D'  /*Military operations involving destruction of aircraft due to collision with other aircraft, civilian, subsequent encounter*/
,'Y37121S'  /*Military operations involving destruction of aircraft due to collision with other aircraft, civilian, sequela*/
,'Y37130A'  /*Military operations involving destruction of aircraft due to onboard fire, military personnel, initial encounter*/
,'Y37130D'  /*Military operations involving destruction of aircraft due to onboard fire, military personnel, subsequent encounter*/
,'Y37130S'  /*Military operations involving destruction of aircraft due to onboard fire, military personnel, sequela*/
,'Y37131A'  /*Military operations involving destruction of aircraft due to onboard fire, civilian, initial encounter*/
,'Y37131D'  /*Military operations involving destruction of aircraft due to onboard fire, civilian, subsequent encounter*/
,'Y37131S'  /*Military operations involving destruction of aircraft due to onboard fire, civilian, sequela*/
,'Y37140A'  /*Military operations involving destruction of aircraft due to accidental detonation of onboard munitions and explosives, military personnel, initial encounter*/
,'Y37140D'  /*Military operations involving destruction of aircraft due to accidental detonation of onboard munitions and explosives, military personnel, subsequent encounter*/
,'Y37140S'  /*Military operations involving destruction of aircraft due to accidental detonation of onboard munitions and explosives, military personnel, sequela*/
,'Y37141A'  /*Military operations involving destruction of aircraft due to accidental detonation of onboard munitions and explosives, civilian, initial encounter*/
,'Y37141D'  /*Military operations involving destruction of aircraft due to accidental detonation of onboard munitions and explosives, civilian, subsequent encounter*/
,'Y37141S'  /*Military operations involving destruction of aircraft due to accidental detonation of onboard munitions and explosives, civilian, sequela*/
,'Y37190A'  /*Military operations involving other destruction of aircraft, military personnel, initial encounter*/
,'Y37190D'  /*Military operations involving other destruction of aircraft, military personnel, subsequent encounter*/
,'Y37190S'  /*Military operations involving other destruction of aircraft, military personnel, sequela*/
,'Y37191A'  /*Military operations involving other destruction of aircraft, civilian, initial encounter*/
,'Y37191D'  /*Military operations involving other destruction of aircraft, civilian, subsequent encounter*/
,'Y37191S'  /*Military operations involving other destruction of aircraft, civilian, sequela*/
,'Y37200A'  /*Military operations involving unspecified explosion and fragments, military personnel, initial encounter*/
,'Y37200D'  /*Military operations involving unspecified explosion and fragments, military personnel, subsequent encounter*/
,'Y37200S'  /*Military operations involving unspecified explosion and fragments, military personnel, sequela*/
,'Y37201A'  /*Military operations involving unspecified explosion and fragments, civilian, initial encounter*/
,'Y37201D'  /*Military operations involving unspecified explosion and fragments, civilian, subsequent encounter*/
,'Y37201S'  /*Military operations involving unspecified explosion and fragments, civilian, sequela*/
,'Y37210A'  /*Military operations involving explosion of aerial bomb, military personnel, initial encounter*/
,'Y37210D'  /*Military operations involving explosion of aerial bomb, military personnel, subsequent encounter*/
,'Y37210S'  /*Military operations involving explosion of aerial bomb, military personnel, sequela*/
,'Y37211A'  /*Military operations involving explosion of aerial bomb, civilian, initial encounter*/
,'Y37211D'  /*Military operations involving explosion of aerial bomb, civilian, subsequent encounter*/
,'Y37211S'  /*Military operations involving explosion of aerial bomb, civilian, sequela*/
,'Y37220A'  /*Military operations involving explosion of guided missile, military personnel, initial encounter*/
,'Y37220D'  /*Military operations involving explosion of guided missile, military personnel, subsequent encounter*/
,'Y37220S'  /*Military operations involving explosion of guided missile, military personnel, sequela*/
,'Y37221A'  /*Military operations involving explosion of guided missile, civilian, initial encounter*/
,'Y37221D'  /*Military operations involving explosion of guided missile, civilian, subsequent encounter*/
,'Y37221S'  /*Military operations involving explosion of guided missile, civilian, sequela*/
,'Y37230A'  /*Military operations involving explosion of improvised explosive device [IED], military personnel, initial encounter*/
,'Y37230D'  /*Military operations involving explosion of improvised explosive device [IED], military personnel, subsequent encounter*/
,'Y37230S'  /*Military operations involving explosion of improvised explosive device [IED], military personnel, sequela*/
,'Y37231A'  /*Military operations involving explosion of improvised explosive device [IED], civilian, initial encounter*/
,'Y37231D'  /*Military operations involving explosion of improvised explosive device [IED], civilian, subsequent encounter*/
,'Y37231S'  /*Military operations involving explosion of improvised explosive device [IED], civilian, sequela*/
,'Y37240A'  /*Military operations involving explosion due to accidental detonation and discharge of own munitions or munitions launch device, military personnel, initial encounter*/
,'Y37240D'  /*Military operations involving explosion due to accidental detonation and discharge of own munitions or munitions launch device, military personnel, subsequent encounter*/
,'Y37240S'  /*Military operations involving explosion due to accidental detonation and discharge of own munitions or munitions launch device, military personnel, sequela*/
,'Y37241A'  /*Military operations involving explosion due to accidental detonation and discharge of own munitions or munitions launch device, civilian, initial encounter*/
,'Y37241D'  /*Military operations involving explosion due to accidental detonation and discharge of own munitions or munitions launch device, civilian, subsequent encounter*/
,'Y37241S'  /*Military operations involving explosion due to accidental detonation and discharge of own munitions or munitions launch device, civilian, sequela*/
,'Y37250A'  /*Military operations involving fragments from munitions, military personnel, initial encounter*/
,'Y37250D'  /*Military operations involving fragments from munitions, military personnel, subsequent encounter*/
,'Y37250S'  /*Military operations involving fragments from munitions, military personnel, sequela*/
,'Y37251A'  /*Military operations involving fragments from munitions, civilian, initial encounter*/
,'Y37251D'  /*Military operations involving fragments from munitions, civilian, subsequent encounter*/
,'Y37251S'  /*Military operations involving fragments from munitions, civilian, sequela*/
,'Y37260A'  /*Military operations involving fragments of improvised explosive device [IED], military personnel, initial encounter*/
,'Y37260D'  /*Military operations involving fragments of improvised explosive device [IED], military personnel, subsequent encounter*/
,'Y37260S'  /*Military operations involving fragments of improvised explosive device [IED], military personnel, sequela*/
,'Y37261A'  /*Military operations involving fragments of improvised explosive device [IED], civilian, initial encounter*/
,'Y37261D'  /*Military operations involving fragments of improvised explosive device [IED], civilian, subsequent encounter*/
,'Y37261S'  /*Military operations involving fragments of improvised explosive device [IED], civilian, sequela*/
,'Y37270A'  /*Military operations involving fragments from weapons, military personnel, initial encounter*/
,'Y37270D'  /*Military operations involving fragments from weapons, military personnel, subsequent encounter*/
,'Y37270S'  /*Military operations involving fragments from weapons, military personnel, sequela*/
,'Y37271A'  /*Military operations involving fragments from weapons, civilian, initial encounter*/
,'Y37271D'  /*Military operations involving fragments from weapons, civilian, subsequent encounter*/
,'Y37271S'  /*Military operations involving fragments from weapons, civilian, sequela*/
,'Y37290A'  /*Military operations involving other explosions and fragments, military personnel, initial encounter*/
,'Y37290D'  /*Military operations involving other explosions and fragments, military personnel, subsequent encounter*/
,'Y37290S'  /*Military operations involving other explosions and fragments, military personnel, sequela*/
,'Y37291A'  /*Military operations involving other explosions and fragments, civilian, initial encounter*/
,'Y37291D'  /*Military operations involving other explosions and fragments, civilian, subsequent encounter*/
,'Y37291S'  /*Military operations involving other explosions and fragments, civilian, sequela*/
,'Y37300A'  /*Military operations involving unspecified fire, conflagration and hot substance, military personnel, initial encounter*/
,'Y37300D'  /*Military operations involving unspecified fire, conflagration and hot substance, military personnel, subsequent encounter*/
,'Y37300S'  /*Military operations involving unspecified fire, conflagration and hot substance, military personnel, sequela*/
,'Y37301A'  /*Military operations involving unspecified fire, conflagration and hot substance, civilian, initial encounter*/
,'Y37301D'  /*Military operations involving unspecified fire, conflagration and hot substance, civilian, subsequent encounter*/
,'Y37301S'  /*Military operations involving unspecified fire, conflagration and hot substance, civilian, sequela*/
,'Y37310A'  /*Military operations involving gasoline bomb, military personnel, initial encounter*/
,'Y37310D'  /*Military operations involving gasoline bomb, military personnel, subsequent encounter*/
,'Y37310S'  /*Military operations involving gasoline bomb, military personnel, sequela*/
,'Y37311A'  /*Military operations involving gasoline bomb, civilian, initial encounter*/
,'Y37311D'  /*Military operations involving gasoline bomb, civilian, subsequent encounter*/
,'Y37311S'  /*Military operations involving gasoline bomb, civilian, sequela*/
,'Y37320A'  /*Military operations involving incendiary bullet, military personnel, initial encounter*/
,'Y37320D'  /*Military operations involving incendiary bullet, military personnel, subsequent encounter*/
,'Y37320S'  /*Military operations involving incendiary bullet, military personnel, sequela*/
,'Y37321A'  /*Military operations involving incendiary bullet, civilian, initial encounter*/
,'Y37321D'  /*Military operations involving incendiary bullet, civilian, subsequent encounter*/
,'Y37321S'  /*Military operations involving incendiary bullet, civilian, sequela*/
,'Y37330A'  /*Military operations involving flamethrower, military personnel, initial encounter*/
,'Y37330D'  /*Military operations involving flamethrower, military personnel, subsequent encounter*/
,'Y37330S'  /*Military operations involving flamethrower, military personnel, sequela*/
,'Y37331A'  /*Military operations involving flamethrower, civilian, initial encounter*/
,'Y37331D'  /*Military operations involving flamethrower, civilian, subsequent encounter*/
,'Y37331S'  /*Military operations involving flamethrower, civilian, sequela*/
,'Y37390A'  /*Military operations involving other fires, conflagrations and hot substances, military personnel, initial encounter*/
,'Y37390D'  /*Military operations involving other fires, conflagrations and hot substances, military personnel, subsequent encounter*/
,'Y37390S'  /*Military operations involving other fires, conflagrations and hot substances, military personnel, sequela*/
,'Y37391A'  /*Military operations involving other fires, conflagrations and hot substances, civilian, initial encounter*/
,'Y37391D'  /*Military operations involving other fires, conflagrations and hot substances, civilian, subsequent encounter*/
,'Y37391S'  /*Military operations involving other fires, conflagrations and hot substances, civilian, sequela*/
,'Y37410A'  /*Military operations involving rubber bullets, military personnel, initial encounter*/
,'Y37410D'  /*Military operations involving rubber bullets, military personnel, subsequent encounter*/
,'Y37410S'  /*Military operations involving rubber bullets, military personnel, sequela*/
,'Y37411A'  /*Military operations involving rubber bullets, civilian, initial encounter*/
,'Y37411D'  /*Military operations involving rubber bullets, civilian, subsequent encounter*/
,'Y37411S'  /*Military operations involving rubber bullets, civilian, sequela*/
,'Y37420A'  /*Military operations involving firearms pellets, military personnel, initial encounter*/
,'Y37420D'  /*Military operations involving firearms pellets, military personnel, subsequent encounter*/
,'Y37420S'  /*Military operations involving firearms pellets, military personnel, sequela*/
,'Y37421A'  /*Military operations involving firearms pellets, civilian, initial encounter*/
,'Y37421D'  /*Military operations involving firearms pellets, civilian, subsequent encounter*/
,'Y37421S'  /*Military operations involving firearms pellets, civilian, sequela*/
,'Y37430A'  /*Military operations involving other firearms discharge, military personnel, initial encounter*/
,'Y37430D'  /*Military operations involving other firearms discharge, military personnel, subsequent encounter*/
,'Y37430S'  /*Military operations involving other firearms discharge, military personnel, sequela*/
,'Y37431A'  /*Military operations involving other firearms discharge, civilian, initial encounter*/
,'Y37431D'  /*Military operations involving other firearms discharge, civilian, subsequent encounter*/
,'Y37431S'  /*Military operations involving other firearms discharge, civilian, sequela*/
,'Y37440A'  /*Military operations involving unarmed hand to hand combat, military personnel, initial encounter*/
,'Y37440D'  /*Military operations involving unarmed hand to hand combat, military personnel, subsequent encounter*/
,'Y37440S'  /*Military operations involving unarmed hand to hand combat, military personnel, sequela*/
,'Y37441A'  /*Military operations involving unarmed hand to hand combat, civilian, initial encounter*/
,'Y37441D'  /*Military operations involving unarmed hand to hand combat, civilian, subsequent encounter*/
,'Y37441S'  /*Military operations involving unarmed hand to hand combat, civilian, sequela*/
,'Y37450A'  /*Military operations involving combat using blunt or piercing object, military personnel, initial encounter*/
,'Y37450D'  /*Military operations involving combat using blunt or piercing object, military personnel, subsequent encounter*/
,'Y37450S'  /*Military operations involving combat using blunt or piercing object, military personnel, sequela*/
,'Y37451A'  /*Military operations involving combat using blunt or piercing object, civilian, initial encounter*/
,'Y37451D'  /*Military operations involving combat using blunt or piercing object, civilian, subsequent encounter*/
,'Y37451S'  /*Military operations involving combat using blunt or piercing object, civilian, sequela*/
,'Y37460A'  /*Military operations involving intentional restriction of air and airway, military personnel, initial encounter*/
,'Y37460D'  /*Military operations involving intentional restriction of air and airway, military personnel, subsequent encounter*/
,'Y37460S'  /*Military operations involving intentional restriction of air and airway, military personnel, sequela*/
,'Y37461A'  /*Military operations involving intentional restriction of air and airway, civilian, initial encounter*/
,'Y37461D'  /*Military operations involving intentional restriction of air and airway, civilian, subsequent encounter*/
,'Y37461S'  /*Military operations involving intentional restriction of air and airway, civilian, sequela*/
,'Y37470A'  /*Military operations involving unintentional restriction of air and airway, military personnel, initial encounter*/
,'Y37470D'  /*Military operations involving unintentional restriction of air and airway, military personnel, subsequent encounter*/
,'Y37470S'  /*Military operations involving unintentional restriction of air and airway, military personnel, sequela*/
,'Y37471A'  /*Military operations involving unintentional restriction of air and airway, civilian, initial encounter*/
,'Y37471D'  /*Military operations involving unintentional restriction of air and airway, civilian, subsequent encounter*/
,'Y37471S'  /*Military operations involving unintentional restriction of air and airway, civilian, sequela*/
,'Y37490A'  /*Military operations involving other forms of conventional warfare, military personnel, initial encounter*/
,'Y37490D'  /*Military operations involving other forms of conventional warfare, military personnel, subsequent encounter*/
,'Y37490S'  /*Military operations involving other forms of conventional warfare, military personnel, sequela*/
,'Y37491A'  /*Military operations involving other forms of conventional warfare, civilian, initial encounter*/
,'Y37491D'  /*Military operations involving other forms of conventional warfare, civilian, subsequent encounter*/
,'Y37491S'  /*Military operations involving other forms of conventional warfare, civilian, sequela*/
,'Y37500A'  /*Military operations involving unspecified effect of nuclear weapon, military personnel, initial encounter*/
,'Y37500D'  /*Military operations involving unspecified effect of nuclear weapon, military personnel, subsequent encounter*/
,'Y37500S'  /*Military operations involving unspecified effect of nuclear weapon, military personnel, sequela*/
,'Y37501A'  /*Military operations involving unspecified effect of nuclear weapon, civilian, initial encounter*/
,'Y37501D'  /*Military operations involving unspecified effect of nuclear weapon, civilian, subsequent encounter*/
,'Y37501S'  /*Military operations involving unspecified effect of nuclear weapon, civilian, sequela*/
,'Y37510A'  /*Military operations involving direct blast effect of nuclear weapon, military personnel, initial encounter*/
,'Y37510D'  /*Military operations involving direct blast effect of nuclear weapon, military personnel, subsequent encounter*/
,'Y37510S'  /*Military operations involving direct blast effect of nuclear weapon, military personnel, sequela*/
,'Y37511A'  /*Military operations involving direct blast effect of nuclear weapon, civilian, initial encounter*/
,'Y37511D'  /*Military operations involving direct blast effect of nuclear weapon, civilian, subsequent encounter*/
,'Y37511S'  /*Military operations involving direct blast effect of nuclear weapon, civilian, sequela*/
,'Y37520A'  /*Military operations involving indirect blast effect of nuclear weapon, military personnel, initial encounter*/
,'Y37520D'  /*Military operations involving indirect blast effect of nuclear weapon, military personnel, subsequent encounter*/
,'Y37520S'  /*Military operations involving indirect blast effect of nuclear weapon, military personnel, sequela*/
,'Y37521A'  /*Military operations involving indirect blast effect of nuclear weapon, civilian, initial encounter*/
,'Y37521D'  /*Military operations involving indirect blast effect of nuclear weapon, civilian, subsequent encounter*/
,'Y37521S'  /*Military operations involving indirect blast effect of nuclear weapon, civilian, sequela*/
,'Y37530A'  /*Military operations involving thermal radiation effect of nuclear weapon, military personnel, initial encounter*/
,'Y37530D'  /*Military operations involving thermal radiation effect of nuclear weapon, military personnel, subsequent encounter*/
,'Y37530S'  /*Military operations involving thermal radiation effect of nuclear weapon, military personnel, sequela*/
,'Y37531A'  /*Military operations involving thermal radiation effect of nuclear weapon, civilian, initial encounter*/
,'Y37531D'  /*Military operations involving thermal radiation effect of nuclear weapon, civilian, subsequent encounter*/
,'Y37531S'  /*Military operations involving thermal radiation effect of nuclear weapon, civilian, sequela*/
,'Y37540A'  /*Military operation involving nuclear radiation effects of nuclear weapon, military personnel, initial encounter*/
,'Y37540D'  /*Military operation involving nuclear radiation effects of nuclear weapon, military personnel, subsequent encounter*/
,'Y37540S'  /*Military operation involving nuclear radiation effects of nuclear weapon, military personnel, sequela*/
,'Y37541A'  /*Military operation involving nuclear radiation effects of nuclear weapon, civilian, initial encounter*/
,'Y37541D'  /*Military operation involving nuclear radiation effects of nuclear weapon, civilian, subsequent encounter*/
,'Y37541S'  /*Military operation involving nuclear radiation effects of nuclear weapon, civilian, sequela*/
,'Y37590A'  /*Military operation involving other effects of nuclear weapons, military personnel, initial encounter*/
,'Y37590D'  /*Military operation involving other effects of nuclear weapons, military personnel, subsequent encounter*/
,'Y37590S'  /*Military operation involving other effects of nuclear weapons, military personnel, sequela*/
,'Y37591A'  /*Military operation involving other effects of nuclear weapons, civilian, initial encounter*/
,'Y37591D'  /*Military operation involving other effects of nuclear weapons, civilian, subsequent encounter*/
,'Y37591S'  /*Military operation involving other effects of nuclear weapons, civilian, sequela*/
,'Y376X0A'  /*Military operations involving biological weapons, military personnel, initial encounter*/
,'Y376X0D'  /*Military operations involving biological weapons, military personnel, subsequent encounter*/
,'Y376X0S'  /*Military operations involving biological weapons, military personnel, sequela*/
,'Y376X1A'  /*Military operations involving biological weapons, civilian, initial encounter*/
,'Y376X1D'  /*Military operations involving biological weapons, civilian, subsequent encounter*/
,'Y376X1S'  /*Military operations involving biological weapons, civilian, sequela*/
,'Y377X0A'  /*Military operations involving chemical weapons and other forms of unconventional warfare, military personnel, initial encounter*/
,'Y377X0D'  /*Military operations involving chemical weapons and other forms of unconventional warfare, military personnel, subsequent encounter*/
,'Y377X0S'  /*Military operations involving chemical weapons and other forms of unconventional warfare, military personnel, sequela*/
,'Y377X1A'  /*Military operations involving chemical weapons and other forms of unconventional warfare, civilian, initial encounter*/
,'Y377X1D'  /*Military operations involving chemical weapons and other forms of unconventional warfare, civilian, subsequent encounter*/
,'Y377X1S'  /*Military operations involving chemical weapons and other forms of unconventional warfare, civilian, sequela*/
,'Y3790XA'  /*Military operations, unspecified, initial encounter*/
,'Y3790XD'  /*Military operations, unspecified, subsequent encounter*/
,'Y3790XS'  /*Military operations, unspecified, sequela*/
,'Y3791XA'  /*Military operations involving unspecified weapon of mass destruction [WMD], initial encounter*/
,'Y3791XD'  /*Military operations involving unspecified weapon of mass destruction [WMD], subsequent encounter*/
,'Y3791XS'  /*Military operations involving unspecified weapon of mass destruction [WMD], sequela*/
,'Y3792XA'  /*Military operations involving friendly fire, initial encounter*/
,'Y3792XD'  /*Military operations involving friendly fire, subsequent encounter*/
,'Y3792XS'  /*Military operations involving friendly fire, sequela*/
,'Y380X1D'  /*Terrorism involving explosion of marine weapons, public safety official injured, subsequent encounter*/
,'Y380X1S'  /*Terrorism involving explosion of marine weapons, public safety official injured, sequela*/
,'Y380X2D'  /*Terrorism involving explosion of marine weapons, civilian injured, subsequent encounter*/
,'Y380X2S'  /*Terrorism involving explosion of marine weapons, civilian injured, sequela*/
,'Y380X3D'  /*Terrorism involving explosion of marine weapons, terrorist injured, subsequent encounter*/
,'Y380X3S'  /*Terrorism involving explosion of marine weapons, terrorist injured, sequela*/
,'Y381X1D'  /*Terrorism involving destruction of aircraft, public safety official injured, subsequent encounter*/
,'Y381X1S'  /*Terrorism involving destruction of aircraft, public safety official injured, sequela*/
,'Y381X2D'  /*Terrorism involving destruction of aircraft, civilian injured, subsequent encounter*/
,'Y381X2S'  /*Terrorism involving destruction of aircraft, civilian injured, sequela*/
,'Y381X3D'  /*Terrorism involving destruction of aircraft, terrorist injured, subsequent encounter*/
,'Y381X3S'  /*Terrorism involving destruction of aircraft, terrorist injured, sequela*/
,'Y382X1D'  /*Terrorism involving other explosions and fragments, public safety official injured, subsequent encounter*/
,'Y382X1S'  /*Terrorism involving other explosions and fragments, public safety official injured, sequela*/
,'Y382X2D'  /*Terrorism involving other explosions and fragments, civilian injured, subsequent encounter*/
,'Y382X2S'  /*Terrorism involving other explosions and fragments, civilian injured, sequela*/
,'Y382X3D'  /*Terrorism involving other explosions and fragments, terrorist injured, subsequent encounter*/
,'Y382X3S'  /*Terrorism involving other explosions and fragments, terrorist injured, sequela*/
,'Y383X1D'  /*Terrorism involving fires, conflagration and hot substances, public safety official injured, subsequent encounter*/
,'Y383X1S'  /*Terrorism involving fires, conflagration and hot substances, public safety official injured, sequela*/
,'Y383X2D'  /*Terrorism involving fires, conflagration and hot substances, civilian injured, subsequent encounter*/
,'Y383X2S'  /*Terrorism involving fires, conflagration and hot substances, civilian injured, sequela*/
,'Y383X3D'  /*Terrorism involving fires, conflagration and hot substances, terrorist injured, subsequent encounter*/
,'Y383X3S'  /*Terrorism involving fires, conflagration and hot substances, terrorist injured, sequela*/
,'Y384X1D'  /*Terrorism involving firearms, public safety official injured, subsequent encounter*/
,'Y384X1S'  /*Terrorism involving firearms, public safety official injured, sequela*/
,'Y384X2D'  /*Terrorism involving firearms, civilian injured, subsequent encounter*/
,'Y384X2S'  /*Terrorism involving firearms, civilian injured, sequela*/
,'Y384X3D'  /*Terrorism involving firearms, terrorist injured, subsequent encounter*/
,'Y384X3S'  /*Terrorism involving firearms, terrorist injured, sequela*/
,'Y385X1D'  /*Terrorism involving nuclear weapons, public safety official injured, subsequent encounter*/
,'Y385X1S'  /*Terrorism involving nuclear weapons, public safety official injured, sequela*/
,'Y385X2D'  /*Terrorism involving nuclear weapons, civilian injured, subsequent encounter*/
,'Y385X2S'  /*Terrorism involving nuclear weapons, civilian injured, sequela*/
,'Y385X3D'  /*Terrorism involving nuclear weapons, terrorist injured, subsequent encounter*/
,'Y385X3S'  /*Terrorism involving nuclear weapons, terrorist injured, sequela*/
,'Y386X1D'  /*Terrorism involving biological weapons, public safety official injured, subsequent encounter*/
,'Y386X1S'  /*Terrorism involving biological weapons, public safety official injured, sequela*/
,'Y386X2D'  /*Terrorism involving biological weapons, civilian injured, subsequent encounter*/
,'Y386X2S'  /*Terrorism involving biological weapons, civilian injured, sequela*/
,'Y386X3D'  /*Terrorism involving biological weapons, terrorist injured, subsequent encounter*/
,'Y386X3S'  /*Terrorism involving biological weapons, terrorist injured, sequela*/
,'Y387X1D'  /*Terrorism involving chemical weapons, public safety official injured, subsequent encounter*/
,'Y387X1S'  /*Terrorism involving chemical weapons, public safety official injured, sequela*/
,'Y387X2D'  /*Terrorism involving chemical weapons, civilian injured, subsequent encounter*/
,'Y387X2S'  /*Terrorism involving chemical weapons, civilian injured, sequela*/
,'Y387X3D'  /*Terrorism involving chemical weapons, terrorist injured, subsequent encounter*/
,'Y387X3S'  /*Terrorism involving chemical weapons, terrorist injured, sequela*/
,'Y3880XD'  /*Terrorism involving unspecified means, subsequent encounter*/
,'Y3880XS'  /*Terrorism involving unspecified means, sequela*/
,'Y38811D'  /*Terrorism involving suicide bomber, public safety official injured, subsequent encounter*/
,'Y38811S'  /*Terrorism involving suicide bomber, public safety official injured, sequela*/
,'Y38812D'  /*Terrorism involving suicide bomber, civilian injured, subsequent encounter*/
,'Y38812S'  /*Terrorism involving suicide bomber, civilian injured, sequela*/
,'Y38891D'  /*Terrorism involving other means, public safety official injured, subsequent encounter*/
,'Y38891S'  /*Terrorism involving other means, public safety official injured, sequela*/
,'Y38892D'  /*Terrorism involving other means, civilian injured, subsequent encounter*/
,'Y38892S'  /*Terrorism involving other means, civilian injured, sequela*/
,'Y38893D'  /*Terrorism involving other means, terrorist injured, subsequent encounter*/
,'Y38893S'  /*Terrorism involving other means, terrorist injured, sequela*/
,'Y389X1D'  /*Terrorism, secondary effects, public safety official injured, subsequent encounter*/
,'Y389X1S'  /*Terrorism, secondary effects, public safety official injured, sequela*/
,'Y389X2D'  /*Terrorism, secondary effects, civilian injured, subsequent encounter*/
,'Y389X2S'  /*Terrorism, secondary effects, civilian injured, sequela*/
,'Y92000'  /*Kitchen of unspecified non-institutional (private) residence as the place of occurrence of the external cause*/
,'Y92001'  /*Dining room of unspecified non-institutional (private) residence as the place of occurrence of the external cause*/
,'Y92002'  /*Bathroom of unspecified non-institutional (private) residence single-family (private) house as the place of occurrence of the external cause*/
,'Y92003'  /*Bedroom of unspecified non-institutional (private) residence as the place of occurrence of the external cause*/
,'Y92007'  /*Garden or yard of unspecified non-institutional (private) residence as the place of occurrence of the external cause*/
,'Y92008'  /*Other place in unspecified non-institutional (private) residence as the place of occurrence of the external cause*/
,'Y92009'  /*Unspecified place in unspecified non-institutional (private) residence as the place of occurrence of the external cause*/
,'Y92010'  /*Kitchen of single-family (private) house as the place of occurrence of the external cause*/
,'Y92011'  /*Dining room of single-family (private) house as the place of occurrence of the external cause*/
,'Y92012'  /*Bathroom of single-family (private) house as the place of occurrence of the external cause*/
,'Y92013'  /*Bedroom of single-family (private) house as the place of occurrence of the external cause*/
,'Y92014'  /*Private driveway to single-family (private) house as the place of occurrence of the external cause*/
,'Y92015'  /*Private garage of single-family (private) house as the place of occurrence of the external cause*/
,'Y92016'  /*Swimming-pool in single-family (private) house or garden as the place of occurrence of the external cause*/
,'Y92017'  /*Garden or yard in single-family (private) house as the place of occurrence of the external cause*/
,'Y92018'  /*Other place in single-family (private) house as the place of occurrence of the external cause*/
,'Y92019'  /*Unspecified place in single-family (private) house as the place of occurrence of the external cause*/
,'Y92020'  /*Kitchen in mobile home as the place of occurrence of the external cause*/
,'Y92021'  /*Dining room in mobile home as the place of occurrence of the external cause*/
,'Y92022'  /*Bathroom in mobile home as the place of occurrence of the external cause*/
,'Y92023'  /*Bedroom in mobile home as the place of occurrence of the external cause*/
,'Y92024'  /*Driveway of mobile home as the place of occurrence of the external cause*/
,'Y92025'  /*Garage of mobile home as the place of occurrence of the external cause*/
,'Y92026'  /*Swimming-pool of mobile home as the place of occurrence of the external cause*/
,'Y92027'  /*Garden or yard of mobile home as the place of occurrence of the external cause*/
,'Y92028'  /*Other place in mobile home as the place of occurrence of the external cause*/
,'Y92029'  /*Unspecified place in mobile home as the place of occurrence of the external cause*/
,'Y92030'  /*Kitchen in apartment as the place of occurrence of the external cause*/
,'Y92031'  /*Bathroom in apartment as the place of occurrence of the external cause*/
,'Y92032'  /*Bedroom in apartment as the place of occurrence of the external cause*/
,'Y92038'  /*Other place in apartment as the place of occurrence of the external cause*/
,'Y92039'  /*Unspecified place in apartment as the place of occurrence of the external cause*/
,'Y92040'  /*Kitchen in boarding-house as the place of occurrence of the external cause*/
,'Y92041'  /*Bathroom in boarding-house as the place of occurrence of the external cause*/
,'Y92042'  /*Bedroom in boarding-house as the place of occurrence of the external cause*/
,'Y92043'  /*Driveway of boarding-house as the place of occurrence of the external cause*/
,'Y92044'  /*Garage of boarding-house as the place of occurrence of the external cause*/
,'Y92045'  /*Swimming-pool of boarding-house as the place of occurrence of the external cause*/
,'Y92046'  /*Garden or yard of boarding-house as the place of occurrence of the external cause*/
,'Y92048'  /*Other place in boarding-house as the place of occurrence of the external cause*/
,'Y92049'  /*Unspecified place in boarding-house as the place of occurrence of the external cause*/
,'Y92090'  /*Kitchen in other non-institutional residence as the place of occurrence of the external cause*/
,'Y92091'  /*Bathroom in other non-institutional residence as the place of occurrence of the external cause*/
,'Y92092'  /*Bedroom in other non-institutional residence as the place of occurrence of the external cause*/
,'Y92093'  /*Driveway of other non-institutional residence as the place of occurrence of the external cause*/
,'Y92094'  /*Garage of other non-institutional residence as the place of occurrence of the external cause*/
,'Y92095'  /*Swimming-pool of other non-institutional residence as the place of occurrence of the external cause*/
,'Y92096'  /*Garden or yard of other non-institutional residence as the place of occurrence of the external cause*/
,'Y92098'  /*Other place in other non-institutional residence as the place of occurrence of the external cause*/
,'Y92099'  /*Unspecified place in other non-institutional residence as the place of occurrence of the external cause*/
,'Y9210'  /*Unspecified residential institution as the place of occurrence of the external cause*/
,'Y92110'  /*Kitchen in children's home and orphanage as the place of occurrence of the external cause*/
,'Y92111'  /*Bathroom in children's home and orphanage as the place of occurrence of the external cause*/
,'Y92112'  /*Bedroom in children's home and orphanage as the place of occurrence of the external cause*/
,'Y92113'  /*Driveway of children's home and orphanage as the place of occurrence of the external cause*/
,'Y92114'  /*Garage of children's home and orphanage as the place of occurrence of the external cause*/
,'Y92115'  /*Swimming-pool of children's home and orphanage as the place of occurrence of the external cause*/
,'Y92116'  /*Garden or yard of children's home and orphanage as the place of occurrence of the external cause*/
,'Y92118'  /*Other place in children's home and orphanage as the place of occurrence of the external cause*/
,'Y92119'  /*Unspecified place in children's home and orphanage as the place of occurrence of the external cause*/
,'Y92120'  /*Kitchen in nursing home as the place of occurrence of the external cause*/
,'Y92121'  /*Bathroom in nursing home as the place of occurrence of the external cause*/
,'Y92122'  /*Bedroom in nursing home as the place of occurrence of the external cause*/
,'Y92123'  /*Driveway of nursing home as the place of occurrence of the external cause*/
,'Y92124'  /*Garage of nursing home as the place of occurrence of the external cause*/
,'Y92125'  /*Swimming-pool of nursing home as the place of occurrence of the external cause*/
,'Y92126'  /*Garden or yard of nursing home as the place of occurrence of the external cause*/
,'Y92128'  /*Other place in nursing home as the place of occurrence of the external cause*/
,'Y92129'  /*Unspecified place in nursing home as the place of occurrence of the external cause*/
,'Y92130'  /*Kitchen on military base as the place of occurrence of the external cause*/
,'Y92131'  /*Mess hall on military base as the place of occurrence of the external cause*/
,'Y92133'  /*Barracks on military base as the place of occurrence of the external cause*/
,'Y92135'  /*Garage on military base as the place of occurrence of the external cause*/
,'Y92136'  /*Swimming-pool on military base as the place of occurrence of the external cause*/
,'Y92137'  /*Garden or yard on military base as the place of occurrence of the external cause*/
,'Y92138'  /*Other place on military base as the place of occurrence of the external cause*/
,'Y92139'  /*Unspecified place military base as the place of occurrence of the external cause*/
,'Y92140'  /*Kitchen in prison as the place of occurrence of the external cause*/
,'Y92141'  /*Dining room in prison as the place of occurrence of the external cause*/
,'Y92142'  /*Bathroom in prison as the place of occurrence of the external cause*/
,'Y92143'  /*Cell of prison as the place of occurrence of the external cause*/
,'Y92146'  /*Swimming-pool of prison as the place of occurrence of the external cause*/
,'Y92147'  /*Courtyard of prison as the place of occurrence of the external cause*/
,'Y92148'  /*Other place in prison as the place of occurrence of the external cause*/
,'Y92149'  /*Unspecified place in prison as the place of occurrence of the external cause*/
,'Y92150'  /*Kitchen in reform school as the place of occurrence of the external cause*/
,'Y92151'  /*Dining room in reform school as the place of occurrence of the external cause*/
,'Y92152'  /*Bathroom in reform school as the place of occurrence of the external cause*/
,'Y92153'  /*Bedroom in reform school as the place of occurrence of the external cause*/
,'Y92154'  /*Driveway of reform school as the place of occurrence of the external cause*/
,'Y92155'  /*Garage of reform school as the place of occurrence of the external cause*/
,'Y92156'  /*Swimming-pool of reform school as the place of occurrence of the external cause*/
,'Y92157'  /*Garden or yard of reform school as the place of occurrence of the external cause*/
,'Y92158'  /*Other place in reform school as the place of occurrence of the external cause*/
,'Y92159'  /*Unspecified place in reform school as the place of occurrence of the external cause*/
,'Y92160'  /*Kitchen in school dormitory as the place of occurrence of the external cause*/
,'Y92161'  /*Dining room in school dormitory as the place of occurrence of the external cause*/
,'Y92162'  /*Bathroom in school dormitory as the place of occurrence of the external cause*/
,'Y92163'  /*Bedroom in school dormitory as the place of occurrence of the external cause*/
,'Y92168'  /*Other place in school dormitory as the place of occurrence of the external cause*/
,'Y92169'  /*Unspecified place in school dormitory as the place of occurrence of the external cause*/
,'Y92190'  /*Kitchen in other specified residential institution as the place of occurrence of the external cause*/
,'Y92191'  /*Dining room in other specified residential institution as the place of occurrence of the external cause*/
,'Y92192'  /*Bathroom in other specified residential institution as the place of occurrence of the external cause*/
,'Y92193'  /*Bedroom in other specified residential institution as the place of occurrence of the external cause*/
,'Y92194'  /*Driveway of other specified residential institution as the place of occurrence of the external cause*/
,'Y92195'  /*Garage of other specified residential institution as the place of occurrence of the external cause*/
,'Y92196'  /*Pool of other specified residential institution as the place of occurrence of the external cause*/
,'Y92197'  /*Garden or yard of other specified residential institution as the place of occurrence of the external cause*/
,'Y92198'  /*Other place in other specified residential institution as the place of occurrence of the external cause*/
,'Y92199'  /*Unspecified place in other specified residential institution as the place of occurrence of the external cause*/
,'Y92210'  /*Daycare center as the place of occurrence of the external cause*/
,'Y92211'  /*Elementary school as the place of occurrence of the external cause*/
,'Y92212'  /*Middle school as the place of occurrence of the external cause*/
,'Y92213'  /*High school as the place of occurrence of the external cause*/
,'Y92214'  /*College as the place of occurrence of the external cause*/
,'Y92215'  /*Trade school as the place of occurrence of the external cause*/
,'Y92218'  /*Other school as the place of occurrence of the external cause*/
,'Y92219'  /*Unspecified school as the place of occurrence of the external cause*/
,'Y9222'  /*Religious institution as the place of occurrence of the external cause*/
,'Y92240'  /*Courthouse as the place of occurrence of the external cause*/
,'Y92241'  /*Library as the place of occurrence of the external cause*/
,'Y92242'  /*Post office as the place of occurrence of the external cause*/
,'Y92243'  /*City hall as the place of occurrence of the external cause*/
,'Y92248'  /*Other public administrative building as the place of occurrence of the external cause*/
,'Y92250'  /*Art Gallery as the place of occurrence of the external cause*/
,'Y92251'  /*Museum as the place of occurrence of the external cause*/
,'Y92252'  /*Music hall as the place of occurrence of the external cause*/
,'Y92253'  /*Opera house as the place of occurrence of the external cause*/
,'Y92254'  /*Theater (live) as the place of occurrence of the external cause*/
,'Y92258'  /*Other cultural public building as the place of occurrence of the external cause*/
,'Y9226'  /*Movie house or cinema as the place of occurrence of the external cause*/
,'Y9229'  /*Other specified public building as the place of occurrence of the external cause*/
,'Y92310'  /*Basketball court as the place of occurrence of the external cause*/
,'Y92311'  /*Squash court as the place of occurrence of the external cause*/
,'Y92312'  /*Tennis court as the place of occurrence of the external cause*/
,'Y92318'  /*Other athletic court as the place of occurrence of the external cause*/
,'Y92320'  /*Baseball field as the place of occurrence of the external cause*/
,'Y92321'  /*Football field as the place of occurrence of the external cause*/
,'Y92322'  /*Soccer field as the place of occurrence of the external cause*/
,'Y92328'  /*Other athletic field as the place of occurrence of the external cause*/
,'Y92330'  /*Ice skating rink (indoor) (outdoor) as the place of occurrence of the external cause*/
,'Y92331'  /*Roller skating rink as the place of occurrence of the external cause*/
,'Y9234'  /*Swimming pool (public) as the place of occurrence of the external cause*/
,'Y9239'  /*Other specified sports and athletic area as the place of occurrence of the external cause*/
,'Y92410'  /*Unspecified street and highway as the place of occurrence of the external cause*/
,'Y92411'  /*Interstate highway as the place of occurrence of the external cause*/
,'Y92412'  /*Parkway as the place of occurrence of the external cause*/
,'Y92413'  /*State road as the place of occurrence of the external cause*/
,'Y92414'  /*Local residential or business street as the place of occurrence of the external cause*/
,'Y92415'  /*Exit ramp or entrance ramp of street or highway as the place of occurrence of the external cause*/
,'Y92480'  /*Sidewalk as the place of occurrence of the external cause*/
,'Y92481'  /*Parking lot as the place of occurrence of the external cause*/
,'Y92482'  /*Bike path as the place of occurrence of the external cause*/
,'Y92488'  /*Other paved roadways as the place of occurrence of the external cause*/
,'Y92510'  /*Bank as the place of occurrence of the external cause*/
,'Y92511'  /*Restaurant or cafe as the place of occurrence of the external cause*/
,'Y92512'  /*Supermarket, store or market as the place of occurrence of the external cause*/
,'Y92513'  /*Shop (commercial) as the place of occurrence of the external cause*/
,'Y92520'  /*Airport as the place of occurrence of the external cause*/
,'Y92521'  /*Bus station as the place of occurrence of the external cause*/
,'Y92522'  /*Railway station as the place of occurrence of the external cause*/
,'Y92523'  /*Highway rest stop as the place of occurrence of the external cause*/
,'Y92524'  /*Gas station as the place of occurrence of the external cause*/
,'Y92531'  /*Health care provider office as the place of occurrence of the external cause*/
,'Y92532'  /*Urgent care center as the place of occurrence of the external cause*/
,'Y9259'  /*Other trade areas as the place of occurrence of the external cause*/
,'Y9261'  /*Building [any] under construction as the place of occurrence of the external cause*/
,'Y9262'  /*Dock or shipyard as the place of occurrence of the external cause*/
,'Y9263'  /*Factory as the place of occurrence of the external cause*/
,'Y9264'  /*Mine or pit as the place of occurrence of the external cause*/
,'Y9265'  /*Oil rig as the place of occurrence of the external cause*/
,'Y9269'  /*Other specified industrial and construction area as the place of occurrence of the external cause*/
,'Y9271'  /*Barn as the place of occurrence of the external cause*/
,'Y9272'  /*Chicken coop as the place of occurrence of the external cause*/
,'Y9273'  /*Farm field as the place of occurrence of the external cause*/
,'Y9274'  /*Orchard as the place of occurrence of the external cause*/
,'Y9279'  /*Other farm location as the place of occurrence of the external cause*/
,'Y92810'  /*Car as the place of occurrence of the external cause*/
,'Y92811'  /*Bus as the place of occurrence of the external cause*/
,'Y92812'  /*Truck as the place of occurrence of the external cause*/
,'Y92813'  /*Airplane as the place of occurrence of the external cause*/
,'Y92814'  /*Boat as the place of occurrence of the external cause*/
,'Y92815'  /*Train as the place of occurrence of the external cause*/
,'Y92816'  /*Subway car as the place of occurrence of the external cause*/
,'Y92818'  /*Other transport vehicle as the place of occurrence of the external cause*/
,'Y92820'  /*Desert as the place of occurrence of the external cause*/
,'Y92821'  /*Forest as the place of occurrence of the external cause*/
,'Y92828'  /*Other wilderness area as the place of occurrence of the external cause*/
,'Y92830'  /*Public park as the place of occurrence of the external cause*/
,'Y92831'  /*Amusement park as the place of occurrence of the external cause*/
,'Y92832'  /*Beach as the place of occurrence of the external cause*/
,'Y92833'  /*Campsite as the place of occurrence of the external cause*/
,'Y92834'  /*Zoological garden (Zoo) as the place of occurrence of the external cause*/
,'Y92838'  /*Other recreation area as the place of occurrence of the external cause*/
,'Y9284'  /*Military training ground as the place of occurrence of the external cause*/
,'Y9285'  /*Railroad track as the place of occurrence of the external cause*/
,'Y9286'  /*Slaughter house as the place of occurrence of the external cause*/
,'Y9289'  /*Other specified places as the place of occurrence of the external cause*/
,'Y929'  /*Unspecified place or not applicable*/
,'Y9312'  /*Activity, springboard and platform diving*/
,'Y9313'  /*Activity, water polo*/
,'Y9314'  /*Activity, water aerobics and water exercise*/
,'Y9315'  /*Activity, underwater diving and snorkeling*/
,'Y9316'  /*Activity, rowing, canoeing, kayaking, rafting and tubing*/
,'Y9317'  /*Activity, water skiing and wake boarding*/
,'Y9318'  /*Activity, surfing, windsurfing and boogie boarding*/
,'Y9319'  /*Activity, other involving water and watercraft*/
,'Y9321'  /*Activity, ice skating*/
,'Y9322'  /*Activity, ice hockey*/
,'Y9323'  /*Activity, snow (alpine) (downhill) skiing, snow boarding, sledding, tobogganing and snow tubing*/
,'Y9324'  /*Activity, cross country skiing*/
,'Y9329'  /*Activity, other involving ice and snow*/
,'Y9331'  /*Activity, mountain climbing, rock climbing and wall climbing*/
,'Y9332'  /*Activity, rappelling*/
,'Y9333'  /*Activity, BASE jumping*/
,'Y9334'  /*Activity, bungee jumping*/
,'Y9335'  /*Activity, hang gliding*/
,'Y9339'  /*Activity, other involving climbing, rappelling and jumping off*/
,'Y9341'  /*Activity, dancing*/
,'Y9342'  /*Activity, yoga*/
,'Y9343'  /*Activity, gymnastics*/
,'Y9344'  /*Activity, trampolining*/
,'Y9345'  /*Activity, cheerleading*/
,'Y9349'  /*Activity, other involving dancing and other rhythmic movements*/
,'Y9351'  /*Activity, roller skating (inline) and skateboarding*/
,'Y9352'  /*Activity, horseback riding*/
,'Y9353'  /*Activity, golf*/
,'Y9354'  /*Activity, bowling*/
,'Y9355'  /*Activity, bike riding*/
,'Y9356'  /*Activity, jumping rope*/
,'Y9357'  /*Activity, non-running track and field events*/
,'Y9359'  /*Activity, other involving other sports and athletics played individually*/
,'Y9361'  /*Activity, american tackle football*/
,'Y9362'  /*Activity, american flag or touch football*/
,'Y9363'  /*Activity, rugby*/
,'Y9364'  /*Activity, baseball*/
,'Y9365'  /*Activity, lacrosse and field hockey*/
,'Y9366'  /*Activity, soccer*/
,'Y9367'  /*Activity, basketball*/
,'Y9368'  /*Activity, volleyball (beach) (court)*/
,'Y936A'  /*Activity, physical games generally associated with school recess, summer camp and children*/
,'Y9369'  /*Activity, other involving other sports and athletics played as a team or group*/
,'Y9371'  /*Activity, boxing*/
,'Y9372'  /*Activity, wrestling*/
,'Y9373'  /*Activity, racquet and hand sports*/
,'Y9374'  /*Activity, frisbee*/
,'Y9375'  /*Activity, martial arts*/
,'Y9379'  /*Activity, other specified sports and athletics*/
,'Y93A1'  /*Activity, exercise machines primarily for cardiorespiratory conditioning*/
,'Y93A2'  /*Activity, calisthenics*/
,'Y93A3'  /*Activity, aerobic and step exercise*/
,'Y93A4'  /*Activity, circuit training*/
,'Y93A5'  /*Activity, obstacle course*/
,'Y93A6'  /*Activity, grass drills*/
,'Y93A9'  /*Activity, other involving cardiorespiratory exercise*/
,'Y93B1'  /*Activity, exercise machines primarily for muscle strengthening*/
,'Y93B2'  /*Activity, push-ups, pull-ups, sit-ups*/
,'Y93B3'  /*Activity, free weights*/
,'Y93B4'  /*Activity, pilates*/
,'Y93B9'  /*Activity, other involving muscle strengthening exercises*/
,'Y93C1'  /*Activity, computer keyboarding*/
,'Y93C2'  /*Activity, hand held interactive electronic device*/
,'Y93C9'  /*Activity, other involving computer technology and electronic devices*/
,'Y93D1'  /*Activity, knitting and crocheting*/
,'Y93D2'  /*Activity, sewing*/
,'Y93D3'  /*Activity, furniture building and finishing*/
,'Y93D9'  /*Activity, other involving arts and handcrafts*/
,'Y93E1'  /*Activity, personal bathing and showering*/
,'Y93E2'  /*Activity, laundry*/
,'Y93E3'  /*Activity, vacuuming*/
,'Y93E4'  /*Activity, ironing*/
,'Y93E5'  /*Activity, floor mopping and cleaning*/
,'Y93E6'  /*Activity, residential relocation*/
,'Y93E8'  /*Activity, other personal hygiene*/
,'Y93E9'  /*Activity, other interior property and clothing maintenance*/
,'Y93F1'  /*Activity, caregiving, bathing*/
,'Y93F2'  /*Activity, caregiving, lifting*/
,'Y93F9'  /*Activity, other caregiving*/
,'Y93G1'  /*Activity, food preparation and clean up*/
,'Y93G2'  /*Activity, grilling and smoking food*/
,'Y93G3'  /*Activity, cooking and baking*/
,'Y93G9'  /*Activity, other involving cooking and grilling*/
,'Y93H1'  /*Activity, digging, shoveling and raking*/
,'Y93H2'  /*Activity, gardening and landscaping*/
,'Y93H3'  /*Activity, building and construction*/
,'Y93H9'  /*Activity, other involving exterior property and land maintenance, building and construction*/
,'Y93I1'  /*Activity, roller coaster riding*/
,'Y93I9'  /*Activity, other involving external motion*/
,'Y93J1'  /*Activity, piano playing*/
,'Y93J2'  /*Activity, drum and other percussion instrument playing*/
,'Y93J3'  /*Activity, string instrument playing*/
,'Y93J4'  /*Activity, winds and brass instrument playing*/
,'Y93K1'  /*Activity, walking an animal*/
,'Y93K2'  /*Activity, milking an animal*/
,'Y93K3'  /*Activity, grooming and shearing an animal*/
,'Y93K9'  /*Activity, other involving animal care*/
,'Y9381'  /*Activity, refereeing a sports activity*/
,'Y9382'  /*Activity, spectator at an event*/
,'Y9383'  /*Activity, rough housing and horseplay*/
,'Y9384'  /*Activity, sleeping*/
,'Y9385'  /*Activity, choking game*/
,'Y9389'  /*Activity, other specified*/
,'Y939'  /*Activity, unspecified*/
,'Y990'  /*Civilian activity done for income or pay*/
,'Y991'  /*Military activity*/
,'Y992'  /*Volunteer activity*/
,'Y998'  /*Other external cause status*/
,'Y999'  /*Unspecified external cause status*/
,'Z0000'  /*Encounter for general adult medical examination without abnormal findings*/
,'Z0001'  /*Encounter for general adult medical examination with abnormal findings*/
,'Z00110'  /*Health examination for newborn under 8 days old*/
,'Z00111'  /*Health examination for newborn 8 to 28 days old*/
,'Z00121'  /*Encounter for routine child health examination with abnormal findings*/
,'Z00129'  /*Encounter for routine child health examination without abnormal findings*/
,'Z002'  /*Encounter for examination for period of rapid growth in childhood*/
,'Z003'  /*Encounter for examination for adolescent development state*/
,'Z005'  /*Encounter for examination of potential donor of organ and tissue*/
,'Z006'  /*Encounter for examination for normal comparison and control in clinical research program*/
,'Z0070'  /*Encounter for examination for period of delayed growth in childhood without abnormal findings*/
,'Z0071'  /*Encounter for examination for period of delayed growth in childhood with abnormal findings*/
,'Z008'  /*Encounter for other general examination*/
,'Z0100'  /*Encounter for examination of eyes and vision without abnormal findings*/
,'Z0101'  /*Encounter for examination of eyes and vision with abnormal findings*/
,'Z0110'  /*Encounter for examination of ears and hearing without abnormal findings*/
,'Z01110'  /*Encounter for hearing examination following failed hearing screening*/
,'Z01118'  /*Encounter for examination of ears and hearing with other abnormal findings*/
,'Z0112'  /*Encounter for hearing conservation and treatment*/
,'Z0120'  /*Encounter for dental examination and cleaning without abnormal findings*/
,'Z0121'  /*Encounter for dental examination and cleaning with abnormal findings*/
,'Z0130'  /*Encounter for examination of blood pressure without abnormal findings*/
,'Z0131'  /*Encounter for examination of blood pressure with abnormal findings*/
,'Z01411'  /*Encounter for gynecological examination (general) (routine) with abnormal findings*/
,'Z01419'  /*Encounter for gynecological examination (general) (routine) without abnormal findings*/
,'Z0142'  /*Encounter for cervical smear to confirm findings of recent normal smear following initial abnormal smear*/
,'Z01810'  /*Encounter for preprocedural cardiovascular examination*/
,'Z01811'  /*Encounter for preprocedural respiratory examination*/
,'Z01812'  /*Encounter for preprocedural laboratory examination*/
,'Z01818'  /*Encounter for other preprocedural examination*/
,'Z0182'  /*Encounter for allergy testing*/
,'Z0183'  /*Encounter for blood typing*/
,'Z0184'  /*Encounter for antibody response examination*/
,'Z0189'  /*Encounter for other specified special examinations*/
,'Z020'  /*Encounter for examination for admission to educational institution*/
,'Z021'  /*Encounter for pre-employment examination*/
,'Z022'  /*Encounter for examination for admission to residential institution*/
,'Z023'  /*Encounter for examination for recruitment to armed forces*/
,'Z024'  /*Encounter for examination for driving license*/
,'Z025'  /*Encounter for examination for participation in sport*/
,'Z026'  /*Encounter for examination for insurance purposes*/
,'Z0271'  /*Encounter for disability determination*/
,'Z0279'  /*Encounter for issue of other medical certificate*/
,'Z0281'  /*Encounter for paternity testing*/
,'Z0282'  /*Encounter for adoption services*/
,'Z0283'  /*Encounter for blood-alcohol and blood-drug test*/
,'Z0289'  /*Encounter for other administrative examinations*/
,'Z029'  /*Encounter for administrative examinations, unspecified*/
,'Z036'  /*Encounter for observation for suspected toxic effect from ingested substance ruled out*/
,'Z0371'  /*Encounter for suspected problem with amniotic cavity and membrane ruled out*/
,'Z0372'  /*Encounter for suspected placental problem ruled out*/
,'Z0373'  /*Encounter for suspected fetal anomaly ruled out*/
,'Z0374'  /*Encounter for suspected problem with fetal growth ruled out*/
,'Z0375'  /*Encounter for suspected cervical shortening ruled out*/
,'Z0379'  /*Encounter for other suspected maternal and fetal conditions ruled out*/
,'Z03810'  /*Encounter for observation for suspected exposure to anthrax ruled out*/
,'Z03818'  /*Encounter for observation for suspected exposure to other biological agents ruled out*/
,'Z0389'  /*Encounter for observation for other suspected diseases and conditions ruled out*/
,'Z050'  /*Observation and evaluation of newborn for suspected cardiac condition ruled out*/
,'Z051'  /*Observation and evaluation of newborn for suspected infectious condition ruled out*/
,'Z052'  /*Observation and evaluation of newborn for suspected neurological condition ruled out*/
,'Z053'  /*Observation and evaluation of newborn for suspected respiratory condition ruled out*/
,'Z0541'  /*Observation and evaluation of newborn for suspected genetic condition ruled out*/
,'Z0542'  /*Observation and evaluation of newborn for suspected metabolic condition ruled out*/
,'Z0543'  /*Observation and evaluation of newborn for suspected immunologic condition ruled out*/
,'Z055'  /*Observation and evaluation of newborn for suspected gastrointestinal condition ruled out*/
,'Z056'  /*Observation and evaluation of newborn for suspected genitourinary condition ruled out*/
,'Z0571'  /*Observation and evaluation of newborn for suspected skin and subcutaneous tissue condition ruled out*/
,'Z0572'  /*Observation and evaluation of newborn for suspected musculoskeletal condition ruled out*/
,'Z0573'  /*Observation and evaluation of newborn for suspected connective tissue condition ruled out*/
,'Z058'  /*Observation and evaluation of newborn for other specified suspected condition ruled out*/
,'Z059'  /*Observation and evaluation of newborn for unspecified suspected condition ruled out*/
,'Z08'  /*Encounter for follow-up examination after completed treatment for malignant neoplasm*/
,'Z09'  /*Encounter for follow-up examination after completed treatment for conditions other than malignant neoplasm*/
,'Z110'  /*Encounter for screening for intestinal infectious diseases*/
,'Z111'  /*Encounter for screening for respiratory tuberculosis*/
,'Z112'  /*Encounter for screening for other bacterial diseases*/
,'Z113'  /*Encounter for screening for infections with a predominantly sexual mode of transmission*/
,'Z114'  /*Encounter for screening for human immunodeficiency virus [HIV]*/
,'Z1151'  /*Encounter for screening for human papillomavirus (HPV)*/
,'Z1159'  /*Encounter for screening for other viral diseases*/
,'Z116'  /*Encounter for screening for other protozoal diseases and helminthiases*/
,'Z118'  /*Encounter for screening for other infectious and parasitic diseases*/
,'Z119'  /*Encounter for screening for infectious and parasitic diseases, unspecified*/
,'Z120'  /*Encounter for screening for malignant neoplasm of stomach*/
,'Z1210'  /*Encounter for screening for malignant neoplasm of intestinal tract, unspecified*/
,'Z1211'  /*Encounter for screening for malignant neoplasm of colon*/
,'Z1212'  /*Encounter for screening for malignant neoplasm of rectum*/
,'Z1213'  /*Encounter for screening for malignant neoplasm of small intestine*/
,'Z122'  /*Encounter for screening for malignant neoplasm of respiratory organs*/
,'Z1231'  /*Encounter for screening mammogram for malignant neoplasm of breast*/
,'Z1239'  /*Encounter for other screening for malignant neoplasm of breast*/
,'Z124'  /*Encounter for screening for malignant neoplasm of cervix*/
,'Z125'  /*Encounter for screening for malignant neoplasm of prostate*/
,'Z126'  /*Encounter for screening for malignant neoplasm of bladder*/
,'Z1271'  /*Encounter for screening for malignant neoplasm of testis*/
,'Z1272'  /*Encounter for screening for malignant neoplasm of vagina*/
,'Z1273'  /*Encounter for screening for malignant neoplasm of ovary*/
,'Z1279'  /*Encounter for screening for malignant neoplasm of other genitourinary organs*/
,'Z1281'  /*Encounter for screening for malignant neoplasm of oral cavity*/
,'Z1282'  /*Encounter for screening for malignant neoplasm of nervous system*/
,'Z1283'  /*Encounter for screening for malignant neoplasm of skin*/
,'Z1289'  /*Encounter for screening for malignant neoplasm of other sites*/
,'Z129'  /*Encounter for screening for malignant neoplasm, site unspecified*/
,'Z130'  /*Encounter for screening for diseases of the blood and blood-forming organs and certain disorders involving the immune mechanism*/
,'Z131'  /*Encounter for screening for diabetes mellitus*/
,'Z1321'  /*Encounter for screening for nutritional disorder*/
,'Z13220'  /*Encounter for screening for lipoid disorders*/
,'Z13228'  /*Encounter for screening for other metabolic disorders*/
,'Z1329'  /*Encounter for screening for other suspected endocrine disorder*/
,'Z134'  /*Encounter for screening for certain developmental disorders in childhood*/
,'Z135'  /*Encounter for screening for eye and ear disorders*/
,'Z136'  /*Encounter for screening for cardiovascular disorders*/
,'Z1371'  /*Encounter for nonprocreative screening for genetic disease carrier status*/
,'Z1379'  /*Encounter for other screening for genetic and chromosomal anomalies*/
,'Z13810'  /*Encounter for screening for upper gastrointestinal disorder*/
,'Z13811'  /*Encounter for screening for lower gastrointestinal disorder*/
,'Z13818'  /*Encounter for screening for other digestive system disorders*/
,'Z13820'  /*Encounter for screening for osteoporosis*/
,'Z13828'  /*Encounter for screening for other musculoskeletal disorder*/
,'Z1383'  /*Encounter for screening for respiratory disorder NEC*/
,'Z1384'  /*Encounter for screening for dental disorders*/
,'Z13850'  /*Encounter for screening for traumatic brain injury*/
,'Z13858'  /*Encounter for screening for other nervous system disorders*/
,'Z1388'  /*Encounter for screening for disorder due to exposure to contaminants*/
,'Z1389'  /*Encounter for screening for other disorder*/
,'Z139'  /*Encounter for screening, unspecified*/
,'Z1401'  /*Asymptomatic hemophilia A carrier*/
,'Z1402'  /*Symptomatic hemophilia A carrier*/
,'Z141'  /*Cystic fibrosis carrier*/
,'Z148'  /*Genetic carrier of other disease*/
,'Z1501'  /*Genetic susceptibility to malignant neoplasm of breast*/
,'Z1502'  /*Genetic susceptibility to malignant neoplasm of ovary*/
,'Z1503'  /*Genetic susceptibility to malignant neoplasm of prostate*/
,'Z1504'  /*Genetic susceptibility to malignant neoplasm of endometrium*/
,'Z1509'  /*Genetic susceptibility to other malignant neoplasm*/
,'Z1581'  /*Genetic susceptibility to multiple endocrine neoplasia [MEN]*/
,'Z1589'  /*Genetic susceptibility to other disease*/
,'Z170'  /*Estrogen receptor positive status [ER+]*/
,'Z171'  /*Estrogen receptor negative status [ER-]*/
,'Z1801'  /*Retained depleted uranium fragments*/
,'Z1809'  /*Other retained radioactive fragments*/
,'Z1810'  /*Retained metal fragments, unspecified*/
,'Z1811'  /*Retained magnetic metal fragments*/
,'Z1812'  /*Retained nonmagnetic metal fragments*/
,'Z182'  /*Retained plastic fragments*/
,'Z1831'  /*Retained animal quills or spines*/
,'Z1832'  /*Retained tooth*/
,'Z1833'  /*Retained wood fragments*/
,'Z1839'  /*Other retained organic fragments*/
,'Z1881'  /*Retained glass fragments*/
,'Z1883'  /*Retained stone or crystalline fragments*/
,'Z1889'  /*Other specified retained foreign body fragments*/
,'Z189'  /*Retained foreign body fragments, unspecified material*/
,'Z191'  /*Hormone sensitive malignancy status*/
,'Z192'  /*Hormone resistant malignancy status*/
,'Z220'  /*Carrier of typhoid*/
,'Z221'  /*Carrier of other intestinal infectious diseases*/
,'Z222'  /*Carrier of diphtheria*/
,'Z2231'  /*Carrier of bacterial disease due to meningococci*/
,'Z22321'  /*Carrier or suspected carrier of Methicillin susceptible Staphylococcus aureus*/
,'Z22322'  /*Carrier or suspected carrier of Methicillin resistant Staphylococcus aureus*/
,'Z22330'  /*Carrier of Group B streptococcus*/
,'Z22338'  /*Carrier of other streptococcus*/
,'Z2239'  /*Carrier of other specified bacterial diseases*/
,'Z224'  /*Carrier of infections with a predominantly sexual mode of transmission*/
,'Z226'  /*Carrier of human T-lymphotropic virus type-1 [HTLV-1] infection*/
,'Z228'  /*Carrier of other infectious diseases*/
,'Z229'  /*Carrier of infectious disease, unspecified*/
,'Z23'  /*Encounter for immunization*/
,'Z2801'  /*Immunization not carried out because of acute illness of patient*/
,'Z2802'  /*Immunization not carried out because of chronic illness or condition of patient*/
,'Z2803'  /*Immunization not carried out because of immune compromised state of patient*/
,'Z2804'  /*Immunization not carried out because of patient allergy to vaccine or component*/
,'Z2809'  /*Immunization not carried out because of other contraindication*/
,'Z281'  /*Immunization not carried out because of patient decision for reasons of belief or group pressure*/
,'Z2820'  /*Immunization not carried out because of patient decision for unspecified reason*/
,'Z2821'  /*Immunization not carried out because of patient refusal*/
,'Z2829'  /*Immunization not carried out because of patient decision for other reason*/
,'Z283'  /*Underimmunization status*/
,'Z2881'  /*Immunization not carried out due to patient having had the disease*/
,'Z2882'  /*Immunization not carried out because of caregiver refusal*/
,'Z2889'  /*Immunization not carried out for other reason*/
,'Z289'  /*Immunization not carried out for unspecified reason*/
,'Z2911'  /*Encounter for prophylactic immunotherapy for respiratory syncytial virus (RSV)*/
,'Z2912'  /*Encounter for prophylactic antivenin*/
,'Z2913'  /*Encounter for prophylactic Rho(D) immune globulin*/
,'Z2914'  /*Encounter for prophylactic rabies immune globin*/
,'Z293'  /*Encounter for prophylactic fluoride administration*/
,'Z298'  /*Encounter for other specified prophylactic measures*/
,'Z299'  /*Encounter for prophylactic measures, unspecified*/
,'Z30011'  /*Encounter for initial prescription of contraceptive pills*/
,'Z30012'  /*Encounter for prescription of emergency contraception*/
,'Z30013'  /*Encounter for initial prescription of injectable contraceptive*/
,'Z30014'  /*Encounter for initial prescription of intrauterine contraceptive device*/
,'Z30015'  /*Encounter for initial prescription of vaginal ring hormonal contraceptive*/
,'Z30016'  /*Encounter for initial prescription of transdermal patch hormonal contraceptive device*/
,'Z30017'  /*Encounter for initial prescription of implantable subdermal contraceptive*/
,'Z30018'  /*Encounter for initial prescription of other contraceptives*/
,'Z30019'  /*Encounter for initial prescription of contraceptives, unspecified*/
,'Z3002'  /*Counseling and instruction in natural family planning to avoid pregnancy*/
,'Z3009'  /*Encounter for other general counseling and advice on contraception*/
,'Z302'  /*Encounter for sterilization*/
,'Z3040'  /*Encounter for surveillance of contraceptives, unspecified*/
,'Z3041'  /*Encounter for surveillance of contraceptive pills*/
,'Z3042'  /*Encounter for surveillance of injectable contraceptive*/
,'Z30430'  /*Encounter for insertion of intrauterine contraceptive device*/
,'Z30431'  /*Encounter for routine checking of intrauterine contraceptive device*/
,'Z30432'  /*Encounter for removal of intrauterine contraceptive device*/
,'Z30433'  /*Encounter for removal and reinsertion of intrauterine contraceptive device*/
,'Z3044'  /*Encounter for surveillance of vaginal ring hormonal contraceptive device*/
,'Z3045'  /*Encounter for surveillance of transdermal patch hormonal contraceptive device*/
,'Z3046'  /*Encounter for surveillance of implantable subdermal contraceptive*/
,'Z3049'  /*Encounter for surveillance of other contraceptives*/
,'Z308'  /*Encounter for other contraceptive management*/
,'Z309'  /*Encounter for contraceptive management, unspecified*/
,'Z310'  /*Encounter for reversal of previous sterilization*/
,'Z3141'  /*Encounter for fertility testing*/
,'Z3142'  /*Aftercare following sterilization reversal*/
,'Z31430'  /*Encounter of female for testing for genetic disease carrier status for procreative management*/
,'Z31438'  /*Encounter for other genetic testing of female for procreative management*/
,'Z31440'  /*Encounter of male for testing for genetic disease carrier status for procreative management*/
,'Z31441'  /*Encounter for testing of male partner of patient with recurrent pregnancy loss*/
,'Z31448'  /*Encounter for other genetic testing of male for procreative management*/
,'Z3149'  /*Encounter for other procreative investigation and testing*/
,'Z315'  /*Encounter for genetic counseling*/
,'Z3161'  /*Procreative counseling and advice using natural family planning*/
,'Z3162'  /*Encounter for fertility preservation counseling*/
,'Z3169'  /*Encounter for other general counseling and advice on procreation*/
,'Z317'  /*Encounter for procreative management and counseling for gestational carrier*/
,'Z3181'  /*Encounter for male factor infertility in female patient*/
,'Z3182'  /*Encounter for Rh incompatibility status*/
,'Z3183'  /*Encounter for assisted reproductive fertility procedure cycle*/
,'Z3184'  /*Encounter for fertility preservation procedure*/
,'Z3189'  /*Encounter for other procreative management*/
,'Z319'  /*Encounter for procreative management, unspecified*/
,'Z333'  /*Pregnant state, gestational carrier*/
,'Z3400'  /*Encounter for supervision of normal first pregnancy, unspecified trimester*/
,'Z3401'  /*Encounter for supervision of normal first pregnancy, first trimester*/
,'Z3402'  /*Encounter for supervision of normal first pregnancy, second trimester*/
,'Z3403'  /*Encounter for supervision of normal first pregnancy, third trimester*/
,'Z3480'  /*Encounter for supervision of other normal pregnancy, unspecified trimester*/
,'Z3481'  /*Encounter for supervision of other normal pregnancy, first trimester*/
,'Z3482'  /*Encounter for supervision of other normal pregnancy, second trimester*/
,'Z3483'  /*Encounter for supervision of other normal pregnancy, third trimester*/
,'Z3490'  /*Encounter for supervision of normal pregnancy, unspecified, unspecified trimester*/
,'Z3491'  /*Encounter for supervision of normal pregnancy, unspecified, first trimester*/
,'Z3492'  /*Encounter for supervision of normal pregnancy, unspecified, second trimester*/
,'Z3493'  /*Encounter for supervision of normal pregnancy, unspecified, third trimester*/
,'Z36'  /*Encounter for antenatal screening of mother*/
,'Z3A00'  /*Weeks of gestation of pregnancy not specified*/
,'Z3A01'  /*Less than 8 weeks gestation of pregnancy*/
,'Z3A08'  /*8 weeks gestation of pregnancy*/
,'Z3A09'  /*9 weeks gestation of pregnancy*/
,'Z3A10'  /*10 weeks gestation of pregnancy*/
,'Z3A11'  /*11 weeks gestation of pregnancy*/
,'Z3A12'  /*12 weeks gestation of pregnancy*/
,'Z3A13'  /*13 weeks gestation of pregnancy*/
,'Z3A14'  /*14 weeks gestation of pregnancy*/
,'Z3A15'  /*15 weeks gestation of pregnancy*/
,'Z3A16'  /*16 weeks gestation of pregnancy*/
,'Z3A17'  /*17 weeks gestation of pregnancy*/
,'Z3A18'  /*18 weeks gestation of pregnancy*/
,'Z3A19'  /*19 weeks gestation of pregnancy*/
,'Z3A20'  /*20 weeks gestation of pregnancy*/
,'Z3A21'  /*21 weeks gestation of pregnancy*/
,'Z3A22'  /*22 weeks gestation of pregnancy*/
,'Z3A23'  /*23 weeks gestation of pregnancy*/
,'Z3A24'  /*24 weeks gestation of pregnancy*/
,'Z3A25'  /*25 weeks gestation of pregnancy*/
,'Z3A26'  /*26 weeks gestation of pregnancy*/
,'Z3A27'  /*27 weeks gestation of pregnancy*/
,'Z3A28'  /*28 weeks gestation of pregnancy*/
,'Z3A29'  /*29 weeks gestation of pregnancy*/
,'Z3A30'  /*30 weeks gestation of pregnancy*/
,'Z3A31'  /*31 weeks gestation of pregnancy*/
,'Z3A32'  /*32 weeks gestation of pregnancy*/
,'Z3A33'  /*33 weeks gestation of pregnancy*/
,'Z3A34'  /*34 weeks gestation of pregnancy*/
,'Z3A35'  /*35 weeks gestation of pregnancy*/
,'Z3A36'  /*36 weeks gestation of pregnancy*/
,'Z3A37'  /*37 weeks gestation of pregnancy*/
,'Z3A38'  /*38 weeks gestation of pregnancy*/
,'Z3A39'  /*39 weeks gestation of pregnancy*/
,'Z3A40'  /*40 weeks gestation of pregnancy*/
,'Z3A41'  /*41 weeks gestation of pregnancy*/
,'Z3A42'  /*42 weeks gestation of pregnancy*/
,'Z3A49'  /*Greater than 42 weeks gestation of pregnancy*/
,'Z370'  /*Single live birth*/
,'Z371'  /*Single stillbirth*/
,'Z372'  /*Twins, both liveborn*/
,'Z373'  /*Twins, one liveborn and one stillborn*/
,'Z374'  /*Twins, both stillborn*/
,'Z3750'  /*Multiple births, unspecified, all liveborn*/
,'Z3751'  /*Triplets, all liveborn*/
,'Z3752'  /*Quadruplets, all liveborn*/
,'Z3753'  /*Quintuplets, all liveborn*/
,'Z3754'  /*Sextuplets, all liveborn*/
,'Z3759'  /*Other multiple births, all liveborn*/
,'Z3760'  /*Multiple births, unspecified, some liveborn*/
,'Z3761'  /*Triplets, some liveborn*/
,'Z3762'  /*Quadruplets, some liveborn*/
,'Z3763'  /*Quintuplets, some liveborn*/
,'Z3764'  /*Sextuplets, some liveborn*/
,'Z3769'  /*Other multiple births, some liveborn*/
,'Z377'  /*Other multiple births, all stillborn*/
,'Z379'  /*Outcome of delivery, unspecified*/
,'Z3800'  /*Single liveborn infant, delivered vaginally*/
,'Z3801'  /*Single liveborn infant, delivered by cesarean*/
,'Z381'  /*Single liveborn infant, born outside hospital*/
,'Z382'  /*Single liveborn infant, unspecified as to place of birth*/
,'Z3830'  /*Twin liveborn infant, delivered vaginally*/
,'Z3831'  /*Twin liveborn infant, delivered by cesarean*/
,'Z384'  /*Twin liveborn infant, born outside hospital*/
,'Z385'  /*Twin liveborn infant, unspecified as to place of birth*/
,'Z3861'  /*Triplet liveborn infant, delivered vaginally*/
,'Z3862'  /*Triplet liveborn infant, delivered by cesarean*/
,'Z3863'  /*Quadruplet liveborn infant, delivered vaginally*/
,'Z3864'  /*Quadruplet liveborn infant, delivered by cesarean*/
,'Z3865'  /*Quintuplet liveborn infant, delivered vaginally*/
,'Z3866'  /*Quintuplet liveborn infant, delivered by cesarean*/
,'Z3868'  /*Other multiple liveborn infant, delivered vaginally*/
,'Z3869'  /*Other multiple liveborn infant, delivered by cesarean*/
,'Z387'  /*Other multiple liveborn infant, born outside hospital*/
,'Z388'  /*Other multiple liveborn infant, unspecified as to place of birth*/
,'Z390'  /*Encounter for care and examination of mother immediately after delivery*/
,'Z391'  /*Encounter for care and examination of lactating mother*/
,'Z392'  /*Encounter for routine postpartum follow-up*/
,'Z411'  /*Encounter for cosmetic surgery*/
,'Z412'  /*Encounter for routine and ritual male circumcision*/
,'Z413'  /*Encounter for ear piercing*/
,'Z418'  /*Encounter for other procedures for purposes other than remedying health state*/
,'Z419'  /*Encounter for procedure for purposes other than remedying health state, unspecified*/
,'Z421'  /*Encounter for breast reconstruction following mastectomy*/
,'Z428'  /*Encounter for other plastic and reconstructive surgery following medical procedure or healed injury*/
,'Z430'  /*Encounter for attention to tracheostomy*/
,'Z431'  /*Encounter for attention to gastrostomy*/
,'Z432'  /*Encounter for attention to ileostomy*/
,'Z433'  /*Encounter for attention to colostomy*/
,'Z434'  /*Encounter for attention to other artificial openings of digestive tract*/
,'Z435'  /*Encounter for attention to cystostomy*/
,'Z436'  /*Encounter for attention to other artificial openings of urinary tract*/
,'Z437'  /*Encounter for attention to artificial vagina*/
,'Z438'  /*Encounter for attention to other artificial openings*/
,'Z439'  /*Encounter for attention to unspecified artificial opening*/
,'Z44001'  /*Encounter for fitting and adjustment of unspecified right artificial arm*/
,'Z44002'  /*Encounter for fitting and adjustment of unspecified left artificial arm*/
,'Z44009'  /*Encounter for fitting and adjustment of unspecified artificial arm, unspecified arm*/
,'Z44011'  /*Encounter for fitting and adjustment of complete right artificial arm*/
,'Z44012'  /*Encounter for fitting and adjustment of complete left artificial arm*/
,'Z44019'  /*Encounter for fitting and adjustment of complete artificial arm, unspecified arm*/
,'Z44021'  /*Encounter for fitting and adjustment of partial artificial right arm*/
,'Z44022'  /*Encounter for fitting and adjustment of partial artificial left arm*/
,'Z44029'  /*Encounter for fitting and adjustment of partial artificial arm, unspecified arm*/
,'Z44101'  /*Encounter for fitting and adjustment of unspecified right artificial leg*/
,'Z44102'  /*Encounter for fitting and adjustment of unspecified left artificial leg*/
,'Z44109'  /*Encounter for fitting and adjustment of unspecified artificial leg, unspecified leg*/
,'Z44111'  /*Encounter for fitting and adjustment of complete right artificial leg*/
,'Z44112'  /*Encounter for fitting and adjustment of complete left artificial leg*/
,'Z44119'  /*Encounter for fitting and adjustment of complete artificial leg, unspecified leg*/
,'Z44121'  /*Encounter for fitting and adjustment of partial artificial right leg*/
,'Z44122'  /*Encounter for fitting and adjustment of partial artificial left leg*/
,'Z44129'  /*Encounter for fitting and adjustment of partial artificial leg, unspecified leg*/
,'Z4420'  /*Encounter for fitting and adjustment of artificial eye, unspecified*/
,'Z4421'  /*Encounter for fitting and adjustment of artificial right eye*/
,'Z4422'  /*Encounter for fitting and adjustment of artificial left eye*/
,'Z4430'  /*Encounter for fitting and adjustment of external breast prosthesis, unspecified breast*/
,'Z4431'  /*Encounter for fitting and adjustment of external right breast prosthesis*/
,'Z4432'  /*Encounter for fitting and adjustment of external left breast prosthesis*/
,'Z448'  /*Encounter for fitting and adjustment of other external prosthetic devices*/
,'Z449'  /*Encounter for fitting and adjustment of unspecified external prosthetic device*/
,'Z45010'  /*Encounter for checking and testing of cardiac pacemaker pulse generator [battery]*/
,'Z45018'  /*Encounter for adjustment and management of other part of cardiac pacemaker*/
,'Z4502'  /*Encounter for adjustment and management of automatic implantable cardiac defibrillator*/
,'Z4509'  /*Encounter for adjustment and management of other cardiac device*/
,'Z451'  /*Encounter for adjustment and management of infusion pump*/
,'Z452'  /*Encounter for adjustment and management of vascular access device*/
,'Z4531'  /*Encounter for adjustment and management of implanted visual substitution device*/
,'Z45320'  /*Encounter for adjustment and management of bone conduction device*/
,'Z45321'  /*Encounter for adjustment and management of cochlear device*/
,'Z45328'  /*Encounter for adjustment and management of other implanted hearing device*/
,'Z4541'  /*Encounter for adjustment and management of cerebrospinal fluid drainage device*/
,'Z4542'  /*Encounter for adjustment and management of neuropacemaker (brain) (peripheral nerve) (spinal cord)*/
,'Z4549'  /*Encounter for adjustment and management of other implanted nervous system device*/
,'Z45811'  /*Encounter for adjustment or removal of right breast implant*/
,'Z45812'  /*Encounter for adjustment or removal of left breast implant*/
,'Z45819'  /*Encounter for adjustment or removal of unspecified breast implant*/
,'Z4582'  /*Encounter for adjustment or removal of myringotomy device (stent) (tube)*/
,'Z4589'  /*Encounter for adjustment and management of other implanted devices*/
,'Z459'  /*Encounter for adjustment and management of unspecified implanted device*/
,'Z460'  /*Encounter for fitting and adjustment of spectacles and contact lenses*/
,'Z461'  /*Encounter for fitting and adjustment of hearing aid*/
,'Z462'  /*Encounter for fitting and adjustment of other devices related to nervous system and special senses*/
,'Z463'  /*Encounter for fitting and adjustment of dental prosthetic device*/
,'Z464'  /*Encounter for fitting and adjustment of orthodontic device*/
,'Z4651'  /*Encounter for fitting and adjustment of gastric lap band*/
,'Z4659'  /*Encounter for fitting and adjustment of other gastrointestinal appliance and device*/
,'Z466'  /*Encounter for fitting and adjustment of urinary device*/
,'Z4681'  /*Encounter for fitting and adjustment of insulin pump*/
,'Z4682'  /*Encounter for fitting and adjustment of non-vascular catheter*/
,'Z4689'  /*Encounter for fitting and adjustment of other specified devices*/
,'Z469'  /*Encounter for fitting and adjustment of unspecified device*/
,'Z471'  /*Aftercare following joint replacement surgery*/
,'Z472'  /*Encounter for removal of internal fixation device*/
,'Z4731'  /*Aftercare following explantation of shoulder joint prosthesis*/
,'Z4732'  /*Aftercare following explantation of hip joint prosthesis*/
,'Z4733'  /*Aftercare following explantation of knee joint prosthesis*/
,'Z4781'  /*Encounter for orthopedic aftercare following surgical amputation*/
,'Z4782'  /*Encounter for orthopedic aftercare following scoliosis surgery*/
,'Z4789'  /*Encounter for other orthopedic aftercare*/
,'Z4800'  /*Encounter for change or removal of nonsurgical wound dressing*/
,'Z4801'  /*Encounter for change or removal of surgical wound dressing*/
,'Z4802'  /*Encounter for removal of sutures*/
,'Z4803'  /*Encounter for change or removal of drains*/
,'Z481'  /*Encounter for planned postprocedural wound closure*/
,'Z4821'  /*Encounter for aftercare following heart transplant*/
,'Z4822'  /*Encounter for aftercare following kidney transplant*/
,'Z4823'  /*Encounter for aftercare following liver transplant*/
,'Z4824'  /*Encounter for aftercare following lung transplant*/
,'Z48280'  /*Encounter for aftercare following heart-lung transplant*/
,'Z48288'  /*Encounter for aftercare following multiple organ transplant*/
,'Z48290'  /*Encounter for aftercare following bone marrow transplant*/
,'Z48298'  /*Encounter for aftercare following other organ transplant*/
,'Z483'  /*Aftercare following surgery for neoplasm*/
,'Z48810'  /*Encounter for surgical aftercare following surgery on the sense organs*/
,'Z48811'  /*Encounter for surgical aftercare following surgery on the nervous system*/
,'Z48812'  /*Encounter for surgical aftercare following surgery on the circulatory system*/
,'Z48813'  /*Encounter for surgical aftercare following surgery on the respiratory system*/
,'Z48814'  /*Encounter for surgical aftercare following surgery on the teeth or oral cavity*/
,'Z48815'  /*Encounter for surgical aftercare following surgery on the digestive system*/
,'Z48816'  /*Encounter for surgical aftercare following surgery on the genitourinary system*/
,'Z48817'  /*Encounter for surgical aftercare following surgery on the skin and subcutaneous tissue*/
,'Z4889'  /*Encounter for other specified surgical aftercare*/
,'Z4901'  /*Encounter for fitting and adjustment of extracorporeal dialysis catheter*/
,'Z4902'  /*Encounter for fitting and adjustment of peritoneal dialysis catheter*/
,'Z4931'  /*Encounter for adequacy testing for hemodialysis*/
,'Z4932'  /*Encounter for adequacy testing for peritoneal dialysis*/
,'Z510'  /*Encounter for antineoplastic radiation therapy*/
,'Z5111'  /*Encounter for antineoplastic chemotherapy*/
,'Z5112'  /*Encounter for antineoplastic immunotherapy*/
,'Z516'  /*Encounter for desensitization to allergens*/
,'Z5181'  /*Encounter for therapeutic drug level monitoring*/
,'Z5189'  /*Encounter for other specified aftercare*/
,'Z52000'  /*Unspecified donor, whole blood*/
,'Z52001'  /*Unspecified donor, stem cells*/
,'Z52008'  /*Unspecified donor, other blood*/
,'Z52010'  /*Autologous donor, whole blood*/
,'Z52011'  /*Autologous donor, stem cells*/
,'Z52018'  /*Autologous donor, other blood*/
,'Z52090'  /*Other blood donor, whole blood*/
,'Z52091'  /*Other blood donor, stem cells*/
,'Z52098'  /*Other blood donor, other blood*/
,'Z5210'  /*Skin donor, unspecified*/
,'Z5211'  /*Skin donor, autologous*/
,'Z5219'  /*Skin donor, other*/
,'Z5220'  /*Bone donor, unspecified*/
,'Z5221'  /*Bone donor, autologous*/
,'Z5229'  /*Bone donor, other*/
,'Z523'  /*Bone marrow donor*/
,'Z524'  /*Kidney donor*/
,'Z525'  /*Cornea donor*/
,'Z526'  /*Liver donor*/
,'Z52810'  /*Egg (Oocyte) donor under age 35, anonymous recipient*/
,'Z52811'  /*Egg (Oocyte) donor under age 35, designated recipient*/
,'Z52812'  /*Egg (Oocyte) donor age 35 and over, anonymous recipient*/
,'Z52813'  /*Egg (Oocyte) donor age 35 and over, designated recipient*/
,'Z52819'  /*Egg (Oocyte) donor, unspecified*/
,'Z5289'  /*Donor of other specified organs or tissues*/
,'Z529'  /*Donor of unspecified organ or tissue*/
,'Z5331'  /*Laparoscopic surgical procedure converted to open procedure*/
,'Z5332'  /*Thoracoscopic surgical procedure converted to open procedure*/
,'Z5333'  /*Arthroscopic surgical procedure converted to open procedure*/
,'Z5339'  /*Other specified procedure converted to open procedure*/
,'Z550'  /*Illiteracy and low-level literacy*/
,'Z551'  /*Schooling unavailable and unattainable*/
,'Z552'  /*Failed school examinations*/
,'Z553'  /*Underachievement in school*/
,'Z554'  /*Educational maladjustment and discord with teachers and classmates*/
,'Z558'  /*Other problems related to education and literacy*/
,'Z559'  /*Problems related to education and literacy, unspecified*/
,'Z560'  /*Unemployment, unspecified*/
,'Z561'  /*Change of job*/
,'Z562'  /*Threat of job loss*/
,'Z563'  /*Stressful work schedule*/
,'Z564'  /*Discord with boss and workmates*/
,'Z565'  /*Uncongenial work environment*/
,'Z566'  /*Other physical and mental strain related to work*/
,'Z5681'  /*Sexual harassment on the job*/
,'Z5682'  /*Military deployment status*/
,'Z5689'  /*Other problems related to employment*/
,'Z569'  /*Unspecified problems related to employment*/
,'Z570'  /*Occupational exposure to noise*/
,'Z571'  /*Occupational exposure to radiation*/
,'Z572'  /*Occupational exposure to dust*/
,'Z5731'  /*Occupational exposure to environmental tobacco smoke*/
,'Z5739'  /*Occupational exposure to other air contaminants*/
,'Z574'  /*Occupational exposure to toxic agents in agriculture*/
,'Z575'  /*Occupational exposure to toxic agents in other industries*/
,'Z576'  /*Occupational exposure to extreme temperature*/
,'Z577'  /*Occupational exposure to vibration*/
,'Z578'  /*Occupational exposure to other risk factors*/
,'Z579'  /*Occupational exposure to unspecified risk factor*/
,'Z590'  /*Homelessness*/
,'Z591'  /*Inadequate housing*/
,'Z592'  /*Discord with neighbors, lodgers and landlord*/
,'Z593'  /*Problems related to living in residential institution*/
,'Z594'  /*Lack of adequate food and safe drinking water*/
,'Z595'  /*Extreme poverty*/
,'Z596'  /*Low income*/
,'Z597'  /*Insufficient social insurance and welfare support*/
,'Z598'  /*Other problems related to housing and economic circumstances*/
,'Z599'  /*Problem related to housing and economic circumstances, unspecified*/
,'Z630'  /*Problems in relationship with spouse or partner*/
,'Z631'  /*Problems in relationship with in-laws*/
,'Z6331'  /*Absence of family member due to military deployment*/
,'Z6332'  /*Other absence of family member*/
,'Z634'  /*Disappearance and death of family member*/
,'Z635'  /*Disruption of family by separation and divorce*/
,'Z636'  /*Dependent relative needing care at home*/
,'Z6371'  /*Stress on family due to return of family member from military deployment*/
,'Z6372'  /*Alcoholism and drug addiction in family*/
,'Z6379'  /*Other stressful life events affecting family and household*/
,'Z638'  /*Other specified problems related to primary support group*/
,'Z639'  /*Problem related to primary support group, unspecified*/
,'Z640'  /*Problems related to unwanted pregnancy*/
,'Z641'  /*Problems related to multiparity*/
,'Z644'  /*Discord with counselors*/
,'Z650'  /*Conviction in civil and criminal proceedings without imprisonment*/
,'Z651'  /*Imprisonment and other incarceration*/
,'Z652'  /*Problems related to release from prison*/
,'Z653'  /*Problems related to other legal circumstances*/
,'Z654'  /*Victim of crime and terrorism*/
,'Z655'  /*Exposure to disaster, war and other hostilities*/
,'Z658'  /*Other specified problems related to psychosocial circumstances*/
,'Z659'  /*Problem related to unspecified psychosocial circumstances*/
,'Z6710'  /*Type A blood, Rh positive*/
,'Z6711'  /*Type A blood, Rh negative*/
,'Z6720'  /*Type B blood, Rh positive*/
,'Z6721'  /*Type B blood, Rh negative*/
,'Z6730'  /*Type AB blood, Rh positive*/
,'Z6731'  /*Type AB blood, Rh negative*/
,'Z6740'  /*Type O blood, Rh positive*/
,'Z6741'  /*Type O blood, Rh negative*/
,'Z6790'  /*Unspecified blood type, Rh positive*/
,'Z6791'  /*Unspecified blood type, Rh negative*/
,'Z681'  /*Body mass index (BMI) 19 or less, adult*/
,'Z6820'  /*Body mass index (BMI) 200-209, adult*/
,'Z6821'  /*Body mass index (BMI) 210-219, adult*/
,'Z6822'  /*Body mass index (BMI) 220-229, adult*/
,'Z6823'  /*Body mass index (BMI) 230-239, adult*/
,'Z6824'  /*Body mass index (BMI) 240-249, adult*/
,'Z6825'  /*Body mass index (BMI) 250-259, adult*/
,'Z6826'  /*Body mass index (BMI) 260-269, adult*/
,'Z6827'  /*Body mass index (BMI) 270-279, adult*/
,'Z6828'  /*Body mass index (BMI) 280-289, adult*/
,'Z6829'  /*Body mass index (BMI) 290-299, adult*/
,'Z6830'  /*Body mass index (BMI) 300-309, adult*/
,'Z6831'  /*Body mass index (BMI) 310-319, adult*/
,'Z6832'  /*Body mass index (BMI) 320-329, adult*/
,'Z6833'  /*Body mass index (BMI) 330-339, adult*/
,'Z6834'  /*Body mass index (BMI) 340-349, adult*/
,'Z6835'  /*Body mass index (BMI) 350-359, adult*/
,'Z6836'  /*Body mass index (BMI) 360-369, adult*/
,'Z6837'  /*Body mass index (BMI) 370-379, adult*/
,'Z6838'  /*Body mass index (BMI) 380-389, adult*/
,'Z6839'  /*Body mass index (BMI) 390-399, adult*/
,'Z6841'  /*Body mass index (BMI) 400-449, adult*/
,'Z6842'  /*Body mass index (BMI) 450-499, adult*/
,'Z6843'  /*Body mass index (BMI) 50-599 , adult*/
,'Z6844'  /*Body mass index (BMI) 600-699, adult*/
,'Z6845'  /*Body mass index (BMI) 70 or greater, adult*/
,'Z6851'  /*Body mass index (BMI) pediatric, less than 5th percentile for age*/
,'Z6852'  /*Body mass index (BMI) pediatric, 5th percentile to less than 85th percentile for age*/
,'Z6853'  /*Body mass index (BMI) pediatric, 85th percentile to less than 95th percentile for age*/
,'Z6854'  /*Body mass index (BMI) pediatric, greater than or equal to 95th percentile for age*/
,'Z69010'  /*Encounter for mental health services for victim of parental child abuse*/
,'Z69011'  /*Encounter for mental health services for perpetrator of parental child abuse*/
,'Z69020'  /*Encounter for mental health services for victim of non-parental child abuse*/
,'Z69021'  /*Encounter for mental health services for perpetrator of non-parental child abuse*/
,'Z6911'  /*Encounter for mental health services for victim of spousal or partner abuse*/
,'Z6912'  /*Encounter for mental health services for perpetrator of spousal or partner abuse*/
,'Z6981'  /*Encounter for mental health services for victim of other abuse*/
,'Z6982'  /*Encounter for mental health services for perpetrator of other abuse*/
,'Z700'  /*Counseling related to sexual attitude*/
,'Z701'  /*Counseling related to patient's sexual behavior and orientation*/
,'Z702'  /*Counseling related to sexual behavior and orientation of third party*/
,'Z703'  /*Counseling related to combined concerns regarding sexual attitude, behavior and orientation*/
,'Z708'  /*Other sex counseling*/
,'Z709'  /*Sex counseling, unspecified*/
,'Z710'  /*Person encountering health services to consult on behalf of another person*/
,'Z711'  /*Person with feared health complaint in whom no diagnosis is made*/
,'Z712'  /*Person consulting for explanation of examination or test findings*/
,'Z713'  /*Dietary counseling and surveillance*/
,'Z7141'  /*Alcohol abuse counseling and surveillance of alcoholic*/
,'Z7142'  /*Counseling for family member of alcoholic*/
,'Z7151'  /*Drug abuse counseling and surveillance of drug abuser*/
,'Z7152'  /*Counseling for family member of drug abuser*/
,'Z716'  /*Tobacco abuse counseling*/
,'Z717'  /*Human immunodeficiency virus [HIV] counseling*/
,'Z7181'  /*Spiritual or religious counseling*/
,'Z7189'  /*Other specified counseling*/
,'Z719'  /*Counseling, unspecified*/
,'Z720'  /*Tobacco use*/
,'Z723'  /*Lack of physical exercise*/
,'Z724'  /*Inappropriate diet and eating habits*/
,'Z7251'  /*High risk heterosexual behavior*/
,'Z7252'  /*High risk homosexual behavior*/
,'Z7253'  /*High risk bisexual behavior*/
,'Z726'  /*Gambling and betting*/
,'Z72810'  /*Child and adolescent antisocial behavior*/
,'Z72811'  /*Adult antisocial behavior*/
,'Z72820'  /*Sleep deprivation*/
,'Z72821'  /*Inadequate sleep hygiene*/
,'Z7289'  /*Other problems related to lifestyle*/
,'Z729'  /*Problem related to lifestyle, unspecified*/
,'Z730'  /*Burn-out*/
,'Z731'  /*Type A behavior pattern*/
,'Z732'  /*Lack of relaxation and leisure*/
,'Z733'  /*Stress, not elsewhere classified*/
,'Z734'  /*Inadequate social skills, not elsewhere classified*/
,'Z735'  /*Social role conflict, not elsewhere classified*/
,'Z736'  /*Limitation of activities due to disability*/
,'Z73810'  /*Behavioral insomnia of childhood, sleep-onset association type*/
,'Z73811'  /*Behavioral insomnia of childhood, limit setting type*/
,'Z73812'  /*Behavioral insomnia of childhood, combined type*/
,'Z73819'  /*Behavioral insomnia of childhood, unspecified type*/
,'Z7382'  /*Dual sensory impairment*/
,'Z7389'  /*Other problems related to life management difficulty*/
,'Z739'  /*Problem related to life management difficulty, unspecified*/
,'Z7401'  /*Bed confinement status*/
,'Z750'  /*Medical services not available in home*/
,'Z751'  /*Person awaiting admission to adequate facility elsewhere*/
,'Z752'  /*Other waiting period for investigation and treatment*/
,'Z753'  /*Unavailability and inaccessibility of health-care facilities*/
,'Z754'  /*Unavailability and inaccessibility of other helping agencies*/
,'Z755'  /*Holiday relief care*/
,'Z758'  /*Other problems related to medical facilities and other health care*/
,'Z759'  /*Unspecified problem related to medical facilities and other health care*/
,'Z760'  /*Encounter for issue of repeat prescription*/
,'Z761'  /*Encounter for health supervision and care of foundling*/
,'Z762'  /*Encounter for health supervision and care of other healthy infant and child*/
,'Z763'  /*Healthy person accompanying sick person*/
,'Z764'  /*Other boarder to healthcare facility*/
,'Z765'  /*Malingerer [conscious simulation]*/
,'Z7681'  /*Expectant parent(s) prebirth pediatrician visit*/
,'Z7682'  /*Awaiting organ transplant status*/
,'Z7689'  /*Persons encountering health services in other specified circumstances*/
,'Z77110'  /*Contact with and (suspected) exposure to air pollution*/
,'Z77111'  /*Contact with and (suspected) exposure to water pollution*/
,'Z77112'  /*Contact with and (suspected) exposure to soil pollution*/
,'Z77118'  /*Contact with and (suspected) exposure to other environmental pollution*/
,'Z77120'  /*Contact with and (suspected) exposure to mold (toxic)*/
,'Z77121'  /*Contact with and (suspected) exposure to harmful algae and algae toxins*/
,'Z77122'  /*Contact with and (suspected) exposure to noise*/
,'Z77123'  /*Contact with and (suspected) exposure to radon and other naturally occuring radiation*/
,'Z77128'  /*Contact with and (suspected) exposure to other hazards in the physical environment*/
,'Z780'  /*Asymptomatic menopausal state*/
,'Z781'  /*Physical restraint status*/
,'Z789'  /*Other specified health status*/
,'Z7901'  /*Long term (current) use of anticoagulants*/
,'Z7902'  /*Long term (current) use of antithrombotics/antiplatelets*/
,'Z791'  /*Long term (current) use of non-steroidal anti-inflammatories (NSAID)*/
,'Z792'  /*Long term (current) use of antibiotics*/
,'Z793'  /*Long term (current) use of hormonal contraceptives*/
,'Z794'  /*Long term (current) use of insulin*/
,'Z7951'  /*Long term (current) use of inhaled steroids*/
,'Z7952'  /*Long term (current) use of systemic steroids*/
,'Z79810'  /*Long term (current) use of selective estrogen receptor modulators (SERMs)*/
,'Z79811'  /*Long term (current) use of aromatase inhibitors*/
,'Z79818'  /*Long term (current) use of other agents affecting estrogen receptors and estrogen levels*/
,'Z7982'  /*Long term (current) use of aspirin*/
,'Z7983'  /*Long term (current) use of bisphosphonates*/
,'Z7984'  /*Long term (current) use of oral hypoglycemic drugs*/
,'Z79890'  /*Hormone replacement therapy (postmenopausal)*/
,'Z79891'  /*Long term (current) use of opiate analgesic*/
,'Z79899'  /*Other long term (current) drug therapy*/
,'Z800'  /*Family history of malignant neoplasm of digestive organs*/
,'Z801'  /*Family history of malignant neoplasm of trachea, bronchus and lung*/
,'Z802'  /*Family history of malignant neoplasm of other respiratory and intrathoracic organs*/
,'Z803'  /*Family history of malignant neoplasm of breast*/
,'Z8041'  /*Family history of malignant neoplasm of ovary*/
,'Z8042'  /*Family history of malignant neoplasm of prostate*/
,'Z8043'  /*Family history of malignant neoplasm of testis*/
,'Z8049'  /*Family history of malignant neoplasm of other genital organs*/
,'Z8051'  /*Family history of malignant neoplasm of kidney*/
,'Z8052'  /*Family history of malignant neoplasm of bladder*/
,'Z8059'  /*Family history of malignant neoplasm of other urinary tract organ*/
,'Z806'  /*Family history of leukemia*/
,'Z807'  /*Family history of other malignant neoplasms of lymphoid, hematopoietic and related tissues*/
,'Z808'  /*Family history of malignant neoplasm of other organs or systems*/
,'Z809'  /*Family history of malignant neoplasm, unspecified*/
,'Z810'  /*Family history of intellectual disabilities*/
,'Z811'  /*Family history of alcohol abuse and dependence*/
,'Z812'  /*Family history of tobacco abuse and dependence*/
,'Z813'  /*Family history of other psychoactive substance abuse and dependence*/
,'Z814'  /*Family history of other substance abuse and dependence*/
,'Z818'  /*Family history of other mental and behavioral disorders*/
,'Z820'  /*Family history of epilepsy and other diseases of the nervous system*/
,'Z821'  /*Family history of blindness and visual loss*/
,'Z822'  /*Family history of deafness and hearing loss*/
,'Z823'  /*Family history of stroke*/
,'Z8241'  /*Family history of sudden cardiac death*/
,'Z8249'  /*Family history of ischemic heart disease and other diseases of the circulatory system*/
,'Z825'  /*Family history of asthma and other chronic lower respiratory diseases*/
,'Z8261'  /*Family history of arthritis*/
,'Z8262'  /*Family history of osteoporosis*/
,'Z8269'  /*Family history of other diseases of the musculoskeletal system and connective tissue*/
,'Z8271'  /*Family history of polycystic kidney*/
,'Z8279'  /*Family history of other congenital malformations, deformations and chromosomal abnormalities*/
,'Z828'  /*Family history of other disabilities and chronic diseases leading to disablement, not elsewhere classified*/
,'Z830'  /*Family history of human immunodeficiency virus [HIV] disease*/
,'Z831'  /*Family history of other infectious and parasitic diseases*/
,'Z832'  /*Family history of diseases of the blood and blood-forming organs and certain disorders involving the immune mechanism*/
,'Z833'  /*Family history of diabetes mellitus*/
,'Z8341'  /*Family history of multiple endocrine neoplasia [MEN] syndrome*/
,'Z8342'  /*Family history of familial hypercholesterolemia*/
,'Z8349'  /*Family history of other endocrine, nutritional and metabolic diseases*/
,'Z83511'  /*Family history of glaucoma*/
,'Z83518'  /*Family history of other specified eye disorder*/
,'Z8352'  /*Family history of ear disorders*/
,'Z836'  /*Family history of other diseases of the respiratory system*/
,'Z8371'  /*Family history of colonic polyps*/
,'Z8379'  /*Family history of other diseases of the digestive system*/
,'Z840'  /*Family history of diseases of the skin and subcutaneous tissue*/
,'Z841'  /*Family history of disorders of kidney and ureter*/
,'Z842'  /*Family history of other diseases of the genitourinary system*/
,'Z843'  /*Family history of consanguinity*/
,'Z8481'  /*Family history of carrier of genetic disease*/
,'Z8482'  /*Family history of sudden infant death syndrome*/
,'Z8489'  /*Family history of other specified conditions*/
,'Z8500'  /*Personal history of malignant neoplasm of unspecified digestive organ*/
,'Z8501'  /*Personal history of malignant neoplasm of esophagus*/
,'Z85020'  /*Personal history of malignant carcinoid tumor of stomach*/
,'Z85028'  /*Personal history of other malignant neoplasm of stomach*/
,'Z85030'  /*Personal history of malignant carcinoid tumor of large intestine*/
,'Z85038'  /*Personal history of other malignant neoplasm of large intestine*/
,'Z85040'  /*Personal history of malignant carcinoid tumor of rectum*/
,'Z85048'  /*Personal history of other malignant neoplasm of rectum, rectosigmoid junction, and anus*/
,'Z8505'  /*Personal history of malignant neoplasm of liver*/
,'Z85060'  /*Personal history of malignant carcinoid tumor of small intestine*/
,'Z85068'  /*Personal history of other malignant neoplasm of small intestine*/
,'Z8507'  /*Personal history of malignant neoplasm of pancreas*/
,'Z8509'  /*Personal history of malignant neoplasm of other digestive organs*/
,'Z85110'  /*Personal history of malignant carcinoid tumor of bronchus and lung*/
,'Z85118'  /*Personal history of other malignant neoplasm of bronchus and lung*/
,'Z8512'  /*Personal history of malignant neoplasm of trachea*/
,'Z8520'  /*Personal history of malignant neoplasm of unspecified respiratory organ*/
,'Z8521'  /*Personal history of malignant neoplasm of larynx*/
,'Z8522'  /*Personal history of malignant neoplasm of nasal cavities, middle ear, and accessory sinuses*/
,'Z85230'  /*Personal history of malignant carcinoid tumor of thymus*/
,'Z85238'  /*Personal history of other malignant neoplasm of thymus*/
,'Z8529'  /*Personal history of malignant neoplasm of other respiratory and intrathoracic organs*/
,'Z853'  /*Personal history of malignant neoplasm of breast*/
,'Z8540'  /*Personal history of malignant neoplasm of unspecified female genital organ*/
,'Z8541'  /*Personal history of malignant neoplasm of cervix uteri*/
,'Z8542'  /*Personal history of malignant neoplasm of other parts of uterus*/
,'Z8543'  /*Personal history of malignant neoplasm of ovary*/
,'Z8544'  /*Personal history of malignant neoplasm of other female genital organs*/
,'Z8545'  /*Personal history of malignant neoplasm of unspecified male genital organ*/
,'Z8546'  /*Personal history of malignant neoplasm of prostate*/
,'Z8547'  /*Personal history of malignant neoplasm of testis*/
,'Z8548'  /*Personal history of malignant neoplasm of epididymis*/
,'Z8549'  /*Personal history of malignant neoplasm of other male genital organs*/
,'Z8550'  /*Personal history of malignant neoplasm of unspecified urinary tract organ*/
,'Z8551'  /*Personal history of malignant neoplasm of bladder*/
,'Z85520'  /*Personal history of malignant carcinoid tumor of kidney*/
,'Z85528'  /*Personal history of other malignant neoplasm of kidney*/
,'Z8553'  /*Personal history of malignant neoplasm of renal pelvis*/
,'Z8554'  /*Personal history of malignant neoplasm of ureter*/
,'Z8559'  /*Personal history of malignant neoplasm of other urinary tract organ*/
,'Z856'  /*Personal history of leukemia*/
,'Z8571'  /*Personal history of Hodgkin lymphoma*/
,'Z8572'  /*Personal history of non-Hodgkin lymphomas*/
,'Z8579'  /*Personal history of other malignant neoplasms of lymphoid, hematopoietic and related tissues*/
,'Z85810'  /*Personal history of malignant neoplasm of tongue*/
,'Z85818'  /*Personal history of malignant neoplasm of other sites of lip, oral cavity, and pharynx*/
,'Z85819'  /*Personal history of malignant neoplasm of unspecified site of lip, oral cavity, and pharynx*/
,'Z85820'  /*Personal history of malignant melanoma of skin*/
,'Z85821'  /*Personal history of Merkel cell carcinoma*/
,'Z85828'  /*Personal history of other malignant neoplasm of skin*/
,'Z85830'  /*Personal history of malignant neoplasm of bone*/
,'Z85831'  /*Personal history of malignant neoplasm of soft tissue*/
,'Z85840'  /*Personal history of malignant neoplasm of eye*/
,'Z85841'  /*Personal history of malignant neoplasm of brain*/
,'Z85848'  /*Personal history of malignant neoplasm of other parts of nervous tissue*/
,'Z85850'  /*Personal history of malignant neoplasm of thyroid*/
,'Z85858'  /*Personal history of malignant neoplasm of other endocrine glands*/
,'Z8589'  /*Personal history of malignant neoplasm of other organs and systems*/
,'Z859'  /*Personal history of malignant neoplasm, unspecified*/
,'Z86000'  /*Personal history of in-situ neoplasm of breast*/
,'Z86001'  /*Personal history of in-situ neoplasm of cervix uteri*/
,'Z86008'  /*Personal history of in-situ neoplasm of other site*/
,'Z86010'  /*Personal history of colonic polyps*/
,'Z86011'  /*Personal history of benign neoplasm of the brain*/
,'Z86012'  /*Personal history of benign carcinoid tumor*/
,'Z86018'  /*Personal history of other benign neoplasm*/
,'Z8603'  /*Personal history of neoplasm of uncertain behavior*/
,'Z8611'  /*Personal history of tuberculosis*/
,'Z8612'  /*Personal history of poliomyelitis*/
,'Z8613'  /*Personal history of malaria*/
,'Z8614'  /*Personal history of Methicillin resistant Staphylococcus aureus infection*/
,'Z8619'  /*Personal history of other infectious and parasitic diseases*/
,'Z862'  /*Personal history of diseases of the blood and blood-forming organs and certain disorders involving the immune mechanism*/
,'Z8631'  /*Personal history of diabetic foot ulcer*/
,'Z8632'  /*Personal history of gestational diabetes*/
,'Z8639'  /*Personal history of other endocrine, nutritional and metabolic disease*/
,'Z8651'  /*Personal history of combat and operational stress reaction*/
,'Z8659'  /*Personal history of other mental and behavioral disorders*/
,'Z8661'  /*Personal history of infections of the central nervous system*/
,'Z8669'  /*Personal history of other diseases of the nervous system and sense organs*/
,'Z86711'  /*Personal history of pulmonary embolism*/
,'Z86718'  /*Personal history of other venous thrombosis and embolism*/
,'Z8672'  /*Personal history of thrombophlebitis*/
,'Z8673'  /*Personal history of transient ischemic attack (TIA), and cerebral infarction without residual deficits*/
,'Z8674'  /*Personal history of sudden cardiac arrest*/
,'Z8679'  /*Personal history of other diseases of the circulatory system*/
,'Z8701'  /*Personal history of pneumonia (recurrent)*/
,'Z8709'  /*Personal history of other diseases of the respiratory system*/
,'Z8711'  /*Personal history of peptic ulcer disease*/
,'Z8719'  /*Personal history of other diseases of the digestive system*/
,'Z872'  /*Personal history of diseases of the skin and subcutaneous tissue*/
,'Z87310'  /*Personal history of (healed) osteoporosis fracture*/
,'Z87311'  /*Personal history of (healed) other pathological fracture*/
,'Z87312'  /*Personal history of (healed) stress fracture*/
,'Z8739'  /*Personal history of other diseases of the musculoskeletal system and connective tissue*/
,'Z87410'  /*Personal history of cervical dysplasia*/
,'Z87411'  /*Personal history of vaginal dysplasia*/
,'Z87412'  /*Personal history of vulvar dysplasia*/
,'Z8742'  /*Personal history of other diseases of the female genital tract*/
,'Z87430'  /*Personal history of prostatic dysplasia*/
,'Z87438'  /*Personal history of other diseases of male genital organs*/
,'Z87440'  /*Personal history of urinary (tract) infections*/
,'Z87441'  /*Personal history of nephrotic syndrome*/
,'Z87442'  /*Personal history of urinary calculi*/
,'Z87448'  /*Personal history of other diseases of urinary system*/
,'Z8751'  /*Personal history of pre-term labor*/
,'Z8759'  /*Personal history of other complications of pregnancy, childbirth and the puerperium*/
,'Z87710'  /*Personal history of (corrected) hypospadias*/
,'Z87718'  /*Personal history of other specified (corrected) congenital malformations of genitourinary system*/
,'Z87720'  /*Personal history of (corrected) congenital malformations of eye*/
,'Z87721'  /*Personal history of (corrected) congenital malformations of ear*/
,'Z87728'  /*Personal history of other specified (corrected) congenital malformations of nervous system and sense organs*/
,'Z87730'  /*Personal history of (corrected) cleft lip and palate*/
,'Z87738'  /*Personal history of other specified (corrected) congenital malformations of digestive system*/
,'Z8774'  /*Personal history of (corrected) congenital malformations of heart and circulatory system*/
,'Z8775'  /*Personal history of (corrected) congenital malformations of respiratory system*/
,'Z8776'  /*Personal history of (corrected) congenital malformations of integument, limbs and musculoskeletal system*/
,'Z87790'  /*Personal history of (corrected) congenital malformations of face and neck*/
,'Z87798'  /*Personal history of other (corrected) congenital malformations*/
,'Z8781'  /*Personal history of (healed) traumatic fracture*/
,'Z87820'  /*Personal history of traumatic brain injury*/
,'Z87821'  /*Personal history of retained foreign body fully removed*/
,'Z87828'  /*Personal history of other (healed) physical injury and trauma*/
,'Z87890'  /*Personal history of sex reassignment*/
,'Z87891'  /*Personal history of nicotine dependence*/
,'Z87892'  /*Personal history of anaphylaxis*/
,'Z87898'  /*Personal history of other specified conditions*/
,'Z880'  /*Allergy status to penicillin*/
,'Z881'  /*Allergy status to other antibiotic agents status*/
,'Z882'  /*Allergy status to sulfonamides status*/
,'Z883'  /*Allergy status to other anti-infective agents status*/
,'Z884'  /*Allergy status to anesthetic agent status*/
,'Z885'  /*Allergy status to narcotic agent status*/
,'Z886'  /*Allergy status to analgesic agent status*/
,'Z887'  /*Allergy status to serum and vaccine status*/
,'Z888'  /*Allergy status to other drugs, medicaments and biological substances status*/
,'Z889'  /*Allergy status to unspecified drugs, medicaments and biological substances status*/
,'Z89011'  /*Acquired absence of right thumb*/
,'Z89012'  /*Acquired absence of left thumb*/
,'Z89019'  /*Acquired absence of unspecified thumb*/
,'Z89021'  /*Acquired absence of right finger(s)*/
,'Z89022'  /*Acquired absence of left finger(s)*/
,'Z89029'  /*Acquired absence of unspecified finger(s)*/
,'Z89111'  /*Acquired absence of right hand*/
,'Z89112'  /*Acquired absence of left hand*/
,'Z89119'  /*Acquired absence of unspecified hand*/
,'Z89121'  /*Acquired absence of right wrist*/
,'Z89122'  /*Acquired absence of left wrist*/
,'Z89129'  /*Acquired absence of unspecified wrist*/
,'Z89201'  /*Acquired absence of right upper limb, unspecified level*/
,'Z89202'  /*Acquired absence of left upper limb, unspecified level*/
,'Z89209'  /*Acquired absence of unspecified upper limb, unspecified level*/
,'Z89211'  /*Acquired absence of right upper limb below elbow*/
,'Z89212'  /*Acquired absence of left upper limb below elbow*/
,'Z89219'  /*Acquired absence of unspecified upper limb below elbow*/
,'Z89221'  /*Acquired absence of right upper limb above elbow*/
,'Z89222'  /*Acquired absence of left upper limb above elbow*/
,'Z89229'  /*Acquired absence of unspecified upper limb above elbow*/
,'Z89231'  /*Acquired absence of right shoulder*/
,'Z89232'  /*Acquired absence of left shoulder*/
,'Z89239'  /*Acquired absence of unspecified shoulder*/
,'Z89411'  /*Acquired absence of right great toe*/
,'Z89412'  /*Acquired absence of left great toe*/
,'Z89419'  /*Acquired absence of unspecified great toe*/
,'Z89421'  /*Acquired absence of other right toe(s)*/
,'Z89422'  /*Acquired absence of other left toe(s)*/
,'Z89429'  /*Acquired absence of other toe(s), unspecified side*/
,'Z89431'  /*Acquired absence of right foot*/
,'Z89432'  /*Acquired absence of left foot*/
,'Z89439'  /*Acquired absence of unspecified foot*/
,'Z89441'  /*Acquired absence of right ankle*/
,'Z89442'  /*Acquired absence of left ankle*/
,'Z89449'  /*Acquired absence of unspecified ankle*/
,'Z89511'  /*Acquired absence of right leg below knee*/
,'Z89512'  /*Acquired absence of left leg below knee*/
,'Z89519'  /*Acquired absence of unspecified leg below knee*/
,'Z89521'  /*Acquired absence of right knee*/
,'Z89522'  /*Acquired absence of left knee*/
,'Z89529'  /*Acquired absence of unspecified knee*/
,'Z89611'  /*Acquired absence of right leg above knee*/
,'Z89612'  /*Acquired absence of left leg above knee*/
,'Z89619'  /*Acquired absence of unspecified leg above knee*/
,'Z89621'  /*Acquired absence of right hip joint*/
,'Z89622'  /*Acquired absence of left hip joint*/
,'Z89629'  /*Acquired absence of unspecified hip joint*/
,'Z899'  /*Acquired absence of limb, unspecified*/
,'Z9001'  /*Acquired absence of eye*/
,'Z9002'  /*Acquired absence of larynx*/
,'Z9009'  /*Acquired absence of other part of head and neck*/
,'Z9010'  /*Acquired absence of unspecified breast and nipple*/
,'Z9011'  /*Acquired absence of right breast and nipple*/
,'Z9012'  /*Acquired absence of left breast and nipple*/
,'Z9013'  /*Acquired absence of bilateral breasts and nipples*/
,'Z902'  /*Acquired absence of lung [part of]*/
,'Z903'  /*Acquired absence of stomach [part of]*/
,'Z90410'  /*Acquired total absence of pancreas*/
,'Z90411'  /*Acquired partial absence of pancreas*/
,'Z9049'  /*Acquired absence of other specified parts of digestive tract*/
,'Z905'  /*Acquired absence of kidney*/
,'Z906'  /*Acquired absence of other parts of urinary tract*/
,'Z90710'  /*Acquired absence of both cervix and uterus*/
,'Z90711'  /*Acquired absence of uterus with remaining cervical stump*/
,'Z90712'  /*Acquired absence of cervix with remaining uterus*/
,'Z90721'  /*Acquired absence of ovaries, unilateral*/
,'Z90722'  /*Acquired absence of ovaries, bilateral*/
,'Z9079'  /*Acquired absence of other genital organ(s)*/
,'Z9081'  /*Acquired absence of spleen*/
,'Z9089'  /*Acquired absence of other organs*/
,'Z91010'  /*Allergy to peanuts*/
,'Z91011'  /*Allergy to milk products*/
,'Z91012'  /*Allergy to eggs*/
,'Z91013'  /*Allergy to seafood*/
,'Z91018'  /*Allergy to other foods*/
,'Z9102'  /*Food additives allergy status*/
,'Z91030'  /*Bee allergy status*/
,'Z91038'  /*Other insect allergy status*/
,'Z91040'  /*Latex allergy status*/
,'Z91041'  /*Radiographic dye allergy status*/
,'Z91048'  /*Other nonmedicinal substance allergy status*/
,'Z9109'  /*Other allergy status, other than to drugs and biological substances*/
,'Z9111'  /*Patient's noncompliance with dietary regimen*/
,'Z91120'  /*Patient's intentional underdosing of medication regimen due to financial hardship*/
,'Z91128'  /*Patient's intentional underdosing of medication regimen for other reason*/
,'Z91130'  /*Patient's unintentional underdosing of medication regimen due to age-related debility*/
,'Z91138'  /*Patient's unintentional underdosing of medication regimen for other reason*/
,'Z9114'  /*Patient's other noncompliance with medication regimen*/
,'Z9115'  /*Patient's noncompliance with renal dialysis*/
,'Z9119'  /*Patient's noncompliance with other medical treatment and regimen*/
,'Z91410'  /*Personal history of adult physical and sexual abuse*/
,'Z91411'  /*Personal history of adult psychological abuse*/
,'Z91412'  /*Personal history of adult neglect*/
,'Z91419'  /*Personal history of unspecified adult abuse*/
,'Z9149'  /*Other personal history of psychological trauma, not elsewhere classified*/
,'Z915'  /*Personal history of self-harm*/
,'Z9181'  /*History of falling*/
,'Z9182'  /*Personal history of military deployment*/
,'Z9183'  /*Wandering in diseases classified elsewhere*/
,'Z9189'  /*Other specified personal risk factors, not elsewhere classified*/
,'Z920'  /*Personal history of contraception*/
,'Z9221'  /*Personal history of antineoplastic chemotherapy*/
,'Z9222'  /*Personal history of monoclonal drug therapy*/
,'Z9223'  /*Personal history of estrogen therapy*/
,'Z92240'  /*Personal history of inhaled steroid therapy*/
,'Z92241'  /*Personal history of systemic steroid therapy*/
,'Z9225'  /*Personal history of immunosupression therapy*/
,'Z9229'  /*Personal history of other drug therapy*/
,'Z923'  /*Personal history of irradiation*/
,'Z9281'  /*Personal history of extracorporeal membrane oxygenation (ECMO)*/
,'Z9282'  /*Status post administration of tPA (rtPA) in a different facility within the last 24 hours prior to admission to current facility*/
,'Z9283'  /*Personal history of failed moderate sedation*/
,'Z9284'  /*Personal history of unintended awareness under general anesthesia*/
,'Z9289'  /*Personal history of other medical treatment*/
,'Z930'  /*Tracheostomy status*/
,'Z931'  /*Gastrostomy status*/
,'Z932'  /*Ileostomy status*/
,'Z933'  /*Colostomy status*/
,'Z934'  /*Other artificial openings of gastrointestinal tract status*/
,'Z9350'  /*Unspecified cystostomy status*/
,'Z9351'  /*Cutaneous-vesicostomy status*/
,'Z9352'  /*Appendico-vesicostomy status*/
,'Z9359'  /*Other cystostomy status*/
,'Z936'  /*Other artificial openings of urinary tract status*/
,'Z938'  /*Other artificial opening status*/
,'Z939'  /*Artificial opening status, unspecified*/
,'Z940'  /*Kidney transplant status*/
,'Z941'  /*Heart transplant status*/
,'Z942'  /*Lung transplant status*/
,'Z943'  /*Heart and lungs transplant status*/
,'Z944'  /*Liver transplant status*/
,'Z945'  /*Skin transplant status*/
,'Z946'  /*Bone transplant status*/
,'Z947'  /*Corneal transplant status*/
,'Z9481'  /*Bone marrow transplant status*/
,'Z9482'  /*Intestine transplant status*/
,'Z9483'  /*Pancreas transplant status*/
,'Z9484'  /*Stem cells transplant status*/
,'Z9489'  /*Other transplanted organ and tissue status*/
,'Z949'  /*Transplanted organ and tissue status, unspecified*/
,'Z950'  /*Presence of cardiac pacemaker*/
,'Z951'  /*Presence of aortocoronary bypass graft*/
,'Z952'  /*Presence of prosthetic heart valve*/
,'Z953'  /*Presence of xenogenic heart valve*/
,'Z954'  /*Presence of other heart-valve replacement*/
,'Z955'  /*Presence of coronary angioplasty implant and graft*/
,'Z95810'  /*Presence of automatic (implantable) cardiac defibrillator*/
,'Z95811'  /*Presence of heart assist device*/
,'Z95812'  /*Presence of fully implantable artificial heart*/
,'Z95818'  /*Presence of other cardiac implants and grafts*/
,'Z95820'  /*Peripheral vascular angioplasty status with implants and grafts*/
,'Z95828'  /*Presence of other vascular implants and grafts*/
,'Z959'  /*Presence of cardiac and vascular implant and graft, unspecified*/
,'Z970'  /*Presence of artificial eye*/
,'Z9710'  /*Presence of artificial limb (complete) (partial), unspecified*/
,'Z9711'  /*Presence of artificial right arm (complete) (partial)*/
,'Z9712'  /*Presence of artificial left arm (complete) (partial)*/
,'Z9713'  /*Presence of artificial right leg (complete) (partial)*/
,'Z9714'  /*Presence of artificial left leg (complete) (partial)*/
,'Z9715'  /*Presence of artificial arms, bilateral (complete) (partial)*/
,'Z9716'  /*Presence of artificial legs, bilateral (complete) (partial)*/
,'Z972'  /*Presence of dental prosthetic device (complete) (partial)*/
,'Z973'  /*Presence of spectacles and contact lenses*/
,'Z974'  /*Presence of external hearing-aid*/
,'Z975'  /*Presence of (intrauterine) contraceptive device*/
,'Z978'  /*Presence of other specified devices*/
,'Z980'  /*Intestinal bypass and anastomosis status*/
,'Z981'  /*Arthrodesis status*/
,'Z982'  /*Presence of cerebrospinal fluid drainage device*/
,'Z983'  /*Post therapeutic collapse of lung status*/
,'Z9841'  /*Cataract extraction status, right eye*/
,'Z9842'  /*Cataract extraction status, left eye*/
,'Z9849'  /*Cataract extraction status, unspecified eye*/
,'Z9851'  /*Tubal ligation status*/
,'Z9852'  /*Vasectomy status*/
,'Z9861'  /*Coronary angioplasty status*/
,'Z9862'  /*Peripheral vascular angioplasty status*/
,'Z98810'  /*Dental sealant status*/
,'Z98811'  /*Dental restoration status*/
,'Z98818'  /*Other dental procedure status*/
,'Z9882'  /*Breast implant status*/
,'Z9883'  /*Filtering (vitreous) bleb after glaucoma surgery status*/
,'Z9884'  /*Bariatric surgery status*/
,'Z9885'  /*Transplanted organ removal status*/
,'Z9886'  /*Personal history of breast implant removal*/
,'Z98870'  /*Personal history of in utero procedure during pregnancy*/
,'Z98871'  /*Personal history of in utero procedure while a fetus*/
,'Z98890'  /*Other specified postprocedural states*/
,'Z98891'  /*History of uterine scar from previous surgery*/
,'Z990'  /*Dependence on aspirator*/
,'Z9911'  /*Dependence on respirator [ventilator] status*/
,'Z9912'  /*Encounter for respirator [ventilator] dependence during power failure*/
,'Z992'  /*Dependence on renal dialysis*/
,'Z993'  /*Dependence on wheelchair*/
,'Z9981'  /*Dependence on supplemental oxygen*/
,'Z9989' = '1' /*Dependence on other enabling machines and devices*/
OTHER='0'
;

/* Diagnosis codeset ABWALLCD last updated 160922 for IDC10 v60rev3 */
Value $ABWALLCD
"T8132XA" = "1" /* Disruption of internal operation (surgical) wound */
Other = "0"
;

/* Diagnosis codeset ACBACGD last updated 160922 for IDC10 v60rev3 */
Value $ACBACGD
"A020" = "1" /* Salmonella enteritis */
"A030" = "1" /* Shigellosis due to Shigella dysenteriae */
"A031" = "1" /* Shigellosis due to Shigella flexneri */
"A032" = "1" /* Shigellosis due to Shigella boydii */
"A033" = "1" /* Shigellosis due to Shigella sonnei */
"A038" = "1" /* Other shigellosis */
"A039" = "1" /* Shigellosis, unspecified */
"A040" = "1" /* Enteropathogenic Escherichia coli infection */
"A041" = "1" /* Enterotoxigenic Escherichia coli infection */
"A042" = "1" /* Enteroinvasive Escherichia coli infection */
"A043" = "1" /* Enterohemorrhagic Escherichia coli infection */
"A044" = "1" /* Other intestinal Escherichia coli infections */
"A045" = "1" /* Campylobacter enteritis */
"A046" = "1" /* Enteritis due to Yersinia enterocolitica */
"A047" = "1" /* Enterocolitis due to Clostridium difficile */
"A048" = "1" /* Other specified bacterial intestinal infections */
"A049" = "1" /* Bacterial intestinal infection, unspecified */
"A050" = "1" /* Foodborne staphylococcal intoxication */
"A051" = "1" /* Botulism food poisoning */
"A052" = "1" /* Foodborne Clostridium perfringens [Clostridium welchii] intoxication */
"A053" = "1" /* Foodborne Vibrio parahaemolyticus intoxication */
"A054" = "1" /* Foodborne Bacillus cereus intoxication */
"A055" = "1" /* Foodborne Vibrio vulnificus intoxication */
"A058" = "1" /* Other specified bacterial foodborne intoxications */
"A059" = "1" /* Bacterial foodborne intoxication, unspecified */
"A060" = "1" /* Acute amebic dysentery */
"A061" = "1" /* Chronic intestinal amebiasis */
"A070" = "1" /* Balantidiasis */
"A071" = "1" /* Giardiasis [lambliasis] */
"A072" = "1" /* Cryptosporidiosis */
"A073" = "1" /* Isosporiasis */
"A074" = "1" /* Cyclosporiasis */
"A078" = "1" /* Other specified protozoal intestinal diseases */
"A079" = "1" /* Protozoal intestinal disease, unspecified */
"B3782" = "1" /* Candidal enteritis */
Other = "0"
;

/* Diagnosis codeset ACSAP2D last updated 160922 for IDC10 v60rev3 */
Value $ACSAP2D
"K352" = "1" /* Acute appendicitis with generalized peritonitis */
"K353" = "1" /* Acute appendicitis with localized peritonitis */
"K3580" = "1" /* Unspecified acute appendicitis */
"K3589" = "1" /* Other acute appendicitis */
"K37" = "1" /* Unspecified appendicitis */
Other = "0"
;

/* Diagnosis codeset ACSAPPD last updated 160922 for IDC10 v60rev3 */
Value $ACSAPPD
"K352" = "1" /* Acute appendicitis with generalized peritonitis */
"K353" = "1" /* Acute appendicitis with localized peritonitis */
Other = "0"
;

/* Diagnosis codeset ACSASTD last updated 160922 for IDC10 v60rev3 */
Value $ACSASTD
"J4521" = "1" /* Mild intermittent asthma with (acute) exacerbation */
"J4522" = "1" /* Mild intermittent asthma with status asthmaticus */
"J4531" = "1" /* Mild persistent asthma with (acute) exacerbation */
"J4532" = "1" /* Mild persistent asthma with status asthmaticus */
"J4541" = "1" /* Moderate persistent asthma with (acute) exacerbation */
"J4542" = "1" /* Moderate persistent asthma with status asthmaticus */
"J4551" = "1" /* Severe persistent asthma with (acute) exacerbation */
"J4552" = "1" /* Severe persistent asthma with status asthmaticus */
"J45901" = "1" /* Unspecified asthma with (acute) exacerbation */
"J45902" = "1" /* Unspecified asthma with status asthmaticus */
"J45990" = "1" /* Exercise induced bronchospasm */
"J45991" = "1" /* Cough variant asthma */
"J45998" = "1" /* Other asthma */
Other = "0"
;

/* Diagnosis codeset ACSCYFD last updated 160922 for IDC10 v60rev3 */
Value $ACSCYFD
"E840" = "1" /* Cystic fibrosis with pulmonary manifestations */
"E8411" = "1" /* Meconium ileus in cystic fibrosis */
"E8419" = "1" /* Cystic fibrosis with other intestinal manifestations */
"E848" = "1" /* Cystic fibrosis with other manifestations */
"E849" = "1" /* Cystic fibrosis, unspecified */
Other = "0"
;

/* Diagnosis codeset ACSDEHD last updated 160922 for IDC10 v60rev3 */
Value $ACSDEHD
"E860" = "1" /* Dehydration */
"E861" = "1" /* Hypovolemia */
"E869" = "1" /* Volume depletion, unspecified */
Other = "0"
;

/* Diagnosis codeset ACSLBWD last updated 160922 for IDC10 v60rev3 */
Value $ACSLBWD
"P0501" = "1" /* Newborn light for gestational age, less than 500 grams */
"P0502" = "1" /* Newborn light for gestational age, 500-749 grams */
"P0503" = "1" /* Newborn light for gestational age, 750-999 grams */
"P0504" = "1" /* Newborn light for gestational age, 1000-1249 grams */
"P0505" = "1" /* Newborn light for gestational age, 1250-1499 grams */
"P0506" = "1" /* Newborn light for gestational age, 1500-1749 grams */
"P0507" = "1" /* Newborn light for gestational age, 1750-1999 grams */
"P0508" = "1" /* Newborn light for gestational age, 2000-2499 grams */
"P0511" = "1" /* Newborn small for gestational age, less than 500 grams */
"P0512" = "1" /* Newborn small for gestational age, 500-749 grams */
"P0513" = "1" /* Newborn small for gestational age, 750-999 grams */
"P0514" = "1" /* Newborn small for gestational age, 1000-1249 grams */
"P0515" = "1" /* Newborn small for gestational age, 1250-1499 grams */
"P0516" = "1" /* Newborn small for gestational age, 1500-1749 grams */
"P0517" = "1" /* Newborn small for gestational age, 1750-1999 grams */
"P0518" = "1" /* Newborn small for gestational age, 2000-2499 grams */
"P0700" = "1" /* Extremely low birth weight newborn, unspecified weight */
"P0701" = "1" /* Extremely low birth weight newborn, less than 500 grams */
"P0702" = "1" /* Extremely low birth weight newborn, 500-749 grams */
"P0703" = "1" /* Extremely low birth weight newborn, 750-999 grams */
"P0710" = "1" /* Other low birth weight newborn, unspecified weight */
"P0714" = "1" /* Other low birth weight newborn, 1000-1249 grams */
"P0715" = "1" /* Other low birth weight newborn, 1250-1499 grams */
"P0716" = "1" /* Other low birth weight newborn, 1500-1749 grams */
"P0717" = "1" /* Other low birth weight newborn, 1750-1999 grams */
"P0718" = "1" /* Other low birth weight newborn, 2000-2499 grams */
Other = "0"
;

/* Diagnosis codeset ACURF2D last updated 160922 for IDC10 v60rev3 */
Value $ACURF2D
"J95821" = "1" /* Acute postprocedural respiratory failure */
"J95822" = "1" /* Acute and chronic postprocedural respiratory failure */
Other = "0"
;

/* Diagnosis codeset ACURF3D last updated 160922 for IDC10 v60rev3 */
Value $ACURF3D
"J95821" = "1" /* Acute postprocedural respiratory failure */
"J95822" = "1" /* Acute and chronic postprocedural respiratory failure */
"J9600" = "1" /* Acute respiratory failure, unspecified whether with hypoxia or hypercapnia */
"J9601" = "1" /* Acute respiratory failure with hypoxia */
"J9602" = "1" /* Acute respiratory failure with hypercapnia */
"J9610" = "1" /* Chronic respiratory failure, unspecified whether with hypoxia or hypercapnia */
"J9611" = "1" /* Chronic respiratory failure with hypoxia */
"J9612" = "1" /* Chronic respiratory failure with hypercapnia */
"J9620" = "1" /* Acute and chronic respiratory failure, unspecified whether with hypoxia or hypercapnia */
"J9621" = "1" /* Acute and chronic respiratory failure with hypoxia */
"J9622" = "1" /* Acute and chronic respiratory failure with hypercapnia */
"J9690" = "1" /* Respiratory failure, unspecified, unspecified whether with hypoxia or hypercapnia */
"J9691" = "1" /* Respiratory failure, unspecified with hypoxia */
"J9692" = "1" /* Respiratory failure, unspecified with hypercapnia */
Other = "0"
;

/* Diagnosis codeset ANOXBD last updated 160922 for IDC10 v60rev3 */
Value $ANOXBD
"G931" = "1" /* Anoxic brain damage, not elsewhere classified */
Other = "0"
;

/* Diagnosis codeset BIRTHID last updated 160922 for IDC10 v60rev3 */
Value $BIRTHID
"P100" = "1" /* Subdural hemorrhage due to birth injury */
"P101" = "1" /* Cerebral hemorrhage due to birth injury */
"P102" = "1" /* Intraventricular hemorrhage due to birth injury */
"P103" = "1" /* Subarachnoid hemorrhage due to birth injury */
"P104" = "1" /* Tentorial tear due to birth injury */
"P108" = "1" /* Other intracranial lacerations and hemorrhages due to birth injury */
"P109" = "1" /* Unspecified intracranial laceration and hemorrhage due to birth injury */
"P110" = "1" /* Cerebral edema due to birth injury */
"P111" = "1" /* Other specified brain damage due to birth injury */
"P112" = "1" /* Unspecified brain damage due to birth injury */
"P113" = "1" /* Birth injury to facial nerve */
"P114" = "1" /* Birth injury to other cranial nerves */
"P115" = "1" /* Birth injury to spine and spinal cord */
"P119" = "1" /* Birth injury to central nervous system, unspecified */
"P122" = "1" /* Epicranial subaponeurotic hemorrhage due to birth injury */
"P130" = "1" /* Fracture of skull due to birth injury */
"P131" = "1" /* Other birth injuries to skull */
"P132" = "1" /* Birth injury to femur */
"P133" = "1" /* Birth injury to other long bones */
"P138" = "1" /* Birth injuries to other parts of skeleton */
"P139" = "1" /* Birth injury to skeleton, unspecified */
"P142" = "1" /* Phrenic nerve paralysis due to birth injury */
"P148" = "1" /* Birth injuries to other parts of peripheral nervous system */
"P149" = "1" /* Birth injury to peripheral nervous system, unspecified */
"P150" = "1" /* Birth injury to liver */
"P151" = "1" /* Birth injury to spleen */
"P152" = "1" /* Sternomastoid injury due to birth injury */
"P153" = "1" /* Birth injury to eye */
"P154" = "1" /* Birth injury to face */
"P155" = "1" /* Birth injury to external genitalia */
"P156" = "1" /* Subcutaneous fat necrosis due to birth injury */
"P158" = "1" /* Other specified birth injuries */
Other = "0"
;

/* Diagnosis codeset BSI3DX last updated 160922 for IDC10 v60rev3 */
Value $BSI3DX
"B961" = "1" /* Klebsiella pneumoniae [K. pneumoniae] as the cause of diseases classified elsewhere */
"B9620" = "1" /* Unspecified Escherichia coli [E. coli] as the cause of diseases classified elsewhere */
"B9621" = "1" /* Shiga toxin-producing Escherichia coli [E. coli] (STEC) O157 as the cause of diseases classified elsewhere */
"B9622" = "1" /* Other specified Shiga toxin-producing Escherichia coli [E. coli] (STEC) as the cause of diseases classified elsewhere */
"B9623" = "1" /* Unspecified Shiga toxin-producing Escherichia coli [E. coli] (STEC) as the cause of diseases classified elsewhere */
"B9629" = "1" /* Other Escherichia coli [E. coli] as the cause of diseases classified elsewhere */
"B965" = "1" /* Pseudomonas (aeruginosa) (mallei) (pseudomallei) as the cause of diseases classified elsewhere */
"B9689" = "1" /* Other specified bacterial agents as the cause of diseases classified elsewhere */
Other = "0"
;

/* Diagnosis codeset BSI4DX last updated 160922 for IDC10 v60rev3 */
Value $BSI4DX
"A021" = "1" /* Salmonella sepsis */
"A227" = "1" /* Anthrax sepsis */
"A267" = "1" /* Erysipelothrix sepsis */
"A327" = "1" /* Listerial sepsis */
"A400" = "1" /* Sepsis due to streptococcus, group A */
"A401" = "1" /* Sepsis due to streptococcus, group B */
"A403" = "1" /* Sepsis due to Streptococcus pneumoniae */
"A408" = "1" /* Other streptococcal sepsis */
"A409" = "1" /* Streptococcal sepsis, unspecified */
"A4101" = "1" /* Sepsis due to Methicillin susceptible Staphylococcus aureus */
"A4102" = "1" /* Sepsis due to Methicillin resistant Staphylococcus aureus */
"A411" = "1" /* Sepsis due to other specified staphylococcus */
"A412" = "1" /* Sepsis due to unspecified staphylococcus */
"A413" = "1" /* Sepsis due to Hemophilus influenzae */
"A414" = "1" /* Sepsis due to anaerobes */
"A4150" = "1" /* Gram-negative sepsis, unspecified */
"A4151" = "1" /* Sepsis due to Escherichia coli [E. coli] */
"A4152" = "1" /* Sepsis due to Pseudomonas */
"A4153" = "1" /* Sepsis due to Serratia */
"A4159" = "1" /* Other Gram-negative sepsis */
"A4181" = "1" /* Sepsis due to Enterococcus */
"A4189" = "1" /* Other specified sepsis */
"A419" = "1" /* Sepsis, unspecified organism */
"A427" = "1" /* Actinomycotic sepsis */
"A5486" = "1" /* Gonococcal sepsis */
"B377" = "1" /* Candidal sepsis */
"P360" = "1" /* Sepsis of newborn due to streptococcus, group B */
"P3610" = "1" /* Sepsis of newborn due to unspecified streptococci */
"P3619" = "1" /* Sepsis of newborn due to other streptococci */
"P362" = "1" /* Sepsis of newborn due to Staphylococcus aureus */
"P3630" = "1" /* Sepsis of newborn due to unspecified staphylococci */
"P3639" = "1" /* Sepsis of newborn due to other staphylococci */
"P364" = "1" /* Sepsis of newborn due to Escherichia coli */
"P365" = "1" /* Sepsis of newborn due to anaerobes */
"P368" = "1" /* Other bacterial sepsis of newborn */
"P369" = "1" /* Bacterial sepsis of newborn, unspecified */
"R6520" = "1" /* Severe sepsis without septic shock */
"R6521" = "1" /* Severe sepsis with septic shock */
"R7881" = "1" /* Bacteremia */
"T8112XA" = "1" /* Postprocedural septic shock, initial encounter */
Other = "0"
;

/* Procedure codeset CMVENP last updated 160922 for IDC10 v60rev3 */
Value $CMVENP
"5A1955Z" = "1" /* Respiratory Ventilation, Greater than 96 Consecutive Hours */
Other = "0"
;

/* Diagnosis codeset CRANIID last updated 160922 for IDC10 v60rev3 */
Value $CRANIID
"Q184" = "1" /* Macrostomia */
"Q185" = "1" /* Microstomia */
"Q189" = "1" /* Congenital malformation of face and neck, unspecified */
"Q311" = "1" /* Congenital subglottic stenosis */
"Q312" = "1" /* Laryngeal hypoplasia */
"Q313" = "1" /* Laryngocele */
"Q315" = "1" /* Congenital laryngomalacia */
"Q318" = "1" /* Other congenital malformations of larynx */
"Q319" = "1" /* Congenital malformation of larynx, unspecified */
"Q320" = "1" /* Congenital tracheomalacia */
"Q321" = "1" /* Other congenital malformations of trachea */
"Q322" = "1" /* Congenital bronchomalacia */
"Q323" = "1" /* Congenital stenosis of bronchus */
"Q324" = "1" /* Other congenital malformations of bronchus */
"Q750" = "1" /* Craniosynostosis */
"Q751" = "1" /* Craniofacial dysostosis */
"Q752" = "1" /* Hypertelorism */
"Q753" = "1" /* Macrocephaly */
"Q754" = "1" /* Mandibulofacial dysostosis */
"Q755" = "1" /* Oculomandibular dysostosis */
"Q758" = "1" /* Other specified congenital malformations of skull and face bones */
"Q759" = "1" /* Congenital malformation of skull and face bones, unspecified */
"Q870" = "1" /* Congenital malformation syndromes predominantly affecting facial appearance */
Other = "0"
;

/* Diagnosis codeset CTRAUMD last updated 160922 for IDC10 v60rev3 */
Value $CTRAUMD
"S21101A" = "1" /* Unspecified open wound of right front wall of thorax without penetration into thoracic cavity, initial encounter */
"S21102A" = "1" /* Unspecified open wound of left front wall of thorax without penetration into thoracic cavity, initial encounter */
"S21109A" = "1" /* Unspecified open wound of unspecified front wall of thorax without penetration into thoracic cavity, initial encounter */
"S21111A" = "1" /* Laceration without foreign body of right front wall of thorax without penetration into thoracic cavity, initial encounter */
"S21112A" = "1" /* Laceration without foreign body of left front wall of thorax without penetration into thoracic cavity, initial encounter */
"S21119A" = "1" /* Laceration without foreign body of unspecified front wall of thorax without penetration into thoracic cavity, initial encounter */
"S21121A" = "1" /* Laceration with foreign body of right front wall of thorax without penetration into thoracic cavity, initial encounter */
"S21122A" = "1" /* Laceration with foreign body of left front wall of thorax without penetration into thoracic cavity, initial encounter */
"S21129A" = "1" /* Laceration with foreign body of unspecified front wall of thorax without penetration into thoracic cavity, initial encounter */
"S21131A" = "1" /* Puncture wound without foreign body of right front wall of thorax without penetration into thoracic cavity, initial encounter */
"S21132A" = "1" /* Puncture wound without foreign body of left front wall of thorax without penetration into thoracic cavity, initial encounter */
"S21139A" = "1" /* Puncture wound without foreign body of unspecified front wall of thorax without penetration into thoracic cavity, initial encounter */
"S21141A" = "1" /* Puncture wound with foreign body of right front wall of thorax without penetration into thoracic cavity, initial encounter */
"S21142A" = "1" /* Puncture wound with foreign body of left front wall of thorax without penetration into thoracic cavity, initial encounter */
"S21149A" = "1" /* Puncture wound with foreign body of unspecified front wall of thorax without penetration into thoracic cavity, initial encounter */
"S21151A" = "1" /* Open bite of right front wall of thorax without penetration into thoracic cavity, initial encounter */
"S21152A" = "1" /* Open bite of left front wall of thorax without penetration into thoracic cavity, initial encounter */
"S21159A" = "1" /* Open bite of unspecified front wall of thorax without penetration into thoracic cavity, initial encounter */
"S21201A" = "1" /* Unspecified open wound of right back wall of thorax without penetration into thoracic cavity, initial encounter */
"S21202A" = "1" /* Unspecified open wound of left back wall of thorax without penetration into thoracic cavity, initial encounter */
"S21209A" = "1" /* Unspecified open wound of unspecified back wall of thorax without penetration into thoracic cavity, initial encounter */
"S21211A" = "1" /* Laceration without foreign body of right back wall of thorax without penetration into thoracic cavity, initial encounter */
"S21212A" = "1" /* Laceration without foreign body of left back wall of thorax without penetration into thoracic cavity, initial encounter */
"S21219A" = "1" /* Laceration without foreign body of unspecified back wall of thorax without penetration into thoracic cavity, initial encounter */
"S21221A" = "1" /* Laceration with foreign body of right back wall of thorax without penetration into thoracic cavity, initial encounter */
"S21222A" = "1" /* Laceration with foreign body of left back wall of thorax without penetration into thoracic cavity, initial encounter */
"S21229A" = "1" /* Laceration with foreign body of unspecified back wall of thorax without penetration into thoracic cavity, initial encounter */
"S21231A" = "1" /* Puncture wound without foreign body of right back wall of thorax without penetration into thoracic cavity, initial encounter */
"S21232A" = "1" /* Puncture wound without foreign body of left back wall of thorax without penetration into thoracic cavity, initial encounter */
"S21239A" = "1" /* Puncture wound without foreign body of unspecified back wall of thorax without penetration into thoracic cavity, initial encounter */
"S21241A" = "1" /* Puncture wound with foreign body of right back wall of thorax without penetration into thoracic cavity, initial encounter */
"S21242A" = "1" /* Puncture wound with foreign body of left back wall of thorax without penetration into thoracic cavity, initial encounter */
"S21249A" = "1" /* Puncture wound with foreign body of unspecified back wall of thorax without penetration into thoracic cavity, initial encounter */
"S21251A" = "1" /* Open bite of right back wall of thorax without penetration into thoracic cavity, initial encounter */
"S21252A" = "1" /* Open bite of left back wall of thorax without penetration into thoracic cavity, initial encounter */
"S21259A" = "1" /* Open bite of unspecified back wall of thorax without penetration into thoracic cavity, initial encounter */
"S21301A" = "1" /* Unspecified open wound of right front wall of thorax with penetration into thoracic cavity, initial encounter */
"S21302A" = "1" /* Unspecified open wound of left front wall of thorax with penetration into thoracic cavity, initial encounter */
"S21309A" = "1" /* Unspecified open wound of unspecified front wall of thorax with penetration into thoracic cavity, initial encounter */
"S21311A" = "1" /* Laceration without foreign body of right front wall of thorax with penetration into thoracic cavity, initial encounter */
"S21312A" = "1" /* Laceration without foreign body of left front wall of thorax with penetration into thoracic cavity, initial encounter */
"S21319A" = "1" /* Laceration without foreign body of unspecified front wall of thorax with penetration into thoracic cavity, initial encounter */
"S21321A" = "1" /* Laceration with foreign body of right front wall of thorax with penetration into thoracic cavity, initial encounter */
"S21322A" = "1" /* Laceration with foreign body of left front wall of thorax with penetration into thoracic cavity, initial encounter */
"S21329A" = "1" /* Laceration with foreign body of unspecified front wall of thorax with penetration into thoracic cavity, initial encounter */
"S21331A" = "1" /* Puncture wound without foreign body of right front wall of thorax with penetration into thoracic cavity, initial encounter */
"S21332A" = "1" /* Puncture wound without foreign body of left front wall of thorax with penetration into thoracic cavity, initial encounter */
"S21339A" = "1" /* Puncture wound without foreign body of unspecified front wall of thorax with penetration into thoracic cavity, initial encounter */
"S21341A" = "1" /* Puncture wound with foreign body of right front wall of thorax with penetration into thoracic cavity, initial encounter */
"S21342A" = "1" /* Puncture wound with foreign body of left front wall of thorax with penetration into thoracic cavity, initial encounter */
"S21349A" = "1" /* Puncture wound with foreign body of unspecified front wall of thorax with penetration into thoracic cavity, initial encounter */
"S21351A" = "1" /* Open bite of right front wall of thorax with penetration into thoracic cavity, initial encounter */
"S21352A" = "1" /* Open bite of left front wall of thorax with penetration into thoracic cavity, initial encounter */
"S21359A" = "1" /* Open bite of unspecified front wall of thorax with penetration into thoracic cavity, initial encounter */
"S21401A" = "1" /* Unspecified open wound of right back wall of thorax with penetration into thoracic cavity, initial encounter */
"S21402A" = "1" /* Unspecified open wound of left back wall of thorax with penetration into thoracic cavity, initial encounter */
"S21409A" = "1" /* Unspecified open wound of unspecified back wall of thorax with penetration into thoracic cavity, initial encounter */
"S21411A" = "1" /* Laceration without foreign body of right back wall of thorax with penetration into thoracic cavity, initial encounter */
"S21412A" = "1" /* Laceration without foreign body of left back wall of thorax with penetration into thoracic cavity, initial encounter */
"S21419A" = "1" /* Laceration without foreign body of unspecified back wall of thorax with penetration into thoracic cavity, initial encounter */
"S21421A" = "1" /* Laceration with foreign body of right back wall of thorax with penetration into thoracic cavity, initial encounter */
"S21422A" = "1" /* Laceration with foreign body of left back wall of thorax with penetration into thoracic cavity, initial encounter */
"S21429A" = "1" /* Laceration with foreign body of unspecified back wall of thorax with penetration into thoracic cavity, initial encounter */
"S21431A" = "1" /* Puncture wound without foreign body of right back wall of thorax with penetration into thoracic cavity, initial encounter */
"S21432A" = "1" /* Puncture wound without foreign body of left back wall of thorax with penetration into thoracic cavity, initial encounter */
"S21439A" = "1" /* Puncture wound without foreign body of unspecified back wall of thorax with penetration into thoracic cavity, initial encounter */
"S21441A" = "1" /* Puncture wound with foreign body of right back wall of thorax with penetration into thoracic cavity, initial encounter */
"S21442A" = "1" /* Puncture wound with foreign body of left back wall of thorax with penetration into thoracic cavity, initial encounter */
"S21449A" = "1" /* Puncture wound with foreign body of unspecified back wall of thorax with penetration into thoracic cavity, initial encounter */
"S21451A" = "1" /* Open bite of right back wall of thorax with penetration into thoracic cavity, initial encounter */
"S21452A" = "1" /* Open bite of left back wall of thorax with penetration into thoracic cavity, initial encounter */
"S21459A" = "1" /* Open bite of unspecified back wall of thorax with penetration into thoracic cavity, initial encounter */
"S2190XA" = "1" /* Unspecified open wound of unspecified part of thorax, initial encounter */
"S2191XA" = "1" /* Laceration without foreign body of unspecified part of thorax, initial encounter */
"S2192XA" = "1" /* Laceration with foreign body of unspecified part of thorax, initial encounter */
"S2193XA" = "1" /* Puncture wound without foreign body of unspecified part of thorax, initial encounter */
"S2194XA" = "1" /* Puncture wound with foreign body of unspecified part of thorax, initial encounter */
"S2195XA" = "1" /* Open bite of unspecified part of thorax, initial encounter */
"S2220XB" = "1" /* Unspecified fracture of sternum, initial encounter for open fracture */
"S2221XB" = "1" /* Fracture of manubrium, initial encounter for open fracture */
"S2222XB" = "1" /* Fracture of body of sternum, initial encounter for open fracture */
"S2223XB" = "1" /* Sternal manubrial dissociation, initial encounter for open fracture */
"S2224XB" = "1" /* Fracture of xiphoid process, initial encounter for open fracture */
"S2231XA" = "1" /* Fracture of one rib, right side, initial encounter for closed fracture */
"S2231XB" = "1" /* Fracture of one rib, right side, initial encounter for open fracture */
"S2232XA" = "1" /* Fracture of one rib, left side, initial encounter for closed fracture */
"S2232XB" = "1" /* Fracture of one rib, left side, initial encounter for open fracture */
"S2239XA" = "1" /* Fracture of one rib, unspecified side, initial encounter for closed fracture */
"S2239XB" = "1" /* Fracture of one rib, unspecified side, initial encounter for open fracture */
"S2241XA" = "1" /* Multiple fractures of ribs, right side, initial encounter for closed fracture */
"S2241XB" = "1" /* Multiple fractures of ribs, right side, initial encounter for open fracture */
"S2242XA" = "1" /* Multiple fractures of ribs, left side, initial encounter for closed fracture */
"S2242XB" = "1" /* Multiple fractures of ribs, left side, initial encounter for open fracture */
"S2243XA" = "1" /* Multiple fractures of ribs, bilateral, initial encounter for closed fracture */
"S2243XB" = "1" /* Multiple fractures of ribs, bilateral, initial encounter for open fracture */
"S2249XA" = "1" /* Multiple fractures of ribs, unspecified side, initial encounter for closed fracture */
"S2249XB" = "1" /* Multiple fractures of ribs, unspecified side, initial encounter for open fracture */
"S225XXA" = "1" /* Flail chest, initial encounter for closed fracture */
"S225XXB" = "1" /* Flail chest, initial encounter for open fracture */
"S229XXA" = "1" /* Fracture of bony thorax, part unspecified, initial encounter for closed fracture */
"S229XXB" = "1" /* Fracture of bony thorax, part unspecified, initial encounter for open fracture */
"S2501XA" = "1" /* Minor laceration of thoracic aorta, initial encounter */
"S2502XA" = "1" /* Major laceration of thoracic aorta, initial encounter */
"S25101A" = "1" /* Unspecified injury of right innominate or subclavian artery, initial encounter */
"S25102A" = "1" /* Unspecified injury of left innominate or subclavian artery, initial encounter */
"S25109A" = "1" /* Unspecified injury of unspecified innominate or subclavian artery, initial encounter */
"S25111A" = "1" /* Minor laceration of right innominate or subclavian artery, initial encounter */
"S25112A" = "1" /* Minor laceration of left innominate or subclavian artery, initial encounter */
"S25119A" = "1" /* Minor laceration of unspecified innominate or subclavian artery, initial encounter */
"S25121A" = "1" /* Major laceration of right innominate or subclavian artery, initial encounter */
"S25122A" = "1" /* Major laceration of left innominate or subclavian artery, initial encounter */
"S25129A" = "1" /* Major laceration of unspecified innominate or subclavian artery, initial encounter */
"S25191A" = "1" /* Other specified injury of right innominate or subclavian artery, initial encounter */
"S25192A" = "1" /* Other specified injury of left innominate or subclavian artery, initial encounter */
"S25199A" = "1" /* Other specified injury of unspecified innominate or subclavian artery, initial encounter */
"S2520XA" = "1" /* Unspecified injury of superior vena cava, initial encounter */
"S2521XA" = "1" /* Minor laceration of superior vena cava, initial encounter */
"S2522XA" = "1" /* Major laceration of superior vena cava, initial encounter */
"S2529XA" = "1" /* Other specified injury of superior vena cava, initial encounter */
"S25301A" = "1" /* Unspecified injury of right innominate or subclavian vein, initial encounter */
"S25302A" = "1" /* Unspecified injury of left innominate or subclavian vein, initial encounter */
"S25309A" = "1" /* Unspecified injury of unspecified innominate or subclavian vein, initial encounter */
"S25311A" = "1" /* Minor laceration of right innominate or subclavian vein, initial encounter */
"S25312A" = "1" /* Minor laceration of left innominate or subclavian vein, initial encounter */
"S25319A" = "1" /* Minor laceration of unspecified innominate or subclavian vein, initial encounter */
"S25321A" = "1" /* Major laceration of right innominate or subclavian vein, initial encounter */
"S25322A" = "1" /* Major laceration of left innominate or subclavian vein, initial encounter */
"S25329A" = "1" /* Major laceration of unspecified innominate or subclavian vein, initial encounter */
"S25391A" = "1" /* Other specified injury of right innominate or subclavian vein, initial encounter */
"S25392A" = "1" /* Other specified injury of left innominate or subclavian vein, initial encounter */
"S25399A" = "1" /* Other specified injury of unspecified innominate or subclavian vein, initial encounter */
"S25401A" = "1" /* Unspecified injury of right pulmonary blood vessels, initial encounter */
"S25402A" = "1" /* Unspecified injury of left pulmonary blood vessels, initial encounter */
"S25409A" = "1" /* Unspecified injury of unspecified pulmonary blood vessels, initial encounter */
"S25411A" = "1" /* Minor laceration of right pulmonary blood vessels, initial encounter */
"S25412A" = "1" /* Minor laceration of left pulmonary blood vessels, initial encounter */
"S25419A" = "1" /* Minor laceration of unspecified pulmonary blood vessels, initial encounter */
"S25421A" = "1" /* Major laceration of right pulmonary blood vessels, initial encounter */
"S25422A" = "1" /* Major laceration of left pulmonary blood vessels, initial encounter */
"S25429A" = "1" /* Major laceration of unspecified pulmonary blood vessels, initial encounter */
"S25491A" = "1" /* Other specified injury of right pulmonary blood vessels, initial encounter */
"S25492A" = "1" /* Other specified injury of left pulmonary blood vessels, initial encounter */
"S25499A" = "1" /* Other specified injury of unspecified pulmonary blood vessels, initial encounter */
"S25501A" = "1" /* Unspecified injury of intercostal blood vessels, right side, initial encounter */
"S25502A" = "1" /* Unspecified injury of intercostal blood vessels, left side, initial encounter */
"S25509A" = "1" /* Unspecified injury of intercostal blood vessels, unspecified side, initial encounter */
"S25511A" = "1" /* Laceration of intercostal blood vessels, right side, initial encounter */
"S25512A" = "1" /* Laceration of intercostal blood vessels, left side, initial encounter */
"S25519A" = "1" /* Laceration of intercostal blood vessels, unspecified side, initial encounter */
"S25591A" = "1" /* Other specified injury of intercostal blood vessels, right side, initial encounter */
"S25592A" = "1" /* Other specified injury of intercostal blood vessels, left side, initial encounter */
"S25599A" = "1" /* Other specified injury of intercostal blood vessels, unspecified side, initial encounter */
"S25801A" = "1" /* Unspecified injury of other blood vessels of thorax, right side, initial encounter */
"S25802A" = "1" /* Unspecified injury of other blood vessels of thorax, left side, initial encounter */
"S25809A" = "1" /* Unspecified injury of other blood vessels of thorax, unspecified side, initial encounter */
"S25811A" = "1" /* Laceration of other blood vessels of thorax, right side, initial encounter */
"S25812A" = "1" /* Laceration of other blood vessels of thorax, left side, initial encounter */
"S25819A" = "1" /* Laceration of other blood vessels of thorax, unspecified side, initial encounter */
"S25891A" = "1" /* Other specified injury of other blood vessels of thorax, right side, initial encounter */
"S25892A" = "1" /* Other specified injury of other blood vessels of thorax, left side, initial encounter */
"S25899A" = "1" /* Other specified injury of other blood vessels of thorax, unspecified side, initial encounter */
"S2590XA" = "1" /* Unspecified injury of unspecified blood vessel of thorax, initial encounter */
"S2591XA" = "1" /* Laceration of unspecified blood vessel of thorax, initial encounter */
"S2599XA" = "1" /* Other specified injury of unspecified blood vessel of thorax, initial encounter */
"S2600XA" = "1" /* Unspecified injury of heart with hemopericardium, initial encounter */
"S26020A" = "1" /* Mild laceration of heart with hemopericardium, initial encounter */
"S26021A" = "1" /* Moderate laceration of heart with hemopericardium, initial encounter */
"S26022A" = "1" /* Major laceration of heart with hemopericardium, initial encounter */
"S2609XA" = "1" /* Other injury of heart with hemopericardium, initial encounter */
"S2610XA" = "1" /* Unspecified injury of heart without hemopericardium, initial encounter */
"S2612XA" = "1" /* Laceration of heart without hemopericardium, initial encounter */
"S2692XA" = "1" /* Laceration of heart, unspecified with or without hemopericardium, initial encounter */
"S270XXA" = "1" /* Traumatic pneumothorax, initial encounter */
"S271XXA" = "1" /* Traumatic hemothorax, initial encounter */
"S272XXA" = "1" /* Traumatic hemopneumothorax, initial encounter */
"S27301A" = "1" /* Unspecified injury of lung, unilateral, initial encounter */
"S27302A" = "1" /* Unspecified injury of lung, bilateral, initial encounter */
"S27309A" = "1" /* Unspecified injury of lung, unspecified, initial encounter */
"S27311A" = "1" /* Primary blast injury of lung, unilateral, initial encounter */
"S27312A" = "1" /* Primary blast injury of lung, bilateral, initial encounter */
"S27319A" = "1" /* Primary blast injury of lung, unspecified, initial encounter */
"S27321A" = "1" /* Contusion of lung, unilateral, initial encounter */
"S27322A" = "1" /* Contusion of lung, bilateral, initial encounter */
"S27329A" = "1" /* Contusion of lung, unspecified, initial encounter */
"S27331A" = "1" /* Laceration of lung, unilateral, initial encounter */
"S27332A" = "1" /* Laceration of lung, bilateral, initial encounter */
"S27339A" = "1" /* Laceration of lung, unspecified, initial encounter */
"S27391A" = "1" /* Other injuries of lung, unilateral, initial encounter */
"S27392A" = "1" /* Other injuries of lung, bilateral, initial encounter */
"S27399A" = "1" /* Other injuries of lung, unspecified, initial encounter */
"S27401A" = "1" /* Unspecified injury of bronchus, unilateral, initial encounter */
"S27402A" = "1" /* Unspecified injury of bronchus, bilateral, initial encounter */
"S27409A" = "1" /* Unspecified injury of bronchus, unspecified, initial encounter */
"S27411A" = "1" /* Primary blast injury of bronchus, unilateral, initial encounter */
"S27412A" = "1" /* Primary blast injury of bronchus, bilateral, initial encounter */
"S27419A" = "1" /* Primary blast injury of bronchus, unspecified, initial encounter */
"S27421A" = "1" /* Contusion of bronchus, unilateral, initial encounter */
"S27422A" = "1" /* Contusion of bronchus, bilateral, initial encounter */
"S27429A" = "1" /* Contusion of bronchus, unspecified, initial encounter */
"S27431A" = "1" /* Laceration of bronchus, unilateral, initial encounter */
"S27432A" = "1" /* Laceration of bronchus, bilateral, initial encounter */
"S27439A" = "1" /* Laceration of bronchus, unspecified, initial encounter */
"S27491A" = "1" /* Other injury of bronchus, unilateral, initial encounter */
"S27492A" = "1" /* Other injury of bronchus, bilateral, initial encounter */
"S27499A" = "1" /* Other injury of bronchus, unspecified, initial encounter */
"S2750XA" = "1" /* Unspecified injury of thoracic trachea, initial encounter */
"S2751XA" = "1" /* Primary blast injury of thoracic trachea, initial encounter */
"S2752XA" = "1" /* Contusion of thoracic trachea, initial encounter */
"S2753XA" = "1" /* Laceration of thoracic trachea, initial encounter */
"S2759XA" = "1" /* Other injury of thoracic trachea, initial encounter */
"S2760XA" = "1" /* Unspecified injury of pleura, initial encounter */
"S2763XA" = "1" /* Laceration of pleura, initial encounter */
"S2769XA" = "1" /* Other injury of pleura, initial encounter */
"S27803A" = "1" /* Laceration of diaphragm, initial encounter */
"S27808A" = "1" /* Other injury of diaphragm, initial encounter */
"S27809A" = "1" /* Unspecified injury of diaphragm, initial encounter */
"S27813A" = "1" /* Laceration of esophagus (thoracic part), initial encounter */
"S27818A" = "1" /* Other injury of esophagus (thoracic part), initial encounter */
"S27819A" = "1" /* Unspecified injury of esophagus (thoracic part), initial encounter */
"S27893A" = "1" /* Laceration of other specified intrathoracic organs, initial encounter */
"S280XXA" = "1" /* Crushed chest, initial encounter */
"S281XXA" = "1" /* Traumatic amputation (partial) of part of thorax, except breast, initial encounter */
Other = "0"
;

/* Diagnosis codeset DECUBVD last updated 160922 for IDC10 v60rev3 */
Value $DECUBVD
"L89000" = "1" /* Pressure ulcer of unspecified elbow, unstageable */
"L89003" = "1" /* Pressure ulcer of unspecified elbow, stage 3 */
"L89004" = "1" /* Pressure ulcer of unspecified elbow, stage 4 */
"L89010" = "1" /* Pressure ulcer of right elbow, unstageable */
"L89013" = "1" /* Pressure ulcer of right elbow, stage 3 */
"L89014" = "1" /* Pressure ulcer of right elbow, stage 4 */
"L89020" = "1" /* Pressure ulcer of left elbow, unstageable */
"L89023" = "1" /* Pressure ulcer of left elbow, stage 3 */
"L89024" = "1" /* Pressure ulcer of left elbow, stage 4 */
"L89100" = "1" /* Pressure ulcer of unspecified part of back, unstageable */
"L89103" = "1" /* Pressure ulcer of unspecified part of back, stage 3 */
"L89104" = "1" /* Pressure ulcer of unspecified part of back, stage 4 */
"L89110" = "1" /* Pressure ulcer of right upper back, unstageable */
"L89113" = "1" /* Pressure ulcer of right upper back, stage 3 */
"L89114" = "1" /* Pressure ulcer of right upper back, stage 4 */
"L89120" = "1" /* Pressure ulcer of left upper back, unstageable */
"L89123" = "1" /* Pressure ulcer of left upper back, stage 3 */
"L89124" = "1" /* Pressure ulcer of left upper back, stage 4 */
"L89130" = "1" /* Pressure ulcer of right lower back, unstageable */
"L89133" = "1" /* Pressure ulcer of right lower back, stage 3 */
"L89134" = "1" /* Pressure ulcer of right lower back, stage 4 */
"L89140" = "1" /* Pressure ulcer of left lower back, unstageable */
"L89143" = "1" /* Pressure ulcer of left lower back, stage 3 */
"L89144" = "1" /* Pressure ulcer of left lower back, stage 4 */
"L89150" = "1" /* Pressure ulcer of sacral region, unstageable */
"L89153" = "1" /* Pressure ulcer of sacral region, stage 3 */
"L89154" = "1" /* Pressure ulcer of sacral region, stage 4 */
"L89200" = "1" /* Pressure ulcer of unspecified hip, unstageable */
"L89203" = "1" /* Pressure ulcer of unspecified hip, stage 3 */
"L89204" = "1" /* Pressure ulcer of unspecified hip, stage 4 */
"L89210" = "1" /* Pressure ulcer of right hip, unstageable */
"L89213" = "1" /* Pressure ulcer of right hip, stage 3 */
"L89214" = "1" /* Pressure ulcer of right hip, stage 4 */
"L89220" = "1" /* Pressure ulcer of left hip, unstageable */
"L89223" = "1" /* Pressure ulcer of left hip, stage 3 */
"L89224" = "1" /* Pressure ulcer of left hip, stage 4 */
"L89300" = "1" /* Pressure ulcer of unspecified buttock, unstageable */
"L89303" = "1" /* Pressure ulcer of unspecified buttock, stage 3 */
"L89304" = "1" /* Pressure ulcer of unspecified buttock, stage 4 */
"L89310" = "1" /* Pressure ulcer of right buttock, unstageable */
"L89313" = "1" /* Pressure ulcer of right buttock, stage 3 */
"L89314" = "1" /* Pressure ulcer of right buttock, stage 4 */
"L89320" = "1" /* Pressure ulcer of left buttock, unstageable */
"L89323" = "1" /* Pressure ulcer of left buttock, stage 3 */
"L89324" = "1" /* Pressure ulcer of left buttock, stage 4 */
"L8943" = "1" /* Pressure ulcer of contiguous site of back, buttock and hip, stage 3 */
"L8944" = "1" /* Pressure ulcer of contiguous site of back, buttock and hip, stage 4 */
"L8945" = "1" /* Pressure ulcer of contiguous site of back, buttock and hip, unstageable */
"L89500" = "1" /* Pressure ulcer of unspecified ankle, unstageable */
"L89503" = "1" /* Pressure ulcer of unspecified ankle, stage 3 */
"L89504" = "1" /* Pressure ulcer of unspecified ankle, stage 4 */
"L89510" = "1" /* Pressure ulcer of right ankle, unstageable */
"L89513" = "1" /* Pressure ulcer of right ankle, stage 3 */
"L89514" = "1" /* Pressure ulcer of right ankle, stage 4 */
"L89520" = "1" /* Pressure ulcer of left ankle, unstageable */
"L89523" = "1" /* Pressure ulcer of left ankle, stage 3 */
"L89524" = "1" /* Pressure ulcer of left ankle, stage 4 */
"L89600" = "1" /* Pressure ulcer of unspecified heel, unstageable */
"L89603" = "1" /* Pressure ulcer of unspecified heel, stage 3 */
"L89604" = "1" /* Pressure ulcer of unspecified heel, stage 4 */
"L89610" = "1" /* Pressure ulcer of right heel, unstageable */
"L89613" = "1" /* Pressure ulcer of right heel, stage 3 */
"L89614" = "1" /* Pressure ulcer of right heel, stage 4 */
"L89620" = "1" /* Pressure ulcer of left heel, unstageable */
"L89623" = "1" /* Pressure ulcer of left heel, stage 3 */
"L89624" = "1" /* Pressure ulcer of left heel, stage 4 */
"L89810" = "1" /* Pressure ulcer of head, unstageable */
"L89813" = "1" /* Pressure ulcer of head, stage 3 */
"L89814" = "1" /* Pressure ulcer of head, stage 4 */
"L89890" = "1" /* Pressure ulcer of other site, unstageable */
"L89893" = "1" /* Pressure ulcer of other site, stage 3 */
"L89894" = "1" /* Pressure ulcer of other site, stage 4 */
"L8993" = "1" /* Pressure ulcer of unspecified site, stage 3 */
"L8994" = "1" /* Pressure ulcer of unspecified site, stage 4 */
"L8995" = "1" /* Pressure ulcer of unspecified site, unstageable */
Other = "0"
;

/* Diagnosis codeset DGNEUID last updated 160922 for IDC10 v60rev3 */
Value $DGNEUID
"F0150" = "1" /* Vascular dementia without behavioral disturbance */
"F0151" = "1" /* Vascular dementia with behavioral disturbance */
"F0280" = "1" /* Dementia in other diseases classified elsewhere without behavioral disturbance */
"F0281" = "1" /* Dementia in other diseases classified elsewhere with behavioral disturbance */
"F0390" = "1" /* Unspecified dementia without behavioral disturbance */
"F04" = "1" /* Amnestic disorder due to known physiological condition */
"F05" = "1" /* Delirium due to known physiological condition */
"F060" = "1" /* Psychotic disorder with hallucinations due to known physiological condition */
"F061" = "1" /* Catatonic disorder due to known physiological condition */
"F068" = "1" /* Other specified mental disorders due to known physiological condition */
"F070" = "1" /* Personality change due to known physiological condition */
"F0789" = "1" /* Other personality and behavioral disorders due to known physiological condition */
"F079" = "1" /* Unspecified personality and behavioral disorder due to known physiological condition */
"F09" = "1" /* Unspecified mental disorder due to known physiological condition */
"F482" = "1" /* Pseudobulbar affect */
"G300" = "1" /* Alzheimer's disease with early onset */
"G301" = "1" /* Alzheimer's disease with late onset */
"G308" = "1" /* Other Alzheimer's disease */
"G309" = "1" /* Alzheimer's disease, unspecified */
"G3101" = "1" /* Pick's disease */
"G3109" = "1" /* Other frontotemporal dementia */
"G311" = "1" /* Senile degeneration of brain, not elsewhere classified */
"G3183" = "1" /* Dementia with Lewy bodies */
"G3185" = "1" /* Corticobasal degeneration */
"G9382" = "1" /* Brain death */
Other = "0"
;

/* Procedure codeset DIAPHRP last updated 160922 for IDC10 v60rev3 */
Value $DIAPHRP
"0BQR0ZZ" = "1" /* Repair Right Diaphragm, Open Approach */
"0BQR3ZZ" = "1" /* Repair Right Diaphragm, Percutaneous Approach */
"0BQR4ZZ" = "1" /* Repair Right Diaphragm, Percutaneous Endoscopic Approach */
"0BQS0ZZ" = "1" /* Repair Left Diaphragm, Open Approach */
"0BQS3ZZ" = "1" /* Repair Left Diaphragm, Percutaneous Approach */
"0BQS4ZZ" = "1" /* Repair Left Diaphragm, Percutaneous Endoscopic Approach */
"0BUR07Z" = "1" /* Supplement Right Diaphragm with Autologous Tissue Substitute, Open Approach */
"0BUR0JZ" = "1" /* Supplement Right Diaphragm with Synthetic Substitute, Open Approach */
"0BUR0KZ" = "1" /* Supplement Right Diaphragm with Nonautologous Tissue Substitute, Open Approach */
"0BUR47Z" = "1" /* Supplement Right Diaphragm with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BUR4JZ" = "1" /* Supplement Right Diaphragm with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BUR4KZ" = "1" /* Supplement Right Diaphragm with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BUS07Z" = "1" /* Supplement Left Diaphragm with Autologous Tissue Substitute, Open Approach */
"0BUS0JZ" = "1" /* Supplement Left Diaphragm with Synthetic Substitute, Open Approach */
"0BUS0KZ" = "1" /* Supplement Left Diaphragm with Nonautologous Tissue Substitute, Open Approach */
"0BUS47Z" = "1" /* Supplement Left Diaphragm with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BUS4JZ" = "1" /* Supplement Left Diaphragm with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BUS4KZ" = "1" /* Supplement Left Diaphragm with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
Other = "0"
;

/* Procedure codeset ECMOP last updated 160922 for IDC10 v60rev3 */
Value $ECMOP
"5A15223" = "1" /* Extracorporeal Membrane Oxygenation, Continuous */
Other = "0"
;

/* Diagnosis codeset EXFOLIATXD last updated 160922 for IDC10 v60rev3 */
Value $EXFOLIATXD
"L492" = "1" /* Exfoliation due to erythematous condition involving 20-29 percent of body surface */
"L493" = "1" /* Exfoliation due to erythematous condition involving 30-39 percent of body surface */
"L494" = "1" /* Exfoliation due to erythematous condition involving 40-49 percent of body surface */
"L495" = "1" /* Exfoliation due to erythematous condition involving 50-59 percent of body surface */
"L496" = "1" /* Exfoliation due to erythematous condition involving 60-69 percent of body surface */
"L497" = "1" /* Exfoliation due to erythematous condition involving 70-79 percent of body surface */
"L498" = "1" /* Exfoliation due to erythematous condition involving 80-89 percent of body surface */
"L499" = "1" /* Exfoliation due to erythematous condition involving 90 or more percent of body surface */
Other = "0"
;

/* Diagnosis codeset FOREIID last updated 160922 for IDC10 v60rev3 */
Value $FOREIID
"T81500A" = "1" /* Unspecified complication of foreign body accidentally left in body following surgical operation, initial encounter */
"T81501A" = "1" /* Unspecified complication of foreign body accidentally left in body following infusion or transfusion, initial encounter */
"T81502A" = "1" /* Unspecified complication of foreign body accidentally left in body following kidney dialysis, initial encounter */
"T81503A" = "1" /* Unspecified complication of foreign body accidentally left in body following injection or immunization, initial encounter */
"T81504A" = "1" /* Unspecified complication of foreign body accidentally left in body following endoscopic examination, initial encounter */
"T81505A" = "1" /* Unspecified complication of foreign body accidentally left in body following heart catheterization, initial encounter */
"T81506A" = "1" /* Unspecified complication of foreign body accidentally left in body following aspiration, puncture or other catheterization, initial encounter */
"T81507A" = "1" /* Unspecified complication of foreign body accidentally left in body following removal of catheter or packing, initial encounter */
"T81508A" = "1" /* Unspecified complication of foreign body accidentally left in body following other procedure, initial encounter */
"T81509A" = "1" /* Unspecified complication of foreign body accidentally left in body following unspecified procedure, initial encounter */
"T81510A" = "1" /* Adhesions due to foreign body accidentally left in body following surgical operation, initial encounter */
"T81511A" = "1" /* Adhesions due to foreign body accidentally left in body following infusion or transfusion, initial encounter */
"T81512A" = "1" /* Adhesions due to foreign body accidentally left in body following kidney dialysis, initial encounter */
"T81513A" = "1" /* Adhesions due to foreign body accidentally left in body following injection or immunization, initial encounter */
"T81514A" = "1" /* Adhesions due to foreign body accidentally left in body following endoscopic examination, initial encounter */
"T81515A" = "1" /* Adhesions due to foreign body accidentally left in body following heart catheterization, initial encounter */
"T81516A" = "1" /* Adhesions due to foreign body accidentally left in body following aspiration, puncture or other catheterization, initial encounter */
"T81517A" = "1" /* Adhesions due to foreign body accidentally left in body following removal of catheter or packing, initial encounter */
"T81518A" = "1" /* Adhesions due to foreign body accidentally left in body following other procedure, initial encounter */
"T81519A" = "1" /* Adhesions due to foreign body accidentally left in body following unspecified procedure, initial encounter */
"T81520A" = "1" /* Obstruction due to foreign body accidentally left in body following surgical operation, initial encounter */
"T81521A" = "1" /* Obstruction due to foreign body accidentally left in body following infusion or transfusion, initial encounter */
"T81522A" = "1" /* Obstruction due to foreign body accidentally left in body following kidney dialysis, initial encounter */
"T81523A" = "1" /* Obstruction due to foreign body accidentally left in body following injection or immunization, initial encounter */
"T81524A" = "1" /* Obstruction due to foreign body accidentally left in body following endoscopic examination, initial encounter */
"T81525A" = "1" /* Obstruction due to foreign body accidentally left in body following heart catheterization, initial encounter */
"T81526A" = "1" /* Obstruction due to foreign body accidentally left in body following aspiration, puncture or other catheterization, initial encounter */
"T81527A" = "1" /* Obstruction due to foreign body accidentally left in body following removal of catheter or packing, initial encounter */
"T81528A" = "1" /* Obstruction due to foreign body accidentally left in body following other procedure, initial encounter */
"T81529A" = "1" /* Obstruction due to foreign body accidentally left in body following unspecified procedure, initial encounter */
"T81530A" = "1" /* Perforation due to foreign body accidentally left in body following surgical operation, initial encounter */
"T81531A" = "1" /* Perforation due to foreign body accidentally left in body following infusion or transfusion, initial encounter */
"T81532A" = "1" /* Perforation due to foreign body accidentally left in body following kidney dialysis, initial encounter */
"T81533A" = "1" /* Perforation due to foreign body accidentally left in body following injection or immunization, initial encounter */
"T81534A" = "1" /* Perforation due to foreign body accidentally left in body following endoscopic examination, initial encounter */
"T81535A" = "1" /* Perforation due to foreign body accidentally left in body following heart catheterization, initial encounter */
"T81536A" = "1" /* Perforation due to foreign body accidentally left in body following aspiration, puncture or other catheterization, initial encounter */
"T81537A" = "1" /* Perforation due to foreign body accidentally left in body following removal of catheter or packing, initial encounter */
"T81538A" = "1" /* Perforation due to foreign body accidentally left in body following other procedure, initial encounter */
"T81539A" = "1" /* Perforation due to foreign body accidentally left in body following unspecified procedure, initial encounter */
"T81590A" = "1" /* Other complications of foreign body accidentally left in body following surgical operation, initial encounter */
"T81591A" = "1" /* Other complications of foreign body accidentally left in body following infusion or transfusion, initial encounter */
"T81592A" = "1" /* Other complications of foreign body accidentally left in body following kidney dialysis, initial encounter */
"T81593A" = "1" /* Other complications of foreign body accidentally left in body following injection or immunization, initial encounter */
"T81594A" = "1" /* Other complications of foreign body accidentally left in body following endoscopic examination, initial encounter */
"T81595A" = "1" /* Other complications of foreign body accidentally left in body following heart catheterization, initial encounter */
"T81596A" = "1" /* Other complications of foreign body accidentally left in body following aspiration, puncture or other catheterization, initial encounter */
"T81597A" = "1" /* Other complications of foreign body accidentally left in body following removal of catheter or packing, initial encounter */
"T81598A" = "1" /* Other complications of foreign body accidentally left in body following other procedure, initial encounter */
"T81599A" = "1" /* Other complications of foreign body accidentally left in body following unspecified procedure, initial encounter */
"T8160XA" = "1" /* Unspecified acute reaction to foreign substance accidentally left during a procedure, initial encounter */
"T8161XA" = "1" /* Aseptic peritonitis due to foreign substance accidentally left during a procedure, initial encounter */
"T8169XA" = "1" /* Other acute reaction to foreign substance accidentally left during a procedure, initial encounter */
Other = "0"
;

/* Diagnosis codeset GESTC1D last updated 160922 for IDC10 v60rev3 */
Value $GESTC1D
"P0721" = "1" /* Extreme immaturity of newborn, gestational age less than 23 completed weeks */
"P0722" = "1" /* Extreme immaturity of newborn, gestational age 23 completed weeks */
Other = "0"
;

/* Diagnosis codeset GESTC2D last updated 160922 for IDC10 v60rev3 */
Value $GESTC2D
"P0723" = "1" /* Extreme immaturity of newborn, gestational age 24 completed weeks */
Other = "0"
;

/* Diagnosis codeset GESTC3D last updated 160922 for IDC10 v60rev3 */
Value $GESTC3D
"P0724" = "1" /* Extreme immaturity of newborn, gestational age 25 completed weeks */
"P0725" = "1" /* Extreme immaturity of newborn, gestational age 26 completed weeks */
Other = "0"
;

/* Diagnosis codeset GESTC4D last updated 160922 for IDC10 v60rev3 */
Value $GESTC4D
"P0726" = "1" /* Extreme immaturity of newborn, gestational age 27 completed weeks */
"P0731" = "1" /* Preterm newborn, gestational age 28 completed weeks */
Other = "0"
;

/* Diagnosis codeset GESTC5D last updated 160922 for IDC10 v60rev3 */
Value $GESTC5D
"P0732" = "1" /* Preterm newborn, gestational age 29 completed weeks */
"P0733" = "1" /* Preterm newborn, gestational age 30 completed weeks */
Other = "0"
;

/* Diagnosis codeset GESTC6D last updated 160922 for IDC10 v60rev3 */
Value $GESTC6D
"P0734" = "1" /* Preterm newborn, gestational age 31 completed weeks */
"P0735" = "1" /* Preterm newborn, gestational age 32 completed weeks */
Other = "0"
;

/* Diagnosis codeset GESTC7D last updated 160922 for IDC10 v60rev3 */
Value $GESTC7D
"P0736" = "1" /* Preterm newborn, gestational age 33 completed weeks */
"P0737" = "1" /* Preterm newborn, gestational age 34 completed weeks */
Other = "0"
;

/* Diagnosis codeset GESTC8D last updated 160922 for IDC10 v60rev3 */
Value $GESTC8D
"P0738" = "1" /* Preterm newborn, gestational age 35 completed weeks */
"P0739" = "1" /* Preterm newborn, gestational age 36 completed weeks */
Other = "0"
;

/* Diagnosis codeset HEMIPID last updated 160922 for IDC10 v60rev3 */
Value $HEMIPID
"G041" = "1" /* Tropical spastic paraplegia */
"G114" = "1" /* Hereditary spastic paraplegia */
"G800" = "1" /* Spastic quadriplegic cerebral palsy */
"G801" = "1" /* Spastic diplegic cerebral palsy */
"G802" = "1" /* Spastic hemiplegic cerebral palsy */
"G803" = "1" /* Athetoid cerebral palsy */
"G804" = "1" /* Ataxic cerebral palsy */
"G808" = "1" /* Other cerebral palsy */
"G809" = "1" /* Cerebral palsy, unspecified */
"G8100" = "1" /* Flaccid hemiplegia affecting unspecified side */
"G8101" = "1" /* Flaccid hemiplegia affecting right dominant side */
"G8102" = "1" /* Flaccid hemiplegia affecting left dominant side */
"G8103" = "1" /* Flaccid hemiplegia affecting right nondominant side */
"G8104" = "1" /* Flaccid hemiplegia affecting left nondominant side */
"G8110" = "1" /* Spastic hemiplegia affecting unspecified side */
"G8111" = "1" /* Spastic hemiplegia affecting right dominant side */
"G8112" = "1" /* Spastic hemiplegia affecting left dominant side */
"G8113" = "1" /* Spastic hemiplegia affecting right nondominant side */
"G8114" = "1" /* Spastic hemiplegia affecting left nondominant side */
"G8190" = "1" /* Hemiplegia, unspecified affecting unspecified side */
"G8191" = "1" /* Hemiplegia, unspecified affecting right dominant side */
"G8192" = "1" /* Hemiplegia, unspecified affecting left dominant side */
"G8193" = "1" /* Hemiplegia, unspecified affecting right nondominant side */
"G8194" = "1" /* Hemiplegia, unspecified affecting left nondominant side */
"G8220" = "1" /* Paraplegia, unspecified */
"G8221" = "1" /* Paraplegia, complete */
"G8222" = "1" /* Paraplegia, incomplete */
"G8250" = "1" /* Quadriplegia, unspecified */
"G8251" = "1" /* Quadriplegia, C1-C4 complete */
"G8252" = "1" /* Quadriplegia, C1-C4 incomplete */
"G8253" = "1" /* Quadriplegia, C5-C7 complete */
"G8254" = "1" /* Quadriplegia, C5-C7 incomplete */
"G830" = "1" /* Diplegia of upper limbs */
"G8310" = "1" /* Monoplegia of lower limb affecting unspecified side */
"G8311" = "1" /* Monoplegia of lower limb affecting right dominant side */
"G8312" = "1" /* Monoplegia of lower limb affecting left dominant side */
"G8313" = "1" /* Monoplegia of lower limb affecting right nondominant side */
"G8314" = "1" /* Monoplegia of lower limb affecting left nondominant side */
"G8320" = "1" /* Monoplegia of upper limb affecting unspecified side */
"G8321" = "1" /* Monoplegia of upper limb affecting right dominant side */
"G8322" = "1" /* Monoplegia of upper limb affecting left dominant side */
"G8323" = "1" /* Monoplegia of upper limb affecting right nondominant side */
"G8324" = "1" /* Monoplegia of upper limb affecting left nondominant side */
"G8330" = "1" /* Monoplegia, unspecified affecting unspecified side */
"G8331" = "1" /* Monoplegia, unspecified affecting right dominant side */
"G8332" = "1" /* Monoplegia, unspecified affecting left dominant side */
"G8333" = "1" /* Monoplegia, unspecified affecting right nondominant side */
"G8334" = "1" /* Monoplegia, unspecified affecting left nondominant side */
"G834" = "1" /* Cauda equina syndrome */
"G835" = "1" /* Locked-in state */
"G8381" = "1" /* Brown-Sequard syndrome */
"G8382" = "1" /* Anterior cord syndrome */
"G8383" = "1" /* Posterior cord syndrome */
"G8384" = "1" /* Todd's paralysis (postepileptic) */
"G8389" = "1" /* Other specified paralytic syndromes */
"G839" = "1" /* Paralytic syndrome, unspecified */
"I69031" = "1" /* Monoplegia of upper limb following nontraumatic subarachnoid hemorrhage affecting right dominant side */
"I69032" = "1" /* Monoplegia of upper limb following nontraumatic subarachnoid hemorrhage affecting left dominant side */
"I69033" = "1" /* Monoplegia of upper limb following nontraumatic subarachnoid hemorrhage affecting right non-dominant side */
"I69034" = "1" /* Monoplegia of upper limb following nontraumatic subarachnoid hemorrhage affecting left non-dominant side */
"I69039" = "1" /* Monoplegia of upper limb following nontraumatic subarachnoid hemorrhage affecting unspecified side */
"I69041" = "1" /* Monoplegia of lower limb following nontraumatic subarachnoid hemorrhage affecting right dominant side */
"I69042" = "1" /* Monoplegia of lower limb following nontraumatic subarachnoid hemorrhage affecting left dominant side */
"I69043" = "1" /* Monoplegia of lower limb following nontraumatic subarachnoid hemorrhage affecting right non-dominant side */
"I69044" = "1" /* Monoplegia of lower limb following nontraumatic subarachnoid hemorrhage affecting left non-dominant side */
"I69049" = "1" /* Monoplegia of lower limb following nontraumatic subarachnoid hemorrhage affecting unspecified side */
"I69051" = "1" /* Hemiplegia and hemiparesis following nontraumatic subarachnoid hemorrhage affecting right dominant side */
"I69052" = "1" /* Hemiplegia and hemiparesis following nontraumatic subarachnoid hemorrhage affecting left dominant side */
"I69053" = "1" /* Hemiplegia and hemiparesis following nontraumatic subarachnoid hemorrhage affecting right non-dominant side */
"I69054" = "1" /* Hemiplegia and hemiparesis following nontraumatic subarachnoid hemorrhage affecting left non-dominant side */
"I69059" = "1" /* Hemiplegia and hemiparesis following nontraumatic subarachnoid hemorrhage affecting unspecified side */
"I69061" = "1" /* Other paralytic syndrome following nontraumatic subarachnoid hemorrhage affecting right dominant side */
"I69062" = "1" /* Other paralytic syndrome following nontraumatic subarachnoid hemorrhage affecting left dominant side */
"I69063" = "1" /* Other paralytic syndrome following nontraumatic subarachnoid hemorrhage affecting right non-dominant side */
"I69064" = "1" /* Other paralytic syndrome following nontraumatic subarachnoid hemorrhage affecting left non-dominant side */
"I69065" = "1" /* Other paralytic syndrome following nontraumatic subarachnoid hemorrhage, bilateral */
"I69069" = "1" /* Other paralytic syndrome following nontraumatic subarachnoid hemorrhage affecting unspecified side */
"I69131" = "1" /* Monoplegia of upper limb following nontraumatic intracerebral hemorrhage affecting right dominant side */
"I69132" = "1" /* Monoplegia of upper limb following nontraumatic intracerebral hemorrhage affecting left dominant side */
"I69133" = "1" /* Monoplegia of upper limb following nontraumatic intracerebral hemorrhage affecting right non-dominant side */
"I69134" = "1" /* Monoplegia of upper limb following nontraumatic intracerebral hemorrhage affecting left non-dominant side */
"I69139" = "1" /* Monoplegia of upper limb following nontraumatic intracerebral hemorrhage affecting unspecified side */
"I69141" = "1" /* Monoplegia of lower limb following nontraumatic intracerebral hemorrhage affecting right dominant side */
"I69142" = "1" /* Monoplegia of lower limb following nontraumatic intracerebral hemorrhage affecting left dominant side */
"I69143" = "1" /* Monoplegia of lower limb following nontraumatic intracerebral hemorrhage affecting right non-dominant side */
"I69144" = "1" /* Monoplegia of lower limb following nontraumatic intracerebral hemorrhage affecting left non-dominant side */
"I69149" = "1" /* Monoplegia of lower limb following nontraumatic intracerebral hemorrhage affecting unspecified side */
"I69151" = "1" /* Hemiplegia and hemiparesis following nontraumatic intracerebral hemorrhage affecting right dominant side */
"I69152" = "1" /* Hemiplegia and hemiparesis following nontraumatic intracerebral hemorrhage affecting left dominant side */
"I69153" = "1" /* Hemiplegia and hemiparesis following nontraumatic intracerebral hemorrhage affecting right non-dominant side */
"I69154" = "1" /* Hemiplegia and hemiparesis following nontraumatic intracerebral hemorrhage affecting left non-dominant side */
"I69159" = "1" /* Hemiplegia and hemiparesis following nontraumatic intracerebral hemorrhage affecting unspecified side */
"I69161" = "1" /* Other paralytic syndrome following nontraumatic intracerebral hemorrhage affecting right dominant side */
"I69162" = "1" /* Other paralytic syndrome following nontraumatic intracerebral hemorrhage affecting left dominant side */
"I69163" = "1" /* Other paralytic syndrome following nontraumatic intracerebral hemorrhage affecting right non-dominant side */
"I69164" = "1" /* Other paralytic syndrome following nontraumatic intracerebral hemorrhage affecting left non-dominant side */
"I69165" = "1" /* Other paralytic syndrome following nontraumatic intracerebral hemorrhage, bilateral */
"I69169" = "1" /* Other paralytic syndrome following nontraumatic intracerebral hemorrhage affecting unspecified side */
"I69231" = "1" /* Monoplegia of upper limb following other nontraumatic intracranial hemorrhage affecting right dominant side */
"I69232" = "1" /* Monoplegia of upper limb following other nontraumatic intracranial hemorrhage affecting left dominant side */
"I69233" = "1" /* Monoplegia of upper limb following other nontraumatic intracranial hemorrhage affecting right non-dominant side */
"I69234" = "1" /* Monoplegia of upper limb following other nontraumatic intracranial hemorrhage affecting left non-dominant side */
"I69239" = "1" /* Monoplegia of upper limb following other nontraumatic intracranial hemorrhage affecting unspecified side */
"I69241" = "1" /* Monoplegia of lower limb following other nontraumatic intracranial hemorrhage affecting right dominant side */
"I69242" = "1" /* Monoplegia of lower limb following other nontraumatic intracranial hemorrhage affecting left dominant side */
"I69243" = "1" /* Monoplegia of lower limb following other nontraumatic intracranial hemorrhage affecting right non-dominant side */
"I69244" = "1" /* Monoplegia of lower limb following other nontraumatic intracranial hemorrhage affecting left non-dominant side */
"I69249" = "1" /* Monoplegia of lower limb following other nontraumatic intracranial hemorrhage affecting unspecified side */
"I69251" = "1" /* Hemiplegia and hemiparesis following other nontraumatic intracranial hemorrhage affecting right dominant side */
"I69252" = "1" /* Hemiplegia and hemiparesis following other nontraumatic intracranial hemorrhage affecting left dominant side */
"I69253" = "1" /* Hemiplegia and hemiparesis following other nontraumatic intracranial hemorrhage affecting right non-dominant side */
"I69254" = "1" /* Hemiplegia and hemiparesis following other nontraumatic intracranial hemorrhage affecting left non-dominant side */
"I69259" = "1" /* Hemiplegia and hemiparesis following other nontraumatic intracranial hemorrhage affecting unspecified side */
"I69261" = "1" /* Other paralytic syndrome following other nontraumatic intracranial hemorrhage affecting right dominant side */
"I69262" = "1" /* Other paralytic syndrome following other nontraumatic intracranial hemorrhage affecting left dominant side */
"I69263" = "1" /* Other paralytic syndrome following other nontraumatic intracranial hemorrhage affecting right non-dominant side */
"I69264" = "1" /* Other paralytic syndrome following other nontraumatic intracranial hemorrhage affecting left non-dominant side */
"I69265" = "1" /* Other paralytic syndrome following other nontraumatic intracranial hemorrhage, bilateral */
"I69269" = "1" /* Other paralytic syndrome following other nontraumatic intracranial hemorrhage affecting unspecified side */
"I69331" = "1" /* Monoplegia of upper limb following cerebral infarction affecting right dominant side */
"I69332" = "1" /* Monoplegia of upper limb following cerebral infarction affecting left dominant side */
"I69333" = "1" /* Monoplegia of upper limb following cerebral infarction affecting right non-dominant side */
"I69334" = "1" /* Monoplegia of upper limb following cerebral infarction affecting left non-dominant side */
"I69339" = "1" /* Monoplegia of upper limb following cerebral infarction affecting unspecified side */
"I69341" = "1" /* Monoplegia of lower limb following cerebral infarction affecting right dominant side */
"I69342" = "1" /* Monoplegia of lower limb following cerebral infarction affecting left dominant side */
"I69343" = "1" /* Monoplegia of lower limb following cerebral infarction affecting right non-dominant side */
"I69344" = "1" /* Monoplegia of lower limb following cerebral infarction affecting left non-dominant side */
"I69349" = "1" /* Monoplegia of lower limb following cerebral infarction affecting unspecified side */
"I69351" = "1" /* Hemiplegia and hemiparesis following cerebral infarction affecting right dominant side */
"I69352" = "1" /* Hemiplegia and hemiparesis following cerebral infarction affecting left dominant side */
"I69353" = "1" /* Hemiplegia and hemiparesis following cerebral infarction affecting right non-dominant side */
"I69354" = "1" /* Hemiplegia and hemiparesis following cerebral infarction affecting left non-dominant side */
"I69359" = "1" /* Hemiplegia and hemiparesis following cerebral infarction affecting unspecified side */
"I69361" = "1" /* Other paralytic syndrome following cerebral infarction affecting right dominant side */
"I69362" = "1" /* Other paralytic syndrome following cerebral infarction affecting left dominant side */
"I69363" = "1" /* Other paralytic syndrome following cerebral infarction affecting right non-dominant side */
"I69364" = "1" /* Other paralytic syndrome following cerebral infarction affecting left non-dominant side */
"I69365" = "1" /* Other paralytic syndrome following cerebral infarction, bilateral */
"I69369" = "1" /* Other paralytic syndrome following cerebral infarction affecting unspecified side */
"I69831" = "1" /* Monoplegia of upper limb following other cerebrovascular disease affecting right dominant side */
"I69832" = "1" /* Monoplegia of upper limb following other cerebrovascular disease affecting left dominant side */
"I69833" = "1" /* Monoplegia of upper limb following other cerebrovascular disease affecting right non-dominant side */
"I69834" = "1" /* Monoplegia of upper limb following other cerebrovascular disease affecting left non-dominant side */
"I69839" = "1" /* Monoplegia of upper limb following other cerebrovascular disease affecting unspecified side */
"I69841" = "1" /* Monoplegia of lower limb following other cerebrovascular disease affecting right dominant side */
"I69842" = "1" /* Monoplegia of lower limb following other cerebrovascular disease affecting left dominant side */
"I69843" = "1" /* Monoplegia of lower limb following other cerebrovascular disease affecting right non-dominant side */
"I69844" = "1" /* Monoplegia of lower limb following other cerebrovascular disease affecting left non-dominant side */
"I69849" = "1" /* Monoplegia of lower limb following other cerebrovascular disease affecting unspecified side */
"I69851" = "1" /* Hemiplegia and hemiparesis following other cerebrovascular disease affecting right dominant side */
"I69852" = "1" /* Hemiplegia and hemiparesis following other cerebrovascular disease affecting left dominant side */
"I69853" = "1" /* Hemiplegia and hemiparesis following other cerebrovascular disease affecting right non-dominant side */
"I69854" = "1" /* Hemiplegia and hemiparesis following other cerebrovascular disease affecting left non-dominant side */
"I69859" = "1" /* Hemiplegia and hemiparesis following other cerebrovascular disease affecting unspecified side */
"I69861" = "1" /* Other paralytic syndrome following other cerebrovascular disease affecting right dominant side */
"I69862" = "1" /* Other paralytic syndrome following other cerebrovascular disease affecting left dominant side */
"I69863" = "1" /* Other paralytic syndrome following other cerebrovascular disease affecting right non-dominant side */
"I69864" = "1" /* Other paralytic syndrome following other cerebrovascular disease affecting left non-dominant side */
"I69865" = "1" /* Other paralytic syndrome following other cerebrovascular disease, bilateral */
"I69869" = "1" /* Other paralytic syndrome following other cerebrovascular disease affecting unspecified side */
"I69931" = "1" /* Monoplegia of upper limb following unspecified cerebrovascular disease affecting right dominant side */
"I69932" = "1" /* Monoplegia of upper limb following unspecified cerebrovascular disease affecting left dominant side */
"I69933" = "1" /* Monoplegia of upper limb following unspecified cerebrovascular disease affecting right non-dominant side */
"I69934" = "1" /* Monoplegia of upper limb following unspecified cerebrovascular disease affecting left non-dominant side */
"I69939" = "1" /* Monoplegia of upper limb following unspecified cerebrovascular disease affecting unspecified side */
"I69941" = "1" /* Monoplegia of lower limb following unspecified cerebrovascular disease affecting right dominant side */
"I69942" = "1" /* Monoplegia of lower limb following unspecified cerebrovascular disease affecting left dominant side */
"I69943" = "1" /* Monoplegia of lower limb following unspecified cerebrovascular disease affecting right non-dominant side */
"I69944" = "1" /* Monoplegia of lower limb following unspecified cerebrovascular disease affecting left non-dominant side */
"I69949" = "1" /* Monoplegia of lower limb following unspecified cerebrovascular disease affecting unspecified side */
"I69951" = "1" /* Hemiplegia and hemiparesis following unspecified cerebrovascular disease affecting right dominant side */
"I69952" = "1" /* Hemiplegia and hemiparesis following unspecified cerebrovascular disease affecting left dominant side */
"I69953" = "1" /* Hemiplegia and hemiparesis following unspecified cerebrovascular disease affecting right non-dominant side */
"I69954" = "1" /* Hemiplegia and hemiparesis following unspecified cerebrovascular disease affecting left non-dominant side */
"I69959" = "1" /* Hemiplegia and hemiparesis following unspecified cerebrovascular disease affecting unspecified side */
"I69961" = "1" /* Other paralytic syndrome following unspecified cerebrovascular disease affecting right dominant side */
"I69962" = "1" /* Other paralytic syndrome following unspecified cerebrovascular disease affecting left dominant side */
"I69963" = "1" /* Other paralytic syndrome following unspecified cerebrovascular disease affecting right non-dominant side */
"I69964" = "1" /* Other paralytic syndrome following unspecified cerebrovascular disease affecting left non-dominant side */
"I69965" = "1" /* Other paralytic syndrome following unspecified cerebrovascular disease, bilateral */
"I69969" = "1" /* Other paralytic syndrome following unspecified cerebrovascular disease affecting unspecified side */
"P9160" = "1" /* Hypoxic ischemic encephalopathy [HIE], unspecified */
"P9162" = "1" /* Moderate hypoxic ischemic encephalopathy [HIE] */
"P9163" = "1" /* Severe hypoxic ischemic encephalopathy [HIE] */
Other = "0"
;

/* Diagnosis codeset HEMOPHD last updated 160922 for IDC10 v60rev3 */
Value $HEMOPHD
"D66" = "1" /* Hereditary factor VIII deficiency */
"D67" = "1" /* Hereditary factor IX deficiency */
"D680" = "1" /* Von Willebrand's disease */
"D681" = "1" /* Hereditary factor XI deficiency */
"D682" = "1" /* Hereditary deficiency of other clotting factors */
Other = "0"
;

/* Diagnosis codeset HEPFA2D last updated 160922 for IDC10 v60rev3 */
Value $HEPFA2D
"K702" = "1" /* Alcoholic fibrosis and sclerosis of liver */
"K7030" = "1" /* Alcoholic cirrhosis of liver without ascites */
"K7031" = "1" /* Alcoholic cirrhosis of liver with ascites */
"K740" = "1" /* Hepatic fibrosis */
"K743" = "1" /* Primary biliary cirrhosis */
"K744" = "1" /* Secondary biliary cirrhosis */
"K745" = "1" /* Biliary cirrhosis, unspecified */
"K7460" = "1" /* Unspecified cirrhosis of liver */
"K7469" = "1" /* Other cirrhosis of liver */
Other = "0"
;

/* Diagnosis codeset HEPFA3D last updated 160922 for IDC10 v60rev3 */
Value $HEPFA3D
"K7040" = "1" /* Alcoholic hepatic failure without coma */
"K7041" = "1" /* Alcoholic hepatic failure with coma */
"K7110" = "1" /* Toxic liver disease with hepatic necrosis, without coma */
"K7111" = "1" /* Toxic liver disease with hepatic necrosis, with coma */
"K7200" = "1" /* Acute and subacute hepatic failure without coma */
"K7201" = "1" /* Acute and subacute hepatic failure with coma */
"K7210" = "1" /* Chronic hepatic failure without coma */
"K7211" = "1" /* Chronic hepatic failure with coma */
"K7290" = "1" /* Hepatic failure, unspecified without coma */
"K7291" = "1" /* Hepatic failure, unspecified with coma */
"K767" = "1" /* Hepatorenal syndrome */
Other = "0"
;

/* Diagnosis codeset IATROID last updated 160922 for IDC10 v60rev3 */
Value $IATROID
"J95811" = "1" /* Postprocedural pneumothorax */
Other = "0"
;

/* Diagnosis codeset IDTMC3D last updated 160922 for IDC10 v60rev3 */
Value $IDTMC3D
"T80211A" = "1" /* Bloodstream infection due to central venous catheter, initial encounter */
Other = "0"
;

/* Diagnosis codeset LIVEB2D last updated 160922 for IDC10 v60rev3 */
Value $LIVEB2D
"Z381" = "1" /* Single liveborn infant, born outside hospital */
"Z384" = "1" /* Twin liveborn infant, born outside hospital */
"Z387" = "1" /* Other multiple liveborn infant, born outside hospital */
Other = "0"
;

/* Diagnosis codeset LIVEBND last updated 160922 for IDC10 v60rev3 */
Value $LIVEBND
"Z3800" = "1" /* Single liveborn infant, delivered vaginally */
"Z3801" = "1" /* Single liveborn infant, delivered by cesarean */
"Z3830" = "1" /* Twin liveborn infant, delivered vaginally */
"Z3831" = "1" /* Twin liveborn infant, delivered by cesarean */
"Z3861" = "1" /* Triplet liveborn infant, delivered vaginally */
"Z3862" = "1" /* Triplet liveborn infant, delivered by cesarean */
"Z3863" = "1" /* Quadruplet liveborn infant, delivered vaginally */
"Z3864" = "1" /* Quadruplet liveborn infant, delivered by cesarean */
"Z3865" = "1" /* Quintuplet liveborn infant, delivered vaginally */
"Z3866" = "1" /* Quintuplet liveborn infant, delivered by cesarean */
"Z3868" = "1" /* Other multiple liveborn infant, delivered vaginally */
"Z3869" = "1" /* Other multiple liveborn infant, delivered by cesarean */
Other = "0"
;

/* Procedure codeset LUNGBIP last updated 160922 for IDC10 v60rev3 */
Value $LUNGBIP
"0B9C0ZX" = "1" /* Drainage of Right Upper Lung Lobe, Open Approach, Diagnostic */
"0B9C3ZX" = "1" /* Drainage of Right Upper Lung Lobe, Percutaneous Approach, Diagnostic */
"0B9C4ZX" = "1" /* Drainage of Right Upper Lung Lobe, Percutaneous Endoscopic Approach, Diagnostic */
"0B9C7ZX" = "1" /* Drainage of Right Upper Lung Lobe, Via Natural or Artificial Opening, Diagnostic */
"0B9D0ZX" = "1" /* Drainage of Right Middle Lung Lobe, Open Approach, Diagnostic */
"0B9D3ZX" = "1" /* Drainage of Right Middle Lung Lobe, Percutaneous Approach, Diagnostic */
"0B9D4ZX" = "1" /* Drainage of Right Middle Lung Lobe, Percutaneous Endoscopic Approach, Diagnostic */
"0B9D7ZX" = "1" /* Drainage of Right Middle Lung Lobe, Via Natural or Artificial Opening, Diagnostic */
"0B9F0ZX" = "1" /* Drainage of Right Lower Lung Lobe, Open Approach, Diagnostic */
"0B9F3ZX" = "1" /* Drainage of Right Lower Lung Lobe, Percutaneous Approach, Diagnostic */
"0B9F4ZX" = "1" /* Drainage of Right Lower Lung Lobe, Percutaneous Endoscopic Approach, Diagnostic */
"0B9F7ZX" = "1" /* Drainage of Right Lower Lung Lobe, Via Natural or Artificial Opening, Diagnostic */
"0B9G0ZX" = "1" /* Drainage of Left Upper Lung Lobe, Open Approach, Diagnostic */
"0B9G3ZX" = "1" /* Drainage of Left Upper Lung Lobe, Percutaneous Approach, Diagnostic */
"0B9G4ZX" = "1" /* Drainage of Left Upper Lung Lobe, Percutaneous Endoscopic Approach, Diagnostic */
"0B9G7ZX" = "1" /* Drainage of Left Upper Lung Lobe, Via Natural or Artificial Opening, Diagnostic */
"0B9H0ZX" = "1" /* Drainage of Lung Lingula, Open Approach, Diagnostic */
"0B9H3ZX" = "1" /* Drainage of Lung Lingula, Percutaneous Approach, Diagnostic */
"0B9H4ZX" = "1" /* Drainage of Lung Lingula, Percutaneous Endoscopic Approach, Diagnostic */
"0B9H7ZX" = "1" /* Drainage of Lung Lingula, Via Natural or Artificial Opening, Diagnostic */
"0B9J0ZX" = "1" /* Drainage of Left Lower Lung Lobe, Open Approach, Diagnostic */
"0B9J3ZX" = "1" /* Drainage of Left Lower Lung Lobe, Percutaneous Approach, Diagnostic */
"0B9J4ZX" = "1" /* Drainage of Left Lower Lung Lobe, Percutaneous Endoscopic Approach, Diagnostic */
"0B9J7ZX" = "1" /* Drainage of Left Lower Lung Lobe, Via Natural or Artificial Opening, Diagnostic */
"0B9K0ZX" = "1" /* Drainage of Right Lung, Open Approach, Diagnostic */
"0B9K3ZX" = "1" /* Drainage of Right Lung, Percutaneous Approach, Diagnostic */
"0B9K4ZX" = "1" /* Drainage of Right Lung, Percutaneous Endoscopic Approach, Diagnostic */
"0B9K7ZX" = "1" /* Drainage of Right Lung, Via Natural or Artificial Opening, Diagnostic */
"0B9L0ZX" = "1" /* Drainage of Left Lung, Open Approach, Diagnostic */
"0B9L3ZX" = "1" /* Drainage of Left Lung, Percutaneous Approach, Diagnostic */
"0B9L4ZX" = "1" /* Drainage of Left Lung, Percutaneous Endoscopic Approach, Diagnostic */
"0B9L7ZX" = "1" /* Drainage of Left Lung, Via Natural or Artificial Opening, Diagnostic */
"0B9M0ZX" = "1" /* Drainage of Bilateral Lungs, Open Approach, Diagnostic */
"0B9M3ZX" = "1" /* Drainage of Bilateral Lungs, Percutaneous Approach, Diagnostic */
"0B9M4ZX" = "1" /* Drainage of Bilateral Lungs, Percutaneous Endoscopic Approach, Diagnostic */
"0B9M7ZX" = "1" /* Drainage of Bilateral Lungs, Via Natural or Artificial Opening, Diagnostic */
"0B9N0ZX" = "1" /* Drainage of Right Pleura, Open Approach, Diagnostic */
"0B9N3ZX" = "1" /* Drainage of Right Pleura, Percutaneous Approach, Diagnostic */
"0B9N4ZX" = "1" /* Drainage of Right Pleura, Percutaneous Endoscopic Approach, Diagnostic */
"0B9P0ZX" = "1" /* Drainage of Left Pleura, Open Approach, Diagnostic */
"0B9P3ZX" = "1" /* Drainage of Left Pleura, Percutaneous Approach, Diagnostic */
"0B9P4ZX" = "1" /* Drainage of Left Pleura, Percutaneous Endoscopic Approach, Diagnostic */
"0BBC0ZX" = "1" /* Excision of Right Upper Lung Lobe, Open Approach, Diagnostic */
"0BBC3ZX" = "1" /* Excision of Right Upper Lung Lobe, Percutaneous Approach, Diagnostic */
"0BBD0ZX" = "1" /* Excision of Right Middle Lung Lobe, Open Approach, Diagnostic */
"0BBD3ZX" = "1" /* Excision of Right Middle Lung Lobe, Percutaneous Approach, Diagnostic */
"0BBF0ZX" = "1" /* Excision of Right Lower Lung Lobe, Open Approach, Diagnostic */
"0BBF3ZX" = "1" /* Excision of Right Lower Lung Lobe, Percutaneous Approach, Diagnostic */
"0BBG0ZX" = "1" /* Excision of Left Upper Lung Lobe, Open Approach, Diagnostic */
"0BBG3ZX" = "1" /* Excision of Left Upper Lung Lobe, Percutaneous Approach, Diagnostic */
"0BBH0ZX" = "1" /* Excision of Lung Lingula, Open Approach, Diagnostic */
"0BBH3ZX" = "1" /* Excision of Lung Lingula, Percutaneous Approach, Diagnostic */
"0BBJ0ZX" = "1" /* Excision of Left Lower Lung Lobe, Open Approach, Diagnostic */
"0BBJ3ZX" = "1" /* Excision of Left Lower Lung Lobe, Percutaneous Approach, Diagnostic */
"0BBK0ZX" = "1" /* Excision of Right Lung, Open Approach, Diagnostic */
"0BBK3ZX" = "1" /* Excision of Right Lung, Percutaneous Approach, Diagnostic */
"0BBL0ZX" = "1" /* Excision of Left Lung, Open Approach, Diagnostic */
"0BBL3ZX" = "1" /* Excision of Left Lung, Percutaneous Approach, Diagnostic */
"0BBM0ZX" = "1" /* Excision of Bilateral Lungs, Open Approach, Diagnostic */
"0BBM3ZX" = "1" /* Excision of Bilateral Lungs, Percutaneous Approach, Diagnostic */
"0BBN0ZX" = "1" /* Excision of Right Pleura, Open Approach, Diagnostic */
"0BBN3ZX" = "1" /* Excision of Right Pleura, Percutaneous Approach, Diagnostic */
"0BBP0ZX" = "1" /* Excision of Left Pleura, Open Approach, Diagnostic */
"0BBP3ZX" = "1" /* Excision of Left Pleura, Percutaneous Approach, Diagnostic */
"0W990ZX" = "1" /* Drainage of Right Pleural Cavity, Open Approach, Diagnostic */
"0W993ZX" = "1" /* Drainage of Right Pleural Cavity, Percutaneous Approach, Diagnostic */
"0W994ZX" = "1" /* Drainage of Right Pleural Cavity, Percutaneous Endoscopic Approach, Diagnostic */
"0W9B0ZX" = "1" /* Drainage of Left Pleural Cavity, Open Approach, Diagnostic */
"0W9B3ZX" = "1" /* Drainage of Left Pleural Cavity, Percutaneous Approach, Diagnostic */
"0W9B4ZX" = "1" /* Drainage of Left Pleural Cavity, Percutaneous Endoscopic Approach, Diagnostic */
Other = "0"
;

/* Procedure codeset LUNGCIP last updated 160922 for IDC10 v60rev3 */
Value $LUNGCIP
"0BBC4ZZ" = "1" /* Excision of Right Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BBD4ZZ" = "1" /* Excision of Right Middle Lung Lobe, Percutaneous Endoscopic Approach */
"0BBF4ZZ" = "1" /* Excision of Right Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BBG4ZZ" = "1" /* Excision of Left Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BBH4ZZ" = "1" /* Excision of Lung Lingula, Percutaneous Endoscopic Approach */
"0BBJ4ZZ" = "1" /* Excision of Left Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BBK0ZZ" = "1" /* Excision of Right Lung, Open Approach */
"0BBK3ZZ" = "1" /* Excision of Right Lung, Percutaneous Approach */
"0BBK4ZZ" = "1" /* Excision of Right Lung, Percutaneous Endoscopic Approach */
"0BBK7ZZ" = "1" /* Excision of Right Lung, Via Natural or Artificial Opening */
"0BBL0ZZ" = "1" /* Excision of Left Lung, Open Approach */
"0BBL3ZZ" = "1" /* Excision of Left Lung, Percutaneous Approach */
"0BBL4ZZ" = "1" /* Excision of Left Lung, Percutaneous Endoscopic Approach */
"0BBL7ZZ" = "1" /* Excision of Left Lung, Via Natural or Artificial Opening */
"0BTC0ZZ" = "1" /* Resection of Right Upper Lung Lobe, Open Approach */
"0BTC4ZZ" = "1" /* Resection of Right Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BTD0ZZ" = "1" /* Resection of Right Middle Lung Lobe, Open Approach */
"0BTD4ZZ" = "1" /* Resection of Right Middle Lung Lobe, Percutaneous Endoscopic Approach */
"0BTF0ZZ" = "1" /* Resection of Right Lower Lung Lobe, Open Approach */
"0BTF4ZZ" = "1" /* Resection of Right Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BTG0ZZ" = "1" /* Resection of Left Upper Lung Lobe, Open Approach */
"0BTG4ZZ" = "1" /* Resection of Left Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BTH0ZZ" = "1" /* Resection of Lung Lingula, Open Approach */
"0BTH4ZZ" = "1" /* Resection of Lung Lingula, Percutaneous Endoscopic Approach */
"0BTJ0ZZ" = "1" /* Resection of Left Lower Lung Lobe, Open Approach */
"0BTJ4ZZ" = "1" /* Resection of Left Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BTK0ZZ" = "1" /* Resection of Right Lung, Open Approach */
"0BTK4ZZ" = "1" /* Resection of Right Lung, Percutaneous Endoscopic Approach */
"0BTL0ZZ" = "1" /* Resection of Left Lung, Open Approach */
"0BTL4ZZ" = "1" /* Resection of Left Lung, Percutaneous Endoscopic Approach */
"0BTM0ZZ" = "1" /* Resection of Bilateral Lungs, Open Approach */
"0BTM4ZZ" = "1" /* Resection of Bilateral Lungs, Percutaneous Endoscopic Approach */
Other = "0"
;

/* Procedure codeset LUNGTRANSP last updated 160922 for IDC10 v60rev3 */
Value $LUNGTRANSP
"0BYC0Z0" = "1" /* Transplantation of Right Upper Lung Lobe, Allogeneic, Open Approach */
"0BYC0Z1" = "1" /* Transplantation of Right Upper Lung Lobe, Syngeneic, Open Approach */
"0BYC0Z2" = "1" /* Transplantation of Right Upper Lung Lobe, Zooplastic, Open Approach */
"0BYD0Z0" = "1" /* Transplantation of Right Middle Lung Lobe, Allogeneic, Open Approach */
"0BYD0Z1" = "1" /* Transplantation of Right Middle Lung Lobe, Syngeneic, Open Approach */
"0BYD0Z2" = "1" /* Transplantation of Right Middle Lung Lobe, Zooplastic, Open Approach */
"0BYF0Z0" = "1" /* Transplantation of Right Lower Lung Lobe, Allogeneic, Open Approach */
"0BYF0Z1" = "1" /* Transplantation of Right Lower Lung Lobe, Syngeneic, Open Approach */
"0BYF0Z2" = "1" /* Transplantation of Right Lower Lung Lobe, Zooplastic, Open Approach */
"0BYG0Z0" = "1" /* Transplantation of Left Upper Lung Lobe, Allogeneic, Open Approach */
"0BYG0Z1" = "1" /* Transplantation of Left Upper Lung Lobe, Syngeneic, Open Approach */
"0BYG0Z2" = "1" /* Transplantation of Left Upper Lung Lobe, Zooplastic, Open Approach */
"0BYH0Z0" = "1" /* Transplantation of Lung Lingula, Allogeneic, Open Approach */
"0BYH0Z1" = "1" /* Transplantation of Lung Lingula, Syngeneic, Open Approach */
"0BYH0Z2" = "1" /* Transplantation of Lung Lingula, Zooplastic, Open Approach */
"0BYJ0Z0" = "1" /* Transplantation of Left Lower Lung Lobe, Allogeneic, Open Approach */
"0BYJ0Z1" = "1" /* Transplantation of Left Lower Lung Lobe, Syngeneic, Open Approach */
"0BYJ0Z2" = "1" /* Transplantation of Left Lower Lung Lobe, Zooplastic, Open Approach */
"0BYK0Z0" = "1" /* Transplantation of Right Lung, Allogeneic, Open Approach */
"0BYK0Z1" = "1" /* Transplantation of Right Lung, Syngeneic, Open Approach */
"0BYK0Z2" = "1" /* Transplantation of Right Lung, Zooplastic, Open Approach */
"0BYL0Z0" = "1" /* Transplantation of Left Lung, Allogeneic, Open Approach */
"0BYL0Z1" = "1" /* Transplantation of Left Lung, Syngeneic, Open Approach */
"0BYL0Z2" = "1" /* Transplantation of Left Lung, Zooplastic, Open Approach */
"0BYM0Z0" = "1" /* Transplantation of Bilateral Lungs, Allogeneic, Open Approach */
"0BYM0Z1" = "1" /* Transplantation of Bilateral Lungs, Syngeneic, Open Approach */
"0BYM0Z2" = "1" /* Transplantation of Bilateral Lungs, Zooplastic, Open Approach */
Other = "0"
;

/* Diagnosis codeset LW1000G last updated 160922 for IDC10 v60rev3 */
Value $LW1000G
"P0503" = "1" /* Newborn light for gestational age, 750-999 grams */
"P0513" = "1" /* Newborn small for gestational age, 750-999 grams */
"P0703" = "1" /* Extremely low birth weight newborn, 750-999 grams */
Other = "0"
;

/* Diagnosis codeset LW1250G last updated 160922 for IDC10 v60rev3 */
Value $LW1250G
"P0504" = "1" /* Newborn light for gestational age, 1000-1249 grams */
"P0514" = "1" /* Newborn small for gestational age, 1000-1249 grams */
"P0714" = "1" /* Other low birth weight newborn, 1000-1249 grams */
Other = "0"
;

/* Diagnosis codeset LW1500G last updated 160922 for IDC10 v60rev3 */
Value $LW1500G
"P0505" = "1" /* Newborn light for gestational age, 1250-1499 grams */
"P0515" = "1" /* Newborn small for gestational age, 1250-1499 grams */
"P0715" = "1" /* Other low birth weight newborn, 1250-1499 grams */
Other = "0"
;

/* Diagnosis codeset LW1750G last updated 160922 for IDC10 v60rev3 */
Value $LW1750G
"P0506" = "1" /* Newborn light for gestational age, 1500-1749 grams */
"P0516" = "1" /* Newborn small for gestational age, 1500-1749 grams */
"P0716" = "1" /* Other low birth weight newborn, 1500-1749 grams */
Other = "0"
;

/* Diagnosis codeset LW2000G last updated 160922 for IDC10 v60rev3 */
Value $LW2000G
"P0507" = "1" /* Newborn light for gestational age, 1750-1999 grams */
"P0517" = "1" /* Newborn small for gestational age, 1750-1999 grams */
"P0717" = "1" /* Other low birth weight newborn, 1750-1999 grams */
Other = "0"
;

/* Diagnosis codeset LW2500G last updated 160922 for IDC10 v60rev3 */
Value $LW2500G
"P0508" = "1" /* Newborn light for gestational age, 2000-2499 grams */
"P0518" = "1" /* Newborn small for gestational age, 2000-2499 grams */
"P0718" = "1" /* Other low birth weight newborn, 2000-2499 grams */
Other = "0"
;

/* Diagnosis codeset LW500G last updated 160922 for IDC10 v60rev3 */
Value $LW500G
"P0501" = "1" /* Newborn light for gestational age, less than 500 grams */
"P0511" = "1" /* Newborn small for gestational age, less than 500 grams */
"P0701" = "1" /* Extremely low birth weight newborn, less than 500 grams */
Other = "0"
;

/* Diagnosis codeset LW750G last updated 160922 for IDC10 v60rev3 */
Value $LW750G
"P0502" = "1" /* Newborn light for gestational age, 500-749 grams */
"P0512" = "1" /* Newborn small for gestational age, 500-749 grams */
"P0702" = "1" /* Extremely low birth weight newborn, 500-749 grams */
Other = "0"
;

/* Procedure codeset MECHVCD last updated 160922 for IDC10 v60rev3 */
Value $MECHVCD
"5A1935Z" = "1" /* Respiratory Ventilation, Less than 24 Consecutive Hours */
"5A1945Z" = "1" /* Respiratory Ventilation, 24-96 Consecutive Hours */
"5A1955Z" = "1" /* Respiratory Ventilation, Greater than 96 Consecutive Hours */
Other = "0"
;

/* Diagnosis codeset NEOMTDX last updated 160922 for IDC10 v60rev3 */
Value $NEOMTDX
"Q000" = "1" /* Anencephaly */
"Q001" = "1" /* Craniorachischisis */
"Q002" = "1" /* Iniencephaly */
"Q6111" = "1" /* Cystic dilatation of collecting ducts */
"Q6119" = "1" /* Other polycystic kidney, infantile type */
"Q910" = "1" /* Trisomy 18, nonmosaicism (meiotic nondisjunction) */
"Q911" = "1" /* Trisomy 18, mosaicism (mitotic nondisjunction) */
"Q912" = "1" /* Trisomy 18, translocation */
"Q913" = "1" /* Trisomy 18, unspecified */
"Q914" = "1" /* Trisomy 13, nonmosaicism (meiotic nondisjunction) */
"Q915" = "1" /* Trisomy 13, mosaicism (mitotic nondisjunction) */
"Q916" = "1" /* Trisomy 13, translocation */
"Q917" = "1" /* Trisomy 13, unspecified */
Other = "0"
;

/* Diagnosis codeset NEUROMD last updated 160922 for IDC10 v60rev3 */
Value $NEUROMD
"G610" = "1" /* Guillain-Barre syndrome */
"G7000" = "1" /* Myasthenia gravis without (acute) exacerbation */
"G7001" = "1" /* Myasthenia gravis with (acute) exacerbation */
"G701" = "1" /* Toxic myoneural disorders */
"G702" = "1" /* Congenital and developmental myasthenia */
"G7080" = "1" /* Lambert-Eaton syndrome, unspecified */
"G7081" = "1" /* Lambert-Eaton syndrome in disease classified elsewhere */
"G7089" = "1" /* Other specified myoneural disorders */
"G709" = "1" /* Myoneural disorder, unspecified */
"G710" = "1" /* Muscular dystrophy */
"G7111" = "1" /* Myotonic muscular dystrophy */
"G7112" = "1" /* Myotonia congenita */
"G7113" = "1" /* Myotonic chondrodystrophy */
"G7119" = "1" /* Other specified myotonic disorders */
"G712" = "1" /* Congenital myopathies */
"G713" = "1" /* Mitochondrial myopathy, not elsewhere classified */
"G718" = "1" /* Other primary disorders of muscles */
"G719" = "1" /* Primary disorder of muscle, unspecified */
"G720" = "1" /* Drug-induced myopathy */
"G721" = "1" /* Alcoholic myopathy */
"G722" = "1" /* Myopathy due to other toxic agents */
"G723" = "1" /* Periodic paralysis */
"G7241" = "1" /* Inclusion body myositis [IBM] */
"G7249" = "1" /* Other inflammatory and immune myopathies, not elsewhere classified */
"G7281" = "1" /* Critical illness myopathy */
"G7289" = "1" /* Other specified myopathies */
"G729" = "1" /* Myopathy, unspecified */
"G731" = "1" /* Lambert-Eaton syndrome in neoplastic disease */
"G733" = "1" /* Myasthenic syndromes in other diseases classified elsewhere */
"G737" = "1" /* Myopathy in diseases classified elsewhere */
"M0540" = "1" /* Rheumatoid myopathy with rheumatoid arthritis of unspecified site */
"M05411" = "1" /* Rheumatoid myopathy with rheumatoid arthritis of right shoulder */
"M05412" = "1" /* Rheumatoid myopathy with rheumatoid arthritis of left shoulder */
"M05419" = "1" /* Rheumatoid myopathy with rheumatoid arthritis of unspecified shoulder */
"M05421" = "1" /* Rheumatoid myopathy with rheumatoid arthritis of right elbow */
"M05422" = "1" /* Rheumatoid myopathy with rheumatoid arthritis of left elbow */
"M05429" = "1" /* Rheumatoid myopathy with rheumatoid arthritis of unspecified elbow */
"M05431" = "1" /* Rheumatoid myopathy with rheumatoid arthritis of right wrist */
"M05432" = "1" /* Rheumatoid myopathy with rheumatoid arthritis of left wrist */
"M05439" = "1" /* Rheumatoid myopathy with rheumatoid arthritis of unspecified wrist */
"M05441" = "1" /* Rheumatoid myopathy with rheumatoid arthritis of right hand */
"M05442" = "1" /* Rheumatoid myopathy with rheumatoid arthritis of left hand */
"M05449" = "1" /* Rheumatoid myopathy with rheumatoid arthritis of unspecified hand */
"M05451" = "1" /* Rheumatoid myopathy with rheumatoid arthritis of right hip */
"M05452" = "1" /* Rheumatoid myopathy with rheumatoid arthritis of left hip */
"M05459" = "1" /* Rheumatoid myopathy with rheumatoid arthritis of unspecified hip */
"M05461" = "1" /* Rheumatoid myopathy with rheumatoid arthritis of right knee */
"M05462" = "1" /* Rheumatoid myopathy with rheumatoid arthritis of left knee */
"M05469" = "1" /* Rheumatoid myopathy with rheumatoid arthritis of unspecified knee */
"M05471" = "1" /* Rheumatoid myopathy with rheumatoid arthritis of right ankle and foot */
"M05472" = "1" /* Rheumatoid myopathy with rheumatoid arthritis of left ankle and foot */
"M05479" = "1" /* Rheumatoid myopathy with rheumatoid arthritis of unspecified ankle and foot */
"M0549" = "1" /* Rheumatoid myopathy with rheumatoid arthritis of multiple sites */
"M3302" = "1" /* Juvenile dermatopolymyositis with myopathy */
"M3312" = "1" /* Other dermatopolymyositis with myopathy */
"M3322" = "1" /* Polymyositis with myopathy */
"M3392" = "1" /* Dermatopolymyositis, unspecified with myopathy */
"M3482" = "1" /* Systemic sclerosis with myopathy */
"M3503" = "1" /* Sicca syndrome with myopathy */
Other = "0"
;

/* Diagnosis codeset OSTEOID last updated 160922 for IDC10 v60rev3 */
Value $OSTEOID
"Q780" = "1" /* Osteogenesis imperfecta */
Other = "0"
;

/* Diagnosis codeset PLEURAD last updated 160922 for IDC10 v60rev3 */
Value $PLEURAD
"A150" = "1" /* Tuberculosis of lung */
"A156" = "1" /* Tuberculous pleurisy */
"C782" = "1" /* Secondary malignant neoplasm of pleura */
"J90" = "1" /* Pleural effusion, not elsewhere classified */
"J910" = "1" /* Malignant pleural effusion */
"J918" = "1" /* Pleural effusion in other conditions classified elsewhere */
"J940" = "1" /* Chylous effusion */
"J942" = "1" /* Hemothorax */
"J948" = "1" /* Other specified pleural conditions */
Other = "0"
;

/* Procedure codeset PR9604P last updated 160922 for IDC10 v60rev3 */
Value $PR9604P
"0BH13EZ" = "1" /* Insertion of Endotracheal Airway into Trachea, Percutaneous Approach */
"0BH17EZ" = "1" /* Insertion of Endotracheal Airway into Trachea, Via Natural or Artificial Opening */
"0BH18EZ" = "1" /* Insertion of Endotracheal Airway into Trachea, Via Natural or Artificial Opening Endoscopic */
Other = "0"
;

/* Procedure codeset PR9671P last updated 160922 for IDC10 v60rev3 */
Value $PR9671P
"5A1945Z" = "1" /* Respiratory Ventilation, 24-96 Consecutive Hours */
Other = "0"
;

/* Procedure codeset PR9672P last updated 160922 for IDC10 v60rev3 */
Value $PR9672P
"5A1955Z" = "1" /* Respiratory Ventilation, Greater than 96 Consecutive Hours */
Other = "0"
;

/* Procedure codeset PRESOPP last updated 160922 for IDC10 v60rev3 */
Value $PRESOPP
"0D11074" = "1" /* Bypass Upper Esophagus to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D11076" = "1" /* Bypass Upper Esophagus to Stomach with Autologous Tissue Substitute, Open Approach */
"0D11079" = "1" /* Bypass Upper Esophagus to Duodenum with Autologous Tissue Substitute, Open Approach */
"0D1107A" = "1" /* Bypass Upper Esophagus to Jejunum with Autologous Tissue Substitute, Open Approach */
"0D1107B" = "1" /* Bypass Upper Esophagus to Ileum with Autologous Tissue Substitute, Open Approach */
"0D110J4" = "1" /* Bypass Upper Esophagus to Cutaneous with Synthetic Substitute, Open Approach */
"0D110J6" = "1" /* Bypass Upper Esophagus to Stomach with Synthetic Substitute, Open Approach */
"0D110J9" = "1" /* Bypass Upper Esophagus to Duodenum with Synthetic Substitute, Open Approach */
"0D110JA" = "1" /* Bypass Upper Esophagus to Jejunum with Synthetic Substitute, Open Approach */
"0D110JB" = "1" /* Bypass Upper Esophagus to Ileum with Synthetic Substitute, Open Approach */
"0D110K4" = "1" /* Bypass Upper Esophagus to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D110K6" = "1" /* Bypass Upper Esophagus to Stomach with Nonautologous Tissue Substitute, Open Approach */
"0D110K9" = "1" /* Bypass Upper Esophagus to Duodenum with Nonautologous Tissue Substitute, Open Approach */
"0D110KA" = "1" /* Bypass Upper Esophagus to Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0D110KB" = "1" /* Bypass Upper Esophagus to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D110Z4" = "1" /* Bypass Upper Esophagus to Cutaneous, Open Approach */
"0D110Z6" = "1" /* Bypass Upper Esophagus to Stomach, Open Approach */
"0D110Z9" = "1" /* Bypass Upper Esophagus to Duodenum, Open Approach */
"0D110ZA" = "1" /* Bypass Upper Esophagus to Jejunum, Open Approach */
"0D110ZB" = "1" /* Bypass Upper Esophagus to Ileum, Open Approach */
"0D113J4" = "1" /* Bypass Upper Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D11474" = "1" /* Bypass Upper Esophagus to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D11476" = "1" /* Bypass Upper Esophagus to Stomach with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D11479" = "1" /* Bypass Upper Esophagus to Duodenum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1147A" = "1" /* Bypass Upper Esophagus to Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1147B" = "1" /* Bypass Upper Esophagus to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D114J4" = "1" /* Bypass Upper Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D114J6" = "1" /* Bypass Upper Esophagus to Stomach with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D114J9" = "1" /* Bypass Upper Esophagus to Duodenum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D114JA" = "1" /* Bypass Upper Esophagus to Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D114JB" = "1" /* Bypass Upper Esophagus to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D114K4" = "1" /* Bypass Upper Esophagus to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D114K6" = "1" /* Bypass Upper Esophagus to Stomach with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D114K9" = "1" /* Bypass Upper Esophagus to Duodenum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D114KA" = "1" /* Bypass Upper Esophagus to Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D114KB" = "1" /* Bypass Upper Esophagus to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D114Z4" = "1" /* Bypass Upper Esophagus to Cutaneous, Percutaneous Endoscopic Approach */
"0D114Z6" = "1" /* Bypass Upper Esophagus to Stomach, Percutaneous Endoscopic Approach */
"0D114Z9" = "1" /* Bypass Upper Esophagus to Duodenum, Percutaneous Endoscopic Approach */
"0D114ZA" = "1" /* Bypass Upper Esophagus to Jejunum, Percutaneous Endoscopic Approach */
"0D114ZB" = "1" /* Bypass Upper Esophagus to Ileum, Percutaneous Endoscopic Approach */
"0D11874" = "1" /* Bypass Upper Esophagus to Cutaneous with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D11876" = "1" /* Bypass Upper Esophagus to Stomach with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D11879" = "1" /* Bypass Upper Esophagus to Duodenum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1187A" = "1" /* Bypass Upper Esophagus to Jejunum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1187B" = "1" /* Bypass Upper Esophagus to Ileum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118J4" = "1" /* Bypass Upper Esophagus to Cutaneous with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118J6" = "1" /* Bypass Upper Esophagus to Stomach with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118J9" = "1" /* Bypass Upper Esophagus to Duodenum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118JA" = "1" /* Bypass Upper Esophagus to Jejunum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118JB" = "1" /* Bypass Upper Esophagus to Ileum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118K4" = "1" /* Bypass Upper Esophagus to Cutaneous with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118K6" = "1" /* Bypass Upper Esophagus to Stomach with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118K9" = "1" /* Bypass Upper Esophagus to Duodenum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118KA" = "1" /* Bypass Upper Esophagus to Jejunum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118KB" = "1" /* Bypass Upper Esophagus to Ileum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118Z4" = "1" /* Bypass Upper Esophagus to Cutaneous, Via Natural or Artificial Opening Endoscopic */
"0D118Z6" = "1" /* Bypass Upper Esophagus to Stomach, Via Natural or Artificial Opening Endoscopic */
"0D118Z9" = "1" /* Bypass Upper Esophagus to Duodenum, Via Natural or Artificial Opening Endoscopic */
"0D118ZA" = "1" /* Bypass Upper Esophagus to Jejunum, Via Natural or Artificial Opening Endoscopic */
"0D118ZB" = "1" /* Bypass Upper Esophagus to Ileum, Via Natural or Artificial Opening Endoscopic */
"0D12074" = "1" /* Bypass Middle Esophagus to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D12076" = "1" /* Bypass Middle Esophagus to Stomach with Autologous Tissue Substitute, Open Approach */
"0D12079" = "1" /* Bypass Middle Esophagus to Duodenum with Autologous Tissue Substitute, Open Approach */
"0D1207A" = "1" /* Bypass Middle Esophagus to Jejunum with Autologous Tissue Substitute, Open Approach */
"0D1207B" = "1" /* Bypass Middle Esophagus to Ileum with Autologous Tissue Substitute, Open Approach */
"0D120J4" = "1" /* Bypass Middle Esophagus to Cutaneous with Synthetic Substitute, Open Approach */
"0D120J6" = "1" /* Bypass Middle Esophagus to Stomach with Synthetic Substitute, Open Approach */
"0D120J9" = "1" /* Bypass Middle Esophagus to Duodenum with Synthetic Substitute, Open Approach */
"0D120JA" = "1" /* Bypass Middle Esophagus to Jejunum with Synthetic Substitute, Open Approach */
"0D120JB" = "1" /* Bypass Middle Esophagus to Ileum with Synthetic Substitute, Open Approach */
"0D120K4" = "1" /* Bypass Middle Esophagus to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D120K6" = "1" /* Bypass Middle Esophagus to Stomach with Nonautologous Tissue Substitute, Open Approach */
"0D120K9" = "1" /* Bypass Middle Esophagus to Duodenum with Nonautologous Tissue Substitute, Open Approach */
"0D120KA" = "1" /* Bypass Middle Esophagus to Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0D120KB" = "1" /* Bypass Middle Esophagus to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D120Z4" = "1" /* Bypass Middle Esophagus to Cutaneous, Open Approach */
"0D120Z6" = "1" /* Bypass Middle Esophagus to Stomach, Open Approach */
"0D120Z9" = "1" /* Bypass Middle Esophagus to Duodenum, Open Approach */
"0D120ZA" = "1" /* Bypass Middle Esophagus to Jejunum, Open Approach */
"0D120ZB" = "1" /* Bypass Middle Esophagus to Ileum, Open Approach */
"0D123J4" = "1" /* Bypass Middle Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D12474" = "1" /* Bypass Middle Esophagus to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D12476" = "1" /* Bypass Middle Esophagus to Stomach with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D12479" = "1" /* Bypass Middle Esophagus to Duodenum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1247A" = "1" /* Bypass Middle Esophagus to Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1247B" = "1" /* Bypass Middle Esophagus to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D124J4" = "1" /* Bypass Middle Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D124J6" = "1" /* Bypass Middle Esophagus to Stomach with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D124J9" = "1" /* Bypass Middle Esophagus to Duodenum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D124JA" = "1" /* Bypass Middle Esophagus to Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D124JB" = "1" /* Bypass Middle Esophagus to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D124K4" = "1" /* Bypass Middle Esophagus to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D124K6" = "1" /* Bypass Middle Esophagus to Stomach with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D124K9" = "1" /* Bypass Middle Esophagus to Duodenum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D124KA" = "1" /* Bypass Middle Esophagus to Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D124KB" = "1" /* Bypass Middle Esophagus to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D124Z4" = "1" /* Bypass Middle Esophagus to Cutaneous, Percutaneous Endoscopic Approach */
"0D124Z6" = "1" /* Bypass Middle Esophagus to Stomach, Percutaneous Endoscopic Approach */
"0D124Z9" = "1" /* Bypass Middle Esophagus to Duodenum, Percutaneous Endoscopic Approach */
"0D124ZA" = "1" /* Bypass Middle Esophagus to Jejunum, Percutaneous Endoscopic Approach */
"0D124ZB" = "1" /* Bypass Middle Esophagus to Ileum, Percutaneous Endoscopic Approach */
"0D12874" = "1" /* Bypass Middle Esophagus to Cutaneous with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D12876" = "1" /* Bypass Middle Esophagus to Stomach with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D12879" = "1" /* Bypass Middle Esophagus to Duodenum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1287A" = "1" /* Bypass Middle Esophagus to Jejunum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1287B" = "1" /* Bypass Middle Esophagus to Ileum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128J4" = "1" /* Bypass Middle Esophagus to Cutaneous with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128J6" = "1" /* Bypass Middle Esophagus to Stomach with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128J9" = "1" /* Bypass Middle Esophagus to Duodenum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128JA" = "1" /* Bypass Middle Esophagus to Jejunum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128JB" = "1" /* Bypass Middle Esophagus to Ileum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128K4" = "1" /* Bypass Middle Esophagus to Cutaneous with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128K6" = "1" /* Bypass Middle Esophagus to Stomach with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128K9" = "1" /* Bypass Middle Esophagus to Duodenum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128KA" = "1" /* Bypass Middle Esophagus to Jejunum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128KB" = "1" /* Bypass Middle Esophagus to Ileum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128Z4" = "1" /* Bypass Middle Esophagus to Cutaneous, Via Natural or Artificial Opening Endoscopic */
"0D128Z6" = "1" /* Bypass Middle Esophagus to Stomach, Via Natural or Artificial Opening Endoscopic */
"0D128Z9" = "1" /* Bypass Middle Esophagus to Duodenum, Via Natural or Artificial Opening Endoscopic */
"0D128ZA" = "1" /* Bypass Middle Esophagus to Jejunum, Via Natural or Artificial Opening Endoscopic */
"0D128ZB" = "1" /* Bypass Middle Esophagus to Ileum, Via Natural or Artificial Opening Endoscopic */
"0D13074" = "1" /* Bypass Lower Esophagus to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D13076" = "1" /* Bypass Lower Esophagus to Stomach with Autologous Tissue Substitute, Open Approach */
"0D13079" = "1" /* Bypass Lower Esophagus to Duodenum with Autologous Tissue Substitute, Open Approach */
"0D1307A" = "1" /* Bypass Lower Esophagus to Jejunum with Autologous Tissue Substitute, Open Approach */
"0D1307B" = "1" /* Bypass Lower Esophagus to Ileum with Autologous Tissue Substitute, Open Approach */
"0D130J4" = "1" /* Bypass Lower Esophagus to Cutaneous with Synthetic Substitute, Open Approach */
"0D130J6" = "1" /* Bypass Lower Esophagus to Stomach with Synthetic Substitute, Open Approach */
"0D130J9" = "1" /* Bypass Lower Esophagus to Duodenum with Synthetic Substitute, Open Approach */
"0D130JA" = "1" /* Bypass Lower Esophagus to Jejunum with Synthetic Substitute, Open Approach */
"0D130JB" = "1" /* Bypass Lower Esophagus to Ileum with Synthetic Substitute, Open Approach */
"0D130K4" = "1" /* Bypass Lower Esophagus to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D130K6" = "1" /* Bypass Lower Esophagus to Stomach with Nonautologous Tissue Substitute, Open Approach */
"0D130K9" = "1" /* Bypass Lower Esophagus to Duodenum with Nonautologous Tissue Substitute, Open Approach */
"0D130KA" = "1" /* Bypass Lower Esophagus to Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0D130KB" = "1" /* Bypass Lower Esophagus to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D130Z4" = "1" /* Bypass Lower Esophagus to Cutaneous, Open Approach */
"0D130Z6" = "1" /* Bypass Lower Esophagus to Stomach, Open Approach */
"0D130Z9" = "1" /* Bypass Lower Esophagus to Duodenum, Open Approach */
"0D130ZA" = "1" /* Bypass Lower Esophagus to Jejunum, Open Approach */
"0D130ZB" = "1" /* Bypass Lower Esophagus to Ileum, Open Approach */
"0D133J4" = "1" /* Bypass Lower Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D13474" = "1" /* Bypass Lower Esophagus to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D13476" = "1" /* Bypass Lower Esophagus to Stomach with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D13479" = "1" /* Bypass Lower Esophagus to Duodenum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1347A" = "1" /* Bypass Lower Esophagus to Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1347B" = "1" /* Bypass Lower Esophagus to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134J4" = "1" /* Bypass Lower Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D134J6" = "1" /* Bypass Lower Esophagus to Stomach with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D134J9" = "1" /* Bypass Lower Esophagus to Duodenum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D134JA" = "1" /* Bypass Lower Esophagus to Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D134JB" = "1" /* Bypass Lower Esophagus to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D134K4" = "1" /* Bypass Lower Esophagus to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134K6" = "1" /* Bypass Lower Esophagus to Stomach with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134K9" = "1" /* Bypass Lower Esophagus to Duodenum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134KA" = "1" /* Bypass Lower Esophagus to Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134KB" = "1" /* Bypass Lower Esophagus to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134Z4" = "1" /* Bypass Lower Esophagus to Cutaneous, Percutaneous Endoscopic Approach */
"0D134Z6" = "1" /* Bypass Lower Esophagus to Stomach, Percutaneous Endoscopic Approach */
"0D134Z9" = "1" /* Bypass Lower Esophagus to Duodenum, Percutaneous Endoscopic Approach */
"0D134ZA" = "1" /* Bypass Lower Esophagus to Jejunum, Percutaneous Endoscopic Approach */
"0D134ZB" = "1" /* Bypass Lower Esophagus to Ileum, Percutaneous Endoscopic Approach */
"0D13874" = "1" /* Bypass Lower Esophagus to Cutaneous with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D13876" = "1" /* Bypass Lower Esophagus to Stomach with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D13879" = "1" /* Bypass Lower Esophagus to Duodenum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1387A" = "1" /* Bypass Lower Esophagus to Jejunum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1387B" = "1" /* Bypass Lower Esophagus to Ileum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138J4" = "1" /* Bypass Lower Esophagus to Cutaneous with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138J6" = "1" /* Bypass Lower Esophagus to Stomach with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138J9" = "1" /* Bypass Lower Esophagus to Duodenum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138JA" = "1" /* Bypass Lower Esophagus to Jejunum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138JB" = "1" /* Bypass Lower Esophagus to Ileum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138K4" = "1" /* Bypass Lower Esophagus to Cutaneous with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138K6" = "1" /* Bypass Lower Esophagus to Stomach with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138K9" = "1" /* Bypass Lower Esophagus to Duodenum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138KA" = "1" /* Bypass Lower Esophagus to Jejunum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138KB" = "1" /* Bypass Lower Esophagus to Ileum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138Z4" = "1" /* Bypass Lower Esophagus to Cutaneous, Via Natural or Artificial Opening Endoscopic */
"0D138Z6" = "1" /* Bypass Lower Esophagus to Stomach, Via Natural or Artificial Opening Endoscopic */
"0D138Z9" = "1" /* Bypass Lower Esophagus to Duodenum, Via Natural or Artificial Opening Endoscopic */
"0D138ZA" = "1" /* Bypass Lower Esophagus to Jejunum, Via Natural or Artificial Opening Endoscopic */
"0D138ZB" = "1" /* Bypass Lower Esophagus to Ileum, Via Natural or Artificial Opening Endoscopic */
"0D15074" = "1" /* Bypass Esophagus to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D15076" = "1" /* Bypass Esophagus to Stomach with Autologous Tissue Substitute, Open Approach */
"0D15079" = "1" /* Bypass Esophagus to Duodenum with Autologous Tissue Substitute, Open Approach */
"0D1507A" = "1" /* Bypass Esophagus to Jejunum with Autologous Tissue Substitute, Open Approach */
"0D1507B" = "1" /* Bypass Esophagus to Ileum with Autologous Tissue Substitute, Open Approach */
"0D150J4" = "1" /* Bypass Esophagus to Cutaneous with Synthetic Substitute, Open Approach */
"0D150J6" = "1" /* Bypass Esophagus to Stomach with Synthetic Substitute, Open Approach */
"0D150J9" = "1" /* Bypass Esophagus to Duodenum with Synthetic Substitute, Open Approach */
"0D150JA" = "1" /* Bypass Esophagus to Jejunum with Synthetic Substitute, Open Approach */
"0D150JB" = "1" /* Bypass Esophagus to Ileum with Synthetic Substitute, Open Approach */
"0D150K4" = "1" /* Bypass Esophagus to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D150K6" = "1" /* Bypass Esophagus to Stomach with Nonautologous Tissue Substitute, Open Approach */
"0D150K9" = "1" /* Bypass Esophagus to Duodenum with Nonautologous Tissue Substitute, Open Approach */
"0D150KA" = "1" /* Bypass Esophagus to Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0D150KB" = "1" /* Bypass Esophagus to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D150Z4" = "1" /* Bypass Esophagus to Cutaneous, Open Approach */
"0D150Z6" = "1" /* Bypass Esophagus to Stomach, Open Approach */
"0D150Z9" = "1" /* Bypass Esophagus to Duodenum, Open Approach */
"0D150ZA" = "1" /* Bypass Esophagus to Jejunum, Open Approach */
"0D150ZB" = "1" /* Bypass Esophagus to Ileum, Open Approach */
"0D153J4" = "1" /* Bypass Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D15474" = "1" /* Bypass Esophagus to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D15476" = "1" /* Bypass Esophagus to Stomach with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D15479" = "1" /* Bypass Esophagus to Duodenum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1547A" = "1" /* Bypass Esophagus to Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1547B" = "1" /* Bypass Esophagus to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D154J4" = "1" /* Bypass Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D154J6" = "1" /* Bypass Esophagus to Stomach with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D154J9" = "1" /* Bypass Esophagus to Duodenum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D154JA" = "1" /* Bypass Esophagus to Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D154JB" = "1" /* Bypass Esophagus to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D154K4" = "1" /* Bypass Esophagus to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D154K6" = "1" /* Bypass Esophagus to Stomach with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D154K9" = "1" /* Bypass Esophagus to Duodenum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D154KA" = "1" /* Bypass Esophagus to Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D154KB" = "1" /* Bypass Esophagus to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D154Z4" = "1" /* Bypass Esophagus to Cutaneous, Percutaneous Endoscopic Approach */
"0D154Z6" = "1" /* Bypass Esophagus to Stomach, Percutaneous Endoscopic Approach */
"0D154Z9" = "1" /* Bypass Esophagus to Duodenum, Percutaneous Endoscopic Approach */
"0D154ZA" = "1" /* Bypass Esophagus to Jejunum, Percutaneous Endoscopic Approach */
"0D154ZB" = "1" /* Bypass Esophagus to Ileum, Percutaneous Endoscopic Approach */
"0D15874" = "1" /* Bypass Esophagus to Cutaneous with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D15876" = "1" /* Bypass Esophagus to Stomach with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D15879" = "1" /* Bypass Esophagus to Duodenum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1587A" = "1" /* Bypass Esophagus to Jejunum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1587B" = "1" /* Bypass Esophagus to Ileum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158J4" = "1" /* Bypass Esophagus to Cutaneous with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158J6" = "1" /* Bypass Esophagus to Stomach with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158J9" = "1" /* Bypass Esophagus to Duodenum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158JA" = "1" /* Bypass Esophagus to Jejunum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158JB" = "1" /* Bypass Esophagus to Ileum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158K4" = "1" /* Bypass Esophagus to Cutaneous with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158K6" = "1" /* Bypass Esophagus to Stomach with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158K9" = "1" /* Bypass Esophagus to Duodenum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158KA" = "1" /* Bypass Esophagus to Jejunum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158KB" = "1" /* Bypass Esophagus to Ileum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158Z4" = "1" /* Bypass Esophagus to Cutaneous, Via Natural or Artificial Opening Endoscopic */
"0D158Z6" = "1" /* Bypass Esophagus to Stomach, Via Natural or Artificial Opening Endoscopic */
"0D158Z9" = "1" /* Bypass Esophagus to Duodenum, Via Natural or Artificial Opening Endoscopic */
"0D158ZA" = "1" /* Bypass Esophagus to Jejunum, Via Natural or Artificial Opening Endoscopic */
"0D158ZB" = "1" /* Bypass Esophagus to Ileum, Via Natural or Artificial Opening Endoscopic */
"0DB10ZZ" = "1" /* Excision of Upper Esophagus, Open Approach */
"0DB13ZZ" = "1" /* Excision of Upper Esophagus, Percutaneous Approach */
"0DB17ZZ" = "1" /* Excision of Upper Esophagus, Via Natural or Artificial Opening */
"0DB20ZZ" = "1" /* Excision of Middle Esophagus, Open Approach */
"0DB23ZZ" = "1" /* Excision of Middle Esophagus, Percutaneous Approach */
"0DB27ZZ" = "1" /* Excision of Middle Esophagus, Via Natural or Artificial Opening */
"0DB30ZZ" = "1" /* Excision of Lower Esophagus, Open Approach */
"0DB33ZZ" = "1" /* Excision of Lower Esophagus, Percutaneous Approach */
"0DB37ZZ" = "1" /* Excision of Lower Esophagus, Via Natural or Artificial Opening */
"0DB50ZZ" = "1" /* Excision of Esophagus, Open Approach */
"0DB53ZZ" = "1" /* Excision of Esophagus, Percutaneous Approach */
"0DB57ZZ" = "1" /* Excision of Esophagus, Via Natural or Artificial Opening */
"0DT10ZZ" = "1" /* Resection of Upper Esophagus, Open Approach */
"0DT14ZZ" = "1" /* Resection of Upper Esophagus, Percutaneous Endoscopic Approach */
"0DT17ZZ" = "1" /* Resection of Upper Esophagus, Via Natural or Artificial Opening */
"0DT18ZZ" = "1" /* Resection of Upper Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DT20ZZ" = "1" /* Resection of Middle Esophagus, Open Approach */
"0DT24ZZ" = "1" /* Resection of Middle Esophagus, Percutaneous Endoscopic Approach */
"0DT27ZZ" = "1" /* Resection of Middle Esophagus, Via Natural or Artificial Opening */
"0DT28ZZ" = "1" /* Resection of Middle Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DT30ZZ" = "1" /* Resection of Lower Esophagus, Open Approach */
"0DT34ZZ" = "1" /* Resection of Lower Esophagus, Percutaneous Endoscopic Approach */
"0DT37ZZ" = "1" /* Resection of Lower Esophagus, Via Natural or Artificial Opening */
"0DT38ZZ" = "1" /* Resection of Lower Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DT50ZZ" = "1" /* Resection of Esophagus, Open Approach */
"0DT54ZZ" = "1" /* Resection of Esophagus, Percutaneous Endoscopic Approach */
"0DT57ZZ" = "1" /* Resection of Esophagus, Via Natural or Artificial Opening */
"0DT58ZZ" = "1" /* Resection of Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DX60Z5" = "1" /* Transfer Stomach to Esophagus, Open Approach */
"0DX64Z5" = "1" /* Transfer Stomach to Esophagus, Percutaneous Endoscopic Approach */
"0DX80Z5" = "1" /* Transfer Small Intestine to Esophagus, Open Approach */
"0DX84Z5" = "1" /* Transfer Small Intestine to Esophagus, Percutaneous Endoscopic Approach */
"0DXE0Z5" = "1" /* Transfer Large Intestine to Esophagus, Open Approach */
"0DXE4Z5" = "1" /* Transfer Large Intestine to Esophagus, Percutaneous Endoscopic Approach */
Other = "0"
;

/* Diagnosis codeset PRETEID last updated 160922 for IDC10 v60rev3 */
Value $PRETEID
"P0700" = "1" /* Extremely low birth weight newborn, unspecified weight */
"P0701" = "1" /* Extremely low birth weight newborn, less than 500 grams */
"P0702" = "1" /* Extremely low birth weight newborn, 500-749 grams */
"P0703" = "1" /* Extremely low birth weight newborn, 750-999 grams */
"P0710" = "1" /* Other low birth weight newborn, unspecified weight */
"P0714" = "1" /* Other low birth weight newborn, 1000-1249 grams */
"P0715" = "1" /* Other low birth weight newborn, 1250-1499 grams */
"P0716" = "1" /* Other low birth weight newborn, 1500-1749 grams */
"P0717" = "1" /* Other low birth weight newborn, 1750-1999 grams */
Other = "0"
;

/* Procedure codeset RECLOIP last updated 160922 for IDC10 v60rev3 */
Value $RECLOIP
"0JB80ZX" = "1" /* Excision of Abdomen Subcutaneous Tissue and Fascia, Open Approach, Diagnostic */
"0JB80ZZ" = "1" /* Excision of Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JB83ZX" = "1" /* Excision of Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach, Diagnostic */
"0JB83ZZ" = "1" /* Excision of Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JBC0ZX" = "1" /* Excision of PELVIC Subcutaneous Tissue and Fascia, Open Approach, Diagnostic */
"0JBC0ZZ" = "1" /* Excision of PELVIC Subcutaneous Tissue and Fascia, Open Approach */
"0JBC3ZX" = "1" /* Excision of PELVIC Subcutaneous Tissue and Fascia, Percutaneous Approach, Diagnostic */
"0JBC3ZZ" = "1" /* Excision of PELVIC Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JJT0ZZ" = "1" /* Inspection of Trunk Subcutaneous Tissue and Fascia, Open Approach */
"0JJT3ZZ" = "1" /* Inspection of Trunk Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JQ80ZZ" = "1" /* Repair Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JQ83ZZ" = "1" /* Repair Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JQC0ZZ" = "1" /* Repair PELVIC Subcutaneous Tissue and Fascia, Open Approach */
"0JQC3ZZ" = "1" /* Repair PELVIC Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JR807Z" = "1" /* Replacement of Abdomen Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JR80JZ" = "1" /* Replacement of Abdomen Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JR80KZ" = "1" /* Replacement of Abdomen Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JR837Z" = "1" /* Replacement of Abdomen Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JR83JZ" = "1" /* Replacement of Abdomen Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JR83KZ" = "1" /* Replacement of Abdomen Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JRC07Z" = "1" /* Replacement of PELVIC Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JRC0JZ" = "1" /* Replacement of PELVIC Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JRC0KZ" = "1" /* Replacement of PELVIC Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JRC37Z" = "1" /* Replacement of PELVIC Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JRC3JZ" = "1" /* Replacement of PELVIC Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JRC3KZ" = "1" /* Replacement of PELVIC Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JU807Z" = "1" /* Supplement of Abdomen Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JU80JZ" = "1" /* Supplement of Abdomen Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JU80KZ" = "1" /* Supplement of Abdomen Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JU837Z" = "1" /* Supplement of Abdomen Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JU83JZ" = "1" /* Supplement of Abdomen Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JU83KZ" = "1" /* Supplement of Abdomen Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JUC07Z" = "1" /* Supplement of PELVIC Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JUC0JZ" = "1" /* Supplement of PELVIC Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JUC0KZ" = "1" /* Supplement of PELVIC Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JUC37Z" = "1" /* Supplement of PELVIC Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JUC3JZ" = "1" /* Supplement of PELVIC Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JUC3KZ" = "1" /* Supplement of PELVIC Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0KBK0ZX" = "1" /* Excision of Right Abdominal Muscle Muscle, Open Approach, Diagnostic */
"0KBK0ZZ" = "1" /* Excision of Right Abdominal Muscle Muscle, Open Approach */
"0KBK3ZX" = "1" /* Excision of Right Abdominal Muscle Muscle, Percutaneous Approach, Diagnostic */
"0KBK3ZZ" = "1" /* Excision of Right Abdominal Muscle Muscle, Percutaneous Approach */
"0KBK4ZX" = "1" /* Excision of Right Abdominal Muscle Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KBK4ZZ" = "1" /* Excision of Right Abdominal Muscle Muscle, Percutaneous Endoscopic Approach */
"0KBL0ZX" = "1" /* Excision of Left Abdominal Muscle Muscle, Open Approach, Diagnostic */
"0KBL0ZZ" = "1" /* Excision of Left Abdominal Muscle Muscle, Open Approach */
"0KBL3ZX" = "1" /* Excision of Left Abdominal Muscle Muscle, Percutaneous Approach, Diagnostic */
"0KBL3ZZ" = "1" /* Excision of Left Abdominal Muscle Muscle, Percutaneous Approach */
"0KBL4ZX" = "1" /* Excision of Left Abdominal Muscle Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KBL4ZZ" = "1" /* Excision of Left Abdominal Muscle Muscle, Percutaneous Endoscopic Approach */
"0KQK0ZZ" = "1" /* Repair Right Abdominal Muscle Muscle, Open Approach */
"0KQK3ZZ" = "1" /* Repair Right Abdominal Muscle Muscle, Percutaneous Approach */
"0KQK4ZZ" = "1" /* Repair Right Abdominal Muscle Muscle, Percutaneous Endoscopic Approach */
"0KQL0ZZ" = "1" /* Repair Left Abdominal Muscle Muscle, Open Approach */
"0KQL3ZZ" = "1" /* Repair Left Abdominal Muscle Muscle, Percutaneous Approach */
"0KQL4ZZ" = "1" /* Repair Left Abdominal Muscle Muscle, Percutaneous Endoscopic Approach */
"0KUK07Z" = "1" /* Supplement of Right Abdominal Muscle Muscle with Autologous Tissue Substitute, Open Approach */
"0KUK0JZ" = "1" /* Supplement of Right Abdominal Muscle Muscle with Synthetic Substitute, Open Approach */
"0KUK0KZ" = "1" /* Supplement of Right Abdominal Muscle Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KUK47Z" = "1" /* Supplement of Right Abdominal Muscle Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUK4JZ" = "1" /* Supplement of Right Abdominal Muscle Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KUK4KZ" = "1" /* Supplement of Right Abdominal Muscle Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUL07Z" = "1" /* Supplement of Left Abdominal Muscle Muscle with Autologous Tissue Substitute, Open Approach */
"0KUL0JZ" = "1" /* Supplement of Left Abdominal Muscle Muscle with Synthetic Substitute, Open Approach */
"0KUL0KZ" = "1" /* Supplement of Left Abdominal Muscle Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KUL47Z" = "1" /* Supplement of Left Abdominal Muscle Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUL4JZ" = "1" /* Supplement of Left Abdominal Muscle Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KUL4KZ" = "1" /* Supplement of Left Abdominal Muscle Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WBF0ZZ" = "1" /* Excision of Abdominal Wall, Open Approach */
"0WBF3ZX" = "1" /* Excision of Abdominal Wall, Percutaneous Approach, Diagnostic */
"0WBF3ZZ" = "1" /* Excision of Abdominal Wall, Percutaneous Approach */
"0WBF4ZX" = "1" /* Excision of Abdominal Wall, Percutaneous Endoscopic Approach, Diagnostic */
"0WBF4ZZ" = "1" /* Excision of Abdominal Wall, Percutaneous Endoscopic Approach */
"0WBFXZ2" = "1" /* Excision of Abdominal Wall, Stoma, External Approach */
"0WBFXZX" = "1" /* Excision of Abdominal Wall, External Approach, Diagnostic */
"0WBFXZZ" = "1" /* Excision of Abdominal Wall, External Approach */
"0WJF0ZZ" = "1" /* Inspection of Abdominal Wall, Open Approach */
"0WJF3ZZ" = "1" /* Inspection of Abdominal Wall, Percutaneous Approach */
"0WJF4ZZ" = "1" /* Inspection of Abdominal Wall, Percutaneous Endoscopic Approach */
"0WPF07Z" = "1" /* Removal of Autologous Tissue Substitute from Abdominal Wall, Open Approach */
"0WPF0JZ" = "1" /* Removal of Synthetic Substitute from Abdominal Wall, Open Approach */
"0WPF0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Abdominal Wall, Open Approach */
"0WPF37Z" = "1" /* Removal of Autologous Tissue Substitute from Abdominal Wall, Percutaneous Approach */
"0WPF3JZ" = "1" /* Removal of Synthetic Substitute from Abdominal Wall, Percutaneous Approach */
"0WPF3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Abdominal Wall, Percutaneous Approach */
"0WPF47Z" = "1" /* Removal of Autologous Tissue Substitute from Abdominal Wall, Percutaneous Endoscopic Approach */
"0WPF4JZ" = "1" /* Removal of Synthetic Substitute from Abdominal Wall, Percutaneous Endoscopic Approach */
"0WPF4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Abdominal Wall, Percutaneous Endoscopic Approach */
"0WPFX7Z" = "1" /* Removal of Autologous Tissue Substitute from Abdominal Wall, External Approach */
"0WPFXJZ" = "1" /* Removal of Synthetic Substitute from Abdominal Wall, External Approach */
"0WPFXKZ" = "1" /* Removal of Nonautologous Tissue Substitute from Abdominal Wall, External Approach */
"0WQF0ZZ" = "1" /* Repair Abdominal Wall, Open Approach */
"0WQF3ZZ" = "1" /* Repair Abdominal Wall, Percutaneous Approach */
"0WQF4ZZ" = "1" /* Repair Abdominal Wall, Percutaneous Endoscopic Approach */
"0WQFXZ2" = "1" /* Repair Abdominal Wall, Stoma, External Approach */
"0WQFXZZ" = "1" /* Repair Abdominal Wall, External Approach */
"0WUF07Z" = "1" /* Supplement Abdominal Wall with Autologous Tissue Substitute, Open Approach */
"0WUF0JZ" = "1" /* Supplement Abdominal Wall with Synthetic Substitute, Open Approach */
"0WUF0KZ" = "1" /* Supplement Abdominal Wall with Nonautologous Tissue Substitute, Open Approach */
"0WUF47Z" = "1" /* Supplement Abdominal Wall with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WUF4JZ" = "1" /* Supplement Abdominal Wall with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0WUF4KZ" = "1" /* Supplement Abdominal Wall with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WWF07Z" = "1" /* Revision of Autologous Tissue Substitute in Abdominal Wall, Open Approach */
"0WWF0JZ" = "1" /* Revision of Synthetic Substitute in Abdominal Wall, Open Approach */
"0WWF0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Abdominal Wall, Open Approach */
"0WWF37Z" = "1" /* Revision of Autologous Tissue Substitute in Abdominal Wall, Percutaneous Approach */
"0WWF3JZ" = "1" /* Revision of Synthetic Substitute in Abdominal Wall, Percutaneous Approach */
"0WWF3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Abdominal Wall, Percutaneous Approach */
"0WWF47Z" = "1" /* Revision of Autologous Tissue Substitute in Abdominal Wall, Percutaneous Endoscopic Approach */
"0WWF4JZ" = "1" /* Revision of Synthetic Substitute in Abdominal Wall, Percutaneous Endoscopic Approach */
"0WWF4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Abdominal Wall, Percutaneous Endoscopic Approach */
"0WWFX7Z" = "1" /* Revision of Autologous Tissue Substitute in Abdominal Wall, External Approach */
"0WWFXJZ" = "1" /* Revision of Synthetic Substitute in Abdominal Wall, External Approach */
"0WWFXKZ" = "1" /* Revision of Nonautologous Tissue Substitute in Abdominal Wall, External Approach */
Other = "0"
;

/* Procedure codeset REPGAST last updated 160922 for IDC10 v60rev3 */
Value $REPGAST
"0WQF0ZZ" = "1" /* Repair Abdominal Wall, Open Approach */
"0WQF3ZZ" = "1" /* Repair Abdominal Wall, Percutaneous Approach */
"0WQF4ZZ" = "1" /* Repair Abdominal Wall, Percutaneous Endoscopic Approach */
"0WUF07Z" = "1" /* Supplement Abdominal Wall with Autologous Tissue Substitute, Open Approach */
"0WUF0JZ" = "1" /* Supplement Abdominal Wall with Synthetic Substitute, Open Approach */
"0WUF0KZ" = "1" /* Supplement Abdominal Wall with Nonautologous Tissue Substitute, Open Approach */
Other = "0"
;

/* Diagnosis codeset SEPTI2D last updated 160922 for IDC10 v60rev3 */
Value $SEPTI2D
"A021" = "1" /* Salmonella sepsis */
"A227" = "1" /* Anthrax sepsis */
"A267" = "1" /* Erysipelothrix sepsis */
"A327" = "1" /* Listerial sepsis */
"A400" = "1" /* Sepsis due to streptococcus, group A */
"A401" = "1" /* Sepsis due to streptococcus, group B */
"A403" = "1" /* Sepsis due to Streptococcus pneumoniae */
"A408" = "1" /* Other streptococcal sepsis */
"A409" = "1" /* Streptococcal sepsis, unspecified */
"A4101" = "1" /* Sepsis due to Methicillin susceptible Staphylococcus aureus */
"A4102" = "1" /* Sepsis due to Methicillin resistant Staphylococcus aureus */
"A411" = "1" /* Sepsis due to other specified staphylococcus */
"A412" = "1" /* Sepsis due to unspecified staphylococcus */
"A413" = "1" /* Sepsis due to Hemophilus influenzae */
"A414" = "1" /* Sepsis due to anaerobes */
"A4150" = "1" /* Gram-negative sepsis, unspecified */
"A4151" = "1" /* Sepsis due to Escherichia coli [E. coli] */
"A4152" = "1" /* Sepsis due to Pseudomonas */
"A4153" = "1" /* Sepsis due to Serratia */
"A4159" = "1" /* Other Gram-negative sepsis */
"A4181" = "1" /* Sepsis due to Enterococcus */
"A4189" = "1" /* Other specified sepsis */
"A419" = "1" /* Sepsis, unspecified organism */
"A427" = "1" /* Actinomycotic sepsis */
"A5486" = "1" /* Gonococcal sepsis */
"B377" = "1" /* Candidal sepsis */
"R6520" = "1" /* Severe sepsis without septic shock */
"R6521" = "1" /* Severe sepsis with septic shock */
"T8112XA" = "1" /* Postprocedural septic shock, initial encounter */
Other = "0"
;

/* Diagnosis codeset SPINABD last updated 160922 for IDC10 v60rev3 */
Value $SPINABD
"G931" = "1" /* Anoxic brain damage, not elsewhere classified */
"Q050" = "1" /* Cervical spina bifida with hydrocephalus */
"Q051" = "1" /* Thoracic spina bifida with hydrocephalus */
"Q052" = "1" /* Lumbar spina bifida with hydrocephalus */
"Q053" = "1" /* Sacral spina bifida with hydrocephalus */
"Q054" = "1" /* Unspecified spina bifida with hydrocephalus */
"Q055" = "1" /* Cervical spina bifida without hydrocephalus */
"Q056" = "1" /* Thoracic spina bifida without hydrocephalus */
"Q057" = "1" /* Lumbar spina bifida without hydrocephalus */
"Q058" = "1" /* Sacral spina bifida without hydrocephalus */
"Q059" = "1" /* Spina bifida, unspecified */
"Q0701" = "1" /* Arnold-Chiari syndrome with spina bifida */
"Q0703" = "1" /* Arnold-Chiari syndrome with spina bifida and hydrocephalus */
Other = "0"
;

/* Procedure codeset SPINEP last updated 160922 for IDC10 v60rev3 */
Value $SPINEP
"009T00Z" = "1" /* Drainage of Spinal Meninges with Drainage Device, Open Approach */
"009T0ZZ" = "1" /* Drainage of Spinal Meninges, Open Approach */
"009T30Z" = "1" /* Drainage of Spinal Meninges with Drainage Device, Percutaneous Approach */
"009T3ZZ" = "1" /* Drainage of Spinal Meninges, Percutaneous Approach */
"009T40Z" = "1" /* Drainage of Spinal Meninges with Drainage Device, Percutaneous Endoscopic Approach */
"009T4ZZ" = "1" /* Drainage of Spinal Meninges, Percutaneous Endoscopic Approach */
"009U00Z" = "1" /* Drainage of Spinal Canal with Drainage Device, Open Approach */
"009U0ZZ" = "1" /* Drainage of Spinal Canal, Open Approach */
"009W00Z" = "1" /* Drainage of Cervical Spinal Cord with Drainage Device, Open Approach */
"009W0ZZ" = "1" /* Drainage of Cervical Spinal Cord, Open Approach */
"009W30Z" = "1" /* Drainage of Cervical Spinal Cord with Drainage Device, Percutaneous Approach */
"009W3ZZ" = "1" /* Drainage of Cervical Spinal Cord, Percutaneous Approach */
"009W40Z" = "1" /* Drainage of Cervical Spinal Cord with Drainage Device, Percutaneous Endoscopic Approach */
"009W4ZZ" = "1" /* Drainage of Cervical Spinal Cord, Percutaneous Endoscopic Approach */
"009X00Z" = "1" /* Drainage of Thoracic Spinal Cord with Drainage Device, Open Approach */
"009X0ZZ" = "1" /* Drainage of Thoracic Spinal Cord, Open Approach */
"009X30Z" = "1" /* Drainage of Thoracic Spinal Cord with Drainage Device, Percutaneous Approach */
"009X3ZZ" = "1" /* Drainage of Thoracic Spinal Cord, Percutaneous Approach */
"009X40Z" = "1" /* Drainage of Thoracic Spinal Cord with Drainage Device, Percutaneous Endoscopic Approach */
"009X4ZZ" = "1" /* Drainage of Thoracic Spinal Cord, Percutaneous Endoscopic Approach */
"009Y00Z" = "1" /* Drainage of Lumbar Spinal Cord with Drainage Device, Open Approach */
"009Y0ZZ" = "1" /* Drainage of Lumbar Spinal Cord, Open Approach */
"009Y30Z" = "1" /* Drainage of Lumbar Spinal Cord with Drainage Device, Percutaneous Approach */
"009Y3ZZ" = "1" /* Drainage of Lumbar Spinal Cord, Percutaneous Approach */
"009Y40Z" = "1" /* Drainage of Lumbar Spinal Cord with Drainage Device, Percutaneous Endoscopic Approach */
"009Y4ZZ" = "1" /* Drainage of Lumbar Spinal Cord, Percutaneous Endoscopic Approach */
"00C30ZZ" = "1" /* Extirpation of Matter from Epidural Space, Open Approach */
"00C33ZZ" = "1" /* Extirpation of Matter from Epidural Space, Percutaneous Approach */
"00C34ZZ" = "1" /* Extirpation of Matter from Epidural Space, Percutaneous Endoscopic Approach */
"00CT0ZZ" = "1" /* Extirpation of Matter from Spinal Meninges, Open Approach */
"00CT3ZZ" = "1" /* Extirpation of Matter from Spinal Meninges, Percutaneous Approach */
"00CT4ZZ" = "1" /* Extirpation of Matter from Spinal Meninges, Percutaneous Endoscopic Approach */
"00CW0ZZ" = "1" /* Extirpation of Matter from Cervical Spinal Cord, Open Approach */
"00CW3ZZ" = "1" /* Extirpation of Matter from Cervical Spinal Cord, Percutaneous Approach */
"00CW4ZZ" = "1" /* Extirpation of Matter from Cervical Spinal Cord, Percutaneous Endoscopic Approach */
"00CX0ZZ" = "1" /* Extirpation of Matter from Thoracic Spinal Cord, Open Approach */
"00CX3ZZ" = "1" /* Extirpation of Matter from Thoracic Spinal Cord, Percutaneous Approach */
"00CX4ZZ" = "1" /* Extirpation of Matter from Thoracic Spinal Cord, Percutaneous Endoscopic Approach */
"00CY0ZZ" = "1" /* Extirpation of Matter from Lumbar Spinal Cord, Open Approach */
"00CY3ZZ" = "1" /* Extirpation of Matter from Lumbar Spinal Cord, Percutaneous Approach */
"00CY4ZZ" = "1" /* Extirpation of Matter from Lumbar Spinal Cord, Percutaneous Endoscopic Approach */
"00JU0ZZ" = "1" /* Inspection of Spinal Canal, Open Approach */
"00JV0ZZ" = "1" /* Inspection of Spinal Cord, Open Approach */
"00NW0ZZ" = "1" /* Release Cervical Spinal Cord, Open Approach */
"00NW3ZZ" = "1" /* Release Cervical Spinal Cord, Percutaneous Approach */
"00NW4ZZ" = "1" /* Release Cervical Spinal Cord, Percutaneous Endoscopic Approach */
"00NX0ZZ" = "1" /* Release Thoracic Spinal Cord, Open Approach */
"00NX3ZZ" = "1" /* Release Thoracic Spinal Cord, Percutaneous Approach */
"00NX4ZZ" = "1" /* Release Thoracic Spinal Cord, Percutaneous Endoscopic Approach */
"00NY0ZZ" = "1" /* Release Lumbar Spinal Cord, Open Approach */
"00NY3ZZ" = "1" /* Release Lumbar Spinal Cord, Percutaneous Approach */
"00NY4ZZ" = "1" /* Release Lumbar Spinal Cord, Percutaneous Endoscopic Approach */
"0PS304Z" = "1" /* Reposition Cervical Vertebra with Internal Fixation Device, Open Approach */
"0PS30ZZ" = "1" /* Reposition Cervical Vertebra, Open Approach */
"0PS334Z" = "1" /* Reposition Cervical Vertebra with Internal Fixation Device, Percutaneous Approach */
"0PS33ZZ" = "1" /* Reposition Cervical Vertebra, Percutaneous Approach */
"0PS344Z" = "1" /* Reposition Cervical Vertebra with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PS34ZZ" = "1" /* Reposition Cervical Vertebra, Percutaneous Endoscopic Approach */
"0PS3XZZ" = "1" /* Reposition Cervical Vertebra, External Approach */
"0PS404Z" = "1" /* Reposition Thoracic Vertebra with Internal Fixation Device, Open Approach */
"0PS40ZZ" = "1" /* Reposition Thoracic Vertebra, Open Approach */
"0PS434Z" = "1" /* Reposition Thoracic Vertebra with Internal Fixation Device, Percutaneous Approach */
"0PS43ZZ" = "1" /* Reposition Thoracic Vertebra, Percutaneous Approach */
"0PS444Z" = "1" /* Reposition Thoracic Vertebra with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PS44ZZ" = "1" /* Reposition Thoracic Vertebra, Percutaneous Endoscopic Approach */
"0PS4XZZ" = "1" /* Reposition Thoracic Vertebra, External Approach */
"0PU33JZ" = "1" /* Supplement Cervical Vertebra with Synthetic Substitute, Percutaneous Approach */
"0PU34JZ" = "1" /* Supplement Cervical Vertebra with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PU43JZ" = "1" /* Supplement Thoracic Vertebra with Synthetic Substitute, Percutaneous Approach */
"0PU44JZ" = "1" /* Supplement Thoracic Vertebra with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QS004Z" = "1" /* Reposition Lumbar Vertebra with Internal Fixation Device, Open Approach */
"0QS00ZZ" = "1" /* Reposition Lumbar Vertebra, Open Approach */
"0QS034Z" = "1" /* Reposition Lumbar Vertebra with Internal Fixation Device, Percutaneous Approach */
"0QS03ZZ" = "1" /* Reposition Lumbar Vertebra, Percutaneous Approach */
"0QS044Z" = "1" /* Reposition Lumbar Vertebra with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QS04ZZ" = "1" /* Reposition Lumbar Vertebra, Percutaneous Endoscopic Approach */
"0QS0XZZ" = "1" /* Reposition Lumbar Vertebra, External Approach */
"0QU03JZ" = "1" /* Supplement Lumbar Vertebra with Synthetic Substitute, Percutaneous Approach */
"0QU04JZ" = "1" /* Supplement Lumbar Vertebra with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RB00ZZ" = "1" /* Excision of Occipital-cervical Joint, Open Approach */
"0RB03ZZ" = "1" /* Excision of Occipital-cervical Joint, Percutaneous Approach */
"0RB04ZZ" = "1" /* Excision of Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RB10ZZ" = "1" /* Excision of Cervical Vertebral Joint, Open Approach */
"0RB13ZZ" = "1" /* Excision of Cervical Vertebral Joint, Percutaneous Approach */
"0RB14ZZ" = "1" /* Excision of Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RB40ZZ" = "1" /* Excision of Cervicothoracic Vertebral Joint, Open Approach */
"0RB43ZZ" = "1" /* Excision of Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RB44ZZ" = "1" /* Excision of Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RB60ZZ" = "1" /* Excision of Thoracic Vertebral Joint, Open Approach */
"0RB63ZZ" = "1" /* Excision of Thoracic Vertebral Joint, Percutaneous Approach */
"0RB64ZZ" = "1" /* Excision of Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RBA0ZZ" = "1" /* Excision of Thoracolumbar Vertebral Joint, Open Approach */
"0RBA3ZZ" = "1" /* Excision of Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RBA4ZZ" = "1" /* Excision of Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RG0070" = "1" /* Fusion of Occipital-cervical Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG0071" = "1" /* Fusion of Occipital-cervical Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG007J" = "1" /* Fusion of Occipital-cervical Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG00A0" = "1" /* Fusion of Occipital-cervical Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0RG00A1" = "1" /* Fusion of Occipital-cervical Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Open Approach */
"0RG00AJ" = "1" /* Fusion of Occipital-cervical Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Open Approach */
"0RG00J0" = "1" /* Fusion of Occipital-cervical Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG00J1" = "1" /* Fusion of Occipital-cervical Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG00JJ" = "1" /* Fusion of Occipital-cervical Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG00K0" = "1" /* Fusion of Occipital-cervical Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG00K1" = "1" /* Fusion of Occipital-cervical Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG00KJ" = "1" /* Fusion of Occipital-cervical Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG00Z0" = "1" /* Fusion of Occipital-cervical Joint, Anterior Approach, Anterior Column, Open Approach */
"0RG00Z1" = "1" /* Fusion of Occipital-cervical Joint, Posterior Approach, Posterior Column, Open Approach */
"0RG00ZJ" = "1" /* Fusion of Occipital-cervical Joint, Posterior Approach, Anterior Column, Open Approach */
"0RG0370" = "1" /* Fusion of Occipital-cervical Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG0371" = "1" /* Fusion of Occipital-cervical Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG037J" = "1" /* Fusion of Occipital-cervical Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG03A0" = "1" /* Fusion of Occipital-cervical Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG03A1" = "1" /* Fusion of Occipital-cervical Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG03AJ" = "1" /* Fusion of Occipital-cervical Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG03J0" = "1" /* Fusion of Occipital-cervical Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG03J1" = "1" /* Fusion of Occipital-cervical Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG03JJ" = "1" /* Fusion of Occipital-cervical Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG03K0" = "1" /* Fusion of Occipital-cervical Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG03K1" = "1" /* Fusion of Occipital-cervical Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG03KJ" = "1" /* Fusion of Occipital-cervical Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG03Z0" = "1" /* Fusion of Occipital-cervical Joint, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG03Z1" = "1" /* Fusion of Occipital-cervical Joint, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG03ZJ" = "1" /* Fusion of Occipital-cervical Joint, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG0470" = "1" /* Fusion of Occipital-cervical Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG0471" = "1" /* Fusion of Occipital-cervical Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG047J" = "1" /* Fusion of Occipital-cervical Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG04A0" = "1" /* Fusion of Occipital-cervical Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG04A1" = "1" /* Fusion of Occipital-cervical Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG04AJ" = "1" /* Fusion of Occipital-cervical Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG04J0" = "1" /* Fusion of Occipital-cervical Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG04J1" = "1" /* Fusion of Occipital-cervical Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG04JJ" = "1" /* Fusion of Occipital-cervical Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG04K0" = "1" /* Fusion of Occipital-cervical Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG04K1" = "1" /* Fusion of Occipital-cervical Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG04KJ" = "1" /* Fusion of Occipital-cervical Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG04Z0" = "1" /* Fusion of Occipital-cervical Joint, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG04Z1" = "1" /* Fusion of Occipital-cervical Joint, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG04ZJ" = "1" /* Fusion of Occipital-cervical Joint, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG1070" = "1" /* Fusion of Cervical Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG1071" = "1" /* Fusion of Cervical Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG107J" = "1" /* Fusion of Cervical Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG10A0" = "1" /* Fusion of Cervical Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0RG10A1" = "1" /* Fusion of Cervical Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Open Approach */
"0RG10AJ" = "1" /* Fusion of Cervical Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Open Approach */
"0RG10J0" = "1" /* Fusion of Cervical Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG10J1" = "1" /* Fusion of Cervical Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG10JJ" = "1" /* Fusion of Cervical Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG10K0" = "1" /* Fusion of Cervical Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG10K1" = "1" /* Fusion of Cervical Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG10KJ" = "1" /* Fusion of Cervical Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG10Z0" = "1" /* Fusion of Cervical Vertebral Joint, Anterior Approach, Anterior Column, Open Approach */
"0RG10Z1" = "1" /* Fusion of Cervical Vertebral Joint, Posterior Approach, Posterior Column, Open Approach */
"0RG10ZJ" = "1" /* Fusion of Cervical Vertebral Joint, Posterior Approach, Anterior Column, Open Approach */
"0RG1370" = "1" /* Fusion of Cervical Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG1371" = "1" /* Fusion of Cervical Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG137J" = "1" /* Fusion of Cervical Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG13A0" = "1" /* Fusion of Cervical Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG13A1" = "1" /* Fusion of Cervical Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG13AJ" = "1" /* Fusion of Cervical Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG13J0" = "1" /* Fusion of Cervical Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG13J1" = "1" /* Fusion of Cervical Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG13JJ" = "1" /* Fusion of Cervical Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG13K0" = "1" /* Fusion of Cervical Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG13K1" = "1" /* Fusion of Cervical Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG13KJ" = "1" /* Fusion of Cervical Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG13Z0" = "1" /* Fusion of Cervical Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG13Z1" = "1" /* Fusion of Cervical Vertebral Joint, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG13ZJ" = "1" /* Fusion of Cervical Vertebral Joint, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG1470" = "1" /* Fusion of Cervical Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG1471" = "1" /* Fusion of Cervical Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG147J" = "1" /* Fusion of Cervical Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG14A0" = "1" /* Fusion of Cervical Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG14A1" = "1" /* Fusion of Cervical Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG14AJ" = "1" /* Fusion of Cervical Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG14J0" = "1" /* Fusion of Cervical Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG14J1" = "1" /* Fusion of Cervical Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG14JJ" = "1" /* Fusion of Cervical Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG14K0" = "1" /* Fusion of Cervical Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG14K1" = "1" /* Fusion of Cervical Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG14KJ" = "1" /* Fusion of Cervical Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG14Z0" = "1" /* Fusion of Cervical Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG14Z1" = "1" /* Fusion of Cervical Vertebral Joint, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG14ZJ" = "1" /* Fusion of Cervical Vertebral Joint, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG2070" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG2071" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG207J" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG20A0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0RG20A1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Open Approach */
"0RG20AJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Open Approach */
"0RG20J0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG20J1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG20JJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG20K0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG20K1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG20KJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG20Z0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints, Anterior Approach, Anterior Column, Open Approach */
"0RG20Z1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints, Posterior Approach, Posterior Column, Open Approach */
"0RG20ZJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints, Posterior Approach, Anterior Column, Open Approach */
"0RG2370" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG2371" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG237J" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG23A0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG23A1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG23AJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG23J0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG23J1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG23JJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG23K0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG23K1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG23KJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG23Z0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG23Z1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG23ZJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG2470" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG2471" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG247J" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG24A0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG24A1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG24AJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG24J0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG24J1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG24JJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG24K0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG24K1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG24KJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG24Z0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG24Z1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG24ZJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG4070" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG4071" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG407J" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG40A0" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0RG40A1" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Open Approach */
"0RG40AJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Open Approach */
"0RG40J0" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG40J1" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG40JJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG40K0" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG40K1" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG40KJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG40Z0" = "1" /* Fusion of Cervicothoracic Vertebral Joint, Anterior Approach, Anterior Column, Open Approach */
"0RG40Z1" = "1" /* Fusion of Cervicothoracic Vertebral Joint, Posterior Approach, Posterior Column, Open Approach */
"0RG40ZJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint, Posterior Approach, Anterior Column, Open Approach */
"0RG4370" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG4371" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG437J" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG43A0" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG43A1" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG43AJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG43J0" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG43J1" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG43JJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG43K0" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG43K1" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG43KJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG43Z0" = "1" /* Fusion of Cervicothoracic Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG43Z1" = "1" /* Fusion of Cervicothoracic Vertebral Joint, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG43ZJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG4470" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG4471" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG447J" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG44A0" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG44A1" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG44AJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG44J0" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG44J1" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG44JJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG44K0" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG44K1" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG44KJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG44Z0" = "1" /* Fusion of Cervicothoracic Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG44Z1" = "1" /* Fusion of Cervicothoracic Vertebral Joint, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG44ZJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG6070" = "1" /* Fusion of Thoracic Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG6071" = "1" /* Fusion of Thoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG607J" = "1" /* Fusion of Thoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG60A0" = "1" /* Fusion of Thoracic Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0RG60A1" = "1" /* Fusion of Thoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Open Approach */
"0RG60AJ" = "1" /* Fusion of Thoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Open Approach */
"0RG60J0" = "1" /* Fusion of Thoracic Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG60J1" = "1" /* Fusion of Thoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG60JJ" = "1" /* Fusion of Thoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG60K0" = "1" /* Fusion of Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG60K1" = "1" /* Fusion of Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG60KJ" = "1" /* Fusion of Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG60Z0" = "1" /* Fusion of Thoracic Vertebral Joint, Anterior Approach, Anterior Column, Open Approach */
"0RG60Z1" = "1" /* Fusion of Thoracic Vertebral Joint, Posterior Approach, Posterior Column, Open Approach */
"0RG60ZJ" = "1" /* Fusion of Thoracic Vertebral Joint, Posterior Approach, Anterior Column, Open Approach */
"0RG6370" = "1" /* Fusion of Thoracic Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG6371" = "1" /* Fusion of Thoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG637J" = "1" /* Fusion of Thoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG63A0" = "1" /* Fusion of Thoracic Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG63A1" = "1" /* Fusion of Thoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG63AJ" = "1" /* Fusion of Thoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG63J0" = "1" /* Fusion of Thoracic Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG63J1" = "1" /* Fusion of Thoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG63JJ" = "1" /* Fusion of Thoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG63K0" = "1" /* Fusion of Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG63K1" = "1" /* Fusion of Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG63KJ" = "1" /* Fusion of Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG63Z0" = "1" /* Fusion of Thoracic Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG63Z1" = "1" /* Fusion of Thoracic Vertebral Joint, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG63ZJ" = "1" /* Fusion of Thoracic Vertebral Joint, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG6470" = "1" /* Fusion of Thoracic Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG6471" = "1" /* Fusion of Thoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG647J" = "1" /* Fusion of Thoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG64A0" = "1" /* Fusion of Thoracic Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG64A1" = "1" /* Fusion of Thoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG64AJ" = "1" /* Fusion of Thoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG64J0" = "1" /* Fusion of Thoracic Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG64J1" = "1" /* Fusion of Thoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG64JJ" = "1" /* Fusion of Thoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG64K0" = "1" /* Fusion of Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG64K1" = "1" /* Fusion of Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG64KJ" = "1" /* Fusion of Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG64Z0" = "1" /* Fusion of Thoracic Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG64Z1" = "1" /* Fusion of Thoracic Vertebral Joint, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG64ZJ" = "1" /* Fusion of Thoracic Vertebral Joint, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG7070" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG7071" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG707J" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG70A0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0RG70A1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Open Approach */
"0RG70AJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Open Approach */
"0RG70J0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG70J1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG70JJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG70K0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG70K1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG70KJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG70Z0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints, Anterior Approach, Anterior Column, Open Approach */
"0RG70Z1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints, Posterior Approach, Posterior Column, Open Approach */
"0RG70ZJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints, Posterior Approach, Anterior Column, Open Approach */
"0RG7370" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG7371" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG737J" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG73A0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG73A1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG73AJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG73J0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG73J1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG73JJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG73K0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG73K1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG73KJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG73Z0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG73Z1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG73ZJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG7470" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG7471" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG747J" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG74A0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG74A1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG74AJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG74J0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG74J1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG74JJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG74K0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG74K1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG74KJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG74Z0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG74Z1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG74ZJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG8070" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG8071" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG807J" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG80A0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0RG80A1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Open Approach */
"0RG80AJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Open Approach */
"0RG80J0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG80J1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG80JJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG80K0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG80K1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG80KJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG80Z0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints, Anterior Approach, Anterior Column, Open Approach */
"0RG80Z1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints, Posterior Approach, Posterior Column, Open Approach */
"0RG80ZJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints, Posterior Approach, Anterior Column, Open Approach */
"0RG8370" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG8371" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG837J" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG83A0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG83A1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG83AJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG83J0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG83J1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG83JJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG83K0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG83K1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG83KJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG83Z0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG83Z1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG83ZJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG8470" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG8471" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG847J" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG84A0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG84A1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG84AJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG84J0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG84J1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG84JJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG84K0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG84K1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG84KJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG84Z0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG84Z1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG84ZJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA070" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RGA071" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RGA07J" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RGA0A0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0RGA0A1" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Open Approach */
"0RGA0AJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Open Approach */
"0RGA0J0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RGA0J1" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RGA0JJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RGA0K0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RGA0K1" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RGA0KJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RGA0Z0" = "1" /* Fusion of Thoracolumbar Vertebral Joint, Anterior Approach, Anterior Column, Open Approach */
"0RGA0Z1" = "1" /* Fusion of Thoracolumbar Vertebral Joint, Posterior Approach, Posterior Column, Open Approach */
"0RGA0ZJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint, Posterior Approach, Anterior Column, Open Approach */
"0RGA370" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RGA371" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RGA37J" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RGA3A0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RGA3A1" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RGA3AJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RGA3J0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RGA3J1" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RGA3JJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RGA3K0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RGA3K1" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RGA3KJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RGA3Z0" = "1" /* Fusion of Thoracolumbar Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RGA3Z1" = "1" /* Fusion of Thoracolumbar Vertebral Joint, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RGA3ZJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RGA470" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA471" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RGA47J" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA4A0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA4A1" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RGA4AJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA4J0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA4J1" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RGA4JJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA4K0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA4K1" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RGA4KJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA4Z0" = "1" /* Fusion of Thoracolumbar Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA4Z1" = "1" /* Fusion of Thoracolumbar Vertebral Joint, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RGA4ZJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RH00BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Occipital-cervical Joint, Open Approach */
"0RH00CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Occipital-cervical Joint, Open Approach */
"0RH00DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Occipital-cervical Joint, Open Approach */
"0RH03BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Occipital-cervical Joint, Percutaneous Approach */
"0RH03CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Occipital-cervical Joint, Percutaneous Approach */
"0RH03DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Occipital-cervical Joint, Percutaneous Approach */
"0RH04BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RH04CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RH04DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RH10BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Cervical Vertebral Joint, Open Approach */
"0RH10CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Cervical Vertebral Joint, Open Approach */
"0RH10DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Cervical Vertebral Joint, Open Approach */
"0RH13BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Cervical Vertebral Joint, Percutaneous Approach */
"0RH13CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Cervical Vertebral Joint, Percutaneous Approach */
"0RH13DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Cervical Vertebral Joint, Percutaneous Approach */
"0RH14BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RH14CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RH14DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RH40BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Cervicothoracic Vertebral Joint, Open Approach */
"0RH40CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Cervicothoracic Vertebral Joint, Open Approach */
"0RH40DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Cervicothoracic Vertebral Joint, Open Approach */
"0RH43BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RH43CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RH43DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RH44BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RH44CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RH44DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RH60BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Thoracic Vertebral Joint, Open Approach */
"0RH60CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Thoracic Vertebral Joint, Open Approach */
"0RH60DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Thoracic Vertebral Joint, Open Approach */
"0RH63BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Thoracic Vertebral Joint, Percutaneous Approach */
"0RH63CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Thoracic Vertebral Joint, Percutaneous Approach */
"0RH63DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Thoracic Vertebral Joint, Percutaneous Approach */
"0RH64BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RH64CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RH64DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RHA0BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Thoracolumbar Vertebral Joint, Open Approach */
"0RHA0CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Thoracolumbar Vertebral Joint, Open Approach */
"0RHA0DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Thoracolumbar Vertebral Joint, Open Approach */
"0RHA3BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RHA3CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RHA3DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RHA4BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RHA4CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RHA4DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP004Z" = "1" /* Removal of Internal Fixation Device from Occipital-cervical Joint, Open Approach */
"0RP034Z" = "1" /* Removal of Internal Fixation Device from Occipital-cervical Joint, Percutaneous Approach */
"0RP044Z" = "1" /* Removal of Internal Fixation Device from Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RP104Z" = "1" /* Removal of Internal Fixation Device from Cervical Vertebral Joint, Open Approach */
"0RP134Z" = "1" /* Removal of Internal Fixation Device from Cervical Vertebral Joint, Percutaneous Approach */
"0RP144Z" = "1" /* Removal of Internal Fixation Device from Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP30JZ" = "1" /* Removal of Synthetic Substitute from Cervical Vertebral Disc, Open Approach */
"0RP404Z" = "1" /* Removal of Internal Fixation Device from Cervicothoracic Vertebral Joint, Open Approach */
"0RP434Z" = "1" /* Removal of Internal Fixation Device from Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RP444Z" = "1" /* Removal of Internal Fixation Device from Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP50JZ" = "1" /* Removal of Synthetic Substitute from Cervicothoracic Vertebral Disc, Open Approach */
"0RP604Z" = "1" /* Removal of Internal Fixation Device from Thoracic Vertebral Joint, Open Approach */
"0RP634Z" = "1" /* Removal of Internal Fixation Device from Thoracic Vertebral Joint, Percutaneous Approach */
"0RP644Z" = "1" /* Removal of Internal Fixation Device from Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP90JZ" = "1" /* Removal of Synthetic Substitute from Thoracic Vertebral Disc, Open Approach */
"0RPA04Z" = "1" /* Removal of Internal Fixation Device from Thoracolumbar Vertebral Joint, Open Approach */
"0RPA34Z" = "1" /* Removal of Internal Fixation Device from Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RPA44Z" = "1" /* Removal of Internal Fixation Device from Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RPB0JZ" = "1" /* Removal of Synthetic Substitute from Thoracolumbar Vertebral Disc, Open Approach */
"0RQ30ZZ" = "1" /* Repair Cervical Vertebral Disc, Open Approach */
"0RQ90ZZ" = "1" /* Repair Thoracic Vertebral Disc, Open Approach */
"0RQB0ZZ" = "1" /* Repair Thoracolumbar Vertebral Disc, Open Approach */
"0RR30JZ" = "1" /* Replacement of Cervical Vertebral Disc with Synthetic Substitute, Open Approach */
"0RR50JZ" = "1" /* Replacement of Cervicothoracic Vertebral Disc with Synthetic Substitute, Open Approach */
"0RR90JZ" = "1" /* Replacement of Thoracic Vertebral Disc with Synthetic Substitute, Open Approach */
"0RRB0JZ" = "1" /* Replacement of Thoracolumbar Vertebral Disc with Synthetic Substitute, Open Approach */
"0RU00JZ" = "1" /* Supplement Occipital-cervical Joint with Synthetic Substitute, Open Approach */
"0RU03JZ" = "1" /* Supplement Occipital-cervical Joint with Synthetic Substitute, Percutaneous Approach */
"0RU04JZ" = "1" /* Supplement Occipital-cervical Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RU10JZ" = "1" /* Supplement Cervical Vertebral Joint with Synthetic Substitute, Open Approach */
"0RU13JZ" = "1" /* Supplement Cervical Vertebral Joint with Synthetic Substitute, Percutaneous Approach */
"0RU14JZ" = "1" /* Supplement Cervical Vertebral Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RU307Z" = "1" /* Supplement Cervical Vertebral Disc with Autologous Tissue Substitute, Open Approach */
"0RU30JZ" = "1" /* Supplement Cervical Vertebral Disc with Synthetic Substitute, Open Approach */
"0RU30KZ" = "1" /* Supplement Cervical Vertebral Disc with Nonautologous Tissue Substitute, Open Approach */
"0RU337Z" = "1" /* Supplement Cervical Vertebral Disc with Autologous Tissue Substitute, Percutaneous Approach */
"0RU33JZ" = "1" /* Supplement Cervical Vertebral Disc with Synthetic Substitute, Percutaneous Approach */
"0RU33KZ" = "1" /* Supplement Cervical Vertebral Disc with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RU347Z" = "1" /* Supplement Cervical Vertebral Disc with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RU34JZ" = "1" /* Supplement Cervical Vertebral Disc with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RU34KZ" = "1" /* Supplement Cervical Vertebral Disc with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RU40JZ" = "1" /* Supplement Cervicothoracic Vertebral Joint with Synthetic Substitute, Open Approach */
"0RU43JZ" = "1" /* Supplement Cervicothoracic Vertebral Joint with Synthetic Substitute, Percutaneous Approach */
"0RU44JZ" = "1" /* Supplement Cervicothoracic Vertebral Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RU50JZ" = "1" /* Supplement Cervicothoracic Vertebral Disc with Synthetic Substitute, Open Approach */
"0RU53JZ" = "1" /* Supplement Cervicothoracic Vertebral Disc with Synthetic Substitute, Percutaneous Approach */
"0RU54JZ" = "1" /* Supplement Cervicothoracic Vertebral Disc with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RU60JZ" = "1" /* Supplement Thoracic Vertebral Joint with Synthetic Substitute, Open Approach */
"0RU63JZ" = "1" /* Supplement Thoracic Vertebral Joint with Synthetic Substitute, Percutaneous Approach */
"0RU64JZ" = "1" /* Supplement Thoracic Vertebral Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RU907Z" = "1" /* Supplement Thoracic Vertebral Disc with Autologous Tissue Substitute, Open Approach */
"0RU90JZ" = "1" /* Supplement Thoracic Vertebral Disc with Synthetic Substitute, Open Approach */
"0RU90KZ" = "1" /* Supplement Thoracic Vertebral Disc with Nonautologous Tissue Substitute, Open Approach */
"0RU937Z" = "1" /* Supplement Thoracic Vertebral Disc with Autologous Tissue Substitute, Percutaneous Approach */
"0RU93JZ" = "1" /* Supplement Thoracic Vertebral Disc with Synthetic Substitute, Percutaneous Approach */
"0RU93KZ" = "1" /* Supplement Thoracic Vertebral Disc with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RU947Z" = "1" /* Supplement Thoracic Vertebral Disc with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RU94JZ" = "1" /* Supplement Thoracic Vertebral Disc with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RU94KZ" = "1" /* Supplement Thoracic Vertebral Disc with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUA0JZ" = "1" /* Supplement Thoracolumbar Vertebral Joint with Synthetic Substitute, Open Approach */
"0RUA3JZ" = "1" /* Supplement Thoracolumbar Vertebral Joint with Synthetic Substitute, Percutaneous Approach */
"0RUA4JZ" = "1" /* Supplement Thoracolumbar Vertebral Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUB07Z" = "1" /* Supplement Thoracolumbar Vertebral Disc with Autologous Tissue Substitute, Open Approach */
"0RUB0JZ" = "1" /* Supplement Thoracolumbar Vertebral Disc with Synthetic Substitute, Open Approach */
"0RUB0KZ" = "1" /* Supplement Thoracolumbar Vertebral Disc with Nonautologous Tissue Substitute, Open Approach */
"0RUB37Z" = "1" /* Supplement Thoracolumbar Vertebral Disc with Autologous Tissue Substitute, Percutaneous Approach */
"0RUB3JZ" = "1" /* Supplement Thoracolumbar Vertebral Disc with Synthetic Substitute, Percutaneous Approach */
"0RUB3KZ" = "1" /* Supplement Thoracolumbar Vertebral Disc with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RUB47Z" = "1" /* Supplement Thoracolumbar Vertebral Disc with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUB4JZ" = "1" /* Supplement Thoracolumbar Vertebral Disc with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUB4KZ" = "1" /* Supplement Thoracolumbar Vertebral Disc with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RW004Z" = "1" /* Revision of Internal Fixation Device in Occipital-cervical Joint, Open Approach */
"0RW00JZ" = "1" /* Revision of Synthetic Substitute in Occipital-cervical Joint, Open Approach */
"0RW034Z" = "1" /* Revision of Internal Fixation Device in Occipital-cervical Joint, Percutaneous Approach */
"0RW03JZ" = "1" /* Revision of Synthetic Substitute in Occipital-cervical Joint, Percutaneous Approach */
"0RW044Z" = "1" /* Revision of Internal Fixation Device in Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RW04JZ" = "1" /* Revision of Synthetic Substitute in Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RW104Z" = "1" /* Revision of Internal Fixation Device in Cervical Vertebral Joint, Open Approach */
"0RW10JZ" = "1" /* Revision of Synthetic Substitute in Cervical Vertebral Joint, Open Approach */
"0RW134Z" = "1" /* Revision of Internal Fixation Device in Cervical Vertebral Joint, Percutaneous Approach */
"0RW13JZ" = "1" /* Revision of Synthetic Substitute in Cervical Vertebral Joint, Percutaneous Approach */
"0RW144Z" = "1" /* Revision of Internal Fixation Device in Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW14JZ" = "1" /* Revision of Synthetic Substitute in Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW30JZ" = "1" /* Revision of Synthetic Substitute in Cervical Vertebral Disc, Open Approach */
"0RW33JZ" = "1" /* Revision of Synthetic Substitute in Cervical Vertebral Disc, Percutaneous Approach */
"0RW34JZ" = "1" /* Revision of Synthetic Substitute in Cervical Vertebral Disc, Percutaneous Endoscopic Approach */
"0RW404Z" = "1" /* Revision of Internal Fixation Device in Cervicothoracic Vertebral Joint, Open Approach */
"0RW40JZ" = "1" /* Revision of Synthetic Substitute in Cervicothoracic Vertebral Joint, Open Approach */
"0RW434Z" = "1" /* Revision of Internal Fixation Device in Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RW43JZ" = "1" /* Revision of Synthetic Substitute in Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RW444Z" = "1" /* Revision of Internal Fixation Device in Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW44JZ" = "1" /* Revision of Synthetic Substitute in Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW50JZ" = "1" /* Revision of Synthetic Substitute in Cervicothoracic Vertebral Disc, Open Approach */
"0RW53JZ" = "1" /* Revision of Synthetic Substitute in Cervicothoracic Vertebral Disc, Percutaneous Approach */
"0RW54JZ" = "1" /* Revision of Synthetic Substitute in Cervicothoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RW604Z" = "1" /* Revision of Internal Fixation Device in Thoracic Vertebral Joint, Open Approach */
"0RW60JZ" = "1" /* Revision of Synthetic Substitute in Thoracic Vertebral Joint, Open Approach */
"0RW634Z" = "1" /* Revision of Internal Fixation Device in Thoracic Vertebral Joint, Percutaneous Approach */
"0RW63JZ" = "1" /* Revision of Synthetic Substitute in Thoracic Vertebral Joint, Percutaneous Approach */
"0RW644Z" = "1" /* Revision of Internal Fixation Device in Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW64JZ" = "1" /* Revision of Synthetic Substitute in Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW90JZ" = "1" /* Revision of Synthetic Substitute in Thoracic Vertebral Disc, Open Approach */
"0RW93JZ" = "1" /* Revision of Synthetic Substitute in Thoracic Vertebral Disc, Percutaneous Approach */
"0RW94JZ" = "1" /* Revision of Synthetic Substitute in Thoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RWA04Z" = "1" /* Revision of Internal Fixation Device in Thoracolumbar Vertebral Joint, Open Approach */
"0RWA0JZ" = "1" /* Revision of Synthetic Substitute in Thoracolumbar Vertebral Joint, Open Approach */
"0RWA34Z" = "1" /* Revision of Internal Fixation Device in Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RWA3JZ" = "1" /* Revision of Synthetic Substitute in Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RWA44Z" = "1" /* Revision of Internal Fixation Device in Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RWA4JZ" = "1" /* Revision of Synthetic Substitute in Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RWB0JZ" = "1" /* Revision of Synthetic Substitute in Thoracolumbar Vertebral Disc, Open Approach */
"0RWB3JZ" = "1" /* Revision of Synthetic Substitute in Thoracolumbar Vertebral Disc, Percutaneous Approach */
"0RWB4JZ" = "1" /* Revision of Synthetic Substitute in Thoracolumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0SB00ZZ" = "1" /* Excision of Lumbar Vertebral Joint, Open Approach */
"0SB03ZZ" = "1" /* Excision of Lumbar Vertebral Joint, Percutaneous Approach */
"0SB04ZZ" = "1" /* Excision of Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SB30ZZ" = "1" /* Excision of Lumbosacral Joint, Open Approach */
"0SB33ZZ" = "1" /* Excision of Lumbosacral Joint, Percutaneous Approach */
"0SB34ZZ" = "1" /* Excision of Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SG0070" = "1" /* Fusion of Lumbar Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG0071" = "1" /* Fusion of Lumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0SG007J" = "1" /* Fusion of Lumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0SG00A0" = "1" /* Fusion of Lumbar Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0SG00A1" = "1" /* Fusion of Lumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Open Approach */
"0SG00AJ" = "1" /* Fusion of Lumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Open Approach */
"0SG00J0" = "1" /* Fusion of Lumbar Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG00J1" = "1" /* Fusion of Lumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Open Approach */
"0SG00JJ" = "1" /* Fusion of Lumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Open Approach */
"0SG00K0" = "1" /* Fusion of Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG00K1" = "1" /* Fusion of Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0SG00KJ" = "1" /* Fusion of Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0SG00Z0" = "1" /* Fusion of Lumbar Vertebral Joint, Anterior Approach, Anterior Column, Open Approach */
"0SG00Z1" = "1" /* Fusion of Lumbar Vertebral Joint, Posterior Approach, Posterior Column, Open Approach */
"0SG00ZJ" = "1" /* Fusion of Lumbar Vertebral Joint, Posterior Approach, Anterior Column, Open Approach */
"0SG0370" = "1" /* Fusion of Lumbar Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG0371" = "1" /* Fusion of Lumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG037J" = "1" /* Fusion of Lumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG03A0" = "1" /* Fusion of Lumbar Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG03A1" = "1" /* Fusion of Lumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG03AJ" = "1" /* Fusion of Lumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG03J0" = "1" /* Fusion of Lumbar Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG03J1" = "1" /* Fusion of Lumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG03JJ" = "1" /* Fusion of Lumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG03K0" = "1" /* Fusion of Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG03K1" = "1" /* Fusion of Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG03KJ" = "1" /* Fusion of Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG03Z0" = "1" /* Fusion of Lumbar Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG03Z1" = "1" /* Fusion of Lumbar Vertebral Joint, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG03ZJ" = "1" /* Fusion of Lumbar Vertebral Joint, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG0470" = "1" /* Fusion of Lumbar Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG0471" = "1" /* Fusion of Lumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG047J" = "1" /* Fusion of Lumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG04A0" = "1" /* Fusion of Lumbar Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG04A1" = "1" /* Fusion of Lumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG04AJ" = "1" /* Fusion of Lumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG04J0" = "1" /* Fusion of Lumbar Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG04J1" = "1" /* Fusion of Lumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG04JJ" = "1" /* Fusion of Lumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG04K0" = "1" /* Fusion of Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG04K1" = "1" /* Fusion of Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG04KJ" = "1" /* Fusion of Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG04Z0" = "1" /* Fusion of Lumbar Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG04Z1" = "1" /* Fusion of Lumbar Vertebral Joint, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG04ZJ" = "1" /* Fusion of Lumbar Vertebral Joint, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG1070" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG1071" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0SG107J" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0SG10A0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0SG10A1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Open Approach */
"0SG10AJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Open Approach */
"0SG10J0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG10J1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Open Approach */
"0SG10JJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Open Approach */
"0SG10K0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG10K1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0SG10KJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0SG10Z0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints, Anterior Approach, Anterior Column, Open Approach */
"0SG10Z1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints, Posterior Approach, Posterior Column, Open Approach */
"0SG10ZJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints, Posterior Approach, Anterior Column, Open Approach */
"0SG1370" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG1371" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG137J" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG13A0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG13A1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG13AJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG13J0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG13J1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG13JJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG13K0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG13K1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG13KJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG13Z0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG13Z1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG13ZJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG1470" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG1471" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG147J" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG14A0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG14A1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG14AJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG14J0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG14J1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG14JJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG14K0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG14K1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG14KJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG14Z0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG14Z1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG14ZJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG3070" = "1" /* Fusion of Lumbosacral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG3071" = "1" /* Fusion of Lumbosacral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0SG307J" = "1" /* Fusion of Lumbosacral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0SG30A0" = "1" /* Fusion of Lumbosacral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0SG30A1" = "1" /* Fusion of Lumbosacral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Open Approach */
"0SG30AJ" = "1" /* Fusion of Lumbosacral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Open Approach */
"0SG30J0" = "1" /* Fusion of Lumbosacral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG30J1" = "1" /* Fusion of Lumbosacral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Open Approach */
"0SG30JJ" = "1" /* Fusion of Lumbosacral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Open Approach */
"0SG30K0" = "1" /* Fusion of Lumbosacral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG30K1" = "1" /* Fusion of Lumbosacral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0SG30KJ" = "1" /* Fusion of Lumbosacral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0SG30Z0" = "1" /* Fusion of Lumbosacral Joint, Anterior Approach, Anterior Column, Open Approach */
"0SG30Z1" = "1" /* Fusion of Lumbosacral Joint, Posterior Approach, Posterior Column, Open Approach */
"0SG30ZJ" = "1" /* Fusion of Lumbosacral Joint, Posterior Approach, Anterior Column, Open Approach */
"0SG3370" = "1" /* Fusion of Lumbosacral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG3371" = "1" /* Fusion of Lumbosacral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG337J" = "1" /* Fusion of Lumbosacral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG33A0" = "1" /* Fusion of Lumbosacral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG33A1" = "1" /* Fusion of Lumbosacral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG33AJ" = "1" /* Fusion of Lumbosacral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG33J0" = "1" /* Fusion of Lumbosacral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG33J1" = "1" /* Fusion of Lumbosacral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG33JJ" = "1" /* Fusion of Lumbosacral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG33K0" = "1" /* Fusion of Lumbosacral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG33K1" = "1" /* Fusion of Lumbosacral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG33KJ" = "1" /* Fusion of Lumbosacral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG33Z0" = "1" /* Fusion of Lumbosacral Joint, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG33Z1" = "1" /* Fusion of Lumbosacral Joint, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG33ZJ" = "1" /* Fusion of Lumbosacral Joint, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG3470" = "1" /* Fusion of Lumbosacral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG3471" = "1" /* Fusion of Lumbosacral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG347J" = "1" /* Fusion of Lumbosacral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG34A0" = "1" /* Fusion of Lumbosacral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG34A1" = "1" /* Fusion of Lumbosacral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG34AJ" = "1" /* Fusion of Lumbosacral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG34J0" = "1" /* Fusion of Lumbosacral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG34J1" = "1" /* Fusion of Lumbosacral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG34JJ" = "1" /* Fusion of Lumbosacral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG34K0" = "1" /* Fusion of Lumbosacral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG34K1" = "1" /* Fusion of Lumbosacral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG34KJ" = "1" /* Fusion of Lumbosacral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG34Z0" = "1" /* Fusion of Lumbosacral Joint, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG34Z1" = "1" /* Fusion of Lumbosacral Joint, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG34ZJ" = "1" /* Fusion of Lumbosacral Joint, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SH00BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Lumbar Vertebral Joint, Open Approach */
"0SH00CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Lumbar Vertebral Joint, Open Approach */
"0SH00DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Lumbar Vertebral Joint, Open Approach */
"0SH03BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Lumbar Vertebral Joint, Percutaneous Approach */
"0SH03CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Lumbar Vertebral Joint, Percutaneous Approach */
"0SH03DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Lumbar Vertebral Joint, Percutaneous Approach */
"0SH04BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SH04CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SH04DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SH30BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Lumbosacral Joint, Open Approach */
"0SH30CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Lumbosacral Joint, Open Approach */
"0SH30DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Lumbosacral Joint, Open Approach */
"0SH33BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Lumbosacral Joint, Percutaneous Approach */
"0SH33CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Lumbosacral Joint, Percutaneous Approach */
"0SH33DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Lumbosacral Joint, Percutaneous Approach */
"0SH34BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SH34CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SH34DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SP004Z" = "1" /* Removal of Internal Fixation Device from Lumbar Vertebral Joint, Open Approach */
"0SP034Z" = "1" /* Removal of Internal Fixation Device from Lumbar Vertebral Joint, Percutaneous Approach */
"0SP044Z" = "1" /* Removal of Internal Fixation Device from Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SP20JZ" = "1" /* Removal of Synthetic Substitute from Lumbar Vertebral Disc, Open Approach */
"0SP304Z" = "1" /* Removal of Internal Fixation Device from Lumbosacral Joint, Open Approach */
"0SP334Z" = "1" /* Removal of Internal Fixation Device from Lumbosacral Joint, Percutaneous Approach */
"0SP344Z" = "1" /* Removal of Internal Fixation Device from Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SP40JZ" = "1" /* Removal of Synthetic Substitute from Lumbosacral Disc, Open Approach */
"0SQ20ZZ" = "1" /* Repair Lumbar Vertebral Disc, Open Approach */
"0SQ40ZZ" = "1" /* Repair Lumbosacral Disc, Open Approach */
"0SR20JZ" = "1" /* Replacement of Lumbar Vertebral Disc with Synthetic Substitute, Open Approach */
"0SR40JZ" = "1" /* Replacement of Lumbosacral Disc with Synthetic Substitute, Open Approach */
"0SU00JZ" = "1" /* Supplement Lumbar Vertebral Joint with Synthetic Substitute, Open Approach */
"0SU03JZ" = "1" /* Supplement Lumbar Vertebral Joint with Synthetic Substitute, Percutaneous Approach */
"0SU04JZ" = "1" /* Supplement Lumbar Vertebral Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SU207Z" = "1" /* Supplement Lumbar Vertebral Disc with Autologous Tissue Substitute, Open Approach */
"0SU20JZ" = "1" /* Supplement Lumbar Vertebral Disc with Synthetic Substitute, Open Approach */
"0SU20KZ" = "1" /* Supplement Lumbar Vertebral Disc with Nonautologous Tissue Substitute, Open Approach */
"0SU237Z" = "1" /* Supplement Lumbar Vertebral Disc with Autologous Tissue Substitute, Percutaneous Approach */
"0SU23JZ" = "1" /* Supplement Lumbar Vertebral Disc with Synthetic Substitute, Percutaneous Approach */
"0SU23KZ" = "1" /* Supplement Lumbar Vertebral Disc with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SU247Z" = "1" /* Supplement Lumbar Vertebral Disc with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SU24JZ" = "1" /* Supplement Lumbar Vertebral Disc with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SU24KZ" = "1" /* Supplement Lumbar Vertebral Disc with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SU30JZ" = "1" /* Supplement Lumbosacral Joint with Synthetic Substitute, Open Approach */
"0SU33JZ" = "1" /* Supplement Lumbosacral Joint with Synthetic Substitute, Percutaneous Approach */
"0SU34JZ" = "1" /* Supplement Lumbosacral Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SU407Z" = "1" /* Supplement Lumbosacral Disc with Autologous Tissue Substitute, Open Approach */
"0SU40JZ" = "1" /* Supplement Lumbosacral Disc with Synthetic Substitute, Open Approach */
"0SU40KZ" = "1" /* Supplement Lumbosacral Disc with Nonautologous Tissue Substitute, Open Approach */
"0SU437Z" = "1" /* Supplement Lumbosacral Disc with Autologous Tissue Substitute, Percutaneous Approach */
"0SU43JZ" = "1" /* Supplement Lumbosacral Disc with Synthetic Substitute, Percutaneous Approach */
"0SU43KZ" = "1" /* Supplement Lumbosacral Disc with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SU447Z" = "1" /* Supplement Lumbosacral Disc with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SU44JZ" = "1" /* Supplement Lumbosacral Disc with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SU44KZ" = "1" /* Supplement Lumbosacral Disc with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SW004Z" = "1" /* Revision of Internal Fixation Device in Lumbar Vertebral Joint, Open Approach */
"0SW00JZ" = "1" /* Revision of Synthetic Substitute in Lumbar Vertebral Joint, Open Approach */
"0SW034Z" = "1" /* Revision of Internal Fixation Device in Lumbar Vertebral Joint, Percutaneous Approach */
"0SW03JZ" = "1" /* Revision of Synthetic Substitute in Lumbar Vertebral Joint, Percutaneous Approach */
"0SW044Z" = "1" /* Revision of Internal Fixation Device in Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SW04JZ" = "1" /* Revision of Synthetic Substitute in Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SW20JZ" = "1" /* Revision of Synthetic Substitute in Lumbar Vertebral Disc, Open Approach */
"0SW23JZ" = "1" /* Revision of Synthetic Substitute in Lumbar Vertebral Disc, Percutaneous Approach */
"0SW24JZ" = "1" /* Revision of Synthetic Substitute in Lumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0SW304Z" = "1" /* Revision of Internal Fixation Device in Lumbosacral Joint, Open Approach */
"0SW30JZ" = "1" /* Revision of Synthetic Substitute in Lumbosacral Joint, Open Approach */
"0SW334Z" = "1" /* Revision of Internal Fixation Device in Lumbosacral Joint, Percutaneous Approach */
"0SW33JZ" = "1" /* Revision of Synthetic Substitute in Lumbosacral Joint, Percutaneous Approach */
"0SW344Z" = "1" /* Revision of Internal Fixation Device in Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SW34JZ" = "1" /* Revision of Synthetic Substitute in Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SW40JZ" = "1" /* Revision of Synthetic Substitute in Lumbosacral Disc, Open Approach */
"0SW43JZ" = "1" /* Revision of Synthetic Substitute in Lumbosacral Disc, Percutaneous Approach */
"0SW44JZ" = "1" /* Revision of Synthetic Substitute in Lumbosacral Disc, Percutaneous Endoscopic Approach */
Other = "0"
;

/* Diagnosis codeset TECHNID last updated 160922 for IDC10 v60rev3 */
Value $TECHNID
"D7811" = "1" /* Accidental puncture and laceration of the spleen during a procedure on the spleen */
"D7812" = "1" /* Accidental puncture and laceration of the spleen during other procedure */
"E3611" = "1" /* Accidental puncture and laceration of an endocrine system organ or structure during an endocrine system procedure */
"E3612" = "1" /* Accidental puncture and laceration of an endocrine system organ or structure during other procedure */
"G9748" = "1" /* Accidental puncture and laceration of other nervous system organ or structure during a nervous system procedure */
"G9749" = "1" /* Accidental puncture and laceration of other nervous system organ or structure during other procedure */
"H59211" = "1" /* Accidental puncture and laceration of right eye and adnexa during an ophthalmic procedure */
"H59212" = "1" /* Accidental puncture and laceration of left eye and adnexa during an ophthalmic procedure */
"H59213" = "1" /* Accidental puncture and laceration of eye and adnexa during an ophthalmic procedure, bilateral */
"H59219" = "1" /* Accidental puncture and laceration of unspecified eye and adnexa during an ophthalmic procedure */
"H59221" = "1" /* Accidental puncture and laceration of right eye and adnexa during other procedure */
"H59222" = "1" /* Accidental puncture and laceration of left eye and adnexa during other procedure */
"H59223" = "1" /* Accidental puncture and laceration of eye and adnexa during other procedure, bilateral */
"H59229" = "1" /* Accidental puncture and laceration of unspecified eye and adnexa during other procedure */
"H9531" = "1" /* Accidental puncture and laceration of the ear and mastoid process during a procedure on the ear and mastoid process */
"H9532" = "1" /* Accidental puncture and laceration of the ear and mastoid process during other procedure */
"I9751" = "1" /* Accidental puncture and laceration of a circulatory system organ or structure during a circulatory system procedure */
"I9752" = "1" /* Accidental puncture and laceration of a circulatory system organ or structure during other procedure */
"J9571" = "1" /* Accidental puncture and laceration of a respiratory system organ or structure during a respiratory system procedure */
"J9572" = "1" /* Accidental puncture and laceration of a respiratory system organ or structure during other procedure */
"K9171" = "1" /* Accidental puncture and laceration of a digestive system organ or structure during a digestive system procedure */
"K9172" = "1" /* Accidental puncture and laceration of a digestive system organ or structure during other procedure */
"L7611" = "1" /* Accidental puncture and laceration of skin and subcutaneous tissue during a dermatologic procedure */
"L7612" = "1" /* Accidental puncture and laceration of skin and subcutaneous tissue during other procedure */
"M96820" = "1" /* Accidental puncture and laceration of a musculoskeletal structure during a musculoskeletal system procedure */
"M96821" = "1" /* Accidental puncture and laceration of a musculoskeletal structure during other procedure */
"N9971" = "1" /* Accidental puncture and laceration of a genitourinary system organ or structure during a genitourinary system procedure */
"N9972" = "1" /* Accidental puncture and laceration of a genitourinary system organ or structure during other procedure */
Other = "0"
;

/* Procedure codeset TRACHIP last updated 160922 for IDC10 v60rev3 */
Value $TRACHIP
"0B110F4" = "1" /* Bypass Trachea to Cutaneous with Tracheostomy Device, Open Approach */
"0B110Z4" = "1" /* Bypass Trachea to Cutaneous, Open Approach */
"0B113F4" = "1" /* Bypass Trachea to Cutaneous with Tracheostomy Device, Percutaneous Approach */
"0B113Z4" = "1" /* Bypass Trachea to Cutaneous, Percutaneous Approach */
"0B114F4" = "1" /* Bypass Trachea to Cutaneous with Tracheostomy Device, Percutaneous Endoscopic Approach */
"0B114Z4" = "1" /* Bypass Trachea to Cutaneous, Percutaneous Endoscopic Approach */
"0BW10FZ" = "1" /* Revision of Tracheostomy Device in Trachea, Open Approach */
"0BW13FZ" = "1" /* Revision of Tracheostomy Device in Trachea, Percutaneous Approach */
"0BW14FZ" = "1" /* Revision of Tracheostomy Device in Trachea, Percutaneous Endoscopic Approach */
"0WB6XZ2" = "1" /* Excision of Neck, Stoma, External Approach */
Other = "0"
;

/* Diagnosis codeset TRANFID last updated 160922 for IDC10 v60rev3 */
Value $TRANFID
"T8030XA" = "1" /* ABO incompatibility reaction due to transfusion of blood or blood products, unspecified, initial encounter */
"T80310A" = "1" /* ABO incompatibility with acute hemolytic transfusion reaction, initial encounter */
"T80311A" = "1" /* ABO incompatibility with delayed hemolytic transfusion reaction, initial encounter */
"T80319A" = "1" /* ABO incompatibility with hemolytic transfusion reaction, unspecified, initial encounter */
"T8039XA" = "1" /* Other ABO incompatibility reaction due to transfusion of blood or blood products, initial encounter */
"T8040XA" = "1" /* Rh incompatibility reaction due to transfusion of blood or blood products, unspecified, initial encounter */
"T80410A" = "1" /* Rh incompatibility with acute hemolytic transfusion reaction, initial encounter */
"T80411A" = "1" /* Rh incompatibility with delayed hemolytic transfusion reaction, initial encounter */
"T80419A" = "1" /* Rh incompatibility with hemolytic transfusion reaction, unspecified, initial encounter */
"T8049XA" = "1" /* Other Rh incompatibility reaction due to transfusion of blood or blood products, initial encounter */
Other = "0"
;

/* Diagnosis codeset UMBHERND last updated 160922 for IDC10 v60rev3 */
Value $UMBHERND
"Q792" = "1" /* Exomphalos - Other congenital anomalies */
"Q793" = "1" /* Gastroschisis - Other congenital anomalies */
Other = "0"
;

/* Diagnosis codeset ACDIASD last updated 161203 for ICD10 v70rev0 */
Value $ACDIASD
"E1010" = "1" /* Type 1 diabetes mellitus with ketoacidosis without coma */
"E1011" = "1" /* Type 1 diabetes mellitus with ketoacidosis with coma */
"E10641" = "1" /* Type 1 diabetes mellitus with hypoglycemia with coma */
"E1100" = "1" /* Type 2 diabetes mellitus with hyperosmolarity without nonketotic hyperglycemic-hyperosmolar coma (NKHHC) */
"E1101" = "1" /* Type 2 diabetes mellitus with hyperosmolarity with coma */
"E11641" = "1" /* Type 2 diabetes mellitus with hypoglycemia with coma */
Other = "0"
;

/* Diagnosis codeset ACGDISD last updated 170530 for ICD10 v70rev2 */
Value $ACGDISD
"K5000" = "1" /* Crohn's disease of small intestine without complications */
"K50011" = "1" /* Crohn's disease of small intestine with rectal bleeding */
"K50012" = "1" /* Crohn's disease of small intestine with intestinal obstruction */
"K50013" = "1" /* Crohn's disease of small intestine with fistula */
"K50014" = "1" /* Crohn's disease of small intestine with abscess */
"K50018" = "1" /* Crohn's disease of small intestine with other complication */
"K50019" = "1" /* Crohn's disease of small intestine with unspecified complications */
"K5010" = "1" /* Crohn's disease of large intestine without complications */
"K50111" = "1" /* Crohn's disease of large intestine with rectal bleeding */
"K50112" = "1" /* Crohn's disease of large intestine with intestinal obstruction */
"K50113" = "1" /* Crohn's disease of large intestine with fistula */
"K50114" = "1" /* Crohn's disease of large intestine with abscess */
"K50118" = "1" /* Crohn's disease of large intestine with other complication */
"K50119" = "1" /* Crohn's disease of large intestine with unspecified complications */
"K5080" = "1" /* Crohn's disease of both small and large intestine without complications */
"K50811" = "1" /* Crohn's disease of both small and large intestine with rectal bleeding */
"K50812" = "1" /* Crohn's disease of both small and large intestine with intestinal obstruction */
"K50813" = "1" /* Crohn's disease of both small and large intestine with fistula */
"K50814" = "1" /* Crohn's disease of both small and large intestine with abscess */
"K50818" = "1" /* Crohn's disease of both small and large intestine with other complication */
"K50819" = "1" /* Crohn's disease of both small and large intestine with unspecified complications */
"K5090" = "1" /* Crohn's disease, unspecified, without complications */
"K50911" = "1" /* Crohn's disease, unspecified, with rectal bleeding */
"K50912" = "1" /* Crohn's disease, unspecified, with intestinal obstruction */
"K50913" = "1" /* Crohn's disease, unspecified, with fistula */
"K50914" = "1" /* Crohn's disease, unspecified, with abscess */
"K50918" = "1" /* Crohn's disease, unspecified, with other complication */
"K50919" = "1" /* Crohn's disease, unspecified, with unspecified complications */
"K5100" = "1" /* Ulcerative (chronic) pancolitis without complications */
"K51011" = "1" /* Ulcerative (chronic) pancolitis with rectal bleeding */
"K51012" = "1" /* Ulcerative (chronic) pancolitis with intestinal obstruction */
"K51013" = "1" /* Ulcerative (chronic) pancolitis with fistula */
"K51014" = "1" /* Ulcerative (chronic) pancolitis with abscess */
"K51018" = "1" /* Ulcerative (chronic) pancolitis with other complication */
"K51019" = "1" /* Ulcerative (chronic) pancolitis with unspecified complications */
"K5120" = "1" /* Ulcerative (chronic) proctitis without complications */
"K51211" = "1" /* Ulcerative (chronic) proctitis with rectal bleeding */
"K51212" = "1" /* Ulcerative (chronic) proctitis with intestinal obstruction */
"K51213" = "1" /* Ulcerative (chronic) proctitis with fistula */
"K51214" = "1" /* Ulcerative (chronic) proctitis with abscess */
"K51218" = "1" /* Ulcerative (chronic) proctitis with other complication */
"K51219" = "1" /* Ulcerative (chronic) proctitis with unspecified complications */
"K5130" = "1" /* Ulcerative (chronic) rectosigmoiditis without complications */
"K51311" = "1" /* Ulcerative (chronic) rectosigmoiditis with rectal bleeding */
"K51312" = "1" /* Ulcerative (chronic) rectosigmoiditis with intestinal obstruction */
"K51313" = "1" /* Ulcerative (chronic) rectosigmoiditis with fistula */
"K51314" = "1" /* Ulcerative (chronic) rectosigmoiditis with abscess */
"K51318" = "1" /* Ulcerative (chronic) rectosigmoiditis with other complication */
"K51319" = "1" /* Ulcerative (chronic) rectosigmoiditis with unspecified complications */
"K5140" = "1" /* Inflammatory polyps of colon without complications */
"K51411" = "1" /* Inflammatory polyps of colon with rectal bleeding */
"K51412" = "1" /* Inflammatory polyps of colon with intestinal obstruction */
"K51413" = "1" /* Inflammatory polyps of colon with fistula */
"K51414" = "1" /* Inflammatory polyps of colon with abscess */
"K51418" = "1" /* Inflammatory polyps of colon with other complication */
"K51419" = "1" /* Inflammatory polyps of colon with unspecified complications */
"K5150" = "1" /* Left sided colitis without complications */
"K51511" = "1" /* Left sided colitis with rectal bleeding */
"K51512" = "1" /* Left sided colitis with intestinal obstruction */
"K51513" = "1" /* Left sided colitis with fistula */
"K51514" = "1" /* Left sided colitis with abscess */
"K51518" = "1" /* Left sided colitis with other complication */
"K51519" = "1" /* Left sided colitis with unspecified complications */
"K5180" = "1" /* Other ulcerative colitis without complications */
"K51811" = "1" /* Other ulcerative colitis with rectal bleeding */
"K51812" = "1" /* Other ulcerative colitis with intestinal obstruction */
"K51813" = "1" /* Other ulcerative colitis with fistula */
"K51814" = "1" /* Other ulcerative colitis with abscess */
"K51818" = "1" /* Other ulcerative colitis with other complication */
"K51819" = "1" /* Other ulcerative colitis with unspecified complications */
"K5190" = "1" /* Ulcerative colitis, unspecified, without complications */
"K51911" = "1" /* Ulcerative colitis, unspecified with rectal bleeding */
"K51912" = "1" /* Ulcerative colitis, unspecified with intestinal obstruction */
"K51913" = "1" /* Ulcerative colitis, unspecified with fistula */
"K51914" = "1" /* Ulcerative colitis, unspecified with abscess */
"K51918" = "1" /* Ulcerative colitis, unspecified with other complication */
"K51919" = "1" /* Ulcerative colitis, unspecified with unspecified complications */
"K520" = "1" /* Gastroenteritis and colitis due to radiation */
"K521" = "1" /* Toxic gastroenteritis and colitis */
"K522" = "1" /* Allergic and dietetic gastroenteritis and colitis */
"K5221" = "1" /* Food protein-induced enterocolitis syndrome */
"K5222" = "1" /* Food protein-induced enteropathy */
"K5229" = "1" /* Other allergic and dietetic gastroenteritis and colitis */
"K5281" = "1" /* Eosinophilic gastritis or gastroenteritis */
"K5282" = "1" /* Eosinophilic colitis */
"K52831" = "1" /* Collagenous colitis */
"K52832" = "1" /* Lymphocytic colitis */
"K52838" = "1" /* Other microscopic colitis */
"K52839" = "1" /* Microscopic colitis, unspecified */
"K900" = "1" /* Celiac disease */
"K901" = "1" /* Tropical sprue */
"K902" = "1" /* Blind loop syndrome, not elsewhere classified */
"K903" = "1" /* Pancreatic steatorrhea */
"K904" = "1" /* Malabsorption due to intolerance, not elsewhere classified */
"K9041" = "1" /* Non-celiac gluten sensitivity */
"K9049" = "1" /* Malabsorption due to intolerance, not elsewhere classified */
"K9089" = "1" /* Other intestinal malabsorption */
"K909" = "1" /* Intestinal malabsorption, unspecified */
"K912" = "1" /* Postsurgical malabsorption, not elsewhere classified */
"K9281" = "1" /* Gastrointestinal mucositis (ulcerative) */
Other = "0"
;

/* Diagnosis codeset ACPGASD last updated 161203 for ICD10 v70rev0 */
Value $ACPGASD
"A080" = "1" /* Rotaviral enteritis */
"A0811" = "1" /* Acute gastroenteropathy due to Norwalk agent */
"A0819" = "1" /* Acute gastroenteropathy due to other small round viruses */
"A082" = "1" /* Adenoviral enteritis */
"A0831" = "1" /* Calicivirus enteritis */
"A0832" = "1" /* Astrovirus enteritis */
"A0839" = "1" /* Other viral enteritis */
"A084" = "1" /* Viral intestinal infection, unspecified */
"A088" = "1" /* Other specified intestinal infections */
"A09" = "1" /* Infectious gastroenteritis and colitis, unspecified */
"K523" = "1" /* Indeterminate colitis */
"K5289" = "1" /* Other specified noninfective gastroenteritis and colitis */
"K529" = "1" /* Noninfective gastroenteritis and colitis, unspecified */
Other = "0"
;

/* Diagnosis codeset ACSUTID last updated 161230 for ICD10 v70rev0 */
Value $ACSUTID
"N10" = "1" /* Acute pyelonephritis */
"N119" = "1" /* Chronic tubulo-interstitial nephritis, unspecified */
"N12" = "1" /* Tubulo-interstitial nephritis, not specified as acute or chronic */
"N151" = "1" /* Renal and perinephric abscess */
"N159" = "1" /* Renal tubulo-interstitial disease, unspecified */
"N16" = "1" /* Renal tubulo-interstitial disorders in diseases classified elsewhere */
"N2884" = "1" /* Pyelitis cystica */
"N2885" = "1" /* Pyeloureteritis cystica */
"N2886" = "1" /* Ureteritis cystica */
"N3000" = "1" /* Acute cystitis without hematuria */
"N3001" = "1" /* Acute cystitis with hematuria */
"N3090" = "1" /* Cystitis, unspecified without hematuria */
"N3091" = "1" /* Cystitis, unspecified with hematuria */
"N390" = "1" /* Urinary tract infection, site not specified */
Other = "0"
;

/* Diagnosis codeset BSI2DX last updated 161203 for ICD10 v70rev0 */
Value $BSI2DX
"P368" = "1" /* Other bacterial sepsis of newborn */
"R7881" = "1" /* Bacteremia */
Other = "0"
;

/* Diagnosis codeset BSI5DX last updated 161203 for ICD10 v70rev0 */
Value $BSI5DX
"P3619" = "1" /* Sepsis of newborn due to other streptococci */
"P362" = "1" /* Sepsis of newborn due to Staphylococcus aureus */
"P3630" = "1" /* Sepsis of newborn due to unspecified staphylococci */
"P3639" = "1" /* Sepsis of newborn due to other staphylococci */
"P364" = "1" /* Sepsis of newborn due to Escherichia coli */
Other = "0"
;

/* Diagnosis codeset BURNDX last updated 161201 for ICD10 v70rev0 */
Value $BURNDX
"T3120" = "1" /* Burns involving 20-29% of body surface with 0% to 9% third degree burns */
"T3121" = "1" /* Burns involving 20-29% of body surface with 10-19% third degree burns */
"T3122" = "1" /* Burns involving 20-29% of body surface with 20-29% third degree burns */
"T3130" = "1" /* Burns involving 30-39% of body surface with 0% to 9% third degree burns */
"T3131" = "1" /* Burns involving 30-39% of body surface with 10-19% third degree burns */
"T3132" = "1" /* Burns involving 30-39% of body surface with 20-29% third degree burns */
"T3133" = "1" /* Burns involving 30-39% of body surface with 30-39% third degree burns */
"T3140" = "1" /* Burns involving 40-49% of body surface with 0% to 9% third degree burns */
"T3141" = "1" /* Burns involving 40-49% of body surface with 10-19% third degree burns */
"T3142" = "1" /* Burns involving 40-49% of body surface with 20-29% third degree burns */
"T3143" = "1" /* Burns involving 40-49% of body surface with 30-39% third degree burns */
"T3144" = "1" /* Burns involving 40-49% of body surface with 40-49% third degree burns */
"T3150" = "1" /* Burns involving 50-59% of body surface with 0% to 9% third degree burns */
"T3151" = "1" /* Burns involving 50-59% of body surface with 10-19% third degree burns */
"T3152" = "1" /* Burns involving 50-59% of body surface with 20-29% third degree burns */
"T3153" = "1" /* Burns involving 50-59% of body surface with 30-39% third degree burns */
"T3154" = "1" /* Burns involving 50-59% of body surface with 40-49% third degree burns */
"T3155" = "1" /* Burns involving 50-59% of body surface with 50-59% third degree burns */
"T3160" = "1" /* Burns involving 60-69% of body surface with 0% to 9% third degree burns */
"T3161" = "1" /* Burns involving 60-69% of body surface with 10-19% third degree burns */
"T3162" = "1" /* Burns involving 60-69% of body surface with 20-29% third degree burns */
"T3163" = "1" /* Burns involving 60-69% of body surface with 30-39% third degree burns */
"T3164" = "1" /* Burns involving 60-69% of body surface with 40-49% third degree burns */
"T3165" = "1" /* Burns involving 60-69% of body surface with 50-59% third degree burns */
"T3166" = "1" /* Burns involving 60-69% of body surface with 60-69% third degree burns */
"T3170" = "1" /* Burns involving 70-79% of body surface with 0% to 9% third degree burns */
"T3171" = "1" /* Burns involving 70-79% of body surface with 10-19% third degree burns */
"T3172" = "1" /* Burns involving 70-79% of body surface with 20-29% third degree burns */
"T3173" = "1" /* Burns involving 70-79% of body surface with 30-39% third degree burns */
"T3174" = "1" /* Burns involving 70-79% of body surface with 40-49% third degree burns */
"T3175" = "1" /* Burns involving 70-79% of body surface with 50-59% third degree burns */
"T3176" = "1" /* Burns involving 70-79% of body surface with 60-69% third degree burns */
"T3177" = "1" /* Burns involving 70-79% of body surface with 70-79% third degree burns */
"T3180" = "1" /* Burns involving 80-89% of body surface with 0% to 9% third degree burns */
"T3181" = "1" /* Burns involving 80-89% of body surface with 10-19% third degree burns */
"T3182" = "1" /* Burns involving 80-89% of body surface with 20-29% third degree burns */
"T3183" = "1" /* Burns involving 80-89% of body surface with 30-39% third degree burns */
"T3184" = "1" /* Burns involving 80-89% of body surface with 40-49% third degree burns */
"T3185" = "1" /* Burns involving 80-89% of body surface with 50-59% third degree burns */
"T3186" = "1" /* Burns involving 80-89% of body surface with 60-69% third degree burns */
"T3187" = "1" /* Burns involving 80-89% of body surface with 70-79% third degree burns */
"T3188" = "1" /* Burns involving 80-89% of body surface with 80-89% third degree burns */
"T3190" = "1" /* Burns involving 90% or more of body surface with 0% to 9% third degree burns */
"T3191" = "1" /* Burns involving 90% or more of body surface with 10-19% third degree burns */
"T3192" = "1" /* Burns involving 90% or more of body surface with 20-29% third degree burns */
"T3193" = "1" /* Burns involving 90% or more of body surface with 30-39% third degree burns */
"T3194" = "1" /* Burns involving 90% or more of body surface with 40-49% third degree burns */
"T3195" = "1" /* Burns involving 90% or more of body surface with 50-59% third degree burns */
"T3196" = "1" /* Burns involving 90% or more of body surface with 60-69% third degree burns */
"T3197" = "1" /* Burns involving 90% or more of body surface with 70-79% third degree burns */
"T3198" = "1" /* Burns involving 90% or more of body surface with 80-89% third degree burns */
"T3199" = "1" /* Burns involving 90% or more of body surface with 90% or more third degree burns */
"T3220" = "1" /* Corrosions involving 20-29% of body surface with 0% to 9% third degree corrosion */
"T3221" = "1" /* Corrosions involving 20-29% of body surface with 10-19% third degree corrosion */
"T3222" = "1" /* Corrosions involving 20-29% of body surface with 20-29% third degree corrosion */
"T3230" = "1" /* Corrosions involving 30-39% of body surface with 0% to 9% third degree corrosion */
"T3231" = "1" /* Corrosions involving 30-39% of body surface with 10-19% third degree corrosion */
"T3232" = "1" /* Corrosions involving 30-39% of body surface with 20-29% third degree corrosion */
"T3233" = "1" /* Corrosions involving 30-39% of body surface with 30-39% third degree corrosion */
"T3240" = "1" /* Corrosions involving 40-49% of body surface with 0% to 9% third degree corrosion */
"T3241" = "1" /* Corrosions involving 40-49% of body surface with 10-19% third degree corrosion */
"T3242" = "1" /* Corrosions involving 40-49% of body surface with 20-29% third degree corrosion */
"T3243" = "1" /* Corrosions involving 40-49% of body surface with 30-39% third degree corrosion */
"T3244" = "1" /* Corrosions involving 40-49% of body surface with 40-49% third degree corrosion */
"T3250" = "1" /* Corrosions involving 50-59% of body surface with 0% to 9% third degree corrosion */
"T3251" = "1" /* Corrosions involving 50-59% of body surface with 10-19% third degree corrosion */
"T3252" = "1" /* Corrosions involving 50-59% of body surface with 20-29% third degree corrosion */
"T3253" = "1" /* Corrosions involving 50-59% of body surface with 30-39% third degree corrosion */
"T3254" = "1" /* Corrosions involving 50-59% of body surface with 40-49% third degree corrosion */
"T3255" = "1" /* Corrosions involving 50-59% of body surface with 50-59% third degree corrosion */
"T3260" = "1" /* Corrosions involving 60-69% of body surface with 0% to 9% third degree corrosion */
"T3261" = "1" /* Corrosions involving 60-69% of body surface with 10-19% third degree corrosion */
"T3262" = "1" /* Corrosions involving 60-69% of body surface with 20-29% third degree corrosion */
"T3263" = "1" /* Corrosions involving 60-69% of body surface with 30-39% third degree corrosion */
"T3264" = "1" /* Corrosions involving 60-69% of body surface with 40-49% third degree corrosion */
"T3265" = "1" /* Corrosions involving 60-69% of body surface with 50-59% third degree corrosion */
"T3266" = "1" /* Corrosions involving 60-69% of body surface with 60-69% third degree corrosion */
"T3270" = "1" /* Corrosions involving 70-79% of body surface with 0% to 9% third degree corrosion */
"T3271" = "1" /* Corrosions involving 70-79% of body surface with 10-19% third degree corrosion */
"T3272" = "1" /* Corrosions involving 70-79% of body surface with 20-29% third degree corrosion */
"T3273" = "1" /* Corrosions involving 70-79% of body surface with 30-39% third degree corrosion */
"T3274" = "1" /* Corrosions involving 70-79% of body surface with 40-49% third degree corrosion */
"T3275" = "1" /* Corrosions involving 70-79% of body surface with 50-59% third degree corrosion */
"T3276" = "1" /* Corrosions involving 70-79% of body surface with 60-69% third degree corrosion */
"T3277" = "1" /* Corrosions involving 70-79% of body surface with 70-79% third degree corrosion */
"T3280" = "1" /* Corrosions involving 80-89% of body surface with 0% to 9% third degree corrosion */
"T3281" = "1" /* Corrosions involving 80-89% of body surface with 10-19% third degree corrosion */
"T3282" = "1" /* Corrosions involving 80-89% of body surface with 20-29% third degree corrosion */
"T3283" = "1" /* Corrosions involving 80-89% of body surface with 30-39% third degree corrosion */
"T3284" = "1" /* Corrosions involving 80-89% of body surface with 40-49% third degree corrosion */
"T3285" = "1" /* Corrosions involving 80-89% of body surface with 50-59% third degree corrosion */
"T3286" = "1" /* Corrosions involving 80-89% of body surface with 60-69% third degree corrosion */
"T3287" = "1" /* Corrosions involving 80-89% of body surface with 70-79% third degree corrosion */
"T3288" = "1" /* Corrosions involving 80-89% of body surface with 80-89% third degree corrosion */
"T3290" = "1" /* Corrosions involving 90% or more of body surface with 0% to 9% third degree corrosion */
"T3291" = "1" /* Corrosions involving 90% or more of body surface with 10-19% third degree corrosion */
"T3292" = "1" /* Corrosions involving 90% or more of body surface with 20-29% third degree corrosion */
"T3293" = "1" /* Corrosions involving 90% or more of body surface with 30-39% third degree corrosion */
"T3294" = "1" /* Corrosions involving 90% or more of body surface with 40-49% third degree corrosion */
"T3295" = "1" /* Corrosions involving 90% or more of body surface with 50-59% third degree corrosion */
"T3296" = "1" /* Corrosions involving 90% or more of body surface with 60-69% third degree corrosion */
"T3297" = "1" /* Corrosions involving 90% or more of body surface with 70-79% third degree corrosion */
"T3298" = "1" /* Corrosions involving 90% or more of body surface with 80-89% third degree corrosion */
"T3299" = "1" /* Corrosions involving 90% or more of body surface with 90% or more third degree corrosion */
Other = "0"
;

/* Diagnosis codeset CANITD last updated 161230 for ICD10 v70rev0 */
Value $CANITD
"C000" = "1" /* Malignant neoplasm of external upper lip */
"C001" = "1" /* Malignant neoplasm of external lower lip */
"C002" = "1" /* Malignant neoplasm of external lip, unspecified */
"C003" = "1" /* Malignant neoplasm of upper lip, inner aspect */
"C004" = "1" /* Malignant neoplasm of lower lip, inner aspect */
"C005" = "1" /* Malignant neoplasm of lip, unspecified, inner aspect */
"C006" = "1" /* Malignant neoplasm of commissure of lip, unspecified */
"C008" = "1" /* Malignant neoplasm of overlapping sites of lip */
"C009" = "1" /* Malignant neoplasm of lip, unspecified */
"C01" = "1" /* Malignant neoplasm of base of tongue */
"C020" = "1" /* Malignant neoplasm of dorsal surface of tongue */
"C021" = "1" /* Malignant neoplasm of border of tongue */
"C022" = "1" /* Malignant neoplasm of ventral surface of tongue */
"C023" = "1" /* Malignant neoplasm of anterior two-thirds of tongue, part unspecified */
"C024" = "1" /* Malignant neoplasm of lingual tonsil */
"C028" = "1" /* Malignant neoplasm of overlapping sites of tongue */
"C029" = "1" /* Malignant neoplasm of tongue, unspecified */
"C030" = "1" /* Malignant neoplasm of upper gum */
"C031" = "1" /* Malignant neoplasm of lower gum */
"C039" = "1" /* Malignant neoplasm of gum, unspecified */
"C040" = "1" /* Malignant neoplasm of anterior floor of mouth */
"C041" = "1" /* Malignant neoplasm of lateral floor of mouth */
"C048" = "1" /* Malignant neoplasm of overlapping sites of floor of mouth */
"C049" = "1" /* Malignant neoplasm of floor of mouth, unspecified */
"C050" = "1" /* Malignant neoplasm of hard palate */
"C051" = "1" /* Malignant neoplasm of soft palate */
"C052" = "1" /* Malignant neoplasm of uvula */
"C058" = "1" /* Malignant neoplasm of overlapping sites of palate */
"C059" = "1" /* Malignant neoplasm of palate, unspecified */
"C060" = "1" /* Malignant neoplasm of cheek mucosa */
"C061" = "1" /* Malignant neoplasm of vestibule of mouth */
"C062" = "1" /* Malignant neoplasm of retromolar area */
"C0680" = "1" /* Malignant neoplasm of overlapping sites of unspecified parts of mouth */
"C0689" = "1" /* Malignant neoplasm of overlapping sites of other parts of mouth */
"C069" = "1" /* Malignant neoplasm of mouth, unspecified */
"C07" = "1" /* Malignant neoplasm of parotid gland */
"C080" = "1" /* Malignant neoplasm of submandibular gland */
"C081" = "1" /* Malignant neoplasm of sublingual gland */
"C089" = "1" /* Malignant neoplasm of major salivary gland, unspecified */
"C090" = "1" /* Malignant neoplasm of tonsillar fossa */
"C091" = "1" /* Malignant neoplasm of tonsillar pillar (anterior) (posterior) */
"C098" = "1" /* Malignant neoplasm of overlapping sites of tonsil */
"C099" = "1" /* Malignant neoplasm of tonsil, unspecified */
"C100" = "1" /* Malignant neoplasm of vallecula */
"C101" = "1" /* Malignant neoplasm of anterior surface of epiglottis */
"C102" = "1" /* Malignant neoplasm of lateral wall of oropharynx */
"C103" = "1" /* Malignant neoplasm of posterior wall of oropharynx */
"C104" = "1" /* Malignant neoplasm of branchial cleft */
"C108" = "1" /* Malignant neoplasm of overlapping sites of oropharynx */
"C109" = "1" /* Malignant neoplasm of oropharynx, unspecified */
"C110" = "1" /* Malignant neoplasm of superior wall of nasopharynx */
"C111" = "1" /* Malignant neoplasm of posterior wall of nasopharynx */
"C112" = "1" /* Malignant neoplasm of lateral wall of nasopharynx */
"C113" = "1" /* Malignant neoplasm of anterior wall of nasopharynx */
"C118" = "1" /* Malignant neoplasm of overlapping sites of nasopharynx */
"C119" = "1" /* Malignant neoplasm of nasopharynx, unspecified */
"C12" = "1" /* Malignant neoplasm of pyriform sinus */
"C130" = "1" /* Malignant neoplasm of postcricoid region */
"C131" = "1" /* Malignant neoplasm of aryepiglottic fold, hypopharyngeal aspect */
"C132" = "1" /* Malignant neoplasm of posterior wall of hypopharynx */
"C138" = "1" /* Malignant neoplasm of overlapping sites of hypopharynx */
"C139" = "1" /* Malignant neoplasm of hypopharynx, unspecified */
"C140" = "1" /* Malignant neoplasm of pharynx, unspecified */
"C142" = "1" /* Malignant neoplasm of Waldeyer's ring */
"C148" = "1" /* Malignant neoplasm of overlapping sites of lip, oral cavity and pharynx */
"C153" = "1" /* Malignant neoplasm of upper third of esophagus */
"C154" = "1" /* Malignant neoplasm of middle third of esophagus */
"C155" = "1" /* Malignant neoplasm of lower third of esophagus */
"C158" = "1" /* Malignant neoplasm of overlapping sites of esophagus */
"C159" = "1" /* Malignant neoplasm of esophagus, unspecified */
"C160" = "1" /* Malignant neoplasm of cardia */
"C161" = "1" /* Malignant neoplasm of fundus of stomach */
"C162" = "1" /* Malignant neoplasm of body of stomach */
"C163" = "1" /* Malignant neoplasm of pyloric antrum */
"C164" = "1" /* Malignant neoplasm of pylorus */
"C165" = "1" /* Malignant neoplasm of lesser curvature of stomach, unspecified */
"C166" = "1" /* Malignant neoplasm of greater curvature of stomach, unspecified */
"C168" = "1" /* Malignant neoplasm of overlapping sites of stomach */
"C169" = "1" /* Malignant neoplasm of stomach, unspecified */
"C170" = "1" /* Malignant neoplasm of duodenum */
"C171" = "1" /* Malignant neoplasm of jejunum */
"C172" = "1" /* Malignant neoplasm of ileum */
"C173" = "1" /* Meckel's diverticulum, malignant */
"C178" = "1" /* Malignant neoplasm of overlapping sites of small intestine */
"C179" = "1" /* Malignant neoplasm of small intestine, unspecified */
"C180" = "1" /* Malignant neoplasm of cecum */
"C181" = "1" /* Malignant neoplasm of appendix */
"C182" = "1" /* Malignant neoplasm of ascending colon */
"C183" = "1" /* Malignant neoplasm of hepatic flexure */
"C184" = "1" /* Malignant neoplasm of transverse colon */
"C185" = "1" /* Malignant neoplasm of splenic flexure */
"C186" = "1" /* Malignant neoplasm of descending colon */
"C187" = "1" /* Malignant neoplasm of sigmoid colon */
"C188" = "1" /* Malignant neoplasm of overlapping sites of colon */
"C189" = "1" /* Malignant neoplasm of colon, unspecified */
"C19" = "1" /* Malignant neoplasm of rectosigmoid junction */
"C20" = "1" /* Malignant neoplasm of rectum */
"C210" = "1" /* Malignant neoplasm of anus, unspecified */
"C211" = "1" /* Malignant neoplasm of anal canal */
"C212" = "1" /* Malignant neoplasm of cloacogenic zone */
"C218" = "1" /* Malignant neoplasm of overlapping sites of rectum, anus and anal canal */
"C220" = "1" /* Liver cell carcinoma */
"C221" = "1" /* Intrahepatic bile duct carcinoma */
"C222" = "1" /* Hepatoblastoma */
"C223" = "1" /* Angiosarcoma of liver */
"C224" = "1" /* Other sarcomas of liver */
"C227" = "1" /* Other specified carcinomas of liver */
"C228" = "1" /* Malignant neoplasm of liver, primary, unspecified as to type */
"C229" = "1" /* Malignant neoplasm of liver, not specified as primary or secondary */
"C23" = "1" /* Malignant neoplasm of gallbladder */
"C240" = "1" /* Malignant neoplasm of extrahepatic bile duct */
"C241" = "1" /* Malignant neoplasm of ampulla of Vater */
"C248" = "1" /* Malignant neoplasm of overlapping sites of biliary tract */
"C249" = "1" /* Malignant neoplasm of biliary tract, unspecified */
"C250" = "1" /* Malignant neoplasm of head of pancreas */
"C251" = "1" /* Malignant neoplasm of body of pancreas */
"C252" = "1" /* Malignant neoplasm of tail of pancreas */
"C253" = "1" /* Malignant neoplasm of pancreatic duct */
"C254" = "1" /* Malignant neoplasm of endocrine pancreas */
"C257" = "1" /* Malignant neoplasm of other parts of pancreas */
"C258" = "1" /* Malignant neoplasm of overlapping sites of pancreas */
"C259" = "1" /* Malignant neoplasm of pancreas, unspecified */
"C260" = "1" /* Malignant neoplasm of intestinal tract, part unspecified */
"C261" = "1" /* Malignant neoplasm of spleen */
"C269" = "1" /* Malignant neoplasm of ill-defined sites within the digestive system */
"C300" = "1" /* Malignant neoplasm of nasal cavity */
"C301" = "1" /* Malignant neoplasm of middle ear */
"C310" = "1" /* Malignant neoplasm of maxillary sinus */
"C311" = "1" /* Malignant neoplasm of ethmoidal sinus */
"C312" = "1" /* Malignant neoplasm of frontal sinus */
"C313" = "1" /* Malignant neoplasm of sphenoid sinus */
"C318" = "1" /* Malignant neoplasm of overlapping sites of accessory sinuses */
"C319" = "1" /* Malignant neoplasm of accessory sinus, unspecified */
"C320" = "1" /* Malignant neoplasm of glottis */
"C321" = "1" /* Malignant neoplasm of supraglottis */
"C322" = "1" /* Malignant neoplasm of subglottis */
"C323" = "1" /* Malignant neoplasm of laryngeal cartilage */
"C328" = "1" /* Malignant neoplasm of overlapping sites of larynx */
"C329" = "1" /* Malignant neoplasm of larynx, unspecified */
"C33" = "1" /* Malignant neoplasm of trachea */
"C3400" = "1" /* Malignant neoplasm of unspecified main bronchus */
"C3401" = "1" /* Malignant neoplasm of right main bronchus */
"C3402" = "1" /* Malignant neoplasm of left main bronchus */
"C3410" = "1" /* Malignant neoplasm of upper lobe, unspecified bronchus or lung */
"C3411" = "1" /* Malignant neoplasm of upper lobe, right bronchus or lung */
"C3412" = "1" /* Malignant neoplasm of upper lobe, left bronchus or lung */
"C342" = "1" /* Malignant neoplasm of middle lobe, bronchus or lung */
"C3430" = "1" /* Malignant neoplasm of lower lobe, unspecified bronchus or lung */
"C3431" = "1" /* Malignant neoplasm of lower lobe, right bronchus or lung */
"C3432" = "1" /* Malignant neoplasm of lower lobe, left bronchus or lung */
"C3480" = "1" /* Malignant neoplasm of overlapping sites of unspecified bronchus and lung */
"C3481" = "1" /* Malignant neoplasm of overlapping sites of right bronchus and lung */
"C3482" = "1" /* Malignant neoplasm of overlapping sites of left bronchus and lung */
"C3490" = "1" /* Malignant neoplasm of unspecified part of unspecified bronchus or lung */
"C3491" = "1" /* Malignant neoplasm of unspecified part of right bronchus or lung */
"C3492" = "1" /* Malignant neoplasm of unspecified part of left bronchus or lung */
"C37" = "1" /* Malignant neoplasm of thymus */
"C380" = "1" /* Malignant neoplasm of heart */
"C381" = "1" /* Malignant neoplasm of anterior mediastinum */
"C382" = "1" /* Malignant neoplasm of posterior mediastinum */
"C383" = "1" /* Malignant neoplasm of mediastinum, part unspecified */
"C384" = "1" /* Malignant neoplasm of pleura */
"C388" = "1" /* Malignant neoplasm of overlapping sites of heart, mediastinum and pleura */
"C390" = "1" /* Malignant neoplasm of upper respiratory tract, part unspecified */
"C399" = "1" /* Malignant neoplasm of lower respiratory tract, part unspecified */
"C4000" = "1" /* Malignant neoplasm of scapula and long bones of unspecified upper limb */
"C4001" = "1" /* Malignant neoplasm of scapula and long bones of right upper limb */
"C4002" = "1" /* Malignant neoplasm of scapula and long bones of left upper limb */
"C4010" = "1" /* Malignant neoplasm of short bones of unspecified upper limb */
"C4011" = "1" /* Malignant neoplasm of short bones of right upper limb */
"C4012" = "1" /* Malignant neoplasm of short bones of left upper limb */
"C4020" = "1" /* Malignant neoplasm of long bones of unspecified lower limb */
"C4021" = "1" /* Malignant neoplasm of long bones of right lower limb */
"C4022" = "1" /* Malignant neoplasm of long bones of left lower limb */
"C4030" = "1" /* Malignant neoplasm of short bones of unspecified lower limb */
"C4031" = "1" /* Malignant neoplasm of short bones of right lower limb */
"C4032" = "1" /* Malignant neoplasm of short bones of left lower limb */
"C4080" = "1" /* Malignant neoplasm of overlapping sites of bone and articular cartilage of unspecified limb */
"C4081" = "1" /* Malignant neoplasm of overlapping sites of bone and articular cartilage of right limb */
"C4082" = "1" /* Malignant neoplasm of overlapping sites of bone and articular cartilage of left limb */
"C4090" = "1" /* Malignant neoplasm of unspecified bones and articular cartilage of unspecified limb */
"C4091" = "1" /* Malignant neoplasm of unspecified bones and articular cartilage of right limb */
"C4092" = "1" /* Malignant neoplasm of unspecified bones and articular cartilage of left limb */
"C410" = "1" /* Malignant neoplasm of bones of skull and face */
"C411" = "1" /* Malignant neoplasm of mandible */
"C412" = "1" /* Malignant neoplasm of vertebral column */
"C413" = "1" /* Malignant neoplasm of ribs, sternum and clavicle */
"C414" = "1" /* Malignant neoplasm of pelvic bones, sacrum and coccyx */
"C419" = "1" /* Malignant neoplasm of bone and articular cartilage, unspecified */
"C430" = "1" /* Malignant melanoma of lip */
"C4310" = "1" /* Malignant melanoma of unspecified eyelid, including canthus */
"C4311" = "1" /* Malignant melanoma of right eyelid, including canthus */
"C4312" = "1" /* Malignant melanoma of left eyelid, including canthus */
"C4320" = "1" /* Malignant melanoma of unspecified ear and external auricular canal */
"C4321" = "1" /* Malignant melanoma of right ear and external auricular canal */
"C4322" = "1" /* Malignant melanoma of left ear and external auricular canal */
"C4330" = "1" /* Malignant melanoma of unspecified part of face */
"C4331" = "1" /* Malignant melanoma of nose */
"C4339" = "1" /* Malignant melanoma of other parts of face */
"C434" = "1" /* Malignant melanoma of scalp and neck */
"C4351" = "1" /* Malignant melanoma of anal skin */
"C4352" = "1" /* Malignant melanoma of skin of breast */
"C4359" = "1" /* Malignant melanoma of other part of trunk */
"C4360" = "1" /* Malignant melanoma of unspecified upper limb, including shoulder */
"C4361" = "1" /* Malignant melanoma of right upper limb, including shoulder */
"C4362" = "1" /* Malignant melanoma of left upper limb, including shoulder */
"C4370" = "1" /* Malignant melanoma of unspecified lower limb, including hip */
"C4371" = "1" /* Malignant melanoma of right lower limb, including hip */
"C4372" = "1" /* Malignant melanoma of left lower limb, including hip */
"C438" = "1" /* Malignant melanoma of overlapping sites of skin */
"C439" = "1" /* Malignant melanoma of skin, unspecified */
"C450" = "1" /* Mesothelioma of pleura */
"C451" = "1" /* Mesothelioma of peritoneum */
"C452" = "1" /* Mesothelioma of pericardium */
"C457" = "1" /* Mesothelioma of other sites */
"C459" = "1" /* Mesothelioma, unspecified */
"C460" = "1" /* Kaposi's sarcoma of skin */
"C461" = "1" /* Kaposi's sarcoma of soft tissue */
"C462" = "1" /* Kaposi's sarcoma of palate */
"C463" = "1" /* Kaposi's sarcoma of lymph nodes */
"C464" = "1" /* Kaposi's sarcoma of gastrointestinal sites */
"C4650" = "1" /* Kaposi's sarcoma of unspecified lung */
"C4651" = "1" /* Kaposi's sarcoma of right lung */
"C4652" = "1" /* Kaposi's sarcoma of left lung */
"C467" = "1" /* Kaposi's sarcoma of other sites */
"C469" = "1" /* Kaposi's sarcoma, unspecified */
"C470" = "1" /* Malignant neoplasm of peripheral nerves of head, face and neck */
"C4710" = "1" /* Malignant neoplasm of peripheral nerves of unspecified upper limb, including shoulder */
"C4711" = "1" /* Malignant neoplasm of peripheral nerves of right upper limb, including shoulder */
"C4712" = "1" /* Malignant neoplasm of peripheral nerves of left upper limb, including shoulder */
"C4720" = "1" /* Malignant neoplasm of peripheral nerves of unspecified lower limb, including hip */
"C4721" = "1" /* Malignant neoplasm of peripheral nerves of right lower limb, including hip */
"C4722" = "1" /* Malignant neoplasm of peripheral nerves of left lower limb, including hip */
"C473" = "1" /* Malignant neoplasm of peripheral nerves of thorax */
"C474" = "1" /* Malignant neoplasm of peripheral nerves of abdomen */
"C475" = "1" /* Malignant neoplasm of peripheral nerves of pelvis */
"C476" = "1" /* Malignant neoplasm of peripheral nerves of trunk, unspecified */
"C478" = "1" /* Malignant neoplasm of overlapping sites of peripheral nerves and autonomic nervous system */
"C479" = "1" /* Malignant neoplasm of peripheral nerves and autonomic nervous system, unspecified */
"C480" = "1" /* Malignant neoplasm of retroperitoneum */
"C481" = "1" /* Malignant neoplasm of specified parts of peritoneum */
"C482" = "1" /* Malignant neoplasm of peritoneum, unspecified */
"C488" = "1" /* Malignant neoplasm of overlapping sites of retroperitoneum and peritoneum */
"C490" = "1" /* Malignant neoplasm of connective and soft tissue of head, face and neck */
"C4910" = "1" /* Malignant neoplasm of connective and soft tissue of unspecified upper limb, including shoulder */
"C4911" = "1" /* Malignant neoplasm of connective and soft tissue of right upper limb, including shoulder */
"C4912" = "1" /* Malignant neoplasm of connective and soft tissue of left upper limb, including shoulder */
"C4920" = "1" /* Malignant neoplasm of connective and soft tissue of unspecified lower limb, including hip */
"C4921" = "1" /* Malignant neoplasm of connective and soft tissue of right lower limb, including hip */
"C4922" = "1" /* Malignant neoplasm of connective and soft tissue of left lower limb, including hip */
"C493" = "1" /* Malignant neoplasm of connective and soft tissue of thorax */
"C494" = "1" /* Malignant neoplasm of connective and soft tissue of abdomen */
"C495" = "1" /* Malignant neoplasm of connective and soft tissue of pelvis */
"C496" = "1" /* Malignant neoplasm of connective and soft tissue of trunk, unspecified */
"C498" = "1" /* Malignant neoplasm of overlapping sites of connective and soft tissue */
"C499" = "1" /* Malignant neoplasm of connective and soft tissue, unspecified */
"C50011" = "1" /* Malignant neoplasm of nipple and areola, right female breast */
"C50012" = "1" /* Malignant neoplasm of nipple and areola, left female breast */
"C50019" = "1" /* Malignant neoplasm of nipple and areola, unspecified female breast */
"C50021" = "1" /* Malignant neoplasm of nipple and areola, right male breast */
"C50022" = "1" /* Malignant neoplasm of nipple and areola, left male breast */
"C50029" = "1" /* Malignant neoplasm of nipple and areola, unspecified male breast */
"C50111" = "1" /* Malignant neoplasm of central portion of right female breast */
"C50112" = "1" /* Malignant neoplasm of central portion of left female breast */
"C50119" = "1" /* Malignant neoplasm of central portion of unspecified female breast */
"C50121" = "1" /* Malignant neoplasm of central portion of right male breast */
"C50122" = "1" /* Malignant neoplasm of central portion of left male breast */
"C50129" = "1" /* Malignant neoplasm of central portion of unspecified male breast */
"C50211" = "1" /* Malignant neoplasm of upper-inner quadrant of right female breast */
"C50212" = "1" /* Malignant neoplasm of upper-inner quadrant of left female breast */
"C50219" = "1" /* Malignant neoplasm of upper-inner quadrant of unspecified female breast */
"C50221" = "1" /* Malignant neoplasm of upper-inner quadrant of right male breast */
"C50222" = "1" /* Malignant neoplasm of upper-inner quadrant of left male breast */
"C50229" = "1" /* Malignant neoplasm of upper-inner quadrant of unspecified male breast */
"C50311" = "1" /* Malignant neoplasm of lower-inner quadrant of right female breast */
"C50312" = "1" /* Malignant neoplasm of lower-inner quadrant of left female breast */
"C50319" = "1" /* Malignant neoplasm of lower-inner quadrant of unspecified female breast */
"C50321" = "1" /* Malignant neoplasm of lower-inner quadrant of right male breast */
"C50322" = "1" /* Malignant neoplasm of lower-inner quadrant of left male breast */
"C50329" = "1" /* Malignant neoplasm of lower-inner quadrant of unspecified male breast */
"C50411" = "1" /* Malignant neoplasm of upper-outer quadrant of right female breast */
"C50412" = "1" /* Malignant neoplasm of upper-outer quadrant of left female breast */
"C50419" = "1" /* Malignant neoplasm of upper-outer quadrant of unspecified female breast */
"C50421" = "1" /* Malignant neoplasm of upper-outer quadrant of right male breast */
"C50422" = "1" /* Malignant neoplasm of upper-outer quadrant of left male breast */
"C50429" = "1" /* Malignant neoplasm of upper-outer quadrant of unspecified male breast */
"C50511" = "1" /* Malignant neoplasm of lower-outer quadrant of right female breast */
"C50512" = "1" /* Malignant neoplasm of lower-outer quadrant of left female breast */
"C50519" = "1" /* Malignant neoplasm of lower-outer quadrant of unspecified female breast */
"C50521" = "1" /* Malignant neoplasm of lower-outer quadrant of right male breast */
"C50522" = "1" /* Malignant neoplasm of lower-outer quadrant of left male breast */
"C50529" = "1" /* Malignant neoplasm of lower-outer quadrant of unspecified male breast */
"C50611" = "1" /* Malignant neoplasm of axillary tail of right female breast */
"C50612" = "1" /* Malignant neoplasm of axillary tail of left female breast */
"C50619" = "1" /* Malignant neoplasm of axillary tail of unspecified female breast */
"C50621" = "1" /* Malignant neoplasm of axillary tail of right male breast */
"C50622" = "1" /* Malignant neoplasm of axillary tail of left male breast */
"C50629" = "1" /* Malignant neoplasm of axillary tail of unspecified male breast */
"C50811" = "1" /* Malignant neoplasm of overlapping sites of right female breast */
"C50812" = "1" /* Malignant neoplasm of overlapping sites of left female breast */
"C50819" = "1" /* Malignant neoplasm of overlapping sites of unspecified female breast */
"C50821" = "1" /* Malignant neoplasm of overlapping sites of right male breast */
"C50822" = "1" /* Malignant neoplasm of overlapping sites of left male breast */
"C50829" = "1" /* Malignant neoplasm of overlapping sites of unspecified male breast */
"C50911" = "1" /* Malignant neoplasm of unspecified site of right female breast */
"C50912" = "1" /* Malignant neoplasm of unspecified site of left female breast */
"C50919" = "1" /* Malignant neoplasm of unspecified site of unspecified female breast */
"C50921" = "1" /* Malignant neoplasm of unspecified site of right male breast */
"C50922" = "1" /* Malignant neoplasm of unspecified site of left male breast */
"C50929" = "1" /* Malignant neoplasm of unspecified site of unspecified male breast */
"C510" = "1" /* Malignant neoplasm of labium majus */
"C511" = "1" /* Malignant neoplasm of labium minus */
"C512" = "1" /* Malignant neoplasm of clitoris */
"C518" = "1" /* Malignant neoplasm of overlapping sites of vulva */
"C519" = "1" /* Malignant neoplasm of vulva, unspecified */
"C52" = "1" /* Malignant neoplasm of vagina */
"C530" = "1" /* Malignant neoplasm of endocervix */
"C531" = "1" /* Malignant neoplasm of exocervix */
"C538" = "1" /* Malignant neoplasm of overlapping sites of cervix uteri */
"C539" = "1" /* Malignant neoplasm of cervix uteri, unspecified */
"C540" = "1" /* Malignant neoplasm of isthmus uteri */
"C541" = "1" /* Malignant neoplasm of endometrium */
"C542" = "1" /* Malignant neoplasm of myometrium */
"C543" = "1" /* Malignant neoplasm of fundus uteri */
"C548" = "1" /* Malignant neoplasm of overlapping sites of corpus uteri */
"C549" = "1" /* Malignant neoplasm of corpus uteri, unspecified */
"C55" = "1" /* Malignant neoplasm of uterus, part unspecified */
"C561" = "1" /* Malignant neoplasm of right ovary */
"C562" = "1" /* Malignant neoplasm of left ovary */
"C569" = "1" /* Malignant neoplasm of unspecified ovary */
"C5700" = "1" /* Malignant neoplasm of unspecified fallopian tube */
"C5701" = "1" /* Malignant neoplasm of right fallopian tube */
"C5702" = "1" /* Malignant neoplasm of left fallopian tube */
"C5710" = "1" /* Malignant neoplasm of unspecified broad ligament */
"C5711" = "1" /* Malignant neoplasm of right broad ligament */
"C5712" = "1" /* Malignant neoplasm of left broad ligament */
"C5720" = "1" /* Malignant neoplasm of unspecified round ligament */
"C5721" = "1" /* Malignant neoplasm of right round ligament */
"C5722" = "1" /* Malignant neoplasm of left round ligament */
"C573" = "1" /* Malignant neoplasm of parametrium */
"C574" = "1" /* Malignant neoplasm of uterine adnexa, unspecified */
"C577" = "1" /* Malignant neoplasm of other specified female genital organs */
"C578" = "1" /* Malignant neoplasm of overlapping sites of female genital organs */
"C579" = "1" /* Malignant neoplasm of female genital organ, unspecified */
"C58" = "1" /* Malignant neoplasm of placenta */
"C600" = "1" /* Malignant neoplasm of prepuce */
"C601" = "1" /* Malignant neoplasm of glans penis */
"C602" = "1" /* Malignant neoplasm of body of penis */
"C608" = "1" /* Malignant neoplasm of overlapping sites of penis */
"C609" = "1" /* Malignant neoplasm of penis, unspecified */
"C61" = "1" /* Malignant neoplasm of prostate */
"C6200" = "1" /* Malignant neoplasm of unspecified undescended testis */
"C6201" = "1" /* Malignant neoplasm of undescended right testis */
"C6202" = "1" /* Malignant neoplasm of undescended left testis */
"C6210" = "1" /* Malignant neoplasm of unspecified descended testis */
"C6211" = "1" /* Malignant neoplasm of descended right testis */
"C6212" = "1" /* Malignant neoplasm of descended left testis */
"C6290" = "1" /* Malignant neoplasm of unspecified testis, unspecified whether descended or undescended */
"C6291" = "1" /* Malignant neoplasm of right testis, unspecified whether descended or undescended */
"C6292" = "1" /* Malignant neoplasm of left testis, unspecified whether descended or undescended */
"C6300" = "1" /* Malignant neoplasm of unspecified epididymis */
"C6301" = "1" /* Malignant neoplasm of right epididymis */
"C6302" = "1" /* Malignant neoplasm of left epididymis */
"C6310" = "1" /* Malignant neoplasm of unspecified spermatic cord */
"C6311" = "1" /* Malignant neoplasm of right spermatic cord */
"C6312" = "1" /* Malignant neoplasm of left spermatic cord */
"C632" = "1" /* Malignant neoplasm of scrotum */
"C637" = "1" /* Malignant neoplasm of other specified male genital organs */
"C638" = "1" /* Malignant neoplasm of overlapping sites of male genital organs */
"C639" = "1" /* Malignant neoplasm of male genital organ, unspecified */
"C641" = "1" /* Malignant neoplasm of right kidney, except renal pelvis */
"C642" = "1" /* Malignant neoplasm of left kidney, except renal pelvis */
"C649" = "1" /* Malignant neoplasm of unspecified kidney, except renal pelvis */
"C651" = "1" /* Malignant neoplasm of right renal pelvis */
"C652" = "1" /* Malignant neoplasm of left renal pelvis */
"C659" = "1" /* Malignant neoplasm of unspecified renal pelvis */
"C661" = "1" /* Malignant neoplasm of right ureter */
"C662" = "1" /* Malignant neoplasm of left ureter */
"C669" = "1" /* Malignant neoplasm of unspecified ureter */
"C670" = "1" /* Malignant neoplasm of trigone of bladder */
"C671" = "1" /* Malignant neoplasm of dome of bladder */
"C672" = "1" /* Malignant neoplasm of lateral wall of bladder */
"C673" = "1" /* Malignant neoplasm of anterior wall of bladder */
"C674" = "1" /* Malignant neoplasm of posterior wall of bladder */
"C675" = "1" /* Malignant neoplasm of bladder neck */
"C676" = "1" /* Malignant neoplasm of ureteric orifice */
"C677" = "1" /* Malignant neoplasm of urachus */
"C678" = "1" /* Malignant neoplasm of overlapping sites of bladder */
"C679" = "1" /* Malignant neoplasm of bladder, unspecified */
"C680" = "1" /* Malignant neoplasm of urethra */
"C681" = "1" /* Malignant neoplasm of paraurethral glands */
"C688" = "1" /* Malignant neoplasm of overlapping sites of urinary organs */
"C689" = "1" /* Malignant neoplasm of urinary organ, unspecified */
"C6900" = "1" /* Malignant neoplasm of unspecified conjunctiva */
"C6901" = "1" /* Malignant neoplasm of right conjunctiva */
"C6902" = "1" /* Malignant neoplasm of left conjunctiva */
"C6910" = "1" /* Malignant neoplasm of unspecified cornea */
"C6911" = "1" /* Malignant neoplasm of right cornea */
"C6912" = "1" /* Malignant neoplasm of left cornea */
"C6920" = "1" /* Malignant neoplasm of unspecified retina */
"C6921" = "1" /* Malignant neoplasm of right retina */
"C6922" = "1" /* Malignant neoplasm of left retina */
"C6930" = "1" /* Malignant neoplasm of unspecified choroid */
"C6931" = "1" /* Malignant neoplasm of right choroid */
"C6932" = "1" /* Malignant neoplasm of left choroid */
"C6940" = "1" /* Malignant neoplasm of unspecified ciliary body */
"C6941" = "1" /* Malignant neoplasm of right ciliary body */
"C6942" = "1" /* Malignant neoplasm of left ciliary body */
"C6950" = "1" /* Malignant neoplasm of unspecified lacrimal gland and duct */
"C6951" = "1" /* Malignant neoplasm of right lacrimal gland and duct */
"C6952" = "1" /* Malignant neoplasm of left lacrimal gland and duct */
"C6960" = "1" /* Malignant neoplasm of unspecified orbit */
"C6961" = "1" /* Malignant neoplasm of right orbit */
"C6962" = "1" /* Malignant neoplasm of left orbit */
"C6980" = "1" /* Malignant neoplasm of overlapping sites of unspecified eye and adnexa */
"C6981" = "1" /* Malignant neoplasm of overlapping sites of right eye and adnexa */
"C6982" = "1" /* Malignant neoplasm of overlapping sites of left eye and adnexa */
"C6990" = "1" /* Malignant neoplasm of unspecified site of unspecified eye */
"C6991" = "1" /* Malignant neoplasm of unspecified site of right eye */
"C6992" = "1" /* Malignant neoplasm of unspecified site of left eye */
"C700" = "1" /* Malignant neoplasm of cerebral meninges */
"C701" = "1" /* Malignant neoplasm of spinal meninges */
"C709" = "1" /* Malignant neoplasm of meninges, unspecified */
"C710" = "1" /* Malignant neoplasm of cerebrum, except lobes and ventricles */
"C711" = "1" /* Malignant neoplasm of frontal lobe */
"C712" = "1" /* Malignant neoplasm of temporal lobe */
"C713" = "1" /* Malignant neoplasm of parietal lobe */
"C714" = "1" /* Malignant neoplasm of occipital lobe */
"C715" = "1" /* Malignant neoplasm of cerebral ventricle */
"C716" = "1" /* Malignant neoplasm of cerebellum */
"C717" = "1" /* Malignant neoplasm of brain stem */
"C718" = "1" /* Malignant neoplasm of overlapping sites of brain */
"C719" = "1" /* Malignant neoplasm of brain, unspecified */
"C720" = "1" /* Malignant neoplasm of spinal cord */
"C721" = "1" /* Malignant neoplasm of cauda equina */
"C7220" = "1" /* Malignant neoplasm of unspecified olfactory nerve */
"C7221" = "1" /* Malignant neoplasm of right olfactory nerve */
"C7222" = "1" /* Malignant neoplasm of left olfactory nerve */
"C7230" = "1" /* Malignant neoplasm of unspecified optic nerve */
"C7231" = "1" /* Malignant neoplasm of right optic nerve */
"C7232" = "1" /* Malignant neoplasm of left optic nerve */
"C7240" = "1" /* Malignant neoplasm of unspecified acoustic nerve */
"C7241" = "1" /* Malignant neoplasm of right acoustic nerve */
"C7242" = "1" /* Malignant neoplasm of left acoustic nerve */
"C7250" = "1" /* Malignant neoplasm of unspecified cranial nerve */
"C7259" = "1" /* Malignant neoplasm of other cranial nerves */
"C729" = "1" /* Malignant neoplasm of central nervous system, unspecified */
"C73" = "1" /* Malignant neoplasm of thyroid gland */
"C7400" = "1" /* Malignant neoplasm of cortex of unspecified adrenal gland */
"C7401" = "1" /* Malignant neoplasm of cortex of right adrenal gland */
"C7402" = "1" /* Malignant neoplasm of cortex of left adrenal gland */
"C7410" = "1" /* Malignant neoplasm of medulla of unspecified adrenal gland */
"C7411" = "1" /* Malignant neoplasm of medulla of right adrenal gland */
"C7412" = "1" /* Malignant neoplasm of medulla of left adrenal gland */
"C7490" = "1" /* Malignant neoplasm of unspecified part of unspecified adrenal gland */
"C7491" = "1" /* Malignant neoplasm of unspecified part of right adrenal gland */
"C7492" = "1" /* Malignant neoplasm of unspecified part of left adrenal gland */
"C750" = "1" /* Malignant neoplasm of parathyroid gland */
"C751" = "1" /* Malignant neoplasm of pituitary gland */
"C752" = "1" /* Malignant neoplasm of craniopharyngeal duct */
"C753" = "1" /* Malignant neoplasm of pineal gland */
"C754" = "1" /* Malignant neoplasm of carotid body */
"C755" = "1" /* Malignant neoplasm of aortic body and other paraganglia */
"C758" = "1" /* Malignant neoplasm with pluriglandular involvement, unspecified */
"C759" = "1" /* Malignant neoplasm of endocrine gland, unspecified */
"C760" = "1" /* Malignant neoplasm of head, face and neck */
"C761" = "1" /* Malignant neoplasm of thorax */
"C762" = "1" /* Malignant neoplasm of abdomen */
"C763" = "1" /* Malignant neoplasm of pelvis */
"C7640" = "1" /* Malignant neoplasm of unspecified upper limb */
"C7641" = "1" /* Malignant neoplasm of right upper limb */
"C7642" = "1" /* Malignant neoplasm of left upper limb */
"C7650" = "1" /* Malignant neoplasm of unspecified lower limb */
"C7651" = "1" /* Malignant neoplasm of right lower limb */
"C7652" = "1" /* Malignant neoplasm of left lower limb */
"C768" = "1" /* Malignant neoplasm of other specified ill-defined sites */
"C770" = "1" /* Secondary and unspecified malignant neoplasm of lymph nodes of head, face and neck */
"C771" = "1" /* Secondary and unspecified malignant neoplasm of intrathoracic lymph nodes */
"C772" = "1" /* Secondary and unspecified malignant neoplasm of intra-abdominal lymph nodes */
"C773" = "1" /* Secondary and unspecified malignant neoplasm of axilla and upper limb lymph nodes */
"C774" = "1" /* Secondary and unspecified malignant neoplasm of inguinal and lower limb lymph nodes */
"C775" = "1" /* Secondary and unspecified malignant neoplasm of intrapelvic lymph nodes */
"C778" = "1" /* Secondary and unspecified malignant neoplasm of lymph nodes of multiple regions */
"C779" = "1" /* Secondary and unspecified malignant neoplasm of lymph node, unspecified */
"C7800" = "1" /* Secondary malignant neoplasm of unspecified lung */
"C7801" = "1" /* Secondary malignant neoplasm of right lung */
"C7802" = "1" /* Secondary malignant neoplasm of left lung */
"C781" = "1" /* Secondary malignant neoplasm of mediastinum */
"C782" = "1" /* Secondary malignant neoplasm of pleura */
"C7830" = "1" /* Secondary malignant neoplasm of unspecified respiratory organ */
"C7839" = "1" /* Secondary malignant neoplasm of other respiratory organs */
"C784" = "1" /* Secondary malignant neoplasm of small intestine */
"C785" = "1" /* Secondary malignant neoplasm of large intestine and rectum */
"C786" = "1" /* Secondary malignant neoplasm of retroperitoneum and peritoneum */
"C787" = "1" /* Secondary malignant neoplasm of liver and intrahepatic bile duct */
"C7880" = "1" /* Secondary malignant neoplasm of unspecified digestive organ */
"C7889" = "1" /* Secondary malignant neoplasm of other digestive organs */
"C7900" = "1" /* Secondary malignant neoplasm of unspecified kidney and renal pelvis */
"C7901" = "1" /* Secondary malignant neoplasm of right kidney and renal pelvis */
"C7902" = "1" /* Secondary malignant neoplasm of left kidney and renal pelvis */
"C7910" = "1" /* Secondary malignant neoplasm of unspecified urinary organs */
"C7911" = "1" /* Secondary malignant neoplasm of bladder */
"C7919" = "1" /* Secondary malignant neoplasm of other urinary organs */
"C792" = "1" /* Secondary malignant neoplasm of skin */
"C7931" = "1" /* Secondary malignant neoplasm of brain */
"C7932" = "1" /* Secondary malignant neoplasm of cerebral meninges */
"C7940" = "1" /* Secondary malignant neoplasm of unspecified part of nervous system */
"C7949" = "1" /* Secondary malignant neoplasm of other parts of nervous system */
"C7951" = "1" /* Secondary malignant neoplasm of bone */
"C7952" = "1" /* Secondary malignant neoplasm of bone marrow */
"C7960" = "1" /* Secondary malignant neoplasm of unspecified ovary */
"C7961" = "1" /* Secondary malignant neoplasm of right ovary */
"C7962" = "1" /* Secondary malignant neoplasm of left ovary */
"C7970" = "1" /* Secondary malignant neoplasm of unspecified adrenal gland */
"C7971" = "1" /* Secondary malignant neoplasm of right adrenal gland */
"C7972" = "1" /* Secondary malignant neoplasm of left adrenal gland */
"C7981" = "1" /* Secondary malignant neoplasm of breast */
"C7982" = "1" /* Secondary malignant neoplasm of genital organs */
"C7989" = "1" /* Secondary malignant neoplasm of other specified sites */
"C799" = "1" /* Secondary malignant neoplasm of unspecified site */
"C800" = "1" /* Disseminated malignant neoplasm, unspecified */
"C801" = "1" /* Malignant (primary) neoplasm, unspecified */
"C8100" = "1" /* Nodular lymphocyte predominant Hodgkin lymphoma, unspecified site */
"C8101" = "1" /* Nodular lymphocyte predominant Hodgkin lymphoma, lymph nodes of head, face, and neck */
"C8102" = "1" /* Nodular lymphocyte predominant Hodgkin lymphoma, intrathoracic lymph nodes */
"C8103" = "1" /* Nodular lymphocyte predominant Hodgkin lymphoma, intra-abdominal lymph nodes */
"C8104" = "1" /* Nodular lymphocyte predominant Hodgkin lymphoma, lymph nodes of axilla and upper limb */
"C8105" = "1" /* Nodular lymphocyte predominant Hodgkin lymphoma, lymph nodes of inguinal region and lower limb */
"C8106" = "1" /* Nodular lymphocyte predominant Hodgkin lymphoma, intrapelvic lymph nodes */
"C8107" = "1" /* Nodular lymphocyte predominant Hodgkin lymphoma, spleen */
"C8108" = "1" /* Nodular lymphocyte predominant Hodgkin lymphoma, lymph nodes of multiple sites */
"C8109" = "1" /* Nodular lymphocyte predominant Hodgkin lymphoma, extranodal and solid organ sites */
"C8110" = "1" /* Nodular sclerosis Hodgkin lymphoma, unspecified site */
"C8111" = "1" /* Nodular sclerosis Hodgkin lymphoma, lymph nodes of head, face, and neck */
"C8112" = "1" /* Nodular sclerosis Hodgkin lymphoma, intrathoracic lymph nodes */
"C8113" = "1" /* Nodular sclerosis Hodgkin lymphoma, intra-abdominal lymph nodes */
"C8114" = "1" /* Nodular sclerosis Hodgkin lymphoma, lymph nodes of axilla and upper limb */
"C8115" = "1" /* Nodular sclerosis Hodgkin lymphoma, lymph nodes of inguinal region and lower limb */
"C8116" = "1" /* Nodular sclerosis Hodgkin lymphoma, intrapelvic lymph nodes */
"C8117" = "1" /* Nodular sclerosis Hodgkin lymphoma, spleen */
"C8118" = "1" /* Nodular sclerosis Hodgkin lymphoma, lymph nodes of multiple sites */
"C8119" = "1" /* Nodular sclerosis Hodgkin lymphoma, extranodal and solid organ sites */
"C8120" = "1" /* Mixed cellularity Hodgkin lymphoma, unspecified site */
"C8121" = "1" /* Mixed cellularity Hodgkin lymphoma, lymph nodes of head, face, and neck */
"C8122" = "1" /* Mixed cellularity Hodgkin lymphoma, intrathoracic lymph nodes */
"C8123" = "1" /* Mixed cellularity Hodgkin lymphoma, intra-abdominal lymph nodes */
"C8124" = "1" /* Mixed cellularity Hodgkin lymphoma, lymph nodes of axilla and upper limb */
"C8125" = "1" /* Mixed cellularity Hodgkin lymphoma, lymph nodes of inguinal region and lower limb */
"C8126" = "1" /* Mixed cellularity Hodgkin lymphoma, intrapelvic lymph nodes */
"C8127" = "1" /* Mixed cellularity Hodgkin lymphoma, spleen */
"C8128" = "1" /* Mixed cellularity Hodgkin lymphoma, lymph nodes of multiple sites */
"C8129" = "1" /* Mixed cellularity Hodgkin lymphoma, extranodal and solid organ sites */
"C8130" = "1" /* Lymphocyte depleted Hodgkin lymphoma, unspecified site */
"C8131" = "1" /* Lymphocyte depleted Hodgkin lymphoma, lymph nodes of head, face, and neck */
"C8132" = "1" /* Lymphocyte depleted Hodgkin lymphoma, intrathoracic lymph nodes */
"C8133" = "1" /* Lymphocyte depleted Hodgkin lymphoma, intra-abdominal lymph nodes */
"C8134" = "1" /* Lymphocyte depleted Hodgkin lymphoma, lymph nodes of axilla and upper limb */
"C8135" = "1" /* Lymphocyte depleted Hodgkin lymphoma, lymph nodes of inguinal region and lower limb */
"C8136" = "1" /* Lymphocyte depleted Hodgkin lymphoma, intrapelvic lymph nodes */
"C8137" = "1" /* Lymphocyte depleted Hodgkin lymphoma, spleen */
"C8138" = "1" /* Lymphocyte depleted Hodgkin lymphoma, lymph nodes of multiple sites */
"C8139" = "1" /* Lymphocyte depleted Hodgkin lymphoma, extranodal and solid organ sites */
"C8140" = "1" /* Lymphocyte-rich Hodgkin lymphoma, unspecified site */
"C8141" = "1" /* Lymphocyte-rich Hodgkin lymphoma, lymph nodes of head, face, and neck */
"C8142" = "1" /* Lymphocyte-rich Hodgkin lymphoma, intrathoracic lymph nodes */
"C8143" = "1" /* Lymphocyte-rich Hodgkin lymphoma, intra-abdominal lymph nodes */
"C8144" = "1" /* Lymphocyte-rich Hodgkin lymphoma, lymph nodes of axilla and upper limb */
"C8145" = "1" /* Lymphocyte-rich Hodgkin lymphoma, lymph nodes of inguinal region and lower limb */
"C8146" = "1" /* Lymphocyte-rich Hodgkin lymphoma, intrapelvic lymph nodes */
"C8147" = "1" /* Lymphocyte-rich Hodgkin lymphoma, spleen */
"C8148" = "1" /* Lymphocyte-rich Hodgkin lymphoma, lymph nodes of multiple sites */
"C8149" = "1" /* Lymphocyte-rich Hodgkin lymphoma, extranodal and solid organ sites */
"C8170" = "1" /* Other Hodgkin lymphoma, unspecified site */
"C8171" = "1" /* Other Hodgkin lymphoma, lymph nodes of head, face, and neck */
"C8172" = "1" /* Other Hodgkin lymphoma, intrathoracic lymph nodes */
"C8173" = "1" /* Other Hodgkin lymphoma, intra-abdominal lymph nodes */
"C8174" = "1" /* Other Hodgkin lymphoma, lymph nodes of axilla and upper limb */
"C8175" = "1" /* Other Hodgkin lymphoma, lymph nodes of inguinal region and lower limb */
"C8176" = "1" /* Other Hodgkin lymphoma, intrapelvic lymph nodes */
"C8177" = "1" /* Other Hodgkin lymphoma, spleen */
"C8178" = "1" /* Other Hodgkin lymphoma, lymph nodes of multiple sites */
"C8179" = "1" /* Other Hodgkin lymphoma, extranodal and solid organ sites */
"C8190" = "1" /* Hodgkin lymphoma, unspecified, unspecified site */
"C8191" = "1" /* Hodgkin lymphoma, unspecified, lymph nodes of head, face, and neck */
"C8192" = "1" /* Hodgkin lymphoma, unspecified, intrathoracic lymph nodes */
"C8193" = "1" /* Hodgkin lymphoma, unspecified, intra-abdominal lymph nodes */
"C8194" = "1" /* Hodgkin lymphoma, unspecified, lymph nodes of axilla and upper limb */
"C8195" = "1" /* Hodgkin lymphoma, unspecified, lymph nodes of inguinal region and lower limb */
"C8196" = "1" /* Hodgkin lymphoma, unspecified, intrapelvic lymph nodes */
"C8197" = "1" /* Hodgkin lymphoma, unspecified, spleen */
"C8198" = "1" /* Hodgkin lymphoma, unspecified, lymph nodes of multiple sites */
"C8199" = "1" /* Hodgkin lymphoma, unspecified, extranodal and solid organ sites */
"C8200" = "1" /* Follicular lymphoma grade I, unspecified site */
"C8201" = "1" /* Follicular lymphoma grade I, lymph nodes of head, face, and neck */
"C8202" = "1" /* Follicular lymphoma grade I, intrathoracic lymph nodes */
"C8203" = "1" /* Follicular lymphoma grade I, intra-abdominal lymph nodes */
"C8204" = "1" /* Follicular lymphoma grade I, lymph nodes of axilla and upper limb */
"C8205" = "1" /* Follicular lymphoma grade I, lymph nodes of inguinal region and lower limb */
"C8206" = "1" /* Follicular lymphoma grade I, intrapelvic lymph nodes */
"C8207" = "1" /* Follicular lymphoma grade I, spleen */
"C8208" = "1" /* Follicular lymphoma grade I, lymph nodes of multiple sites */
"C8209" = "1" /* Follicular lymphoma grade I, extranodal and solid organ sites */
"C8210" = "1" /* Follicular lymphoma grade II, unspecified site */
"C8211" = "1" /* Follicular lymphoma grade II, lymph nodes of head, face, and neck */
"C8212" = "1" /* Follicular lymphoma grade II, intrathoracic lymph nodes */
"C8213" = "1" /* Follicular lymphoma grade II, intra-abdominal lymph nodes */
"C8214" = "1" /* Follicular lymphoma grade II, lymph nodes of axilla and upper limb */
"C8215" = "1" /* Follicular lymphoma grade II, lymph nodes of inguinal region and lower limb */
"C8216" = "1" /* Follicular lymphoma grade II, intrapelvic lymph nodes */
"C8217" = "1" /* Follicular lymphoma grade II, spleen */
"C8218" = "1" /* Follicular lymphoma grade II, lymph nodes of multiple sites */
"C8219" = "1" /* Follicular lymphoma grade II, extranodal and solid organ sites */
"C8220" = "1" /* Follicular lymphoma grade III, unspecified, unspecified site */
"C8221" = "1" /* Follicular lymphoma grade III, unspecified, lymph nodes of head, face, and neck */
"C8222" = "1" /* Follicular lymphoma grade III, unspecified, intrathoracic lymph nodes */
"C8223" = "1" /* Follicular lymphoma grade III, unspecified, intra-abdominal lymph nodes */
"C8224" = "1" /* Follicular lymphoma grade III, unspecified, lymph nodes of axilla and upper limb */
"C8225" = "1" /* Follicular lymphoma grade III, unspecified, lymph nodes of inguinal region and lower limb */
"C8226" = "1" /* Follicular lymphoma grade III, unspecified, intrapelvic lymph nodes */
"C8227" = "1" /* Follicular lymphoma grade III, unspecified, spleen */
"C8228" = "1" /* Follicular lymphoma grade III, unspecified, lymph nodes of multiple sites */
"C8229" = "1" /* Follicular lymphoma grade III, unspecified, extranodal and solid organ sites */
"C8230" = "1" /* Follicular lymphoma grade IIIa, unspecified site */
"C8231" = "1" /* Follicular lymphoma grade IIIa, lymph nodes of head, face, and neck */
"C8232" = "1" /* Follicular lymphoma grade IIIa, intrathoracic lymph nodes */
"C8233" = "1" /* Follicular lymphoma grade IIIa, intra-abdominal lymph nodes */
"C8234" = "1" /* Follicular lymphoma grade IIIa, lymph nodes of axilla and upper limb */
"C8235" = "1" /* Follicular lymphoma grade IIIa, lymph nodes of inguinal region and lower limb */
"C8236" = "1" /* Follicular lymphoma grade IIIa, intrapelvic lymph nodes */
"C8237" = "1" /* Follicular lymphoma grade IIIa, spleen */
"C8238" = "1" /* Follicular lymphoma grade IIIa, lymph nodes of multiple sites */
"C8239" = "1" /* Follicular lymphoma grade IIIa, extranodal and solid organ sites */
"C8240" = "1" /* Follicular lymphoma grade IIIb, unspecified site */
"C8241" = "1" /* Follicular lymphoma grade IIIb, lymph nodes of head, face, and neck */
"C8242" = "1" /* Follicular lymphoma grade IIIb, intrathoracic lymph nodes */
"C8243" = "1" /* Follicular lymphoma grade IIIb, intra-abdominal lymph nodes */
"C8244" = "1" /* Follicular lymphoma grade IIIb, lymph nodes of axilla and upper limb */
"C8245" = "1" /* Follicular lymphoma grade IIIb, lymph nodes of inguinal region and lower limb */
"C8246" = "1" /* Follicular lymphoma grade IIIb, intrapelvic lymph nodes */
"C8247" = "1" /* Follicular lymphoma grade IIIb, spleen */
"C8248" = "1" /* Follicular lymphoma grade IIIb, lymph nodes of multiple sites */
"C8249" = "1" /* Follicular lymphoma grade IIIb, extranodal and solid organ sites */
"C8250" = "1" /* Diffuse follicle center lymphoma, unspecified site */
"C8251" = "1" /* Diffuse follicle center lymphoma, lymph nodes of head, face, and neck */
"C8252" = "1" /* Diffuse follicle center lymphoma, intrathoracic lymph nodes */
"C8253" = "1" /* Diffuse follicle center lymphoma, intra-abdominal lymph nodes */
"C8254" = "1" /* Diffuse follicle center lymphoma, lymph nodes of axilla and upper limb */
"C8255" = "1" /* Diffuse follicle center lymphoma, lymph nodes of inguinal region and lower limb */
"C8256" = "1" /* Diffuse follicle center lymphoma, intrapelvic lymph nodes */
"C8257" = "1" /* Diffuse follicle center lymphoma, spleen */
"C8258" = "1" /* Diffuse follicle center lymphoma, lymph nodes of multiple sites */
"C8259" = "1" /* Diffuse follicle center lymphoma, extranodal and solid organ sites */
"C8260" = "1" /* Cutaneous follicle center lymphoma, unspecified site */
"C8261" = "1" /* Cutaneous follicle center lymphoma, lymph nodes of head, face, and neck */
"C8262" = "1" /* Cutaneous follicle center lymphoma, intrathoracic lymph nodes */
"C8263" = "1" /* Cutaneous follicle center lymphoma, intra-abdominal lymph nodes */
"C8264" = "1" /* Cutaneous follicle center lymphoma, lymph nodes of axilla and upper limb */
"C8265" = "1" /* Cutaneous follicle center lymphoma, lymph nodes of inguinal region and lower limb */
"C8266" = "1" /* Cutaneous follicle center lymphoma, intrapelvic lymph nodes */
"C8267" = "1" /* Cutaneous follicle center lymphoma, spleen */
"C8268" = "1" /* Cutaneous follicle center lymphoma, lymph nodes of multiple sites */
"C8269" = "1" /* Cutaneous follicle center lymphoma, extranodal and solid organ sites */
"C8280" = "1" /* Other types of follicular lymphoma, unspecified site */
"C8281" = "1" /* Other types of follicular lymphoma, lymph nodes of head, face, and neck */
"C8282" = "1" /* Other types of follicular lymphoma, intrathoracic lymph nodes */
"C8283" = "1" /* Other types of follicular lymphoma, intra-abdominal lymph nodes */
"C8284" = "1" /* Other types of follicular lymphoma, lymph nodes of axilla and upper limb */
"C8285" = "1" /* Other types of follicular lymphoma, lymph nodes of inguinal region and lower limb */
"C8286" = "1" /* Other types of follicular lymphoma, intrapelvic lymph nodes */
"C8287" = "1" /* Other types of follicular lymphoma, spleen */
"C8288" = "1" /* Other types of follicular lymphoma, lymph nodes of multiple sites */
"C8289" = "1" /* Other types of follicular lymphoma, extranodal and solid organ sites */
"C8290" = "1" /* Follicular lymphoma, unspecified, unspecified site */
"C8291" = "1" /* Follicular lymphoma, unspecified, lymph nodes of head, face, and neck */
"C8292" = "1" /* Follicular lymphoma, unspecified, intrathoracic lymph nodes */
"C8293" = "1" /* Follicular lymphoma, unspecified, intra-abdominal lymph nodes */
"C8294" = "1" /* Follicular lymphoma, unspecified, lymph nodes of axilla and upper limb */
"C8295" = "1" /* Follicular lymphoma, unspecified, lymph nodes of inguinal region and lower limb */
"C8296" = "1" /* Follicular lymphoma, unspecified, intrapelvic lymph nodes */
"C8297" = "1" /* Follicular lymphoma, unspecified, spleen */
"C8298" = "1" /* Follicular lymphoma, unspecified, lymph nodes of multiple sites */
"C8299" = "1" /* Follicular lymphoma, unspecified, extranodal and solid organ sites */
"C8400" = "1" /* Mycosis fungoides, unspecified site */
"C8401" = "1" /* Mycosis fungoides, lymph nodes of head, face, and neck */
"C8402" = "1" /* Mycosis fungoides, intrathoracic lymph nodes */
"C8403" = "1" /* Mycosis fungoides, intra-abdominal lymph nodes */
"C8404" = "1" /* Mycosis fungoides, lymph nodes of axilla and upper limb */
"C8405" = "1" /* Mycosis fungoides, lymph nodes of inguinal region and lower limb */
"C8406" = "1" /* Mycosis fungoides, intrapelvic lymph nodes */
"C8407" = "1" /* Mycosis fungoides, spleen */
"C8408" = "1" /* Mycosis fungoides, lymph nodes of multiple sites */
"C8409" = "1" /* Mycosis fungoides, extranodal and solid organ sites */
"C8410" = "1" /* Sezary disease, unspecified site */
"C8411" = "1" /* Sezary disease, lymph nodes of head, face, and neck */
"C8412" = "1" /* Sezary disease, intrathoracic lymph nodes */
"C8413" = "1" /* Sezary disease, intra-abdominal lymph nodes */
"C8414" = "1" /* Sezary disease, lymph nodes of axilla and upper limb */
"C8415" = "1" /* Sezary disease, lymph nodes of inguinal region and lower limb */
"C8416" = "1" /* Sezary disease, intrapelvic lymph nodes */
"C8417" = "1" /* Sezary disease, spleen */
"C8418" = "1" /* Sezary disease, lymph nodes of multiple sites */
"C8419" = "1" /* Sezary disease, extranodal and solid organ sites */
"C8490" = "1" /* Mature T/NK-cell lymphomas, unspecified, unspecified site */
"C8491" = "1" /* Mature T/NK-cell lymphomas, unspecified, lymph nodes of head, face, and neck */
"C8492" = "1" /* Mature T/NK-cell lymphomas, unspecified, intrathoracic lymph nodes */
"C8493" = "1" /* Mature T/NK-cell lymphomas, unspecified, intra-abdominal lymph nodes */
"C8494" = "1" /* Mature T/NK-cell lymphomas, unspecified, lymph nodes of axilla and upper limb */
"C8495" = "1" /* Mature T/NK-cell lymphomas, unspecified, lymph nodes of inguinal region and lower limb */
"C8496" = "1" /* Mature T/NK-cell lymphomas, unspecified, intrapelvic lymph nodes */
"C8497" = "1" /* Mature T/NK-cell lymphomas, unspecified, spleen */
"C8498" = "1" /* Mature T/NK-cell lymphomas, unspecified, lymph nodes of multiple sites */
"C8499" = "1" /* Mature T/NK-cell lymphomas, unspecified, extranodal and solid organ sites */
"C84A0" = "1" /* Cutaneous T-cell lymphoma, unspecified, unspecified site */
"C84A1" = "1" /* Cutaneous T-cell lymphoma, unspecified lymph nodes of head, face, and neck */
"C84A2" = "1" /* Cutaneous T-cell lymphoma, unspecified, intrathoracic lymph nodes */
"C84A3" = "1" /* Cutaneous T-cell lymphoma, unspecified, intra-abdominal lymph nodes */
"C84A4" = "1" /* Cutaneous T-cell lymphoma, unspecified, lymph nodes of axilla and upper limb */
"C84A5" = "1" /* Cutaneous T-cell lymphoma, unspecified, lymph nodes of inguinal region and lower limb */
"C84A6" = "1" /* Cutaneous T-cell lymphoma, unspecified, intrapelvic lymph nodes */
"C84A7" = "1" /* Cutaneous T-cell lymphoma, unspecified, spleen */
"C84A8" = "1" /* Cutaneous T-cell lymphoma, unspecified, lymph nodes of multiple sites */
"C84A9" = "1" /* Cutaneous T-cell lymphoma, unspecified, extranodal and solid organ sites */
"C84Z0" = "1" /* Other mature T/NK-cell lymphomas, unspecified site */
"C84Z1" = "1" /* Other mature T/NK-cell lymphomas, lymph nodes of head, face, and neck */
"C84Z2" = "1" /* Other mature T/NK-cell lymphomas, intrathoracic lymph nodes */
"C84Z3" = "1" /* Other mature T/NK-cell lymphomas, intra-abdominal lymph nodes */
"C84Z4" = "1" /* Other mature T/NK-cell lymphomas, lymph nodes of axilla and upper limb */
"C84Z5" = "1" /* Other mature T/NK-cell lymphomas, lymph nodes of inguinal region and lower limb */
"C84Z6" = "1" /* Other mature T/NK-cell lymphomas, intrapelvic lymph nodes */
"C84Z7" = "1" /* Other mature T/NK-cell lymphomas, spleen */
"C84Z8" = "1" /* Other mature T/NK-cell lymphomas, lymph nodes of multiple sites */
"C84Z9" = "1" /* Other mature T/NK-cell lymphomas, extranodal and solid organ sites */
"C8510" = "1" /* Unspecified B-cell lymphoma, unspecified site */
"C8511" = "1" /* Unspecified B-cell lymphoma, lymph nodes of head, face, and neck */
"C8512" = "1" /* Unspecified B-cell lymphoma, intrathoracic lymph nodes */
"C8513" = "1" /* Unspecified B-cell lymphoma, intra-abdominal lymph nodes */
"C8514" = "1" /* Unspecified B-cell lymphoma, lymph nodes of axilla and upper limb */
"C8515" = "1" /* Unspecified B-cell lymphoma, lymph nodes of inguinal region and lower limb */
"C8516" = "1" /* Unspecified B-cell lymphoma, intrapelvic lymph nodes */
"C8517" = "1" /* Unspecified B-cell lymphoma, spleen */
"C8518" = "1" /* Unspecified B-cell lymphoma, lymph nodes of multiple sites */
"C8519" = "1" /* Unspecified B-cell lymphoma, extranodal and solid organ sites */
"C8520" = "1" /* Mediastinal (thymic) large B-cell lymphoma, unspecified site */
"C8521" = "1" /* Mediastinal (thymic) large B-cell lymphoma, lymph nodes of head, face, and neck */
"C8522" = "1" /* Mediastinal (thymic) large B-cell lymphoma, intrathoracic lymph nodes */
"C8523" = "1" /* Mediastinal (thymic) large B-cell lymphoma, intra-abdominal lymph nodes */
"C8524" = "1" /* Mediastinal (thymic) large B-cell lymphoma, lymph nodes of axilla and upper limb */
"C8525" = "1" /* Mediastinal (thymic) large B-cell lymphoma, lymph nodes of inguinal region and lower limb */
"C8526" = "1" /* Mediastinal (thymic) large B-cell lymphoma, intrapelvic lymph nodes */
"C8527" = "1" /* Mediastinal (thymic) large B-cell lymphoma, spleen */
"C8528" = "1" /* Mediastinal (thymic) large B-cell lymphoma, lymph nodes of multiple sites */
"C8529" = "1" /* Mediastinal (thymic) large B-cell lymphoma, extranodal and solid organ sites */
"C8580" = "1" /* Other specified types of non-Hodgkin lymphoma, unspecified site */
"C8581" = "1" /* Other specified types of non-Hodgkin lymphoma, lymph nodes of head, face, and neck */
"C8582" = "1" /* Other specified types of non-Hodgkin lymphoma, intrathoracic lymph nodes */
"C8583" = "1" /* Other specified types of non-Hodgkin lymphoma, intra-abdominal lymph nodes */
"C8584" = "1" /* Other specified types of non-Hodgkin lymphoma, lymph nodes of axilla and upper limb */
"C8585" = "1" /* Other specified types of non-Hodgkin lymphoma, lymph nodes of inguinal region and lower limb */
"C8586" = "1" /* Other specified types of non-Hodgkin lymphoma, intrapelvic lymph nodes */
"C8587" = "1" /* Other specified types of non-Hodgkin lymphoma, spleen */
"C8588" = "1" /* Other specified types of non-Hodgkin lymphoma, lymph nodes of multiple sites */
"C8589" = "1" /* Other specified types of non-Hodgkin lymphoma, extranodal and solid organ sites */
"C8590" = "1" /* Non-Hodgkin lymphoma, unspecified, unspecified site */
"C8591" = "1" /* Non-Hodgkin lymphoma, unspecified, lymph nodes of head, face, and neck */
"C8592" = "1" /* Non-Hodgkin lymphoma, unspecified, intrathoracic lymph nodes */
"C8593" = "1" /* Non-Hodgkin lymphoma, unspecified, intra-abdominal lymph nodes */
"C8594" = "1" /* Non-Hodgkin lymphoma, unspecified, lymph nodes of axilla and upper limb */
"C8595" = "1" /* Non-Hodgkin lymphoma, unspecified, lymph nodes of inguinal region and lower limb */
"C8596" = "1" /* Non-Hodgkin lymphoma, unspecified, intrapelvic lymph nodes */
"C8597" = "1" /* Non-Hodgkin lymphoma, unspecified, spleen */
"C8598" = "1" /* Non-Hodgkin lymphoma, unspecified, lymph nodes of multiple sites */
"C8599" = "1" /* Non-Hodgkin lymphoma, unspecified, extranodal and solid organ sites */
"C860" = "1" /* Extranodal NK/T-cell lymphoma, nasal type */
"C861" = "1" /* Hepatosplenic T-cell lymphoma */
"C862" = "1" /* Enteropathy-type (intestinal) T-cell lymphoma */
"C863" = "1" /* Subcutaneous panniculitis-like T-cell lymphoma */
"C864" = "1" /* Blastic NK-cell lymphoma */
"C880" = "1" /* Waldenstrom macroglobulinemia */
"C882" = "1" /* Heavy chain disease */
"C883" = "1" /* Immunoproliferative small intestinal disease */
"C888" = "1" /* Other malignant immunoproliferative diseases */
"C889" = "1" /* Malignant immunoproliferative disease, unspecified */
"C9000" = "1" /* Multiple myeloma not having achieved remission */
"C9001" = "1" /* Multiple myeloma in remission */
"C9010" = "1" /* Plasma cell leukemia not having achieved remission */
"C9011" = "1" /* Plasma cell leukemia in remission */
"C9020" = "1" /* Extramedullary plasmacytoma not having achieved remission */
"C9021" = "1" /* Extramedullary plasmacytoma in remission */
"C9030" = "1" /* Solitary plasmacytoma not having achieved remission */
"C9031" = "1" /* Solitary plasmacytoma in remission */
"C9100" = "1" /* Acute lymphoblastic leukemia not having achieved remission */
"C9101" = "1" /* Acute lymphoblastic leukemia, in remission */
"C9110" = "1" /* Chronic lymphocytic leukemia of B-cell type not having achieved remission */
"C9111" = "1" /* Chronic lymphocytic leukemia of B-cell type in remission */
"C9130" = "1" /* Prolymphocytic leukemia of B-cell type not having achieved remission */
"C9131" = "1" /* Prolymphocytic leukemia of B-cell type, in remission */
"C9140" = "1" /* Hairy cell leukemia not having achieved remission */
"C9141" = "1" /* Hairy cell leukemia, in remission */
"C9142" = "1" /* Hairy cell leukemia, in relapse */
"C9150" = "1" /* Adult T-cell lymphoma/leukemia (HTLV-1-associated) not having achieved remission */
"C9151" = "1" /* Adult T-cell lymphoma/leukemia (HTLV-1-associated), in remission */
"C9160" = "1" /* Prolymphocytic leukemia of T-cell type not having achieved remission */
"C9161" = "1" /* Prolymphocytic leukemia of T-cell type, in remission */
"C9190" = "1" /* Lymphoid leukemia, unspecified not having achieved remission */
"C9191" = "1" /* Lymphoid leukemia, unspecified, in remission */
"C91A0" = "1" /* Mature B-cell leukemia Burkitt-type not having achieved remission */
"C91A1" = "1" /* Mature B-cell leukemia Burkitt-type, in remission */
"C91Z0" = "1" /* Other lymphoid leukemia not having achieved remission */
"C91Z1" = "1" /* Other lymphoid leukemia, in remission */
"C960" = "1" /* Multifocal and multisystemic (disseminated) Langerhans-cell histiocytosis */
"C962" = "1" /* Malignant mast cell tumor */
"C964" = "1" /* Sarcoma of dendritic cells (accessory cells) */
"C969" = "1" /* Malignant neoplasm of lymphoid, hematopoietic and related tissue, unspecified */
"C96A" = "1" /* Histiocytic sarcoma */
"C96Z" = "1" /* Other specified malignant neoplasms of lymphoid, hematopoietic and related tissue */
"D47Z2" = "1" /* Castleman disease */
"D47Z9" = "1" /* Other specified neoplasms of uncertain behavior of lymphoid, hematopoietic and related tissue */
Other = "0"
;

/* Diagnosis codeset COAGDID last updated 161203 for ICD10 v70rev0 */
Value $COAGDID
"D6109" = "1" /* Other constitutional aplastic anemia */
"D611" = "1" /* Drug-induced aplastic anemia */
"D612" = "1" /* Aplastic anemia due to other external agents */
"D613" = "1" /* Idiopathic aplastic anemia */
"D61810" = "1" /* Antineoplastic chemotherapy induced pancytopenia */
"D61811" = "1" /* Other drug-induced pancytopenia */
"D61818" = "1" /* Other pancytopenia */
"D6182" = "1" /* Myelophthisis */
"D6189" = "1" /* Other specified aplastic anemias and other bone marrow failure syndromes */
"D619" = "1" /* Aplastic anemia, unspecified */
"D65" = "1" /* Disseminated intravascular coagulation [defibrination syndrome] */
"D66" = "1" /* Hereditary factor VIII deficiency */
"D67" = "1" /* Hereditary factor IX deficiency */
"D680" = "1" /* Von Willebrand's disease */
"D681" = "1" /* Hereditary factor XI deficiency */
"D682" = "1" /* Hereditary deficiency of other clotting factors */
"D68311" = "1" /* Acquired hemophilia */
"D68312" = "1" /* Antiphospholipid antibody with hemorrhagic disorder */
"D68318" = "1" /* Other hemorrhagic disorder due to intrinsic circulating anticoagulants, antibodies, or inhibitors */
"D6832" = "1" /* Hemorrhagic disorder due to extrinsic circulating anticoagulants */
"D684" = "1" /* Acquired coagulation factor deficiency */
"D688" = "1" /* Other specified coagulation defects */
"D689" = "1" /* Coagulation defect, unspecified */
"D691" = "1" /* Qualitative platelet defects */
"D693" = "1" /* Immune thrombocytopenic purpura */
"D6941" = "1" /* Evans syndrome */
"D6942" = "1" /* Congenital and hereditary thrombocytopenia purpura */
"D6949" = "1" /* Other primary thrombocytopenia */
"D6951" = "1" /* Posttransfusion purpura */
"D696" = "1" /* Thrombocytopenia, unspecified */
"D698" = "1" /* Other specified hemorrhagic conditions */
"D699" = "1" /* Hemorrhagic condition, unspecified */
Other = "0"
;

/* Diagnosis codeset IMMUITD last updated 161203 for ICD10 v70rev0 */
Value $IMMUITD
"B180" = "1" /* Chronic viral hepatitis B with delta-agent */
"B181" = "1" /* Chronic viral hepatitis B without delta-agent */
"B182" = "1" /* Chronic viral hepatitis C */
"B520" = "1" /* Plasmodium malariae malaria with nephropathy */
"D5702" = "1" /* Hb-SS disease with splenic sequestration */
"D57212" = "1" /* Sickle-cell/Hb-C disease with splenic sequestration */
"D57412" = "1" /* Sickle-cell thalassemia with splenic sequestration */
"D57812" = "1" /* Other sickle-cell disorders with splenic sequestration */
"D730" = "1" /* Hyposplenism */
"D731" = "1" /* Hypersplenism */
"D732" = "1" /* Chronic congestive splenomegaly */
"D733" = "1" /* Abscess of spleen */
"D735" = "1" /* Infarction of spleen */
"D7389" = "1" /* Other diseases of spleen */
"D739" = "1" /* Disease of spleen, unspecified */
"I8500" = "1" /* Esophageal varices without bleeding */
"I8501" = "1" /* Esophageal varices with bleeding */
"I8510" = "1" /* Secondary esophageal varices without bleeding */
"I8511" = "1" /* Secondary esophageal varices with bleeding */
"K7210" = "1" /* Chronic hepatic failure without coma */
"K7211" = "1" /* Chronic hepatic failure with coma */
"K7290" = "1" /* Hepatic failure, unspecified without coma */
"K7291" = "1" /* Hepatic failure, unspecified with coma */
"K766" = "1" /* Portal hypertension */
"K7681" = "1" /* Hepatopulmonary syndrome */
"M320" = "1" /* Drug-induced systemic lupus erythematosus */
"M3210" = "1" /* Systemic lupus erythematosus, organ or system involvement unspecified */
"M3211" = "1" /* Endocarditis in systemic lupus erythematosus */
"M3212" = "1" /* Pericarditis in systemic lupus erythematosus */
"M3213" = "1" /* Lung involvement in systemic lupus erythematosus */
"M3214" = "1" /* Glomerular disease in systemic lupus erythematosus */
"M3215" = "1" /* Tubulo-interstitial nephropathy in systemic lupus erythematosus */
"M3219" = "1" /* Other organ or system involvement in systemic lupus erythematosus */
"M328" = "1" /* Other forms of systemic lupus erythematosus */
"M329" = "1" /* Systemic lupus erythematosus, unspecified */
"M3300" = "1" /* Juvenile dermatopolymyositis, organ involvement unspecified */
"M3301" = "1" /* Juvenile dermatopolymyositis with respiratory involvement */
"M3302" = "1" /* Juvenile dermatopolymyositis with myopathy */
"M3309" = "1" /* Juvenile dermatopolymyositis with other organ involvement */
"M3310" = "1" /* Other dermatopolymyositis, organ involvement unspecified */
"M3311" = "1" /* Other dermatopolymyositis with respiratory involvement */
"M3312" = "1" /* Other dermatopolymyositis with myopathy */
"M3319" = "1" /* Other dermatopolymyositis with other organ involvement */
"M3320" = "1" /* Polymyositis, organ involvement unspecified */
"M3321" = "1" /* Polymyositis with respiratory involvement */
"M3322" = "1" /* Polymyositis with myopathy */
"M3329" = "1" /* Polymyositis with other organ involvement */
"M3390" = "1" /* Dermatopolymyositis, unspecified, organ involvement unspecified */
"M3391" = "1" /* Dermatopolymyositis, unspecified with respiratory involvement */
"M3392" = "1" /* Dermatopolymyositis, unspecified with myopathy */
"M3399" = "1" /* Dermatopolymyositis, unspecified with other organ involvement */
"M340" = "1" /* Progressive systemic sclerosis */
"M341" = "1" /* CR(E)ST syndrome */
"M342" = "1" /* Systemic sclerosis induced by drug and chemical */
"M3481" = "1" /* Systemic sclerosis with lung involvement */
"M3482" = "1" /* Systemic sclerosis with myopathy */
"M3483" = "1" /* Systemic sclerosis with polyneuropathy */
"M3489" = "1" /* Other systemic sclerosis */
"M349" = "1" /* Systemic sclerosis, unspecified */
"M3500" = "1" /* Sicca syndrome, unspecified */
"M3501" = "1" /* Sicca syndrome with keratoconjunctivitis */
"M3502" = "1" /* Sicca syndrome with lung involvement */
"M3503" = "1" /* Sicca syndrome with myopathy */
"M3504" = "1" /* Sicca syndrome with tubulo-interstitial nephropathy */
"M3509" = "1" /* Sicca syndrome with other organ involvement */
"M351" = "1" /* Other overlap syndromes */
"M355" = "1" /* Multifocal fibrosclerosis */
"M358" = "1" /* Other specified systemic involvement of connective tissue */
"M359" = "1" /* Systemic involvement of connective tissue, unspecified */
"M360" = "1" /* Dermato(poly)myositis in neoplastic disease */
"M368" = "1" /* Systemic disorders of connective tissue in other diseases classified elsewhere */
"N000" = "1" /* Acute nephritic syndrome with minor glomerular abnormality */
"N001" = "1" /* Acute nephritic syndrome with focal and segmental glomerular lesions */
"N002" = "1" /* Acute nephritic syndrome with diffuse membranous glomerulonephritis */
"N003" = "1" /* Acute nephritic syndrome with diffuse mesangial proliferative glomerulonephritis */
"N004" = "1" /* Acute nephritic syndrome with diffuse endocapillary proliferative glomerulonephritis */
"N005" = "1" /* Acute nephritic syndrome with diffuse mesangiocapillary glomerulonephritis */
"N006" = "1" /* Acute nephritic syndrome with dense deposit disease */
"N007" = "1" /* Acute nephritic syndrome with diffuse crescentic glomerulonephritis */
"N008" = "1" /* Acute nephritic syndrome with other morphologic changes */
"N009" = "1" /* Acute nephritic syndrome with unspecified morphologic changes */
"N010" = "1" /* Rapidly progressive nephritic syndrome with minor glomerular abnormality */
"N011" = "1" /* Rapidly progressive nephritic syndrome with focal and segmental glomerular lesions */
"N012" = "1" /* Rapidly progressive nephritic syndrome with diffuse membranous glomerulonephritis */
"N013" = "1" /* Rapidly progressive nephritic syndrome with diffuse mesangial proliferative glomerulonephritis */
"N014" = "1" /* Rapidly progressive nephritic syndrome with diffuse endocapillary proliferative glomerulonephritis */
"N015" = "1" /* Rapidly progressive nephritic syndrome with diffuse mesangiocapillary glomerulonephritis */
"N016" = "1" /* Rapidly progressive nephritic syndrome with dense deposit disease */
"N017" = "1" /* Rapidly progressive nephritic syndrome with diffuse crescentic glomerulonephritis */
"N018" = "1" /* Rapidly progressive nephritic syndrome with other morphologic changes */
"N019" = "1" /* Rapidly progressive nephritic syndrome with unspecified morphologic changes */
"N020" = "1" /* Recurrent and persistent hematuria with minor glomerular abnormality */
"N021" = "1" /* Recurrent and persistent hematuria with focal and segmental glomerular lesions */
"N022" = "1" /* Recurrent and persistent hematuria with diffuse membranous glomerulonephritis */
"N023" = "1" /* Recurrent and persistent hematuria with diffuse mesangial proliferative glomerulonephritis */
"N024" = "1" /* Recurrent and persistent hematuria with diffuse endocapillary proliferative glomerulonephritis */
"N025" = "1" /* Recurrent and persistent hematuria with diffuse mesangiocapillary glomerulonephritis */
"N026" = "1" /* Recurrent and persistent hematuria with dense deposit disease */
"N027" = "1" /* Recurrent and persistent hematuria with diffuse crescentic glomerulonephritis */
"N028" = "1" /* Recurrent and persistent hematuria with other morphologic changes */
"N029" = "1" /* Recurrent and persistent hematuria with unspecified morphologic changes */
"N030" = "1" /* Chronic nephritic syndrome with minor glomerular abnormality */
"N031" = "1" /* Chronic nephritic syndrome with focal and segmental glomerular lesions */
"N032" = "1" /* Chronic nephritic syndrome with diffuse membranous glomerulonephritis */
"N033" = "1" /* Chronic nephritic syndrome with diffuse mesangial proliferative glomerulonephritis */
"N034" = "1" /* Chronic nephritic syndrome with diffuse endocapillary proliferative glomerulonephritis */
"N035" = "1" /* Chronic nephritic syndrome with diffuse mesangiocapillary glomerulonephritis */
"N036" = "1" /* Chronic nephritic syndrome with dense deposit disease */
"N037" = "1" /* Chronic nephritic syndrome with diffuse crescentic glomerulonephritis */
"N038" = "1" /* Chronic nephritic syndrome with other morphologic changes */
"N039" = "1" /* Chronic nephritic syndrome with unspecified morphologic changes */
"N040" = "1" /* Nephrotic syndrome with minor glomerular abnormality */
"N041" = "1" /* Nephrotic syndrome with focal and segmental glomerular lesions */
"N042" = "1" /* Nephrotic syndrome with diffuse membranous glomerulonephritis */
"N043" = "1" /* Nephrotic syndrome with diffuse mesangial proliferative glomerulonephritis */
"N044" = "1" /* Nephrotic syndrome with diffuse endocapillary proliferative glomerulonephritis */
"N045" = "1" /* Nephrotic syndrome with diffuse mesangiocapillary glomerulonephritis */
"N046" = "1" /* Nephrotic syndrome with dense deposit disease */
"N047" = "1" /* Nephrotic syndrome with diffuse crescentic glomerulonephritis */
"N048" = "1" /* Nephrotic syndrome with other morphologic changes */
"N049" = "1" /* Nephrotic syndrome with unspecified morphologic changes */
"N050" = "1" /* Unspecified nephritic syndrome with minor glomerular abnormality */
"N051" = "1" /* Unspecified nephritic syndrome with focal and segmental glomerular lesions */
"N052" = "1" /* Unspecified nephritic syndrome with diffuse membranous glomerulonephritis */
"N053" = "1" /* Unspecified nephritic syndrome with diffuse mesangial proliferative glomerulonephritis */
"N054" = "1" /* Unspecified nephritic syndrome with diffuse endocapillary proliferative glomerulonephritis */
"N055" = "1" /* Unspecified nephritic syndrome with diffuse mesangiocapillary glomerulonephritis */
"N056" = "1" /* Unspecified nephritic syndrome with dense deposit disease */
"N057" = "1" /* Unspecified nephritic syndrome with diffuse crescentic glomerulonephritis */
"N058" = "1" /* Unspecified nephritic syndrome with other morphologic changes */
"N059" = "1" /* Unspecified nephritic syndrome with unspecified morphologic changes */
"N060" = "1" /* Isolated proteinuria with minor glomerular abnormality */
"N061" = "1" /* Isolated proteinuria with focal and segmental glomerular lesions */
"N062" = "1" /* Isolated proteinuria with diffuse membranous glomerulonephritis */
"N063" = "1" /* Isolated proteinuria with diffuse mesangial proliferative glomerulonephritis */
"N064" = "1" /* Isolated proteinuria with diffuse endocapillary proliferative glomerulonephritis */
"N065" = "1" /* Isolated proteinuria with diffuse mesangiocapillary glomerulonephritis */
"N066" = "1" /* Isolated proteinuria with dense deposit disease */
"N067" = "1" /* Isolated proteinuria with diffuse crescentic glomerulonephritis */
"N068" = "1" /* Isolated proteinuria with other morphologic lesion */
"N069" = "1" /* Isolated proteinuria with unspecified morphologic lesion */
"N070" = "1" /* Hereditary nephropathy, not elsewhere classified with minor glomerular abnormality */
"N071" = "1" /* Hereditary nephropathy, not elsewhere classified with focal and segmental glomerular lesions */
"N072" = "1" /* Hereditary nephropathy, not elsewhere classified with diffuse membranous glomerulonephritis */
"N073" = "1" /* Hereditary nephropathy, not elsewhere classified with diffuse mesangial proliferative glomerulonephritis */
"N074" = "1" /* Hereditary nephropathy, not elsewhere classified with diffuse endocapillary proliferative glomerulonephritis */
"N075" = "1" /* Hereditary nephropathy, not elsewhere classified with diffuse mesangiocapillary glomerulonephritis */
"N076" = "1" /* Hereditary nephropathy, not elsewhere classified with dense deposit disease */
"N077" = "1" /* Hereditary nephropathy, not elsewhere classified with diffuse crescentic glomerulonephritis */
"N078" = "1" /* Hereditary nephropathy, not elsewhere classified with other morphologic lesions */
"N079" = "1" /* Hereditary nephropathy, not elsewhere classified with unspecified morphologic lesions */
"N140" = "1" /* Analgesic nephropathy */
"N141" = "1" /* Nephropathy induced by other drugs, medicaments and biological substances */
"N142" = "1" /* Nephropathy induced by unspecified drug, medicament or biological substance */
"N143" = "1" /* Nephropathy induced by heavy metals */
"N144" = "1" /* Toxic nephropathy, not elsewhere classified */
"N150" = "1" /* Balkan nephropathy */
"N158" = "1" /* Other specified renal tubulo-interstitial diseases */
"N159" = "1" /* Renal tubulo-interstitial disease, unspecified */
"N16" = "1" /* Renal tubulo-interstitial disorders in diseases classified elsewhere */
"Q8901" = "1" /* Asplenia (congenital) */
"Q8909" = "1" /* Congenital malformations of spleen */
"R64" = "1" /* Cachexia */
"S3600XA" = "1" /* Unspecified injury of spleen, initial encounter */
"S36020A" = "1" /* Minor contusion of spleen, initial encounter */
"S36021A" = "1" /* Major contusion of spleen, initial encounter */
"S36029A" = "1" /* Unspecified contusion of spleen, initial encounter */
"S36030A" = "1" /* Superficial (capsular) laceration of spleen, initial encounter */
"S36031A" = "1" /* Moderate laceration of spleen, initial encounter */
"S36032A" = "1" /* Major laceration of spleen, initial encounter */
"S36039A" = "1" /* Unspecified laceration of spleen, initial encounter */
"S3609XA" = "1" /* Other injury of spleen, initial encounter */
Other = "0"
;

/* Diagnosis codeset IMMUNHD last updated 161203 for ICD10 v70rev0 */
Value $IMMUNHD
"B20" = "1" /* Human immunodeficiency virus [HIV] disease */
"B59" = "1" /* Pneumocystosis */
"C802" = "1" /* Malignant neoplasm associated with transplanted organ */
"C8300" = "1" /* Small cell B-cell lymphoma, unspecified site */
"C8301" = "1" /* Small cell B-cell lymphoma, lymph nodes of head, face, and neck */
"C8302" = "1" /* Small cell B-cell lymphoma, intrathoracic lymph nodes */
"C8303" = "1" /* Small cell B-cell lymphoma, intra-abdominal lymph nodes */
"C8304" = "1" /* Small cell B-cell lymphoma, lymph nodes of axilla and upper limb */
"C8305" = "1" /* Small cell B-cell lymphoma, lymph nodes of inguinal region and lower limb */
"C8306" = "1" /* Small cell B-cell lymphoma, intrapelvic lymph nodes */
"C8307" = "1" /* Small cell B-cell lymphoma, spleen */
"C8308" = "1" /* Small cell B-cell lymphoma, lymph nodes of multiple sites */
"C8309" = "1" /* Small cell B-cell lymphoma, extranodal and solid organ sites */
"C8330" = "1" /* Diffuse large B-cell lymphoma, unspecified site */
"C8331" = "1" /* Diffuse large B-cell lymphoma, lymph nodes of head, face, and neck */
"C8332" = "1" /* Diffuse large B-cell lymphoma, intrathoracic lymph nodes */
"C8333" = "1" /* Diffuse large B-cell lymphoma, intra-abdominal lymph nodes */
"C8334" = "1" /* Diffuse large B-cell lymphoma, lymph nodes of axilla and upper limb */
"C8335" = "1" /* Diffuse large B-cell lymphoma, lymph nodes of inguinal region and lower limb */
"C8336" = "1" /* Diffuse large B-cell lymphoma, intrapelvic lymph nodes */
"C8337" = "1" /* Diffuse large B-cell lymphoma, spleen */
"C8338" = "1" /* Diffuse large B-cell lymphoma, lymph nodes of multiple sites */
"C8339" = "1" /* Diffuse large B-cell lymphoma, extranodal and solid organ sites */
"C8350" = "1" /* Lymphoblastic (diffuse) lymphoma, unspecified site */
"C8351" = "1" /* Lymphoblastic (diffuse) lymphoma, lymph nodes of head, face, and neck */
"C8352" = "1" /* Lymphoblastic (diffuse) lymphoma, intrathoracic lymph nodes */
"C8353" = "1" /* Lymphoblastic (diffuse) lymphoma, intra-abdominal lymph nodes */
"C8354" = "1" /* Lymphoblastic (diffuse) lymphoma, lymph nodes of axilla and upper limb */
"C8355" = "1" /* Lymphoblastic (diffuse) lymphoma, lymph nodes of inguinal region and lower limb */
"C8356" = "1" /* Lymphoblastic (diffuse) lymphoma, intrapelvic lymph nodes */
"C8357" = "1" /* Lymphoblastic (diffuse) lymphoma, spleen */
"C8358" = "1" /* Lymphoblastic (diffuse) lymphoma, lymph nodes of multiple sites */
"C8359" = "1" /* Lymphoblastic (diffuse) lymphoma, extranodal and solid organ sites */
"C8370" = "1" /* Burkitt lymphoma, unspecified site */
"C8371" = "1" /* Burkitt lymphoma, lymph nodes of head, face, and neck */
"C8372" = "1" /* Burkitt lymphoma, intrathoracic lymph nodes */
"C8373" = "1" /* Burkitt lymphoma, intra-abdominal lymph nodes */
"C8374" = "1" /* Burkitt lymphoma, lymph nodes of axilla and upper limb */
"C8375" = "1" /* Burkitt lymphoma, lymph nodes of inguinal region and lower limb */
"C8376" = "1" /* Burkitt lymphoma, intrapelvic lymph nodes */
"C8377" = "1" /* Burkitt lymphoma, spleen */
"C8378" = "1" /* Burkitt lymphoma, lymph nodes of multiple sites */
"C8379" = "1" /* Burkitt lymphoma, extranodal and solid organ sites */
"C8380" = "1" /* Other non-follicular lymphoma, unspecified site */
"C8381" = "1" /* Other non-follicular lymphoma, lymph nodes of head, face, and neck */
"C8382" = "1" /* Other non-follicular lymphoma, intrathoracic lymph nodes */
"C8383" = "1" /* Other non-follicular lymphoma, intra-abdominal lymph nodes */
"C8384" = "1" /* Other non-follicular lymphoma, lymph nodes of axilla and upper limb */
"C8385" = "1" /* Other non-follicular lymphoma, lymph nodes of inguinal region and lower limb */
"C8386" = "1" /* Other non-follicular lymphoma, intrapelvic lymph nodes */
"C8387" = "1" /* Other non-follicular lymphoma, spleen */
"C8388" = "1" /* Other non-follicular lymphoma, lymph nodes of multiple sites */
"C8389" = "1" /* Other non-follicular lymphoma, extranodal and solid organ sites */
"C8390" = "1" /* Non-follicular (diffuse) lymphoma, unspecified, unspecified site */
"C8391" = "1" /* Non-follicular (diffuse) lymphoma, unspecified, lymph nodes of head, face, and neck */
"C8392" = "1" /* Non-follicular (diffuse) lymphoma, unspecified, intrathoracic lymph nodes */
"C8393" = "1" /* Non-follicular (diffuse) lymphoma, unspecified, intra-abdominal lymph nodes */
"C8394" = "1" /* Non-follicular (diffuse) lymphoma, unspecified, lymph nodes of axilla and upper limb */
"C8395" = "1" /* Non-follicular (diffuse) lymphoma, unspecified, lymph nodes of inguinal region and lower limb */
"C8396" = "1" /* Non-follicular (diffuse) lymphoma, unspecified, intrapelvic lymph nodes */
"C8397" = "1" /* Non-follicular (diffuse) lymphoma, unspecified, spleen */
"C8398" = "1" /* Non-follicular (diffuse) lymphoma, unspecified, lymph nodes of multiple sites */
"C8399" = "1" /* Non-follicular (diffuse) lymphoma, unspecified, extranodal and solid organ sites */
"C865" = "1" /* Angioimmunoblastic T-cell lymphoma */
"C866" = "1" /* Primary cutaneous CD30-positive T-cell proliferations */
"C888" = "1" /* Other malignant immunoproliferative diseases */
"C9002" = "1" /* Multiple myeloma in relapse */
"C9012" = "1" /* Plasma cell leukemia in relapse */
"C9022" = "1" /* Extramedullary plasmacytoma in relapse */
"C9032" = "1" /* Solitary plasmacytoma in relapse */
"C9102" = "1" /* Acute lymphoblastic leukemia, in relapse */
"C9112" = "1" /* Chronic lymphocytic leukemia of B-cell type in relapse */
"C9132" = "1" /* Prolymphocytic leukemia of B-cell type, in relapse */
"C9152" = "1" /* Adult T-cell lymphoma/leukemia (HTLV-1-associated), in relapse */
"C9162" = "1" /* Prolymphocytic leukemia of T-cell type, in relapse */
"C9192" = "1" /* Lymphoid leukemia, unspecified, in relapse */
"C91A2" = "1" /* Mature B-cell leukemia Burkitt-type, in relapse */
"C91Z2" = "1" /* Other lymphoid leukemia, in relapse */
"C9200" = "1" /* Acute myeloblastic leukemia, not having achieved remission */
"C9201" = "1" /* Acute myeloblastic leukemia, in remission */
"C9202" = "1" /* Acute myeloblastic leukemia, in relapse */
"C9210" = "1" /* Chronic myeloid leukemia, BCR/ABL-positive, not having achieved remission */
"C9211" = "1" /* Chronic myeloid leukemia, BCR/ABL-positive, in remission */
"C9212" = "1" /* Chronic myeloid leukemia, BCR/ABL-positive, in relapse */
"C9220" = "1" /* Atypical chronic myeloid leukemia, BCR/ABL-negative, not having achieved remission */
"C9221" = "1" /* Atypical chronic myeloid leukemia, BCR/ABL-negative, in remission */
"C9222" = "1" /* Atypical chronic myeloid leukemia, BCR/ABL-negative, in relapse */
"C9230" = "1" /* Myeloid sarcoma, not having achieved remission */
"C9231" = "1" /* Myeloid sarcoma, in remission */
"C9232" = "1" /* Myeloid sarcoma, in relapse */
"C9240" = "1" /* Acute promyelocytic leukemia, not having achieved remission */
"C9241" = "1" /* Acute promyelocytic leukemia, in remission */
"C9242" = "1" /* Acute promyelocytic leukemia, in relapse */
"C9250" = "1" /* Acute myelomonocytic leukemia, not having achieved remission */
"C9251" = "1" /* Acute myelomonocytic leukemia, in remission */
"C9252" = "1" /* Acute myelomonocytic leukemia, in relapse */
"C9260" = "1" /* Acute myeloid leukemia with 11q23-abnormality not having achieved remission */
"C9261" = "1" /* Acute myeloid leukemia with 11q23-abnormality in remission */
"C9262" = "1" /* Acute myeloid leukemia with 11q23-abnormality in relapse */
"C9290" = "1" /* Myeloid leukemia, unspecified, not having achieved remission */
"C9291" = "1" /* Myeloid leukemia, unspecified in remission */
"C9292" = "1" /* Myeloid leukemia, unspecified in relapse */
"C92A0" = "1" /* Acute myeloid leukemia with multilineage dysplasia, not having achieved remission */
"C92A1" = "1" /* Acute myeloid leukemia with multilineage dysplasia, in remission */
"C92A2" = "1" /* Acute myeloid leukemia with multilineage dysplasia, in relapse */
"C92Z0" = "1" /* Other myeloid leukemia not having achieved remission */
"C92Z1" = "1" /* Other myeloid leukemia, in remission */
"C92Z2" = "1" /* Other myeloid leukemia, in relapse */
"C9300" = "1" /* Acute monoblastic/monocytic leukemia, not having achieved remission */
"C9301" = "1" /* Acute monoblastic/monocytic leukemia, in remission */
"C9302" = "1" /* Acute monoblastic/monocytic leukemia, in relapse */
"C9310" = "1" /* Chronic myelomonocytic leukemia not having achieved remission */
"C9311" = "1" /* Chronic myelomonocytic leukemia, in remission */
"C9312" = "1" /* Chronic myelomonocytic leukemia, in relapse */
"C9330" = "1" /* Juvenile myelomonocytic leukemia, not having achieved remission */
"C9331" = "1" /* Juvenile myelomonocytic leukemia, in remission */
"C9332" = "1" /* Juvenile myelomonocytic leukemia, in relapse */
"C9390" = "1" /* Monocytic leukemia, unspecified, not having achieved remission */
"C9391" = "1" /* Monocytic leukemia, unspecified in remission */
"C9392" = "1" /* Monocytic leukemia, unspecified in relapse */
"C93Z0" = "1" /* Other monocytic leukemia, not having achieved remission */
"C93Z1" = "1" /* Other monocytic leukemia, in remission */
"C93Z2" = "1" /* Other monocytic leukemia, in relapse */
"C9400" = "1" /* Acute erythroid leukemia, not having achieved remission */
"C9401" = "1" /* Acute erythroid leukemia, in remission */
"C9402" = "1" /* Acute erythroid leukemia, in relapse */
"C9420" = "1" /* Acute megakaryoblastic leukemia not having achieved remission */
"C9421" = "1" /* Acute megakaryoblastic leukemia, in remission */
"C9422" = "1" /* Acute megakaryoblastic leukemia, in relapse */
"C9430" = "1" /* Mast cell leukemia not having achieved remission */
"C9431" = "1" /* Mast cell leukemia, in remission */
"C9432" = "1" /* Mast cell leukemia, in relapse */
"C9440" = "1" /* Acute panmyelosis with myelofibrosis not having achieved remission */
"C9441" = "1" /* Acute panmyelosis with myelofibrosis, in remission */
"C9442" = "1" /* Acute panmyelosis with myelofibrosis, in relapse */
"C946" = "1" /* Myelodysplastic disease, not classified */
"C9480" = "1" /* Other specified leukemias not having achieved remission */
"C9481" = "1" /* Other specified leukemias, in remission */
"C9482" = "1" /* Other specified leukemias, in relapse */
"C9500" = "1" /* Acute leukemia of unspecified cell type not having achieved remission */
"C9501" = "1" /* Acute leukemia of unspecified cell type, in remission */
"C9502" = "1" /* Acute leukemia of unspecified cell type, in relapse */
"C9510" = "1" /* Chronic leukemia of unspecified cell type not having achieved remission */
"C9511" = "1" /* Chronic leukemia of unspecified cell type, in remission */
"C9512" = "1" /* Chronic leukemia of unspecified cell type, in relapse */
"C9590" = "1" /* Leukemia, unspecified not having achieved remission */
"C9591" = "1" /* Leukemia, unspecified, in remission */
"C9592" = "1" /* Leukemia, unspecified, in relapse */
"D45" = "1" /* Polycythemia vera */
"D4622" = "1" /* Refractory anemia with excess of blasts 2 */
"D471" = "1" /* Chronic myeloproliferative disease */
"D479" = "1" /* Neoplasm of uncertain behavior of lymphoid, hematopoietic and related tissue, unspecified */
"D47Z1" = "1" /* Post-transplant lymphoproliferative disorder (PTLD) */
"D47Z9" = "1" /* Other specified neoplasms of uncertain behavior of lymphoid, hematopoietic and related tissue */
"D6109" = "1" /* Other constitutional aplastic anemia */
"D61810" = "1" /* Antineoplastic chemotherapy induced pancytopenia */
"D61811" = "1" /* Other drug-induced pancytopenia */
"D61818" = "1" /* Other pancytopenia */
"D700" = "1" /* Congenital agranulocytosis */
"D701" = "1" /* Agranulocytosis secondary to cancer chemotherapy */
"D702" = "1" /* Other drug-induced agranulocytosis */
"D704" = "1" /* Cyclic neutropenia */
"D708" = "1" /* Other neutropenia */
"D709" = "1" /* Neutropenia, unspecified */
"D71" = "1" /* Functional disorders of polymorphonuclear neutrophils */
"D720" = "1" /* Genetic anomalies of leukocytes */
"D72810" = "1" /* Lymphocytopenia */
"D72818" = "1" /* Other decreased white blood cell count */
"D72819" = "1" /* Decreased white blood cell count, unspecified */
"D7381" = "1" /* Neutropenic splenomegaly */
"D7581" = "1" /* Myelofibrosis */
"D761" = "1" /* Hemophagocytic lymphohistiocytosis */
"D762" = "1" /* Hemophagocytic syndrome, infection-associated */
"D763" = "1" /* Other histiocytosis syndromes */
"D800" = "1" /* Hereditary hypogammaglobulinemia */
"D801" = "1" /* Nonfamilial hypogammaglobulinemia */
"D802" = "1" /* Selective deficiency of immunoglobulin A [IgA] */
"D803" = "1" /* Selective deficiency of immunoglobulin G [IgG] subclasses */
"D804" = "1" /* Selective deficiency of immunoglobulin M [IgM] */
"D805" = "1" /* Immunodeficiency with increased immunoglobulin M [IgM] */
"D806" = "1" /* Antibody deficiency with near-normal immunoglobulins or with hyperimmunoglobulinemia */
"D807" = "1" /* Transient hypogammaglobulinemia of infancy */
"D808" = "1" /* Other immunodeficiencies with predominantly antibody defects */
"D809" = "1" /* Immunodeficiency with predominantly antibody defects, unspecified */
"D810" = "1" /* Severe combined immunodeficiency [SCID] with reticular dysgenesis */
"D811" = "1" /* Severe combined immunodeficiency [SCID] with low T- and B-cell numbers */
"D812" = "1" /* Severe combined immunodeficiency [SCID] with low or normal B-cell numbers */
"D814" = "1" /* Nezelof's syndrome */
"D816" = "1" /* Major histocompatibility complex class I deficiency */
"D817" = "1" /* Major histocompatibility complex class II deficiency */
"D8189" = "1" /* Other combined immunodeficiencies */
"D819" = "1" /* Combined immunodeficiency, unspecified */
"D820" = "1" /* Wiskott-Aldrich syndrome */
"D821" = "1" /* Di George's syndrome */
"D822" = "1" /* Immunodeficiency with short-limbed stature */
"D823" = "1" /* Immunodeficiency following hereditary defective response to Epstein-Barr virus */
"D824" = "1" /* Hyperimmunoglobulin E [IgE] syndrome */
"D828" = "1" /* Immunodeficiency associated with other specified major defects */
"D829" = "1" /* Immunodeficiency associated with major defect, unspecified */
"D830" = "1" /* Common variable immunodeficiency with predominant abnormalities of B-cell numbers and function */
"D831" = "1" /* Common variable immunodeficiency with predominant immunoregulatory T-cell disorders */
"D832" = "1" /* Common variable immunodeficiency with autoantibodies to B- or T-cells */
"D838" = "1" /* Other common variable immunodeficiencies */
"D839" = "1" /* Common variable immunodeficiency, unspecified */
"D840" = "1" /* Lymphocyte function antigen-1 [LFA-1] defect */
"D841" = "1" /* Defects in the complement system */
"D848" = "1" /* Other specified immunodeficiencies */
"D849" = "1" /* Immunodeficiency, unspecified */
"D893" = "1" /* Immune reconstitution syndrome */
"D89810" = "1" /* Acute graft-versus-host disease */
"D89811" = "1" /* Chronic graft-versus-host disease */
"D89812" = "1" /* Acute on chronic graft-versus-host disease */
"D89813" = "1" /* Graft-versus-host disease, unspecified */
"D8982" = "1" /* Autoimmune lymphoproliferative syndrome [ALPS] */
"D8989" = "1" /* Other specified disorders involving the immune mechanism, not elsewhere classified */
"D899" = "1" /* Disorder involving the immune mechanism, unspecified */
"E40" = "1" /* Kwashiorkor */
"E41" = "1" /* Nutritional marasmus */
"E42" = "1" /* Marasmic kwashiorkor */
"E43" = "1" /* Unspecified severe protein-calorie malnutrition */
"I120" = "1" /* Hypertensive chronic kidney disease with stage 5 chronic kidney disease or end stage renal disease */
"I1311" = "1" /* Hypertensive heart and chronic kidney disease without heart failure, with stage 5 chronic kidney disease, or end stage renal disease */
"I132" = "1" /* Hypertensive heart and chronic kidney disease with heart failure and with stage 5 chronic kidney disease, or end stage renal disease */
"K912" = "1" /* Postsurgical malabsorption, not elsewhere classified */
"N185" = "1" /* Chronic kidney disease, stage 5 */
"N186" = "1" /* End stage renal disease */
"T8600" = "1" /* Unspecified complication of bone marrow transplant */
"T8601" = "1" /* Bone marrow transplant rejection */
"T8602" = "1" /* Bone marrow transplant failure */
"T8603" = "1" /* Bone marrow transplant infection */
"T8609" = "1" /* Other complications of bone marrow transplant */
"T8610" = "1" /* Unspecified complication of kidney transplant */
"T8611" = "1" /* Kidney transplant rejection */
"T8612" = "1" /* Kidney transplant failure */
"T8613" = "1" /* Kidney transplant infection */
"T8619" = "1" /* Other complication of kidney transplant */
"T8620" = "1" /* Unspecified complication of heart transplant */
"T8621" = "1" /* Heart transplant rejection */
"T8622" = "1" /* Heart transplant failure */
"T8623" = "1" /* Heart transplant infection */
"T86290" = "1" /* Cardiac allograft vasculopathy */
"T86298" = "1" /* Other complications of heart transplant */
"T8630" = "1" /* Unspecified complication of heart-lung transplant */
"T8631" = "1" /* Heart-lung transplant rejection */
"T8632" = "1" /* Heart-lung transplant failure */
"T8633" = "1" /* Heart-lung transplant infection */
"T8639" = "1" /* Other complications of heart-lung transplant */
"T8640" = "1" /* Unspecified complication of liver transplant */
"T8641" = "1" /* Liver transplant rejection */
"T8642" = "1" /* Liver transplant failure */
"T8643" = "1" /* Liver transplant infection */
"T8649" = "1" /* Other complications of liver transplant */
"T865" = "1" /* Complications of stem cell transplant */
"T86810" = "1" /* Lung transplant rejection */
"T86811" = "1" /* Lung transplant failure */
"T86812" = "1" /* Lung transplant infection */
"T86818" = "1" /* Other complications of lung transplant */
"T86819" = "1" /* Unspecified complication of lung transplant */
"T86830" = "1" /* Bone graft rejection */
"T86831" = "1" /* Bone graft failure */
"T86832" = "1" /* Bone graft infection */
"T86838" = "1" /* Other complications of bone graft */
"T86839" = "1" /* Unspecified complication of bone graft */
"T86850" = "1" /* Intestine transplant rejection */
"T86851" = "1" /* Intestine transplant failure */
"T86852" = "1" /* Intestine transplant infection */
"T86858" = "1" /* Other complications of intestine transplant */
"T86859" = "1" /* Unspecified complication of intestine transplant */
"T86890" = "1" /* Other transplanted tissue rejection */
"T86891" = "1" /* Other transplanted tissue failure */
"T86892" = "1" /* Other transplanted tissue infection */
"T86898" = "1" /* Other complications of other transplanted tissue */
"T86899" = "1" /* Unspecified complication of other transplanted tissue */
"T8690" = "1" /* Unspecified complication of unspecified transplanted organ and tissue */
"T8691" = "1" /* Unspecified transplanted organ and tissue rejection */
"T8692" = "1" /* Unspecified transplanted organ and tissue failure */
"T8693" = "1" /* Unspecified transplanted organ and tissue infection */
"T8699" = "1" /* Other complications of unspecified transplanted organ and tissue */
"Z4821" = "1" /* Encounter for aftercare following heart transplant */
"Z4822" = "1" /* Encounter for aftercare following kidney transplant */
"Z4823" = "1" /* Encounter for aftercare following liver transplant */
"Z4824" = "1" /* Encounter for aftercare following lung transplant */
"Z48280" = "1" /* Encounter for aftercare following heart-lung transplant */
"Z48290" = "1" /* Encounter for aftercare following bone marrow transplant */
"Z48288" = "1" /* Encounter for aftercare following multiple organ transplant */
"Z48298" = "1" /* Encounter for aftercare following other organ transplant */
"Z4901" = "1" /* Encounter for fitting and adjustment of extracorporeal dialysis catheter */
"Z4902" = "1" /* Encounter for fitting and adjustment of peritoneal dialysis catheter */
"Z4931" = "1" /* Encounter for adequacy testing for hemodialysis */
"Z4932" = "1" /* Encounter for adequacy testing for peritoneal dialysis */
"Z940" = "1" /* Kidney transplant status */
"Z941" = "1" /* Heart transplant status */
"Z942" = "1" /* Lung transplant status */
"Z943" = "1" /* Heart and lungs transplant status */
"Z944" = "1" /* Liver transplant status */
"Z9481" = "1" /* Bone marrow transplant status */
"Z9482" = "1" /* Intestine transplant status */
"Z9483" = "1" /* Pancreas transplant status */
"Z9484" = "1" /* Stem cells transplant status */
"Z9489" = "1" /* Other transplanted organ and tissue status */
"Z992" = "1" /* Dependence on renal dialysis */
"D47Z2" = "1" /* Castleman disease */
Other = "0"
;

/* Diagnosis codeset INFECID last updated 170530 for ICD10 v70rev2 */
Value $INFECID
"A000" = "1" /* Cholera due to Vibrio cholerae 01, biovar cholerae */
"A001" = "1" /* Cholera due to Vibrio cholerae 01, biovar eltor */
"A009" = "1" /* Cholera, unspecified */
"A0100" = "1" /* Typhoid fever, unspecified */
"A0101" = "1" /* Typhoid meningitis */
"A0102" = "1" /* Typhoid fever with heart involvement */
"A0103" = "1" /* Typhoid pneumonia */
"A0104" = "1" /* Typhoid arthritis */
"A0105" = "1" /* Typhoid osteomyelitis */
"A0109" = "1" /* Typhoid fever with other complications */
"A011" = "1" /* Paratyphoid fever A */
"A012" = "1" /* Paratyphoid fever B */
"A013" = "1" /* Paratyphoid fever C */
"A014" = "1" /* Paratyphoid fever, unspecified */
"A020" = "1" /* Salmonella enteritis */
"A021" = "1" /* Salmonella sepsis */
"A0220" = "1" /* Localized salmonella infection, unspecified */
"A0221" = "1" /* Salmonella meningitis */
"A0222" = "1" /* Salmonella pneumonia */
"A0223" = "1" /* Salmonella arthritis */
"A0224" = "1" /* Salmonella osteomyelitis */
"A0225" = "1" /* Salmonella pyelonephritis */
"A0229" = "1" /* Salmonella with other localized infection */
"A028" = "1" /* Other specified salmonella infections */
"A029" = "1" /* Salmonella infection, unspecified */
"A030" = "1" /* Shigellosis due to Shigella dysenteriae */
"A031" = "1" /* Shigellosis due to Shigella flexneri */
"A032" = "1" /* Shigellosis due to Shigella boydii */
"A033" = "1" /* Shigellosis due to Shigella sonnei */
"A038" = "1" /* Other shigellosis */
"A039" = "1" /* Shigellosis, unspecified */
"A040" = "1" /* Enteropathogenic Escherichia coli infection */
"A041" = "1" /* Enterotoxigenic Escherichia coli infection */
"A042" = "1" /* Enteroinvasive Escherichia coli infection */
"A043" = "1" /* Enterohemorrhagic Escherichia coli infection */
"A044" = "1" /* Other intestinal Escherichia coli infections */
"A045" = "1" /* Campylobacter enteritis */
"A046" = "1" /* Enteritis due to Yersinia enterocolitica */
"A047" = "1" /* Enterocolitis due to Clostridium difficile */
"A048" = "1" /* Other specified bacterial intestinal infections */
"A049" = "1" /* Bacterial intestinal infection, unspecified */
"A050" = "1" /* Foodborne staphylococcal intoxication */
"A051" = "1" /* Botulism food poisoning */
"A052" = "1" /* Foodborne Clostridium perfringens [Clostridium welchii] intoxication */
"A053" = "1" /* Foodborne Vibrio parahaemolyticus intoxication */
"A054" = "1" /* Foodborne Bacillus cereus intoxication */
"A055" = "1" /* Foodborne Vibrio vulnificus intoxication */
"A058" = "1" /* Other specified bacterial foodborne intoxications */
"A059" = "1" /* Bacterial foodborne intoxication, unspecified */
"A1801" = "1" /* Tuberculosis of spine */
"A1803" = "1" /* Tuberculosis of other bones */
"A1814" = "1" /* Tuberculosis of prostate */
"A1884" = "1" /* Tuberculosis of heart */
"A200" = "1" /* Bubonic plague */
"A201" = "1" /* Cellulocutaneous plague */
"A202" = "1" /* Pneumonic plague */
"A203" = "1" /* Plague meningitis */
"A207" = "1" /* Septicemic plague */
"A208" = "1" /* Other forms of plague */
"A209" = "1" /* Plague, unspecified */
"A210" = "1" /* Ulceroglandular tularemia */
"A211" = "1" /* Oculoglandular tularemia */
"A212" = "1" /* Pulmonary tularemia */
"A213" = "1" /* Gastrointestinal tularemia */
"A217" = "1" /* Generalized tularemia */
"A218" = "1" /* Other forms of tularemia */
"A219" = "1" /* Tularemia, unspecified */
"A220" = "1" /* Cutaneous anthrax */
"A221" = "1" /* Pulmonary anthrax */
"A222" = "1" /* Gastrointestinal anthrax */
"A227" = "1" /* Anthrax sepsis */
"A228" = "1" /* Other forms of anthrax */
"A229" = "1" /* Anthrax, unspecified */
"A230" = "1" /* Brucellosis due to Brucella melitensis */
"A231" = "1" /* Brucellosis due to Brucella abortus */
"A232" = "1" /* Brucellosis due to Brucella suis */
"A233" = "1" /* Brucellosis due to Brucella canis */
"A238" = "1" /* Other brucellosis */
"A239" = "1" /* Brucellosis, unspecified */
"A240" = "1" /* Glanders */
"A241" = "1" /* Acute and fulminating melioidosis */
"A242" = "1" /* Subacute and chronic melioidosis */
"A243" = "1" /* Other melioidosis */
"A249" = "1" /* Melioidosis, unspecified */
"A250" = "1" /* Spirillosis */
"A251" = "1" /* Streptobacillosis */
"A259" = "1" /* Rat-bite fever, unspecified */
"A260" = "1" /* Cutaneous erysipeloid */
"A267" = "1" /* Erysipelothrix sepsis */
"A268" = "1" /* Other forms of erysipeloid */
"A269" = "1" /* Erysipeloid, unspecified */
"A280" = "1" /* Pasteurellosis */
"A281" = "1" /* Cat-scratch disease */
"A282" = "1" /* Extraintestinal yersiniosis */
"A288" = "1" /* Other specified zoonotic bacterial diseases, not elsewhere classified */
"A289" = "1" /* Zoonotic bacterial disease, unspecified */
"A320" = "1" /* Cutaneous listeriosis */
"A3211" = "1" /* Listerial meningitis */
"A3212" = "1" /* Listerial meningoencephalitis */
"A327" = "1" /* Listerial sepsis */
"A3281" = "1" /* Oculoglandular listeriosis */
"A3282" = "1" /* Listerial endocarditis */
"A3289" = "1" /* Other forms of listeriosis */
"A329" = "1" /* Listeriosis, unspecified */
"A33" = "1" /* Tetanus neonatorum */
"A34" = "1" /* Obstetrical tetanus */
"A35" = "1" /* Other tetanus */
"A360" = "1" /* Pharyngeal diphtheria */
"A361" = "1" /* Nasopharyngeal diphtheria */
"A362" = "1" /* Laryngeal diphtheria */
"A363" = "1" /* Cutaneous diphtheria */
"A3681" = "1" /* Diphtheritic cardiomyopathy */
"A3682" = "1" /* Diphtheritic radiculomyelitis */
"A3683" = "1" /* Diphtheritic polyneuritis */
"A3684" = "1" /* Diphtheritic tubulo-interstitial nephropathy */
"A3685" = "1" /* Diphtheritic cystitis */
"A3686" = "1" /* Diphtheritic conjunctivitis */
"A3689" = "1" /* Other diphtheritic complications */
"A369" = "1" /* Diphtheria, unspecified */
"A3700" = "1" /* Whooping cough due to Bordetella pertussis without pneumonia */
"A3701" = "1" /* Whooping cough due to Bordetella pertussis with pneumonia */
"A3710" = "1" /* Whooping cough due to Bordetella parapertussis without pneumonia */
"A3711" = "1" /* Whooping cough due to Bordetella parapertussis with pneumonia */
"A3780" = "1" /* Whooping cough due to other Bordetella species without pneumonia */
"A3781" = "1" /* Whooping cough due to other Bordetella species with pneumonia */
"A3790" = "1" /* Whooping cough, unspecified species without pneumonia */
"A3791" = "1" /* Whooping cough, unspecified species with pneumonia */
"A380" = "1" /* Scarlet fever with otitis media */
"A381" = "1" /* Scarlet fever with myocarditis */
"A388" = "1" /* Scarlet fever with other complications */
"A389" = "1" /* Scarlet fever, uncomplicated */
"A390" = "1" /* Meningococcal meningitis */
"A391" = "1" /* Waterhouse-Friderichsen syndrome */
"A392" = "1" /* Acute meningococcemia */
"A393" = "1" /* Chronic meningococcemia */
"A394" = "1" /* Meningococcemia, unspecified */
"A3950" = "1" /* Meningococcal carditis, unspecified */
"A3951" = "1" /* Meningococcal endocarditis */
"A3952" = "1" /* Meningococcal myocarditis */
"A3953" = "1" /* Meningococcal pericarditis */
"A3981" = "1" /* Meningococcal encephalitis */
"A3982" = "1" /* Meningococcal retrobulbar neuritis */
"A3983" = "1" /* Meningococcal arthritis */
"A3984" = "1" /* Postmeningococcal arthritis */
"A3989" = "1" /* Other meningococcal infections */
"A399" = "1" /* Meningococcal infection, unspecified */
"A400" = "1" /* Sepsis due to streptococcus, group A */
"A401" = "1" /* Sepsis due to streptococcus, group B */
"A403" = "1" /* Sepsis due to Streptococcus pneumoniae */
"A408" = "1" /* Other streptococcal sepsis */
"A409" = "1" /* Streptococcal sepsis, unspecified */
"A4101" = "1" /* Sepsis due to Methicillin susceptible Staphylococcus aureus */
"A4102" = "1" /* Sepsis due to Methicillin resistant Staphylococcus aureus */
"A411" = "1" /* Sepsis due to other specified staphylococcus */
"A412" = "1" /* Sepsis due to unspecified staphylococcus */
"A413" = "1" /* Sepsis due to Hemophilus influenzae */
"A414" = "1" /* Sepsis due to anaerobes */
"A4150" = "1" /* Gram-negative sepsis, unspecified */
"A4151" = "1" /* Sepsis due to Escherichia coli [E. coli] */
"A4152" = "1" /* Sepsis due to Pseudomonas */
"A4153" = "1" /* Sepsis due to Serratia */
"A4159" = "1" /* Other Gram-negative sepsis */
"A4181" = "1" /* Sepsis due to Enterococcus */
"A4189" = "1" /* Other specified sepsis */
"A419" = "1" /* Sepsis, unspecified organism */
"A420" = "1" /* Pulmonary actinomycosis */
"A421" = "1" /* Abdominal actinomycosis */
"A422" = "1" /* Cervicofacial actinomycosis */
"A427" = "1" /* Actinomycotic sepsis */
"A4281" = "1" /* Actinomycotic meningitis */
"A4282" = "1" /* Actinomycotic encephalitis */
"A4289" = "1" /* Other forms of actinomycosis */
"A429" = "1" /* Actinomycosis, unspecified */
"A430" = "1" /* Pulmonary nocardiosis */
"A431" = "1" /* Cutaneous nocardiosis */
"A438" = "1" /* Other forms of nocardiosis */
"A439" = "1" /* Nocardiosis, unspecified */
"A46" = "1" /* Erysipelas */
"A480" = "1" /* Gas gangrene */
"A481" = "1" /* Legionnaires' disease */
"A482" = "1" /* Nonpneumonic Legionnaires' disease [Pontiac fever] */
"A483" = "1" /* Toxic shock syndrome */
"A484" = "1" /* Brazilian purpuric fever */
"A4851" = "1" /* Infant botulism */
"A4852" = "1" /* Wound botulism */
"A488" = "1" /* Other specified bacterial diseases */
"A4901" = "1" /* Methicillin susceptible Staphylococcus aureus infection, unspecified site */
"A4902" = "1" /* Methicillin resistant Staphylococcus aureus infection, unspecified site */
"A491" = "1" /* Streptococcal infection, unspecified site */
"A492" = "1" /* Hemophilus influenzae infection, unspecified site */
"A498" = "1" /* Other bacterial infections of unspecified site */
"A499" = "1" /* Bacterial infection, unspecified */
"A5400" = "1" /* Gonococcal infection of lower genitourinary tract, unspecified */
"A5401" = "1" /* Gonococcal cystitis and urethritis, unspecified */
"A5402" = "1" /* Gonococcal vulvovaginitis, unspecified */
"A5403" = "1" /* Gonococcal cervicitis, unspecified */
"A5409" = "1" /* Other gonococcal infection of lower genitourinary tract */
"A541" = "1" /* Gonococcal infection of lower genitourinary tract with periurethral and accessory gland abscess */
"A5421" = "1" /* Gonococcal infection of kidney and ureter */
"A5422" = "1" /* Gonococcal prostatitis */
"A5423" = "1" /* Gonococcal infection of other male genital organs */
"A5424" = "1" /* Gonococcal female pelvic inflammatory disease */
"A5429" = "1" /* Other gonococcal genitourinary infections */
"A5430" = "1" /* Gonococcal infection of eye, unspecified */
"A5431" = "1" /* Gonococcal conjunctivitis */
"A5432" = "1" /* Gonococcal iridocyclitis */
"A5433" = "1" /* Gonococcal keratitis */
"A5439" = "1" /* Other gonococcal eye infection */
"A5440" = "1" /* Gonococcal infection of musculoskeletal system, unspecified */
"A5441" = "1" /* Gonococcal spondylopathy */
"A5442" = "1" /* Gonococcal arthritis */
"A5443" = "1" /* Gonococcal osteomyelitis */
"A5449" = "1" /* Gonococcal infection of other musculoskeletal tissue */
"A545" = "1" /* Gonococcal pharyngitis */
"A546" = "1" /* Gonococcal infection of anus and rectum */
"A5481" = "1" /* Gonococcal meningitis */
"A5482" = "1" /* Gonococcal brain abscess */
"A5483" = "1" /* Gonococcal heart infection */
"A5484" = "1" /* Gonococcal pneumonia */
"A5485" = "1" /* Gonococcal peritonitis */
"A5486" = "1" /* Gonococcal sepsis */
"A5489" = "1" /* Other gonococcal infections */
"A549" = "1" /* Gonococcal infection, unspecified */
"A5601" = "1" /* Chlamydial cystitis and urethritis */
"A5611" = "1" /* Chlamydial female pelvic inflammatory disease */
"B252" = "1" /* Cytomegaloviral pancreatitis */
"B377" = "1" /* Candidal sepsis */
"B471" = "1" /* Actinomycetoma */
"B479" = "1" /* Mycetoma, unspecified */
"B950" = "1" /* Streptococcus, group A, as the cause of diseases classified elsewhere */
"B951" = "1" /* Streptococcus, group B, as the cause of diseases classified elsewhere */
"B952" = "1" /* Enterococcus as the cause of diseases classified elsewhere */
"B953" = "1" /* Streptococcus pneumoniae as the cause of diseases classified elsewhere */
"B954" = "1" /* Other streptococcus as the cause of diseases classified elsewhere */
"B955" = "1" /* Unspecified streptococcus as the cause of diseases classified elsewhere */
"B9561" = "1" /* Methicillin susceptible Staphylococcus aureus infection as the cause of diseases classified elsewhere */
"B9562" = "1" /* Methicillin resistant Staphylococcus aureus infection as the cause of diseases classified elsewhere */
"B957" = "1" /* Other staphylococcus as the cause of diseases classified elsewhere */
"B958" = "1" /* Unspecified staphylococcus as the cause of diseases classified elsewhere */
"B961" = "1" /* Klebsiella pneumoniae [K. pneumoniae] as the cause of diseases classified elsewhere */
"B9620" = "1" /* Unspecified Escherichia coli [E. coli] as the cause of diseases classified elsewhere */
"B9621" = "1" /* Shiga toxin-producing Escherichia coli [E. coli] (STEC) O157 as the cause of diseases classified elsewhere */
"B9622" = "1" /* Other specified Shiga toxin-producing Escherichia coli [E. coli] (STEC) as the cause of diseases classified elsewhere */
"B9623" = "1" /* Unspecified Shiga toxin-producing Escherichia coli [E. coli] (STEC) as the cause of diseases classified elsewhere */
"B9629" = "1" /* Other Escherichia coli [E. coli] as the cause of diseases classified elsewhere */
"B963" = "1" /* Hemophilus influenzae [H. influenzae] as the cause of diseases classified elsewhere */
"B964" = "1" /* Proteus (mirabilis) (morganii) as the cause of diseases classified elsewhere */
"B965" = "1" /* Pseudomonas (aeruginosa) (mallei) (pseudomallei) as the cause of diseases classified elsewhere */
"B966" = "1" /* Bacteroides fragilis [B. fragilis] as the cause of diseases classified elsewhere */
"B967" = "1" /* Clostridium perfringens [C. perfringens] as the cause of diseases classified elsewhere */
"B9681" = "1" /* Helicobacter pylori [H. pylori] as the cause of diseases classified elsewhere */
"B9682" = "1" /* Vibrio vulnificus as the cause of diseases classified elsewhere */
"B9689" = "1" /* Other specified bacterial agents as the cause of diseases classified elsewhere */
"E0852" = "1" /* Diabetes mellitus due to underlying condition with diabetic peripheral angiopathy with gangrene */
"E0952" = "1" /* Drug or chemical induced diabetes mellitus with diabetic peripheral angiopathy with gangrene */
"E1052" = "1" /* Type 1 diabetes mellitus with diabetic peripheral angiopathy with gangrene */
"E1152" = "1" /* Type 2 diabetes mellitus with diabetic peripheral angiopathy with gangrene */
"E1352" = "1" /* Other specified diabetes mellitus with diabetic peripheral angiopathy with gangrene */
"G000" = "1" /* Hemophilus meningitis */
"G001" = "1" /* Pneumococcal meningitis */
"G002" = "1" /* Streptococcal meningitis */
"G003" = "1" /* Staphylococcal meningitis */
"G008" = "1" /* Other bacterial meningitis */
"G009" = "1" /* Bacterial meningitis, unspecified */
"G01" = "1" /* Meningitis in bacterial diseases classified elsewhere */
"G039" = "1" /* Meningitis, unspecified */
"G042" = "1" /* Bacterial meningoencephalitis and meningomyelitis, not elsewhere classified */
"G060" = "1" /* Intracranial abscess and granuloma */
"G061" = "1" /* Intraspinal abscess and granuloma */
"G062" = "1" /* Extradural and subdural abscess, unspecified */
"G07" = "1" /* Intracranial and intraspinal abscess and granuloma in diseases classified elsewhere */
"H00011" = "1" /* Hordeolum externum right upper eyelid */
"H00012" = "1" /* Hordeolum externum right lower eyelid */
"H00013" = "1" /* Hordeolum externum right eye, unspecified eyelid */
"H00014" = "1" /* Hordeolum externum left upper eyelid */
"H00015" = "1" /* Hordeolum externum left lower eyelid */
"H00016" = "1" /* Hordeolum externum left eye, unspecified eyelid */
"H00019" = "1" /* Hordeolum externum unspecified eye, unspecified eyelid */
"H00021" = "1" /* Hordeolum internum right upper eyelid */
"H00022" = "1" /* Hordeolum internum right lower eyelid */
"H00023" = "1" /* Hordeolum internum right eye, unspecified eyelid */
"H00024" = "1" /* Hordeolum internum left upper eyelid */
"H00025" = "1" /* Hordeolum internum left lower eyelid */
"H00026" = "1" /* Hordeolum internum left eye, unspecified eyelid */
"H00029" = "1" /* Hordeolum internum unspecified eye, unspecified eyelid */
"H00031" = "1" /* Abscess of right upper eyelid */
"H00032" = "1" /* Abscess of right lower eyelid */
"H00033" = "1" /* Abscess of eyelid right eye, unspecified eyelid */
"H00034" = "1" /* Abscess of left upper eyelid */
"H00035" = "1" /* Abscess of left lower eyelid */
"H00036" = "1" /* Abscess of eyelid left eye, unspecified eyelid */
"H00039" = "1" /* Abscess of eyelid unspecified eye, unspecified eyelid */
"H01001" = "1" /* Unspecified blepharitis right upper eyelid */
"H01002" = "1" /* Unspecified blepharitis right lower eyelid */
"H01003" = "1" /* Unspecified blepharitis right eye, unspecified eyelid */
"H01004" = "1" /* Unspecified blepharitis left upper eyelid */
"H01005" = "1" /* Unspecified blepharitis left lower eyelid */
"H01006" = "1" /* Unspecified blepharitis left eye, unspecified eyelid */
"H01009" = "1" /* Unspecified blepharitis unspecified eye, unspecified eyelid */
"H01011" = "1" /* Ulcerative blepharitis right upper eyelid */
"H01012" = "1" /* Ulcerative blepharitis right lower eyelid */
"H01013" = "1" /* Ulcerative blepharitis right eye, unspecified eyelid */
"H01014" = "1" /* Ulcerative blepharitis left upper eyelid */
"H01015" = "1" /* Ulcerative blepharitis left lower eyelid */
"H01016" = "1" /* Ulcerative blepharitis left eye, unspecified eyelid */
"H01019" = "1" /* Ulcerative blepharitis unspecified eye, unspecified eyelid */
"H04001" = "1" /* Unspecified dacryoadenitis, right lacrimal gland */
"H04002" = "1" /* Unspecified dacryoadenitis, left lacrimal gland */
"H04003" = "1" /* Unspecified dacryoadenitis, bilateral lacrimal glands */
"H04009" = "1" /* Unspecified dacryoadenitis, unspecified lacrimal gland */
"H04011" = "1" /* Acute dacryoadenitis, right lacrimal gland */
"H04012" = "1" /* Acute dacryoadenitis, left lacrimal gland */
"H04013" = "1" /* Acute dacryoadenitis, bilateral lacrimal glands */
"H04019" = "1" /* Acute dacryoadenitis, unspecified lacrimal gland */
"H04301" = "1" /* Unspecified dacryocystitis of right lacrimal passage */
"H04302" = "1" /* Unspecified dacryocystitis of left lacrimal passage */
"H04303" = "1" /* Unspecified dacryocystitis of bilateral lacrimal passages */
"H04309" = "1" /* Unspecified dacryocystitis of unspecified lacrimal passage */
"H04321" = "1" /* Acute dacryocystitis of right lacrimal passage */
"H04322" = "1" /* Acute dacryocystitis of left lacrimal passage */
"H04323" = "1" /* Acute dacryocystitis of bilateral lacrimal passages */
"H04329" = "1" /* Acute dacryocystitis of unspecified lacrimal passage */
"H04331" = "1" /* Acute lacrimal canaliculitis of right lacrimal passage */
"H04332" = "1" /* Acute lacrimal canaliculitis of left lacrimal passage */
"H04333" = "1" /* Acute lacrimal canaliculitis of bilateral lacrimal passages */
"H04339" = "1" /* Acute lacrimal canaliculitis of unspecified lacrimal passage */
"H05011" = "1" /* Cellulitis of right orbit */
"H05012" = "1" /* Cellulitis of left orbit */
"H05013" = "1" /* Cellulitis of bilateral orbits */
"H05019" = "1" /* Cellulitis of unspecified orbit */
"H05021" = "1" /* Osteomyelitis of right orbit */
"H05022" = "1" /* Osteomyelitis of left orbit */
"H05023" = "1" /* Osteomyelitis of bilateral orbits */
"H05029" = "1" /* Osteomyelitis of unspecified orbit */
"H05031" = "1" /* Periostitis of right orbit */
"H05032" = "1" /* Periostitis of left orbit */
"H05033" = "1" /* Periostitis of bilateral orbits */
"H05039" = "1" /* Periostitis of unspecified orbit */
"H05041" = "1" /* Tenonitis of right orbit */
"H05042" = "1" /* Tenonitis of left orbit */
"H05043" = "1" /* Tenonitis of bilateral orbits */
"H05049" = "1" /* Tenonitis of unspecified orbit */
"H10021" = "1" /* Other mucopurulent conjunctivitis, right eye */
"H10022" = "1" /* Other mucopurulent conjunctivitis, left eye */
"H10023" = "1" /* Other mucopurulent conjunctivitis, bilateral */
"H10029" = "1" /* Other mucopurulent conjunctivitis, unspecified eye */
"H10221" = "1" /* Pseudomembranous conjunctivitis, right eye */
"H10222" = "1" /* Pseudomembranous conjunctivitis, left eye */
"H10223" = "1" /* Pseudomembranous conjunctivitis, bilateral */
"H10229" = "1" /* Pseudomembranous conjunctivitis, unspecified eye */
"H1030" = "1" /* Unspecified acute conjunctivitis, unspecified eye */
"H1031" = "1" /* Unspecified acute conjunctivitis, right eye */
"H1032" = "1" /* Unspecified acute conjunctivitis, left eye */
"H1033" = "1" /* Unspecified acute conjunctivitis, bilateral */
"H10501" = "1" /* Unspecified blepharoconjunctivitis, right eye */
"H10502" = "1" /* Unspecified blepharoconjunctivitis, left eye */
"H10503" = "1" /* Unspecified blepharoconjunctivitis, bilateral */
"H10509" = "1" /* Unspecified blepharoconjunctivitis, unspecified eye */
"H10521" = "1" /* Angular blepharoconjunctivitis, right eye */
"H10522" = "1" /* Angular blepharoconjunctivitis, left eye */
"H10523" = "1" /* Angular blepharoconjunctivitis, bilateral */
"H10529" = "1" /* Angular blepharoconjunctivitis, unspecified eye */
"H109" = "1" /* Unspecified conjunctivitis */
"H16311" = "1" /* Corneal abscess, right eye */
"H16312" = "1" /* Corneal abscess, left eye */
"H16313" = "1" /* Corneal abscess, bilateral */
"H16319" = "1" /* Corneal abscess, unspecified eye */
"H44001" = "1" /* Unspecified purulent endophthalmitis, right eye */
"H44002" = "1" /* Unspecified purulent endophthalmitis, left eye */
"H44003" = "1" /* Unspecified purulent endophthalmitis, bilateral */
"H44009" = "1" /* Unspecified purulent endophthalmitis, unspecified eye */
"H44011" = "1" /* Panophthalmitis (acute), right eye */
"H44012" = "1" /* Panophthalmitis (acute), left eye */
"H44013" = "1" /* Panophthalmitis (acute), bilateral */
"H44019" = "1" /* Panophthalmitis (acute), unspecified eye */
"H44021" = "1" /* Vitreous abscess (chronic), right eye */
"H44022" = "1" /* Vitreous abscess (chronic), left eye */
"H44023" = "1" /* Vitreous abscess (chronic), bilateral */
"H44029" = "1" /* Vitreous abscess (chronic), unspecified eye */
"H6000" = "1" /* Abscess of external ear, unspecified ear */
"H6001" = "1" /* Abscess of right external ear */
"H6002" = "1" /* Abscess of left external ear */
"H6003" = "1" /* Abscess of external ear, bilateral */
"H6010" = "1" /* Cellulitis of external ear, unspecified ear */
"H6011" = "1" /* Cellulitis of right external ear */
"H6012" = "1" /* Cellulitis of left external ear */
"H6013" = "1" /* Cellulitis of external ear, bilateral */
"H6020" = "1" /* Malignant otitis externa, unspecified ear */
"H6021" = "1" /* Malignant otitis externa, right ear */
"H6022" = "1" /* Malignant otitis externa, left ear */
"H6023" = "1" /* Malignant otitis externa, bilateral */
"H60311" = "1" /* Diffuse otitis externa, right ear */
"H60312" = "1" /* Diffuse otitis externa, left ear */
"H60313" = "1" /* Diffuse otitis externa, bilateral */
"H60319" = "1" /* Diffuse otitis externa, unspecified ear */
"H60321" = "1" /* Hemorrhagic otitis externa, right ear */
"H60322" = "1" /* Hemorrhagic otitis externa, left ear */
"H60323" = "1" /* Hemorrhagic otitis externa, bilateral */
"H60329" = "1" /* Hemorrhagic otitis externa, unspecified ear */
"H60331" = "1" /* Swimmer's ear, right ear */
"H60332" = "1" /* Swimmer's ear, left ear */
"H60333" = "1" /* Swimmer's ear, bilateral */
"H60339" = "1" /* Swimmer's ear, unspecified ear */
"H60391" = "1" /* Other infective otitis externa, right ear */
"H60392" = "1" /* Other infective otitis externa, left ear */
"H60393" = "1" /* Other infective otitis externa, bilateral */
"H60399" = "1" /* Other infective otitis externa, unspecified ear */
"H6240" = "1" /* Otitis externa in other diseases classified elsewhere, unspecified ear */
"H6241" = "1" /* Otitis externa in other diseases classified elsewhere, right ear */
"H6242" = "1" /* Otitis externa in other diseases classified elsewhere, left ear */
"H6243" = "1" /* Otitis externa in other diseases classified elsewhere, bilateral */
"H66001" = "1" /* Acute suppurative otitis media without spontaneous rupture of ear drum, right ear */
"H66002" = "1" /* Acute suppurative otitis media without spontaneous rupture of ear drum, left ear */
"H66003" = "1" /* Acute suppurative otitis media without spontaneous rupture of ear drum, bilateral */
"H66004" = "1" /* Acute suppurative otitis media without spontaneous rupture of ear drum, recurrent, right ear */
"H66005" = "1" /* Acute suppurative otitis media without spontaneous rupture of ear drum, recurrent, left ear */
"H66006" = "1" /* Acute suppurative otitis media without spontaneous rupture of ear drum, recurrent, bilateral */
"H66007" = "1" /* Acute suppurative otitis media without spontaneous rupture of ear drum, recurrent, unspecified ear */
"H66009" = "1" /* Acute suppurative otitis media without spontaneous rupture of ear drum, unspecified ear */
"H66011" = "1" /* Acute suppurative otitis media with spontaneous rupture of ear drum, right ear */
"H66012" = "1" /* Acute suppurative otitis media with spontaneous rupture of ear drum, left ear */
"H66013" = "1" /* Acute suppurative otitis media with spontaneous rupture of ear drum, bilateral */
"H66014" = "1" /* Acute suppurative otitis media with spontaneous rupture of ear drum, recurrent, right ear */
"H66015" = "1" /* Acute suppurative otitis media with spontaneous rupture of ear drum, recurrent, left ear */
"H66016" = "1" /* Acute suppurative otitis media with spontaneous rupture of ear drum, recurrent, bilateral */
"H66017" = "1" /* Acute suppurative otitis media with spontaneous rupture of ear drum, recurrent, unspecified ear */
"H66019" = "1" /* Acute suppurative otitis media with spontaneous rupture of ear drum, unspecified ear */
"H6610" = "1" /* Chronic tubotympanic suppurative otitis media, unspecified */
"H6611" = "1" /* Chronic tubotympanic suppurative otitis media, right ear */
"H6612" = "1" /* Chronic tubotympanic suppurative otitis media, left ear */
"H6613" = "1" /* Chronic tubotympanic suppurative otitis media, bilateral */
"H6620" = "1" /* Chronic atticoantral suppurative otitis media, unspecified ear */
"H6621" = "1" /* Chronic atticoantral suppurative otitis media, right ear */
"H6622" = "1" /* Chronic atticoantral suppurative otitis media, left ear */
"H6623" = "1" /* Chronic atticoantral suppurative otitis media, bilateral */
"H663X1" = "1" /* Other chronic suppurative otitis media, right ear */
"H663X2" = "1" /* Other chronic suppurative otitis media, left ear */
"H663X3" = "1" /* Other chronic suppurative otitis media, bilateral */
"H663X9" = "1" /* Other chronic suppurative otitis media, unspecified ear */
"H6640" = "1" /* Suppurative otitis media, unspecified, unspecified ear */
"H6641" = "1" /* Suppurative otitis media, unspecified, right ear */
"H6642" = "1" /* Suppurative otitis media, unspecified, left ear */
"H6643" = "1" /* Suppurative otitis media, unspecified, bilateral */
"H6690" = "1" /* Otitis media, unspecified, unspecified ear */
"H6691" = "1" /* Otitis media, unspecified, right ear */
"H6692" = "1" /* Otitis media, unspecified, left ear */
"H6693" = "1" /* Otitis media, unspecified, bilateral */
"H671" = "1" /* Otitis media in diseases classified elsewhere, right ear */
"H672" = "1" /* Otitis media in diseases classified elsewhere, left ear */
"H673" = "1" /* Otitis media in diseases classified elsewhere, bilateral */
"H679" = "1" /* Otitis media in diseases classified elsewhere, unspecified ear */
"H68001" = "1" /* Unspecified Eustachian salpingitis, right ear */
"H68002" = "1" /* Unspecified Eustachian salpingitis, left ear */
"H68003" = "1" /* Unspecified Eustachian salpingitis, bilateral */
"H68009" = "1" /* Unspecified Eustachian salpingitis, unspecified ear */
"H68011" = "1" /* Acute Eustachian salpingitis, right ear */
"H68012" = "1" /* Acute Eustachian salpingitis, left ear */
"H68013" = "1" /* Acute Eustachian salpingitis, bilateral */
"H68019" = "1" /* Acute Eustachian salpingitis, unspecified ear */
"H70001" = "1" /* Acute mastoiditis without complications, right ear */
"H70002" = "1" /* Acute mastoiditis without complications, left ear */
"H70003" = "1" /* Acute mastoiditis without complications, bilateral */
"H70009" = "1" /* Acute mastoiditis without complications, unspecified ear */
"H70011" = "1" /* Subperiosteal abscess of mastoid, right ear */
"H70012" = "1" /* Subperiosteal abscess of mastoid, left ear */
"H70013" = "1" /* Subperiosteal abscess of mastoid, bilateral */
"H70019" = "1" /* Subperiosteal abscess of mastoid, unspecified ear */
"H70091" = "1" /* Acute mastoiditis with other complications, right ear */
"H70092" = "1" /* Acute mastoiditis with other complications, left ear */
"H70093" = "1" /* Acute mastoiditis with other complications, bilateral */
"H70099" = "1" /* Acute mastoiditis with other complications, unspecified ear */
"H70201" = "1" /* Unspecified petrositis, right ear */
"H70202" = "1" /* Unspecified petrositis, left ear */
"H70203" = "1" /* Unspecified petrositis, bilateral */
"H70209" = "1" /* Unspecified petrositis, unspecified ear */
"H70211" = "1" /* Acute petrositis, right ear */
"H70212" = "1" /* Acute petrositis, left ear */
"H70213" = "1" /* Acute petrositis, bilateral */
"H70219" = "1" /* Acute petrositis, unspecified ear */
"H73001" = "1" /* Acute myringitis, right ear */
"H73002" = "1" /* Acute myringitis, left ear */
"H73003" = "1" /* Acute myringitis, bilateral */
"H73009" = "1" /* Acute myringitis, unspecified ear */
"I301" = "1" /* Infective pericarditis */
"I308" = "1" /* Other forms of acute pericarditis */
"I309" = "1" /* Acute pericarditis, unspecified */
"I32" = "1" /* Pericarditis in diseases classified elsewhere */
"I330" = "1" /* Acute and subacute infective endocarditis */
"I339" = "1" /* Acute and subacute endocarditis, unspecified */
"I39" = "1" /* Endocarditis and heart valve disorders in diseases classified elsewhere */
"I400" = "1" /* Infective myocarditis */
"I70361" = "1" /* Atherosclerosis of unspecified type of bypass graft(s) of the extremities with gangrene, right leg */
"I70362" = "1" /* Atherosclerosis of unspecified type of bypass graft(s) of the extremities with gangrene, left leg */
"I70363" = "1" /* Atherosclerosis of unspecified type of bypass graft(s) of the extremities with gangrene, bilateral legs */
"I70368" = "1" /* Atherosclerosis of unspecified type of bypass graft(s) of the extremities with gangrene, other extremity */
"I70369" = "1" /* Atherosclerosis of unspecified type of bypass graft(s) of the extremities with gangrene, unspecified extremity */
"I70461" = "1" /* Atherosclerosis of autologous vein bypass graft(s) of the extremities with gangrene, right leg */
"I70462" = "1" /* Atherosclerosis of autologous vein bypass graft(s) of the extremities with gangrene, left leg */
"I70463" = "1" /* Atherosclerosis of autologous vein bypass graft(s) of the extremities with gangrene, bilateral legs */
"I70468" = "1" /* Atherosclerosis of autologous vein bypass graft(s) of the extremities with gangrene, other extremity */
"I70469" = "1" /* Atherosclerosis of autologous vein bypass graft(s) of the extremities with gangrene, unspecified extremity */
"I70561" = "1" /* Atherosclerosis of nonautologous biological bypass graft(s) of the extremities with gangrene, right leg */
"I70562" = "1" /* Atherosclerosis of nonautologous biological bypass graft(s) of the extremities with gangrene, left leg */
"I70563" = "1" /* Atherosclerosis of nonautologous biological bypass graft(s) of the extremities with gangrene, bilateral legs */
"I70568" = "1" /* Atherosclerosis of nonautologous biological bypass graft(s) of the extremities with gangrene, other extremity */
"I70569" = "1" /* Atherosclerosis of nonautologous biological bypass graft(s) of the extremities with gangrene, unspecified extremity */
"I70661" = "1" /* Atherosclerosis of nonbiological bypass graft(s) of the extremities with gangrene, right leg */
"I70662" = "1" /* Atherosclerosis of nonbiological bypass graft(s) of the extremities with gangrene, left leg */
"I70663" = "1" /* Atherosclerosis of nonbiological bypass graft(s) of the extremities with gangrene, bilateral legs */
"I70668" = "1" /* Atherosclerosis of nonbiological bypass graft(s) of the extremities with gangrene, other extremity */
"I70669" = "1" /* Atherosclerosis of nonbiological bypass graft(s) of the extremities with gangrene, unspecified extremity */
"I70761" = "1" /* Atherosclerosis of other type of bypass graft(s) of the extremities with gangrene, right leg */
"I70762" = "1" /* Atherosclerosis of other type of bypass graft(s) of the extremities with gangrene, left leg */
"I70763" = "1" /* Atherosclerosis of other type of bypass graft(s) of the extremities with gangrene, bilateral legs */
"I70768" = "1" /* Atherosclerosis of other type of bypass graft(s) of the extremities with gangrene, other extremity */
"I70769" = "1" /* Atherosclerosis of other type of bypass graft(s) of the extremities with gangrene, unspecified extremity */
"I7301" = "1" /* Raynaud's syndrome with gangrene */
"I96" = "1" /* Gangrene, not elsewhere classified */
"J0100" = "1" /* Acute maxillary sinusitis, unspecified */
"J0101" = "1" /* Acute recurrent maxillary sinusitis */
"J0110" = "1" /* Acute frontal sinusitis, unspecified */
"J0111" = "1" /* Acute recurrent frontal sinusitis */
"J0120" = "1" /* Acute ethmoidal sinusitis, unspecified */
"J0121" = "1" /* Acute recurrent ethmoidal sinusitis */
"J0130" = "1" /* Acute sphenoidal sinusitis, unspecified */
"J0131" = "1" /* Acute recurrent sphenoidal sinusitis */
"J0140" = "1" /* Acute pansinusitis, unspecified */
"J0141" = "1" /* Acute recurrent pansinusitis */
"J0180" = "1" /* Other acute sinusitis */
"J0181" = "1" /* Other acute recurrent sinusitis */
"J0190" = "1" /* Acute sinusitis, unspecified */
"J0191" = "1" /* Acute recurrent sinusitis, unspecified */
"J020" = "1" /* Streptococcal pharyngitis */
"J028" = "1" /* Acute pharyngitis due to other specified organisms */
"J029" = "1" /* Acute pharyngitis, unspecified */
"J0300" = "1" /* Acute streptococcal tonsillitis, unspecified */
"J0301" = "1" /* Acute recurrent streptococcal tonsillitis */
"J0380" = "1" /* Acute tonsillitis due to other specified organisms */
"J0381" = "1" /* Acute recurrent tonsillitis due to other specified organisms */
"J0390" = "1" /* Acute tonsillitis, unspecified */
"J0391" = "1" /* Acute recurrent tonsillitis, unspecified */
"J0510" = "1" /* Acute epiglottitis without obstruction */
"J0511" = "1" /* Acute epiglottitis with obstruction */
"J13" = "1" /* Pneumonia due to Streptococcus pneumoniae */
"J14" = "1" /* Pneumonia due to Hemophilus influenzae */
"J150" = "1" /* Pneumonia due to Klebsiella pneumoniae */
"J151" = "1" /* Pneumonia due to Pseudomonas */
"J1520" = "1" /* Pneumonia due to staphylococcus, unspecified */
"J15211" = "1" /* Pneumonia due to Methicillin susceptible Staphylococcus aureus */
"J15212" = "1" /* Pneumonia due to Methicillin resistant Staphylococcus aureus */
"J1529" = "1" /* Pneumonia due to other staphylococcus */
"J153" = "1" /* Pneumonia due to streptococcus, group B */
"J154" = "1" /* Pneumonia due to other streptococci */
"J155" = "1" /* Pneumonia due to Escherichia coli */
"J156" = "1" /* Pneumonia due to other aerobic Gram-negative bacteria */
"J158" = "1" /* Pneumonia due to other specified bacteria */
"J159" = "1" /* Unspecified bacterial pneumonia */
"J17" = "1" /* Pneumonia in diseases classified elsewhere */
"J180" = "1" /* Bronchopneumonia, unspecified organism */
"J181" = "1" /* Lobar pneumonia, unspecified organism */
"J188" = "1" /* Other pneumonia, unspecified organism */
"J189" = "1" /* Pneumonia, unspecified organism */
"J200" = "1" /* Acute bronchitis due to Mycoplasma pneumoniae */
"J201" = "1" /* Acute bronchitis due to Hemophilus influenzae */
"J202" = "1" /* Acute bronchitis due to streptococcus */
"J203" = "1" /* Acute bronchitis due to coxsackievirus */
"J204" = "1" /* Acute bronchitis due to parainfluenza virus */
"J205" = "1" /* Acute bronchitis due to respiratory syncytial virus */
"J206" = "1" /* Acute bronchitis due to rhinovirus */
"J207" = "1" /* Acute bronchitis due to echovirus */
"J208" = "1" /* Acute bronchitis due to other specified organisms */
"J209" = "1" /* Acute bronchitis, unspecified */
"J36" = "1" /* Peritonsillar abscess */
"J390" = "1" /* Retropharyngeal and parapharyngeal abscess */
"J40" = "1" /* Bronchitis, not specified as acute or chronic */
"J440" = "1" /* Chronic obstructive pulmonary disease with acute lower respiratory infection */
"J470" = "1" /* Bronchiectasis with acute lower respiratory infection */
"J471" = "1" /* Bronchiectasis with (acute) exacerbation */
"J850" = "1" /* Gangrene and necrosis of lung */
"J851" = "1" /* Abscess of lung with pneumonia */
"J852" = "1" /* Abscess of lung without pneumonia */
"J853" = "1" /* Abscess of mediastinum */
"J860" = "1" /* Pyothorax with fistula */
"J869" = "1" /* Pyothorax without fistula */
"J9502" = "1" /* Infection of tracheostomy stoma */
"K040" = "1" /* Pulpitis */
"K0401" = "1" /* Reversible pulpitis */
"K0402" = "1" /* Irreversible pulpitis */
"K046" = "1" /* Periapical abscess with sinus */
"K047" = "1" /* Periapical abscess without sinus */
"K0500" = "1" /* Acute gingivitis, plaque induced */
"K0501" = "1" /* Acute gingivitis, non-plaque induced */
"K0520" = "1" /* Aggressive periodontitis, unspecified */
"K0521" = "1" /* Aggressive periodontitis, localized */
"K05211" = "1" /* Aggressive periodontitis, localized, slight */
"K05212" = "1" /* Aggressive periodontitis, localized, moderate */
"K05213" = "1" /* Aggressive periodontitis, localized, severe */
"K05219" = "1" /* Aggressive periodontitis, localized, unspecified severity */
"K0522" = "1" /* Aggressive periodontitis, generalized */
"K05221" = "1" /* Aggressive periodontitis, generalized, slight */
"K05222" = "1" /* Aggressive periodontitis, generalized, moderate */
"K05223" = "1" /* Aggressive periodontitis, generalized, severe */
"K05229" = "1" /* Aggressive periodontitis, generalized, unspecified severity */
"K113" = "1" /* Abscess of salivary gland */
"K122" = "1" /* Cellulitis and abscess of mouth */
"K352" = "1" /* Acute appendicitis with generalized peritonitis */
"K353" = "1" /* Acute appendicitis with localized peritonitis */
"K3580" = "1" /* Unspecified acute appendicitis */
"K3589" = "1" /* Other acute appendicitis */
"K36" = "1" /* Other appendicitis */
"K37" = "1" /* Unspecified appendicitis */
"K50014" = "1" /* Crohn's disease of small intestine with abscess */
"K50114" = "1" /* Crohn's disease of large intestine with abscess */
"K50814" = "1" /* Crohn's disease of both small and large intestine with abscess */
"K50914" = "1" /* Crohn's disease, unspecified, with abscess */
"K51014" = "1" /* Ulcerative (chronic) pancolitis with abscess */
"K51214" = "1" /* Ulcerative (chronic) proctitis with abscess */
"K51314" = "1" /* Ulcerative (chronic) rectosigmoiditis with abscess */
"K51414" = "1" /* Inflammatory polyps of colon with abscess */
"K51514" = "1" /* Left sided colitis with abscess */
"K51814" = "1" /* Other ulcerative colitis with abscess */
"K51914" = "1" /* Ulcerative colitis, unspecified with abscess */
"K5700" = "1" /* Diverticulitis of small intestine with perforation and abscess without bleeding */
"K5701" = "1" /* Diverticulitis of small intestine with perforation and abscess with bleeding */
"K5712" = "1" /* Diverticulitis of small intestine without perforation or abscess without bleeding */
"K5713" = "1" /* Diverticulitis of small intestine without perforation or abscess with bleeding */
"K5720" = "1" /* Diverticulitis of large intestine with perforation and abscess without bleeding */
"K5721" = "1" /* Diverticulitis of large intestine with perforation and abscess with bleeding */
"K5732" = "1" /* Diverticulitis of large intestine without perforation or abscess without bleeding */
"K5733" = "1" /* Diverticulitis of large intestine without perforation or abscess with bleeding */
"K5740" = "1" /* Diverticulitis of both small and large intestine with perforation and abscess without bleeding */
"K5741" = "1" /* Diverticulitis of both small and large intestine with perforation and abscess with bleeding */
"K5752" = "1" /* Diverticulitis of both small and large intestine without perforation or abscess without bleeding */
"K5753" = "1" /* Diverticulitis of both small and large intestine without perforation or abscess with bleeding */
"K5780" = "1" /* Diverticulitis of intestine, part unspecified, with perforation and abscess without bleeding */
"K5781" = "1" /* Diverticulitis of intestine, part unspecified, with perforation and abscess with bleeding */
"K5792" = "1" /* Diverticulitis of intestine, part unspecified, without perforation or abscess without bleeding */
"K5793" = "1" /* Diverticulitis of intestine, part unspecified, without perforation or abscess with bleeding */
"K610" = "1" /* Anal abscess */
"K611" = "1" /* Rectal abscess */
"K612" = "1" /* Anorectal abscess */
"K613" = "1" /* Ischiorectal abscess */
"K614" = "1" /* Intrasphincteric abscess */
"K630" = "1" /* Abscess of intestine */
"K650" = "1" /* Generalized (acute) peritonitis */
"K651" = "1" /* Peritoneal abscess */
"K652" = "1" /* Spontaneous bacterial peritonitis */
"K653" = "1" /* Choleperitonitis */
"K654" = "1" /* Sclerosing mesenteritis */
"K658" = "1" /* Other peritonitis */
"K659" = "1" /* Peritonitis, unspecified */
"K67" = "1" /* Disorders of peritoneum in infectious diseases classified elsewhere */
"K6811" = "1" /* Postprocedural retroperitoneal abscess */
"K6812" = "1" /* Psoas muscle abscess */
"K6819" = "1" /* Other retroperitoneal abscess */
"K750" = "1" /* Abscess of liver */
"K751" = "1" /* Phlebitis of portal vein */
"K8000" = "1" /* Calculus of gallbladder with acute cholecystitis without obstruction */
"K8001" = "1" /* Calculus of gallbladder with acute cholecystitis with obstruction */
"K8012" = "1" /* Calculus of gallbladder with acute and chronic cholecystitis without obstruction */
"K8013" = "1" /* Calculus of gallbladder with acute and chronic cholecystitis with obstruction */
"K8030" = "1" /* Calculus of bile duct with cholangitis, unspecified, without obstruction */
"K8031" = "1" /* Calculus of bile duct with cholangitis, unspecified, with obstruction */
"K8032" = "1" /* Calculus of bile duct with acute cholangitis without obstruction */
"K8033" = "1" /* Calculus of bile duct with acute cholangitis with obstruction */
"K8034" = "1" /* Calculus of bile duct with chronic cholangitis without obstruction */
"K8035" = "1" /* Calculus of bile duct with chronic cholangitis with obstruction */
"K8036" = "1" /* Calculus of bile duct with acute and chronic cholangitis without obstruction */
"K8037" = "1" /* Calculus of bile duct with acute and chronic cholangitis with obstruction */
"K8042" = "1" /* Calculus of bile duct with acute cholecystitis without obstruction */
"K8043" = "1" /* Calculus of bile duct with acute cholecystitis with obstruction */
"K8046" = "1" /* Calculus of bile duct with acute and chronic cholecystitis without obstruction */
"K8047" = "1" /* Calculus of bile duct with acute and chronic cholecystitis with obstruction */
"K8062" = "1" /* Calculus of gallbladder and bile duct with acute cholecystitis without obstruction */
"K8063" = "1" /* Calculus of gallbladder and bile duct with acute cholecystitis with obstruction */
"K8066" = "1" /* Calculus of gallbladder and bile duct with acute and chronic cholecystitis without obstruction */
"K8067" = "1" /* Calculus of gallbladder and bile duct with acute and chronic cholecystitis with obstruction */
"K810" = "1" /* Acute cholecystitis */
"K812" = "1" /* Acute cholecystitis with chronic cholecystitis */
"K819" = "1" /* Cholecystitis, unspecified */
"K822" = "1" /* Perforation of gallbladder */
"K830" = "1" /* Cholangitis */
"K832" = "1" /* Perforation of bile duct */
"K850" = "1" /* Idiopathic acute pancreatitis */
"K8502" = "1" /* Idiopathic acute pancreatitis with infected necrosis */
"K851" = "1" /* Biliary acute pancreatitis */
"K8512" = "1" /* Biliary acute pancreatitis with infected necrosis */
"K858" = "1" /* Other acute pancreatitis */
"K8582" = "1" /* Other acute pancreatitis with infected necrosis */
"K859" = "1" /* Acute pancreatitis, unspecified */
"K8592" = "1" /* Acute pancreatitis with infected necrosis, unspecified */
"K9081" = "1" /* Whipple's disease */
"K9402" = "1" /* Colostomy infection */
"K9412" = "1" /* Enterostomy infection */
"K9422" = "1" /* Gastrostomy infection */
"K9501" = "1" /* Infection due to gastric band procedure */
"K9581" = "1" /* Infection due to other bariatric procedure */
"L00" = "1" /* Staphylococcal scalded skin syndrome */
"L0100" = "1" /* Impetigo, unspecified */
"L0101" = "1" /* Non-bullous impetigo */
"L0102" = "1" /* Bockhart's impetigo */
"L0103" = "1" /* Bullous impetigo */
"L0109" = "1" /* Other impetigo */
"L011" = "1" /* Impetiginization of other dermatoses */
"L0201" = "1" /* Cutaneous abscess of face */
"L0202" = "1" /* Furuncle of face */
"L0203" = "1" /* Carbuncle of face */
"L0211" = "1" /* Cutaneous abscess of neck */
"L0212" = "1" /* Furuncle of neck */
"L0213" = "1" /* Carbuncle of neck */
"L02211" = "1" /* Cutaneous abscess of abdominal wall */
"L02212" = "1" /* Cutaneous abscess of back [any part, except buttock] */
"L02213" = "1" /* Cutaneous abscess of chest wall */
"L02214" = "1" /* Cutaneous abscess of groin */
"L02215" = "1" /* Cutaneous abscess of perineum */
"L02216" = "1" /* Cutaneous abscess of umbilicus */
"L02219" = "1" /* Cutaneous abscess of trunk, unspecified */
"L02221" = "1" /* Furuncle of abdominal wall */
"L02222" = "1" /* Furuncle of back [any part, except buttock] */
"L02223" = "1" /* Furuncle of chest wall */
"L02224" = "1" /* Furuncle of groin */
"L02225" = "1" /* Furuncle of perineum */
"L02226" = "1" /* Furuncle of umbilicus */
"L02229" = "1" /* Furuncle of trunk, unspecified */
"L02231" = "1" /* Carbuncle of abdominal wall */
"L02232" = "1" /* Carbuncle of back [any part, except buttock] */
"L02233" = "1" /* Carbuncle of chest wall */
"L02234" = "1" /* Carbuncle of groin */
"L02235" = "1" /* Carbuncle of perineum */
"L02236" = "1" /* Carbuncle of umbilicus */
"L02239" = "1" /* Carbuncle of trunk, unspecified */
"L0231" = "1" /* Cutaneous abscess of buttock */
"L0232" = "1" /* Furuncle of buttock */
"L0233" = "1" /* Carbuncle of buttock */
"L02411" = "1" /* Cutaneous abscess of right axilla */
"L02412" = "1" /* Cutaneous abscess of left axilla */
"L02413" = "1" /* Cutaneous abscess of right upper limb */
"L02414" = "1" /* Cutaneous abscess of left upper limb */
"L02415" = "1" /* Cutaneous abscess of right lower limb */
"L02416" = "1" /* Cutaneous abscess of left lower limb */
"L02419" = "1" /* Cutaneous abscess of limb, unspecified */
"L02421" = "1" /* Furuncle of right axilla */
"L02422" = "1" /* Furuncle of left axilla */
"L02423" = "1" /* Furuncle of right upper limb */
"L02424" = "1" /* Furuncle of left upper limb */
"L02425" = "1" /* Furuncle of right lower limb */
"L02426" = "1" /* Furuncle of left lower limb */
"L02429" = "1" /* Furuncle of limb, unspecified */
"L02431" = "1" /* Carbuncle of right axilla */
"L02432" = "1" /* Carbuncle of left axilla */
"L02433" = "1" /* Carbuncle of right upper limb */
"L02434" = "1" /* Carbuncle of left upper limb */
"L02435" = "1" /* Carbuncle of right lower limb */
"L02436" = "1" /* Carbuncle of left lower limb */
"L02439" = "1" /* Carbuncle of limb, unspecified */
"L02511" = "1" /* Cutaneous abscess of right hand */
"L02512" = "1" /* Cutaneous abscess of left hand */
"L02519" = "1" /* Cutaneous abscess of unspecified hand */
"L02521" = "1" /* Furuncle right hand */
"L02522" = "1" /* Furuncle left hand */
"L02529" = "1" /* Furuncle unspecified hand */
"L02531" = "1" /* Carbuncle of right hand */
"L02532" = "1" /* Carbuncle of left hand */
"L02539" = "1" /* Carbuncle of unspecified hand */
"L02611" = "1" /* Cutaneous abscess of right foot */
"L02612" = "1" /* Cutaneous abscess of left foot */
"L02619" = "1" /* Cutaneous abscess of unspecified foot */
"L02621" = "1" /* Furuncle of right foot */
"L02622" = "1" /* Furuncle of left foot */
"L02629" = "1" /* Furuncle of unspecified foot */
"L02631" = "1" /* Carbuncle of right foot */
"L02632" = "1" /* Carbuncle of left foot */
"L02639" = "1" /* Carbuncle of unspecified foot */
"L02811" = "1" /* Cutaneous abscess of head [any part, except face] */
"L02818" = "1" /* Cutaneous abscess of other sites */
"L02821" = "1" /* Furuncle of head [any part, except face] */
"L02828" = "1" /* Furuncle of other sites */
"L02831" = "1" /* Carbuncle of head [any part, except face] */
"L02838" = "1" /* Carbuncle of other sites */
"L0291" = "1" /* Cutaneous abscess, unspecified */
"L0292" = "1" /* Furuncle, unspecified */
"L0293" = "1" /* Carbuncle, unspecified */
"L03011" = "1" /* Cellulitis of right finger */
"L03012" = "1" /* Cellulitis of left finger */
"L03019" = "1" /* Cellulitis of unspecified finger */
"L03021" = "1" /* Acute lymphangitis of right finger */
"L03022" = "1" /* Acute lymphangitis of left finger */
"L03029" = "1" /* Acute lymphangitis of unspecified finger */
"L03031" = "1" /* Cellulitis of right toe */
"L03032" = "1" /* Cellulitis of left toe */
"L03039" = "1" /* Cellulitis of unspecified toe */
"L03041" = "1" /* Acute lymphangitis of right toe */
"L03042" = "1" /* Acute lymphangitis of left toe */
"L03049" = "1" /* Acute lymphangitis of unspecified toe */
"L03111" = "1" /* Cellulitis of right axilla */
"L03112" = "1" /* Cellulitis of left axilla */
"L03113" = "1" /* Cellulitis of right upper limb */
"L03114" = "1" /* Cellulitis of left upper limb */
"L03115" = "1" /* Cellulitis of right lower limb */
"L03116" = "1" /* Cellulitis of left lower limb */
"L03119" = "1" /* Cellulitis of unspecified part of limb */
"L03121" = "1" /* Acute lymphangitis of right axilla */
"L03122" = "1" /* Acute lymphangitis of left axilla */
"L03123" = "1" /* Acute lymphangitis of right upper limb */
"L03124" = "1" /* Acute lymphangitis of left upper limb */
"L03125" = "1" /* Acute lymphangitis of right lower limb */
"L03126" = "1" /* Acute lymphangitis of left lower limb */
"L03129" = "1" /* Acute lymphangitis of unspecified part of limb */
"L03211" = "1" /* Cellulitis of face */
"L03212" = "1" /* Acute lymphangitis of face */
"L03213" = "1" /* Periorbital cellulitis */
"L03221" = "1" /* Cellulitis of neck */
"L03222" = "1" /* Acute lymphangitis of neck */
"L03311" = "1" /* Cellulitis of abdominal wall */
"L03312" = "1" /* Cellulitis of back [any part except buttock] */
"L03313" = "1" /* Cellulitis of chest wall */
"L03314" = "1" /* Cellulitis of groin */
"L03315" = "1" /* Cellulitis of perineum */
"L03316" = "1" /* Cellulitis of umbilicus */
"L03317" = "1" /* Cellulitis of buttock */
"L03319" = "1" /* Cellulitis of trunk, unspecified */
"L03321" = "1" /* Acute lymphangitis of abdominal wall */
"L03322" = "1" /* Acute lymphangitis of back [any part except buttock] */
"L03323" = "1" /* Acute lymphangitis of chest wall */
"L03324" = "1" /* Acute lymphangitis of groin */
"L03325" = "1" /* Acute lymphangitis of perineum */
"L03326" = "1" /* Acute lymphangitis of umbilicus */
"L03327" = "1" /* Acute lymphangitis of buttock */
"L03329" = "1" /* Acute lymphangitis of trunk, unspecified */
"L03811" = "1" /* Cellulitis of head [any part, except face] */
"L03818" = "1" /* Cellulitis of other sites */
"L03891" = "1" /* Acute lymphangitis of head [any part, except face] */
"L03898" = "1" /* Acute lymphangitis of other sites */
"L0390" = "1" /* Cellulitis, unspecified */
"L0391" = "1" /* Acute lymphangitis, unspecified */
"L040" = "1" /* Acute lymphadenitis of face, head and neck */
"L041" = "1" /* Acute lymphadenitis of trunk */
"L042" = "1" /* Acute lymphadenitis of upper limb */
"L043" = "1" /* Acute lymphadenitis of lower limb */
"L048" = "1" /* Acute lymphadenitis of other sites */
"L049" = "1" /* Acute lymphadenitis, unspecified */
"L080" = "1" /* Pyoderma */
"L081" = "1" /* Erythrasma */
"L0881" = "1" /* Pyoderma vegetans */
"L0882" = "1" /* Omphalitis not of newborn */
"L0889" = "1" /* Other specified local infections of the skin and subcutaneous tissue */
"L089" = "1" /* Local infection of the skin and subcutaneous tissue, unspecified */
"L89002" = "1" /* Pressure ulcer of unspecified elbow, stage 2 */
"L89003" = "1" /* Pressure ulcer of unspecified elbow, stage 3 */
"L89004" = "1" /* Pressure ulcer of unspecified elbow, stage 4 */
"L89009" = "1" /* Pressure ulcer of unspecified elbow, unspecified stage */
"L89012" = "1" /* Pressure ulcer of right elbow, stage 2 */
"L89013" = "1" /* Pressure ulcer of right elbow, stage 3 */
"L89014" = "1" /* Pressure ulcer of right elbow, stage 4 */
"L89019" = "1" /* Pressure ulcer of right elbow, unspecified stage */
"L89022" = "1" /* Pressure ulcer of left elbow, stage 2 */
"L89023" = "1" /* Pressure ulcer of left elbow, stage 3 */
"L89024" = "1" /* Pressure ulcer of left elbow, stage 4 */
"L89029" = "1" /* Pressure ulcer of left elbow, unspecified stage */
"L89102" = "1" /* Pressure ulcer of unspecified part of back, stage 2 */
"L89103" = "1" /* Pressure ulcer of unspecified part of back, stage 3 */
"L89104" = "1" /* Pressure ulcer of unspecified part of back, stage 4 */
"L89109" = "1" /* Pressure ulcer of unspecified part of back, unspecified stage */
"L89112" = "1" /* Pressure ulcer of right upper back, stage 2 */
"L89113" = "1" /* Pressure ulcer of right upper back, stage 3 */
"L89114" = "1" /* Pressure ulcer of right upper back, stage 4 */
"L89119" = "1" /* Pressure ulcer of right upper back, unspecified stage */
"L89122" = "1" /* Pressure ulcer of left upper back, stage 2 */
"L89123" = "1" /* Pressure ulcer of left upper back, stage 3 */
"L89124" = "1" /* Pressure ulcer of left upper back, stage 4 */
"L89129" = "1" /* Pressure ulcer of left upper back, unspecified stage */
"L89132" = "1" /* Pressure ulcer of right lower back, stage 2 */
"L89133" = "1" /* Pressure ulcer of right lower back, stage 3 */
"L89134" = "1" /* Pressure ulcer of right lower back, stage 4 */
"L89139" = "1" /* Pressure ulcer of right lower back, unspecified stage */
"L89142" = "1" /* Pressure ulcer of left lower back, stage 2 */
"L89143" = "1" /* Pressure ulcer of left lower back, stage 3 */
"L89144" = "1" /* Pressure ulcer of left lower back, stage 4 */
"L89149" = "1" /* Pressure ulcer of left lower back, unspecified stage */
"L89152" = "1" /* Pressure ulcer of sacral region, stage 2 */
"L89153" = "1" /* Pressure ulcer of sacral region, stage 3 */
"L89154" = "1" /* Pressure ulcer of sacral region, stage 4 */
"L89159" = "1" /* Pressure ulcer of sacral region, unspecified stage */
"L89202" = "1" /* Pressure ulcer of unspecified hip, stage 2 */
"L89203" = "1" /* Pressure ulcer of unspecified hip, stage 3 */
"L89204" = "1" /* Pressure ulcer of unspecified hip, stage 4 */
"L89209" = "1" /* Pressure ulcer of unspecified hip, unspecified stage */
"L89212" = "1" /* Pressure ulcer of right hip, stage 2 */
"L89213" = "1" /* Pressure ulcer of right hip, stage 3 */
"L89214" = "1" /* Pressure ulcer of right hip, stage 4 */
"L89219" = "1" /* Pressure ulcer of right hip, unspecified stage */
"L89222" = "1" /* Pressure ulcer of left hip, stage 2 */
"L89223" = "1" /* Pressure ulcer of left hip, stage 3 */
"L89224" = "1" /* Pressure ulcer of left hip, stage 4 */
"L89229" = "1" /* Pressure ulcer of left hip, unspecified stage */
"L89302" = "1" /* Pressure ulcer of unspecified buttock, stage 2 */
"L89303" = "1" /* Pressure ulcer of unspecified buttock, stage 3 */
"L89304" = "1" /* Pressure ulcer of unspecified buttock, stage 4 */
"L89309" = "1" /* Pressure ulcer of unspecified buttock, unspecified stage */
"L89312" = "1" /* Pressure ulcer of right buttock, stage 2 */
"L89313" = "1" /* Pressure ulcer of right buttock, stage 3 */
"L89314" = "1" /* Pressure ulcer of right buttock, stage 4 */
"L89319" = "1" /* Pressure ulcer of right buttock, unspecified stage */
"L89322" = "1" /* Pressure ulcer of left buttock, stage 2 */
"L89323" = "1" /* Pressure ulcer of left buttock, stage 3 */
"L89324" = "1" /* Pressure ulcer of left buttock, stage 4 */
"L89329" = "1" /* Pressure ulcer of left buttock, unspecified stage */
"L8940" = "1" /* Pressure ulcer of contiguous site of back, buttock and hip, unspecified stage */
"L8942" = "1" /* Pressure ulcer of contiguous site of back, buttock and hip, stage 2 */
"L8943" = "1" /* Pressure ulcer of contiguous site of back, buttock and hip, stage 3 */
"L8944" = "1" /* Pressure ulcer of contiguous site of back, buttock and hip, stage 4 */
"L89502" = "1" /* Pressure ulcer of unspecified ankle, stage 2 */
"L89503" = "1" /* Pressure ulcer of unspecified ankle, stage 3 */
"L89504" = "1" /* Pressure ulcer of unspecified ankle, stage 4 */
"L89509" = "1" /* Pressure ulcer of unspecified ankle, unspecified stage */
"L89512" = "1" /* Pressure ulcer of right ankle, stage 2 */
"L89513" = "1" /* Pressure ulcer of right ankle, stage 3 */
"L89514" = "1" /* Pressure ulcer of right ankle, stage 4 */
"L89519" = "1" /* Pressure ulcer of right ankle, unspecified stage */
"L89522" = "1" /* Pressure ulcer of left ankle, stage 2 */
"L89523" = "1" /* Pressure ulcer of left ankle, stage 3 */
"L89524" = "1" /* Pressure ulcer of left ankle, stage 4 */
"L89529" = "1" /* Pressure ulcer of left ankle, unspecified stage */
"L89602" = "1" /* Pressure ulcer of unspecified heel, stage 2 */
"L89603" = "1" /* Pressure ulcer of unspecified heel, stage 3 */
"L89604" = "1" /* Pressure ulcer of unspecified heel, stage 4 */
"L89609" = "1" /* Pressure ulcer of unspecified heel, unspecified stage */
"L89612" = "1" /* Pressure ulcer of right heel, stage 2 */
"L89613" = "1" /* Pressure ulcer of right heel, stage 3 */
"L89614" = "1" /* Pressure ulcer of right heel, stage 4 */
"L89619" = "1" /* Pressure ulcer of right heel, unspecified stage */
"L89622" = "1" /* Pressure ulcer of left heel, stage 2 */
"L89623" = "1" /* Pressure ulcer of left heel, stage 3 */
"L89624" = "1" /* Pressure ulcer of left heel, stage 4 */
"L89629" = "1" /* Pressure ulcer of left heel, unspecified stage */
"L89812" = "1" /* Pressure ulcer of head, stage 2 */
"L89813" = "1" /* Pressure ulcer of head, stage 3 */
"L89814" = "1" /* Pressure ulcer of head, stage 4 */
"L89819" = "1" /* Pressure ulcer of head, unspecified stage */
"L89892" = "1" /* Pressure ulcer of other site, stage 2 */
"L89893" = "1" /* Pressure ulcer of other site, stage 3 */
"L89894" = "1" /* Pressure ulcer of other site, stage 4 */
"L89899" = "1" /* Pressure ulcer of other site, unspecified stage */
"L8990" = "1" /* Pressure ulcer of unspecified site, unspecified stage */
"L8992" = "1" /* Pressure ulcer of unspecified site, stage 2 */
"L8993" = "1" /* Pressure ulcer of unspecified site, stage 3 */
"L8994" = "1" /* Pressure ulcer of unspecified site, stage 4 */
"L983" = "1" /* Eosinophilic cellulitis [Wells] */
"M0000" = "1" /* Staphylococcal arthritis, unspecified joint */
"M00011" = "1" /* Staphylococcal arthritis, right shoulder */
"M00012" = "1" /* Staphylococcal arthritis, left shoulder */
"M00019" = "1" /* Staphylococcal arthritis, unspecified shoulder */
"M00021" = "1" /* Staphylococcal arthritis, right elbow */
"M00022" = "1" /* Staphylococcal arthritis, left elbow */
"M00029" = "1" /* Staphylococcal arthritis, unspecified elbow */
"M00031" = "1" /* Staphylococcal arthritis, right wrist */
"M00032" = "1" /* Staphylococcal arthritis, left wrist */
"M00039" = "1" /* Staphylococcal arthritis, unspecified wrist */
"M00041" = "1" /* Staphylococcal arthritis, right hand */
"M00042" = "1" /* Staphylococcal arthritis, left hand */
"M00049" = "1" /* Staphylococcal arthritis, unspecified hand */
"M00051" = "1" /* Staphylococcal arthritis, right hip */
"M00052" = "1" /* Staphylococcal arthritis, left hip */
"M00059" = "1" /* Staphylococcal arthritis, unspecified hip */
"M00061" = "1" /* Staphylococcal arthritis, right knee */
"M00062" = "1" /* Staphylococcal arthritis, left knee */
"M00069" = "1" /* Staphylococcal arthritis, unspecified knee */
"M00071" = "1" /* Staphylococcal arthritis, right ankle and foot */
"M00072" = "1" /* Staphylococcal arthritis, left ankle and foot */
"M00079" = "1" /* Staphylococcal arthritis, unspecified ankle and foot */
"M0008" = "1" /* Staphylococcal arthritis, vertebrae */
"M0009" = "1" /* Staphylococcal polyarthritis */
"M0010" = "1" /* Pneumococcal arthritis, unspecified joint */
"M00111" = "1" /* Pneumococcal arthritis, right shoulder */
"M00112" = "1" /* Pneumococcal arthritis, left shoulder */
"M00119" = "1" /* Pneumococcal arthritis, unspecified shoulder */
"M00121" = "1" /* Pneumococcal arthritis, right elbow */
"M00122" = "1" /* Pneumococcal arthritis, left elbow */
"M00129" = "1" /* Pneumococcal arthritis, unspecified elbow */
"M00131" = "1" /* Pneumococcal arthritis, right wrist */
"M00132" = "1" /* Pneumococcal arthritis, left wrist */
"M00139" = "1" /* Pneumococcal arthritis, unspecified wrist */
"M00141" = "1" /* Pneumococcal arthritis, right hand */
"M00142" = "1" /* Pneumococcal arthritis, left hand */
"M00149" = "1" /* Pneumococcal arthritis, unspecified hand */
"M00151" = "1" /* Pneumococcal arthritis, right hip */
"M00152" = "1" /* Pneumococcal arthritis, left hip */
"M00159" = "1" /* Pneumococcal arthritis, unspecified hip */
"M00161" = "1" /* Pneumococcal arthritis, right knee */
"M00162" = "1" /* Pneumococcal arthritis, left knee */
"M00169" = "1" /* Pneumococcal arthritis, unspecified knee */
"M00171" = "1" /* Pneumococcal arthritis, right ankle and foot */
"M00172" = "1" /* Pneumococcal arthritis, left ankle and foot */
"M00179" = "1" /* Pneumococcal arthritis, unspecified ankle and foot */
"M0018" = "1" /* Pneumococcal arthritis, vertebrae */
"M0019" = "1" /* Pneumococcal polyarthritis */
"M0020" = "1" /* Other streptococcal arthritis, unspecified joint */
"M00211" = "1" /* Other streptococcal arthritis, right shoulder */
"M00212" = "1" /* Other streptococcal arthritis, left shoulder */
"M00219" = "1" /* Other streptococcal arthritis, unspecified shoulder */
"M00221" = "1" /* Other streptococcal arthritis, right elbow */
"M00222" = "1" /* Other streptococcal arthritis, left elbow */
"M00229" = "1" /* Other streptococcal arthritis, unspecified elbow */
"M00231" = "1" /* Other streptococcal arthritis, right wrist */
"M00232" = "1" /* Other streptococcal arthritis, left wrist */
"M00239" = "1" /* Other streptococcal arthritis, unspecified wrist */
"M00241" = "1" /* Other streptococcal arthritis, right hand */
"M00242" = "1" /* Other streptococcal arthritis, left hand */
"M00249" = "1" /* Other streptococcal arthritis, unspecified hand */
"M00251" = "1" /* Other streptococcal arthritis, right hip */
"M00252" = "1" /* Other streptococcal arthritis, left hip */
"M00259" = "1" /* Other streptococcal arthritis, unspecified hip */
"M00261" = "1" /* Other streptococcal arthritis, right knee */
"M00262" = "1" /* Other streptococcal arthritis, left knee */
"M00269" = "1" /* Other streptococcal arthritis, unspecified knee */
"M00271" = "1" /* Other streptococcal arthritis, right ankle and foot */
"M00272" = "1" /* Other streptococcal arthritis, left ankle and foot */
"M00279" = "1" /* Other streptococcal arthritis, unspecified ankle and foot */
"M0028" = "1" /* Other streptococcal arthritis, vertebrae */
"M0029" = "1" /* Other streptococcal polyarthritis */
"M0080" = "1" /* Arthritis due to other bacteria, unspecified joint */
"M00811" = "1" /* Arthritis due to other bacteria, right shoulder */
"M00812" = "1" /* Arthritis due to other bacteria, left shoulder */
"M00819" = "1" /* Arthritis due to other bacteria, unspecified shoulder */
"M00821" = "1" /* Arthritis due to other bacteria, right elbow */
"M00822" = "1" /* Arthritis due to other bacteria, left elbow */
"M00829" = "1" /* Arthritis due to other bacteria, unspecified elbow */
"M00831" = "1" /* Arthritis due to other bacteria, right wrist */
"M00832" = "1" /* Arthritis due to other bacteria, left wrist */
"M00839" = "1" /* Arthritis due to other bacteria, unspecified wrist */
"M00841" = "1" /* Arthritis due to other bacteria, right hand */
"M00842" = "1" /* Arthritis due to other bacteria, left hand */
"M00849" = "1" /* Arthritis due to other bacteria, unspecified hand */
"M00851" = "1" /* Arthritis due to other bacteria, right hip */
"M00852" = "1" /* Arthritis due to other bacteria, left hip */
"M00859" = "1" /* Arthritis due to other bacteria, unspecified hip */
"M00861" = "1" /* Arthritis due to other bacteria, right knee */
"M00862" = "1" /* Arthritis due to other bacteria, left knee */
"M00869" = "1" /* Arthritis due to other bacteria, unspecified knee */
"M00871" = "1" /* Arthritis due to other bacteria, right ankle and foot */
"M00872" = "1" /* Arthritis due to other bacteria, left ankle and foot */
"M00879" = "1" /* Arthritis due to other bacteria, unspecified ankle and foot */
"M0088" = "1" /* Arthritis due to other bacteria, vertebrae */
"M0089" = "1" /* Polyarthritis due to other bacteria */
"M009" = "1" /* Pyogenic arthritis, unspecified */
"M01X0" = "1" /* Direct infection of unspecified joint in infectious and parasitic diseases classified elsewhere */
"M01X19" = "1" /* Direct infection of unspecified shoulder in infectious and parasitic diseases classified elsewhere */
"M01X29" = "1" /* Direct infection of unspecified elbow in infectious and parasitic diseases classified elsewhere */
"M01X39" = "1" /* Direct infection of unspecified wrist in infectious and parasitic diseases classified elsewhere */
"M01X49" = "1" /* Direct infection of unspecified hand in infectious and parasitic diseases classified elsewhere */
"M01X59" = "1" /* Direct infection of unspecified hip in infectious and parasitic diseases classified elsewhere */
"M01X69" = "1" /* Direct infection of unspecified knee in infectious and parasitic diseases classified elsewhere */
"M01X79" = "1" /* Direct infection of unspecified ankle and foot in infectious and parasitic diseases classified elsewhere */
"M01X8" = "1" /* Direct infection of vertebrae in infectious and parasitic diseases classified elsewhere */
"M01X9" = "1" /* Direct infection of multiple joints in infectious and parasitic diseases classified elsewhere */
"M272" = "1" /* Inflammatory conditions of jaws */
"M3212" = "1" /* Pericarditis in systemic lupus erythematosus */
"M4620" = "1" /* Osteomyelitis of vertebra, site unspecified */
"M4621" = "1" /* Osteomyelitis of vertebra, occipito-atlanto-axial region */
"M4622" = "1" /* Osteomyelitis of vertebra, cervical region */
"M4623" = "1" /* Osteomyelitis of vertebra, cervicothoracic region */
"M4624" = "1" /* Osteomyelitis of vertebra, thoracic region */
"M4625" = "1" /* Osteomyelitis of vertebra, thoracolumbar region */
"M4626" = "1" /* Osteomyelitis of vertebra, lumbar region */
"M4627" = "1" /* Osteomyelitis of vertebra, lumbosacral region */
"M4628" = "1" /* Osteomyelitis of vertebra, sacral and sacrococcygeal region */
"M4630" = "1" /* Infection of intervertebral disc (pyogenic), site unspecified */
"M4631" = "1" /* Infection of intervertebral disc (pyogenic), occipito-atlanto-axial region */
"M4632" = "1" /* Infection of intervertebral disc (pyogenic), cervical region */
"M4633" = "1" /* Infection of intervertebral disc (pyogenic), cervicothoracic region */
"M4634" = "1" /* Infection of intervertebral disc (pyogenic), thoracic region */
"M4635" = "1" /* Infection of intervertebral disc (pyogenic), thoracolumbar region */
"M4636" = "1" /* Infection of intervertebral disc (pyogenic), lumbar region */
"M4637" = "1" /* Infection of intervertebral disc (pyogenic), lumbosacral region */
"M4638" = "1" /* Infection of intervertebral disc (pyogenic), sacral and sacrococcygeal region */
"M4639" = "1" /* Infection of intervertebral disc (pyogenic), multiple sites in spine */
"M60000" = "1" /* Infective myositis, unspecified right arm */
"M60001" = "1" /* Infective myositis, unspecified left arm */
"M60002" = "1" /* Infective myositis, unspecified arm */
"M60003" = "1" /* Infective myositis, unspecified right leg */
"M60004" = "1" /* Infective myositis, unspecified left leg */
"M60005" = "1" /* Infective myositis, unspecified leg */
"M60009" = "1" /* Infective myositis, unspecified site */
"M60011" = "1" /* Infective myositis, right shoulder */
"M60012" = "1" /* Infective myositis, left shoulder */
"M60019" = "1" /* Infective myositis, unspecified shoulder */
"M60021" = "1" /* Infective myositis, right upper arm */
"M60022" = "1" /* Infective myositis, left upper arm */
"M60029" = "1" /* Infective myositis, unspecified upper arm */
"M60031" = "1" /* Infective myositis, right forearm */
"M60032" = "1" /* Infective myositis, left forearm */
"M60039" = "1" /* Infective myositis, unspecified forearm */
"M60041" = "1" /* Infective myositis, right hand */
"M60042" = "1" /* Infective myositis, left hand */
"M60043" = "1" /* Infective myositis, unspecified hand */
"M60044" = "1" /* Infective myositis, right finger(s) */
"M60045" = "1" /* Infective myositis, left finger(s) */
"M60046" = "1" /* Infective myositis, unspecified finger(s) */
"M60051" = "1" /* Infective myositis, right thigh */
"M60052" = "1" /* Infective myositis, left thigh */
"M60059" = "1" /* Infective myositis, unspecified thigh */
"M60061" = "1" /* Infective myositis, right lower leg */
"M60062" = "1" /* Infective myositis, left lower leg */
"M60069" = "1" /* Infective myositis, unspecified lower leg */
"M60070" = "1" /* Infective myositis, right ankle */
"M60071" = "1" /* Infective myositis, left ankle */
"M60072" = "1" /* Infective myositis, unspecified ankle */
"M60073" = "1" /* Infective myositis, right foot */
"M60074" = "1" /* Infective myositis, left foot */
"M60075" = "1" /* Infective myositis, unspecified foot */
"M60076" = "1" /* Infective myositis, right toe(s) */
"M60077" = "1" /* Infective myositis, left toe(s) */
"M60078" = "1" /* Infective myositis, unspecified toe(s) */
"M6008" = "1" /* Infective myositis, other site */
"M6009" = "1" /* Infective myositis, multiple sites */
"M726" = "1" /* Necrotizing fasciitis */
"M8600" = "1" /* Acute hematogenous osteomyelitis, unspecified site */
"M86011" = "1" /* Acute hematogenous osteomyelitis, right shoulder */
"M86012" = "1" /* Acute hematogenous osteomyelitis, left shoulder */
"M86019" = "1" /* Acute hematogenous osteomyelitis, unspecified shoulder */
"M86021" = "1" /* Acute hematogenous osteomyelitis, right humerus */
"M86022" = "1" /* Acute hematogenous osteomyelitis, left humerus */
"M86029" = "1" /* Acute hematogenous osteomyelitis, unspecified humerus */
"M86031" = "1" /* Acute hematogenous osteomyelitis, right radius and ulna */
"M86032" = "1" /* Acute hematogenous osteomyelitis, left radius and ulna */
"M86039" = "1" /* Acute hematogenous osteomyelitis, unspecified radius and ulna */
"M86041" = "1" /* Acute hematogenous osteomyelitis, right hand */
"M86042" = "1" /* Acute hematogenous osteomyelitis, left hand */
"M86049" = "1" /* Acute hematogenous osteomyelitis, unspecified hand */
"M86051" = "1" /* Acute hematogenous osteomyelitis, right femur */
"M86052" = "1" /* Acute hematogenous osteomyelitis, left femur */
"M86059" = "1" /* Acute hematogenous osteomyelitis, unspecified femur */
"M86061" = "1" /* Acute hematogenous osteomyelitis, right tibia and fibula */
"M86062" = "1" /* Acute hematogenous osteomyelitis, left tibia and fibula */
"M86069" = "1" /* Acute hematogenous osteomyelitis, unspecified tibia and fibula */
"M86071" = "1" /* Acute hematogenous osteomyelitis, right ankle and foot */
"M86072" = "1" /* Acute hematogenous osteomyelitis, left ankle and foot */
"M86079" = "1" /* Acute hematogenous osteomyelitis, unspecified ankle and foot */
"M8608" = "1" /* Acute hematogenous osteomyelitis, other sites */
"M8609" = "1" /* Acute hematogenous osteomyelitis, multiple sites */
"M8610" = "1" /* Other acute osteomyelitis, unspecified site */
"M86111" = "1" /* Other acute osteomyelitis, right shoulder */
"M86112" = "1" /* Other acute osteomyelitis, left shoulder */
"M86119" = "1" /* Other acute osteomyelitis, unspecified shoulder */
"M86121" = "1" /* Other acute osteomyelitis, right humerus */
"M86122" = "1" /* Other acute osteomyelitis, left humerus */
"M86129" = "1" /* Other acute osteomyelitis, unspecified humerus */
"M86131" = "1" /* Other acute osteomyelitis, right radius and ulna */
"M86132" = "1" /* Other acute osteomyelitis, left radius and ulna */
"M86139" = "1" /* Other acute osteomyelitis, unspecified radius and ulna */
"M86141" = "1" /* Other acute osteomyelitis, right hand */
"M86142" = "1" /* Other acute osteomyelitis, left hand */
"M86149" = "1" /* Other acute osteomyelitis, unspecified hand */
"M86151" = "1" /* Other acute osteomyelitis, right femur */
"M86152" = "1" /* Other acute osteomyelitis, left femur */
"M86159" = "1" /* Other acute osteomyelitis, unspecified femur */
"M86161" = "1" /* Other acute osteomyelitis, right tibia and fibula */
"M86162" = "1" /* Other acute osteomyelitis, left tibia and fibula */
"M86169" = "1" /* Other acute osteomyelitis, unspecified tibia and fibula */
"M86171" = "1" /* Other acute osteomyelitis, right ankle and foot */
"M86172" = "1" /* Other acute osteomyelitis, left ankle and foot */
"M86179" = "1" /* Other acute osteomyelitis, unspecified ankle and foot */
"M8618" = "1" /* Other acute osteomyelitis, other site */
"M8619" = "1" /* Other acute osteomyelitis, multiple sites */
"M8620" = "1" /* Subacute osteomyelitis, unspecified site */
"M86211" = "1" /* Subacute osteomyelitis, right shoulder */
"M86212" = "1" /* Subacute osteomyelitis, left shoulder */
"M86219" = "1" /* Subacute osteomyelitis, unspecified shoulder */
"M86221" = "1" /* Subacute osteomyelitis, right humerus */
"M86222" = "1" /* Subacute osteomyelitis, left humerus */
"M86229" = "1" /* Subacute osteomyelitis, unspecified humerus */
"M86231" = "1" /* Subacute osteomyelitis, right radius and ulna */
"M86232" = "1" /* Subacute osteomyelitis, left radius and ulna */
"M86239" = "1" /* Subacute osteomyelitis, unspecified radius and ulna */
"M86241" = "1" /* Subacute osteomyelitis, right hand */
"M86242" = "1" /* Subacute osteomyelitis, left hand */
"M86249" = "1" /* Subacute osteomyelitis, unspecified hand */
"M86251" = "1" /* Subacute osteomyelitis, right femur */
"M86252" = "1" /* Subacute osteomyelitis, left femur */
"M86259" = "1" /* Subacute osteomyelitis, unspecified femur */
"M86261" = "1" /* Subacute osteomyelitis, right tibia and fibula */
"M86262" = "1" /* Subacute osteomyelitis, left tibia and fibula */
"M86269" = "1" /* Subacute osteomyelitis, unspecified tibia and fibula */
"M86271" = "1" /* Subacute osteomyelitis, right ankle and foot */
"M86272" = "1" /* Subacute osteomyelitis, left ankle and foot */
"M86279" = "1" /* Subacute osteomyelitis, unspecified ankle and foot */
"M8628" = "1" /* Subacute osteomyelitis, other site */
"M8629" = "1" /* Subacute osteomyelitis, multiple sites */
"M8630" = "1" /* Chronic multifocal osteomyelitis, unspecified site */
"M86311" = "1" /* Chronic multifocal osteomyelitis, right shoulder */
"M86312" = "1" /* Chronic multifocal osteomyelitis, left shoulder */
"M86319" = "1" /* Chronic multifocal osteomyelitis, unspecified shoulder */
"M86321" = "1" /* Chronic multifocal osteomyelitis, right humerus */
"M86322" = "1" /* Chronic multifocal osteomyelitis, left humerus */
"M86329" = "1" /* Chronic multifocal osteomyelitis, unspecified humerus */
"M86331" = "1" /* Chronic multifocal osteomyelitis, right radius and ulna */
"M86332" = "1" /* Chronic multifocal osteomyelitis, left radius and ulna */
"M86339" = "1" /* Chronic multifocal osteomyelitis, unspecified radius and ulna */
"M86341" = "1" /* Chronic multifocal osteomyelitis, right hand */
"M86342" = "1" /* Chronic multifocal osteomyelitis, left hand */
"M86349" = "1" /* Chronic multifocal osteomyelitis, unspecified hand */
"M86351" = "1" /* Chronic multifocal osteomyelitis, right femur */
"M86352" = "1" /* Chronic multifocal osteomyelitis, left femur */
"M86359" = "1" /* Chronic multifocal osteomyelitis, unspecified femur */
"M86361" = "1" /* Chronic multifocal osteomyelitis, right tibia and fibula */
"M86362" = "1" /* Chronic multifocal osteomyelitis, left tibia and fibula */
"M86369" = "1" /* Chronic multifocal osteomyelitis, unspecified tibia and fibula */
"M86371" = "1" /* Chronic multifocal osteomyelitis, right ankle and foot */
"M86372" = "1" /* Chronic multifocal osteomyelitis, left ankle and foot */
"M86379" = "1" /* Chronic multifocal osteomyelitis, unspecified ankle and foot */
"M8638" = "1" /* Chronic multifocal osteomyelitis, other site */
"M8639" = "1" /* Chronic multifocal osteomyelitis, multiple sites */
"M8640" = "1" /* Chronic osteomyelitis with draining sinus, unspecified site */
"M86411" = "1" /* Chronic osteomyelitis with draining sinus, right shoulder */
"M86412" = "1" /* Chronic osteomyelitis with draining sinus, left shoulder */
"M86419" = "1" /* Chronic osteomyelitis with draining sinus, unspecified shoulder */
"M86421" = "1" /* Chronic osteomyelitis with draining sinus, right humerus */
"M86422" = "1" /* Chronic osteomyelitis with draining sinus, left humerus */
"M86429" = "1" /* Chronic osteomyelitis with draining sinus, unspecified humerus */
"M86431" = "1" /* Chronic osteomyelitis with draining sinus, right radius and ulna */
"M86432" = "1" /* Chronic osteomyelitis with draining sinus, left radius and ulna */
"M86439" = "1" /* Chronic osteomyelitis with draining sinus, unspecified radius and ulna */
"M86441" = "1" /* Chronic osteomyelitis with draining sinus, right hand */
"M86442" = "1" /* Chronic osteomyelitis with draining sinus, left hand */
"M86449" = "1" /* Chronic osteomyelitis with draining sinus, unspecified hand */
"M86451" = "1" /* Chronic osteomyelitis with draining sinus, right femur */
"M86452" = "1" /* Chronic osteomyelitis with draining sinus, left femur */
"M86459" = "1" /* Chronic osteomyelitis with draining sinus, unspecified femur */
"M86461" = "1" /* Chronic osteomyelitis with draining sinus, right tibia and fibula */
"M86462" = "1" /* Chronic osteomyelitis with draining sinus, left tibia and fibula */
"M86469" = "1" /* Chronic osteomyelitis with draining sinus, unspecified tibia and fibula */
"M86471" = "1" /* Chronic osteomyelitis with draining sinus, right ankle and foot */
"M86472" = "1" /* Chronic osteomyelitis with draining sinus, left ankle and foot */
"M86479" = "1" /* Chronic osteomyelitis with draining sinus, unspecified ankle and foot */
"M8648" = "1" /* Chronic osteomyelitis with draining sinus, other site */
"M8649" = "1" /* Chronic osteomyelitis with draining sinus, multiple sites */
"M8650" = "1" /* Other chronic hematogenous osteomyelitis, unspecified site */
"M86511" = "1" /* Other chronic hematogenous osteomyelitis, right shoulder */
"M86512" = "1" /* Other chronic hematogenous osteomyelitis, left shoulder */
"M86519" = "1" /* Other chronic hematogenous osteomyelitis, unspecified shoulder */
"M86521" = "1" /* Other chronic hematogenous osteomyelitis, right humerus */
"M86522" = "1" /* Other chronic hematogenous osteomyelitis, left humerus */
"M86529" = "1" /* Other chronic hematogenous osteomyelitis, unspecified humerus */
"M86531" = "1" /* Other chronic hematogenous osteomyelitis, right radius and ulna */
"M86532" = "1" /* Other chronic hematogenous osteomyelitis, left radius and ulna */
"M86539" = "1" /* Other chronic hematogenous osteomyelitis, unspecified radius and ulna */
"M86541" = "1" /* Other chronic hematogenous osteomyelitis, right hand */
"M86542" = "1" /* Other chronic hematogenous osteomyelitis, left hand */
"M86549" = "1" /* Other chronic hematogenous osteomyelitis, unspecified hand */
"M86551" = "1" /* Other chronic hematogenous osteomyelitis, right femur */
"M86552" = "1" /* Other chronic hematogenous osteomyelitis, left femur */
"M86559" = "1" /* Other chronic hematogenous osteomyelitis, unspecified femur */
"M86561" = "1" /* Other chronic hematogenous osteomyelitis, right tibia and fibula */
"M86562" = "1" /* Other chronic hematogenous osteomyelitis, left tibia and fibula */
"M86569" = "1" /* Other chronic hematogenous osteomyelitis, unspecified tibia and fibula */
"M86571" = "1" /* Other chronic hematogenous osteomyelitis, right ankle and foot */
"M86572" = "1" /* Other chronic hematogenous osteomyelitis, left ankle and foot */
"M86579" = "1" /* Other chronic hematogenous osteomyelitis, unspecified ankle and foot */
"M8658" = "1" /* Other chronic hematogenous osteomyelitis, other site */
"M8659" = "1" /* Other chronic hematogenous osteomyelitis, multiple sites */
"M8660" = "1" /* Other chronic osteomyelitis, unspecified site */
"M86611" = "1" /* Other chronic osteomyelitis, right shoulder */
"M86612" = "1" /* Other chronic osteomyelitis, left shoulder */
"M86619" = "1" /* Other chronic osteomyelitis, unspecified shoulder */
"M86621" = "1" /* Other chronic osteomyelitis, right  humerus */
"M86622" = "1" /* Other chronic osteomyelitis, left  humerus */
"M86629" = "1" /* Other chronic osteomyelitis, unspecified  humerus */
"M86631" = "1" /* Other chronic osteomyelitis, right radius and ulna */
"M86632" = "1" /* Other chronic osteomyelitis, left radius and ulna */
"M86639" = "1" /* Other chronic osteomyelitis, unspecified radius and ulna */
"M86641" = "1" /* Other chronic osteomyelitis, right hand */
"M86642" = "1" /* Other chronic osteomyelitis, left hand */
"M86649" = "1" /* Other chronic osteomyelitis, unspecified hand */
"M86651" = "1" /* Other chronic osteomyelitis, right thigh */
"M86652" = "1" /* Other chronic osteomyelitis, left thigh */
"M86659" = "1" /* Other chronic osteomyelitis, unspecified thigh */
"M86661" = "1" /* Other chronic osteomyelitis, right tibia and fibula */
"M86662" = "1" /* Other chronic osteomyelitis, left tibia and fibula */
"M86669" = "1" /* Other chronic osteomyelitis, unspecified tibia and fibula */
"M86671" = "1" /* Other chronic osteomyelitis, right ankle and foot */
"M86672" = "1" /* Other chronic osteomyelitis, left ankle and foot */
"M86679" = "1" /* Other chronic osteomyelitis, unspecified ankle and foot */
"M8668" = "1" /* Other chronic osteomyelitis, other site */
"M8669" = "1" /* Other chronic osteomyelitis, multiple sites */
"M868X0" = "1" /* Other osteomyelitis, multiple sites */
"M868X1" = "1" /* Other osteomyelitis, shoulder */
"M868X2" = "1" /* Other osteomyelitis, upper arm */
"M868X3" = "1" /* Other osteomyelitis, forearm */
"M868X4" = "1" /* Other osteomyelitis, hand */
"M868X5" = "1" /* Other osteomyelitis, thigh */
"M868X6" = "1" /* Other osteomyelitis, lower leg */
"M868X7" = "1" /* Other osteomyelitis, ankle and foot */
"M868X8" = "1" /* Other osteomyelitis, other site */
"M868X9" = "1" /* Other osteomyelitis, unspecified sites */
"M869" = "1" /* Osteomyelitis, unspecified */
"N10" = "1" /* Acute pyelonephritis */
"N119" = "1" /* Chronic tubulo-interstitial nephritis, unspecified */
"N12" = "1" /* Tubulo-interstitial nephritis, not specified as acute or chronic */
"N136" = "1" /* Pyonephrosis */
"N151" = "1" /* Renal and perinephric abscess */
"N159" = "1" /* Renal tubulo-interstitial disease, unspecified */
"N16" = "1" /* Renal tubulo-interstitial disorders in diseases classified elsewhere */
"N2884" = "1" /* Pyelitis cystica */
"N2885" = "1" /* Pyeloureteritis cystica */
"N2886" = "1" /* Ureteritis cystica */
"N3000" = "1" /* Acute cystitis without hematuria */
"N3001" = "1" /* Acute cystitis with hematuria */
"N3080" = "1" /* Other cystitis without hematuria */
"N3081" = "1" /* Other cystitis with hematuria */
"N3090" = "1" /* Cystitis, unspecified without hematuria */
"N3091" = "1" /* Cystitis, unspecified with hematuria */
"N340" = "1" /* Urethral abscess */
"N390" = "1" /* Urinary tract infection, site not specified */
"N410" = "1" /* Acute prostatitis */
"N412" = "1" /* Abscess of prostate */
"N413" = "1" /* Prostatocystitis */
"N414" = "1" /* Granulomatous prostatitis */
"N418" = "1" /* Other inflammatory diseases of prostate */
"N419" = "1" /* Inflammatory disease of prostate, unspecified */
"N431" = "1" /* Infected hydrocele */
"N451" = "1" /* Epididymitis */
"N452" = "1" /* Orchitis */
"N453" = "1" /* Epididymo-orchitis */
"N454" = "1" /* Abscess of epididymis or testis */
"N476" = "1" /* Balanoposthitis */
"N481" = "1" /* Balanitis */
"N4821" = "1" /* Abscess of corpus cavernosum and penis */
"N4822" = "1" /* Cellulitis of corpus cavernosum and penis */
"N4829" = "1" /* Other inflammatory disorders of penis */
"N490" = "1" /* Inflammatory disorders of seminal vesicle */
"N491" = "1" /* Inflammatory disorders of spermatic cord, tunica vaginalis and vas deferens */
"N492" = "1" /* Inflammatory disorders of scrotum */
"N493" = "1" /* Fournier gangrene */
"N498" = "1" /* Inflammatory disorders of other specified male genital organs */
"N499" = "1" /* Inflammatory disorder of unspecified male genital organ */
"N61" = "1" /* Inflammatory disorders of breast */
"N610" = "1" /* Mastitis without abscess */
"N611" = "1" /* Abscess of the breast and nipple */
"N7001" = "1" /* Acute salpingitis */
"N7002" = "1" /* Acute oophoritis */
"N7003" = "1" /* Acute salpingitis and oophoritis */
"N7011" = "1" /* Chronic salpingitis */
"N7012" = "1" /* Chronic oophoritis */
"N7013" = "1" /* Chronic salpingitis and oophoritis */
"N7091" = "1" /* Salpingitis, unspecified */
"N7092" = "1" /* Oophoritis, unspecified */
"N7093" = "1" /* Salpingitis and oophoritis, unspecified */
"N710" = "1" /* Acute inflammatory disease of uterus */
"N719" = "1" /* Inflammatory disease of uterus, unspecified */
"N72" = "1" /* Inflammatory disease of cervix uteri */
"N730" = "1" /* Acute parametritis and pelvic cellulitis */
"N731" = "1" /* Chronic parametritis and pelvic cellulitis */
"N732" = "1" /* Unspecified parametritis and pelvic cellulitis */
"N733" = "1" /* Female acute pelvic peritonitis */
"N735" = "1" /* Female pelvic peritonitis, unspecified */
"N739" = "1" /* Female pelvic inflammatory disease, unspecified */
"N751" = "1" /* Abscess of Bartholin's gland */
"N760" = "1" /* Acute vaginitis */
"N761" = "1" /* Subacute and chronic vaginitis */
"N762" = "1" /* Acute vulvitis */
"N763" = "1" /* Subacute and chronic vulvitis */
"N764" = "1" /* Abscess of vulva */
"N99511" = "1" /* Cystostomy infection */
"O030" = "1" /* Genital tract and pelvic infection following incomplete spontaneous abortion */
"O0337" = "1" /* Sepsis following incomplete spontaneous abortion */
"O035" = "1" /* Genital tract and pelvic infection following complete or unspecified spontaneous abortion */
"O0387" = "1" /* Sepsis following complete or unspecified spontaneous abortion */
"O045" = "1" /* Genital tract and pelvic infection following (induced) termination of pregnancy */
"O0487" = "1" /* Sepsis following (induced) termination of pregnancy */
"O070" = "1" /* Genital tract and pelvic infection following failed attempted termination of pregnancy */
"O0737" = "1" /* Sepsis following failed attempted termination of pregnancy */
"O080" = "1" /* Genital tract and pelvic infection following ectopic and molar pregnancy */
"O0882" = "1" /* Sepsis following ectopic and molar pregnancy */
"O2300" = "1" /* Infections of kidney in pregnancy, unspecified trimester */
"O2301" = "1" /* Infections of kidney in pregnancy, first trimester */
"O2302" = "1" /* Infections of kidney in pregnancy, second trimester */
"O2303" = "1" /* Infections of kidney in pregnancy, third trimester */
"O2310" = "1" /* Infections of bladder in pregnancy, unspecified trimester */
"O2311" = "1" /* Infections of bladder in pregnancy, first trimester */
"O2312" = "1" /* Infections of bladder in pregnancy, second trimester */
"O2313" = "1" /* Infections of bladder in pregnancy, third trimester */
"O2320" = "1" /* Infections of urethra in pregnancy, unspecified trimester */
"O2321" = "1" /* Infections of urethra in pregnancy, first trimester */
"O2322" = "1" /* Infections of urethra in pregnancy, second trimester */
"O2323" = "1" /* Infections of urethra in pregnancy, third trimester */
"O2330" = "1" /* Infections of other parts of urinary tract in pregnancy, unspecified trimester */
"O2331" = "1" /* Infections of other parts of urinary tract in pregnancy, first trimester */
"O2332" = "1" /* Infections of other parts of urinary tract in pregnancy, second trimester */
"O2333" = "1" /* Infections of other parts of urinary tract in pregnancy, third trimester */
"O2340" = "1" /* Unspecified infection of urinary tract in pregnancy, unspecified trimester */
"O2341" = "1" /* Unspecified infection of urinary tract in pregnancy, first trimester */
"O2342" = "1" /* Unspecified infection of urinary tract in pregnancy, second trimester */
"O2343" = "1" /* Unspecified infection of urinary tract in pregnancy, third trimester */
"O23511" = "1" /* Infections of cervix in pregnancy, first trimester */
"O23512" = "1" /* Infections of cervix in pregnancy, second trimester */
"O23513" = "1" /* Infections of cervix in pregnancy, third trimester */
"O23519" = "1" /* Infections of cervix in pregnancy, unspecified trimester */
"O23521" = "1" /* Salpingo-oophoritis in pregnancy, first trimester */
"O23522" = "1" /* Salpingo-oophoritis in pregnancy, second trimester */
"O23523" = "1" /* Salpingo-oophoritis in pregnancy, third trimester */
"O23529" = "1" /* Salpingo-oophoritis in pregnancy, unspecified trimester */
"O23591" = "1" /* Infection of other part of genital tract in pregnancy, first trimester */
"O23592" = "1" /* Infection of other part of genital tract in pregnancy, second trimester */
"O23593" = "1" /* Infection of other part of genital tract in pregnancy, third trimester */
"O23599" = "1" /* Infection of other part of genital tract in pregnancy, unspecified trimester */
"O2390" = "1" /* Unspecified genitourinary tract infection in pregnancy, unspecified trimester */
"O2391" = "1" /* Unspecified genitourinary tract infection in pregnancy, first trimester */
"O2392" = "1" /* Unspecified genitourinary tract infection in pregnancy, second trimester */
"O2393" = "1" /* Unspecified genitourinary tract infection in pregnancy, third trimester */
"O411010" = "1" /* Infection of amniotic sac and membranes, unspecified, first trimester, not applicable or unspecified */
"O411011" = "1" /* Infection of amniotic sac and membranes, unspecified, first trimester, fetus 1 */
"O411012" = "1" /* Infection of amniotic sac and membranes, unspecified, first trimester, fetus 2 */
"O411013" = "1" /* Infection of amniotic sac and membranes, unspecified, first trimester, fetus 3 */
"O411014" = "1" /* Infection of amniotic sac and membranes, unspecified, first trimester, fetus 4 */
"O411015" = "1" /* Infection of amniotic sac and membranes, unspecified, first trimester, fetus 5 */
"O411019" = "1" /* Infection of amniotic sac and membranes, unspecified, first trimester, other fetus */
"O411020" = "1" /* Infection of amniotic sac and membranes, unspecified, second trimester, not applicable or unspecified */
"O411021" = "1" /* Infection of amniotic sac and membranes, unspecified, second trimester, fetus 1 */
"O411022" = "1" /* Infection of amniotic sac and membranes, unspecified, second trimester, fetus 2 */
"O411023" = "1" /* Infection of amniotic sac and membranes, unspecified, second trimester, fetus 3 */
"O411024" = "1" /* Infection of amniotic sac and membranes, unspecified, second trimester, fetus 4 */
"O411025" = "1" /* Infection of amniotic sac and membranes, unspecified, second trimester, fetus 5 */
"O411029" = "1" /* Infection of amniotic sac and membranes, unspecified, second trimester, other fetus */
"O411030" = "1" /* Infection of amniotic sac and membranes, unspecified, third trimester, not applicable or unspecified */
"O411031" = "1" /* Infection of amniotic sac and membranes, unspecified, third trimester, fetus 1 */
"O411032" = "1" /* Infection of amniotic sac and membranes, unspecified, third trimester, fetus 2 */
"O411033" = "1" /* Infection of amniotic sac and membranes, unspecified, third trimester, fetus 3 */
"O411034" = "1" /* Infection of amniotic sac and membranes, unspecified, third trimester, fetus 4 */
"O411035" = "1" /* Infection of amniotic sac and membranes, unspecified, third trimester, fetus 5 */
"O411039" = "1" /* Infection of amniotic sac and membranes, unspecified, third trimester, other fetus */
"O411090" = "1" /* Infection of amniotic sac and membranes, unspecified, unspecified trimester, not applicable or unspecified */
"O411091" = "1" /* Infection of amniotic sac and membranes, unspecified, unspecified trimester, fetus 1 */
"O411092" = "1" /* Infection of amniotic sac and membranes, unspecified, unspecified trimester, fetus 2 */
"O411093" = "1" /* Infection of amniotic sac and membranes, unspecified, unspecified trimester, fetus 3 */
"O411094" = "1" /* Infection of amniotic sac and membranes, unspecified, unspecified trimester, fetus 4 */
"O411095" = "1" /* Infection of amniotic sac and membranes, unspecified, unspecified trimester, fetus 5 */
"O411099" = "1" /* Infection of amniotic sac and membranes, unspecified, unspecified trimester, other fetus */
"O411210" = "1" /* Chorioamnionitis, first trimester, not applicable or unspecified */
"O411211" = "1" /* Chorioamnionitis, first trimester, fetus 1 */
"O411212" = "1" /* Chorioamnionitis, first trimester, fetus 2 */
"O411213" = "1" /* Chorioamnionitis, first trimester, fetus 3 */
"O411214" = "1" /* Chorioamnionitis, first trimester, fetus 4 */
"O411215" = "1" /* Chorioamnionitis, first trimester, fetus 5 */
"O411219" = "1" /* Chorioamnionitis, first trimester, other fetus */
"O411220" = "1" /* Chorioamnionitis, second trimester, not applicable or unspecified */
"O411221" = "1" /* Chorioamnionitis, second trimester, fetus 1 */
"O411222" = "1" /* Chorioamnionitis, second trimester, fetus 2 */
"O411223" = "1" /* Chorioamnionitis, second trimester, fetus 3 */
"O411224" = "1" /* Chorioamnionitis, second trimester, fetus 4 */
"O411225" = "1" /* Chorioamnionitis, second trimester, fetus 5 */
"O411229" = "1" /* Chorioamnionitis, second trimester, other fetus */
"O411230" = "1" /* Chorioamnionitis, third trimester, not applicable or unspecified */
"O411231" = "1" /* Chorioamnionitis, third trimester, fetus 1 */
"O411232" = "1" /* Chorioamnionitis, third trimester, fetus 2 */
"O411233" = "1" /* Chorioamnionitis, third trimester, fetus 3 */
"O411234" = "1" /* Chorioamnionitis, third trimester, fetus 4 */
"O411235" = "1" /* Chorioamnionitis, third trimester, fetus 5 */
"O411239" = "1" /* Chorioamnionitis, third trimester, other fetus */
"O411290" = "1" /* Chorioamnionitis, unspecified trimester, not applicable or unspecified */
"O411291" = "1" /* Chorioamnionitis, unspecified trimester, fetus 1 */
"O411292" = "1" /* Chorioamnionitis, unspecified trimester, fetus 2 */
"O411293" = "1" /* Chorioamnionitis, unspecified trimester, fetus 3 */
"O411294" = "1" /* Chorioamnionitis, unspecified trimester, fetus 4 */
"O411295" = "1" /* Chorioamnionitis, unspecified trimester, fetus 5 */
"O411299" = "1" /* Chorioamnionitis, unspecified trimester, other fetus */
"O411410" = "1" /* Placentitis, first trimester, not applicable or unspecified */
"O411411" = "1" /* Placentitis, first trimester, fetus 1 */
"O411412" = "1" /* Placentitis, first trimester, fetus 2 */
"O411413" = "1" /* Placentitis, first trimester, fetus 3 */
"O411414" = "1" /* Placentitis, first trimester, fetus 4 */
"O411415" = "1" /* Placentitis, first trimester, fetus 5 */
"O411419" = "1" /* Placentitis, first trimester, other fetus */
"O411420" = "1" /* Placentitis, second trimester, not applicable or unspecified */
"O411421" = "1" /* Placentitis, second trimester, fetus 1 */
"O411422" = "1" /* Placentitis, second trimester, fetus 2 */
"O411423" = "1" /* Placentitis, second trimester, fetus 3 */
"O411424" = "1" /* Placentitis, second trimester, fetus 4 */
"O411425" = "1" /* Placentitis, second trimester, fetus 5 */
"O411429" = "1" /* Placentitis, second trimester, other fetus */
"O411430" = "1" /* Placentitis, third trimester, not applicable or unspecified */
"O411431" = "1" /* Placentitis, third trimester, fetus 1 */
"O411432" = "1" /* Placentitis, third trimester, fetus 2 */
"O411433" = "1" /* Placentitis, third trimester, fetus 3 */
"O411434" = "1" /* Placentitis, third trimester, fetus 4 */
"O411435" = "1" /* Placentitis, third trimester, fetus 5 */
"O411439" = "1" /* Placentitis, third trimester, other fetus */
"O411490" = "1" /* Placentitis, unspecified trimester, not applicable or unspecified */
"O411491" = "1" /* Placentitis, unspecified trimester, fetus 1 */
"O411492" = "1" /* Placentitis, unspecified trimester, fetus 2 */
"O411493" = "1" /* Placentitis, unspecified trimester, fetus 3 */
"O411494" = "1" /* Placentitis, unspecified trimester, fetus 4 */
"O411495" = "1" /* Placentitis, unspecified trimester, fetus 5 */
"O411499" = "1" /* Placentitis, unspecified trimester, other fetus */
"O85" = "1" /* Puerperal sepsis */
"O8611" = "1" /* Cervicitis following delivery */
"O8612" = "1" /* Endometritis following delivery */
"O8613" = "1" /* Vaginitis following delivery */
"O8619" = "1" /* Other infection of genital tract following delivery */
"O8620" = "1" /* Urinary tract infection following delivery, unspecified */
"O8621" = "1" /* Infection of kidney following delivery */
"O8622" = "1" /* Infection of bladder following delivery */
"O8629" = "1" /* Other urinary tract infection following delivery */
"O8681" = "1" /* Puerperal septic thrombophlebitis */
"O8689" = "1" /* Other specified puerperal infections */
"O9089" = "1" /* Other complications of the puerperium, not elsewhere classified */
"O91011" = "1" /* Infection of nipple associated with pregnancy, first trimester */
"O91012" = "1" /* Infection of nipple associated with pregnancy, second trimester */
"O91013" = "1" /* Infection of nipple associated with pregnancy, third trimester */
"O91019" = "1" /* Infection of nipple associated with pregnancy, unspecified trimester */
"O9102" = "1" /* Infection of nipple associated with the puerperium */
"O9103" = "1" /* Infection of nipple associated with lactation */
"O91111" = "1" /* Abscess of breast associated with pregnancy, first trimester */
"O91112" = "1" /* Abscess of breast associated with pregnancy, second trimester */
"O91113" = "1" /* Abscess of breast associated with pregnancy, third trimester */
"O91119" = "1" /* Abscess of breast associated with pregnancy, unspecified trimester */
"O9112" = "1" /* Abscess of breast associated with the puerperium */
"O9113" = "1" /* Abscess of breast associated with lactation */
"O9123" = "1" /* Nonpurulent mastitis associated with lactation */
"O98211" = "1" /* Gonorrhea complicating pregnancy, first trimester */
"O98212" = "1" /* Gonorrhea complicating pregnancy, second trimester */
"O98213" = "1" /* Gonorrhea complicating pregnancy, third trimester */
"O98219" = "1" /* Gonorrhea complicating pregnancy, unspecified trimester */
"O9822" = "1" /* Gonorrhea complicating childbirth */
"O9823" = "1" /* Gonorrhea complicating the puerperium */
"O98611" = "1" /* Protozoal diseases complicating pregnancy, first trimester */
"O98612" = "1" /* Protozoal diseases complicating pregnancy, second trimester */
"O98613" = "1" /* Protozoal diseases complicating pregnancy, third trimester */
"O98811" = "1" /* Other maternal infectious and parasitic diseases complicating pregnancy, first trimester */
"O98812" = "1" /* Other maternal infectious and parasitic diseases complicating pregnancy, second trimester */
"O98813" = "1" /* Other maternal infectious and parasitic diseases complicating pregnancy, third trimester */
"O98819" = "1" /* Other maternal infectious and parasitic diseases complicating pregnancy, unspecified trimester */
"O9882" = "1" /* Other maternal infectious and parasitic diseases complicating childbirth */
"O9883" = "1" /* Other maternal infectious and parasitic diseases complicating the puerperium */
"O98911" = "1" /* Unspecified maternal infectious and parasitic disease complicating pregnancy, first trimester */
"O98912" = "1" /* Unspecified maternal infectious and parasitic disease complicating pregnancy, second trimester */
"O98913" = "1" /* Unspecified maternal infectious and parasitic disease complicating pregnancy, third trimester */
"O98919" = "1" /* Unspecified maternal infectious and parasitic disease complicating pregnancy, unspecified trimester */
"O9892" = "1" /* Unspecified maternal infectious and parasitic disease complicating childbirth */
"O9893" = "1" /* Unspecified maternal infectious and parasitic disease complicating the puerperium */
"O99830" = "1" /* Other infection carrier state complicating pregnancy */
"O99834" = "1" /* Other infection carrier state complicating childbirth */
"O99835" = "1" /* Other infection carrier state complicating the puerperium */
"P360" = "1" /* Sepsis of newborn due to streptococcus, group B */
"P3610" = "1" /* Sepsis of newborn due to unspecified streptococci */
"P3619" = "1" /* Sepsis of newborn due to other streptococci */
"P362" = "1" /* Sepsis of newborn due to Staphylococcus aureus */
"P3630" = "1" /* Sepsis of newborn due to unspecified staphylococci */
"P3639" = "1" /* Sepsis of newborn due to other staphylococci */
"P364" = "1" /* Sepsis of newborn due to Escherichia coli */
"P365" = "1" /* Sepsis of newborn due to anaerobes */
"P368" = "1" /* Other bacterial sepsis of newborn */
"P369" = "1" /* Bacterial sepsis of newborn, unspecified */
"P381" = "1" /* Omphalitis with mild hemorrhage */
"P389" = "1" /* Omphalitis without hemorrhage */
"P390" = "1" /* Neonatal infective mastitis */
"P392" = "1" /* Intra-amniotic infection affecting newborn, not elsewhere classified */
"P393" = "1" /* Neonatal urinary tract infection */
"P394" = "1" /* Neonatal skin infection */
"P398" = "1" /* Other specified infections specific to the perinatal period */
"P399" = "1" /* Infection specific to the perinatal period, unspecified */
"P771" = "1" /* Stage 1 necrotizing enterocolitis in newborn */
"P772" = "1" /* Stage 2 necrotizing enterocolitis in newborn */
"P773" = "1" /* Stage 3 necrotizing enterocolitis in newborn */
"P779" = "1" /* Necrotizing enterocolitis in newborn, unspecified */
"R6510" = "1" /* Systemic inflammatory response syndrome (SIRS) of non-infectious origin without acute organ dysfunction */
"R6520" = "1" /* Severe sepsis without septic shock */
"R6521" = "1" /* Severe sepsis with septic shock */
"R7881" = "1" /* Bacteremia */
"T80211A" = "1" /* Bloodstream infection due to central venous catheter, initial encounter */
"T80212A" = "1" /* Local infection due to central venous catheter, initial encounter */
"T80218A" = "1" /* Other infection due to central venous catheter, initial encounter */
"T80219A" = "1" /* Unspecified infection due to central venous catheter, initial encounter */
"T8022XA" = "1" /* Acute infection following transfusion, infusion, or injection of blood and blood products, initial encounter */
"T8112XA" = "1" /* Postprocedural septic shock, initial encounter */
"T814XXA" = "1" /* Infection following a procedure, initial encounter */
"T826XXA" = "1" /* Infection and inflammatory reaction due to cardiac valve prosthesis, initial encounter */
"T827XXA" = "1" /* Infection and inflammatory reaction due to other cardiac and vascular devices, implants and grafts, initial encounter */
"T83510A" = "1" /* Infection and inflammatory reaction due to cystostomy catheter, initial encounter */
"T83511A" = "1" /* Infection and inflammatory reaction due to indwelling urethral catheter, initial encounter */
"T83512A" = "1" /* Infection and inflammatory reaction due to nephrostomy catheter, initial encounter */
"T83518A" = "1" /* Infection and inflammatory reaction due to other urinary catheter, initial encounter */
"T8351XA" = "1" /* Infection and inflammatory reaction due to indwelling urinary catheter, initial encounter */
"T83590A" = "1" /* Infection and inflammatory reaction due to implanted urinary neurostimulation device, initial encounter */
"T83591A" = "1" /* Infection and inflammatory reaction due to implanted urinary sphincter, initial encounter */
"T83592A" = "1" /* Infection and inflammatory reaction due to indwelling ureteral stent, initial encounter */
"T83593A" = "1" /* Infection and inflammatory reaction due to other urinary stents, initial encounter */
"T83598A" = "1" /* Infection and inflammatory reaction due to other prosthetic device, implant and graft in urinary system, initial encounter */
"T8359XA" = "1" /* Infection and inflammatory reaction due to prosthetic device, implant and graft in urinary system, initial encounter */
"T8361XA" = "1" /* Infection and inflammatory reaction due to implanted penile prosthesis, initial encounter */
"T8362XA" = "1" /* Infection and inflammatory reaction due to implanted testicular prosthesis, initial encounter */
"T8369XA" = "1" /* Infection and inflammatory reaction due to other prosthetic device, implant and graft in genital tract, initial encounter */
"T836XXA" = "1" /* Infection and inflammatory reaction due to prosthetic device, implant and graft in genital tract, initial encounter */
"T8450XA" = "1" /* Infection and inflammatory reaction due to unspecified internal joint prosthesis, initial encounter */
"T8451XA" = "1" /* Infection and inflammatory reaction due to internal right hip prosthesis, initial encounter */
"T8452XA" = "1" /* Infection and inflammatory reaction due to internal left hip prosthesis, initial encounter */
"T8453XA" = "1" /* Infection and inflammatory reaction due to internal right knee prosthesis, initial encounter */
"T8454XA" = "1" /* Infection and inflammatory reaction due to internal left knee prosthesis, initial encounter */
"T8459XA" = "1" /* Infection and inflammatory reaction due to other internal joint prosthesis, initial encounter */
"T8460XA" = "1" /* Infection and inflammatory reaction due to internal fixation device of unspecified site, initial encounter */
"T84610A" = "1" /* Infection and inflammatory reaction due to internal fixation device of right humerus, initial encounter */
"T84611A" = "1" /* Infection and inflammatory reaction due to internal fixation device of left humerus, initial encounter */
"T84612A" = "1" /* Infection and inflammatory reaction due to internal fixation device of right radius, initial encounter */
"T84613A" = "1" /* Infection and inflammatory reaction due to internal fixation device of left radius, initial encounter */
"T84614A" = "1" /* Infection and inflammatory reaction due to internal fixation device of right ulna, initial encounter */
"T84615A" = "1" /* Infection and inflammatory reaction due to internal fixation device of left ulna, initial encounter */
"T84619A" = "1" /* Infection and inflammatory reaction due to internal fixation device of unspecified bone of arm, initial encounter */
"T84620A" = "1" /* Infection and inflammatory reaction due to internal fixation device of right femur, initial encounter */
"T84621A" = "1" /* Infection and inflammatory reaction due to internal fixation device of left femur, initial encounter */
"T84622A" = "1" /* Infection and inflammatory reaction due to internal fixation device of right tibia, initial encounter */
"T84623A" = "1" /* Infection and inflammatory reaction due to internal fixation device of left tibia, initial encounter */
"T84624A" = "1" /* Infection and inflammatory reaction due to internal fixation device of right fibula, initial encounter */
"T84625A" = "1" /* Infection and inflammatory reaction due to internal fixation device of left fibula, initial encounter */
"T84629A" = "1" /* Infection and inflammatory reaction due to internal fixation device of unspecified bone of leg, initial encounter */
"T8463XA" = "1" /* Infection and inflammatory reaction due to internal fixation device of spine, initial encounter */
"T8469XA" = "1" /* Infection and inflammatory reaction due to internal fixation device of other site, initial encounter */
"T847XXA" = "1" /* Infection and inflammatory reaction due to other internal orthopedic prosthetic devices, implants and grafts, initial encounter */
"T8572XA" = "1" /* Infection and inflammatory reaction due to insulin pump, initial encounter */
"T85730A" = "1" /* Infection and inflammatory reaction due to ventricular intracranial (communicating) shunt, initial encounter */
"T85731A" = "1" /* Infection and inflammatory reaction due to implanted electronic neurostimulator of brain, electrode (lead), initial encounter */
"T85732A" = "1" /* Infection and inflammatory reaction due to implanted electronic neurostimulator of peripheral nerve, electrode (lead), initial */
"T85733A" = "1" /* Infection and inflammatory reaction due to implanted electronic neurostimulator of spinal cord, electrode (lead), initial encou */
"T85734A" = "1" /* Infection and inflammatory reaction due to implanted electronic neurostimulator, generator, initial encounter */
"T85735A" = "1" /* Infection and inflammatory reaction due to cranial or spinal infusion catheter, initial encounter */
"T85738A" = "1" /* Infection and inflammatory reaction due to other nervous system device, implant or graft, initial encounter */
"T8579XA" = "1" /* Infection and inflammatory reaction due to other internal prosthetic devices, implants and grafts, initial encounter */
"T86842" = "1" /* Corneal transplant infection */
"T8740" = "1" /* Infection of amputation stump, unspecified extremity */
"T8741" = "1" /* Infection of amputation stump, right upper extremity */
"T8742" = "1" /* Infection of amputation stump, left upper extremity */
"T8743" = "1" /* Infection of amputation stump, right lower extremity */
"T8744" = "1" /* Infection of amputation stump, left lower extremity */
Other = "0"
;

/* Diagnosis codeset KIDNEY last updated 161203 for ICD10 v70rev0 */
Value $KIDNEY
"N110" = "1" /* Nonobstructive reflux-associated chronic pyelonephritis */
"N111" = "1" /* Chronic obstructive pyelonephritis */
"N118" = "1" /* Other chronic tubulo-interstitial nephritis */
"N119" = "1" /* Chronic tubulo-interstitial nephritis, unspecified */
"N130" = "1" /* Hydronephrosis with ureteropelvic junction obstruction */
"N136" = "1" /* Pyonephrosis */
"N1370" = "1" /* Vesicoureteral-reflux, unspecified */
"N1371" = "1" /* Vesicoureteral-reflux without reflux nephropathy */
"N13721" = "1" /* Vesicoureteral-reflux with reflux nephropathy without hydroureter, unilateral */
"N13722" = "1" /* Vesicoureteral-reflux with reflux nephropathy without hydroureter, bilateral */
"N13729" = "1" /* Vesicoureteral-reflux with reflux nephropathy without hydroureter, unspecified */
"N13731" = "1" /* Vesicoureteral-reflux with reflux nephropathy with hydroureter, unilateral */
"N13732" = "1" /* Vesicoureteral-reflux with reflux nephropathy with hydroureter, bilateral */
"N13739" = "1" /* Vesicoureteral-reflux with reflux nephropathy with hydroureter, unspecified */
"N139" = "1" /* Obstructive and reflux uropathy, unspecified */
"Q600" = "1" /* Renal agenesis, unilateral */
"Q601" = "1" /* Renal agenesis, bilateral */
"Q602" = "1" /* Renal agenesis, unspecified */
"Q603" = "1" /* Renal hypoplasia, unilateral */
"Q604" = "1" /* Renal hypoplasia, bilateral */
"Q605" = "1" /* Renal hypoplasia, unspecified */
"Q606" = "1" /* Potter's syndrome */
"Q6100" = "1" /* Congenital renal cyst, unspecified */
"Q6101" = "1" /* Congenital single renal cyst */
"Q6102" = "1" /* Congenital multiple renal cysts */
"Q6111" = "1" /* Cystic dilatation of collecting ducts */
"Q6119" = "1" /* Other polycystic kidney, infantile type */
"Q612" = "1" /* Polycystic kidney, adult type */
"Q613" = "1" /* Polycystic kidney, unspecified */
"Q614" = "1" /* Renal dysplasia */
"Q615" = "1" /* Medullary cystic kidney */
"Q618" = "1" /* Other cystic kidney diseases */
"Q619" = "1" /* Cystic kidney disease, unspecified */
"Q620" = "1" /* Congenital hydronephrosis */
"Q6210" = "1" /* Congenital occlusion of ureter, unspecified */
"Q6211" = "1" /* Congenital occlusion of ureteropelvic junction */
"Q6212" = "1" /* Congenital occlusion of ureterovesical orifice */
"Q622" = "1" /* Congenital megaureter */
"Q6231" = "1" /* Congenital ureterocele, orthotopic */
"Q6232" = "1" /* Cecoureterocele */
"Q6239" = "1" /* Other obstructive defects of renal pelvis and ureter */
"Q624" = "1" /* Agenesis of ureter */
"Q625" = "1" /* Duplication of ureter */
"Q6260" = "1" /* Malposition of ureter, unspecified */
"Q6261" = "1" /* Deviation of ureter */
"Q6262" = "1" /* Displacement of ureter */
"Q6263" = "1" /* Anomalous implantation of ureter */
"Q6269" = "1" /* Other malposition of ureter */
"Q627" = "1" /* Congenital vesico-uretero-renal reflux */
"Q628" = "1" /* Other congenital malformations of ureter */
"Q630" = "1" /* Accessory kidney */
"Q631" = "1" /* Lobulated, fused and horseshoe kidney */
"Q632" = "1" /* Ectopic kidney */
"Q633" = "1" /* Hyperplastic and giant kidney */
"Q638" = "1" /* Other specified congenital malformations of kidney */
"Q639" = "1" /* Congenital malformation of kidney, unspecified */
"Q6410" = "1" /* Exstrophy of urinary bladder, unspecified */
"Q6411" = "1" /* Supravesical fissure of urinary bladder */
"Q6412" = "1" /* Cloacal extrophy of urinary bladder */
"Q6419" = "1" /* Other exstrophy of urinary bladder */
"Q642" = "1" /* Congenital posterior urethral valves */
"Q6431" = "1" /* Congenital bladder neck obstruction */
"Q6432" = "1" /* Congenital stricture of urethra */
"Q6433" = "1" /* Congenital stricture of urinary meatus */
"Q6439" = "1" /* Other atresia and stenosis of urethra and bladder neck */
"Q645" = "1" /* Congenital absence of bladder and urethra */
"Q646" = "1" /* Congenital diverticulum of bladder */
"Q6470" = "1" /* Unspecified congenital malformation of bladder and urethra */
"Q6471" = "1" /* Congenital prolapse of urethra */
"Q6472" = "1" /* Congenital prolapse of urinary meatus */
"Q6473" = "1" /* Congenital urethrorectal fistula */
"Q6474" = "1" /* Double urethra */
"Q6475" = "1" /* Double urinary meatus */
"Q6479" = "1" /* Other congenital malformations of bladder and urethra */
"Q648" = "1" /* Other specified congenital malformations of urinary system */
"Q649" = "1" /* Congenital malformation of urinary system, unspecified */
Other = "0"
;

/* Diagnosis codeset POHMRI2D last updated 170530 for ICD10 v70rev2 */
Value $POHMRI2D
"D7821" = "1" /* Postprocedural hemorrhage of the spleen following a procedure on the spleen */
"D7822" = "1" /* Postprocedural hemorrhage of the spleen following other procedure */
"D7831" = "1" /* Postprocedural hematoma of the spleen following a procedure on the spleen */
"D7832" = "1" /* Postprocedural hematoma of the spleen following other procedure */
"E89810" = "1" /* Postprocedural hemorrhage of an endocrine system organ or structure following an endocrine system procedure */
"E89811" = "1" /* Postprocedural hemorrhage of an endocrine system organ or structure following other procedure */
"E89820" = "1" /* Postprocedural hematoma of an endocrine system organ or structure following an endocrine system procedure */
"E89821" = "1" /* Postprocedural hematoma of an endocrine system organ or structure following other procedure */
"G9751" = "1" /* Postprocedural hemorrhage of a nervous system organ or structure following a nervous system procedure */
"G9752" = "1" /* Postprocedural hemorrhage of a nervous system organ or structure following other procedure */
"G9761" = "1" /* Postprocedural hematoma of a nervous system organ or structure following a nervous system procedure */
"G9762" = "1" /* Postprocedural hematoma of a nervous system organ or structure following other procedure */
"H59311" = "1" /* Postprocedural hemorrhage of right eye and adnexa following an ophthalmic procedure */
"H59312" = "1" /* Postprocedural hemorrhage of left eye and adnexa following an ophthalmic procedure */
"H59313" = "1" /* Postprocedural hemorrhage of eye and adnexa following an ophthalmic procedure, bilateral */
"H59319" = "1" /* Postprocedural hemorrhage of unspecified eye and adnexa following an ophthalmic procedure */
"H59321" = "1" /* Postprocedural hemorrhage of right eye and adnexa following other procedure */
"H59322" = "1" /* Postprocedural hemorrhage of left eye and adnexa following other procedure */
"H59323" = "1" /* Postprocedural hemorrhage of eye and adnexa following other procedure, bilateral */
"H59329" = "1" /* Postprocedural hemorrhage of unspecified eye and adnexa following other procedure */
"H59331" = "1" /* Postprocedural hematoma of right eye and adnexa following an ophthalmic procedure */
"H59332" = "1" /* Postprocedural hematoma of left eye and adnexa following an ophthalmic procedure */
"H59333" = "1" /* Postprocedural hematoma of eye and adnexa following an ophthalmic procedure, bilateral */
"H59339" = "1" /* Postprocedural hematoma of unspecified eye and adnexa following an ophthalmic procedure */
"H59341" = "1" /* Postprocedural hematoma of right eye and adnexa following other procedure */
"H59342" = "1" /* Postprocedural hematoma of left eye and adnexa following other procedure */
"H59343" = "1" /* Postprocedural hematoma of eye and adnexa following other procedure, bilateral */
"H59349" = "1" /* Postprocedural hematoma of unspecified eye and adnexa following other procedure */
"H9541" = "1" /* Postprocedural hemorrhage of ear and mastoid process following a procedure on the ear and mastoid process */
"H9542" = "1" /* Postprocedural hemorrhage of ear and mastoid process following other procedure */
"H9551" = "1" /* Postprocedural hematoma of ear and mastoid process following a procedure on the ear and mastoid process */
"H9552" = "1" /* Postprocedural hematoma of ear and mastoid process following other procedure */
"I97610" = "1" /* Postprocedural hemorrhage of a circulatory system organ or structure following a cardiac catheterization */
"I97611" = "1" /* Postprocedural hemorrhage of a circulatory system organ or structure following cardiac bypass */
"I97618" = "1" /* Postprocedural hemorrhage of a circulatory system organ or structure following other circulatory system procedure */
"I9762" = "1" /* Postprocedural hemorrhage and hematoma of a circulatory system organ or structure following other procedure */
"I97620" = "1" /* Postprocedural hemorrhage of a circulatory system organ or structure following other procedure */
"I97621" = "1" /* Postprocedural hematoma of a circulatory system organ or structure following other procedure */
"I97630" = "1" /* Postprocedural hematoma of a circulatory system organ or structure following a cardiac catheterization */
"I97631" = "1" /* Postprocedural hematoma of a circulatory system organ or structure following cardiac bypass */
"I97638" = "1" /* Postprocedural hematoma of a circulatory system organ or structure following other circulatory system procedure */
"J95830" = "1" /* Postprocedural hemorrhage of a respiratory system organ or structure following a respiratory system procedure */
"J95831" = "1" /* Postprocedural hemorrhage of a respiratory system organ or structure following other procedure */
"J95860" = "1" /* Postprocedural hematoma of a respiratory system organ or structure following a respiratory system procedure */
"J95861" = "1" /* Postprocedural hematoma of a respiratory system organ or structure following other procedure */
"K91840" = "1" /* Postprocedural hemorrhage of a digestive system organ or structure following a digestive system procedure */
"K91841" = "1" /* Postprocedural hemorrhage of a digestive system organ or structure following other procedure */
"K91870" = "1" /* Postprocedural hematoma of a digestive system organ or structure following a digestive system procedure */
"K91871" = "1" /* Postprocedural hematoma of a digestive system organ or structure following other procedure */
"L7621" = "1" /* Postprocedural hemorrhage of skin and subcutaneous tissue following a dermatologic procedure */
"L7622" = "1" /* Postprocedural hemorrhage of skin and subcutaneous tissue following other procedure */
"L7631" = "1" /* Postprocedural hematoma of skin and subcutaneous tissue following a dermatologic procedure */
"L7632" = "1" /* Postprocedural hematoma of skin and subcutaneous tissue following other procedure */
"M96830" = "1" /* Postprocedural hemorrhage of a musculoskeletal structure following a musculoskeletal system procedure */
"M96831" = "1" /* Postprocedural hemorrhage of a musculoskeletal structure following other procedure */
"M96840" = "1" /* Postprocedural hematoma of a musculoskeletal structure following a musculoskeletal system procedure */
"M96841" = "1" /* Postprocedural hematoma of a musculoskeletal structure following other procedure */
"N99820" = "1" /* Postprocedural hemorrhage of a genitourinary system organ or structure following a genitourinary system procedure */
"N99821" = "1" /* Postprocedural hemorrhage of a genitourinary system organ or structure following other procedure */
"N99840" = "1" /* Postprocedural hematoma of a genitourinary system organ or structure following a genitourinary system procedure */
"N99841" = "1" /* Postprocedural hematoma of a genitourinary system organ or structure following other procedure */
Other = "0"
;

/* Diagnosis codeset RESPAN last updated 161201 for ICD10 v70rev0 */
Value $RESPAN
"E840" = "1" /* Cystic fibrosis with pulmonary manifestations */
"E8411" = "1" /* Meconium ileus in cystic fibrosis */
"E8419" = "1" /* Cystic fibrosis with other intestinal manifestations */
"E848" = "1" /* Cystic fibrosis with other manifestations */
"E849" = "1" /* Cystic fibrosis, unspecified */
"J8483" = "1" /* Surfactant mutations of the lung */
"J84841" = "1" /* Neuroendocrine cell hyperplasia of infancy */
"J84842" = "1" /* Pulmonary interstitial glycogenosis */
"J84843" = "1" /* Alveolar capillary dysplasia with vein misalignment */
"J84848" = "1" /* Other interstitial  lung diseases of childhood */
"P270" = "1" /* Wilson-Mikity syndrome */
"P271" = "1" /* Bronchopulmonary dysplasia originating in the perinatal period */
"P278" = "1" /* Other chronic respiratory diseases originating in the perinatal period */
"P279" = "1" /* Unspecified chronic respiratory disease originating in the perinatal period */
"Q254" = "1"  /*Other Congenital Malformations Of Aorta */
"Q2545" = "1" /* Double aortic arch */
"Q2547" = "1" /* Right aortic arch */
"Q2548" = "1" /* Anomalous origin of subclavian artery */
"Q311" = "1" /* Congenital subglottic stenosis */
"Q312" = "1" /* Laryngeal hypoplasia */
"Q313" = "1" /* Laryngocele */
"Q315" = "1" /* Congenital laryngomalacia */
"Q318" = "1" /* Other congenital malformations of larynx */
"Q319" = "1" /* Congenital malformation of larynx, unspecified */
"Q320" = "1" /* Congenital tracheomalacia */
"Q321" = "1" /* Other congenital malformations of trachea */
"Q322" = "1" /* Congenital bronchomalacia */
"Q323" = "1" /* Congenital stenosis of bronchus */
"Q324" = "1" /* Other congenital malformations of bronchus */
"Q330" = "1" /* Congenital cystic lung */
"Q331" = "1" /* Accessory lobe of lung */
"Q332" = "1" /* Sequestration of lung */
"Q333" = "1" /* Agenesis of lung */
"Q334" = "1" /* Congenital bronchiectasis */
"Q335" = "1" /* Ectopic tissue in lung */
"Q336" = "1" /* Congenital hypoplasia and dysplasia of lung */
"Q338" = "1" /* Other congenital malformations of lung */
"Q339" = "1" /* Congenital malformation of lung, unspecified */
"Q340" = "1" /* Anomaly of pleura */
"Q341" = "1" /* Congenital cyst of mediastinum */
"Q348" = "1" /* Other specified congenital malformations of respiratory system */
"Q349" = "1" /* Congenital malformation of respiratory system, unspecified */
"Q390" = "1" /* Atresia of esophagus without fistula */
"Q391" = "1" /* Atresia of esophagus with tracheo-esophageal fistula */
"Q392" = "1" /* Congenital tracheo-esophageal fistula without atresia */
"Q393" = "1" /* Congenital stenosis and stricture of esophagus */
"Q394" = "1" /* Esophageal web */
"Q893" = "1" /* Situs inversus */
Other = "0"
;

/* Procedure codeset ABDOMIPOPEN last updated 161201 for ICD10 v70rev0 */
Value $ABDOMIPOPEN
"008Q0ZZ" = "1" /* Division of Vagus Nerve, Open Approach */
"01590ZZ" = "1" /* Destruction of Lumbar Plexus, Open Approach */
"015A0ZZ" = "1" /* Destruction of Lumbosacral Plexus, Open Approach */
"015B0ZZ" = "1" /* Destruction of Lumbar Nerve, Open Approach */
"015C0ZZ" = "1" /* Destruction of Pudendal Nerve, Open Approach */
"015M0ZZ" = "1" /* Destruction of Abdominal Sympathetic Nerve, Open Approach */
"015N0ZZ" = "1" /* Destruction of Lumbar Sympathetic Nerve, Open Approach */
"015P0ZZ" = "1" /* Destruction of Sacral Sympathetic Nerve, Open Approach */
"015Q0ZZ" = "1" /* Destruction of Sacral Plexus, Open Approach */
"015R0ZZ" = "1" /* Destruction of Sacral Nerve, Open Approach */
"01890ZZ" = "1" /* Division of Lumbar Plexus, Open Approach */
"018A0ZZ" = "1" /* Division of Lumbosacral Plexus, Open Approach */
"018B0ZZ" = "1" /* Division of Lumbar Nerve, Open Approach */
"018C0ZZ" = "1" /* Division of Pudendal Nerve, Open Approach */
"018M0ZZ" = "1" /* Division of Abdominal Sympathetic Nerve, Open Approach */
"018N0ZZ" = "1" /* Division of Lumbar Sympathetic Nerve, Open Approach */
"018P0ZZ" = "1" /* Division of Sacral Sympathetic Nerve, Open Approach */
"018Q0ZZ" = "1" /* Division of Sacral Plexus, Open Approach */
"018R0ZZ" = "1" /* Division of Sacral Nerve, Open Approach */
"019900Z" = "1" /* Drainage of Lumbar Plexus with Drainage Device, Open Approach */
"01990ZX" = "1" /* Drainage of Lumbar Plexus, Open Approach, Diagnostic */
"01990ZZ" = "1" /* Drainage of Lumbar Plexus, Open Approach */
"019A00Z" = "1" /* Drainage of Lumbosacral Plexus with Drainage Device, Open Approach */
"019A0ZX" = "1" /* Drainage of Lumbosacral Plexus, Open Approach, Diagnostic */
"019A0ZZ" = "1" /* Drainage of Lumbosacral Plexus, Open Approach */
"019B00Z" = "1" /* Drainage of Lumbar Nerve with Drainage Device, Open Approach */
"019B0ZX" = "1" /* Drainage of Lumbar Nerve, Open Approach, Diagnostic */
"019B0ZZ" = "1" /* Drainage of Lumbar Nerve, Open Approach */
"019C00Z" = "1" /* Drainage of Pudendal Nerve with Drainage Device, Open Approach */
"019C0ZX" = "1" /* Drainage of Pudendal Nerve, Open Approach, Diagnostic */
"019C0ZZ" = "1" /* Drainage of Pudendal Nerve, Open Approach */
"019M00Z" = "1" /* Drainage of Abdominal Sympathetic Nerve with Drainage Device, Open Approach */
"019M0ZX" = "1" /* Drainage of Abdominal Sympathetic Nerve, Open Approach, Diagnostic */
"019M0ZZ" = "1" /* Drainage of Abdominal Sympathetic Nerve, Open Approach */
"019N00Z" = "1" /* Drainage of Lumbar Sympathetic Nerve with Drainage Device, Open Approach */
"019N0ZX" = "1" /* Drainage of Lumbar Sympathetic Nerve, Open Approach, Diagnostic */
"019N0ZZ" = "1" /* Drainage of Lumbar Sympathetic Nerve, Open Approach */
"019P00Z" = "1" /* Drainage of Sacral Sympathetic Nerve with Drainage Device, Open Approach */
"019P0ZX" = "1" /* Drainage of Sacral Sympathetic Nerve, Open Approach, Diagnostic */
"019P0ZZ" = "1" /* Drainage of Sacral Sympathetic Nerve, Open Approach */
"019Q00Z" = "1" /* Drainage of Sacral Plexus with Drainage Device, Open Approach */
"019Q0ZX" = "1" /* Drainage of Sacral Plexus, Open Approach, Diagnostic */
"019Q0ZZ" = "1" /* Drainage of Sacral Plexus, Open Approach */
"019R00Z" = "1" /* Drainage of Sacral Nerve with Drainage Device, Open Approach */
"019R0ZX" = "1" /* Drainage of Sacral Nerve, Open Approach, Diagnostic */
"019R0ZZ" = "1" /* Drainage of Sacral Nerve, Open Approach */
"01B90ZX" = "1" /* Excision of Lumbar Plexus, Open Approach, Diagnostic */
"01B90ZZ" = "1" /* Excision of Lumbar Plexus, Open Approach */
"01BA0ZX" = "1" /* Excision of Lumbosacral Plexus, Open Approach, Diagnostic */
"01BA0ZZ" = "1" /* Excision of Lumbosacral Plexus, Open Approach */
"01BB0ZX" = "1" /* Excision of Lumbar Nerve, Open Approach, Diagnostic */
"01BB0ZZ" = "1" /* Excision of Lumbar Nerve, Open Approach */
"01BC0ZX" = "1" /* Excision of Pudendal Nerve, Open Approach, Diagnostic */
"01BC0ZZ" = "1" /* Excision of Pudendal Nerve, Open Approach */
"01BM0ZX" = "1" /* Excision of Abdominal Sympathetic Nerve, Open Approach, Diagnostic */
"01BM0ZZ" = "1" /* Excision of Abdominal Sympathetic Nerve, Open Approach */
"01BN0ZX" = "1" /* Excision of Lumbar Sympathetic Nerve, Open Approach, Diagnostic */
"01BN0ZZ" = "1" /* Excision of Lumbar Sympathetic Nerve, Open Approach */
"01BP0ZX" = "1" /* Excision of Sacral Sympathetic Nerve, Open Approach, Diagnostic */
"01BP0ZZ" = "1" /* Excision of Sacral Sympathetic Nerve, Open Approach */
"01BQ0ZX" = "1" /* Excision of Sacral Plexus, Open Approach, Diagnostic */
"01BQ0ZZ" = "1" /* Excision of Sacral Plexus, Open Approach */
"01BR0ZX" = "1" /* Excision of Sacral Nerve, Open Approach, Diagnostic */
"01BR0ZZ" = "1" /* Excision of Sacral Nerve, Open Approach */
"01C90ZZ" = "1" /* Extirpation of Matter from Lumbar Plexus, Open Approach */
"01CA0ZZ" = "1" /* Extirpation of Matter from Lumbosacral Plexus, Open Approach */
"01CB0ZZ" = "1" /* Extirpation of Matter from Lumbar Nerve, Open Approach */
"01CC0ZZ" = "1" /* Extirpation of Matter from Pudendal Nerve, Open Approach */
"01CM0ZZ" = "1" /* Extirpation of Matter from Abdominal Sympathetic Nerve, Open Approach */
"01CN0ZZ" = "1" /* Extirpation of Matter from Lumbar Sympathetic Nerve, Open Approach */
"01CP0ZZ" = "1" /* Extirpation of Matter from Sacral Sympathetic Nerve, Open Approach */
"01CQ0ZZ" = "1" /* Extirpation of Matter from Sacral Plexus, Open Approach */
"01CR0ZZ" = "1" /* Extirpation of Matter from Sacral Nerve, Open Approach */
"01D90ZZ" = "1" /* Extraction of Lumbar Plexus, Open Approach */
"01DA0ZZ" = "1" /* Extraction of Lumbosacral Plexus, Open Approach */
"01DB0ZZ" = "1" /* Extraction of Lumbar Nerve, Open Approach */
"01DC0ZZ" = "1" /* Extraction of Pudendal Nerve, Open Approach */
"01DM0ZZ" = "1" /* Extraction of Abdominal Sympathetic Nerve, Open Approach */
"01DN0ZZ" = "1" /* Extraction of Lumbar Sympathetic Nerve, Open Approach */
"01DP0ZZ" = "1" /* Extraction of Sacral Sympathetic Nerve, Open Approach */
"01DQ0ZZ" = "1" /* Extraction of Sacral Plexus, Open Approach */
"01DR0ZZ" = "1" /* Extraction of Sacral Nerve, Open Approach */
"01N90ZZ" = "1" /* Release Lumbar Plexus, Open Approach */
"01NA0ZZ" = "1" /* Release Lumbosacral Plexus, Open Approach */
"01NB0ZZ" = "1" /* Release Lumbar Nerve, Open Approach */
"01NC0ZZ" = "1" /* Release Pudendal Nerve, Open Approach */
"01NM0ZZ" = "1" /* Release Abdominal Sympathetic Nerve, Open Approach */
"01NN0ZZ" = "1" /* Release Lumbar Sympathetic Nerve, Open Approach */
"01NP0ZZ" = "1" /* Release Sacral Sympathetic Nerve, Open Approach */
"01NQ0ZZ" = "1" /* Release Sacral Plexus, Open Approach */
"01NR0ZZ" = "1" /* Release Sacral Nerve, Open Approach */
"01Q90ZZ" = "1" /* Repair Lumbar Plexus, Open Approach */
"01QA0ZZ" = "1" /* Repair Lumbosacral Plexus, Open Approach */
"01QB0ZZ" = "1" /* Repair Lumbar Nerve, Open Approach */
"01QC0ZZ" = "1" /* Repair Pudendal Nerve, Open Approach */
"01QM0ZZ" = "1" /* Repair Abdominal Sympathetic Nerve, Open Approach */
"01QN0ZZ" = "1" /* Repair Lumbar Sympathetic Nerve, Open Approach */
"01QP0ZZ" = "1" /* Repair Sacral Sympathetic Nerve, Open Approach */
"01QQ0ZZ" = "1" /* Repair Sacral Plexus, Open Approach */
"01QR0ZZ" = "1" /* Repair Sacral Nerve, Open Approach */
"01S90ZZ" = "1" /* Reposition Lumbar Plexus, Open Approach */
"01SA0ZZ" = "1" /* Reposition Lumbosacral Plexus, Open Approach */
"01SB0ZZ" = "1" /* Reposition Lumbar Nerve, Open Approach */
"01SC0ZZ" = "1" /* Reposition Pudendal Nerve, Open Approach */
"01SQ0ZZ" = "1" /* Reposition Sacral Plexus, Open Approach */
"01SR0ZZ" = "1" /* Reposition Sacral Nerve, Open Approach */
"01UB07Z" = "1" /* Supplement Lumbar Nerve with Autologous Tissue Substitute, Open Approach */
"01UC07Z" = "1" /* Supplement Pudendal Nerve with Autologous Tissue Substitute, Open Approach */
"01UR07Z" = "1" /* Supplement Sacral Nerve with Autologous Tissue Substitute, Open Approach */
"01XB0ZB" = "1" /* Transfer Lumbar Nerve to Lumbar Nerve, Open Approach */
"01XB0ZC" = "1" /* Transfer Lumbar Nerve to Perineal Nerve, Open Approach */
"01XC0ZB" = "1" /* Transfer Pudendal Nerve to Lumbar Nerve, Open Approach */
"01XC0ZC" = "1" /* Transfer Pudendal Nerve to Perineal Nerve, Open Approach */
"0410090" = "1" /* Bypass Abdominal Aorta to Abdominal Aorta with Autologous Venous Tissue, Open Approach */
"0410091" = "1" /* Bypass Abdominal Aorta to Celiac Artery with Autologous Venous Tissue, Open Approach */
"0410092" = "1" /* Bypass Abdominal Aorta to Mesenteric Artery with Autologous Venous Tissue, Open Approach */
"0410093" = "1" /* Bypass Abdominal Aorta to Right Renal Artery with Autologous Venous Tissue, Open Approach */
"0410094" = "1" /* Bypass Abdominal Aorta to Left Renal Artery with Autologous Venous Tissue, Open Approach */
"0410095" = "1" /* Bypass Abdominal Aorta to Bilateral Renal Artery with Autologous Venous Tissue, Open Approach */
"0410096" = "1" /* Bypass Abdominal Aorta to Right Common Iliac Artery with Autologous Venous Tissue, Open Approach */
"0410097" = "1" /* Bypass Abdominal Aorta to Left Common Iliac Artery with Autologous Venous Tissue, Open Approach */
"0410098" = "1" /* Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Autologous Venous Tissue, Open Approach */
"0410099" = "1" /* Bypass Abdominal Aorta to Right Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041009B" = "1" /* Bypass Abdominal Aorta to Left Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041009C" = "1" /* Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041009D" = "1" /* Bypass Abdominal Aorta to Right External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041009F" = "1" /* Bypass Abdominal Aorta to Left External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041009G" = "1" /* Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041009H" = "1" /* Bypass Abdominal Aorta to Right Femoral Artery with Autologous Venous Tissue, Open Approach */
"041009J" = "1" /* Bypass Abdominal Aorta to Left Femoral Artery with Autologous Venous Tissue, Open Approach */
"041009K" = "1" /* Bypass Abdominal Aorta to Bilateral Femoral Arteries with Autologous Venous Tissue, Open Approach */
"041009Q" = "1" /* Bypass Abdominal Aorta to Lower Extremity Artery with Autologous Venous Tissue, Open Approach */
"041009R" = "1" /* Bypass Abdominal Aorta to Lower Artery with Autologous Venous Tissue, Open Approach */
"04100A0" = "1" /* Bypass Abdominal Aorta to Abdominal Aorta with Autologous Arterial Tissue, Open Approach */
"04100A1" = "1" /* Bypass Abdominal Aorta to Celiac Artery with Autologous Arterial Tissue, Open Approach */
"04100A2" = "1" /* Bypass Abdominal Aorta to Mesenteric Artery with Autologous Arterial Tissue, Open Approach */
"04100A3" = "1" /* Bypass Abdominal Aorta to Right Renal Artery with Autologous Arterial Tissue, Open Approach */
"04100A4" = "1" /* Bypass Abdominal Aorta to Left Renal Artery with Autologous Arterial Tissue, Open Approach */
"04100A5" = "1" /* Bypass Abdominal Aorta to Bilateral Renal Artery with Autologous Arterial Tissue, Open Approach */
"04100A6" = "1" /* Bypass Abdominal Aorta to Right Common Iliac Artery with Autologous Arterial Tissue, Open Approach */
"04100A7" = "1" /* Bypass Abdominal Aorta to Left Common Iliac Artery with Autologous Arterial Tissue, Open Approach */
"04100A8" = "1" /* Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"04100A9" = "1" /* Bypass Abdominal Aorta to Right Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"04100AB" = "1" /* Bypass Abdominal Aorta to Left Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"04100AC" = "1" /* Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"04100AD" = "1" /* Bypass Abdominal Aorta to Right External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"04100AF" = "1" /* Bypass Abdominal Aorta to Left External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"04100AG" = "1" /* Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"04100AH" = "1" /* Bypass Abdominal Aorta to Right Femoral Artery with Autologous Arterial Tissue, Open Approach */
"04100AJ" = "1" /* Bypass Abdominal Aorta to Left Femoral Artery with Autologous Arterial Tissue, Open Approach */
"04100AK" = "1" /* Bypass Abdominal Aorta to Bilateral Femoral Arteries with Autologous Arterial Tissue, Open Approach */
"04100AQ" = "1" /* Bypass Abdominal Aorta to Lower Extremity Artery with Autologous Arterial Tissue, Open Approach */
"04100AR" = "1" /* Bypass Abdominal Aorta to Lower Artery with Autologous Arterial Tissue, Open Approach */
"04100J0" = "1" /* Bypass Abdominal Aorta to Abdominal Aorta with Synthetic Substitute, Open Approach */
"04100J1" = "1" /* Bypass Abdominal Aorta to Celiac Artery with Synthetic Substitute, Open Approach */
"04100J2" = "1" /* Bypass Abdominal Aorta to Mesenteric Artery with Synthetic Substitute, Open Approach */
"04100J3" = "1" /* Bypass Abdominal Aorta to Right Renal Artery with Synthetic Substitute, Open Approach */
"04100J4" = "1" /* Bypass Abdominal Aorta to Left Renal Artery with Synthetic Substitute, Open Approach */
"04100J5" = "1" /* Bypass Abdominal Aorta to Bilateral Renal Artery with Synthetic Substitute, Open Approach */
"04100J6" = "1" /* Bypass Abdominal Aorta to Right Common Iliac Artery with Synthetic Substitute, Open Approach */
"04100J7" = "1" /* Bypass Abdominal Aorta to Left Common Iliac Artery with Synthetic Substitute, Open Approach */
"04100J8" = "1" /* Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Synthetic Substitute, Open Approach */
"04100J9" = "1" /* Bypass Abdominal Aorta to Right Internal Iliac Artery with Synthetic Substitute, Open Approach */
"04100JB" = "1" /* Bypass Abdominal Aorta to Left Internal Iliac Artery with Synthetic Substitute, Open Approach */
"04100JC" = "1" /* Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Synthetic Substitute, Open Approach */
"04100JD" = "1" /* Bypass Abdominal Aorta to Right External Iliac Artery with Synthetic Substitute, Open Approach */
"04100JF" = "1" /* Bypass Abdominal Aorta to Left External Iliac Artery with Synthetic Substitute, Open Approach */
"04100JG" = "1" /* Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Synthetic Substitute, Open Approach */
"04100JH" = "1" /* Bypass Abdominal Aorta to Right Femoral Artery with Synthetic Substitute, Open Approach */
"04100JJ" = "1" /* Bypass Abdominal Aorta to Left Femoral Artery with Synthetic Substitute, Open Approach */
"04100JK" = "1" /* Bypass Abdominal Aorta to Bilateral Femoral Arteries with Synthetic Substitute, Open Approach */
"04100JQ" = "1" /* Bypass Abdominal Aorta to Lower Extremity Artery with Synthetic Substitute, Open Approach */
"04100JR" = "1" /* Bypass Abdominal Aorta to Lower Artery with Synthetic Substitute, Open Approach */
"04100K0" = "1" /* Bypass Abdominal Aorta to Abdominal Aorta with Nonautologous Tissue Substitute, Open Approach */
"04100K1" = "1" /* Bypass Abdominal Aorta to Celiac Artery with Nonautologous Tissue Substitute, Open Approach */
"04100K2" = "1" /* Bypass Abdominal Aorta to Mesenteric Artery with Nonautologous Tissue Substitute, Open Approach */
"04100K3" = "1" /* Bypass Abdominal Aorta to Right Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"04100K4" = "1" /* Bypass Abdominal Aorta to Left Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"04100K5" = "1" /* Bypass Abdominal Aorta to Bilateral Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"04100K6" = "1" /* Bypass Abdominal Aorta to Right Common Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04100K7" = "1" /* Bypass Abdominal Aorta to Left Common Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04100K8" = "1" /* Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"04100K9" = "1" /* Bypass Abdominal Aorta to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04100KB" = "1" /* Bypass Abdominal Aorta to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04100KC" = "1" /* Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"04100KD" = "1" /* Bypass Abdominal Aorta to Right External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04100KF" = "1" /* Bypass Abdominal Aorta to Left External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04100KG" = "1" /* Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"04100KH" = "1" /* Bypass Abdominal Aorta to Right Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"04100KJ" = "1" /* Bypass Abdominal Aorta to Left Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"04100KK" = "1" /* Bypass Abdominal Aorta to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Open Approach */
"04100KQ" = "1" /* Bypass Abdominal Aorta to Lower Extremity Artery with Nonautologous Tissue Substitute, Open Approach */
"04100KR" = "1" /* Bypass Abdominal Aorta to Lower Artery with Nonautologous Tissue Substitute, Open Approach */
"04100Z0" = "1" /* Bypass Abdominal Aorta to Abdominal Aorta, Open Approach */
"04100Z1" = "1" /* Bypass Abdominal Aorta to Celiac Artery, Open Approach */
"04100Z2" = "1" /* Bypass Abdominal Aorta to Mesenteric Artery, Open Approach */
"04100Z3" = "1" /* Bypass Abdominal Aorta to Right Renal Artery, Open Approach */
"04100Z4" = "1" /* Bypass Abdominal Aorta to Left Renal Artery, Open Approach */
"04100Z5" = "1" /* Bypass Abdominal Aorta to Bilateral Renal Artery, Open Approach */
"04100Z6" = "1" /* Bypass Abdominal Aorta to Right Common Iliac Artery, Open Approach */
"04100Z7" = "1" /* Bypass Abdominal Aorta to Left Common Iliac Artery, Open Approach */
"04100Z8" = "1" /* Bypass Abdominal Aorta to Bilateral Common Iliac Arteries, Open Approach */
"04100Z9" = "1" /* Bypass Abdominal Aorta to Right Internal Iliac Artery, Open Approach */
"04100ZB" = "1" /* Bypass Abdominal Aorta to Left Internal Iliac Artery, Open Approach */
"04100ZC" = "1" /* Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries, Open Approach */
"04100ZD" = "1" /* Bypass Abdominal Aorta to Right External Iliac Artery, Open Approach */
"04100ZF" = "1" /* Bypass Abdominal Aorta to Left External Iliac Artery, Open Approach */
"04100ZG" = "1" /* Bypass Abdominal Aorta to Bilateral External Iliac Arteries, Open Approach */
"04100ZH" = "1" /* Bypass Abdominal Aorta to Right Femoral Artery, Open Approach */
"04100ZJ" = "1" /* Bypass Abdominal Aorta to Left Femoral Artery, Open Approach */
"04100ZK" = "1" /* Bypass Abdominal Aorta to Bilateral Femoral Arteries, Open Approach */
"04100ZQ" = "1" /* Bypass Abdominal Aorta to Lower Extremity Artery, Open Approach */
"04100ZR" = "1" /* Bypass Abdominal Aorta to Lower Artery, Open Approach */
"0414093" = "1" /* Bypass Splenic Artery to Right Renal Artery with Autologous Venous Tissue, Open Approach */
"0414094" = "1" /* Bypass Splenic Artery to Left Renal Artery with Autologous Venous Tissue, Open Approach */
"0414095" = "1" /* Bypass Splenic Artery to Bilateral Renal Artery with Autologous Venous Tissue, Open Approach */
"04140A3" = "1" /* Bypass Splenic Artery to Right Renal Artery with Autologous Arterial Tissue, Open Approach */
"04140A4" = "1" /* Bypass Splenic Artery to Left Renal Artery with Autologous Arterial Tissue, Open Approach */
"04140A5" = "1" /* Bypass Splenic Artery to Bilateral Renal Artery with Autologous Arterial Tissue, Open Approach */
"04140J3" = "1" /* Bypass Splenic Artery to Right Renal Artery with Synthetic Substitute, Open Approach */
"04140J4" = "1" /* Bypass Splenic Artery to Left Renal Artery with Synthetic Substitute, Open Approach */
"04140J5" = "1" /* Bypass Splenic Artery to Bilateral Renal Artery with Synthetic Substitute, Open Approach */
"04140K3" = "1" /* Bypass Splenic Artery to Right Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"04140K4" = "1" /* Bypass Splenic Artery to Left Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"04140K5" = "1" /* Bypass Splenic Artery to Bilateral Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"04140Z3" = "1" /* Bypass Splenic Artery to Right Renal Artery, Open Approach */
"04140Z4" = "1" /* Bypass Splenic Artery to Left Renal Artery, Open Approach */
"04140Z5" = "1" /* Bypass Splenic Artery to Bilateral Renal Artery, Open Approach */
"041C090" = "1" /* Bypass Right Common Iliac Artery to Abdominal Aorta with Autologous Venous Tissue, Open Approach */
"041C091" = "1" /* Bypass Right Common Iliac Artery to Celiac Artery with Autologous Venous Tissue, Open Approach */
"041C092" = "1" /* Bypass Right Common Iliac Artery to Mesenteric Artery with Autologous Venous Tissue, Open Approach */
"041C093" = "1" /* Bypass Right Common Iliac Artery to Right Renal Artery with Autologous Venous Tissue, Open Approach */
"041C094" = "1" /* Bypass Right Common Iliac Artery to Left Renal Artery with Autologous Venous Tissue, Open Approach */
"041C095" = "1" /* Bypass Right Common Iliac Artery to Bilateral Renal Artery with Autologous Venous Tissue, Open Approach */
"041C096" = "1" /* Bypass Right Common Iliac Artery to Right Common Iliac Artery with Autologous Venous Tissue, Open Approach */
"041C097" = "1" /* Bypass Right Common Iliac Artery to Left Common Iliac Artery with Autologous Venous Tissue, Open Approach */
"041C098" = "1" /* Bypass Right Common Iliac Artery to Bilateral Common Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041C099" = "1" /* Bypass Right Common Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041C09B" = "1" /* Bypass Right Common Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041C09C" = "1" /* Bypass Right Common Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041C09D" = "1" /* Bypass Right Common Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041C09F" = "1" /* Bypass Right Common Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041C09G" = "1" /* Bypass Right Common Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041C09H" = "1" /* Bypass Right Common Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Open Approach */
"041C09J" = "1" /* Bypass Right Common Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Open Approach */
"041C09K" = "1" /* Bypass Right Common Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Open Approach */
"041C09Q" = "1" /* Bypass Right Common Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Open Approach */
"041C09R" = "1" /* Bypass Right Common Iliac Artery to Lower Artery with Autologous Venous Tissue, Open Approach */
"041C0A0" = "1" /* Bypass Right Common Iliac Artery to Abdominal Aorta with Autologous Arterial Tissue, Open Approach */
"041C0A1" = "1" /* Bypass Right Common Iliac Artery to Celiac Artery with Autologous Arterial Tissue, Open Approach */
"041C0A2" = "1" /* Bypass Right Common Iliac Artery to Mesenteric Artery with Autologous Arterial Tissue, Open Approach */
"041C0A3" = "1" /* Bypass Right Common Iliac Artery to Right Renal Artery with Autologous Arterial Tissue, Open Approach */
"041C0A4" = "1" /* Bypass Right Common Iliac Artery to Left Renal Artery with Autologous Arterial Tissue, Open Approach */
"041C0A5" = "1" /* Bypass Right Common Iliac Artery to Bilateral Renal Artery with Autologous Arterial Tissue, Open Approach */
"041C0A6" = "1" /* Bypass Right Common Iliac Artery to Right Common Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041C0A7" = "1" /* Bypass Right Common Iliac Artery to Left Common Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041C0A8" = "1" /* Bypass Right Common Iliac Artery to Bilateral Common Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041C0A9" = "1" /* Bypass Right Common Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041C0AB" = "1" /* Bypass Right Common Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041C0AC" = "1" /* Bypass Right Common Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041C0AD" = "1" /* Bypass Right Common Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041C0AF" = "1" /* Bypass Right Common Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041C0AG" = "1" /* Bypass Right Common Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041C0AH" = "1" /* Bypass Right Common Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041C0AJ" = "1" /* Bypass Right Common Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041C0AK" = "1" /* Bypass Right Common Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Open Approach */
"041C0AQ" = "1" /* Bypass Right Common Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Open Approach */
"041C0AR" = "1" /* Bypass Right Common Iliac Artery to Lower Artery with Autologous Arterial Tissue, Open Approach */
"041C0J0" = "1" /* Bypass Right Common Iliac Artery to Abdominal Aorta with Synthetic Substitute, Open Approach */
"041C0J1" = "1" /* Bypass Right Common Iliac Artery to Celiac Artery with Synthetic Substitute, Open Approach */
"041C0J2" = "1" /* Bypass Right Common Iliac Artery to Mesenteric Artery with Synthetic Substitute, Open Approach */
"041C0J3" = "1" /* Bypass Right Common Iliac Artery to Right Renal Artery with Synthetic Substitute, Open Approach */
"041C0J4" = "1" /* Bypass Right Common Iliac Artery to Left Renal Artery with Synthetic Substitute, Open Approach */
"041C0J5" = "1" /* Bypass Right Common Iliac Artery to Bilateral Renal Artery with Synthetic Substitute, Open Approach */
"041C0J6" = "1" /* Bypass Right Common Iliac Artery to Right Common Iliac Artery with Synthetic Substitute, Open Approach */
"041C0J7" = "1" /* Bypass Right Common Iliac Artery to Left Common Iliac Artery with Synthetic Substitute, Open Approach */
"041C0J8" = "1" /* Bypass Right Common Iliac Artery to Bilateral Common Iliac Arteries with Synthetic Substitute, Open Approach */
"041C0J9" = "1" /* Bypass Right Common Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041C0JB" = "1" /* Bypass Right Common Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041C0JC" = "1" /* Bypass Right Common Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Open Approach */
"041C0JD" = "1" /* Bypass Right Common Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Open Approach */
"041C0JF" = "1" /* Bypass Right Common Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Open Approach */
"041C0JG" = "1" /* Bypass Right Common Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Open Approach */
"041C0JH" = "1" /* Bypass Right Common Iliac Artery to Right Femoral Artery with Synthetic Substitute, Open Approach */
"041C0JJ" = "1" /* Bypass Right Common Iliac Artery to Left Femoral Artery with Synthetic Substitute, Open Approach */
"041C0JK" = "1" /* Bypass Right Common Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Open Approach */
"041C0JQ" = "1" /* Bypass Right Common Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Open Approach */
"041C0JR" = "1" /* Bypass Right Common Iliac Artery to Lower Artery with Synthetic Substitute, Open Approach */
"041C0K0" = "1" /* Bypass Right Common Iliac Artery to Abdominal Aorta with Nonautologous Tissue Substitute, Open Approach */
"041C0K1" = "1" /* Bypass Right Common Iliac Artery to Celiac Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0K2" = "1" /* Bypass Right Common Iliac Artery to Mesenteric Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0K3" = "1" /* Bypass Right Common Iliac Artery to Right Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0K4" = "1" /* Bypass Right Common Iliac Artery to Left Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0K5" = "1" /* Bypass Right Common Iliac Artery to Bilateral Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0K6" = "1" /* Bypass Right Common Iliac Artery to Right Common Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0K7" = "1" /* Bypass Right Common Iliac Artery to Left Common Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0K8" = "1" /* Bypass Right Common Iliac Artery to Bilateral Common Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041C0K9" = "1" /* Bypass Right Common Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0KB" = "1" /* Bypass Right Common Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0KC" = "1" /* Bypass Right Common Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041C0KD" = "1" /* Bypass Right Common Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0KF" = "1" /* Bypass Right Common Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0KG" = "1" /* Bypass Right Common Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041C0KH" = "1" /* Bypass Right Common Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0KJ" = "1" /* Bypass Right Common Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0KK" = "1" /* Bypass Right Common Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Open Approach */
"041C0KQ" = "1" /* Bypass Right Common Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0KR" = "1" /* Bypass Right Common Iliac Artery to Lower Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0Z0" = "1" /* Bypass Right Common Iliac Artery to Abdominal Aorta, Open Approach */
"041C0Z1" = "1" /* Bypass Right Common Iliac Artery to Celiac Artery, Open Approach */
"041C0Z2" = "1" /* Bypass Right Common Iliac Artery to Mesenteric Artery, Open Approach */
"041C0Z3" = "1" /* Bypass Right Common Iliac Artery to Right Renal Artery, Open Approach */
"041C0Z4" = "1" /* Bypass Right Common Iliac Artery to Left Renal Artery, Open Approach */
"041C0Z5" = "1" /* Bypass Right Common Iliac Artery to Bilateral Renal Artery, Open Approach */
"041C0Z6" = "1" /* Bypass Right Common Iliac Artery to Right Common Iliac Artery, Open Approach */
"041C0Z7" = "1" /* Bypass Right Common Iliac Artery to Left Common Iliac Artery, Open Approach */
"041C0Z8" = "1" /* Bypass Right Common Iliac Artery to Bilateral Common Iliac Arteries, Open Approach */
"041C0Z9" = "1" /* Bypass Right Common Iliac Artery to Right Internal Iliac Artery, Open Approach */
"041C0ZB" = "1" /* Bypass Right Common Iliac Artery to Left Internal Iliac Artery, Open Approach */
"041C0ZC" = "1" /* Bypass Right Common Iliac Artery to Bilateral Internal Iliac Arteries, Open Approach */
"041C0ZD" = "1" /* Bypass Right Common Iliac Artery to Right External Iliac Artery, Open Approach */
"041C0ZF" = "1" /* Bypass Right Common Iliac Artery to Left External Iliac Artery, Open Approach */
"041C0ZG" = "1" /* Bypass Right Common Iliac Artery to Bilateral External Iliac Arteries, Open Approach */
"041C0ZH" = "1" /* Bypass Right Common Iliac Artery to Right Femoral Artery, Open Approach */
"041C0ZJ" = "1" /* Bypass Right Common Iliac Artery to Left Femoral Artery, Open Approach */
"041C0ZK" = "1" /* Bypass Right Common Iliac Artery to Bilateral Femoral Arteries, Open Approach */
"041C0ZQ" = "1" /* Bypass Right Common Iliac Artery to Lower Extremity Artery, Open Approach */
"041C0ZR" = "1" /* Bypass Right Common Iliac Artery to Lower Artery, Open Approach */
"041D090" = "1" /* Bypass Left Common Iliac Artery to Abdominal Aorta with Autologous Venous Tissue, Open Approach */
"041D091" = "1" /* Bypass Left Common Iliac Artery to Celiac Artery with Autologous Venous Tissue, Open Approach */
"041D092" = "1" /* Bypass Left Common Iliac Artery to Mesenteric Artery with Autologous Venous Tissue, Open Approach */
"041D093" = "1" /* Bypass Left Common Iliac Artery to Right Renal Artery with Autologous Venous Tissue, Open Approach */
"041D094" = "1" /* Bypass Left Common Iliac Artery to Left Renal Artery with Autologous Venous Tissue, Open Approach */
"041D095" = "1" /* Bypass Left Common Iliac Artery to Bilateral Renal Artery with Autologous Venous Tissue, Open Approach */
"041D096" = "1" /* Bypass Left Common Iliac Artery to Right Common Iliac Artery with Autologous Venous Tissue, Open Approach */
"041D097" = "1" /* Bypass Left Common Iliac Artery to Left Common Iliac Artery with Autologous Venous Tissue, Open Approach */
"041D098" = "1" /* Bypass Left Common Iliac Artery to Bilateral Common Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041D099" = "1" /* Bypass Left Common Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041D09B" = "1" /* Bypass Left Common Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041D09C" = "1" /* Bypass Left Common Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041D09D" = "1" /* Bypass Left Common Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041D09F" = "1" /* Bypass Left Common Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041D09G" = "1" /* Bypass Left Common Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041D09H" = "1" /* Bypass Left Common Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Open Approach */
"041D09J" = "1" /* Bypass Left Common Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Open Approach */
"041D09K" = "1" /* Bypass Left Common Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Open Approach */
"041D09Q" = "1" /* Bypass Left Common Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Open Approach */
"041D09R" = "1" /* Bypass Left Common Iliac Artery to Lower Artery with Autologous Venous Tissue, Open Approach */
"041D0A0" = "1" /* Bypass Left Common Iliac Artery to Abdominal Aorta with Autologous Arterial Tissue, Open Approach */
"041D0A1" = "1" /* Bypass Left Common Iliac Artery to Celiac Artery with Autologous Arterial Tissue, Open Approach */
"041D0A2" = "1" /* Bypass Left Common Iliac Artery to Mesenteric Artery with Autologous Arterial Tissue, Open Approach */
"041D0A3" = "1" /* Bypass Left Common Iliac Artery to Right Renal Artery with Autologous Arterial Tissue, Open Approach */
"041D0A4" = "1" /* Bypass Left Common Iliac Artery to Left Renal Artery with Autologous Arterial Tissue, Open Approach */
"041D0A5" = "1" /* Bypass Left Common Iliac Artery to Bilateral Renal Artery with Autologous Arterial Tissue, Open Approach */
"041D0A6" = "1" /* Bypass Left Common Iliac Artery to Right Common Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041D0A7" = "1" /* Bypass Left Common Iliac Artery to Left Common Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041D0A8" = "1" /* Bypass Left Common Iliac Artery to Bilateral Common Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041D0A9" = "1" /* Bypass Left Common Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041D0AB" = "1" /* Bypass Left Common Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041D0AC" = "1" /* Bypass Left Common Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041D0AD" = "1" /* Bypass Left Common Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041D0AF" = "1" /* Bypass Left Common Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041D0AG" = "1" /* Bypass Left Common Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041D0AH" = "1" /* Bypass Left Common Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041D0AJ" = "1" /* Bypass Left Common Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041D0AK" = "1" /* Bypass Left Common Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Open Approach */
"041D0AQ" = "1" /* Bypass Left Common Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Open Approach */
"041D0AR" = "1" /* Bypass Left Common Iliac Artery to Lower Artery with Autologous Arterial Tissue, Open Approach */
"041D0J0" = "1" /* Bypass Left Common Iliac Artery to Abdominal Aorta with Synthetic Substitute, Open Approach */
"041D0J1" = "1" /* Bypass Left Common Iliac Artery to Celiac Artery with Synthetic Substitute, Open Approach */
"041D0J2" = "1" /* Bypass Left Common Iliac Artery to Mesenteric Artery with Synthetic Substitute, Open Approach */
"041D0J3" = "1" /* Bypass Left Common Iliac Artery to Right Renal Artery with Synthetic Substitute, Open Approach */
"041D0J4" = "1" /* Bypass Left Common Iliac Artery to Left Renal Artery with Synthetic Substitute, Open Approach */
"041D0J5" = "1" /* Bypass Left Common Iliac Artery to Bilateral Renal Artery with Synthetic Substitute, Open Approach */
"041D0J6" = "1" /* Bypass Left Common Iliac Artery to Right Common Iliac Artery with Synthetic Substitute, Open Approach */
"041D0J7" = "1" /* Bypass Left Common Iliac Artery to Left Common Iliac Artery with Synthetic Substitute, Open Approach */
"041D0J8" = "1" /* Bypass Left Common Iliac Artery to Bilateral Common Iliac Arteries with Synthetic Substitute, Open Approach */
"041D0J9" = "1" /* Bypass Left Common Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041D0JB" = "1" /* Bypass Left Common Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041D0JC" = "1" /* Bypass Left Common Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Open Approach */
"041D0JD" = "1" /* Bypass Left Common Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Open Approach */
"041D0JF" = "1" /* Bypass Left Common Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Open Approach */
"041D0JG" = "1" /* Bypass Left Common Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Open Approach */
"041D0JH" = "1" /* Bypass Left Common Iliac Artery to Right Femoral Artery with Synthetic Substitute, Open Approach */
"041D0JJ" = "1" /* Bypass Left Common Iliac Artery to Left Femoral Artery with Synthetic Substitute, Open Approach */
"041D0JK" = "1" /* Bypass Left Common Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Open Approach */
"041D0JQ" = "1" /* Bypass Left Common Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Open Approach */
"041D0JR" = "1" /* Bypass Left Common Iliac Artery to Lower Artery with Synthetic Substitute, Open Approach */
"041D0K0" = "1" /* Bypass Left Common Iliac Artery to Abdominal Aorta with Nonautologous Tissue Substitute, Open Approach */
"041D0K1" = "1" /* Bypass Left Common Iliac Artery to Celiac Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0K2" = "1" /* Bypass Left Common Iliac Artery to Mesenteric Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0K3" = "1" /* Bypass Left Common Iliac Artery to Right Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0K4" = "1" /* Bypass Left Common Iliac Artery to Left Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0K5" = "1" /* Bypass Left Common Iliac Artery to Bilateral Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0K6" = "1" /* Bypass Left Common Iliac Artery to Right Common Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0K7" = "1" /* Bypass Left Common Iliac Artery to Left Common Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0K8" = "1" /* Bypass Left Common Iliac Artery to Bilateral Common Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041D0K9" = "1" /* Bypass Left Common Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0KB" = "1" /* Bypass Left Common Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0KC" = "1" /* Bypass Left Common Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041D0KD" = "1" /* Bypass Left Common Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0KF" = "1" /* Bypass Left Common Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0KG" = "1" /* Bypass Left Common Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041D0KH" = "1" /* Bypass Left Common Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0KJ" = "1" /* Bypass Left Common Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0KK" = "1" /* Bypass Left Common Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Open Approach */
"041D0KQ" = "1" /* Bypass Left Common Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0KR" = "1" /* Bypass Left Common Iliac Artery to Lower Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0Z0" = "1" /* Bypass Left Common Iliac Artery to Abdominal Aorta, Open Approach */
"041D0Z1" = "1" /* Bypass Left Common Iliac Artery to Celiac Artery, Open Approach */
"041D0Z2" = "1" /* Bypass Left Common Iliac Artery to Mesenteric Artery, Open Approach */
"041D0Z3" = "1" /* Bypass Left Common Iliac Artery to Right Renal Artery, Open Approach */
"041D0Z4" = "1" /* Bypass Left Common Iliac Artery to Left Renal Artery, Open Approach */
"041D0Z5" = "1" /* Bypass Left Common Iliac Artery to Bilateral Renal Artery, Open Approach */
"041D0Z6" = "1" /* Bypass Left Common Iliac Artery to Right Common Iliac Artery, Open Approach */
"041D0Z7" = "1" /* Bypass Left Common Iliac Artery to Left Common Iliac Artery, Open Approach */
"041D0Z8" = "1" /* Bypass Left Common Iliac Artery to Bilateral Common Iliac Arteries, Open Approach */
"041D0Z9" = "1" /* Bypass Left Common Iliac Artery to Right Internal Iliac Artery, Open Approach */
"041D0ZB" = "1" /* Bypass Left Common Iliac Artery to Left Internal Iliac Artery, Open Approach */
"041D0ZC" = "1" /* Bypass Left Common Iliac Artery to Bilateral Internal Iliac Arteries, Open Approach */
"041D0ZD" = "1" /* Bypass Left Common Iliac Artery to Right External Iliac Artery, Open Approach */
"041D0ZF" = "1" /* Bypass Left Common Iliac Artery to Left External Iliac Artery, Open Approach */
"041D0ZG" = "1" /* Bypass Left Common Iliac Artery to Bilateral External Iliac Arteries, Open Approach */
"041D0ZH" = "1" /* Bypass Left Common Iliac Artery to Right Femoral Artery, Open Approach */
"041D0ZJ" = "1" /* Bypass Left Common Iliac Artery to Left Femoral Artery, Open Approach */
"041D0ZK" = "1" /* Bypass Left Common Iliac Artery to Bilateral Femoral Arteries, Open Approach */
"041D0ZQ" = "1" /* Bypass Left Common Iliac Artery to Lower Extremity Artery, Open Approach */
"041D0ZR" = "1" /* Bypass Left Common Iliac Artery to Lower Artery, Open Approach */
"041E099" = "1" /* Bypass Right Internal Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041E09B" = "1" /* Bypass Right Internal Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041E09C" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041E09D" = "1" /* Bypass Right Internal Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041E09F" = "1" /* Bypass Right Internal Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041E09G" = "1" /* Bypass Right Internal Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041E09H" = "1" /* Bypass Right Internal Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Open Approach */
"041E09J" = "1" /* Bypass Right Internal Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Open Approach */
"041E09K" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Open Approach */
"041E09P" = "1" /* Bypass Right Internal Iliac Artery to Foot Artery with Autologous Venous Tissue, Open Approach */
"041E09Q" = "1" /* Bypass Right Internal Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Open Approach */
"041E0A9" = "1" /* Bypass Right Internal Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041E0AB" = "1" /* Bypass Right Internal Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041E0AC" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041E0AD" = "1" /* Bypass Right Internal Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041E0AF" = "1" /* Bypass Right Internal Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041E0AG" = "1" /* Bypass Right Internal Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041E0AH" = "1" /* Bypass Right Internal Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041E0AJ" = "1" /* Bypass Right Internal Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041E0AK" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Open Approach */
"041E0AP" = "1" /* Bypass Right Internal Iliac Artery to Foot Artery with Autologous Arterial Tissue, Open Approach */
"041E0AQ" = "1" /* Bypass Right Internal Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Open Approach */
"041E0J9" = "1" /* Bypass Right Internal Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041E0JB" = "1" /* Bypass Right Internal Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041E0JC" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Open Approach */
"041E0JD" = "1" /* Bypass Right Internal Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Open Approach */
"041E0JF" = "1" /* Bypass Right Internal Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Open Approach */
"041E0JG" = "1" /* Bypass Right Internal Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Open Approach */
"041E0JH" = "1" /* Bypass Right Internal Iliac Artery to Right Femoral Artery with Synthetic Substitute, Open Approach */
"041E0JJ" = "1" /* Bypass Right Internal Iliac Artery to Left Femoral Artery with Synthetic Substitute, Open Approach */
"041E0JK" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Open Approach */
"041E0JP" = "1" /* Bypass Right Internal Iliac Artery to Foot Artery with Synthetic Substitute, Open Approach */
"041E0JQ" = "1" /* Bypass Right Internal Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Open Approach */
"041E0K9" = "1" /* Bypass Right Internal Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041E0KB" = "1" /* Bypass Right Internal Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041E0KC" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041E0KD" = "1" /* Bypass Right Internal Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041E0KF" = "1" /* Bypass Right Internal Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041E0KG" = "1" /* Bypass Right Internal Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041E0KH" = "1" /* Bypass Right Internal Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041E0KJ" = "1" /* Bypass Right Internal Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041E0KK" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Open Approach */
"041E0KP" = "1" /* Bypass Right Internal Iliac Artery to Foot Artery with Nonautologous Tissue Substitute, Open Approach */
"041E0KQ" = "1" /* Bypass Right Internal Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Open Approach */
"041E0Z9" = "1" /* Bypass Right Internal Iliac Artery to Right Internal Iliac Artery, Open Approach */
"041E0ZB" = "1" /* Bypass Right Internal Iliac Artery to Left Internal Iliac Artery, Open Approach */
"041E0ZC" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Internal Iliac Arteries, Open Approach */
"041E0ZD" = "1" /* Bypass Right Internal Iliac Artery to Right External Iliac Artery, Open Approach */
"041E0ZF" = "1" /* Bypass Right Internal Iliac Artery to Left External Iliac Artery, Open Approach */
"041E0ZG" = "1" /* Bypass Right Internal Iliac Artery to Bilateral External Iliac Arteries, Open Approach */
"041E0ZH" = "1" /* Bypass Right Internal Iliac Artery to Right Femoral Artery, Open Approach */
"041E0ZJ" = "1" /* Bypass Right Internal Iliac Artery to Left Femoral Artery, Open Approach */
"041E0ZK" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Femoral Arteries, Open Approach */
"041E0ZP" = "1" /* Bypass Right Internal Iliac Artery to Foot Artery, Open Approach */
"041E0ZQ" = "1" /* Bypass Right Internal Iliac Artery to Lower Extremity Artery, Open Approach */
"041F099" = "1" /* Bypass Left Internal Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041F09B" = "1" /* Bypass Left Internal Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041F09C" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041F09D" = "1" /* Bypass Left Internal Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041F09F" = "1" /* Bypass Left Internal Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041F09G" = "1" /* Bypass Left Internal Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041F09H" = "1" /* Bypass Left Internal Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Open Approach */
"041F09J" = "1" /* Bypass Left Internal Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Open Approach */
"041F09K" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Open Approach */
"041F09P" = "1" /* Bypass Left Internal Iliac Artery to Foot Artery with Autologous Venous Tissue, Open Approach */
"041F09Q" = "1" /* Bypass Left Internal Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Open Approach */
"041F0A9" = "1" /* Bypass Left Internal Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041F0AB" = "1" /* Bypass Left Internal Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041F0AC" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041F0AD" = "1" /* Bypass Left Internal Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041F0AF" = "1" /* Bypass Left Internal Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041F0AG" = "1" /* Bypass Left Internal Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041F0AH" = "1" /* Bypass Left Internal Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041F0AJ" = "1" /* Bypass Left Internal Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041F0AK" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Open Approach */
"041F0AP" = "1" /* Bypass Left Internal Iliac Artery to Foot Artery with Autologous Arterial Tissue, Open Approach */
"041F0AQ" = "1" /* Bypass Left Internal Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Open Approach */
"041F0J9" = "1" /* Bypass Left Internal Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041F0JB" = "1" /* Bypass Left Internal Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041F0JC" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Open Approach */
"041F0JD" = "1" /* Bypass Left Internal Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Open Approach */
"041F0JF" = "1" /* Bypass Left Internal Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Open Approach */
"041F0JG" = "1" /* Bypass Left Internal Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Open Approach */
"041F0JH" = "1" /* Bypass Left Internal Iliac Artery to Right Femoral Artery with Synthetic Substitute, Open Approach */
"041F0JJ" = "1" /* Bypass Left Internal Iliac Artery to Left Femoral Artery with Synthetic Substitute, Open Approach */
"041F0JK" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Open Approach */
"041F0JP" = "1" /* Bypass Left Internal Iliac Artery to Foot Artery with Synthetic Substitute, Open Approach */
"041F0JQ" = "1" /* Bypass Left Internal Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Open Approach */
"041F0K9" = "1" /* Bypass Left Internal Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041F0KB" = "1" /* Bypass Left Internal Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041F0KC" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041F0KD" = "1" /* Bypass Left Internal Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041F0KF" = "1" /* Bypass Left Internal Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041F0KG" = "1" /* Bypass Left Internal Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041F0KH" = "1" /* Bypass Left Internal Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041F0KJ" = "1" /* Bypass Left Internal Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041F0KK" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Open Approach */
"041F0KP" = "1" /* Bypass Left Internal Iliac Artery to Foot Artery with Nonautologous Tissue Substitute, Open Approach */
"041F0KQ" = "1" /* Bypass Left Internal Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Open Approach */
"041F0Z9" = "1" /* Bypass Left Internal Iliac Artery to Right Internal Iliac Artery, Open Approach */
"041F0ZB" = "1" /* Bypass Left Internal Iliac Artery to Left Internal Iliac Artery, Open Approach */
"041F0ZC" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Internal Iliac Arteries, Open Approach */
"041F0ZD" = "1" /* Bypass Left Internal Iliac Artery to Right External Iliac Artery, Open Approach */
"041F0ZF" = "1" /* Bypass Left Internal Iliac Artery to Left External Iliac Artery, Open Approach */
"041F0ZG" = "1" /* Bypass Left Internal Iliac Artery to Bilateral External Iliac Arteries, Open Approach */
"041F0ZH" = "1" /* Bypass Left Internal Iliac Artery to Right Femoral Artery, Open Approach */
"041F0ZJ" = "1" /* Bypass Left Internal Iliac Artery to Left Femoral Artery, Open Approach */
"041F0ZK" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Femoral Arteries, Open Approach */
"041F0ZP" = "1" /* Bypass Left Internal Iliac Artery to Foot Artery, Open Approach */
"041F0ZQ" = "1" /* Bypass Left Internal Iliac Artery to Lower Extremity Artery, Open Approach */
"041H099" = "1" /* Bypass Right External Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041H09B" = "1" /* Bypass Right External Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041H09C" = "1" /* Bypass Right External Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041H09D" = "1" /* Bypass Right External Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041H09F" = "1" /* Bypass Right External Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041H09G" = "1" /* Bypass Right External Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041H09H" = "1" /* Bypass Right External Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Open Approach */
"041H09J" = "1" /* Bypass Right External Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Open Approach */
"041H09K" = "1" /* Bypass Right External Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Open Approach */
"041H09P" = "1" /* Bypass Right External Iliac Artery to Foot Artery with Autologous Venous Tissue, Open Approach */
"041H09Q" = "1" /* Bypass Right External Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Open Approach */
"041H0A9" = "1" /* Bypass Right External Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041H0AB" = "1" /* Bypass Right External Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041H0AC" = "1" /* Bypass Right External Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041H0AD" = "1" /* Bypass Right External Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041H0AF" = "1" /* Bypass Right External Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041H0AG" = "1" /* Bypass Right External Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041H0AH" = "1" /* Bypass Right External Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041H0AJ" = "1" /* Bypass Right External Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041H0AK" = "1" /* Bypass Right External Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Open Approach */
"041H0AP" = "1" /* Bypass Right External Iliac Artery to Foot Artery with Autologous Arterial Tissue, Open Approach */
"041H0AQ" = "1" /* Bypass Right External Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Open Approach */
"041H0J9" = "1" /* Bypass Right External Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041H0JB" = "1" /* Bypass Right External Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041H0JC" = "1" /* Bypass Right External Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Open Approach */
"041H0JD" = "1" /* Bypass Right External Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Open Approach */
"041H0JF" = "1" /* Bypass Right External Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Open Approach */
"041H0JG" = "1" /* Bypass Right External Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Open Approach */
"041H0JH" = "1" /* Bypass Right External Iliac Artery to Right Femoral Artery with Synthetic Substitute, Open Approach */
"041H0JJ" = "1" /* Bypass Right External Iliac Artery to Left Femoral Artery with Synthetic Substitute, Open Approach */
"041H0JK" = "1" /* Bypass Right External Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Open Approach */
"041H0JP" = "1" /* Bypass Right External Iliac Artery to Foot Artery with Synthetic Substitute, Open Approach */
"041H0JQ" = "1" /* Bypass Right External Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Open Approach */
"041H0K9" = "1" /* Bypass Right External Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041H0KB" = "1" /* Bypass Right External Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041H0KC" = "1" /* Bypass Right External Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041H0KD" = "1" /* Bypass Right External Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041H0KF" = "1" /* Bypass Right External Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041H0KG" = "1" /* Bypass Right External Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041H0KH" = "1" /* Bypass Right External Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041H0KJ" = "1" /* Bypass Right External Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041H0KK" = "1" /* Bypass Right External Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Open Approach */
"041H0KP" = "1" /* Bypass Right External Iliac Artery to Foot Artery with Nonautologous Tissue Substitute, Open Approach */
"041H0KQ" = "1" /* Bypass Right External Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Open Approach */
"041H0Z9" = "1" /* Bypass Right External Iliac Artery to Right Internal Iliac Artery, Open Approach */
"041H0ZB" = "1" /* Bypass Right External Iliac Artery to Left Internal Iliac Artery, Open Approach */
"041H0ZC" = "1" /* Bypass Right External Iliac Artery to Bilateral Internal Iliac Arteries, Open Approach */
"041H0ZD" = "1" /* Bypass Right External Iliac Artery to Right External Iliac Artery, Open Approach */
"041H0ZF" = "1" /* Bypass Right External Iliac Artery to Left External Iliac Artery, Open Approach */
"041H0ZG" = "1" /* Bypass Right External Iliac Artery to Bilateral External Iliac Arteries, Open Approach */
"041H0ZH" = "1" /* Bypass Right External Iliac Artery to Right Femoral Artery, Open Approach */
"041H0ZJ" = "1" /* Bypass Right External Iliac Artery to Left Femoral Artery, Open Approach */
"041H0ZK" = "1" /* Bypass Right External Iliac Artery to Bilateral Femoral Arteries, Open Approach */
"041H0ZP" = "1" /* Bypass Right External Iliac Artery to Foot Artery, Open Approach */
"041H0ZQ" = "1" /* Bypass Right External Iliac Artery to Lower Extremity Artery, Open Approach */
"041J099" = "1" /* Bypass Left External Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041J09B" = "1" /* Bypass Left External Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041J09C" = "1" /* Bypass Left External Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041J09D" = "1" /* Bypass Left External Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041J09F" = "1" /* Bypass Left External Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041J09G" = "1" /* Bypass Left External Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041J09H" = "1" /* Bypass Left External Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Open Approach */
"041J09J" = "1" /* Bypass Left External Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Open Approach */
"041J09K" = "1" /* Bypass Left External Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Open Approach */
"041J09P" = "1" /* Bypass Left External Iliac Artery to Foot Artery with Autologous Venous Tissue, Open Approach */
"041J09Q" = "1" /* Bypass Left External Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Open Approach */
"041J0A9" = "1" /* Bypass Left External Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041J0AB" = "1" /* Bypass Left External Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041J0AC" = "1" /* Bypass Left External Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041J0AD" = "1" /* Bypass Left External Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041J0AF" = "1" /* Bypass Left External Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041J0AG" = "1" /* Bypass Left External Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041J0AH" = "1" /* Bypass Left External Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041J0AJ" = "1" /* Bypass Left External Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041J0AK" = "1" /* Bypass Left External Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Open Approach */
"041J0AP" = "1" /* Bypass Left External Iliac Artery to Foot Artery with Autologous Arterial Tissue, Open Approach */
"041J0AQ" = "1" /* Bypass Left External Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Open Approach */
"041J0J9" = "1" /* Bypass Left External Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041J0JB" = "1" /* Bypass Left External Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041J0JC" = "1" /* Bypass Left External Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Open Approach */
"041J0JD" = "1" /* Bypass Left External Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Open Approach */
"041J0JF" = "1" /* Bypass Left External Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Open Approach */
"041J0JG" = "1" /* Bypass Left External Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Open Approach */
"041J0JH" = "1" /* Bypass Left External Iliac Artery to Right Femoral Artery with Synthetic Substitute, Open Approach */
"041J0JJ" = "1" /* Bypass Left External Iliac Artery to Left Femoral Artery with Synthetic Substitute, Open Approach */
"041J0JK" = "1" /* Bypass Left External Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Open Approach */
"041J0JP" = "1" /* Bypass Left External Iliac Artery to Foot Artery with Synthetic Substitute, Open Approach */
"041J0JQ" = "1" /* Bypass Left External Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Open Approach */
"041J0K9" = "1" /* Bypass Left External Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041J0KB" = "1" /* Bypass Left External Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041J0KC" = "1" /* Bypass Left External Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041J0KD" = "1" /* Bypass Left External Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041J0KF" = "1" /* Bypass Left External Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041J0KG" = "1" /* Bypass Left External Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041J0KH" = "1" /* Bypass Left External Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041J0KJ" = "1" /* Bypass Left External Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041J0KK" = "1" /* Bypass Left External Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Open Approach */
"041J0KP" = "1" /* Bypass Left External Iliac Artery to Foot Artery with Nonautologous Tissue Substitute, Open Approach */
"041J0KQ" = "1" /* Bypass Left External Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Open Approach */
"041J0Z9" = "1" /* Bypass Left External Iliac Artery to Right Internal Iliac Artery, Open Approach */
"041J0ZB" = "1" /* Bypass Left External Iliac Artery to Left Internal Iliac Artery, Open Approach */
"041J0ZC" = "1" /* Bypass Left External Iliac Artery to Bilateral Internal Iliac Arteries, Open Approach */
"041J0ZD" = "1" /* Bypass Left External Iliac Artery to Right External Iliac Artery, Open Approach */
"041J0ZF" = "1" /* Bypass Left External Iliac Artery to Left External Iliac Artery, Open Approach */
"041J0ZG" = "1" /* Bypass Left External Iliac Artery to Bilateral External Iliac Arteries, Open Approach */
"041J0ZH" = "1" /* Bypass Left External Iliac Artery to Right Femoral Artery, Open Approach */
"041J0ZJ" = "1" /* Bypass Left External Iliac Artery to Left Femoral Artery, Open Approach */
"041J0ZK" = "1" /* Bypass Left External Iliac Artery to Bilateral Femoral Arteries, Open Approach */
"041J0ZP" = "1" /* Bypass Left External Iliac Artery to Foot Artery, Open Approach */
"041J0ZQ" = "1" /* Bypass Left External Iliac Artery to Lower Extremity Artery, Open Approach */
"04500ZZ" = "1" /* Destruction of Abdominal Aorta, Open Approach */
"04510ZZ" = "1" /* Destruction of Celiac Artery, Open Approach */
"04520ZZ" = "1" /* Destruction of Gastric Artery, Open Approach */
"04530ZZ" = "1" /* Destruction of Hepatic Artery, Open Approach */
"04540ZZ" = "1" /* Destruction of Splenic Artery, Open Approach */
"04550ZZ" = "1" /* Destruction of Superior Mesenteric Artery, Open Approach */
"04560ZZ" = "1" /* Destruction of Right Colic Artery, Open Approach */
"04570ZZ" = "1" /* Destruction of Left Colic Artery, Open Approach */
"04580ZZ" = "1" /* Destruction of Middle Colic Artery, Open Approach */
"04590ZZ" = "1" /* Destruction of Right Renal Artery, Open Approach */
"045A0ZZ" = "1" /* Destruction of Left Renal Artery, Open Approach */
"045B0ZZ" = "1" /* Destruction of Inferior Mesenteric Artery, Open Approach */
"045C0ZZ" = "1" /* Destruction of Right Common Iliac Artery, Open Approach */
"045D0ZZ" = "1" /* Destruction of Left Common Iliac Artery, Open Approach */
"045E0ZZ" = "1" /* Destruction of Right Internal Iliac Artery, Open Approach */
"045F0ZZ" = "1" /* Destruction of Left Internal Iliac Artery, Open Approach */
"045H0ZZ" = "1" /* Destruction of Right External Iliac Artery, Open Approach */
"045J0ZZ" = "1" /* Destruction of Left External Iliac Artery, Open Approach */
"0470046" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047004Z" = "1" /* Dilation of Abdominal Aorta with Drug-eluting Intraluminal Device, Open Approach */
"0470056" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047005Z" = "1" /* Dilation of Abdominal Aorta with Two Drug-eluting Intraluminal Devices, Open Approach */
"0470066" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047006Z" = "1" /* Dilation of Abdominal Aorta with Three Drug-eluting Intraluminal Devices, Open Approach */
"0470076" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047007Z" = "1" /* Dilation of Abdominal Aorta with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"04700D6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Intraluminal Device, Open Approach */
"04700DZ" = "1" /* Dilation of Abdominal Aorta with Intraluminal Device, Open Approach */
"04700E6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Two Intraluminal Devices, Open Approach */
"04700EZ" = "1" /* Dilation of Abdominal Aorta with Two Intraluminal Devices, Open Approach */
"04700F6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Three Intraluminal Devices, Open Approach */
"04700FZ" = "1" /* Dilation of Abdominal Aorta with Three Intraluminal Devices, Open Approach */
"04700G6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"04700GZ" = "1" /* Dilation of Abdominal Aorta with Four or More Intraluminal Devices, Open Approach */
"04700Z6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, Open Approach */
"04700ZZ" = "1" /* Dilation of Abdominal Aorta, Open Approach */
"0471046" = "1" /* Dilation of Celiac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047104Z" = "1" /* Dilation of Celiac Artery with Drug-eluting Intraluminal Device, Open Approach */
"0471056" = "1" /* Dilation of Celiac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047105Z" = "1" /* Dilation of Celiac Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0471066" = "1" /* Dilation of Celiac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047106Z" = "1" /* Dilation of Celiac Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0471076" = "1" /* Dilation of Celiac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047107Z" = "1" /* Dilation of Celiac Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"04710D6" = "1" /* Dilation of Celiac Artery, Bifurcation, with Intraluminal Device, Open Approach */
"04710DZ" = "1" /* Dilation of Celiac Artery with Intraluminal Device, Open Approach */
"04710E6" = "1" /* Dilation of Celiac Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"04710EZ" = "1" /* Dilation of Celiac Artery with Two Intraluminal Devices, Open Approach */
"04710F6" = "1" /* Dilation of Celiac Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"04710FZ" = "1" /* Dilation of Celiac Artery with Three Intraluminal Devices, Open Approach */
"04710G6" = "1" /* Dilation of Celiac Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"04710GZ" = "1" /* Dilation of Celiac Artery with Four or More Intraluminal Devices, Open Approach */
"04710Z6" = "1" /* Dilation of Celiac Artery, Bifurcation, Open Approach */
"04710ZZ" = "1" /* Dilation of Celiac Artery, Open Approach */
"0472046" = "1" /* Dilation of Gastric Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047204Z" = "1" /* Dilation of Gastric Artery with Drug-eluting Intraluminal Device, Open Approach */
"0472056" = "1" /* Dilation of Gastric Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047205Z" = "1" /* Dilation of Gastric Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0472066" = "1" /* Dilation of Gastric Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047206Z" = "1" /* Dilation of Gastric Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0472076" = "1" /* Dilation of Gastric Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047207Z" = "1" /* Dilation of Gastric Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"04720D6" = "1" /* Dilation of Gastric Artery, Bifurcation, with Intraluminal Device, Open Approach */
"04720DZ" = "1" /* Dilation of Gastric Artery with Intraluminal Device, Open Approach */
"04720E6" = "1" /* Dilation of Gastric Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"04720EZ" = "1" /* Dilation of Gastric Artery with Two Intraluminal Devices, Open Approach */
"04720F6" = "1" /* Dilation of Gastric Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"04720FZ" = "1" /* Dilation of Gastric Artery with Three Intraluminal Devices, Open Approach */
"04720G6" = "1" /* Dilation of Gastric Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"04720GZ" = "1" /* Dilation of Gastric Artery with Four or More Intraluminal Devices, Open Approach */
"04720Z6" = "1" /* Dilation of Gastric Artery, Bifurcation, Open Approach */
"04720ZZ" = "1" /* Dilation of Gastric Artery, Open Approach */
"0473046" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047304Z" = "1" /* Dilation of Hepatic Artery with Drug-eluting Intraluminal Device, Open Approach */
"0473056" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047305Z" = "1" /* Dilation of Hepatic Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0473066" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047306Z" = "1" /* Dilation of Hepatic Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0473076" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047307Z" = "1" /* Dilation of Hepatic Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"04730D6" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Intraluminal Device, Open Approach */
"04730DZ" = "1" /* Dilation of Hepatic Artery with Intraluminal Device, Open Approach */
"04730E6" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"04730EZ" = "1" /* Dilation of Hepatic Artery with Two Intraluminal Devices, Open Approach */
"04730F6" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"04730FZ" = "1" /* Dilation of Hepatic Artery with Three Intraluminal Devices, Open Approach */
"04730G6" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"04730GZ" = "1" /* Dilation of Hepatic Artery with Four or More Intraluminal Devices, Open Approach */
"04730Z6" = "1" /* Dilation of Hepatic Artery, Bifurcation, Open Approach */
"04730ZZ" = "1" /* Dilation of Hepatic Artery, Open Approach */
"0474046" = "1" /* Dilation of Splenic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047404Z" = "1" /* Dilation of Splenic Artery with Drug-eluting Intraluminal Device, Open Approach */
"0474056" = "1" /* Dilation of Splenic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047405Z" = "1" /* Dilation of Splenic Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0474066" = "1" /* Dilation of Splenic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047406Z" = "1" /* Dilation of Splenic Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0474076" = "1" /* Dilation of Splenic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047407Z" = "1" /* Dilation of Splenic Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"04740D6" = "1" /* Dilation of Splenic Artery, Bifurcation, with Intraluminal Device, Open Approach */
"04740DZ" = "1" /* Dilation of Splenic Artery with Intraluminal Device, Open Approach */
"04740E6" = "1" /* Dilation of Splenic Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"04740EZ" = "1" /* Dilation of Splenic Artery with Two Intraluminal Devices, Open Approach */
"04740F6" = "1" /* Dilation of Splenic Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"04740FZ" = "1" /* Dilation of Splenic Artery with Three Intraluminal Devices, Open Approach */
"04740G6" = "1" /* Dilation of Splenic Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"04740GZ" = "1" /* Dilation of Splenic Artery with Four or More Intraluminal Devices, Open Approach */
"04740Z6" = "1" /* Dilation of Splenic Artery, Bifurcation, Open Approach */
"04740ZZ" = "1" /* Dilation of Splenic Artery, Open Approach */
"0475046" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047504Z" = "1" /* Dilation of Superior Mesenteric Artery with Drug-eluting Intraluminal Device, Open Approach */
"0475056" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047505Z" = "1" /* Dilation of Superior Mesenteric Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0475066" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047506Z" = "1" /* Dilation of Superior Mesenteric Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0475076" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047507Z" = "1" /* Dilation of Superior Mesenteric Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"04750D6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Intraluminal Device, Open Approach */
"04750DZ" = "1" /* Dilation of Superior Mesenteric Artery with Intraluminal Device, Open Approach */
"04750E6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"04750EZ" = "1" /* Dilation of Superior Mesenteric Artery with Two Intraluminal Devices, Open Approach */
"04750F6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"04750FZ" = "1" /* Dilation of Superior Mesenteric Artery with Three Intraluminal Devices, Open Approach */
"04750G6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"04750GZ" = "1" /* Dilation of Superior Mesenteric Artery with Four or More Intraluminal Devices, Open Approach */
"04750Z6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, Open Approach */
"04750ZZ" = "1" /* Dilation of Superior Mesenteric Artery, Open Approach */
"0476046" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047604Z" = "1" /* Dilation of Right Colic Artery with Drug-eluting Intraluminal Device, Open Approach */
"0476056" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047605Z" = "1" /* Dilation of Right Colic Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0476066" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047606Z" = "1" /* Dilation of Right Colic Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0476076" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047607Z" = "1" /* Dilation of Right Colic Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"04760D6" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Intraluminal Device, Open Approach */
"04760DZ" = "1" /* Dilation of Right Colic Artery with Intraluminal Device, Open Approach */
"04760E6" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"04760EZ" = "1" /* Dilation of Right Colic Artery with Two Intraluminal Devices, Open Approach */
"04760F6" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"04760FZ" = "1" /* Dilation of Right Colic Artery with Three Intraluminal Devices, Open Approach */
"04760G6" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"04760GZ" = "1" /* Dilation of Right Colic Artery with Four or More Intraluminal Devices, Open Approach */
"04760Z6" = "1" /* Dilation of Right Colic Artery, Bifurcation, Open Approach */
"04760ZZ" = "1" /* Dilation of Right Colic Artery, Open Approach */
"0477046" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047704Z" = "1" /* Dilation of Left Colic Artery with Drug-eluting Intraluminal Device, Open Approach */
"0477056" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047705Z" = "1" /* Dilation of Left Colic Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0477066" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047706Z" = "1" /* Dilation of Left Colic Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0477076" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047707Z" = "1" /* Dilation of Left Colic Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"04770D6" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Intraluminal Device, Open Approach */
"04770DZ" = "1" /* Dilation of Left Colic Artery with Intraluminal Device, Open Approach */
"04770E6" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"04770EZ" = "1" /* Dilation of Left Colic Artery with Two Intraluminal Devices, Open Approach */
"04770F6" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"04770FZ" = "1" /* Dilation of Left Colic Artery with Three Intraluminal Devices, Open Approach */
"04770G6" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"04770GZ" = "1" /* Dilation of Left Colic Artery with Four or More Intraluminal Devices, Open Approach */
"04770Z6" = "1" /* Dilation of Left Colic Artery, Bifurcation, Open Approach */
"04770ZZ" = "1" /* Dilation of Left Colic Artery, Open Approach */
"0478046" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047804Z" = "1" /* Dilation of Middle Colic Artery with Drug-eluting Intraluminal Device, Open Approach */
"0478056" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047805Z" = "1" /* Dilation of Middle Colic Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0478066" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047806Z" = "1" /* Dilation of Middle Colic Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0478076" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047807Z" = "1" /* Dilation of Middle Colic Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"04780D6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Intraluminal Device, Open Approach */
"04780DZ" = "1" /* Dilation of Middle Colic Artery with Intraluminal Device, Open Approach */
"04780E6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"04780EZ" = "1" /* Dilation of Middle Colic Artery with Two Intraluminal Devices, Open Approach */
"04780F6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"04780FZ" = "1" /* Dilation of Middle Colic Artery with Three Intraluminal Devices, Open Approach */
"04780G6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"04780GZ" = "1" /* Dilation of Middle Colic Artery with Four or More Intraluminal Devices, Open Approach */
"04780Z6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, Open Approach */
"04780ZZ" = "1" /* Dilation of Middle Colic Artery, Open Approach */
"0479046" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047904Z" = "1" /* Dilation of Right Renal Artery with Drug-eluting Intraluminal Device, Open Approach */
"0479056" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047905Z" = "1" /* Dilation of Right Renal Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0479066" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047906Z" = "1" /* Dilation of Right Renal Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0479076" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047907Z" = "1" /* Dilation of Right Renal Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"04790D6" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Intraluminal Device, Open Approach */
"04790DZ" = "1" /* Dilation of Right Renal Artery with Intraluminal Device, Open Approach */
"04790E6" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"04790EZ" = "1" /* Dilation of Right Renal Artery with Two Intraluminal Devices, Open Approach */
"04790F6" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"04790FZ" = "1" /* Dilation of Right Renal Artery with Three Intraluminal Devices, Open Approach */
"04790G6" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"04790GZ" = "1" /* Dilation of Right Renal Artery with Four or More Intraluminal Devices, Open Approach */
"04790Z6" = "1" /* Dilation of Right Renal Artery, Bifurcation, Open Approach */
"04790ZZ" = "1" /* Dilation of Right Renal Artery, Open Approach */
"047A046" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047A04Z" = "1" /* Dilation of Left Renal Artery with Drug-eluting Intraluminal Device, Open Approach */
"047A056" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047A05Z" = "1" /* Dilation of Left Renal Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047A066" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047A06Z" = "1" /* Dilation of Left Renal Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047A076" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047A07Z" = "1" /* Dilation of Left Renal Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047A0D6" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047A0DZ" = "1" /* Dilation of Left Renal Artery with Intraluminal Device, Open Approach */
"047A0E6" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047A0EZ" = "1" /* Dilation of Left Renal Artery with Two Intraluminal Devices, Open Approach */
"047A0F6" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047A0FZ" = "1" /* Dilation of Left Renal Artery with Three Intraluminal Devices, Open Approach */
"047A0G6" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047A0GZ" = "1" /* Dilation of Left Renal Artery with Four or More Intraluminal Devices, Open Approach */
"047A0Z6" = "1" /* Dilation of Left Renal Artery, Bifurcation, Open Approach */
"047A0ZZ" = "1" /* Dilation of Left Renal Artery, Open Approach */
"047B046" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047B04Z" = "1" /* Dilation of Inferior Mesenteric Artery with Drug-eluting Intraluminal Device, Open Approach */
"047B056" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047B05Z" = "1" /* Dilation of Inferior Mesenteric Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047B066" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047B06Z" = "1" /* Dilation of Inferior Mesenteric Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047B076" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047B07Z" = "1" /* Dilation of Inferior Mesenteric Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047B0D6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047B0DZ" = "1" /* Dilation of Inferior Mesenteric Artery with Intraluminal Device, Open Approach */
"047B0E6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047B0EZ" = "1" /* Dilation of Inferior Mesenteric Artery with Two Intraluminal Devices, Open Approach */
"047B0F6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047B0FZ" = "1" /* Dilation of Inferior Mesenteric Artery with Three Intraluminal Devices, Open Approach */
"047B0G6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047B0GZ" = "1" /* Dilation of Inferior Mesenteric Artery with Four or More Intraluminal Devices, Open Approach */
"047B0Z6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, Open Approach */
"047B0ZZ" = "1" /* Dilation of Inferior Mesenteric Artery, Open Approach */
"047C046" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047C04Z" = "1" /* Dilation of Right Common Iliac Artery with Drug-eluting Intraluminal Device, Open Approach */
"047C056" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047C05Z" = "1" /* Dilation of Right Common Iliac Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047C066" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047C06Z" = "1" /* Dilation of Right Common Iliac Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047C076" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047C07Z" = "1" /* Dilation of Right Common Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047C0D6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047C0DZ" = "1" /* Dilation of Right Common Iliac Artery with Intraluminal Device, Open Approach */
"047C0E6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047C0EZ" = "1" /* Dilation of Right Common Iliac Artery with Two Intraluminal Devices, Open Approach */
"047C0F6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047C0FZ" = "1" /* Dilation of Right Common Iliac Artery with Three Intraluminal Devices, Open Approach */
"047C0G6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047C0GZ" = "1" /* Dilation of Right Common Iliac Artery with Four or More Intraluminal Devices, Open Approach */
"047C0Z6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, Open Approach */
"047C0ZZ" = "1" /* Dilation of Right Common Iliac Artery, Open Approach */
"047D046" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047D04Z" = "1" /* Dilation of Left Common Iliac Artery with Drug-eluting Intraluminal Device, Open Approach */
"047D056" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047D05Z" = "1" /* Dilation of Left Common Iliac Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047D066" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047D06Z" = "1" /* Dilation of Left Common Iliac Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047D076" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047D07Z" = "1" /* Dilation of Left Common Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047D0D6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047D0DZ" = "1" /* Dilation of Left Common Iliac Artery with Intraluminal Device, Open Approach */
"047D0E6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047D0EZ" = "1" /* Dilation of Left Common Iliac Artery with Two Intraluminal Devices, Open Approach */
"047D0F6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047D0FZ" = "1" /* Dilation of Left Common Iliac Artery with Three Intraluminal Devices, Open Approach */
"047D0G6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047D0GZ" = "1" /* Dilation of Left Common Iliac Artery with Four or More Intraluminal Devices, Open Approach */
"047D0Z6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, Open Approach */
"047D0ZZ" = "1" /* Dilation of Left Common Iliac Artery, Open Approach */
"047E046" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047E04Z" = "1" /* Dilation of Right Internal Iliac Artery with Drug-eluting Intraluminal Device, Open Approach */
"047E056" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047E05Z" = "1" /* Dilation of Right Internal Iliac Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047E066" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047E06Z" = "1" /* Dilation of Right Internal Iliac Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047E076" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047E07Z" = "1" /* Dilation of Right Internal Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047E0D6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047E0DZ" = "1" /* Dilation of Right Internal Iliac Artery with Intraluminal Device, Open Approach */
"047E0E6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047E0EZ" = "1" /* Dilation of Right Internal Iliac Artery with Two Intraluminal Devices, Open Approach */
"047E0F6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047E0FZ" = "1" /* Dilation of Right Internal Iliac Artery with Three Intraluminal Devices, Open Approach */
"047E0G6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047E0GZ" = "1" /* Dilation of Right Internal Iliac Artery with Four or More Intraluminal Devices, Open Approach */
"047E0Z6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, Open Approach */
"047E0ZZ" = "1" /* Dilation of Right Internal Iliac Artery, Open Approach */
"047F046" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047F04Z" = "1" /* Dilation of Left Internal Iliac Artery with Drug-eluting Intraluminal Device, Open Approach */
"047F056" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047F05Z" = "1" /* Dilation of Left Internal Iliac Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047F066" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047F06Z" = "1" /* Dilation of Left Internal Iliac Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047F076" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047F07Z" = "1" /* Dilation of Left Internal Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047F0D6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047F0DZ" = "1" /* Dilation of Left Internal Iliac Artery with Intraluminal Device, Open Approach */
"047F0E6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047F0EZ" = "1" /* Dilation of Left Internal Iliac Artery with Two Intraluminal Devices, Open Approach */
"047F0F6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047F0FZ" = "1" /* Dilation of Left Internal Iliac Artery with Three Intraluminal Devices, Open Approach */
"047F0G6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047F0GZ" = "1" /* Dilation of Left Internal Iliac Artery with Four or More Intraluminal Devices, Open Approach */
"047F0Z6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, Open Approach */
"047F0ZZ" = "1" /* Dilation of Left Internal Iliac Artery, Open Approach */
"047H046" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047H04Z" = "1" /* Dilation of Right External Iliac Artery with Drug-eluting Intraluminal Device, Open Approach */
"047H056" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047H05Z" = "1" /* Dilation of Right External Iliac Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047H066" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047H06Z" = "1" /* Dilation of Right External Iliac Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047H076" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047H07Z" = "1" /* Dilation of Right External Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047H0D6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047H0DZ" = "1" /* Dilation of Right External Iliac Artery with Intraluminal Device, Open Approach */
"047H0E6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047H0EZ" = "1" /* Dilation of Right External Iliac Artery with Two Intraluminal Devices, Open Approach */
"047H0F6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047H0FZ" = "1" /* Dilation of Right External Iliac Artery with Three Intraluminal Devices, Open Approach */
"047H0G6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047H0GZ" = "1" /* Dilation of Right External Iliac Artery with Four or More Intraluminal Devices, Open Approach */
"047H0Z6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, Open Approach */
"047H0ZZ" = "1" /* Dilation of Right External Iliac Artery, Open Approach */
"047J046" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047J04Z" = "1" /* Dilation of Left External Iliac Artery with Drug-eluting Intraluminal Device, Open Approach */
"047J056" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047J05Z" = "1" /* Dilation of Left External Iliac Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047J066" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047J06Z" = "1" /* Dilation of Left External Iliac Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047J076" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047J07Z" = "1" /* Dilation of Left External Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047J0D6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047J0DZ" = "1" /* Dilation of Left External Iliac Artery with Intraluminal Device, Open Approach */
"047J0E6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047J0EZ" = "1" /* Dilation of Left External Iliac Artery with Two Intraluminal Devices, Open Approach */
"047J0F6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047J0FZ" = "1" /* Dilation of Left External Iliac Artery with Three Intraluminal Devices, Open Approach */
"047J0G6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047J0GZ" = "1" /* Dilation of Left External Iliac Artery with Four or More Intraluminal Devices, Open Approach */
"047J0Z6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, Open Approach */
"047J0ZZ" = "1" /* Dilation of Left External Iliac Artery, Open Approach */
"049000Z" = "1" /* Drainage of Abdominal Aorta with Drainage Device, Open Approach */
"04900ZX" = "1" /* Drainage of Abdominal Aorta, Open Approach, Diagnostic */
"04900ZZ" = "1" /* Drainage of Abdominal Aorta, Open Approach */
"049100Z" = "1" /* Drainage of Celiac Artery with Drainage Device, Open Approach */
"04910ZX" = "1" /* Drainage of Celiac Artery, Open Approach, Diagnostic */
"04910ZZ" = "1" /* Drainage of Celiac Artery, Open Approach */
"049200Z" = "1" /* Drainage of Gastric Artery with Drainage Device, Open Approach */
"04920ZX" = "1" /* Drainage of Gastric Artery, Open Approach, Diagnostic */
"04920ZZ" = "1" /* Drainage of Gastric Artery, Open Approach */
"049300Z" = "1" /* Drainage of Hepatic Artery with Drainage Device, Open Approach */
"04930ZX" = "1" /* Drainage of Hepatic Artery, Open Approach, Diagnostic */
"04930ZZ" = "1" /* Drainage of Hepatic Artery, Open Approach */
"049400Z" = "1" /* Drainage of Splenic Artery with Drainage Device, Open Approach */
"04940ZX" = "1" /* Drainage of Splenic Artery, Open Approach, Diagnostic */
"04940ZZ" = "1" /* Drainage of Splenic Artery, Open Approach */
"049500Z" = "1" /* Drainage of Superior Mesenteric Artery with Drainage Device, Open Approach */
"04950ZX" = "1" /* Drainage of Superior Mesenteric Artery, Open Approach, Diagnostic */
"04950ZZ" = "1" /* Drainage of Superior Mesenteric Artery, Open Approach */
"049600Z" = "1" /* Drainage of Right Colic Artery with Drainage Device, Open Approach */
"04960ZX" = "1" /* Drainage of Right Colic Artery, Open Approach, Diagnostic */
"04960ZZ" = "1" /* Drainage of Right Colic Artery, Open Approach */
"049700Z" = "1" /* Drainage of Left Colic Artery with Drainage Device, Open Approach */
"04970ZX" = "1" /* Drainage of Left Colic Artery, Open Approach, Diagnostic */
"04970ZZ" = "1" /* Drainage of Left Colic Artery, Open Approach */
"049800Z" = "1" /* Drainage of Middle Colic Artery with Drainage Device, Open Approach */
"04980ZX" = "1" /* Drainage of Middle Colic Artery, Open Approach, Diagnostic */
"04980ZZ" = "1" /* Drainage of Middle Colic Artery, Open Approach */
"049900Z" = "1" /* Drainage of Right Renal Artery with Drainage Device, Open Approach */
"04990ZX" = "1" /* Drainage of Right Renal Artery, Open Approach, Diagnostic */
"04990ZZ" = "1" /* Drainage of Right Renal Artery, Open Approach */
"049A00Z" = "1" /* Drainage of Left Renal Artery with Drainage Device, Open Approach */
"049A0ZX" = "1" /* Drainage of Left Renal Artery, Open Approach, Diagnostic */
"049A0ZZ" = "1" /* Drainage of Left Renal Artery, Open Approach */
"049B00Z" = "1" /* Drainage of Inferior Mesenteric Artery with Drainage Device, Open Approach */
"049B0ZX" = "1" /* Drainage of Inferior Mesenteric Artery, Open Approach, Diagnostic */
"049B0ZZ" = "1" /* Drainage of Inferior Mesenteric Artery, Open Approach */
"049C00Z" = "1" /* Drainage of Right Common Iliac Artery with Drainage Device, Open Approach */
"049C0ZX" = "1" /* Drainage of Right Common Iliac Artery, Open Approach, Diagnostic */
"049C0ZZ" = "1" /* Drainage of Right Common Iliac Artery, Open Approach */
"049D00Z" = "1" /* Drainage of Left Common Iliac Artery with Drainage Device, Open Approach */
"049D0ZX" = "1" /* Drainage of Left Common Iliac Artery, Open Approach, Diagnostic */
"049D0ZZ" = "1" /* Drainage of Left Common Iliac Artery, Open Approach */
"049E00Z" = "1" /* Drainage of Right Internal Iliac Artery with Drainage Device, Open Approach */
"049E0ZX" = "1" /* Drainage of Right Internal Iliac Artery, Open Approach, Diagnostic */
"049E0ZZ" = "1" /* Drainage of Right Internal Iliac Artery, Open Approach */
"049F00Z" = "1" /* Drainage of Left Internal Iliac Artery with Drainage Device, Open Approach */
"049F0ZX" = "1" /* Drainage of Left Internal Iliac Artery, Open Approach, Diagnostic */
"049F0ZZ" = "1" /* Drainage of Left Internal Iliac Artery, Open Approach */
"049H00Z" = "1" /* Drainage of Right External Iliac Artery with Drainage Device, Open Approach */
"049H0ZX" = "1" /* Drainage of Right External Iliac Artery, Open Approach, Diagnostic */
"049H0ZZ" = "1" /* Drainage of Right External Iliac Artery, Open Approach */
"049J00Z" = "1" /* Drainage of Left External Iliac Artery with Drainage Device, Open Approach */
"049J0ZX" = "1" /* Drainage of Left External Iliac Artery, Open Approach, Diagnostic */
"049J0ZZ" = "1" /* Drainage of Left External Iliac Artery, Open Approach */
"04B00ZX" = "1" /* Excision of Abdominal Aorta, Open Approach, Diagnostic */
"04B00ZZ" = "1" /* Excision of Abdominal Aorta, Open Approach */
"04B10ZX" = "1" /* Excision of Celiac Artery, Open Approach, Diagnostic */
"04B10ZZ" = "1" /* Excision of Celiac Artery, Open Approach */
"04B20ZX" = "1" /* Excision of Gastric Artery, Open Approach, Diagnostic */
"04B20ZZ" = "1" /* Excision of Gastric Artery, Open Approach */
"04B30ZX" = "1" /* Excision of Hepatic Artery, Open Approach, Diagnostic */
"04B30ZZ" = "1" /* Excision of Hepatic Artery, Open Approach */
"04B40ZX" = "1" /* Excision of Splenic Artery, Open Approach, Diagnostic */
"04B40ZZ" = "1" /* Excision of Splenic Artery, Open Approach */
"04B50ZX" = "1" /* Excision of Superior Mesenteric Artery, Open Approach, Diagnostic */
"04B50ZZ" = "1" /* Excision of Superior Mesenteric Artery, Open Approach */
"04B60ZX" = "1" /* Excision of Right Colic Artery, Open Approach, Diagnostic */
"04B60ZZ" = "1" /* Excision of Right Colic Artery, Open Approach */
"04B70ZX" = "1" /* Excision of Left Colic Artery, Open Approach, Diagnostic */
"04B70ZZ" = "1" /* Excision of Left Colic Artery, Open Approach */
"04B80ZX" = "1" /* Excision of Middle Colic Artery, Open Approach, Diagnostic */
"04B80ZZ" = "1" /* Excision of Middle Colic Artery, Open Approach */
"04B90ZX" = "1" /* Excision of Right Renal Artery, Open Approach, Diagnostic */
"04B90ZZ" = "1" /* Excision of Right Renal Artery, Open Approach */
"04BA0ZX" = "1" /* Excision of Left Renal Artery, Open Approach, Diagnostic */
"04BA0ZZ" = "1" /* Excision of Left Renal Artery, Open Approach */
"04BB0ZX" = "1" /* Excision of Inferior Mesenteric Artery, Open Approach, Diagnostic */
"04BB0ZZ" = "1" /* Excision of Inferior Mesenteric Artery, Open Approach */
"04BC0ZX" = "1" /* Excision of Right Common Iliac Artery, Open Approach, Diagnostic */
"04BC0ZZ" = "1" /* Excision of Right Common Iliac Artery, Open Approach */
"04BD0ZX" = "1" /* Excision of Left Common Iliac Artery, Open Approach, Diagnostic */
"04BD0ZZ" = "1" /* Excision of Left Common Iliac Artery, Open Approach */
"04BE0ZX" = "1" /* Excision of Right Internal Iliac Artery, Open Approach, Diagnostic */
"04BE0ZZ" = "1" /* Excision of Right Internal Iliac Artery, Open Approach */
"04BF0ZX" = "1" /* Excision of Left Internal Iliac Artery, Open Approach, Diagnostic */
"04BF0ZZ" = "1" /* Excision of Left Internal Iliac Artery, Open Approach */
"04BH0ZX" = "1" /* Excision of Right External Iliac Artery, Open Approach, Diagnostic */
"04BH0ZZ" = "1" /* Excision of Right External Iliac Artery, Open Approach */
"04BJ0ZX" = "1" /* Excision of Left External Iliac Artery, Open Approach, Diagnostic */
"04BJ0ZZ" = "1" /* Excision of Left External Iliac Artery, Open Approach */
"04C00Z6" = "1" /* Extirpation of Matter from Abdominal Aorta, Bifurcation, Open Approach */
"04C00ZZ" = "1" /* Extirpation of Matter from Abdominal Aorta, Open Approach */
"04C10Z6" = "1" /* Extirpation of Matter from Celiac Artery, Bifurcation, Open Approach */
"04C10ZZ" = "1" /* Extirpation of Matter from Celiac Artery, Open Approach */
"04C20Z6" = "1" /* Extirpation of Matter from Gastric Artery, Bifurcation, Open Approach */
"04C20ZZ" = "1" /* Extirpation of Matter from Gastric Artery, Open Approach */
"04C30Z6" = "1" /* Extirpation of Matter from Hepatic Artery, Bifurcation, Open Approach */
"04C30ZZ" = "1" /* Extirpation of Matter from Hepatic Artery, Open Approach */
"04C40Z6" = "1" /* Extirpation of Matter from Splenic Artery, Bifurcation, Open Approach */
"04C40ZZ" = "1" /* Extirpation of Matter from Splenic Artery, Open Approach */
"04C50Z6" = "1" /* Extirpation of Matter from Superior Mesenteric Artery, Bifurcation, Open Approach */
"04C50ZZ" = "1" /* Extirpation of Matter from Superior Mesenteric Artery, Open Approach */
"04C60Z6" = "1" /* Extirpation of Matter from Right Colic Artery, Bifurcation, Open Approach */
"04C60ZZ" = "1" /* Extirpation of Matter from Right Colic Artery, Open Approach */
"04C70Z6" = "1" /* Extirpation of Matter from Left Colic Artery, Bifurcation, Open Approach */
"04C70ZZ" = "1" /* Extirpation of Matter from Left Colic Artery, Open Approach */
"04C80Z6" = "1" /* Extirpation of Matter from Middle Colic Artery, Bifurcation, Open Approach */
"04C80ZZ" = "1" /* Extirpation of Matter from Middle Colic Artery, Open Approach */
"04C90Z6" = "1" /* Extirpation of Matter from Right Renal Artery, Bifurcation, Open Approach */
"04C90ZZ" = "1" /* Extirpation of Matter from Right Renal Artery, Open Approach */
"04CA0Z6" = "1" /* Extirpation of Matter from Left Renal Artery, Bifurcation, Open Approach */
"04CA0ZZ" = "1" /* Extirpation of Matter from Left Renal Artery, Open Approach */
"04CB0Z6" = "1" /* Extirpation of Matter from Inferior Mesenteric Artery, Bifurcation, Open Approach */
"04CB0ZZ" = "1" /* Extirpation of Matter from Inferior Mesenteric Artery, Open Approach */
"04CC0Z6" = "1" /* Extirpation of Matter from Right Common Iliac Artery, Bifurcation, Open Approach */
"04CC0ZZ" = "1" /* Extirpation of Matter from Right Common Iliac Artery, Open Approach */
"04CD0Z6" = "1" /* Extirpation of Matter from Left Common Iliac Artery, Bifurcation, Open Approach */
"04CD0ZZ" = "1" /* Extirpation of Matter from Left Common Iliac Artery, Open Approach */
"04CE0Z6" = "1" /* Extirpation of Matter from Right Internal Iliac Artery, Bifurcation, Open Approach */
"04CE0ZZ" = "1" /* Extirpation of Matter from Right Internal Iliac Artery, Open Approach */
"04CF0Z6" = "1" /* Extirpation of Matter from Left Internal Iliac Artery, Bifurcation, Open Approach */
"04CF0ZZ" = "1" /* Extirpation of Matter from Left Internal Iliac Artery, Open Approach */
"04CH0Z6" = "1" /* Extirpation of Matter from Right External Iliac Artery, Bifurcation, Open Approach */
"04CH0ZZ" = "1" /* Extirpation of Matter from Right External Iliac Artery, Open Approach */
"04CJ0Z6" = "1" /* Extirpation of Matter from Left External Iliac Artery, Bifurcation, Open Approach */
"04CJ0ZZ" = "1" /* Extirpation of Matter from Left External Iliac Artery, Open Approach */
"04H002Z" = "1" /* Insertion of Monitoring Device into Abdominal Aorta, Open Approach */
"04H003Z" = "1" /* Insertion of Infusion Device into Abdominal Aorta, Open Approach */
"04H00DZ" = "1" /* Insertion of Intraluminal Device into Abdominal Aorta, Open Approach */
"04H103Z" = "1" /* Insertion of Infusion Device into Celiac Artery, Open Approach */
"04H10DZ" = "1" /* Insertion of Intraluminal Device into Celiac Artery, Open Approach */
"04H203Z" = "1" /* Insertion of Infusion Device into Gastric Artery, Open Approach */
"04H20DZ" = "1" /* Insertion of Intraluminal Device into Gastric Artery, Open Approach */
"04H303Z" = "1" /* Insertion of Infusion Device into Hepatic Artery, Open Approach */
"04H30DZ" = "1" /* Insertion of Intraluminal Device into Hepatic Artery, Open Approach */
"04H403Z" = "1" /* Insertion of Infusion Device into Splenic Artery, Open Approach */
"04H40DZ" = "1" /* Insertion of Intraluminal Device into Splenic Artery, Open Approach */
"04H503Z" = "1" /* Insertion of Infusion Device into Superior Mesenteric Artery, Open Approach */
"04H50DZ" = "1" /* Insertion of Intraluminal Device into Superior Mesenteric Artery, Open Approach */
"04H603Z" = "1" /* Insertion of Infusion Device into Right Colic Artery, Open Approach */
"04H60DZ" = "1" /* Insertion of Intraluminal Device into Right Colic Artery, Open Approach */
"04H703Z" = "1" /* Insertion of Infusion Device into Left Colic Artery, Open Approach */
"04H70DZ" = "1" /* Insertion of Intraluminal Device into Left Colic Artery, Open Approach */
"04H803Z" = "1" /* Insertion of Infusion Device into Middle Colic Artery, Open Approach */
"04H80DZ" = "1" /* Insertion of Intraluminal Device into Middle Colic Artery, Open Approach */
"04H903Z" = "1" /* Insertion of Infusion Device into Right Renal Artery, Open Approach */
"04H90DZ" = "1" /* Insertion of Intraluminal Device into Right Renal Artery, Open Approach */
"04HA03Z" = "1" /* Insertion of Infusion Device into Left Renal Artery, Open Approach */
"04HA0DZ" = "1" /* Insertion of Intraluminal Device into Left Renal Artery, Open Approach */
"04HB03Z" = "1" /* Insertion of Infusion Device into Inferior Mesenteric Artery, Open Approach */
"04HB0DZ" = "1" /* Insertion of Intraluminal Device into Inferior Mesenteric Artery, Open Approach */
"04HC03Z" = "1" /* Insertion of Infusion Device into Right Common Iliac Artery, Open Approach */
"04HC0DZ" = "1" /* Insertion of Intraluminal Device into Right Common Iliac Artery, Open Approach */
"04HD03Z" = "1" /* Insertion of Infusion Device into Left Common Iliac Artery, Open Approach */
"04HD0DZ" = "1" /* Insertion of Intraluminal Device into Left Common Iliac Artery, Open Approach */
"04HE03Z" = "1" /* Insertion of Infusion Device into Right Internal Iliac Artery, Open Approach */
"04HE0DZ" = "1" /* Insertion of Intraluminal Device into Right Internal Iliac Artery, Open Approach */
"04HF03Z" = "1" /* Insertion of Infusion Device into Left Internal Iliac Artery, Open Approach */
"04HF0DZ" = "1" /* Insertion of Intraluminal Device into Left Internal Iliac Artery, Open Approach */
"04HH03Z" = "1" /* Insertion of Infusion Device into Right External Iliac Artery, Open Approach */
"04HH0DZ" = "1" /* Insertion of Intraluminal Device into Right External Iliac Artery, Open Approach */
"04HJ03Z" = "1" /* Insertion of Infusion Device into Left External Iliac Artery, Open Approach */
"04HJ0DZ" = "1" /* Insertion of Intraluminal Device into Left External Iliac Artery, Open Approach */
"04L00CZ" = "1" /* Occlusion of Abdominal Aorta with Extraluminal Device, Open Approach */
"04L00DZ" = "1" /* Occlusion of Abdominal Aorta with Intraluminal Device, Open Approach */
"04L00ZZ" = "1" /* Occlusion of Abdominal Aorta, Open Approach */
"04L10CZ" = "1" /* Occlusion of Celiac Artery with Extraluminal Device, Open Approach */
"04L10DZ" = "1" /* Occlusion of Celiac Artery with Intraluminal Device, Open Approach */
"04L10ZZ" = "1" /* Occlusion of Celiac Artery, Open Approach */
"04L20CZ" = "1" /* Occlusion of Gastric Artery with Extraluminal Device, Open Approach */
"04L20DZ" = "1" /* Occlusion of Gastric Artery with Intraluminal Device, Open Approach */
"04L20ZZ" = "1" /* Occlusion of Gastric Artery, Open Approach */
"04L30CZ" = "1" /* Occlusion of Hepatic Artery with Extraluminal Device, Open Approach */
"04L30DZ" = "1" /* Occlusion of Hepatic Artery with Intraluminal Device, Open Approach */
"04L30ZZ" = "1" /* Occlusion of Hepatic Artery, Open Approach */
"04L40CZ" = "1" /* Occlusion of Splenic Artery with Extraluminal Device, Open Approach */
"04L40DZ" = "1" /* Occlusion of Splenic Artery with Intraluminal Device, Open Approach */
"04L40ZZ" = "1" /* Occlusion of Splenic Artery, Open Approach */
"04L50CZ" = "1" /* Occlusion of Superior Mesenteric Artery with Extraluminal Device, Open Approach */
"04L50DZ" = "1" /* Occlusion of Superior Mesenteric Artery with Intraluminal Device, Open Approach */
"04L50ZZ" = "1" /* Occlusion of Superior Mesenteric Artery, Open Approach */
"04L60CZ" = "1" /* Occlusion of Right Colic Artery with Extraluminal Device, Open Approach */
"04L60DZ" = "1" /* Occlusion of Right Colic Artery with Intraluminal Device, Open Approach */
"04L60ZZ" = "1" /* Occlusion of Right Colic Artery, Open Approach */
"04L70CZ" = "1" /* Occlusion of Left Colic Artery with Extraluminal Device, Open Approach */
"04L70DZ" = "1" /* Occlusion of Left Colic Artery with Intraluminal Device, Open Approach */
"04L70ZZ" = "1" /* Occlusion of Left Colic Artery, Open Approach */
"04L80CZ" = "1" /* Occlusion of Middle Colic Artery with Extraluminal Device, Open Approach */
"04L80DZ" = "1" /* Occlusion of Middle Colic Artery with Intraluminal Device, Open Approach */
"04L80ZZ" = "1" /* Occlusion of Middle Colic Artery, Open Approach */
"04L90CZ" = "1" /* Occlusion of Right Renal Artery with Extraluminal Device, Open Approach */
"04L90DZ" = "1" /* Occlusion of Right Renal Artery with Intraluminal Device, Open Approach */
"04L90ZZ" = "1" /* Occlusion of Right Renal Artery, Open Approach */
"04LA0CZ" = "1" /* Occlusion of Left Renal Artery with Extraluminal Device, Open Approach */
"04LA0DZ" = "1" /* Occlusion of Left Renal Artery with Intraluminal Device, Open Approach */
"04LA0ZZ" = "1" /* Occlusion of Left Renal Artery, Open Approach */
"04LB0CZ" = "1" /* Occlusion of Inferior Mesenteric Artery with Extraluminal Device, Open Approach */
"04LB0DZ" = "1" /* Occlusion of Inferior Mesenteric Artery with Intraluminal Device, Open Approach */
"04LB0ZZ" = "1" /* Occlusion of Inferior Mesenteric Artery, Open Approach */
"04LC0CZ" = "1" /* Occlusion of Right Common Iliac Artery with Extraluminal Device, Open Approach */
"04LC0DZ" = "1" /* Occlusion of Right Common Iliac Artery with Intraluminal Device, Open Approach */
"04LC0ZZ" = "1" /* Occlusion of Right Common Iliac Artery, Open Approach */
"04LD0CZ" = "1" /* Occlusion of Left Common Iliac Artery with Extraluminal Device, Open Approach */
"04LD0DZ" = "1" /* Occlusion of Left Common Iliac Artery with Intraluminal Device, Open Approach */
"04LD0ZZ" = "1" /* Occlusion of Left Common Iliac Artery, Open Approach */
"04LE0CT" = "1" /* Occlusion of Right Uterine Artery with Extraluminal Device, Open Approach */
"04LE0CZ" = "1" /* Occlusion of Right Internal Iliac Artery with Extraluminal Device, Open Approach */
"04LE0DT" = "1" /* Occlusion of Right Uterine Artery with Intraluminal Device, Open Approach */
"04LE0DZ" = "1" /* Occlusion of Right Internal Iliac Artery with Intraluminal Device, Open Approach */
"04LE0ZT" = "1" /* Occlusion of Right Uterine Artery, Open Approach */
"04LE0ZZ" = "1" /* Occlusion of Right Internal Iliac Artery, Open Approach */
"04LF0CU" = "1" /* Occlusion of Left Uterine Artery with Extraluminal Device, Open Approach */
"04LF0CZ" = "1" /* Occlusion of Left Internal Iliac Artery with Extraluminal Device, Open Approach */
"04LF0DU" = "1" /* Occlusion of Left Uterine Artery with Intraluminal Device, Open Approach */
"04LF0DZ" = "1" /* Occlusion of Left Internal Iliac Artery with Intraluminal Device, Open Approach */
"04LF0ZU" = "1" /* Occlusion of Left Uterine Artery, Open Approach */
"04LF0ZZ" = "1" /* Occlusion of Left Internal Iliac Artery, Open Approach */
"04LH0CZ" = "1" /* Occlusion of Right External Iliac Artery with Extraluminal Device, Open Approach */
"04LH0DZ" = "1" /* Occlusion of Right External Iliac Artery with Intraluminal Device, Open Approach */
"04LH0ZZ" = "1" /* Occlusion of Right External Iliac Artery, Open Approach */
"04LJ0CZ" = "1" /* Occlusion of Left External Iliac Artery with Extraluminal Device, Open Approach */
"04LJ0DZ" = "1" /* Occlusion of Left External Iliac Artery with Intraluminal Device, Open Approach */
"04LJ0ZZ" = "1" /* Occlusion of Left External Iliac Artery, Open Approach */
"04N00ZZ" = "1" /* Release Abdominal Aorta, Open Approach */
"04N10ZZ" = "1" /* Release Celiac Artery, Open Approach */
"04N20ZZ" = "1" /* Release Gastric Artery, Open Approach */
"04N30ZZ" = "1" /* Release Hepatic Artery, Open Approach */
"04N40ZZ" = "1" /* Release Splenic Artery, Open Approach */
"04N50ZZ" = "1" /* Release Superior Mesenteric Artery, Open Approach */
"04N60ZZ" = "1" /* Release Right Colic Artery, Open Approach */
"04N70ZZ" = "1" /* Release Left Colic Artery, Open Approach */
"04N80ZZ" = "1" /* Release Middle Colic Artery, Open Approach */
"04N90ZZ" = "1" /* Release Right Renal Artery, Open Approach */
"04NA0ZZ" = "1" /* Release Left Renal Artery, Open Approach */
"04NB0ZZ" = "1" /* Release Inferior Mesenteric Artery, Open Approach */
"04NC0ZZ" = "1" /* Release Right Common Iliac Artery, Open Approach */
"04ND0ZZ" = "1" /* Release Left Common Iliac Artery, Open Approach */
"04NE0ZZ" = "1" /* Release Right Internal Iliac Artery, Open Approach */
"04NF0ZZ" = "1" /* Release Left Internal Iliac Artery, Open Approach */
"04NH0ZZ" = "1" /* Release Right External Iliac Artery, Open Approach */
"04NJ0ZZ" = "1" /* Release Left External Iliac Artery, Open Approach */
"04Q00ZZ" = "1" /* Repair Abdominal Aorta, Open Approach */
"04Q10ZZ" = "1" /* Repair Celiac Artery, Open Approach */
"04Q20ZZ" = "1" /* Repair Gastric Artery, Open Approach */
"04Q30ZZ" = "1" /* Repair Hepatic Artery, Open Approach */
"04Q40ZZ" = "1" /* Repair Splenic Artery, Open Approach */
"04Q50ZZ" = "1" /* Repair Superior Mesenteric Artery, Open Approach */
"04Q60ZZ" = "1" /* Repair Right Colic Artery, Open Approach */
"04Q70ZZ" = "1" /* Repair Left Colic Artery, Open Approach */
"04Q80ZZ" = "1" /* Repair Middle Colic Artery, Open Approach */
"04Q90ZZ" = "1" /* Repair Right Renal Artery, Open Approach */
"04QA0ZZ" = "1" /* Repair Left Renal Artery, Open Approach */
"04QB0ZZ" = "1" /* Repair Inferior Mesenteric Artery, Open Approach */
"04QC0ZZ" = "1" /* Repair Right Common Iliac Artery, Open Approach */
"04QD0ZZ" = "1" /* Repair Left Common Iliac Artery, Open Approach */
"04QE0ZZ" = "1" /* Repair Right Internal Iliac Artery, Open Approach */
"04QF0ZZ" = "1" /* Repair Left Internal Iliac Artery, Open Approach */
"04QH0ZZ" = "1" /* Repair Right External Iliac Artery, Open Approach */
"04QJ0ZZ" = "1" /* Repair Left External Iliac Artery, Open Approach */
"04R007Z" = "1" /* Replacement of Abdominal Aorta with Autologous Tissue Substitute, Open Approach */
"04R00JZ" = "1" /* Replacement of Abdominal Aorta with Synthetic Substitute, Open Approach */
"04R00KZ" = "1" /* Replacement of Abdominal Aorta with Nonautologous Tissue Substitute, Open Approach */
"04R107Z" = "1" /* Replacement of Celiac Artery with Autologous Tissue Substitute, Open Approach */
"04R10JZ" = "1" /* Replacement of Celiac Artery with Synthetic Substitute, Open Approach */
"04R10KZ" = "1" /* Replacement of Celiac Artery with Nonautologous Tissue Substitute, Open Approach */
"04R207Z" = "1" /* Replacement of Gastric Artery with Autologous Tissue Substitute, Open Approach */
"04R20JZ" = "1" /* Replacement of Gastric Artery with Synthetic Substitute, Open Approach */
"04R20KZ" = "1" /* Replacement of Gastric Artery with Nonautologous Tissue Substitute, Open Approach */
"04R307Z" = "1" /* Replacement of Hepatic Artery with Autologous Tissue Substitute, Open Approach */
"04R30JZ" = "1" /* Replacement of Hepatic Artery with Synthetic Substitute, Open Approach */
"04R30KZ" = "1" /* Replacement of Hepatic Artery with Nonautologous Tissue Substitute, Open Approach */
"04R407Z" = "1" /* Replacement of Splenic Artery with Autologous Tissue Substitute, Open Approach */
"04R40JZ" = "1" /* Replacement of Splenic Artery with Synthetic Substitute, Open Approach */
"04R40KZ" = "1" /* Replacement of Splenic Artery with Nonautologous Tissue Substitute, Open Approach */
"04R507Z" = "1" /* Replacement of Superior Mesenteric Artery with Autologous Tissue Substitute, Open Approach */
"04R50JZ" = "1" /* Replacement of Superior Mesenteric Artery with Synthetic Substitute, Open Approach */
"04R50KZ" = "1" /* Replacement of Superior Mesenteric Artery with Nonautologous Tissue Substitute, Open Approach */
"04R607Z" = "1" /* Replacement of Right Colic Artery with Autologous Tissue Substitute, Open Approach */
"04R60JZ" = "1" /* Replacement of Right Colic Artery with Synthetic Substitute, Open Approach */
"04R60KZ" = "1" /* Replacement of Right Colic Artery with Nonautologous Tissue Substitute, Open Approach */
"04R707Z" = "1" /* Replacement of Left Colic Artery with Autologous Tissue Substitute, Open Approach */
"04R70JZ" = "1" /* Replacement of Left Colic Artery with Synthetic Substitute, Open Approach */
"04R70KZ" = "1" /* Replacement of Left Colic Artery with Nonautologous Tissue Substitute, Open Approach */
"04R807Z" = "1" /* Replacement of Middle Colic Artery with Autologous Tissue Substitute, Open Approach */
"04R80JZ" = "1" /* Replacement of Middle Colic Artery with Synthetic Substitute, Open Approach */
"04R80KZ" = "1" /* Replacement of Middle Colic Artery with Nonautologous Tissue Substitute, Open Approach */
"04R907Z" = "1" /* Replacement of Right Renal Artery with Autologous Tissue Substitute, Open Approach */
"04R90JZ" = "1" /* Replacement of Right Renal Artery with Synthetic Substitute, Open Approach */
"04R90KZ" = "1" /* Replacement of Right Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"04RA07Z" = "1" /* Replacement of Left Renal Artery with Autologous Tissue Substitute, Open Approach */
"04RA0JZ" = "1" /* Replacement of Left Renal Artery with Synthetic Substitute, Open Approach */
"04RA0KZ" = "1" /* Replacement of Left Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"04RB07Z" = "1" /* Replacement of Inferior Mesenteric Artery with Autologous Tissue Substitute, Open Approach */
"04RB0JZ" = "1" /* Replacement of Inferior Mesenteric Artery with Synthetic Substitute, Open Approach */
"04RB0KZ" = "1" /* Replacement of Inferior Mesenteric Artery with Nonautologous Tissue Substitute, Open Approach */
"04RC07Z" = "1" /* Replacement of Right Common Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04RC0JZ" = "1" /* Replacement of Right Common Iliac Artery with Synthetic Substitute, Open Approach */
"04RC0KZ" = "1" /* Replacement of Right Common Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04RD07Z" = "1" /* Replacement of Left Common Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04RD0JZ" = "1" /* Replacement of Left Common Iliac Artery with Synthetic Substitute, Open Approach */
"04RD0KZ" = "1" /* Replacement of Left Common Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04RE07Z" = "1" /* Replacement of Right Internal Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04RE0JZ" = "1" /* Replacement of Right Internal Iliac Artery with Synthetic Substitute, Open Approach */
"04RE0KZ" = "1" /* Replacement of Right Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04RF07Z" = "1" /* Replacement of Left Internal Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04RF0JZ" = "1" /* Replacement of Left Internal Iliac Artery with Synthetic Substitute, Open Approach */
"04RF0KZ" = "1" /* Replacement of Left Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04RH07Z" = "1" /* Replacement of Right External Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04RH0JZ" = "1" /* Replacement of Right External Iliac Artery with Synthetic Substitute, Open Approach */
"04RH0KZ" = "1" /* Replacement of Right External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04RJ07Z" = "1" /* Replacement of Left External Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04RJ0JZ" = "1" /* Replacement of Left External Iliac Artery with Synthetic Substitute, Open Approach */
"04RJ0KZ" = "1" /* Replacement of Left External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04S00ZZ" = "1" /* Reposition Abdominal Aorta, Open Approach */
"04S10ZZ" = "1" /* Reposition Celiac Artery, Open Approach */
"04S20ZZ" = "1" /* Reposition Gastric Artery, Open Approach */
"04S30ZZ" = "1" /* Reposition Hepatic Artery, Open Approach */
"04S40ZZ" = "1" /* Reposition Splenic Artery, Open Approach */
"04S50ZZ" = "1" /* Reposition Superior Mesenteric Artery, Open Approach */
"04S60ZZ" = "1" /* Reposition Right Colic Artery, Open Approach */
"04S70ZZ" = "1" /* Reposition Left Colic Artery, Open Approach */
"04S80ZZ" = "1" /* Reposition Middle Colic Artery, Open Approach */
"04S90ZZ" = "1" /* Reposition Right Renal Artery, Open Approach */
"04SA0ZZ" = "1" /* Reposition Left Renal Artery, Open Approach */
"04SB0ZZ" = "1" /* Reposition Inferior Mesenteric Artery, Open Approach */
"04SC0ZZ" = "1" /* Reposition Right Common Iliac Artery, Open Approach */
"04SD0ZZ" = "1" /* Reposition Left Common Iliac Artery, Open Approach */
"04SE0ZZ" = "1" /* Reposition Right Internal Iliac Artery, Open Approach */
"04SF0ZZ" = "1" /* Reposition Left Internal Iliac Artery, Open Approach */
"04SH0ZZ" = "1" /* Reposition Right External Iliac Artery, Open Approach */
"04SJ0ZZ" = "1" /* Reposition Left External Iliac Artery, Open Approach */
"04U007Z" = "1" /* Supplement Abdominal Aorta with Autologous Tissue Substitute, Open Approach */
"04U00JZ" = "1" /* Supplement Abdominal Aorta with Synthetic Substitute, Open Approach */
"04U00KZ" = "1" /* Supplement Abdominal Aorta with Nonautologous Tissue Substitute, Open Approach */
"04U107Z" = "1" /* Supplement Celiac Artery with Autologous Tissue Substitute, Open Approach */
"04U10JZ" = "1" /* Supplement Celiac Artery with Synthetic Substitute, Open Approach */
"04U10KZ" = "1" /* Supplement Celiac Artery with Nonautologous Tissue Substitute, Open Approach */
"04U207Z" = "1" /* Supplement Gastric Artery with Autologous Tissue Substitute, Open Approach */
"04U20JZ" = "1" /* Supplement Gastric Artery with Synthetic Substitute, Open Approach */
"04U20KZ" = "1" /* Supplement Gastric Artery with Nonautologous Tissue Substitute, Open Approach */
"04U307Z" = "1" /* Supplement Hepatic Artery with Autologous Tissue Substitute, Open Approach */
"04U30JZ" = "1" /* Supplement Hepatic Artery with Synthetic Substitute, Open Approach */
"04U30KZ" = "1" /* Supplement Hepatic Artery with Nonautologous Tissue Substitute, Open Approach */
"04U407Z" = "1" /* Supplement Splenic Artery with Autologous Tissue Substitute, Open Approach */
"04U40JZ" = "1" /* Supplement Splenic Artery with Synthetic Substitute, Open Approach */
"04U40KZ" = "1" /* Supplement Splenic Artery with Nonautologous Tissue Substitute, Open Approach */
"04U507Z" = "1" /* Supplement Superior Mesenteric Artery with Autologous Tissue Substitute, Open Approach */
"04U50JZ" = "1" /* Supplement Superior Mesenteric Artery with Synthetic Substitute, Open Approach */
"04U50KZ" = "1" /* Supplement Superior Mesenteric Artery with Nonautologous Tissue Substitute, Open Approach */
"04U607Z" = "1" /* Supplement Right Colic Artery with Autologous Tissue Substitute, Open Approach */
"04U60JZ" = "1" /* Supplement Right Colic Artery with Synthetic Substitute, Open Approach */
"04U60KZ" = "1" /* Supplement Right Colic Artery with Nonautologous Tissue Substitute, Open Approach */
"04U707Z" = "1" /* Supplement Left Colic Artery with Autologous Tissue Substitute, Open Approach */
"04U70JZ" = "1" /* Supplement Left Colic Artery with Synthetic Substitute, Open Approach */
"04U70KZ" = "1" /* Supplement Left Colic Artery with Nonautologous Tissue Substitute, Open Approach */
"04U807Z" = "1" /* Supplement Middle Colic Artery with Autologous Tissue Substitute, Open Approach */
"04U80JZ" = "1" /* Supplement Middle Colic Artery with Synthetic Substitute, Open Approach */
"04U80KZ" = "1" /* Supplement Middle Colic Artery with Nonautologous Tissue Substitute, Open Approach */
"04U907Z" = "1" /* Supplement Right Renal Artery with Autologous Tissue Substitute, Open Approach */
"04U90JZ" = "1" /* Supplement Right Renal Artery with Synthetic Substitute, Open Approach */
"04U90KZ" = "1" /* Supplement Right Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"04UA07Z" = "1" /* Supplement Left Renal Artery with Autologous Tissue Substitute, Open Approach */
"04UA0JZ" = "1" /* Supplement Left Renal Artery with Synthetic Substitute, Open Approach */
"04UA0KZ" = "1" /* Supplement Left Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"04UB07Z" = "1" /* Supplement Inferior Mesenteric Artery with Autologous Tissue Substitute, Open Approach */
"04UB0JZ" = "1" /* Supplement Inferior Mesenteric Artery with Synthetic Substitute, Open Approach */
"04UB0KZ" = "1" /* Supplement Inferior Mesenteric Artery with Nonautologous Tissue Substitute, Open Approach */
"04UC07Z" = "1" /* Supplement Right Common Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04UC0JZ" = "1" /* Supplement Right Common Iliac Artery with Synthetic Substitute, Open Approach */
"04UC0KZ" = "1" /* Supplement Right Common Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04UD07Z" = "1" /* Supplement Left Common Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04UD0JZ" = "1" /* Supplement Left Common Iliac Artery with Synthetic Substitute, Open Approach */
"04UD0KZ" = "1" /* Supplement Left Common Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04UE07Z" = "1" /* Supplement Right Internal Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04UE0JZ" = "1" /* Supplement Right Internal Iliac Artery with Synthetic Substitute, Open Approach */
"04UE0KZ" = "1" /* Supplement Right Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04UF07Z" = "1" /* Supplement Left Internal Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04UF0JZ" = "1" /* Supplement Left Internal Iliac Artery with Synthetic Substitute, Open Approach */
"04UF0KZ" = "1" /* Supplement Left Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04UH07Z" = "1" /* Supplement Right External Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04UH0JZ" = "1" /* Supplement Right External Iliac Artery with Synthetic Substitute, Open Approach */
"04UH0KZ" = "1" /* Supplement Right External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04UJ07Z" = "1" /* Supplement Left External Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04UJ0JZ" = "1" /* Supplement Left External Iliac Artery with Synthetic Substitute, Open Approach */
"04UJ0KZ" = "1" /* Supplement Left External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04V00C6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, with Extraluminal Device, Open Approach */
"04V00CZ" = "1" /* Restriction of Abdominal Aorta with Extraluminal Device, Open Approach */
"04V00D6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, with Intraluminal Device, Open Approach */
"04V00DJ" = "1" /* Restriction of Abdominal Aorta with Intraluminal Device, Temporary, Open Approach */
"04V00DZ" = "1" /* Restriction of Abdominal Aorta with Intraluminal Device, Open Approach */
"04V00E6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Open Approach */
"04V00EZ" = "1" /* Restriction of Abdominal Aorta with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Open Approach */
"04V00F6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Open Approach */
"04V00FZ" = "1" /* Restriction of Abdominal Aorta with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Open Approach */
"04V00Z6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, Open Approach */
"04V00ZZ" = "1" /* Restriction of Abdominal Aorta, Open Approach */
"04V10CZ" = "1" /* Restriction of Celiac Artery with Extraluminal Device, Open Approach */
"04V10DZ" = "1" /* Restriction of Celiac Artery with Intraluminal Device, Open Approach */
"04V10ZZ" = "1" /* Restriction of Celiac Artery, Open Approach */
"04V20CZ" = "1" /* Restriction of Gastric Artery with Extraluminal Device, Open Approach */
"04V20DZ" = "1" /* Restriction of Gastric Artery with Intraluminal Device, Open Approach */
"04V20ZZ" = "1" /* Restriction of Gastric Artery, Open Approach */
"04V30CZ" = "1" /* Restriction of Hepatic Artery with Extraluminal Device, Open Approach */
"04V30DZ" = "1" /* Restriction of Hepatic Artery with Intraluminal Device, Open Approach */
"04V30ZZ" = "1" /* Restriction of Hepatic Artery, Open Approach */
"04V40CZ" = "1" /* Restriction of Splenic Artery with Extraluminal Device, Open Approach */
"04V40DZ" = "1" /* Restriction of Splenic Artery with Intraluminal Device, Open Approach */
"04V40ZZ" = "1" /* Restriction of Splenic Artery, Open Approach */
"04V50CZ" = "1" /* Restriction of Superior Mesenteric Artery with Extraluminal Device, Open Approach */
"04V50DZ" = "1" /* Restriction of Superior Mesenteric Artery with Intraluminal Device, Open Approach */
"04V50ZZ" = "1" /* Restriction of Superior Mesenteric Artery, Open Approach */
"04V60CZ" = "1" /* Restriction of Right Colic Artery with Extraluminal Device, Open Approach */
"04V60DZ" = "1" /* Restriction of Right Colic Artery with Intraluminal Device, Open Approach */
"04V60ZZ" = "1" /* Restriction of Right Colic Artery, Open Approach */
"04V70CZ" = "1" /* Restriction of Left Colic Artery with Extraluminal Device, Open Approach */
"04V70DZ" = "1" /* Restriction of Left Colic Artery with Intraluminal Device, Open Approach */
"04V70ZZ" = "1" /* Restriction of Left Colic Artery, Open Approach */
"04V80CZ" = "1" /* Restriction of Middle Colic Artery with Extraluminal Device, Open Approach */
"04V80DZ" = "1" /* Restriction of Middle Colic Artery with Intraluminal Device, Open Approach */
"04V80ZZ" = "1" /* Restriction of Middle Colic Artery, Open Approach */
"04V90CZ" = "1" /* Restriction of Right Renal Artery with Extraluminal Device, Open Approach */
"04V90DZ" = "1" /* Restriction of Right Renal Artery with Intraluminal Device, Open Approach */
"04V90ZZ" = "1" /* Restriction of Right Renal Artery, Open Approach */
"04VA0CZ" = "1" /* Restriction of Left Renal Artery with Extraluminal Device, Open Approach */
"04VA0DZ" = "1" /* Restriction of Left Renal Artery with Intraluminal Device, Open Approach */
"04VA0ZZ" = "1" /* Restriction of Left Renal Artery, Open Approach */
"04VB0CZ" = "1" /* Restriction of Inferior Mesenteric Artery with Extraluminal Device, Open Approach */
"04VB0DZ" = "1" /* Restriction of Inferior Mesenteric Artery with Intraluminal Device, Open Approach */
"04VB0ZZ" = "1" /* Restriction of Inferior Mesenteric Artery, Open Approach */
"04VC0CZ" = "1" /* Restriction of Right Common Iliac Artery with Extraluminal Device, Open Approach */
"04VC0DZ" = "1" /* Restriction of Right Common Iliac Artery with Intraluminal Device, Open Approach */
"04VC0EZ" = "1" /* Restriction of Right Common Iliac Artery with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Open Approach */
"04VC0FZ" = "1" /* Restriction of Right Common Iliac Artery with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Open Approach */
"04VC0ZZ" = "1" /* Restriction of Right Common Iliac Artery, Open Approach */
"04VD0CZ" = "1" /* Restriction of Left Common Iliac Artery with Extraluminal Device, Open Approach */
"04VD0DZ" = "1" /* Restriction of Left Common Iliac Artery with Intraluminal Device, Open Approach */
"04VD0EZ" = "1" /* Restriction of Left Common Iliac Artery with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Open Approach */
"04VD0FZ" = "1" /* Restriction of Left Common Iliac Artery with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Open Approach */
"04VD0ZZ" = "1" /* Restriction of Left Common Iliac Artery, Open Approach */
"04VE0CZ" = "1" /* Restriction of Right Internal Iliac Artery with Extraluminal Device, Open Approach */
"04VE0DZ" = "1" /* Restriction of Right Internal Iliac Artery with Intraluminal Device, Open Approach */
"04VE0ZZ" = "1" /* Restriction of Right Internal Iliac Artery, Open Approach */
"04VF0CZ" = "1" /* Restriction of Left Internal Iliac Artery with Extraluminal Device, Open Approach */
"04VF0DZ" = "1" /* Restriction of Left Internal Iliac Artery with Intraluminal Device, Open Approach */
"04VF0ZZ" = "1" /* Restriction of Left Internal Iliac Artery, Open Approach */
"04VH0CZ" = "1" /* Restriction of Right External Iliac Artery with Extraluminal Device, Open Approach */
"04VH0DZ" = "1" /* Restriction of Right External Iliac Artery with Intraluminal Device, Open Approach */
"04VH0ZZ" = "1" /* Restriction of Right External Iliac Artery, Open Approach */
"04VJ0CZ" = "1" /* Restriction of Left External Iliac Artery with Extraluminal Device, Open Approach */
"04VJ0DZ" = "1" /* Restriction of Left External Iliac Artery with Intraluminal Device, Open Approach */
"04VJ0ZZ" = "1" /* Restriction of Left External Iliac Artery, Open Approach */
"0610075" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein with Autologous Tissue Substitute, Open Approach */
"0610076" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein with Autologous Tissue Substitute, Open Approach */
"061007Y" = "1" /* Bypass Inferior Vena Cava to Lower Vein with Autologous Tissue Substitute, Open Approach */
"0610095" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein with Autologous Venous Tissue, Open Approach */
"0610096" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein with Autologous Venous Tissue, Open Approach */
"061009Y" = "1" /* Bypass Inferior Vena Cava to Lower Vein with Autologous Venous Tissue, Open Approach */
"06100A5" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein with Autologous Arterial Tissue, Open Approach */
"06100A6" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein with Autologous Arterial Tissue, Open Approach */
"06100AY" = "1" /* Bypass Inferior Vena Cava to Lower Vein with Autologous Arterial Tissue, Open Approach */
"06100J5" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein with Synthetic Substitute, Open Approach */
"06100J6" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein with Synthetic Substitute, Open Approach */
"06100JY" = "1" /* Bypass Inferior Vena Cava to Lower Vein with Synthetic Substitute, Open Approach */
"06100K5" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein with Nonautologous Tissue Substitute, Open Approach */
"06100K6" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein with Nonautologous Tissue Substitute, Open Approach */
"06100KY" = "1" /* Bypass Inferior Vena Cava to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"06100Z5" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein, Open Approach */
"06100Z6" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein, Open Approach */
"06100ZY" = "1" /* Bypass Inferior Vena Cava to Lower Vein, Open Approach */
"0611079" = "1" /* Bypass Splenic Vein to Right Renal Vein with Autologous Tissue Substitute, Open Approach */
"061107B" = "1" /* Bypass Splenic Vein to Left Renal Vein with Autologous Tissue Substitute, Open Approach */
"061107Y" = "1" /* Bypass Splenic Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"0611099" = "1" /* Bypass Splenic Vein to Right Renal Vein with Autologous Venous Tissue, Open Approach */
"061109B" = "1" /* Bypass Splenic Vein to Left Renal Vein with Autologous Venous Tissue, Open Approach */
"061109Y" = "1" /* Bypass Splenic Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"06110A9" = "1" /* Bypass Splenic Vein to Right Renal Vein with Autologous Arterial Tissue, Open Approach */
"06110AB" = "1" /* Bypass Splenic Vein to Left Renal Vein with Autologous Arterial Tissue, Open Approach */
"06110AY" = "1" /* Bypass Splenic Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"06110J9" = "1" /* Bypass Splenic Vein to Right Renal Vein with Synthetic Substitute, Open Approach */
"06110JB" = "1" /* Bypass Splenic Vein to Left Renal Vein with Synthetic Substitute, Open Approach */
"06110JY" = "1" /* Bypass Splenic Vein to Lower Vein with Synthetic Substitute, Open Approach */
"06110K9" = "1" /* Bypass Splenic Vein to Right Renal Vein with Nonautologous Tissue Substitute, Open Approach */
"06110KB" = "1" /* Bypass Splenic Vein to Left Renal Vein with Nonautologous Tissue Substitute, Open Approach */
"06110KY" = "1" /* Bypass Splenic Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"06110Z9" = "1" /* Bypass Splenic Vein to Right Renal Vein, Open Approach */
"06110ZB" = "1" /* Bypass Splenic Vein to Left Renal Vein, Open Approach */
"06110ZY" = "1" /* Bypass Splenic Vein to Lower Vein, Open Approach */
"061207Y" = "1" /* Bypass Gastric Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061209Y" = "1" /* Bypass Gastric Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"06120AY" = "1" /* Bypass Gastric Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"06120JY" = "1" /* Bypass Gastric Vein to Lower Vein with Synthetic Substitute, Open Approach */
"06120KY" = "1" /* Bypass Gastric Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"06120ZY" = "1" /* Bypass Gastric Vein to Lower Vein, Open Approach */
"061307Y" = "1" /* Bypass Esophageal Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061309Y" = "1" /* Bypass Esophageal Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"06130AY" = "1" /* Bypass Esophageal Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"06130JY" = "1" /* Bypass Esophageal Vein to Lower Vein with Synthetic Substitute, Open Approach */
"06130KY" = "1" /* Bypass Esophageal Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"06130ZY" = "1" /* Bypass Esophageal Vein to Lower Vein, Open Approach */
"061407Y" = "1" /* Bypass Hepatic Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061409Y" = "1" /* Bypass Hepatic Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"06140AY" = "1" /* Bypass Hepatic Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"06140JY" = "1" /* Bypass Hepatic Vein to Lower Vein with Synthetic Substitute, Open Approach */
"06140KY" = "1" /* Bypass Hepatic Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"06140ZY" = "1" /* Bypass Hepatic Vein to Lower Vein, Open Approach */
"061507Y" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061509Y" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"06150AY" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"06150JY" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein with Synthetic Substitute, Open Approach */
"06150KY" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"06150ZY" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein, Open Approach */
"061607Y" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061609Y" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"06160AY" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"06160JY" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein with Synthetic Substitute, Open Approach */
"06160KY" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"06160ZY" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein, Open Approach */
"061707Y" = "1" /* Bypass Colic Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061709Y" = "1" /* Bypass Colic Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"06170AY" = "1" /* Bypass Colic Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"06170JY" = "1" /* Bypass Colic Vein to Lower Vein with Synthetic Substitute, Open Approach */
"06170KY" = "1" /* Bypass Colic Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"06170ZY" = "1" /* Bypass Colic Vein to Lower Vein, Open Approach */
"0618079" = "1" /* Bypass Portal Vein to Right Renal Vein with Autologous Tissue Substitute, Open Approach */
"061807B" = "1" /* Bypass Portal Vein to Left Renal Vein with Autologous Tissue Substitute, Open Approach */
"061807Y" = "1" /* Bypass Portal Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"0618099" = "1" /* Bypass Portal Vein to Right Renal Vein with Autologous Venous Tissue, Open Approach */
"061809B" = "1" /* Bypass Portal Vein to Left Renal Vein with Autologous Venous Tissue, Open Approach */
"061809Y" = "1" /* Bypass Portal Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"06180A9" = "1" /* Bypass Portal Vein to Right Renal Vein with Autologous Arterial Tissue, Open Approach */
"06180AB" = "1" /* Bypass Portal Vein to Left Renal Vein with Autologous Arterial Tissue, Open Approach */
"06180AY" = "1" /* Bypass Portal Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"06180J9" = "1" /* Bypass Portal Vein to Right Renal Vein with Synthetic Substitute, Open Approach */
"06180JB" = "1" /* Bypass Portal Vein to Left Renal Vein with Synthetic Substitute, Open Approach */
"06180JY" = "1" /* Bypass Portal Vein to Lower Vein with Synthetic Substitute, Open Approach */
"06180K9" = "1" /* Bypass Portal Vein to Right Renal Vein with Nonautologous Tissue Substitute, Open Approach */
"06180KB" = "1" /* Bypass Portal Vein to Left Renal Vein with Nonautologous Tissue Substitute, Open Approach */
"06180KY" = "1" /* Bypass Portal Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"06180Z9" = "1" /* Bypass Portal Vein to Right Renal Vein, Open Approach */
"06180ZB" = "1" /* Bypass Portal Vein to Left Renal Vein, Open Approach */
"06180ZY" = "1" /* Bypass Portal Vein to Lower Vein, Open Approach */
"061907Y" = "1" /* Bypass Right Renal Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061909Y" = "1" /* Bypass Right Renal Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"06190AY" = "1" /* Bypass Right Renal Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"06190JY" = "1" /* Bypass Right Renal Vein to Lower Vein with Synthetic Substitute, Open Approach */
"06190KY" = "1" /* Bypass Right Renal Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"06190ZY" = "1" /* Bypass Right Renal Vein to Lower Vein, Open Approach */
"061B07Y" = "1" /* Bypass Left Renal Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061B09Y" = "1" /* Bypass Left Renal Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"061B0AY" = "1" /* Bypass Left Renal Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"061B0JY" = "1" /* Bypass Left Renal Vein to Lower Vein with Synthetic Substitute, Open Approach */
"061B0KY" = "1" /* Bypass Left Renal Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"061B0ZY" = "1" /* Bypass Left Renal Vein to Lower Vein, Open Approach */
"061C07Y" = "1" /* Bypass Right Common Iliac Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061C09Y" = "1" /* Bypass Right Common Iliac Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"061C0AY" = "1" /* Bypass Right Common Iliac Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"061C0JY" = "1" /* Bypass Right Common Iliac Vein to Lower Vein with Synthetic Substitute, Open Approach */
"061C0KY" = "1" /* Bypass Right Common Iliac Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"061C0ZY" = "1" /* Bypass Right Common Iliac Vein to Lower Vein, Open Approach */
"061D07Y" = "1" /* Bypass Left Common Iliac Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061D09Y" = "1" /* Bypass Left Common Iliac Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"061D0AY" = "1" /* Bypass Left Common Iliac Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"061D0JY" = "1" /* Bypass Left Common Iliac Vein to Lower Vein with Synthetic Substitute, Open Approach */
"061D0KY" = "1" /* Bypass Left Common Iliac Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"061D0ZY" = "1" /* Bypass Left Common Iliac Vein to Lower Vein, Open Approach */
"061F07Y" = "1" /* Bypass Right External Iliac Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061F09Y" = "1" /* Bypass Right External Iliac Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"061F0AY" = "1" /* Bypass Right External Iliac Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"061F0JY" = "1" /* Bypass Right External Iliac Vein to Lower Vein with Synthetic Substitute, Open Approach */
"061F0KY" = "1" /* Bypass Right External Iliac Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"061F0ZY" = "1" /* Bypass Right External Iliac Vein to Lower Vein, Open Approach */
"061G07Y" = "1" /* Bypass Left External Iliac Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061G09Y" = "1" /* Bypass Left External Iliac Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"061G0AY" = "1" /* Bypass Left External Iliac Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"061G0JY" = "1" /* Bypass Left External Iliac Vein to Lower Vein with Synthetic Substitute, Open Approach */
"061G0KY" = "1" /* Bypass Left External Iliac Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"061G0ZY" = "1" /* Bypass Left External Iliac Vein to Lower Vein, Open Approach */
"061H07Y" = "1" /* Bypass Right Hypogastric Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061H09Y" = "1" /* Bypass Right Hypogastric Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"061H0AY" = "1" /* Bypass Right Hypogastric Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"061H0JY" = "1" /* Bypass Right Hypogastric Vein to Lower Vein with Synthetic Substitute, Open Approach */
"061H0KY" = "1" /* Bypass Right Hypogastric Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"061H0ZY" = "1" /* Bypass Right Hypogastric Vein to Lower Vein, Open Approach */
"061J07Y" = "1" /* Bypass Left Hypogastric Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061J09Y" = "1" /* Bypass Left Hypogastric Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"061J0AY" = "1" /* Bypass Left Hypogastric Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"061J0JY" = "1" /* Bypass Left Hypogastric Vein to Lower Vein with Synthetic Substitute, Open Approach */
"061J0KY" = "1" /* Bypass Left Hypogastric Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"061J0ZY" = "1" /* Bypass Left Hypogastric Vein to Lower Vein, Open Approach */
"06500ZZ" = "1" /* Destruction of Inferior Vena Cava, Open Approach */
"06510ZZ" = "1" /* Destruction of Splenic Vein, Open Approach */
"06520ZZ" = "1" /* Destruction of Gastric Vein, Open Approach */
"06530ZZ" = "1" /* Destruction of Esophageal Vein, Open Approach */
"06540ZZ" = "1" /* Destruction of Hepatic Vein, Open Approach */
"06550ZZ" = "1" /* Destruction of Superior Mesenteric Vein, Open Approach */
"06560ZZ" = "1" /* Destruction of Inferior Mesenteric Vein, Open Approach */
"06570ZZ" = "1" /* Destruction of Colic Vein, Open Approach */
"06580ZZ" = "1" /* Destruction of Portal Vein, Open Approach */
"06590ZZ" = "1" /* Destruction of Right Renal Vein, Open Approach */
"065B0ZZ" = "1" /* Destruction of Left Renal Vein, Open Approach */
"065C0ZZ" = "1" /* Destruction of Right Common Iliac Vein, Open Approach */
"065D0ZZ" = "1" /* Destruction of Left Common Iliac Vein, Open Approach */
"065F0ZZ" = "1" /* Destruction of Right External Iliac Vein, Open Approach */
"065G0ZZ" = "1" /* Destruction of Left External Iliac Vein, Open Approach */
"065H0ZZ" = "1" /* Destruction of Right Hypogastric Vein, Open Approach */
"065J0ZZ" = "1" /* Destruction of Left Hypogastric Vein, Open Approach */
"06700DZ" = "1" /* Dilation of Inferior Vena Cava with Intraluminal Device, Open Approach */
"06700ZZ" = "1" /* Dilation of Inferior Vena Cava, Open Approach */
"06710DZ" = "1" /* Dilation of Splenic Vein with Intraluminal Device, Open Approach */
"06710ZZ" = "1" /* Dilation of Splenic Vein, Open Approach */
"06720DZ" = "1" /* Dilation of Gastric Vein with Intraluminal Device, Open Approach */
"06720ZZ" = "1" /* Dilation of Gastric Vein, Open Approach */
"06730DZ" = "1" /* Dilation of Esophageal Vein with Intraluminal Device, Open Approach */
"06730ZZ" = "1" /* Dilation of Esophageal Vein, Open Approach */
"06740DZ" = "1" /* Dilation of Hepatic Vein with Intraluminal Device, Open Approach */
"06740ZZ" = "1" /* Dilation of Hepatic Vein, Open Approach */
"06750DZ" = "1" /* Dilation of Superior Mesenteric Vein with Intraluminal Device, Open Approach */
"06750ZZ" = "1" /* Dilation of Superior Mesenteric Vein, Open Approach */
"06760DZ" = "1" /* Dilation of Inferior Mesenteric Vein with Intraluminal Device, Open Approach */
"06760ZZ" = "1" /* Dilation of Inferior Mesenteric Vein, Open Approach */
"06770DZ" = "1" /* Dilation of Colic Vein with Intraluminal Device, Open Approach */
"06770ZZ" = "1" /* Dilation of Colic Vein, Open Approach */
"06780DZ" = "1" /* Dilation of Portal Vein with Intraluminal Device, Open Approach */
"06780ZZ" = "1" /* Dilation of Portal Vein, Open Approach */
"06790DZ" = "1" /* Dilation of Right Renal Vein with Intraluminal Device, Open Approach */
"06790ZZ" = "1" /* Dilation of Right Renal Vein, Open Approach */
"067B0DZ" = "1" /* Dilation of Left Renal Vein with Intraluminal Device, Open Approach */
"067B0ZZ" = "1" /* Dilation of Left Renal Vein, Open Approach */
"067C0DZ" = "1" /* Dilation of Right Common Iliac Vein with Intraluminal Device, Open Approach */
"067C0ZZ" = "1" /* Dilation of Right Common Iliac Vein, Open Approach */
"067D0DZ" = "1" /* Dilation of Left Common Iliac Vein with Intraluminal Device, Open Approach */
"067D0ZZ" = "1" /* Dilation of Left Common Iliac Vein, Open Approach */
"067F0DZ" = "1" /* Dilation of Right External Iliac Vein with Intraluminal Device, Open Approach */
"067F0ZZ" = "1" /* Dilation of Right External Iliac Vein, Open Approach */
"067G0DZ" = "1" /* Dilation of Left External Iliac Vein with Intraluminal Device, Open Approach */
"067G0ZZ" = "1" /* Dilation of Left External Iliac Vein, Open Approach */
"067H0DZ" = "1" /* Dilation of Right Hypogastric Vein with Intraluminal Device, Open Approach */
"067H0ZZ" = "1" /* Dilation of Right Hypogastric Vein, Open Approach */
"067J0DZ" = "1" /* Dilation of Left Hypogastric Vein with Intraluminal Device, Open Approach */
"067J0ZZ" = "1" /* Dilation of Left Hypogastric Vein, Open Approach */
"069000Z" = "1" /* Drainage of Inferior Vena Cava with Drainage Device, Open Approach */
"06900ZX" = "1" /* Drainage of Inferior Vena Cava, Open Approach, Diagnostic */
"06900ZZ" = "1" /* Drainage of Inferior Vena Cava, Open Approach */
"069100Z" = "1" /* Drainage of Splenic Vein with Drainage Device, Open Approach */
"06910ZX" = "1" /* Drainage of Splenic Vein, Open Approach, Diagnostic */
"06910ZZ" = "1" /* Drainage of Splenic Vein, Open Approach */
"069200Z" = "1" /* Drainage of Gastric Vein with Drainage Device, Open Approach */
"06920ZX" = "1" /* Drainage of Gastric Vein, Open Approach, Diagnostic */
"06920ZZ" = "1" /* Drainage of Gastric Vein, Open Approach */
"069300Z" = "1" /* Drainage of Esophageal Vein with Drainage Device, Open Approach */
"06930ZX" = "1" /* Drainage of Esophageal Vein, Open Approach, Diagnostic */
"06930ZZ" = "1" /* Drainage of Esophageal Vein, Open Approach */
"069400Z" = "1" /* Drainage of Hepatic Vein with Drainage Device, Open Approach */
"06940ZX" = "1" /* Drainage of Hepatic Vein, Open Approach, Diagnostic */
"06940ZZ" = "1" /* Drainage of Hepatic Vein, Open Approach */
"069500Z" = "1" /* Drainage of Superior Mesenteric Vein with Drainage Device, Open Approach */
"06950ZX" = "1" /* Drainage of Superior Mesenteric Vein, Open Approach, Diagnostic */
"06950ZZ" = "1" /* Drainage of Superior Mesenteric Vein, Open Approach */
"069600Z" = "1" /* Drainage of Inferior Mesenteric Vein with Drainage Device, Open Approach */
"06960ZX" = "1" /* Drainage of Inferior Mesenteric Vein, Open Approach, Diagnostic */
"06960ZZ" = "1" /* Drainage of Inferior Mesenteric Vein, Open Approach */
"069700Z" = "1" /* Drainage of Colic Vein with Drainage Device, Open Approach */
"06970ZX" = "1" /* Drainage of Colic Vein, Open Approach, Diagnostic */
"06970ZZ" = "1" /* Drainage of Colic Vein, Open Approach */
"069800Z" = "1" /* Drainage of Portal Vein with Drainage Device, Open Approach */
"06980ZX" = "1" /* Drainage of Portal Vein, Open Approach, Diagnostic */
"06980ZZ" = "1" /* Drainage of Portal Vein, Open Approach */
"069900Z" = "1" /* Drainage of Right Renal Vein with Drainage Device, Open Approach */
"06990ZX" = "1" /* Drainage of Right Renal Vein, Open Approach, Diagnostic */
"06990ZZ" = "1" /* Drainage of Right Renal Vein, Open Approach */
"069B00Z" = "1" /* Drainage of Left Renal Vein with Drainage Device, Open Approach */
"069B0ZX" = "1" /* Drainage of Left Renal Vein, Open Approach, Diagnostic */
"069B0ZZ" = "1" /* Drainage of Left Renal Vein, Open Approach */
"069C00Z" = "1" /* Drainage of Right Common Iliac Vein with Drainage Device, Open Approach */
"069C0ZX" = "1" /* Drainage of Right Common Iliac Vein, Open Approach, Diagnostic */
"069C0ZZ" = "1" /* Drainage of Right Common Iliac Vein, Open Approach */
"069D00Z" = "1" /* Drainage of Left Common Iliac Vein with Drainage Device, Open Approach */
"069D0ZX" = "1" /* Drainage of Left Common Iliac Vein, Open Approach, Diagnostic */
"069D0ZZ" = "1" /* Drainage of Left Common Iliac Vein, Open Approach */
"069F00Z" = "1" /* Drainage of Right External Iliac Vein with Drainage Device, Open Approach */
"069F0ZX" = "1" /* Drainage of Right External Iliac Vein, Open Approach, Diagnostic */
"069F0ZZ" = "1" /* Drainage of Right External Iliac Vein, Open Approach */
"069G00Z" = "1" /* Drainage of Left External Iliac Vein with Drainage Device, Open Approach */
"069G0ZX" = "1" /* Drainage of Left External Iliac Vein, Open Approach, Diagnostic */
"069G0ZZ" = "1" /* Drainage of Left External Iliac Vein, Open Approach */
"069H00Z" = "1" /* Drainage of Right Hypogastric Vein with Drainage Device, Open Approach */
"069H0ZX" = "1" /* Drainage of Right Hypogastric Vein, Open Approach, Diagnostic */
"069H0ZZ" = "1" /* Drainage of Right Hypogastric Vein, Open Approach */
"069J00Z" = "1" /* Drainage of Left Hypogastric Vein with Drainage Device, Open Approach */
"069J0ZX" = "1" /* Drainage of Left Hypogastric Vein, Open Approach, Diagnostic */
"069J0ZZ" = "1" /* Drainage of Left Hypogastric Vein, Open Approach */
"06B00ZX" = "1" /* Excision of Inferior Vena Cava, Open Approach, Diagnostic */
"06B00ZZ" = "1" /* Excision of Inferior Vena Cava, Open Approach */
"06B10ZX" = "1" /* Excision of Splenic Vein, Open Approach, Diagnostic */
"06B10ZZ" = "1" /* Excision of Splenic Vein, Open Approach */
"06B20ZX" = "1" /* Excision of Gastric Vein, Open Approach, Diagnostic */
"06B20ZZ" = "1" /* Excision of Gastric Vein, Open Approach */
"06B30ZX" = "1" /* Excision of Esophageal Vein, Open Approach, Diagnostic */
"06B30ZZ" = "1" /* Excision of Esophageal Vein, Open Approach */
"06B40ZX" = "1" /* Excision of Hepatic Vein, Open Approach, Diagnostic */
"06B40ZZ" = "1" /* Excision of Hepatic Vein, Open Approach */
"06B50ZX" = "1" /* Excision of Superior Mesenteric Vein, Open Approach, Diagnostic */
"06B50ZZ" = "1" /* Excision of Superior Mesenteric Vein, Open Approach */
"06B60ZX" = "1" /* Excision of Inferior Mesenteric Vein, Open Approach, Diagnostic */
"06B60ZZ" = "1" /* Excision of Inferior Mesenteric Vein, Open Approach */
"06B70ZX" = "1" /* Excision of Colic Vein, Open Approach, Diagnostic */
"06B70ZZ" = "1" /* Excision of Colic Vein, Open Approach */
"06B80ZX" = "1" /* Excision of Portal Vein, Open Approach, Diagnostic */
"06B80ZZ" = "1" /* Excision of Portal Vein, Open Approach */
"06B90ZX" = "1" /* Excision of Right Renal Vein, Open Approach, Diagnostic */
"06B90ZZ" = "1" /* Excision of Right Renal Vein, Open Approach */
"06BB0ZX" = "1" /* Excision of Left Renal Vein, Open Approach, Diagnostic */
"06BB0ZZ" = "1" /* Excision of Left Renal Vein, Open Approach */
"06BC0ZX" = "1" /* Excision of Right Common Iliac Vein, Open Approach, Diagnostic */
"06BC0ZZ" = "1" /* Excision of Right Common Iliac Vein, Open Approach */
"06BD0ZX" = "1" /* Excision of Left Common Iliac Vein, Open Approach, Diagnostic */
"06BD0ZZ" = "1" /* Excision of Left Common Iliac Vein, Open Approach */
"06BF0ZX" = "1" /* Excision of Right External Iliac Vein, Open Approach, Diagnostic */
"06BF0ZZ" = "1" /* Excision of Right External Iliac Vein, Open Approach */
"06BG0ZX" = "1" /* Excision of Left External Iliac Vein, Open Approach, Diagnostic */
"06BG0ZZ" = "1" /* Excision of Left External Iliac Vein, Open Approach */
"06BH0ZX" = "1" /* Excision of Right Hypogastric Vein, Open Approach, Diagnostic */
"06BH0ZZ" = "1" /* Excision of Right Hypogastric Vein, Open Approach */
"06BJ0ZX" = "1" /* Excision of Left Hypogastric Vein, Open Approach, Diagnostic */
"06BJ0ZZ" = "1" /* Excision of Left Hypogastric Vein, Open Approach */
"06C00ZZ" = "1" /* Extirpation of Matter from Inferior Vena Cava, Open Approach */
"06C10ZZ" = "1" /* Extirpation of Matter from Splenic Vein, Open Approach */
"06C20ZZ" = "1" /* Extirpation of Matter from Gastric Vein, Open Approach */
"06C30ZZ" = "1" /* Extirpation of Matter from Esophageal Vein, Open Approach */
"06C40ZZ" = "1" /* Extirpation of Matter from Hepatic Vein, Open Approach */
"06C50ZZ" = "1" /* Extirpation of Matter from Superior Mesenteric Vein, Open Approach */
"06C60ZZ" = "1" /* Extirpation of Matter from Inferior Mesenteric Vein, Open Approach */
"06C70ZZ" = "1" /* Extirpation of Matter from Colic Vein, Open Approach */
"06C80ZZ" = "1" /* Extirpation of Matter from Portal Vein, Open Approach */
"06C90ZZ" = "1" /* Extirpation of Matter from Right Renal Vein, Open Approach */
"06CB0ZZ" = "1" /* Extirpation of Matter from Left Renal Vein, Open Approach */
"06CC0ZZ" = "1" /* Extirpation of Matter from Right Common Iliac Vein, Open Approach */
"06CD0ZZ" = "1" /* Extirpation of Matter from Left Common Iliac Vein, Open Approach */
"06CF0ZZ" = "1" /* Extirpation of Matter from Right External Iliac Vein, Open Approach */
"06CG0ZZ" = "1" /* Extirpation of Matter from Left External Iliac Vein, Open Approach */
"06CH0ZZ" = "1" /* Extirpation of Matter from Right Hypogastric Vein, Open Approach */
"06CJ0ZZ" = "1" /* Extirpation of Matter from Left Hypogastric Vein, Open Approach */
"06H003T" = "1" /* Insertion of Infusion Device, Via Umbilical Vein, into Inferior Vena Cava, Open Approach */
"06H003Z" = "1" /* Insertion of Infusion Device into Inferior Vena Cava, Open Approach */
"06H00DZ" = "1" /* Insertion of Intraluminal Device into Inferior Vena Cava, Open Approach */
"06H103Z" = "1" /* Insertion of Infusion Device into Splenic Vein, Open Approach */
"06H10DZ" = "1" /* Insertion of Intraluminal Device into Splenic Vein, Open Approach */
"06H203Z" = "1" /* Insertion of Infusion Device into Gastric Vein, Open Approach */
"06H20DZ" = "1" /* Insertion of Intraluminal Device into Gastric Vein, Open Approach */
"06H303Z" = "1" /* Insertion of Infusion Device into Esophageal Vein, Open Approach */
"06H30DZ" = "1" /* Insertion of Intraluminal Device into Esophageal Vein, Open Approach */
"06H403Z" = "1" /* Insertion of Infusion Device into Hepatic Vein, Open Approach */
"06H40DZ" = "1" /* Insertion of Intraluminal Device into Hepatic Vein, Open Approach */
"06H503Z" = "1" /* Insertion of Infusion Device into Superior Mesenteric Vein, Open Approach */
"06H50DZ" = "1" /* Insertion of Intraluminal Device into Superior Mesenteric Vein, Open Approach */
"06H603Z" = "1" /* Insertion of Infusion Device into Inferior Mesenteric Vein, Open Approach */
"06H60DZ" = "1" /* Insertion of Intraluminal Device into Inferior Mesenteric Vein, Open Approach */
"06H703Z" = "1" /* Insertion of Infusion Device into Colic Vein, Open Approach */
"06H70DZ" = "1" /* Insertion of Intraluminal Device into Colic Vein, Open Approach */
"06H803Z" = "1" /* Insertion of Infusion Device into Portal Vein, Open Approach */
"06H80DZ" = "1" /* Insertion of Intraluminal Device into Portal Vein, Open Approach */
"06H903Z" = "1" /* Insertion of Infusion Device into Right Renal Vein, Open Approach */
"06H90DZ" = "1" /* Insertion of Intraluminal Device into Right Renal Vein, Open Approach */
"06HB03Z" = "1" /* Insertion of Infusion Device into Left Renal Vein, Open Approach */
"06HB0DZ" = "1" /* Insertion of Intraluminal Device into Left Renal Vein, Open Approach */
"06HC03Z" = "1" /* Insertion of Infusion Device into Right Common Iliac Vein, Open Approach */
"06HC0DZ" = "1" /* Insertion of Intraluminal Device into Right Common Iliac Vein, Open Approach */
"06HD03Z" = "1" /* Insertion of Infusion Device into Left Common Iliac Vein, Open Approach */
"06HD0DZ" = "1" /* Insertion of Intraluminal Device into Left Common Iliac Vein, Open Approach */
"06HF03Z" = "1" /* Insertion of Infusion Device into Right External Iliac Vein, Open Approach */
"06HF0DZ" = "1" /* Insertion of Intraluminal Device into Right External Iliac Vein, Open Approach */
"06HG03Z" = "1" /* Insertion of Infusion Device into Left External Iliac Vein, Open Approach */
"06HG0DZ" = "1" /* Insertion of Intraluminal Device into Left External Iliac Vein, Open Approach */
"06HH03Z" = "1" /* Insertion of Infusion Device into Right Hypogastric Vein, Open Approach */
"06HH0DZ" = "1" /* Insertion of Intraluminal Device into Right Hypogastric Vein, Open Approach */
"06HJ03Z" = "1" /* Insertion of Infusion Device into Left Hypogastric Vein, Open Approach */
"06HJ0DZ" = "1" /* Insertion of Intraluminal Device into Left Hypogastric Vein, Open Approach */
"06L00CZ" = "1" /* Occlusion of Inferior Vena Cava with Extraluminal Device, Open Approach */
"06L00DZ" = "1" /* Occlusion of Inferior Vena Cava with Intraluminal Device, Open Approach */
"06L00ZZ" = "1" /* Occlusion of Inferior Vena Cava, Open Approach */
"06L10CZ" = "1" /* Occlusion of Splenic Vein with Extraluminal Device, Open Approach */
"06L10DZ" = "1" /* Occlusion of Splenic Vein with Intraluminal Device, Open Approach */
"06L10ZZ" = "1" /* Occlusion of Splenic Vein, Open Approach */
"06L20CZ" = "1" /* Occlusion of Gastric Vein with Extraluminal Device, Open Approach */
"06L20DZ" = "1" /* Occlusion of Gastric Vein with Intraluminal Device, Open Approach */
"06L20ZZ" = "1" /* Occlusion of Gastric Vein, Open Approach */
"06L30CZ" = "1" /* Occlusion of Esophageal Vein with Extraluminal Device, Open Approach */
"06L30DZ" = "1" /* Occlusion of Esophageal Vein with Intraluminal Device, Open Approach */
"06L30ZZ" = "1" /* Occlusion of Esophageal Vein, Open Approach */
"06L40CZ" = "1" /* Occlusion of Hepatic Vein with Extraluminal Device, Open Approach */
"06L40DZ" = "1" /* Occlusion of Hepatic Vein with Intraluminal Device, Open Approach */
"06L40ZZ" = "1" /* Occlusion of Hepatic Vein, Open Approach */
"06L50CZ" = "1" /* Occlusion of Superior Mesenteric Vein with Extraluminal Device, Open Approach */
"06L50DZ" = "1" /* Occlusion of Superior Mesenteric Vein with Intraluminal Device, Open Approach */
"06L50ZZ" = "1" /* Occlusion of Superior Mesenteric Vein, Open Approach */
"06L60CZ" = "1" /* Occlusion of Inferior Mesenteric Vein with Extraluminal Device, Open Approach */
"06L60DZ" = "1" /* Occlusion of Inferior Mesenteric Vein with Intraluminal Device, Open Approach */
"06L60ZZ" = "1" /* Occlusion of Inferior Mesenteric Vein, Open Approach */
"06L70CZ" = "1" /* Occlusion of Colic Vein with Extraluminal Device, Open Approach */
"06L70DZ" = "1" /* Occlusion of Colic Vein with Intraluminal Device, Open Approach */
"06L70ZZ" = "1" /* Occlusion of Colic Vein, Open Approach */
"06L80CZ" = "1" /* Occlusion of Portal Vein with Extraluminal Device, Open Approach */
"06L80DZ" = "1" /* Occlusion of Portal Vein with Intraluminal Device, Open Approach */
"06L80ZZ" = "1" /* Occlusion of Portal Vein, Open Approach */
"06L90CZ" = "1" /* Occlusion of Right Renal Vein with Extraluminal Device, Open Approach */
"06L90DZ" = "1" /* Occlusion of Right Renal Vein with Intraluminal Device, Open Approach */
"06L90ZZ" = "1" /* Occlusion of Right Renal Vein, Open Approach */
"06LB0CZ" = "1" /* Occlusion of Left Renal Vein with Extraluminal Device, Open Approach */
"06LB0DZ" = "1" /* Occlusion of Left Renal Vein with Intraluminal Device, Open Approach */
"06LB0ZZ" = "1" /* Occlusion of Left Renal Vein, Open Approach */
"06LC0CZ" = "1" /* Occlusion of Right Common Iliac Vein with Extraluminal Device, Open Approach */
"06LC0DZ" = "1" /* Occlusion of Right Common Iliac Vein with Intraluminal Device, Open Approach */
"06LC0ZZ" = "1" /* Occlusion of Right Common Iliac Vein, Open Approach */
"06LD0CZ" = "1" /* Occlusion of Left Common Iliac Vein with Extraluminal Device, Open Approach */
"06LD0DZ" = "1" /* Occlusion of Left Common Iliac Vein with Intraluminal Device, Open Approach */
"06LD0ZZ" = "1" /* Occlusion of Left Common Iliac Vein, Open Approach */
"06LF0CZ" = "1" /* Occlusion of Right External Iliac Vein with Extraluminal Device, Open Approach */
"06LF0DZ" = "1" /* Occlusion of Right External Iliac Vein with Intraluminal Device, Open Approach */
"06LF0ZZ" = "1" /* Occlusion of Right External Iliac Vein, Open Approach */
"06LG0CZ" = "1" /* Occlusion of Left External Iliac Vein with Extraluminal Device, Open Approach */
"06LG0DZ" = "1" /* Occlusion of Left External Iliac Vein with Intraluminal Device, Open Approach */
"06LG0ZZ" = "1" /* Occlusion of Left External Iliac Vein, Open Approach */
"06LH0CZ" = "1" /* Occlusion of Right Hypogastric Vein with Extraluminal Device, Open Approach */
"06LH0DZ" = "1" /* Occlusion of Right Hypogastric Vein with Intraluminal Device, Open Approach */
"06LH0ZZ" = "1" /* Occlusion of Right Hypogastric Vein, Open Approach */
"06LJ0CZ" = "1" /* Occlusion of Left Hypogastric Vein with Extraluminal Device, Open Approach */
"06LJ0DZ" = "1" /* Occlusion of Left Hypogastric Vein with Intraluminal Device, Open Approach */
"06LJ0ZZ" = "1" /* Occlusion of Left Hypogastric Vein, Open Approach */
"06N00ZZ" = "1" /* Release Inferior Vena Cava, Open Approach */
"06N10ZZ" = "1" /* Release Splenic Vein, Open Approach */
"06N20ZZ" = "1" /* Release Gastric Vein, Open Approach */
"06N30ZZ" = "1" /* Release Esophageal Vein, Open Approach */
"06N40ZZ" = "1" /* Release Hepatic Vein, Open Approach */
"06N50ZZ" = "1" /* Release Superior Mesenteric Vein, Open Approach */
"06N60ZZ" = "1" /* Release Inferior Mesenteric Vein, Open Approach */
"06N70ZZ" = "1" /* Release Colic Vein, Open Approach */
"06N80ZZ" = "1" /* Release Portal Vein, Open Approach */
"06N90ZZ" = "1" /* Release Right Renal Vein, Open Approach */
"06NB0ZZ" = "1" /* Release Left Renal Vein, Open Approach */
"06NC0ZZ" = "1" /* Release Right Common Iliac Vein, Open Approach */
"06ND0ZZ" = "1" /* Release Left Common Iliac Vein, Open Approach */
"06NF0ZZ" = "1" /* Release Right External Iliac Vein, Open Approach */
"06NG0ZZ" = "1" /* Release Left External Iliac Vein, Open Approach */
"06NH0ZZ" = "1" /* Release Right Hypogastric Vein, Open Approach */
"06NJ0ZZ" = "1" /* Release Left Hypogastric Vein, Open Approach */
"06Q00ZZ" = "1" /* Repair Inferior Vena Cava, Open Approach */
"06Q10ZZ" = "1" /* Repair Splenic Vein, Open Approach */
"06Q20ZZ" = "1" /* Repair Gastric Vein, Open Approach */
"06Q30ZZ" = "1" /* Repair Esophageal Vein, Open Approach */
"06Q40ZZ" = "1" /* Repair Hepatic Vein, Open Approach */
"06Q50ZZ" = "1" /* Repair Superior Mesenteric Vein, Open Approach */
"06Q60ZZ" = "1" /* Repair Inferior Mesenteric Vein, Open Approach */
"06Q70ZZ" = "1" /* Repair Colic Vein, Open Approach */
"06Q80ZZ" = "1" /* Repair Portal Vein, Open Approach */
"06Q90ZZ" = "1" /* Repair Right Renal Vein, Open Approach */
"06QB0ZZ" = "1" /* Repair Left Renal Vein, Open Approach */
"06QC0ZZ" = "1" /* Repair Right Common Iliac Vein, Open Approach */
"06QD0ZZ" = "1" /* Repair Left Common Iliac Vein, Open Approach */
"06QF0ZZ" = "1" /* Repair Right External Iliac Vein, Open Approach */
"06QG0ZZ" = "1" /* Repair Left External Iliac Vein, Open Approach */
"06QH0ZZ" = "1" /* Repair Right Hypogastric Vein, Open Approach */
"06QJ0ZZ" = "1" /* Repair Left Hypogastric Vein, Open Approach */
"06R007Z" = "1" /* Replacement of Inferior Vena Cava with Autologous Tissue Substitute, Open Approach */
"06R00JZ" = "1" /* Replacement of Inferior Vena Cava with Synthetic Substitute, Open Approach */
"06R00KZ" = "1" /* Replacement of Inferior Vena Cava with Nonautologous Tissue Substitute, Open Approach */
"06R107Z" = "1" /* Replacement of Splenic Vein with Autologous Tissue Substitute, Open Approach */
"06R10JZ" = "1" /* Replacement of Splenic Vein with Synthetic Substitute, Open Approach */
"06R10KZ" = "1" /* Replacement of Splenic Vein with Nonautologous Tissue Substitute, Open Approach */
"06R207Z" = "1" /* Replacement of Gastric Vein with Autologous Tissue Substitute, Open Approach */
"06R20JZ" = "1" /* Replacement of Gastric Vein with Synthetic Substitute, Open Approach */
"06R20KZ" = "1" /* Replacement of Gastric Vein with Nonautologous Tissue Substitute, Open Approach */
"06R307Z" = "1" /* Replacement of Esophageal Vein with Autologous Tissue Substitute, Open Approach */
"06R30JZ" = "1" /* Replacement of Esophageal Vein with Synthetic Substitute, Open Approach */
"06R30KZ" = "1" /* Replacement of Esophageal Vein with Nonautologous Tissue Substitute, Open Approach */
"06R407Z" = "1" /* Replacement of Hepatic Vein with Autologous Tissue Substitute, Open Approach */
"06R40JZ" = "1" /* Replacement of Hepatic Vein with Synthetic Substitute, Open Approach */
"06R40KZ" = "1" /* Replacement of Hepatic Vein with Nonautologous Tissue Substitute, Open Approach */
"06R507Z" = "1" /* Replacement of Superior Mesenteric Vein with Autologous Tissue Substitute, Open Approach */
"06R50JZ" = "1" /* Replacement of Superior Mesenteric Vein with Synthetic Substitute, Open Approach */
"06R50KZ" = "1" /* Replacement of Superior Mesenteric Vein with Nonautologous Tissue Substitute, Open Approach */
"06R607Z" = "1" /* Replacement of Inferior Mesenteric Vein with Autologous Tissue Substitute, Open Approach */
"06R60JZ" = "1" /* Replacement of Inferior Mesenteric Vein with Synthetic Substitute, Open Approach */
"06R60KZ" = "1" /* Replacement of Inferior Mesenteric Vein with Nonautologous Tissue Substitute, Open Approach */
"06R707Z" = "1" /* Replacement of Colic Vein with Autologous Tissue Substitute, Open Approach */
"06R70JZ" = "1" /* Replacement of Colic Vein with Synthetic Substitute, Open Approach */
"06R70KZ" = "1" /* Replacement of Colic Vein with Nonautologous Tissue Substitute, Open Approach */
"06R807Z" = "1" /* Replacement of Portal Vein with Autologous Tissue Substitute, Open Approach */
"06R80JZ" = "1" /* Replacement of Portal Vein with Synthetic Substitute, Open Approach */
"06R80KZ" = "1" /* Replacement of Portal Vein with Nonautologous Tissue Substitute, Open Approach */
"06R907Z" = "1" /* Replacement of Right Renal Vein with Autologous Tissue Substitute, Open Approach */
"06R90JZ" = "1" /* Replacement of Right Renal Vein with Synthetic Substitute, Open Approach */
"06R90KZ" = "1" /* Replacement of Right Renal Vein with Nonautologous Tissue Substitute, Open Approach */
"06RB07Z" = "1" /* Replacement of Left Renal Vein with Autologous Tissue Substitute, Open Approach */
"06RB0JZ" = "1" /* Replacement of Left Renal Vein with Synthetic Substitute, Open Approach */
"06RB0KZ" = "1" /* Replacement of Left Renal Vein with Nonautologous Tissue Substitute, Open Approach */
"06RC07Z" = "1" /* Replacement of Right Common Iliac Vein with Autologous Tissue Substitute, Open Approach */
"06RC0JZ" = "1" /* Replacement of Right Common Iliac Vein with Synthetic Substitute, Open Approach */
"06RC0KZ" = "1" /* Replacement of Right Common Iliac Vein with Nonautologous Tissue Substitute, Open Approach */
"06RD07Z" = "1" /* Replacement of Left Common Iliac Vein with Autologous Tissue Substitute, Open Approach */
"06RD0JZ" = "1" /* Replacement of Left Common Iliac Vein with Synthetic Substitute, Open Approach */
"06RD0KZ" = "1" /* Replacement of Left Common Iliac Vein with Nonautologous Tissue Substitute, Open Approach */
"06RF07Z" = "1" /* Replacement of Right External Iliac Vein with Autologous Tissue Substitute, Open Approach */
"06RF0JZ" = "1" /* Replacement of Right External Iliac Vein with Synthetic Substitute, Open Approach */
"06RF0KZ" = "1" /* Replacement of Right External Iliac Vein with Nonautologous Tissue Substitute, Open Approach */
"06RG07Z" = "1" /* Replacement of Left External Iliac Vein with Autologous Tissue Substitute, Open Approach */
"06RG0JZ" = "1" /* Replacement of Left External Iliac Vein with Synthetic Substitute, Open Approach */
"06RG0KZ" = "1" /* Replacement of Left External Iliac Vein with Nonautologous Tissue Substitute, Open Approach */
"06RH07Z" = "1" /* Replacement of Right Hypogastric Vein with Autologous Tissue Substitute, Open Approach */
"06RH0JZ" = "1" /* Replacement of Right Hypogastric Vein with Synthetic Substitute, Open Approach */
"06RH0KZ" = "1" /* Replacement of Right Hypogastric Vein with Nonautologous Tissue Substitute, Open Approach */
"06RJ07Z" = "1" /* Replacement of Left Hypogastric Vein with Autologous Tissue Substitute, Open Approach */
"06RJ0JZ" = "1" /* Replacement of Left Hypogastric Vein with Synthetic Substitute, Open Approach */
"06RJ0KZ" = "1" /* Replacement of Left Hypogastric Vein with Nonautologous Tissue Substitute, Open Approach */
"06S00ZZ" = "1" /* Reposition Inferior Vena Cava, Open Approach */
"06S10ZZ" = "1" /* Reposition Splenic Vein, Open Approach */
"06S20ZZ" = "1" /* Reposition Gastric Vein, Open Approach */
"06S30ZZ" = "1" /* Reposition Esophageal Vein, Open Approach */
"06S40ZZ" = "1" /* Reposition Hepatic Vein, Open Approach */
"06S50ZZ" = "1" /* Reposition Superior Mesenteric Vein, Open Approach */
"06S60ZZ" = "1" /* Reposition Inferior Mesenteric Vein, Open Approach */
"06S70ZZ" = "1" /* Reposition Colic Vein, Open Approach */
"06S80ZZ" = "1" /* Reposition Portal Vein, Open Approach */
"06S90ZZ" = "1" /* Reposition Right Renal Vein, Open Approach */
"06SB0ZZ" = "1" /* Reposition Left Renal Vein, Open Approach */
"06SC0ZZ" = "1" /* Reposition Right Common Iliac Vein, Open Approach */
"06SD0ZZ" = "1" /* Reposition Left Common Iliac Vein, Open Approach */
"06SF0ZZ" = "1" /* Reposition Right External Iliac Vein, Open Approach */
"06SG0ZZ" = "1" /* Reposition Left External Iliac Vein, Open Approach */
"06SH0ZZ" = "1" /* Reposition Right Hypogastric Vein, Open Approach */
"06SJ0ZZ" = "1" /* Reposition Left Hypogastric Vein, Open Approach */
"06U007Z" = "1" /* Supplement Inferior Vena Cava with Autologous Tissue Substitute, Open Approach */
"06U00JZ" = "1" /* Supplement Inferior Vena Cava with Synthetic Substitute, Open Approach */
"06U00KZ" = "1" /* Supplement Inferior Vena Cava with Nonautologous Tissue Substitute, Open Approach */
"06U107Z" = "1" /* Supplement Splenic Vein with Autologous Tissue Substitute, Open Approach */
"06U10JZ" = "1" /* Supplement Splenic Vein with Synthetic Substitute, Open Approach */
"06U10KZ" = "1" /* Supplement Splenic Vein with Nonautologous Tissue Substitute, Open Approach */
"06U207Z" = "1" /* Supplement Gastric Vein with Autologous Tissue Substitute, Open Approach */
"06U20JZ" = "1" /* Supplement Gastric Vein with Synthetic Substitute, Open Approach */
"06U20KZ" = "1" /* Supplement Gastric Vein with Nonautologous Tissue Substitute, Open Approach */
"06U307Z" = "1" /* Supplement Esophageal Vein with Autologous Tissue Substitute, Open Approach */
"06U30JZ" = "1" /* Supplement Esophageal Vein with Synthetic Substitute, Open Approach */
"06U30KZ" = "1" /* Supplement Esophageal Vein with Nonautologous Tissue Substitute, Open Approach */
"06U407Z" = "1" /* Supplement Hepatic Vein with Autologous Tissue Substitute, Open Approach */
"06U40JZ" = "1" /* Supplement Hepatic Vein with Synthetic Substitute, Open Approach */
"06U40KZ" = "1" /* Supplement Hepatic Vein with Nonautologous Tissue Substitute, Open Approach */
"06U507Z" = "1" /* Supplement Superior Mesenteric Vein with Autologous Tissue Substitute, Open Approach */
"06U50JZ" = "1" /* Supplement Superior Mesenteric Vein with Synthetic Substitute, Open Approach */
"06U50KZ" = "1" /* Supplement Superior Mesenteric Vein with Nonautologous Tissue Substitute, Open Approach */
"06U607Z" = "1" /* Supplement Inferior Mesenteric Vein with Autologous Tissue Substitute, Open Approach */
"06U60JZ" = "1" /* Supplement Inferior Mesenteric Vein with Synthetic Substitute, Open Approach */
"06U60KZ" = "1" /* Supplement Inferior Mesenteric Vein with Nonautologous Tissue Substitute, Open Approach */
"06U707Z" = "1" /* Supplement Colic Vein with Autologous Tissue Substitute, Open Approach */
"06U70JZ" = "1" /* Supplement Colic Vein with Synthetic Substitute, Open Approach */
"06U70KZ" = "1" /* Supplement Colic Vein with Nonautologous Tissue Substitute, Open Approach */
"06U807Z" = "1" /* Supplement Portal Vein with Autologous Tissue Substitute, Open Approach */
"06U80JZ" = "1" /* Supplement Portal Vein with Synthetic Substitute, Open Approach */
"06U80KZ" = "1" /* Supplement Portal Vein with Nonautologous Tissue Substitute, Open Approach */
"06U907Z" = "1" /* Supplement Right Renal Vein with Autologous Tissue Substitute, Open Approach */
"06U90JZ" = "1" /* Supplement Right Renal Vein with Synthetic Substitute, Open Approach */
"06U90KZ" = "1" /* Supplement Right Renal Vein with Nonautologous Tissue Substitute, Open Approach */
"06UB07Z" = "1" /* Supplement Left Renal Vein with Autologous Tissue Substitute, Open Approach */
"06UB0JZ" = "1" /* Supplement Left Renal Vein with Synthetic Substitute, Open Approach */
"06UB0KZ" = "1" /* Supplement Left Renal Vein with Nonautologous Tissue Substitute, Open Approach */
"06UC07Z" = "1" /* Supplement Right Common Iliac Vein with Autologous Tissue Substitute, Open Approach */
"06UC0JZ" = "1" /* Supplement Right Common Iliac Vein with Synthetic Substitute, Open Approach */
"06UC0KZ" = "1" /* Supplement Right Common Iliac Vein with Nonautologous Tissue Substitute, Open Approach */
"06UD07Z" = "1" /* Supplement Left Common Iliac Vein with Autologous Tissue Substitute, Open Approach */
"06UD0JZ" = "1" /* Supplement Left Common Iliac Vein with Synthetic Substitute, Open Approach */
"06UD0KZ" = "1" /* Supplement Left Common Iliac Vein with Nonautologous Tissue Substitute, Open Approach */
"06UF07Z" = "1" /* Supplement Right External Iliac Vein with Autologous Tissue Substitute, Open Approach */
"06UF0JZ" = "1" /* Supplement Right External Iliac Vein with Synthetic Substitute, Open Approach */
"06UF0KZ" = "1" /* Supplement Right External Iliac Vein with Nonautologous Tissue Substitute, Open Approach */
"06UG07Z" = "1" /* Supplement Left External Iliac Vein with Autologous Tissue Substitute, Open Approach */
"06UG0JZ" = "1" /* Supplement Left External Iliac Vein with Synthetic Substitute, Open Approach */
"06UG0KZ" = "1" /* Supplement Left External Iliac Vein with Nonautologous Tissue Substitute, Open Approach */
"06UH07Z" = "1" /* Supplement Right Hypogastric Vein with Autologous Tissue Substitute, Open Approach */
"06UH0JZ" = "1" /* Supplement Right Hypogastric Vein with Synthetic Substitute, Open Approach */
"06UH0KZ" = "1" /* Supplement Right Hypogastric Vein with Nonautologous Tissue Substitute, Open Approach */
"06UJ07Z" = "1" /* Supplement Left Hypogastric Vein with Autologous Tissue Substitute, Open Approach */
"06UJ0JZ" = "1" /* Supplement Left Hypogastric Vein with Synthetic Substitute, Open Approach */
"06UJ0KZ" = "1" /* Supplement Left Hypogastric Vein with Nonautologous Tissue Substitute, Open Approach */
"06V00CZ" = "1" /* Restriction of Inferior Vena Cava with Extraluminal Device, Open Approach */
"06V00DZ" = "1" /* Restriction of Inferior Vena Cava with Intraluminal Device, Open Approach */
"06V00ZZ" = "1" /* Restriction of Inferior Vena Cava, Open Approach */
"06V10CZ" = "1" /* Restriction of Splenic Vein with Extraluminal Device, Open Approach */
"06V10DZ" = "1" /* Restriction of Splenic Vein with Intraluminal Device, Open Approach */
"06V10ZZ" = "1" /* Restriction of Splenic Vein, Open Approach */
"06V20CZ" = "1" /* Restriction of Gastric Vein with Extraluminal Device, Open Approach */
"06V20DZ" = "1" /* Restriction of Gastric Vein with Intraluminal Device, Open Approach */
"06V20ZZ" = "1" /* Restriction of Gastric Vein, Open Approach */
"06V30CZ" = "1" /* Restriction of Esophageal Vein with Extraluminal Device, Open Approach */
"06V30DZ" = "1" /* Restriction of Esophageal Vein with Intraluminal Device, Open Approach */
"06V30ZZ" = "1" /* Restriction of Esophageal Vein, Open Approach */
"06V40CZ" = "1" /* Restriction of Hepatic Vein with Extraluminal Device, Open Approach */
"06V40DZ" = "1" /* Restriction of Hepatic Vein with Intraluminal Device, Open Approach */
"06V40ZZ" = "1" /* Restriction of Hepatic Vein, Open Approach */
"06V50CZ" = "1" /* Restriction of Superior Mesenteric Vein with Extraluminal Device, Open Approach */
"06V50DZ" = "1" /* Restriction of Superior Mesenteric Vein with Intraluminal Device, Open Approach */
"06V50ZZ" = "1" /* Restriction of Superior Mesenteric Vein, Open Approach */
"06V60CZ" = "1" /* Restriction of Inferior Mesenteric Vein with Extraluminal Device, Open Approach */
"06V60DZ" = "1" /* Restriction of Inferior Mesenteric Vein with Intraluminal Device, Open Approach */
"06V60ZZ" = "1" /* Restriction of Inferior Mesenteric Vein, Open Approach */
"06V70CZ" = "1" /* Restriction of Colic Vein with Extraluminal Device, Open Approach */
"06V70DZ" = "1" /* Restriction of Colic Vein with Intraluminal Device, Open Approach */
"06V70ZZ" = "1" /* Restriction of Colic Vein, Open Approach */
"06V80CZ" = "1" /* Restriction of Portal Vein with Extraluminal Device, Open Approach */
"06V80DZ" = "1" /* Restriction of Portal Vein with Intraluminal Device, Open Approach */
"06V80ZZ" = "1" /* Restriction of Portal Vein, Open Approach */
"06V90CZ" = "1" /* Restriction of Right Renal Vein with Extraluminal Device, Open Approach */
"06V90DZ" = "1" /* Restriction of Right Renal Vein with Intraluminal Device, Open Approach */
"06V90ZZ" = "1" /* Restriction of Right Renal Vein, Open Approach */
"06VB0CZ" = "1" /* Restriction of Left Renal Vein with Extraluminal Device, Open Approach */
"06VB0DZ" = "1" /* Restriction of Left Renal Vein with Intraluminal Device, Open Approach */
"06VB0ZZ" = "1" /* Restriction of Left Renal Vein, Open Approach */
"06VC0CZ" = "1" /* Restriction of Right Common Iliac Vein with Extraluminal Device, Open Approach */
"06VC0DZ" = "1" /* Restriction of Right Common Iliac Vein with Intraluminal Device, Open Approach */
"06VC0ZZ" = "1" /* Restriction of Right Common Iliac Vein, Open Approach */
"06VD0CZ" = "1" /* Restriction of Left Common Iliac Vein with Extraluminal Device, Open Approach */
"06VD0DZ" = "1" /* Restriction of Left Common Iliac Vein with Intraluminal Device, Open Approach */
"06VD0ZZ" = "1" /* Restriction of Left Common Iliac Vein, Open Approach */
"06VF0CZ" = "1" /* Restriction of Right External Iliac Vein with Extraluminal Device, Open Approach */
"06VF0DZ" = "1" /* Restriction of Right External Iliac Vein with Intraluminal Device, Open Approach */
"06VF0ZZ" = "1" /* Restriction of Right External Iliac Vein, Open Approach */
"06VG0CZ" = "1" /* Restriction of Left External Iliac Vein with Extraluminal Device, Open Approach */
"06VG0DZ" = "1" /* Restriction of Left External Iliac Vein with Intraluminal Device, Open Approach */
"06VG0ZZ" = "1" /* Restriction of Left External Iliac Vein, Open Approach */
"06VH0CZ" = "1" /* Restriction of Right Hypogastric Vein with Extraluminal Device, Open Approach */
"06VH0DZ" = "1" /* Restriction of Right Hypogastric Vein with Intraluminal Device, Open Approach */
"06VH0ZZ" = "1" /* Restriction of Right Hypogastric Vein, Open Approach */
"06VJ0CZ" = "1" /* Restriction of Left Hypogastric Vein with Extraluminal Device, Open Approach */
"06VJ0DZ" = "1" /* Restriction of Left Hypogastric Vein with Intraluminal Device, Open Approach */
"06VJ0ZZ" = "1" /* Restriction of Left Hypogastric Vein, Open Approach */
"075B0ZZ" = "1" /* Destruction of Mesenteric Lymphatic, Open Approach */
"075C0ZZ" = "1" /* Destruction of Pelvis Lymphatic, Open Approach */
"075D0ZZ" = "1" /* Destruction of Aortic Lymphatic, Open Approach */
"075P0ZZ" = "1" /* Destruction of Spleen, Open Approach */
"079B00Z" = "1" /* Drainage of Mesenteric Lymphatic with Drainage Device, Open Approach */
"079B0ZX" = "1" /* Drainage of Mesenteric Lymphatic, Open Approach, Diagnostic */
"079B0ZZ" = "1" /* Drainage of Mesenteric Lymphatic, Open Approach */
"079C00Z" = "1" /* Drainage of Pelvis Lymphatic with Drainage Device, Open Approach */
"079C0ZX" = "1" /* Drainage of Pelvis Lymphatic, Open Approach, Diagnostic */
"079C0ZZ" = "1" /* Drainage of Pelvis Lymphatic, Open Approach */
"079D00Z" = "1" /* Drainage of Aortic Lymphatic with Drainage Device, Open Approach */
"079D0ZX" = "1" /* Drainage of Aortic Lymphatic, Open Approach, Diagnostic */
"079D0ZZ" = "1" /* Drainage of Aortic Lymphatic, Open Approach */
"079P00Z" = "1" /* Drainage of Spleen with Drainage Device, Open Approach */
"079P0ZX" = "1" /* Drainage of Spleen, Open Approach, Diagnostic */
"079P0ZZ" = "1" /* Drainage of Spleen, Open Approach */
"07BB0ZX" = "1" /* Excision of Mesenteric Lymphatic, Open Approach, Diagnostic */
"07BB0ZZ" = "1" /* Excision of Mesenteric Lymphatic, Open Approach */
"07BC0ZX" = "1" /* Excision of Pelvis Lymphatic, Open Approach, Diagnostic */
"07BC0ZZ" = "1" /* Excision of Pelvis Lymphatic, Open Approach */
"07BD0ZX" = "1" /* Excision of Aortic Lymphatic, Open Approach, Diagnostic */
"07BD0ZZ" = "1" /* Excision of Aortic Lymphatic, Open Approach */
"07BP0ZX" = "1" /* Excision of Spleen, Open Approach, Diagnostic */
"07BP0ZZ" = "1" /* Excision of Spleen, Open Approach */
"07CB0ZZ" = "1" /* Extirpation of Matter from Mesenteric Lymphatic, Open Approach */
"07CC0ZZ" = "1" /* Extirpation of Matter from Pelvis Lymphatic, Open Approach */
"07CD0ZZ" = "1" /* Extirpation of Matter from Aortic Lymphatic, Open Approach */
"07CP0ZZ" = "1" /* Extirpation of Matter from Spleen, Open Approach */
"07HP03Z" = "1" /* Insertion of Infusion Device into Spleen, Open Approach */
"07JP0ZZ" = "1" /* Inspection of Spleen, Open Approach */
"07LB0CZ" = "1" /* Occlusion of Mesenteric Lymphatic with Extraluminal Device, Open Approach */
"07LB0DZ" = "1" /* Occlusion of Mesenteric Lymphatic with Intraluminal Device, Open Approach */
"07LB0ZZ" = "1" /* Occlusion of Mesenteric Lymphatic, Open Approach */
"07LC0CZ" = "1" /* Occlusion of Pelvis Lymphatic with Extraluminal Device, Open Approach */
"07LC0DZ" = "1" /* Occlusion of Pelvis Lymphatic with Intraluminal Device, Open Approach */
"07LC0ZZ" = "1" /* Occlusion of Pelvis Lymphatic, Open Approach */
"07LD0CZ" = "1" /* Occlusion of Aortic Lymphatic with Extraluminal Device, Open Approach */
"07LD0DZ" = "1" /* Occlusion of Aortic Lymphatic with Intraluminal Device, Open Approach */
"07LD0ZZ" = "1" /* Occlusion of Aortic Lymphatic, Open Approach */
"07NB0ZZ" = "1" /* Release Mesenteric Lymphatic, Open Approach */
"07NC0ZZ" = "1" /* Release Pelvis Lymphatic, Open Approach */
"07ND0ZZ" = "1" /* Release Aortic Lymphatic, Open Approach */
"07NP0ZZ" = "1" /* Release Spleen, Open Approach */
"07PP00Z" = "1" /* Removal of Drainage Device from Spleen, Open Approach */
"07PP03Z" = "1" /* Removal of Infusion Device from Spleen, Open Approach */
"07QB0ZZ" = "1" /* Repair Mesenteric Lymphatic, Open Approach */
"07QC0ZZ" = "1" /* Repair Pelvis Lymphatic, Open Approach */
"07QD0ZZ" = "1" /* Repair Aortic Lymphatic, Open Approach */
"07QP0ZZ" = "1" /* Repair Spleen, Open Approach */
"07SP0ZZ" = "1" /* Reposition Spleen, Open Approach */
"07TB0ZZ" = "1" /* Resection of Mesenteric Lymphatic, Open Approach */
"07TC0ZZ" = "1" /* Resection of Pelvis Lymphatic, Open Approach */
"07TD0ZZ" = "1" /* Resection of Aortic Lymphatic, Open Approach */
"07TP0ZZ" = "1" /* Resection of Spleen, Open Approach */
"07UB07Z" = "1" /* Supplement Mesenteric Lymphatic with Autologous Tissue Substitute, Open Approach */
"07UB0JZ" = "1" /* Supplement Mesenteric Lymphatic with Synthetic Substitute, Open Approach */
"07UB0KZ" = "1" /* Supplement Mesenteric Lymphatic with Nonautologous Tissue Substitute, Open Approach */
"07UC07Z" = "1" /* Supplement Pelvis Lymphatic with Autologous Tissue Substitute, Open Approach */
"07UC0JZ" = "1" /* Supplement Pelvis Lymphatic with Synthetic Substitute, Open Approach */
"07UC0KZ" = "1" /* Supplement Pelvis Lymphatic with Nonautologous Tissue Substitute, Open Approach */
"07UD07Z" = "1" /* Supplement Aortic Lymphatic with Autologous Tissue Substitute, Open Approach */
"07UD0JZ" = "1" /* Supplement Aortic Lymphatic with Synthetic Substitute, Open Approach */
"07UD0KZ" = "1" /* Supplement Aortic Lymphatic with Nonautologous Tissue Substitute, Open Approach */
"07VB0CZ" = "1" /* Restriction of Mesenteric Lymphatic with Extraluminal Device, Open Approach */
"07VB0DZ" = "1" /* Restriction of Mesenteric Lymphatic with Intraluminal Device, Open Approach */
"07VB0ZZ" = "1" /* Restriction of Mesenteric Lymphatic, Open Approach */
"07VC0CZ" = "1" /* Restriction of Pelvis Lymphatic with Extraluminal Device, Open Approach */
"07VC0DZ" = "1" /* Restriction of Pelvis Lymphatic with Intraluminal Device, Open Approach */
"07VC0ZZ" = "1" /* Restriction of Pelvis Lymphatic, Open Approach */
"07VD0CZ" = "1" /* Restriction of Aortic Lymphatic with Extraluminal Device, Open Approach */
"07VD0DZ" = "1" /* Restriction of Aortic Lymphatic with Intraluminal Device, Open Approach */
"07VD0ZZ" = "1" /* Restriction of Aortic Lymphatic, Open Approach */
"07WP00Z" = "1" /* Revision of Drainage Device in Spleen, Open Approach */
"07WP03Z" = "1" /* Revision of Infusion Device in Spleen, Open Approach */
"07YP0Z0" = "1" /* Transplantation of Spleen, Allogeneic, Open Approach */
"07YP0Z1" = "1" /* Transplantation of Spleen, Syngeneic, Open Approach */
"07YP0Z2" = "1" /* Transplantation of Spleen, Zooplastic, Open Approach */
"0B5R0ZZ" = "1" /* Destruction of Right Diaphragm, Open Approach */
"0B5S0ZZ" = "1" /* Destruction of Left Diaphragm, Open Approach */
"0B9R00Z" = "1" /* Drainage of Right Diaphragm with Drainage Device, Open Approach */
"0B9R0ZX" = "1" /* Drainage of Right Diaphragm, Open Approach, Diagnostic */
"0B9R0ZZ" = "1" /* Drainage of Right Diaphragm, Open Approach */
"0B9S00Z" = "1" /* Drainage of Left Diaphragm with Drainage Device, Open Approach */
"0B9S0ZX" = "1" /* Drainage of Left Diaphragm, Open Approach, Diagnostic */
"0B9S0ZZ" = "1" /* Drainage of Left Diaphragm, Open Approach */
"0BBR0ZX" = "1" /* Excision of Right Diaphragm, Open Approach, Diagnostic */
"0BBR0ZZ" = "1" /* Excision of Right Diaphragm, Open Approach */
"0BBS0ZX" = "1" /* Excision of Left Diaphragm, Open Approach, Diagnostic */
"0BBS0ZZ" = "1" /* Excision of Left Diaphragm, Open Approach */
"0BCR0ZZ" = "1" /* Extirpation of Matter from Right Diaphragm, Open Approach */
"0BCS0ZZ" = "1" /* Extirpation of Matter from Left Diaphragm, Open Approach */
"0BHR02Z" = "1" /* Insertion of Monitoring Device into Right Diaphragm, Open Approach */
"0BHR0MZ" = "1" /* Insertion of Diaphragmatic Pacemaker Lead into Right Diaphragm, Open Approach */
"0BHS02Z" = "1" /* Insertion of Monitoring Device into Left Diaphragm, Open Approach */
"0BHS0MZ" = "1" /* Insertion of Diaphragmatic Pacemaker Lead into Left Diaphragm, Open Approach */
"0BJT0ZZ" = "1" /* Inspection of Diaphragm, Open Approach */
"0BMR0ZZ" = "1" /* Reattachment of Right Diaphragm, Open Approach */
"0BMS0ZZ" = "1" /* Reattachment of Left Diaphragm, Open Approach */
"0BNR0ZZ" = "1" /* Release Right Diaphragm, Open Approach */
"0BNS0ZZ" = "1" /* Release Left Diaphragm, Open Approach */
"0BPT00Z" = "1" /* Removal of Drainage Device from Diaphragm, Open Approach */
"0BPT02Z" = "1" /* Removal of Monitoring Device from Diaphragm, Open Approach */
"0BPT07Z" = "1" /* Removal of Autologous Tissue Substitute from Diaphragm, Open Approach */
"0BPT0JZ" = "1" /* Removal of Synthetic Substitute from Diaphragm, Open Approach */
"0BPT0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Diaphragm, Open Approach */
"0BPT0MZ" = "1" /* Removal of Diaphragmatic Pacemaker Lead from Diaphragm, Open Approach */
"0BQR0ZZ" = "1" /* Repair Right Diaphragm, Open Approach */
"0BQS0ZZ" = "1" /* Repair Left Diaphragm, Open Approach */
"0BSR0ZZ" = "1" /* Reposition Right Diaphragm, Open Approach */
"0BSS0ZZ" = "1" /* Reposition Left Diaphragm, Open Approach */
"0BTR0ZZ" = "1" /* Resection of Right Diaphragm, Open Approach */
"0BTS0ZZ" = "1" /* Resection of Left Diaphragm, Open Approach */
"0BUR07Z" = "1" /* Supplement Right Diaphragm with Autologous Tissue Substitute, Open Approach */
"0BUR0JZ" = "1" /* Supplement Right Diaphragm with Synthetic Substitute, Open Approach */
"0BUR0KZ" = "1" /* Supplement Right Diaphragm with Nonautologous Tissue Substitute, Open Approach */
"0BUS07Z" = "1" /* Supplement Left Diaphragm with Autologous Tissue Substitute, Open Approach */
"0BUS0JZ" = "1" /* Supplement Left Diaphragm with Synthetic Substitute, Open Approach */
"0BUS0KZ" = "1" /* Supplement Left Diaphragm with Nonautologous Tissue Substitute, Open Approach */
"0BWT00Z" = "1" /* Revision of Drainage Device in Diaphragm, Open Approach */
"0BWT02Z" = "1" /* Revision of Monitoring Device in Diaphragm, Open Approach */
"0BWT07Z" = "1" /* Revision of Autologous Tissue Substitute in Diaphragm, Open Approach */
"0BWT0JZ" = "1" /* Revision of Synthetic Substitute in Diaphragm, Open Approach */
"0BWT0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Diaphragm, Open Approach */
"0BWT0MZ" = "1" /* Revision of Diaphragmatic Pacemaker Lead in Diaphragm, Open Approach */
"0D11076" = "1" /* Bypass Upper Esophagus to Stomach with Autologous Tissue Substitute, Open Approach */
"0D11079" = "1" /* Bypass Upper Esophagus to Duodenum with Autologous Tissue Substitute, Open Approach */
"0D1107A" = "1" /* Bypass Upper Esophagus to Jejunum with Autologous Tissue Substitute, Open Approach */
"0D1107B" = "1" /* Bypass Upper Esophagus to Ileum with Autologous Tissue Substitute, Open Approach */
"0D110J6" = "1" /* Bypass Upper Esophagus to Stomach with Synthetic Substitute, Open Approach */
"0D110J9" = "1" /* Bypass Upper Esophagus to Duodenum with Synthetic Substitute, Open Approach */
"0D110JA" = "1" /* Bypass Upper Esophagus to Jejunum with Synthetic Substitute, Open Approach */
"0D110JB" = "1" /* Bypass Upper Esophagus to Ileum with Synthetic Substitute, Open Approach */
"0D110K6" = "1" /* Bypass Upper Esophagus to Stomach with Nonautologous Tissue Substitute, Open Approach */
"0D110K9" = "1" /* Bypass Upper Esophagus to Duodenum with Nonautologous Tissue Substitute, Open Approach */
"0D110KA" = "1" /* Bypass Upper Esophagus to Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0D110KB" = "1" /* Bypass Upper Esophagus to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D110Z6" = "1" /* Bypass Upper Esophagus to Stomach, Open Approach */
"0D110Z9" = "1" /* Bypass Upper Esophagus to Duodenum, Open Approach */
"0D110ZA" = "1" /* Bypass Upper Esophagus to Jejunum, Open Approach */
"0D110ZB" = "1" /* Bypass Upper Esophagus to Ileum, Open Approach */
"0D12076" = "1" /* Bypass Middle Esophagus to Stomach with Autologous Tissue Substitute, Open Approach */
"0D12079" = "1" /* Bypass Middle Esophagus to Duodenum with Autologous Tissue Substitute, Open Approach */
"0D1207A" = "1" /* Bypass Middle Esophagus to Jejunum with Autologous Tissue Substitute, Open Approach */
"0D1207B" = "1" /* Bypass Middle Esophagus to Ileum with Autologous Tissue Substitute, Open Approach */
"0D120J6" = "1" /* Bypass Middle Esophagus to Stomach with Synthetic Substitute, Open Approach */
"0D120J9" = "1" /* Bypass Middle Esophagus to Duodenum with Synthetic Substitute, Open Approach */
"0D120JA" = "1" /* Bypass Middle Esophagus to Jejunum with Synthetic Substitute, Open Approach */
"0D120JB" = "1" /* Bypass Middle Esophagus to Ileum with Synthetic Substitute, Open Approach */
"0D120K6" = "1" /* Bypass Middle Esophagus to Stomach with Nonautologous Tissue Substitute, Open Approach */
"0D120K9" = "1" /* Bypass Middle Esophagus to Duodenum with Nonautologous Tissue Substitute, Open Approach */
"0D120KA" = "1" /* Bypass Middle Esophagus to Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0D120KB" = "1" /* Bypass Middle Esophagus to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D120Z6" = "1" /* Bypass Middle Esophagus to Stomach, Open Approach */
"0D120Z9" = "1" /* Bypass Middle Esophagus to Duodenum, Open Approach */
"0D120ZA" = "1" /* Bypass Middle Esophagus to Jejunum, Open Approach */
"0D120ZB" = "1" /* Bypass Middle Esophagus to Ileum, Open Approach */
"0D13074" = "1" /* Bypass Lower Esophagus to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D13076" = "1" /* Bypass Lower Esophagus to Stomach with Autologous Tissue Substitute, Open Approach */
"0D13079" = "1" /* Bypass Lower Esophagus to Duodenum with Autologous Tissue Substitute, Open Approach */
"0D1307A" = "1" /* Bypass Lower Esophagus to Jejunum with Autologous Tissue Substitute, Open Approach */
"0D1307B" = "1" /* Bypass Lower Esophagus to Ileum with Autologous Tissue Substitute, Open Approach */
"0D130J4" = "1" /* Bypass Lower Esophagus to Cutaneous with Synthetic Substitute, Open Approach */
"0D130J6" = "1" /* Bypass Lower Esophagus to Stomach with Synthetic Substitute, Open Approach */
"0D130J9" = "1" /* Bypass Lower Esophagus to Duodenum with Synthetic Substitute, Open Approach */
"0D130JA" = "1" /* Bypass Lower Esophagus to Jejunum with Synthetic Substitute, Open Approach */
"0D130JB" = "1" /* Bypass Lower Esophagus to Ileum with Synthetic Substitute, Open Approach */
"0D130K4" = "1" /* Bypass Lower Esophagus to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D130K6" = "1" /* Bypass Lower Esophagus to Stomach with Nonautologous Tissue Substitute, Open Approach */
"0D130K9" = "1" /* Bypass Lower Esophagus to Duodenum with Nonautologous Tissue Substitute, Open Approach */
"0D130KA" = "1" /* Bypass Lower Esophagus to Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0D130KB" = "1" /* Bypass Lower Esophagus to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D130Z4" = "1" /* Bypass Lower Esophagus to Cutaneous, Open Approach */
"0D130Z6" = "1" /* Bypass Lower Esophagus to Stomach, Open Approach */
"0D130Z9" = "1" /* Bypass Lower Esophagus to Duodenum, Open Approach */
"0D130ZA" = "1" /* Bypass Lower Esophagus to Jejunum, Open Approach */
"0D130ZB" = "1" /* Bypass Lower Esophagus to Ileum, Open Approach */
"0D15076" = "1" /* Bypass Esophagus to Stomach with Autologous Tissue Substitute, Open Approach */
"0D15079" = "1" /* Bypass Esophagus to Duodenum with Autologous Tissue Substitute, Open Approach */
"0D1507A" = "1" /* Bypass Esophagus to Jejunum with Autologous Tissue Substitute, Open Approach */
"0D1507B" = "1" /* Bypass Esophagus to Ileum with Autologous Tissue Substitute, Open Approach */
"0D150J6" = "1" /* Bypass Esophagus to Stomach with Synthetic Substitute, Open Approach */
"0D150J9" = "1" /* Bypass Esophagus to Duodenum with Synthetic Substitute, Open Approach */
"0D150JA" = "1" /* Bypass Esophagus to Jejunum with Synthetic Substitute, Open Approach */
"0D150JB" = "1" /* Bypass Esophagus to Ileum with Synthetic Substitute, Open Approach */
"0D150K6" = "1" /* Bypass Esophagus to Stomach with Nonautologous Tissue Substitute, Open Approach */
"0D150K9" = "1" /* Bypass Esophagus to Duodenum with Nonautologous Tissue Substitute, Open Approach */
"0D150KA" = "1" /* Bypass Esophagus to Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0D150KB" = "1" /* Bypass Esophagus to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D150Z6" = "1" /* Bypass Esophagus to Stomach, Open Approach */
"0D150Z9" = "1" /* Bypass Esophagus to Duodenum, Open Approach */
"0D150ZA" = "1" /* Bypass Esophagus to Jejunum, Open Approach */
"0D150ZB" = "1" /* Bypass Esophagus to Ileum, Open Approach */
"0D16074" = "1" /* Bypass Stomach to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D16079" = "1" /* Bypass Stomach to Duodenum with Autologous Tissue Substitute, Open Approach */
"0D1607A" = "1" /* Bypass Stomach to Jejunum with Autologous Tissue Substitute, Open Approach */
"0D1607B" = "1" /* Bypass Stomach to Ileum with Autologous Tissue Substitute, Open Approach */
"0D1607L" = "1" /* Bypass Stomach to Transverse Colon with Autologous Tissue Substitute, Open Approach */
"0D160J4" = "1" /* Bypass Stomach to Cutaneous with Synthetic Substitute, Open Approach */
"0D160J9" = "1" /* Bypass Stomach to Duodenum with Synthetic Substitute, Open Approach */
"0D160JA" = "1" /* Bypass Stomach to Jejunum with Synthetic Substitute, Open Approach */
"0D160JB" = "1" /* Bypass Stomach to Ileum with Synthetic Substitute, Open Approach */
"0D160JL" = "1" /* Bypass Stomach to Transverse Colon with Synthetic Substitute, Open Approach */
"0D160K4" = "1" /* Bypass Stomach to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D160K9" = "1" /* Bypass Stomach to Duodenum with Nonautologous Tissue Substitute, Open Approach */
"0D160KA" = "1" /* Bypass Stomach to Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0D160KB" = "1" /* Bypass Stomach to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D160KL" = "1" /* Bypass Stomach to Transverse Colon with Nonautologous Tissue Substitute, Open Approach */
"0D160Z4" = "1" /* Bypass Stomach to Cutaneous, Open Approach */
"0D160Z9" = "1" /* Bypass Stomach to Duodenum, Open Approach */
"0D160ZA" = "1" /* Bypass Stomach to Jejunum, Open Approach */
"0D160ZB" = "1" /* Bypass Stomach to Ileum, Open Approach */
"0D160ZL" = "1" /* Bypass Stomach to Transverse Colon, Open Approach */
"0D19074" = "1" /* Bypass Duodenum to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D19079" = "1" /* Bypass Duodenum to Duodenum with Autologous Tissue Substitute, Open Approach */
"0D1907A" = "1" /* Bypass Duodenum to Jejunum with Autologous Tissue Substitute, Open Approach */
"0D1907B" = "1" /* Bypass Duodenum to Ileum with Autologous Tissue Substitute, Open Approach */
"0D1907L" = "1" /* Bypass Duodenum to Transverse Colon with Autologous Tissue Substitute, Open Approach */
"0D190J4" = "1" /* Bypass Duodenum to Cutaneous with Synthetic Substitute, Open Approach */
"0D190J9" = "1" /* Bypass Duodenum to Duodenum with Synthetic Substitute, Open Approach */
"0D190JA" = "1" /* Bypass Duodenum to Jejunum with Synthetic Substitute, Open Approach */
"0D190JB" = "1" /* Bypass Duodenum to Ileum with Synthetic Substitute, Open Approach */
"0D190JL" = "1" /* Bypass Duodenum to Transverse Colon with Synthetic Substitute, Open Approach */
"0D190K4" = "1" /* Bypass Duodenum to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D190K9" = "1" /* Bypass Duodenum to Duodenum with Nonautologous Tissue Substitute, Open Approach */
"0D190KA" = "1" /* Bypass Duodenum to Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0D190KB" = "1" /* Bypass Duodenum to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D190KL" = "1" /* Bypass Duodenum to Transverse Colon with Nonautologous Tissue Substitute, Open Approach */
"0D190Z4" = "1" /* Bypass Duodenum to Cutaneous, Open Approach */
"0D190Z9" = "1" /* Bypass Duodenum to Duodenum, Open Approach */
"0D190ZA" = "1" /* Bypass Duodenum to Jejunum, Open Approach */
"0D190ZB" = "1" /* Bypass Duodenum to Ileum, Open Approach */
"0D190ZL" = "1" /* Bypass Duodenum to Transverse Colon, Open Approach */
"0D1A074" = "1" /* Bypass Jejunum to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D1A07A" = "1" /* Bypass Jejunum to Jejunum with Autologous Tissue Substitute, Open Approach */
"0D1A07B" = "1" /* Bypass Jejunum to Ileum with Autologous Tissue Substitute, Open Approach */
"0D1A07H" = "1" /* Bypass Jejunum to Cecum with Autologous Tissue Substitute, Open Approach */
"0D1A07K" = "1" /* Bypass Jejunum to Ascending Colon with Autologous Tissue Substitute, Open Approach */
"0D1A07L" = "1" /* Bypass Jejunum to Transverse Colon with Autologous Tissue Substitute, Open Approach */
"0D1A07M" = "1" /* Bypass Jejunum to Descending Colon with Autologous Tissue Substitute, Open Approach */
"0D1A07N" = "1" /* Bypass Jejunum to Sigmoid Colon with Autologous Tissue Substitute, Open Approach */
"0D1A07P" = "1" /* Bypass Jejunum to Rectum with Autologous Tissue Substitute, Open Approach */
"0D1A07Q" = "1" /* Bypass Jejunum to Anus with Autologous Tissue Substitute, Open Approach */
"0D1A0J4" = "1" /* Bypass Jejunum to Cutaneous with Synthetic Substitute, Open Approach */
"0D1A0JA" = "1" /* Bypass Jejunum to Jejunum with Synthetic Substitute, Open Approach */
"0D1A0JB" = "1" /* Bypass Jejunum to Ileum with Synthetic Substitute, Open Approach */
"0D1A0JH" = "1" /* Bypass Jejunum to Cecum with Synthetic Substitute, Open Approach */
"0D1A0JK" = "1" /* Bypass Jejunum to Ascending Colon with Synthetic Substitute, Open Approach */
"0D1A0JL" = "1" /* Bypass Jejunum to Transverse Colon with Synthetic Substitute, Open Approach */
"0D1A0JM" = "1" /* Bypass Jejunum to Descending Colon with Synthetic Substitute, Open Approach */
"0D1A0JN" = "1" /* Bypass Jejunum to Sigmoid Colon with Synthetic Substitute, Open Approach */
"0D1A0JP" = "1" /* Bypass Jejunum to Rectum with Synthetic Substitute, Open Approach */
"0D1A0JQ" = "1" /* Bypass Jejunum to Anus with Synthetic Substitute, Open Approach */
"0D1A0K4" = "1" /* Bypass Jejunum to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D1A0KA" = "1" /* Bypass Jejunum to Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0D1A0KB" = "1" /* Bypass Jejunum to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D1A0KH" = "1" /* Bypass Jejunum to Cecum with Nonautologous Tissue Substitute, Open Approach */
"0D1A0KK" = "1" /* Bypass Jejunum to Ascending Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1A0KL" = "1" /* Bypass Jejunum to Transverse Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1A0KM" = "1" /* Bypass Jejunum to Descending Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1A0KN" = "1" /* Bypass Jejunum to Sigmoid Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1A0KP" = "1" /* Bypass Jejunum to Rectum with Nonautologous Tissue Substitute, Open Approach */
"0D1A0KQ" = "1" /* Bypass Jejunum to Anus with Nonautologous Tissue Substitute, Open Approach */
"0D1A0Z4" = "1" /* Bypass Jejunum to Cutaneous, Open Approach */
"0D1A0ZA" = "1" /* Bypass Jejunum to Jejunum, Open Approach */
"0D1A0ZB" = "1" /* Bypass Jejunum to Ileum, Open Approach */
"0D1A0ZH" = "1" /* Bypass Jejunum to Cecum, Open Approach */
"0D1A0ZK" = "1" /* Bypass Jejunum to Ascending Colon, Open Approach */
"0D1A0ZL" = "1" /* Bypass Jejunum to Transverse Colon, Open Approach */
"0D1A0ZM" = "1" /* Bypass Jejunum to Descending Colon, Open Approach */
"0D1A0ZN" = "1" /* Bypass Jejunum to Sigmoid Colon, Open Approach */
"0D1A0ZP" = "1" /* Bypass Jejunum to Rectum, Open Approach */
"0D1A0ZQ" = "1" /* Bypass Jejunum to Anus, Open Approach */
"0D1B074" = "1" /* Bypass Ileum to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D1B07B" = "1" /* Bypass Ileum to Ileum with Autologous Tissue Substitute, Open Approach */
"0D1B07H" = "1" /* Bypass Ileum to Cecum with Autologous Tissue Substitute, Open Approach */
"0D1B07K" = "1" /* Bypass Ileum to Ascending Colon with Autologous Tissue Substitute, Open Approach */
"0D1B07L" = "1" /* Bypass Ileum to Transverse Colon with Autologous Tissue Substitute, Open Approach */
"0D1B07M" = "1" /* Bypass Ileum to Descending Colon with Autologous Tissue Substitute, Open Approach */
"0D1B07N" = "1" /* Bypass Ileum to Sigmoid Colon with Autologous Tissue Substitute, Open Approach */
"0D1B07P" = "1" /* Bypass Ileum to Rectum with Autologous Tissue Substitute, Open Approach */
"0D1B07Q" = "1" /* Bypass Ileum to Anus with Autologous Tissue Substitute, Open Approach */
"0D1B0J4" = "1" /* Bypass Ileum to Cutaneous with Synthetic Substitute, Open Approach */
"0D1B0JB" = "1" /* Bypass Ileum to Ileum with Synthetic Substitute, Open Approach */
"0D1B0JH" = "1" /* Bypass Ileum to Cecum with Synthetic Substitute, Open Approach */
"0D1B0JK" = "1" /* Bypass Ileum to Ascending Colon with Synthetic Substitute, Open Approach */
"0D1B0JL" = "1" /* Bypass Ileum to Transverse Colon with Synthetic Substitute, Open Approach */
"0D1B0JM" = "1" /* Bypass Ileum to Descending Colon with Synthetic Substitute, Open Approach */
"0D1B0JN" = "1" /* Bypass Ileum to Sigmoid Colon with Synthetic Substitute, Open Approach */
"0D1B0JP" = "1" /* Bypass Ileum to Rectum with Synthetic Substitute, Open Approach */
"0D1B0JQ" = "1" /* Bypass Ileum to Anus with Synthetic Substitute, Open Approach */
"0D1B0K4" = "1" /* Bypass Ileum to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D1B0KB" = "1" /* Bypass Ileum to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D1B0KH" = "1" /* Bypass Ileum to Cecum with Nonautologous Tissue Substitute, Open Approach */
"0D1B0KK" = "1" /* Bypass Ileum to Ascending Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1B0KL" = "1" /* Bypass Ileum to Transverse Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1B0KM" = "1" /* Bypass Ileum to Descending Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1B0KN" = "1" /* Bypass Ileum to Sigmoid Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1B0KP" = "1" /* Bypass Ileum to Rectum with Nonautologous Tissue Substitute, Open Approach */
"0D1B0KQ" = "1" /* Bypass Ileum to Anus with Nonautologous Tissue Substitute, Open Approach */
"0D1B0Z4" = "1" /* Bypass Ileum to Cutaneous, Open Approach */
"0D1B0ZB" = "1" /* Bypass Ileum to Ileum, Open Approach */
"0D1B0ZH" = "1" /* Bypass Ileum to Cecum, Open Approach */
"0D1B0ZK" = "1" /* Bypass Ileum to Ascending Colon, Open Approach */
"0D1B0ZL" = "1" /* Bypass Ileum to Transverse Colon, Open Approach */
"0D1B0ZM" = "1" /* Bypass Ileum to Descending Colon, Open Approach */
"0D1B0ZN" = "1" /* Bypass Ileum to Sigmoid Colon, Open Approach */
"0D1B0ZP" = "1" /* Bypass Ileum to Rectum, Open Approach */
"0D1B0ZQ" = "1" /* Bypass Ileum to Anus, Open Approach */
"0D1H074" = "1" /* Bypass Cecum to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D1H07H" = "1" /* Bypass Cecum to Cecum with Autologous Tissue Substitute, Open Approach */
"0D1H07K" = "1" /* Bypass Cecum to Ascending Colon with Autologous Tissue Substitute, Open Approach */
"0D1H07L" = "1" /* Bypass Cecum to Transverse Colon with Autologous Tissue Substitute, Open Approach */
"0D1H07M" = "1" /* Bypass Cecum to Descending Colon with Autologous Tissue Substitute, Open Approach */
"0D1H07N" = "1" /* Bypass Cecum to Sigmoid Colon with Autologous Tissue Substitute, Open Approach */
"0D1H07P" = "1" /* Bypass Cecum to Rectum with Autologous Tissue Substitute, Open Approach */
"0D1H0J4" = "1" /* Bypass Cecum to Cutaneous with Synthetic Substitute, Open Approach */
"0D1H0JH" = "1" /* Bypass Cecum to Cecum with Synthetic Substitute, Open Approach */
"0D1H0JK" = "1" /* Bypass Cecum to Ascending Colon with Synthetic Substitute, Open Approach */
"0D1H0JL" = "1" /* Bypass Cecum to Transverse Colon with Synthetic Substitute, Open Approach */
"0D1H0JM" = "1" /* Bypass Cecum to Descending Colon with Synthetic Substitute, Open Approach */
"0D1H0JN" = "1" /* Bypass Cecum to Sigmoid Colon with Synthetic Substitute, Open Approach */
"0D1H0JP" = "1" /* Bypass Cecum to Rectum with Synthetic Substitute, Open Approach */
"0D1H0K4" = "1" /* Bypass Cecum to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D1H0KH" = "1" /* Bypass Cecum to Cecum with Nonautologous Tissue Substitute, Open Approach */
"0D1H0KK" = "1" /* Bypass Cecum to Ascending Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1H0KL" = "1" /* Bypass Cecum to Transverse Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1H0KM" = "1" /* Bypass Cecum to Descending Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1H0KN" = "1" /* Bypass Cecum to Sigmoid Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1H0KP" = "1" /* Bypass Cecum to Rectum with Nonautologous Tissue Substitute, Open Approach */
"0D1H0Z4" = "1" /* Bypass Cecum to Cutaneous, Open Approach */
"0D1H0ZH" = "1" /* Bypass Cecum to Cecum, Open Approach */
"0D1H0ZK" = "1" /* Bypass Cecum to Ascending Colon, Open Approach */
"0D1H0ZL" = "1" /* Bypass Cecum to Transverse Colon, Open Approach */
"0D1H0ZM" = "1" /* Bypass Cecum to Descending Colon, Open Approach */
"0D1H0ZN" = "1" /* Bypass Cecum to Sigmoid Colon, Open Approach */
"0D1H0ZP" = "1" /* Bypass Cecum to Rectum, Open Approach */
"0D1K074" = "1" /* Bypass Ascending Colon to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D1K07K" = "1" /* Bypass Ascending Colon to Ascending Colon with Autologous Tissue Substitute, Open Approach */
"0D1K07L" = "1" /* Bypass Ascending Colon to Transverse Colon with Autologous Tissue Substitute, Open Approach */
"0D1K07M" = "1" /* Bypass Ascending Colon to Descending Colon with Autologous Tissue Substitute, Open Approach */
"0D1K07N" = "1" /* Bypass Ascending Colon to Sigmoid Colon with Autologous Tissue Substitute, Open Approach */
"0D1K07P" = "1" /* Bypass Ascending Colon to Rectum with Autologous Tissue Substitute, Open Approach */
"0D1K0J4" = "1" /* Bypass Ascending Colon to Cutaneous with Synthetic Substitute, Open Approach */
"0D1K0JK" = "1" /* Bypass Ascending Colon to Ascending Colon with Synthetic Substitute, Open Approach */
"0D1K0JL" = "1" /* Bypass Ascending Colon to Transverse Colon with Synthetic Substitute, Open Approach */
"0D1K0JM" = "1" /* Bypass Ascending Colon to Descending Colon with Synthetic Substitute, Open Approach */
"0D1K0JN" = "1" /* Bypass Ascending Colon to Sigmoid Colon with Synthetic Substitute, Open Approach */
"0D1K0JP" = "1" /* Bypass Ascending Colon to Rectum with Synthetic Substitute, Open Approach */
"0D1K0K4" = "1" /* Bypass Ascending Colon to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D1K0KK" = "1" /* Bypass Ascending Colon to Ascending Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1K0KL" = "1" /* Bypass Ascending Colon to Transverse Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1K0KM" = "1" /* Bypass Ascending Colon to Descending Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1K0KN" = "1" /* Bypass Ascending Colon to Sigmoid Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1K0KP" = "1" /* Bypass Ascending Colon to Rectum with Nonautologous Tissue Substitute, Open Approach */
"0D1K0Z4" = "1" /* Bypass Ascending Colon to Cutaneous, Open Approach */
"0D1K0ZK" = "1" /* Bypass Ascending Colon to Ascending Colon, Open Approach */
"0D1K0ZL" = "1" /* Bypass Ascending Colon to Transverse Colon, Open Approach */
"0D1K0ZM" = "1" /* Bypass Ascending Colon to Descending Colon, Open Approach */
"0D1K0ZN" = "1" /* Bypass Ascending Colon to Sigmoid Colon, Open Approach */
"0D1K0ZP" = "1" /* Bypass Ascending Colon to Rectum, Open Approach */
"0D1L074" = "1" /* Bypass Transverse Colon to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D1L07L" = "1" /* Bypass Transverse Colon to Transverse Colon with Autologous Tissue Substitute, Open Approach */
"0D1L07M" = "1" /* Bypass Transverse Colon to Descending Colon with Autologous Tissue Substitute, Open Approach */
"0D1L07N" = "1" /* Bypass Transverse Colon to Sigmoid Colon with Autologous Tissue Substitute, Open Approach */
"0D1L07P" = "1" /* Bypass Transverse Colon to Rectum with Autologous Tissue Substitute, Open Approach */
"0D1L0J4" = "1" /* Bypass Transverse Colon to Cutaneous with Synthetic Substitute, Open Approach */
"0D1L0JL" = "1" /* Bypass Transverse Colon to Transverse Colon with Synthetic Substitute, Open Approach */
"0D1L0JM" = "1" /* Bypass Transverse Colon to Descending Colon with Synthetic Substitute, Open Approach */
"0D1L0JN" = "1" /* Bypass Transverse Colon to Sigmoid Colon with Synthetic Substitute, Open Approach */
"0D1L0JP" = "1" /* Bypass Transverse Colon to Rectum with Synthetic Substitute, Open Approach */
"0D1L0K4" = "1" /* Bypass Transverse Colon to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D1L0KL" = "1" /* Bypass Transverse Colon to Transverse Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1L0KM" = "1" /* Bypass Transverse Colon to Descending Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1L0KN" = "1" /* Bypass Transverse Colon to Sigmoid Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1L0KP" = "1" /* Bypass Transverse Colon to Rectum with Nonautologous Tissue Substitute, Open Approach */
"0D1L0Z4" = "1" /* Bypass Transverse Colon to Cutaneous, Open Approach */
"0D1L0ZL" = "1" /* Bypass Transverse Colon to Transverse Colon, Open Approach */
"0D1L0ZM" = "1" /* Bypass Transverse Colon to Descending Colon, Open Approach */
"0D1L0ZN" = "1" /* Bypass Transverse Colon to Sigmoid Colon, Open Approach */
"0D1L0ZP" = "1" /* Bypass Transverse Colon to Rectum, Open Approach */
"0D1M074" = "1" /* Bypass Descending Colon to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D1M07M" = "1" /* Bypass Descending Colon to Descending Colon with Autologous Tissue Substitute, Open Approach */
"0D1M07N" = "1" /* Bypass Descending Colon to Sigmoid Colon with Autologous Tissue Substitute, Open Approach */
"0D1M07P" = "1" /* Bypass Descending Colon to Rectum with Autologous Tissue Substitute, Open Approach */
"0D1M0J4" = "1" /* Bypass Descending Colon to Cutaneous with Synthetic Substitute, Open Approach */
"0D1M0JM" = "1" /* Bypass Descending Colon to Descending Colon with Synthetic Substitute, Open Approach */
"0D1M0JN" = "1" /* Bypass Descending Colon to Sigmoid Colon with Synthetic Substitute, Open Approach */
"0D1M0JP" = "1" /* Bypass Descending Colon to Rectum with Synthetic Substitute, Open Approach */
"0D1M0K4" = "1" /* Bypass Descending Colon to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D1M0KM" = "1" /* Bypass Descending Colon to Descending Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1M0KN" = "1" /* Bypass Descending Colon to Sigmoid Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1M0KP" = "1" /* Bypass Descending Colon to Rectum with Nonautologous Tissue Substitute, Open Approach */
"0D1M0Z4" = "1" /* Bypass Descending Colon to Cutaneous, Open Approach */
"0D1M0ZM" = "1" /* Bypass Descending Colon to Descending Colon, Open Approach */
"0D1M0ZN" = "1" /* Bypass Descending Colon to Sigmoid Colon, Open Approach */
"0D1M0ZP" = "1" /* Bypass Descending Colon to Rectum, Open Approach */
"0D1N074" = "1" /* Bypass Sigmoid Colon to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D1N07N" = "1" /* Bypass Sigmoid Colon to Sigmoid Colon with Autologous Tissue Substitute, Open Approach */
"0D1N07P" = "1" /* Bypass Sigmoid Colon to Rectum with Autologous Tissue Substitute, Open Approach */
"0D1N0J4" = "1" /* Bypass Sigmoid Colon to Cutaneous with Synthetic Substitute, Open Approach */
"0D1N0JN" = "1" /* Bypass Sigmoid Colon to Sigmoid Colon with Synthetic Substitute, Open Approach */
"0D1N0JP" = "1" /* Bypass Sigmoid Colon to Rectum with Synthetic Substitute, Open Approach */
"0D1N0K4" = "1" /* Bypass Sigmoid Colon to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D1N0KN" = "1" /* Bypass Sigmoid Colon to Sigmoid Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1N0KP" = "1" /* Bypass Sigmoid Colon to Rectum with Nonautologous Tissue Substitute, Open Approach */
"0D1N0Z4" = "1" /* Bypass Sigmoid Colon to Cutaneous, Open Approach */
"0D1N0ZN" = "1" /* Bypass Sigmoid Colon to Sigmoid Colon, Open Approach */
"0D1N0ZP" = "1" /* Bypass Sigmoid Colon to Rectum, Open Approach */
"0D530ZZ" = "1" /* Destruction of Lower Esophagus, Open Approach */
"0D540ZZ" = "1" /* Destruction of Esophagogastric Junction, Open Approach */
"0D560ZZ" = "1" /* Destruction of Stomach, Open Approach */
"0D570ZZ" = "1" /* Destruction of Stomach, Pylorus, Open Approach */
"0D580ZZ" = "1" /* Destruction of Small Intestine, Open Approach */
"0D590ZZ" = "1" /* Destruction of Duodenum, Open Approach */
"0D5A0ZZ" = "1" /* Destruction of Jejunum, Open Approach */
"0D5B0ZZ" = "1" /* Destruction of Ileum, Open Approach */
"0D5C0ZZ" = "1" /* Destruction of Ileocecal Valve, Open Approach */
"0D5E0ZZ" = "1" /* Destruction of Large Intestine, Open Approach */
"0D5F0ZZ" = "1" /* Destruction of Right Large Intestine, Open Approach */
"0D5G0ZZ" = "1" /* Destruction of Left Large Intestine, Open Approach */
"0D5H0ZZ" = "1" /* Destruction of Cecum, Open Approach */
"0D5J0ZZ" = "1" /* Destruction of Appendix, Open Approach */
"0D5K0ZZ" = "1" /* Destruction of Ascending Colon, Open Approach */
"0D5L0ZZ" = "1" /* Destruction of Transverse Colon, Open Approach */
"0D5M0ZZ" = "1" /* Destruction of Descending Colon, Open Approach */
"0D5N0ZZ" = "1" /* Destruction of Sigmoid Colon, Open Approach */
"0D5P0ZZ" = "1" /* Destruction of Rectum, Open Approach */
"0D5S0ZZ" = "1" /* Destruction of Greater Omentum, Open Approach */
"0D5T0ZZ" = "1" /* Destruction of Lesser Omentum, Open Approach */
"0D5V0ZZ" = "1" /* Destruction of Mesentery, Open Approach */
"0D5W0ZZ" = "1" /* Destruction of Peritoneum, Open Approach */
"0D740DZ" = "1" /* Dilation of Esophagogastric Junction with Intraluminal Device, Open Approach */
"0D740ZZ" = "1" /* Dilation of Esophagogastric Junction, Open Approach */
"0D760DZ" = "1" /* Dilation of Stomach with Intraluminal Device, Open Approach */
"0D760ZZ" = "1" /* Dilation of Stomach, Open Approach */
"0D770DZ" = "1" /* Dilation of Stomach, Pylorus with Intraluminal Device, Open Approach */
"0D770ZZ" = "1" /* Dilation of Stomach, Pylorus, Open Approach */
"0D780DZ" = "1" /* Dilation of Small Intestine with Intraluminal Device, Open Approach */
"0D780ZZ" = "1" /* Dilation of Small Intestine, Open Approach */
"0D790DZ" = "1" /* Dilation of Duodenum with Intraluminal Device, Open Approach */
"0D790ZZ" = "1" /* Dilation of Duodenum, Open Approach */
"0D7A0DZ" = "1" /* Dilation of Jejunum with Intraluminal Device, Open Approach */
"0D7A0ZZ" = "1" /* Dilation of Jejunum, Open Approach */
"0D7B0DZ" = "1" /* Dilation of Ileum with Intraluminal Device, Open Approach */
"0D7B0ZZ" = "1" /* Dilation of Ileum, Open Approach */
"0D7C0DZ" = "1" /* Dilation of Ileocecal Valve with Intraluminal Device, Open Approach */
"0D7C0ZZ" = "1" /* Dilation of Ileocecal Valve, Open Approach */
"0D7E0DZ" = "1" /* Dilation of Large Intestine with Intraluminal Device, Open Approach */
"0D7E0ZZ" = "1" /* Dilation of Large Intestine, Open Approach */
"0D7F0DZ" = "1" /* Dilation of Right Large Intestine with Intraluminal Device, Open Approach */
"0D7F0ZZ" = "1" /* Dilation of Right Large Intestine, Open Approach */
"0D7G0DZ" = "1" /* Dilation of Left Large Intestine with Intraluminal Device, Open Approach */
"0D7G0ZZ" = "1" /* Dilation of Left Large Intestine, Open Approach */
"0D7H0DZ" = "1" /* Dilation of Cecum with Intraluminal Device, Open Approach */
"0D7H0ZZ" = "1" /* Dilation of Cecum, Open Approach */
"0D7K0DZ" = "1" /* Dilation of Ascending Colon with Intraluminal Device, Open Approach */
"0D7K0ZZ" = "1" /* Dilation of Ascending Colon, Open Approach */
"0D7L0DZ" = "1" /* Dilation of Transverse Colon with Intraluminal Device, Open Approach */
"0D7L0ZZ" = "1" /* Dilation of Transverse Colon, Open Approach */
"0D7M0DZ" = "1" /* Dilation of Descending Colon with Intraluminal Device, Open Approach */
"0D7M0ZZ" = "1" /* Dilation of Descending Colon, Open Approach */
"0D7N0DZ" = "1" /* Dilation of Sigmoid Colon with Intraluminal Device, Open Approach */
"0D7N0ZZ" = "1" /* Dilation of Sigmoid Colon, Open Approach */
"0D7P0DZ" = "1" /* Dilation of Rectum with Intraluminal Device, Open Approach */
"0D7P0ZZ" = "1" /* Dilation of Rectum, Open Approach */
"0D840ZZ" = "1" /* Division of Esophagogastric Junction, Open Approach */
"0D870ZZ" = "1" /* Division of Stomach, Pylorus, Open Approach */
"0D9400Z" = "1" /* Drainage of Esophagogastric Junction with Drainage Device, Open Approach */
"0D940ZX" = "1" /* Drainage of Esophagogastric Junction, Open Approach, Diagnostic */
"0D940ZZ" = "1" /* Drainage of Esophagogastric Junction, Open Approach */
"0D9600Z" = "1" /* Drainage of Stomach with Drainage Device, Open Approach */
"0D960ZX" = "1" /* Drainage of Stomach, Open Approach, Diagnostic */
"0D960ZZ" = "1" /* Drainage of Stomach, Open Approach */
"0D9700Z" = "1" /* Drainage of Stomach, Pylorus with Drainage Device, Open Approach */
"0D970ZX" = "1" /* Drainage of Stomach, Pylorus, Open Approach, Diagnostic */
"0D970ZZ" = "1" /* Drainage of Stomach, Pylorus, Open Approach */
"0D9800Z" = "1" /* Drainage of Small Intestine with Drainage Device, Open Approach */
"0D980ZX" = "1" /* Drainage of Small Intestine, Open Approach, Diagnostic */
"0D980ZZ" = "1" /* Drainage of Small Intestine, Open Approach */
"0D9900Z" = "1" /* Drainage of Duodenum with Drainage Device, Open Approach */
"0D990ZX" = "1" /* Drainage of Duodenum, Open Approach, Diagnostic */
"0D990ZZ" = "1" /* Drainage of Duodenum, Open Approach */
"0D9A00Z" = "1" /* Drainage of Jejunum with Drainage Device, Open Approach */
"0D9A0ZX" = "1" /* Drainage of Jejunum, Open Approach, Diagnostic */
"0D9A0ZZ" = "1" /* Drainage of Jejunum, Open Approach */
"0D9B00Z" = "1" /* Drainage of Ileum with Drainage Device, Open Approach */
"0D9B0ZX" = "1" /* Drainage of Ileum, Open Approach, Diagnostic */
"0D9B0ZZ" = "1" /* Drainage of Ileum, Open Approach */
"0D9C00Z" = "1" /* Drainage of Ileocecal Valve with Drainage Device, Open Approach */
"0D9C0ZX" = "1" /* Drainage of Ileocecal Valve, Open Approach, Diagnostic */
"0D9C0ZZ" = "1" /* Drainage of Ileocecal Valve, Open Approach */
"0D9E00Z" = "1" /* Drainage of Large Intestine with Drainage Device, Open Approach */
"0D9E0ZX" = "1" /* Drainage of Large Intestine, Open Approach, Diagnostic */
"0D9E0ZZ" = "1" /* Drainage of Large Intestine, Open Approach */
"0D9F00Z" = "1" /* Drainage of Right Large Intestine with Drainage Device, Open Approach */
"0D9F0ZX" = "1" /* Drainage of Right Large Intestine, Open Approach, Diagnostic */
"0D9F0ZZ" = "1" /* Drainage of Right Large Intestine, Open Approach */
"0D9G00Z" = "1" /* Drainage of Left Large Intestine with Drainage Device, Open Approach */
"0D9G0ZX" = "1" /* Drainage of Left Large Intestine, Open Approach, Diagnostic */
"0D9G0ZZ" = "1" /* Drainage of Left Large Intestine, Open Approach */
"0D9H00Z" = "1" /* Drainage of Cecum with Drainage Device, Open Approach */
"0D9H0ZX" = "1" /* Drainage of Cecum, Open Approach, Diagnostic */
"0D9H0ZZ" = "1" /* Drainage of Cecum, Open Approach */
"0D9J00Z" = "1" /* Drainage of Appendix with Drainage Device, Open Approach */
"0D9J0ZX" = "1" /* Drainage of Appendix, Open Approach, Diagnostic */
"0D9J0ZZ" = "1" /* Drainage of Appendix, Open Approach */
"0D9K00Z" = "1" /* Drainage of Ascending Colon with Drainage Device, Open Approach */
"0D9K0ZX" = "1" /* Drainage of Ascending Colon, Open Approach, Diagnostic */
"0D9K0ZZ" = "1" /* Drainage of Ascending Colon, Open Approach */
"0D9L00Z" = "1" /* Drainage of Transverse Colon with Drainage Device, Open Approach */
"0D9L0ZX" = "1" /* Drainage of Transverse Colon, Open Approach, Diagnostic */
"0D9L0ZZ" = "1" /* Drainage of Transverse Colon, Open Approach */
"0D9M00Z" = "1" /* Drainage of Descending Colon with Drainage Device, Open Approach */
"0D9M0ZX" = "1" /* Drainage of Descending Colon, Open Approach, Diagnostic */
"0D9M0ZZ" = "1" /* Drainage of Descending Colon, Open Approach */
"0D9N00Z" = "1" /* Drainage of Sigmoid Colon with Drainage Device, Open Approach */
"0D9N0ZX" = "1" /* Drainage of Sigmoid Colon, Open Approach, Diagnostic */
"0D9N0ZZ" = "1" /* Drainage of Sigmoid Colon, Open Approach */
"0D9P00Z" = "1" /* Drainage of Rectum with Drainage Device, Open Approach */
"0D9P0ZX" = "1" /* Drainage of Rectum, Open Approach, Diagnostic */
"0D9P0ZZ" = "1" /* Drainage of Rectum, Open Approach */
"0D9S00Z" = "1" /* Drainage of Greater Omentum with Drainage Device, Open Approach */
"0D9S0ZX" = "1" /* Drainage of Greater Omentum, Open Approach, Diagnostic */
"0D9S0ZZ" = "1" /* Drainage of Greater Omentum, Open Approach */
"0D9T00Z" = "1" /* Drainage of Lesser Omentum with Drainage Device, Open Approach */
"0D9T0ZX" = "1" /* Drainage of Lesser Omentum, Open Approach, Diagnostic */
"0D9T0ZZ" = "1" /* Drainage of Lesser Omentum, Open Approach */
"0D9V00Z" = "1" /* Drainage of Mesentery with Drainage Device, Open Approach */
"0D9V0ZX" = "1" /* Drainage of Mesentery, Open Approach, Diagnostic */
"0D9V0ZZ" = "1" /* Drainage of Mesentery, Open Approach */
"0D9W00Z" = "1" /* Drainage of Peritoneum with Drainage Device, Open Approach */
"0D9W0ZX" = "1" /* Drainage of Peritoneum, Open Approach, Diagnostic */
"0D9W0ZZ" = "1" /* Drainage of Peritoneum, Open Approach */
"0DB10ZX" = "1" /* Excision of Upper Esophagus, Open Approach, Diagnostic */
"0DB20ZX" = "1" /* Excision of Middle Esophagus, Open Approach, Diagnostic */
"0DB30ZX" = "1" /* Excision of Lower Esophagus, Open Approach, Diagnostic */
"0DB30ZZ" = "1" /* Excision of Lower Esophagus, Open Approach */
"0DB40ZX" = "1" /* Excision of Esophagogastric Junction, Open Approach, Diagnostic */
"0DB40ZZ" = "1" /* Excision of Esophagogastric Junction, Open Approach */
"0DB50ZX" = "1" /* Excision of Esophagus, Open Approach, Diagnostic */
"0DB50ZZ" = "1" /* Excision of Esophagus, Open Approach */
"0DB60Z3" = "1" /* Excision of Stomach, Open Approach, Vertical */
"0DB60ZX" = "1" /* Excision of Stomach, Open Approach, Diagnostic */
"0DB60ZZ" = "1" /* Excision of Stomach, Open Approach */
"0DB70ZX" = "1" /* Excision of Stomach, Pylorus, Open Approach, Diagnostic */
"0DB70ZZ" = "1" /* Excision of Stomach, Pylorus, Open Approach */
"0DB80ZX" = "1" /* Excision of Small Intestine, Open Approach, Diagnostic */
"0DB80ZZ" = "1" /* Excision of Small Intestine, Open Approach */
"0DB90ZX" = "1" /* Excision of Duodenum, Open Approach, Diagnostic */
"0DB90ZZ" = "1" /* Excision of Duodenum, Open Approach */
"0DBA0ZX" = "1" /* Excision of Jejunum, Open Approach, Diagnostic */
"0DBA0ZZ" = "1" /* Excision of Jejunum, Open Approach */
"0DBB0ZX" = "1" /* Excision of Ileum, Open Approach, Diagnostic */
"0DBB0ZZ" = "1" /* Excision of Ileum, Open Approach */
"0DBC0ZX" = "1" /* Excision of Ileocecal Valve, Open Approach, Diagnostic */
"0DBC0ZZ" = "1" /* Excision of Ileocecal Valve, Open Approach */
"0DBE0ZX" = "1" /* Excision of Large Intestine, Open Approach, Diagnostic */
"0DBE0ZZ" = "1" /* Excision of Large Intestine, Open Approach */
"0DBF0ZX" = "1" /* Excision of Right Large Intestine, Open Approach, Diagnostic */
"0DBF0ZZ" = "1" /* Excision of Right Large Intestine, Open Approach */
"0DBG0ZX" = "1" /* Excision of Left Large Intestine, Open Approach, Diagnostic */
"0DBG0ZZ" = "1" /* Excision of Left Large Intestine, Open Approach */
"0DBH0ZX" = "1" /* Excision of Cecum, Open Approach, Diagnostic */
"0DBH0ZZ" = "1" /* Excision of Cecum, Open Approach */
"0DBJ0ZX" = "1" /* Excision of Appendix, Open Approach, Diagnostic */
"0DBJ0ZZ" = "1" /* Excision of Appendix, Open Approach */
"0DBK0ZX" = "1" /* Excision of Ascending Colon, Open Approach, Diagnostic */
"0DBK0ZZ" = "1" /* Excision of Ascending Colon, Open Approach */
"0DBL0ZX" = "1" /* Excision of Transverse Colon, Open Approach, Diagnostic */
"0DBL0ZZ" = "1" /* Excision of Transverse Colon, Open Approach */
"0DBM0ZX" = "1" /* Excision of Descending Colon, Open Approach, Diagnostic */
"0DBM0ZZ" = "1" /* Excision of Descending Colon, Open Approach */
"0DBN0ZX" = "1" /* Excision of Sigmoid Colon, Open Approach, Diagnostic */
"0DBN0ZZ" = "1" /* Excision of Sigmoid Colon, Open Approach */
"0DBP0ZX" = "1" /* Excision of Rectum, Open Approach, Diagnostic */
"0DBP0ZZ" = "1" /* Excision of Rectum, Open Approach */
"0DBS0ZX" = "1" /* Excision of Greater Omentum, Open Approach, Diagnostic */
"0DBS0ZZ" = "1" /* Excision of Greater Omentum, Open Approach */
"0DBT0ZX" = "1" /* Excision of Lesser Omentum, Open Approach, Diagnostic */
"0DBT0ZZ" = "1" /* Excision of Lesser Omentum, Open Approach */
"0DBV0ZX" = "1" /* Excision of Mesentery, Open Approach, Diagnostic */
"0DBV0ZZ" = "1" /* Excision of Mesentery, Open Approach */
"0DBW0ZX" = "1" /* Excision of Peritoneum, Open Approach, Diagnostic */
"0DBW0ZZ" = "1" /* Excision of Peritoneum, Open Approach */
"0DC40ZZ" = "1" /* Extirpation of Matter from Esophagogastric Junction, Open Approach */
"0DC60ZZ" = "1" /* Extirpation of Matter from Stomach, Open Approach */
"0DC70ZZ" = "1" /* Extirpation of Matter from Stomach, Pylorus, Open Approach */
"0DC80ZZ" = "1" /* Extirpation of Matter from Small Intestine, Open Approach */
"0DC90ZZ" = "1" /* Extirpation of Matter from Duodenum, Open Approach */
"0DCA0ZZ" = "1" /* Extirpation of Matter from Jejunum, Open Approach */
"0DCB0ZZ" = "1" /* Extirpation of Matter from Ileum, Open Approach */
"0DCC0ZZ" = "1" /* Extirpation of Matter from Ileocecal Valve, Open Approach */
"0DCE0ZZ" = "1" /* Extirpation of Matter from Large Intestine, Open Approach */
"0DCF0ZZ" = "1" /* Extirpation of Matter from Right Large Intestine, Open Approach */
"0DCG0ZZ" = "1" /* Extirpation of Matter from Left Large Intestine, Open Approach */
"0DCH0ZZ" = "1" /* Extirpation of Matter from Cecum, Open Approach */
"0DCJ0ZZ" = "1" /* Extirpation of Matter from Appendix, Open Approach */
"0DCK0ZZ" = "1" /* Extirpation of Matter from Ascending Colon, Open Approach */
"0DCL0ZZ" = "1" /* Extirpation of Matter from Transverse Colon, Open Approach */
"0DCM0ZZ" = "1" /* Extirpation of Matter from Descending Colon, Open Approach */
"0DCN0ZZ" = "1" /* Extirpation of Matter from Sigmoid Colon, Open Approach */
"0DCP0ZZ" = "1" /* Extirpation of Matter from Rectum, Open Approach */
"0DCS0ZZ" = "1" /* Extirpation of Matter from Greater Omentum, Open Approach */
"0DCT0ZZ" = "1" /* Extirpation of Matter from Lesser Omentum, Open Approach */
"0DCV0ZZ" = "1" /* Extirpation of Matter from Mesentery, Open Approach */
"0DCW0ZZ" = "1" /* Extirpation of Matter from Peritoneum, Open Approach */
"0DF60ZZ" = "1" /* Fragmentation in Stomach, Open Approach */
"0DF80ZZ" = "1" /* Fragmentation in Small Intestine, Open Approach */
"0DF90ZZ" = "1" /* Fragmentation in Duodenum, Open Approach */
"0DFA0ZZ" = "1" /* Fragmentation in Jejunum, Open Approach */
"0DFB0ZZ" = "1" /* Fragmentation in Ileum, Open Approach */
"0DFE0ZZ" = "1" /* Fragmentation in Large Intestine, Open Approach */
"0DFF0ZZ" = "1" /* Fragmentation in Right Large Intestine, Open Approach */
"0DFG0ZZ" = "1" /* Fragmentation in Left Large Intestine, Open Approach */
"0DFH0ZZ" = "1" /* Fragmentation in Cecum, Open Approach */
"0DFJ0ZZ" = "1" /* Fragmentation in Appendix, Open Approach */
"0DFK0ZZ" = "1" /* Fragmentation in Ascending Colon, Open Approach */
"0DFL0ZZ" = "1" /* Fragmentation in Transverse Colon, Open Approach */
"0DFM0ZZ" = "1" /* Fragmentation in Descending Colon, Open Approach */
"0DFN0ZZ" = "1" /* Fragmentation in Sigmoid Colon, Open Approach */
"0DFP0ZZ" = "1" /* Fragmentation in Rectum, Open Approach */
"0DH602Z" = "1" /* Insertion of Monitoring Device into Stomach, Open Approach */
"0DH603Z" = "1" /* Insertion of Infusion Device into Stomach, Open Approach */
"0DH60DZ" = "1" /* Insertion of Intraluminal Device into Stomach, Open Approach */
"0DH60MZ" = "1" /* Insertion of Stimulator Lead into Stomach, Open Approach */
"0DH60UZ" = "1" /* Insertion of Feeding Device into Stomach, Open Approach */
"0DH802Z" = "1" /* Insertion of Monitoring Device into Small Intestine, Open Approach */
"0DH803Z" = "1" /* Insertion of Infusion Device into Small Intestine, Open Approach */
"0DH80DZ" = "1" /* Insertion of Intraluminal Device into Small Intestine, Open Approach */
"0DH80UZ" = "1" /* Insertion of Feeding Device into Small Intestine, Open Approach */
"0DH902Z" = "1" /* Insertion of Monitoring Device into Duodenum, Open Approach */
"0DH903Z" = "1" /* Insertion of Infusion Device into Duodenum, Open Approach */
"0DH90DZ" = "1" /* Insertion of Intraluminal Device into Duodenum, Open Approach */
"0DH90UZ" = "1" /* Insertion of Feeding Device into Duodenum, Open Approach */
"0DHA02Z" = "1" /* Insertion of Monitoring Device into Jejunum, Open Approach */
"0DHA03Z" = "1" /* Insertion of Infusion Device into Jejunum, Open Approach */
"0DHA0DZ" = "1" /* Insertion of Intraluminal Device into Jejunum, Open Approach */
"0DHA0UZ" = "1" /* Insertion of Feeding Device into Jejunum, Open Approach */
"0DHB02Z" = "1" /* Insertion of Monitoring Device into Ileum, Open Approach */
"0DHB03Z" = "1" /* Insertion of Infusion Device into Ileum, Open Approach */
"0DHB0DZ" = "1" /* Insertion of Intraluminal Device into Ileum, Open Approach */
"0DHB0UZ" = "1" /* Insertion of Feeding Device into Ileum, Open Approach */
"0DHE0DZ" = "1" /* Insertion of Intraluminal Device into Large Intestine, Open Approach */
"0DHP01Z" = "1" /* Insertion of Radioactive Element into Rectum, Open Approach */
"0DHP0DZ" = "1" /* Insertion of Intraluminal Device into Rectum, Open Approach */
"0DJ00ZZ" = "1" /* Inspection of Upper Intestinal Tract, Open Approach */
"0DJ60ZZ" = "1" /* Inspection of Stomach, Open Approach */
"0DJD0ZZ" = "1" /* Inspection of Lower Intestinal Tract, Open Approach */
"0DJU0ZZ" = "1" /* Inspection of Omentum, Open Approach */
"0DJV0ZZ" = "1" /* Inspection of Mesentery, Open Approach */
"0DJW0ZZ" = "1" /* Inspection of Peritoneum, Open Approach */
"0DL40CZ" = "1" /* Occlusion of Esophagogastric Junction with Extraluminal Device, Open Approach */
"0DL40DZ" = "1" /* Occlusion of Esophagogastric Junction with Intraluminal Device, Open Approach */
"0DL40ZZ" = "1" /* Occlusion of Esophagogastric Junction, Open Approach */
"0DL60CZ" = "1" /* Occlusion of Stomach with Extraluminal Device, Open Approach */
"0DL60DZ" = "1" /* Occlusion of Stomach with Intraluminal Device, Open Approach */
"0DL60ZZ" = "1" /* Occlusion of Stomach, Open Approach */
"0DL70CZ" = "1" /* Occlusion of Stomach, Pylorus with Extraluminal Device, Open Approach */
"0DL70DZ" = "1" /* Occlusion of Stomach, Pylorus with Intraluminal Device, Open Approach */
"0DL70ZZ" = "1" /* Occlusion of Stomach, Pylorus, Open Approach */
"0DL80CZ" = "1" /* Occlusion of Small Intestine with Extraluminal Device, Open Approach */
"0DL80DZ" = "1" /* Occlusion of Small Intestine with Intraluminal Device, Open Approach */
"0DL80ZZ" = "1" /* Occlusion of Small Intestine, Open Approach */
"0DL90CZ" = "1" /* Occlusion of Duodenum with Extraluminal Device, Open Approach */
"0DL90DZ" = "1" /* Occlusion of Duodenum with Intraluminal Device, Open Approach */
"0DL90ZZ" = "1" /* Occlusion of Duodenum, Open Approach */
"0DLA0CZ" = "1" /* Occlusion of Jejunum with Extraluminal Device, Open Approach */
"0DLA0DZ" = "1" /* Occlusion of Jejunum with Intraluminal Device, Open Approach */
"0DLA0ZZ" = "1" /* Occlusion of Jejunum, Open Approach */
"0DLB0CZ" = "1" /* Occlusion of Ileum with Extraluminal Device, Open Approach */
"0DLB0DZ" = "1" /* Occlusion of Ileum with Intraluminal Device, Open Approach */
"0DLB0ZZ" = "1" /* Occlusion of Ileum, Open Approach */
"0DLC0CZ" = "1" /* Occlusion of Ileocecal Valve with Extraluminal Device, Open Approach */
"0DLC0DZ" = "1" /* Occlusion of Ileocecal Valve with Intraluminal Device, Open Approach */
"0DLC0ZZ" = "1" /* Occlusion of Ileocecal Valve, Open Approach */
"0DLE0CZ" = "1" /* Occlusion of Large Intestine with Extraluminal Device, Open Approach */
"0DLE0DZ" = "1" /* Occlusion of Large Intestine with Intraluminal Device, Open Approach */
"0DLE0ZZ" = "1" /* Occlusion of Large Intestine, Open Approach */
"0DLF0CZ" = "1" /* Occlusion of Right Large Intestine with Extraluminal Device, Open Approach */
"0DLF0DZ" = "1" /* Occlusion of Right Large Intestine with Intraluminal Device, Open Approach */
"0DLF0ZZ" = "1" /* Occlusion of Right Large Intestine, Open Approach */
"0DLG0CZ" = "1" /* Occlusion of Left Large Intestine with Extraluminal Device, Open Approach */
"0DLG0DZ" = "1" /* Occlusion of Left Large Intestine with Intraluminal Device, Open Approach */
"0DLG0ZZ" = "1" /* Occlusion of Left Large Intestine, Open Approach */
"0DLH0CZ" = "1" /* Occlusion of Cecum with Extraluminal Device, Open Approach */
"0DLH0DZ" = "1" /* Occlusion of Cecum with Intraluminal Device, Open Approach */
"0DLH0ZZ" = "1" /* Occlusion of Cecum, Open Approach */
"0DLK0CZ" = "1" /* Occlusion of Ascending Colon with Extraluminal Device, Open Approach */
"0DLK0DZ" = "1" /* Occlusion of Ascending Colon with Intraluminal Device, Open Approach */
"0DLK0ZZ" = "1" /* Occlusion of Ascending Colon, Open Approach */
"0DLL0CZ" = "1" /* Occlusion of Transverse Colon with Extraluminal Device, Open Approach */
"0DLL0DZ" = "1" /* Occlusion of Transverse Colon with Intraluminal Device, Open Approach */
"0DLL0ZZ" = "1" /* Occlusion of Transverse Colon, Open Approach */
"0DLM0CZ" = "1" /* Occlusion of Descending Colon with Extraluminal Device, Open Approach */
"0DLM0DZ" = "1" /* Occlusion of Descending Colon with Intraluminal Device, Open Approach */
"0DLM0ZZ" = "1" /* Occlusion of Descending Colon, Open Approach */
"0DLN0CZ" = "1" /* Occlusion of Sigmoid Colon with Extraluminal Device, Open Approach */
"0DLN0DZ" = "1" /* Occlusion of Sigmoid Colon with Intraluminal Device, Open Approach */
"0DLN0ZZ" = "1" /* Occlusion of Sigmoid Colon, Open Approach */
"0DLP0CZ" = "1" /* Occlusion of Rectum with Extraluminal Device, Open Approach */
"0DLP0DZ" = "1" /* Occlusion of Rectum with Intraluminal Device, Open Approach */
"0DLP0ZZ" = "1" /* Occlusion of Rectum, Open Approach */
"0DM60ZZ" = "1" /* Reattachment of Stomach, Open Approach */
"0DM80ZZ" = "1" /* Reattachment of Small Intestine, Open Approach */
"0DM90ZZ" = "1" /* Reattachment of Duodenum, Open Approach */
"0DMA0ZZ" = "1" /* Reattachment of Jejunum, Open Approach */
"0DMB0ZZ" = "1" /* Reattachment of Ileum, Open Approach */
"0DME0ZZ" = "1" /* Reattachment of Large Intestine, Open Approach */
"0DMF0ZZ" = "1" /* Reattachment of Right Large Intestine, Open Approach */
"0DMG0ZZ" = "1" /* Reattachment of Left Large Intestine, Open Approach */
"0DMH0ZZ" = "1" /* Reattachment of Cecum, Open Approach */
"0DMK0ZZ" = "1" /* Reattachment of Ascending Colon, Open Approach */
"0DML0ZZ" = "1" /* Reattachment of Transverse Colon, Open Approach */
"0DMM0ZZ" = "1" /* Reattachment of Descending Colon, Open Approach */
"0DMN0ZZ" = "1" /* Reattachment of Sigmoid Colon, Open Approach */
"0DMP0ZZ" = "1" /* Reattachment of Rectum, Open Approach */
"0DN40ZZ" = "1" /* Release Esophagogastric Junction, Open Approach */
"0DN60ZZ" = "1" /* Release Stomach, Open Approach */
"0DN70ZZ" = "1" /* Release Stomach, Pylorus, Open Approach */
"0DN80ZZ" = "1" /* Release Small Intestine, Open Approach */
"0DN90ZZ" = "1" /* Release Duodenum, Open Approach */
"0DNA0ZZ" = "1" /* Release Jejunum, Open Approach */
"0DNB0ZZ" = "1" /* Release Ileum, Open Approach */
"0DNC0ZZ" = "1" /* Release Ileocecal Valve, Open Approach */
"0DNE0ZZ" = "1" /* Release Large Intestine, Open Approach */
"0DNF0ZZ" = "1" /* Release Right Large Intestine, Open Approach */
"0DNG0ZZ" = "1" /* Release Left Large Intestine, Open Approach */
"0DNH0ZZ" = "1" /* Release Cecum, Open Approach */
"0DNJ0ZZ" = "1" /* Release Appendix, Open Approach */
"0DNK0ZZ" = "1" /* Release Ascending Colon, Open Approach */
"0DNL0ZZ" = "1" /* Release Transverse Colon, Open Approach */
"0DNM0ZZ" = "1" /* Release Descending Colon, Open Approach */
"0DNN0ZZ" = "1" /* Release Sigmoid Colon, Open Approach */
"0DNP0ZZ" = "1" /* Release Rectum, Open Approach */
"0DNS0ZZ" = "1" /* Release Greater Omentum, Open Approach */
"0DNT0ZZ" = "1" /* Release Lesser Omentum, Open Approach */
"0DNV0ZZ" = "1" /* Release Mesentery, Open Approach */
"0DNW0ZZ" = "1" /* Release Peritoneum, Open Approach */
"0DP000Z" = "1" /* Removal of Drainage Device from Upper Intestinal Tract, Open Approach */
"0DP002Z" = "1" /* Removal of Monitoring Device from Upper Intestinal Tract, Open Approach */
"0DP003Z" = "1" /* Removal of Infusion Device from Upper Intestinal Tract, Open Approach */
"0DP007Z" = "1" /* Removal of Autologous Tissue Substitute from Upper Intestinal Tract, Open Approach */
"0DP00CZ" = "1" /* Removal of Extraluminal Device from Upper Intestinal Tract, Open Approach */
"0DP00DZ" = "1" /* Removal of Intraluminal Device from Upper Intestinal Tract, Open Approach */
"0DP00JZ" = "1" /* Removal of Synthetic Substitute from Upper Intestinal Tract, Open Approach */
"0DP00KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Upper Intestinal Tract, Open Approach */
"0DP00UZ" = "1" /* Removal of Feeding Device from Upper Intestinal Tract, Open Approach */
"0DP600Z" = "1" /* Removal of Drainage Device from Stomach, Open Approach */
"0DP602Z" = "1" /* Removal of Monitoring Device from Stomach, Open Approach */
"0DP603Z" = "1" /* Removal of Infusion Device from Stomach, Open Approach */
"0DP607Z" = "1" /* Removal of Autologous Tissue Substitute from Stomach, Open Approach */
"0DP60CZ" = "1" /* Removal of Extraluminal Device from Stomach, Open Approach */
"0DP60DZ" = "1" /* Removal of Intraluminal Device from Stomach, Open Approach */
"0DP60JZ" = "1" /* Removal of Synthetic Substitute from Stomach, Open Approach */
"0DP60KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Stomach, Open Approach */
"0DP60MZ" = "1" /* Removal of Stimulator Lead from Stomach, Open Approach */
"0DP60UZ" = "1" /* Removal of Feeding Device from Stomach, Open Approach */
"0DPD00Z" = "1" /* Removal of Drainage Device from Lower Intestinal Tract, Open Approach */
"0DPD02Z" = "1" /* Removal of Monitoring Device from Lower Intestinal Tract, Open Approach */
"0DPD03Z" = "1" /* Removal of Infusion Device from Lower Intestinal Tract, Open Approach */
"0DPD07Z" = "1" /* Removal of Autologous Tissue Substitute from Lower Intestinal Tract, Open Approach */
"0DPD0CZ" = "1" /* Removal of Extraluminal Device from Lower Intestinal Tract, Open Approach */
"0DPD0DZ" = "1" /* Removal of Intraluminal Device from Lower Intestinal Tract, Open Approach */
"0DPD0JZ" = "1" /* Removal of Synthetic Substitute from Lower Intestinal Tract, Open Approach */
"0DPD0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lower Intestinal Tract, Open Approach */
"0DPD0UZ" = "1" /* Removal of Feeding Device from Lower Intestinal Tract, Open Approach */
"0DPP01Z" = "1" /* Removal of Radioactive Element from Rectum, Open Approach */
"0DPU00Z" = "1" /* Removal of Drainage Device from Omentum, Open Approach */
"0DPU01Z" = "1" /* Removal of Radioactive Element from Omentum, Open Approach */
"0DPU07Z" = "1" /* Removal of Autologous Tissue Substitute from Omentum, Open Approach */
"0DPU0JZ" = "1" /* Removal of Synthetic Substitute from Omentum, Open Approach */
"0DPU0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Omentum, Open Approach */
"0DPV00Z" = "1" /* Removal of Drainage Device from Mesentery, Open Approach */
"0DPV01Z" = "1" /* Removal of Radioactive Element from Mesentery, Open Approach */
"0DPV07Z" = "1" /* Removal of Autologous Tissue Substitute from Mesentery, Open Approach */
"0DPV0JZ" = "1" /* Removal of Synthetic Substitute from Mesentery, Open Approach */
"0DPV0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Mesentery, Open Approach */
"0DPW00Z" = "1" /* Removal of Drainage Device from Peritoneum, Open Approach */
"0DPW01Z" = "1" /* Removal of Radioactive Element from Peritoneum, Open Approach */
"0DPW07Z" = "1" /* Removal of Autologous Tissue Substitute from Peritoneum, Open Approach */
"0DPW0JZ" = "1" /* Removal of Synthetic Substitute from Peritoneum, Open Approach */
"0DPW0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Peritoneum, Open Approach */
"0DQ40ZZ" = "1" /* Repair Esophagogastric Junction, Open Approach */
"0DQ60ZZ" = "1" /* Repair Stomach, Open Approach */
"0DQ70ZZ" = "1" /* Repair Stomach, Pylorus, Open Approach */
"0DQ80ZZ" = "1" /* Repair Small Intestine, Open Approach */
"0DQ90ZZ" = "1" /* Repair Duodenum, Open Approach */
"0DQA0ZZ" = "1" /* Repair Jejunum, Open Approach */
"0DQB0ZZ" = "1" /* Repair Ileum, Open Approach */
"0DQC0ZZ" = "1" /* Repair Ileocecal Valve, Open Approach */
"0DQE0ZZ" = "1" /* Repair Large Intestine, Open Approach */
"0DQF0ZZ" = "1" /* Repair Right Large Intestine, Open Approach */
"0DQG0ZZ" = "1" /* Repair Left Large Intestine, Open Approach */
"0DQH0ZZ" = "1" /* Repair Cecum, Open Approach */
"0DQJ0ZZ" = "1" /* Repair Appendix, Open Approach */
"0DQK0ZZ" = "1" /* Repair Ascending Colon, Open Approach */
"0DQL0ZZ" = "1" /* Repair Transverse Colon, Open Approach */
"0DQM0ZZ" = "1" /* Repair Descending Colon, Open Approach */
"0DQN0ZZ" = "1" /* Repair Sigmoid Colon, Open Approach */
"0DQP0ZZ" = "1" /* Repair Rectum, Open Approach */
"0DQS0ZZ" = "1" /* Repair Greater Omentum, Open Approach */
"0DQT0ZZ" = "1" /* Repair Lesser Omentum, Open Approach */
"0DQV0ZZ" = "1" /* Repair Mesentery, Open Approach */
"0DQW0ZZ" = "1" /* Repair Peritoneum, Open Approach */
"0DRS07Z" = "1" /* Replacement of Greater Omentum with Autologous Tissue Substitute, Open Approach */
"0DRS0JZ" = "1" /* Replacement of Greater Omentum with Synthetic Substitute, Open Approach */
"0DRS0KZ" = "1" /* Replacement of Greater Omentum with Nonautologous Tissue Substitute, Open Approach */
"0DRT07Z" = "1" /* Replacement of Lesser Omentum with Autologous Tissue Substitute, Open Approach */
"0DRT0JZ" = "1" /* Replacement of Lesser Omentum with Synthetic Substitute, Open Approach */
"0DRT0KZ" = "1" /* Replacement of Lesser Omentum with Nonautologous Tissue Substitute, Open Approach */
"0DRV07Z" = "1" /* Replacement of Mesentery with Autologous Tissue Substitute, Open Approach */
"0DRV0JZ" = "1" /* Replacement of Mesentery with Synthetic Substitute, Open Approach */
"0DRV0KZ" = "1" /* Replacement of Mesentery with Nonautologous Tissue Substitute, Open Approach */
"0DRW07Z" = "1" /* Replacement of Peritoneum with Autologous Tissue Substitute, Open Approach */
"0DRW0JZ" = "1" /* Replacement of Peritoneum with Synthetic Substitute, Open Approach */
"0DRW0KZ" = "1" /* Replacement of Peritoneum with Nonautologous Tissue Substitute, Open Approach */
"0DS60ZZ" = "1" /* Reposition Stomach, Open Approach */
"0DS90ZZ" = "1" /* Reposition Duodenum, Open Approach */
"0DSA0ZZ" = "1" /* Reposition Jejunum, Open Approach */
"0DSB0ZZ" = "1" /* Reposition Ileum, Open Approach */
"0DSH0ZZ" = "1" /* Reposition Cecum, Open Approach */
"0DSK0ZZ" = "1" /* Reposition Ascending Colon, Open Approach */
"0DSL0ZZ" = "1" /* Reposition Transverse Colon, Open Approach */
"0DSM0ZZ" = "1" /* Reposition Descending Colon, Open Approach */
"0DSN0ZZ" = "1" /* Reposition Sigmoid Colon, Open Approach */
"0DSP0ZZ" = "1" /* Reposition Rectum, Open Approach */
"0DT10ZZ" = "1" /* Resection of Upper Esophagus, Open Approach */
"0DT20ZZ" = "1" /* Resection of Middle Esophagus, Open Approach */
"0DT30ZZ" = "1" /* Resection of Lower Esophagus, Open Approach */
"0DT40ZZ" = "1" /* Resection of Esophagogastric Junction, Open Approach */
"0DT50ZZ" = "1" /* Resection of Esophagus, Open Approach */
"0DT60ZZ" = "1" /* Resection of Stomach, Open Approach */
"0DT70ZZ" = "1" /* Resection of Stomach, Pylorus, Open Approach */
"0DT80ZZ" = "1" /* Resection of Small Intestine, Open Approach */
"0DT90ZZ" = "1" /* Resection of Duodenum, Open Approach */
"0DTA0ZZ" = "1" /* Resection of Jejunum, Open Approach */
"0DTB0ZZ" = "1" /* Resection of Ileum, Open Approach */
"0DTC0ZZ" = "1" /* Resection of Ileocecal Valve, Open Approach */
"0DTE0ZZ" = "1" /* Resection of Large Intestine, Open Approach */
"0DTF0ZZ" = "1" /* Resection of Right Large Intestine, Open Approach */
"0DTG0ZZ" = "1" /* Resection of Left Large Intestine, Open Approach */
"0DTH0ZZ" = "1" /* Resection of Cecum, Open Approach */
"0DTJ0ZZ" = "1" /* Resection of Appendix, Open Approach */
"0DTK0ZZ" = "1" /* Resection of Ascending Colon, Open Approach */
"0DTL0ZZ" = "1" /* Resection of Transverse Colon, Open Approach */
"0DTM0ZZ" = "1" /* Resection of Descending Colon, Open Approach */
"0DTN0ZZ" = "1" /* Resection of Sigmoid Colon, Open Approach */
"0DTP0ZZ" = "1" /* Resection of Rectum, Open Approach */
"0DTS0ZZ" = "1" /* Resection of Greater Omentum, Open Approach */
"0DTT0ZZ" = "1" /* Resection of Lesser Omentum, Open Approach */
"0DU407Z" = "1" /* Supplement Esophagogastric Junction with Autologous Tissue Substitute, Open Approach */
"0DU40JZ" = "1" /* Supplement Esophagogastric Junction with Synthetic Substitute, Open Approach */
"0DU40KZ" = "1" /* Supplement Esophagogastric Junction with Nonautologous Tissue Substitute, Open Approach */
"0DU607Z" = "1" /* Supplement Stomach with Autologous Tissue Substitute, Open Approach */
"0DU60JZ" = "1" /* Supplement Stomach with Synthetic Substitute, Open Approach */
"0DU60KZ" = "1" /* Supplement Stomach with Nonautologous Tissue Substitute, Open Approach */
"0DU707Z" = "1" /* Supplement Stomach, Pylorus with Autologous Tissue Substitute, Open Approach */
"0DU70JZ" = "1" /* Supplement Stomach, Pylorus with Synthetic Substitute, Open Approach */
"0DU70KZ" = "1" /* Supplement Stomach, Pylorus with Nonautologous Tissue Substitute, Open Approach */
"0DU807Z" = "1" /* Supplement Small Intestine with Autologous Tissue Substitute, Open Approach */
"0DU80JZ" = "1" /* Supplement Small Intestine with Synthetic Substitute, Open Approach */
"0DU80KZ" = "1" /* Supplement Small Intestine with Nonautologous Tissue Substitute, Open Approach */
"0DU907Z" = "1" /* Supplement Duodenum with Autologous Tissue Substitute, Open Approach */
"0DU90JZ" = "1" /* Supplement Duodenum with Synthetic Substitute, Open Approach */
"0DU90KZ" = "1" /* Supplement Duodenum with Nonautologous Tissue Substitute, Open Approach */
"0DUA07Z" = "1" /* Supplement Jejunum with Autologous Tissue Substitute, Open Approach */
"0DUA0JZ" = "1" /* Supplement Jejunum with Synthetic Substitute, Open Approach */
"0DUA0KZ" = "1" /* Supplement Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0DUB07Z" = "1" /* Supplement Ileum with Autologous Tissue Substitute, Open Approach */
"0DUB0JZ" = "1" /* Supplement Ileum with Synthetic Substitute, Open Approach */
"0DUB0KZ" = "1" /* Supplement Ileum with Nonautologous Tissue Substitute, Open Approach */
"0DUC07Z" = "1" /* Supplement Ileocecal Valve with Autologous Tissue Substitute, Open Approach */
"0DUC0JZ" = "1" /* Supplement Ileocecal Valve with Synthetic Substitute, Open Approach */
"0DUC0KZ" = "1" /* Supplement Ileocecal Valve with Nonautologous Tissue Substitute, Open Approach */
"0DUE07Z" = "1" /* Supplement Large Intestine with Autologous Tissue Substitute, Open Approach */
"0DUE0JZ" = "1" /* Supplement Large Intestine with Synthetic Substitute, Open Approach */
"0DUE0KZ" = "1" /* Supplement Large Intestine with Nonautologous Tissue Substitute, Open Approach */
"0DUF07Z" = "1" /* Supplement Right Large Intestine with Autologous Tissue Substitute, Open Approach */
"0DUF0JZ" = "1" /* Supplement Right Large Intestine with Synthetic Substitute, Open Approach */
"0DUF0KZ" = "1" /* Supplement Right Large Intestine with Nonautologous Tissue Substitute, Open Approach */
"0DUG07Z" = "1" /* Supplement Left Large Intestine with Autologous Tissue Substitute, Open Approach */
"0DUG0JZ" = "1" /* Supplement Left Large Intestine with Synthetic Substitute, Open Approach */
"0DUG0KZ" = "1" /* Supplement Left Large Intestine with Nonautologous Tissue Substitute, Open Approach */
"0DUH07Z" = "1" /* Supplement Cecum with Autologous Tissue Substitute, Open Approach */
"0DUH0JZ" = "1" /* Supplement Cecum with Synthetic Substitute, Open Approach */
"0DUH0KZ" = "1" /* Supplement Cecum with Nonautologous Tissue Substitute, Open Approach */
"0DUK07Z" = "1" /* Supplement Ascending Colon with Autologous Tissue Substitute, Open Approach */
"0DUK0JZ" = "1" /* Supplement Ascending Colon with Synthetic Substitute, Open Approach */
"0DUK0KZ" = "1" /* Supplement Ascending Colon with Nonautologous Tissue Substitute, Open Approach */
"0DUL07Z" = "1" /* Supplement Transverse Colon with Autologous Tissue Substitute, Open Approach */
"0DUL0JZ" = "1" /* Supplement Transverse Colon with Synthetic Substitute, Open Approach */
"0DUL0KZ" = "1" /* Supplement Transverse Colon with Nonautologous Tissue Substitute, Open Approach */
"0DUM07Z" = "1" /* Supplement Descending Colon with Autologous Tissue Substitute, Open Approach */
"0DUM0JZ" = "1" /* Supplement Descending Colon with Synthetic Substitute, Open Approach */
"0DUM0KZ" = "1" /* Supplement Descending Colon with Nonautologous Tissue Substitute, Open Approach */
"0DUN07Z" = "1" /* Supplement Sigmoid Colon with Autologous Tissue Substitute, Open Approach */
"0DUN0JZ" = "1" /* Supplement Sigmoid Colon with Synthetic Substitute, Open Approach */
"0DUN0KZ" = "1" /* Supplement Sigmoid Colon with Nonautologous Tissue Substitute, Open Approach */
"0DUP07Z" = "1" /* Supplement Rectum with Autologous Tissue Substitute, Open Approach */
"0DUP0JZ" = "1" /* Supplement Rectum with Synthetic Substitute, Open Approach */
"0DUP0KZ" = "1" /* Supplement Rectum with Nonautologous Tissue Substitute, Open Approach */
"0DUS07Z" = "1" /* Supplement Greater Omentum with Autologous Tissue Substitute, Open Approach */
"0DUS0JZ" = "1" /* Supplement Greater Omentum with Synthetic Substitute, Open Approach */
"0DUS0KZ" = "1" /* Supplement Greater Omentum with Nonautologous Tissue Substitute, Open Approach */
"0DUT07Z" = "1" /* Supplement Lesser Omentum with Autologous Tissue Substitute, Open Approach */
"0DUT0JZ" = "1" /* Supplement Lesser Omentum with Synthetic Substitute, Open Approach */
"0DUT0KZ" = "1" /* Supplement Lesser Omentum with Nonautologous Tissue Substitute, Open Approach */
"0DUV07Z" = "1" /* Supplement Mesentery with Autologous Tissue Substitute, Open Approach */
"0DUV0JZ" = "1" /* Supplement Mesentery with Synthetic Substitute, Open Approach */
"0DUV0KZ" = "1" /* Supplement Mesentery with Nonautologous Tissue Substitute, Open Approach */
"0DUW07Z" = "1" /* Supplement Peritoneum with Autologous Tissue Substitute, Open Approach */
"0DUW0JZ" = "1" /* Supplement Peritoneum with Synthetic Substitute, Open Approach */
"0DUW0KZ" = "1" /* Supplement Peritoneum with Nonautologous Tissue Substitute, Open Approach */
"0DV40CZ" = "1" /* Restriction of Esophagogastric Junction with Extraluminal Device, Open Approach */
"0DV40DZ" = "1" /* Restriction of Esophagogastric Junction with Intraluminal Device, Open Approach */
"0DV40ZZ" = "1" /* Restriction of Esophagogastric Junction, Open Approach */
"0DV60CZ" = "1" /* Restriction of Stomach with Extraluminal Device, Open Approach */
"0DV60DZ" = "1" /* Restriction of Stomach with Intraluminal Device, Open Approach */
"0DV60ZZ" = "1" /* Restriction of Stomach, Open Approach */
"0DV70CZ" = "1" /* Restriction of Stomach, Pylorus with Extraluminal Device, Open Approach */
"0DV70DZ" = "1" /* Restriction of Stomach, Pylorus with Intraluminal Device, Open Approach */
"0DV70ZZ" = "1" /* Restriction of Stomach, Pylorus, Open Approach */
"0DV80CZ" = "1" /* Restriction of Small Intestine with Extraluminal Device, Open Approach */
"0DV80DZ" = "1" /* Restriction of Small Intestine with Intraluminal Device, Open Approach */
"0DV80ZZ" = "1" /* Restriction of Small Intestine, Open Approach */
"0DV90CZ" = "1" /* Restriction of Duodenum with Extraluminal Device, Open Approach */
"0DV90DZ" = "1" /* Restriction of Duodenum with Intraluminal Device, Open Approach */
"0DV90ZZ" = "1" /* Restriction of Duodenum, Open Approach */
"0DVA0CZ" = "1" /* Restriction of Jejunum with Extraluminal Device, Open Approach */
"0DVA0DZ" = "1" /* Restriction of Jejunum with Intraluminal Device, Open Approach */
"0DVA0ZZ" = "1" /* Restriction of Jejunum, Open Approach */
"0DVB0CZ" = "1" /* Restriction of Ileum with Extraluminal Device, Open Approach */
"0DVB0DZ" = "1" /* Restriction of Ileum with Intraluminal Device, Open Approach */
"0DVB0ZZ" = "1" /* Restriction of Ileum, Open Approach */
"0DVC0CZ" = "1" /* Restriction of Ileocecal Valve with Extraluminal Device, Open Approach */
"0DVC0DZ" = "1" /* Restriction of Ileocecal Valve with Intraluminal Device, Open Approach */
"0DVC0ZZ" = "1" /* Restriction of Ileocecal Valve, Open Approach */
"0DVE0CZ" = "1" /* Restriction of Large Intestine with Extraluminal Device, Open Approach */
"0DVE0DZ" = "1" /* Restriction of Large Intestine with Intraluminal Device, Open Approach */
"0DVE0ZZ" = "1" /* Restriction of Large Intestine, Open Approach */
"0DVF0CZ" = "1" /* Restriction of Right Large Intestine with Extraluminal Device, Open Approach */
"0DVF0DZ" = "1" /* Restriction of Right Large Intestine with Intraluminal Device, Open Approach */
"0DVF0ZZ" = "1" /* Restriction of Right Large Intestine, Open Approach */
"0DVG0CZ" = "1" /* Restriction of Left Large Intestine with Extraluminal Device, Open Approach */
"0DVG0DZ" = "1" /* Restriction of Left Large Intestine with Intraluminal Device, Open Approach */
"0DVG0ZZ" = "1" /* Restriction of Left Large Intestine, Open Approach */
"0DVH0CZ" = "1" /* Restriction of Cecum with Extraluminal Device, Open Approach */
"0DVH0DZ" = "1" /* Restriction of Cecum with Intraluminal Device, Open Approach */
"0DVH0ZZ" = "1" /* Restriction of Cecum, Open Approach */
"0DVK0CZ" = "1" /* Restriction of Ascending Colon with Extraluminal Device, Open Approach */
"0DVK0DZ" = "1" /* Restriction of Ascending Colon with Intraluminal Device, Open Approach */
"0DVK0ZZ" = "1" /* Restriction of Ascending Colon, Open Approach */
"0DVL0CZ" = "1" /* Restriction of Transverse Colon with Extraluminal Device, Open Approach */
"0DVL0DZ" = "1" /* Restriction of Transverse Colon with Intraluminal Device, Open Approach */
"0DVL0ZZ" = "1" /* Restriction of Transverse Colon, Open Approach */
"0DVM0CZ" = "1" /* Restriction of Descending Colon with Extraluminal Device, Open Approach */
"0DVM0DZ" = "1" /* Restriction of Descending Colon with Intraluminal Device, Open Approach */
"0DVM0ZZ" = "1" /* Restriction of Descending Colon, Open Approach */
"0DVN0CZ" = "1" /* Restriction of Sigmoid Colon with Extraluminal Device, Open Approach */
"0DVN0DZ" = "1" /* Restriction of Sigmoid Colon with Intraluminal Device, Open Approach */
"0DVN0ZZ" = "1" /* Restriction of Sigmoid Colon, Open Approach */
"0DVP0CZ" = "1" /* Restriction of Rectum with Extraluminal Device, Open Approach */
"0DVP0DZ" = "1" /* Restriction of Rectum with Intraluminal Device, Open Approach */
"0DVP0ZZ" = "1" /* Restriction of Rectum, Open Approach */
"0DW000Z" = "1" /* Revision of Drainage Device in Upper Intestinal Tract, Open Approach */
"0DW002Z" = "1" /* Revision of Monitoring Device in Upper Intestinal Tract, Open Approach */
"0DW003Z" = "1" /* Revision of Infusion Device in Upper Intestinal Tract, Open Approach */
"0DW007Z" = "1" /* Revision of Autologous Tissue Substitute in Upper Intestinal Tract, Open Approach */
"0DW00CZ" = "1" /* Revision of Extraluminal Device in Upper Intestinal Tract, Open Approach */
"0DW00DZ" = "1" /* Revision of Intraluminal Device in Upper Intestinal Tract, Open Approach */
"0DW00JZ" = "1" /* Revision of Synthetic Substitute in Upper Intestinal Tract, Open Approach */
"0DW00KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Intestinal Tract, Open Approach */
"0DW00UZ" = "1" /* Revision of Feeding Device in Upper Intestinal Tract, Open Approach */
"0DW600Z" = "1" /* Revision of Drainage Device in Stomach, Open Approach */
"0DW602Z" = "1" /* Revision of Monitoring Device in Stomach, Open Approach */
"0DW603Z" = "1" /* Revision of Infusion Device in Stomach, Open Approach */
"0DW607Z" = "1" /* Revision of Autologous Tissue Substitute in Stomach, Open Approach */
"0DW60CZ" = "1" /* Revision of Extraluminal Device in Stomach, Open Approach */
"0DW60DZ" = "1" /* Revision of Intraluminal Device in Stomach, Open Approach */
"0DW60JZ" = "1" /* Revision of Synthetic Substitute in Stomach, Open Approach */
"0DW60KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Stomach, Open Approach */
"0DW60MZ" = "1" /* Revision of Stimulator Lead in Stomach, Open Approach */
"0DW60UZ" = "1" /* Revision of Feeding Device in Stomach, Open Approach */
"0DW807Z" = "1" /* Revision of Autologous Tissue Substitute in Small Intestine, Open Approach */
"0DW80JZ" = "1" /* Revision of Synthetic Substitute in Small Intestine, Open Approach */
"0DW80KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Small Intestine, Open Approach */
"0DWD00Z" = "1" /* Revision of Drainage Device in Lower Intestinal Tract, Open Approach */
"0DWD02Z" = "1" /* Revision of Monitoring Device in Lower Intestinal Tract, Open Approach */
"0DWD03Z" = "1" /* Revision of Infusion Device in Lower Intestinal Tract, Open Approach */
"0DWD07Z" = "1" /* Revision of Autologous Tissue Substitute in Lower Intestinal Tract, Open Approach */
"0DWD0CZ" = "1" /* Revision of Extraluminal Device in Lower Intestinal Tract, Open Approach */
"0DWD0DZ" = "1" /* Revision of Intraluminal Device in Lower Intestinal Tract, Open Approach */
"0DWD0JZ" = "1" /* Revision of Synthetic Substitute in Lower Intestinal Tract, Open Approach */
"0DWD0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Intestinal Tract, Open Approach */
"0DWD0UZ" = "1" /* Revision of Feeding Device in Lower Intestinal Tract, Open Approach */
"0DWE07Z" = "1" /* Revision of Autologous Tissue Substitute in Large Intestine, Open Approach */
"0DWE0JZ" = "1" /* Revision of Synthetic Substitute in Large Intestine, Open Approach */
"0DWE0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Large Intestine, Open Approach */
"0DWU00Z" = "1" /* Revision of Drainage Device in Omentum, Open Approach */
"0DWU07Z" = "1" /* Revision of Autologous Tissue Substitute in Omentum, Open Approach */
"0DWU0JZ" = "1" /* Revision of Synthetic Substitute in Omentum, Open Approach */
"0DWU0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Omentum, Open Approach */
"0DWV00Z" = "1" /* Revision of Drainage Device in Mesentery, Open Approach */
"0DWV07Z" = "1" /* Revision of Autologous Tissue Substitute in Mesentery, Open Approach */
"0DWV0JZ" = "1" /* Revision of Synthetic Substitute in Mesentery, Open Approach */
"0DWV0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mesentery, Open Approach */
"0DWW00Z" = "1" /* Revision of Drainage Device in Peritoneum, Open Approach */
"0DWW07Z" = "1" /* Revision of Autologous Tissue Substitute in Peritoneum, Open Approach */
"0DWW0JZ" = "1" /* Revision of Synthetic Substitute in Peritoneum, Open Approach */
"0DWW0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Peritoneum, Open Approach */
"0DX60Z5" = "1" /* Transfer Stomach to Esophagus, Open Approach */
"0DX80Z5" = "1" /* Transfer Small Intestine to Esophagus, Open Approach */
"0DXE0Z5" = "1" /* Transfer Large Intestine to Esophagus, Open Approach */
"0DY60Z0" = "1" /* Transplantation of Stomach, Allogeneic, Open Approach */
"0DY60Z1" = "1" /* Transplantation of Stomach, Syngeneic, Open Approach */
"0DY60Z2" = "1" /* Transplantation of Stomach, Zooplastic, Open Approach */
"0DY80Z0" = "1" /* Transplantation of Small Intestine, Allogeneic, Open Approach */
"0DY80Z1" = "1" /* Transplantation of Small Intestine, Syngeneic, Open Approach */
"0DY80Z2" = "1" /* Transplantation of Small Intestine, Zooplastic, Open Approach */
"0DYE0Z0" = "1" /* Transplantation of Large Intestine, Allogeneic, Open Approach */
"0DYE0Z1" = "1" /* Transplantation of Large Intestine, Syngeneic, Open Approach */
"0DYE0Z2" = "1" /* Transplantation of Large Intestine, Zooplastic, Open Approach */
"0F140D3" = "1" /* Bypass Gallbladder to Duodenum with Intraluminal Device, Open Approach */
"0F140D4" = "1" /* Bypass Gallbladder to Stomach with Intraluminal Device, Open Approach */
"0F140D5" = "1" /* Bypass Gallbladder to Right Hepatic Duct with Intraluminal Device, Open Approach */
"0F140D6" = "1" /* Bypass Gallbladder to Left Hepatic Duct with Intraluminal Device, Open Approach */
"0F140D7" = "1" /* Bypass Gallbladder to Caudate Hepatic Duct with Intraluminal Device, Open Approach */
"0F140D8" = "1" /* Bypass Gallbladder to Cystic Duct with Intraluminal Device, Open Approach */
"0F140D9" = "1" /* Bypass Gallbladder to Common Bile Duct with Intraluminal Device, Open Approach */
"0F140DB" = "1" /* Bypass Gallbladder to Small Intestine with Intraluminal Device, Open Approach */
"0F140Z3" = "1" /* Bypass Gallbladder to Duodenum, Open Approach */
"0F140Z4" = "1" /* Bypass Gallbladder to Stomach, Open Approach */
"0F140Z5" = "1" /* Bypass Gallbladder to Right Hepatic Duct, Open Approach */
"0F140Z6" = "1" /* Bypass Gallbladder to Left Hepatic Duct, Open Approach */
"0F140Z7" = "1" /* Bypass Gallbladder to Caudate Hepatic Duct, Open Approach */
"0F140Z8" = "1" /* Bypass Gallbladder to Cystic Duct, Open Approach */
"0F140Z9" = "1" /* Bypass Gallbladder to Common Bile Duct, Open Approach */
"0F140ZB" = "1" /* Bypass Gallbladder to Small Intestine, Open Approach */
"0F150D3" = "1" /* Bypass Right Hepatic Duct to Duodenum with Intraluminal Device, Open Approach */
"0F150D4" = "1" /* Bypass Right Hepatic Duct to Stomach with Intraluminal Device, Open Approach */
"0F150D5" = "1" /* Bypass Right Hepatic Duct to Right Hepatic Duct with Intraluminal Device, Open Approach */
"0F150D6" = "1" /* Bypass Right Hepatic Duct to Left Hepatic Duct with Intraluminal Device, Open Approach */
"0F150D7" = "1" /* Bypass Right Hepatic Duct to Caudate Hepatic Duct with Intraluminal Device, Open Approach */
"0F150D8" = "1" /* Bypass Right Hepatic Duct to Cystic Duct with Intraluminal Device, Open Approach */
"0F150D9" = "1" /* Bypass Right Hepatic Duct to Common Bile Duct with Intraluminal Device, Open Approach */
"0F150DB" = "1" /* Bypass Right Hepatic Duct to Small Intestine with Intraluminal Device, Open Approach */
"0F150Z3" = "1" /* Bypass Right Hepatic Duct to Duodenum, Open Approach */
"0F150Z4" = "1" /* Bypass Right Hepatic Duct to Stomach, Open Approach */
"0F150Z5" = "1" /* Bypass Right Hepatic Duct to Right Hepatic Duct, Open Approach */
"0F150Z6" = "1" /* Bypass Right Hepatic Duct to Left Hepatic Duct, Open Approach */
"0F150Z7" = "1" /* Bypass Right Hepatic Duct to Caudate Hepatic Duct, Open Approach */
"0F150Z8" = "1" /* Bypass Right Hepatic Duct to Cystic Duct, Open Approach */
"0F150Z9" = "1" /* Bypass Right Hepatic Duct to Common Bile Duct, Open Approach */
"0F150ZB" = "1" /* Bypass Right Hepatic Duct to Small Intestine, Open Approach */
"0F160D3" = "1" /* Bypass Left Hepatic Duct to Duodenum with Intraluminal Device, Open Approach */
"0F160D4" = "1" /* Bypass Left Hepatic Duct to Stomach with Intraluminal Device, Open Approach */
"0F160D5" = "1" /* Bypass Left Hepatic Duct to Right Hepatic Duct with Intraluminal Device, Open Approach */
"0F160D6" = "1" /* Bypass Left Hepatic Duct to Left Hepatic Duct with Intraluminal Device, Open Approach */
"0F160D7" = "1" /* Bypass Left Hepatic Duct to Caudate Hepatic Duct with Intraluminal Device, Open Approach */
"0F160D8" = "1" /* Bypass Left Hepatic Duct to Cystic Duct with Intraluminal Device, Open Approach */
"0F160D9" = "1" /* Bypass Left Hepatic Duct to Common Bile Duct with Intraluminal Device, Open Approach */
"0F160DB" = "1" /* Bypass Left Hepatic Duct to Small Intestine with Intraluminal Device, Open Approach */
"0F160Z3" = "1" /* Bypass Left Hepatic Duct to Duodenum, Open Approach */
"0F160Z4" = "1" /* Bypass Left Hepatic Duct to Stomach, Open Approach */
"0F160Z5" = "1" /* Bypass Left Hepatic Duct to Right Hepatic Duct, Open Approach */
"0F160Z6" = "1" /* Bypass Left Hepatic Duct to Left Hepatic Duct, Open Approach */
"0F160Z7" = "1" /* Bypass Left Hepatic Duct to Caudate Hepatic Duct, Open Approach */
"0F160Z8" = "1" /* Bypass Left Hepatic Duct to Cystic Duct, Open Approach */
"0F160Z9" = "1" /* Bypass Left Hepatic Duct to Common Bile Duct, Open Approach */
"0F160ZB" = "1" /* Bypass Left Hepatic Duct to Small Intestine, Open Approach */
"0F180D3" = "1" /* Bypass Cystic Duct to Duodenum with Intraluminal Device, Open Approach */
"0F180D4" = "1" /* Bypass Cystic Duct to Stomach with Intraluminal Device, Open Approach */
"0F180D5" = "1" /* Bypass Cystic Duct to Right Hepatic Duct with Intraluminal Device, Open Approach */
"0F180D6" = "1" /* Bypass Cystic Duct to Left Hepatic Duct with Intraluminal Device, Open Approach */
"0F180D7" = "1" /* Bypass Cystic Duct to Caudate Hepatic Duct with Intraluminal Device, Open Approach */
"0F180D8" = "1" /* Bypass Cystic Duct to Cystic Duct with Intraluminal Device, Open Approach */
"0F180D9" = "1" /* Bypass Cystic Duct to Common Bile Duct with Intraluminal Device, Open Approach */
"0F180DB" = "1" /* Bypass Cystic Duct to Small Intestine with Intraluminal Device, Open Approach */
"0F180Z3" = "1" /* Bypass Cystic Duct to Duodenum, Open Approach */
"0F180Z4" = "1" /* Bypass Cystic Duct to Stomach, Open Approach */
"0F180Z5" = "1" /* Bypass Cystic Duct to Right Hepatic Duct, Open Approach */
"0F180Z6" = "1" /* Bypass Cystic Duct to Left Hepatic Duct, Open Approach */
"0F180Z7" = "1" /* Bypass Cystic Duct to Caudate Hepatic Duct, Open Approach */
"0F180Z8" = "1" /* Bypass Cystic Duct to Cystic Duct, Open Approach */
"0F180Z9" = "1" /* Bypass Cystic Duct to Common Bile Duct, Open Approach */
"0F180ZB" = "1" /* Bypass Cystic Duct to Small Intestine, Open Approach */
"0F190D3" = "1" /* Bypass Common Bile Duct to Duodenum with Intraluminal Device, Open Approach */
"0F190D4" = "1" /* Bypass Common Bile Duct to Stomach with Intraluminal Device, Open Approach */
"0F190D5" = "1" /* Bypass Common Bile Duct to Right Hepatic Duct with Intraluminal Device, Open Approach */
"0F190D6" = "1" /* Bypass Common Bile Duct to Left Hepatic Duct with Intraluminal Device, Open Approach */
"0F190D7" = "1" /* Bypass Common Bile Duct to Caudate Hepatic Duct with Intraluminal Device, Open Approach */
"0F190D8" = "1" /* Bypass Common Bile Duct to Cystic Duct with Intraluminal Device, Open Approach */
"0F190D9" = "1" /* Bypass Common Bile Duct to Common Bile Duct with Intraluminal Device, Open Approach */
"0F190DB" = "1" /* Bypass Common Bile Duct to Small Intestine with Intraluminal Device, Open Approach */
"0F190Z3" = "1" /* Bypass Common Bile Duct to Duodenum, Open Approach */
"0F190Z4" = "1" /* Bypass Common Bile Duct to Stomach, Open Approach */
"0F190Z5" = "1" /* Bypass Common Bile Duct to Right Hepatic Duct, Open Approach */
"0F190Z6" = "1" /* Bypass Common Bile Duct to Left Hepatic Duct, Open Approach */
"0F190Z7" = "1" /* Bypass Common Bile Duct to Caudate Hepatic Duct, Open Approach */
"0F190Z8" = "1" /* Bypass Common Bile Duct to Cystic Duct, Open Approach */
"0F190Z9" = "1" /* Bypass Common Bile Duct to Common Bile Duct, Open Approach */
"0F190ZB" = "1" /* Bypass Common Bile Duct to Small Intestine, Open Approach */
"0F1D0D3" = "1" /* Bypass Pancreatic Duct to Duodenum with Intraluminal Device, Open Approach */
"0F1D0DB" = "1" /* Bypass Pancreatic Duct to Small Intestine with Intraluminal Device, Open Approach */
"0F1D0DC" = "1" /* Bypass Pancreatic Duct to Large Intestine with Intraluminal Device, Open Approach */
"0F1D0Z3" = "1" /* Bypass Pancreatic Duct to Duodenum, Open Approach */
"0F1D0ZB" = "1" /* Bypass Pancreatic Duct to Small Intestine, Open Approach */
"0F1D0ZC" = "1" /* Bypass Pancreatic Duct to Large Intestine, Open Approach */
"0F1F0D3" = "1" /* Bypass Accessory Pancreatic Duct to Duodenum with Intraluminal Device, Open Approach */
"0F1F0DB" = "1" /* Bypass Accessory Pancreatic Duct to Small Intestine with Intraluminal Device, Open Approach */
"0F1F0DC" = "1" /* Bypass Accessory Pancreatic Duct to Large Intestine with Intraluminal Device, Open Approach */
"0F1F0Z3" = "1" /* Bypass Accessory Pancreatic Duct to Duodenum, Open Approach */
"0F1F0ZB" = "1" /* Bypass Accessory Pancreatic Duct to Small Intestine, Open Approach */
"0F1F0ZC" = "1" /* Bypass Accessory Pancreatic Duct to Large Intestine, Open Approach */
"0F1G0D3" = "1" /* Bypass Pancreas to Duodenum with Intraluminal Device, Open Approach */
"0F1G0DB" = "1" /* Bypass Pancreas to Small Intestine with Intraluminal Device, Open Approach */
"0F1G0DC" = "1" /* Bypass Pancreas to Large Intestine with Intraluminal Device, Open Approach */
"0F1G0Z3" = "1" /* Bypass Pancreas to Duodenum, Open Approach */
"0F1G0ZB" = "1" /* Bypass Pancreas to Small Intestine, Open Approach */
"0F1G0ZC" = "1" /* Bypass Pancreas to Large Intestine, Open Approach */
"0F500ZZ" = "1" /* Destruction of Liver, Open Approach */
"0F510ZZ" = "1" /* Destruction of Right Lobe Liver, Open Approach */
"0F520ZZ" = "1" /* Destruction of Left Lobe Liver, Open Approach */
"0F540ZZ" = "1" /* Destruction of Gallbladder, Open Approach */
"0F550ZZ" = "1" /* Destruction of Right Hepatic Duct, Open Approach */
"0F560ZZ" = "1" /* Destruction of Left Hepatic Duct, Open Approach */
"0F580ZZ" = "1" /* Destruction of Cystic Duct, Open Approach */
"0F590ZZ" = "1" /* Destruction of Common Bile Duct, Open Approach */
"0F5C0ZZ" = "1" /* Destruction of Ampulla of Vater, Open Approach */
"0F5D0ZZ" = "1" /* Destruction of Pancreatic Duct, Open Approach */
"0F5F0ZZ" = "1" /* Destruction of Accessory Pancreatic Duct, Open Approach */
"0F5G0ZZ" = "1" /* Destruction of Pancreas, Open Approach */
"0F750DZ" = "1" /* Dilation of Right Hepatic Duct with Intraluminal Device, Open Approach */
"0F750ZZ" = "1" /* Dilation of Right Hepatic Duct, Open Approach */
"0F760DZ" = "1" /* Dilation of Left Hepatic Duct with Intraluminal Device, Open Approach */
"0F760ZZ" = "1" /* Dilation of Left Hepatic Duct, Open Approach */
"0F780DZ" = "1" /* Dilation of Cystic Duct with Intraluminal Device, Open Approach */
"0F780ZZ" = "1" /* Dilation of Cystic Duct, Open Approach */
"0F790DZ" = "1" /* Dilation of Common Bile Duct with Intraluminal Device, Open Approach */
"0F790ZZ" = "1" /* Dilation of Common Bile Duct, Open Approach */
"0F7C0DZ" = "1" /* Dilation of Ampulla of Vater with Intraluminal Device, Open Approach */
"0F7C0ZZ" = "1" /* Dilation of Ampulla of Vater, Open Approach */
"0F7D0DZ" = "1" /* Dilation of Pancreatic Duct with Intraluminal Device, Open Approach */
"0F7D0ZZ" = "1" /* Dilation of Pancreatic Duct, Open Approach */
"0F7F0DZ" = "1" /* Dilation of Accessory Pancreatic Duct with Intraluminal Device, Open Approach */
"0F7F0ZZ" = "1" /* Dilation of Accessory Pancreatic Duct, Open Approach */
"0F8G0ZZ" = "1" /* Division of Pancreas, Open Approach */
"0F9000Z" = "1" /* Drainage of Liver with Drainage Device, Open Approach */
"0F900ZX" = "1" /* Drainage of Liver, Open Approach, Diagnostic */
"0F900ZZ" = "1" /* Drainage of Liver, Open Approach */
"0F9100Z" = "1" /* Drainage of Right Lobe Liver with Drainage Device, Open Approach */
"0F910ZX" = "1" /* Drainage of Right Lobe Liver, Open Approach, Diagnostic */
"0F910ZZ" = "1" /* Drainage of Right Lobe Liver, Open Approach */
"0F9200Z" = "1" /* Drainage of Left Lobe Liver with Drainage Device, Open Approach */
"0F920ZX" = "1" /* Drainage of Left Lobe Liver, Open Approach, Diagnostic */
"0F920ZZ" = "1" /* Drainage of Left Lobe Liver, Open Approach */
"0F9400Z" = "1" /* Drainage of Gallbladder with Drainage Device, Open Approach */
"0F940ZX" = "1" /* Drainage of Gallbladder, Open Approach, Diagnostic */
"0F940ZZ" = "1" /* Drainage of Gallbladder, Open Approach */
"0F9500Z" = "1" /* Drainage of Right Hepatic Duct with Drainage Device, Open Approach */
"0F950ZX" = "1" /* Drainage of Right Hepatic Duct, Open Approach, Diagnostic */
"0F950ZZ" = "1" /* Drainage of Right Hepatic Duct, Open Approach */
"0F9600Z" = "1" /* Drainage of Left Hepatic Duct with Drainage Device, Open Approach */
"0F960ZX" = "1" /* Drainage of Left Hepatic Duct, Open Approach, Diagnostic */
"0F960ZZ" = "1" /* Drainage of Left Hepatic Duct, Open Approach */
"0F9800Z" = "1" /* Drainage of Cystic Duct with Drainage Device, Open Approach */
"0F980ZX" = "1" /* Drainage of Cystic Duct, Open Approach, Diagnostic */
"0F980ZZ" = "1" /* Drainage of Cystic Duct, Open Approach */
"0F9900Z" = "1" /* Drainage of Common Bile Duct with Drainage Device, Open Approach */
"0F990ZX" = "1" /* Drainage of Common Bile Duct, Open Approach, Diagnostic */
"0F990ZZ" = "1" /* Drainage of Common Bile Duct, Open Approach */
"0F9C00Z" = "1" /* Drainage of Ampulla of Vater with Drainage Device, Open Approach */
"0F9C0ZX" = "1" /* Drainage of Ampulla of Vater, Open Approach, Diagnostic */
"0F9C0ZZ" = "1" /* Drainage of Ampulla of Vater, Open Approach */
"0F9D00Z" = "1" /* Drainage of Pancreatic Duct with Drainage Device, Open Approach */
"0F9D0ZX" = "1" /* Drainage of Pancreatic Duct, Open Approach, Diagnostic */
"0F9D0ZZ" = "1" /* Drainage of Pancreatic Duct, Open Approach */
"0F9F00Z" = "1" /* Drainage of Accessory Pancreatic Duct with Drainage Device, Open Approach */
"0F9F0ZX" = "1" /* Drainage of Accessory Pancreatic Duct, Open Approach, Diagnostic */
"0F9F0ZZ" = "1" /* Drainage of Accessory Pancreatic Duct, Open Approach */
"0F9G00Z" = "1" /* Drainage of Pancreas with Drainage Device, Open Approach */
"0F9G0ZX" = "1" /* Drainage of Pancreas, Open Approach, Diagnostic */
"0F9G0ZZ" = "1" /* Drainage of Pancreas, Open Approach */
"0FB00ZX" = "1" /* Excision of Liver, Open Approach, Diagnostic */
"0FB00ZZ" = "1" /* Excision of Liver, Open Approach */
"0FB10ZX" = "1" /* Excision of Right Lobe Liver, Open Approach, Diagnostic */
"0FB10ZZ" = "1" /* Excision of Right Lobe Liver, Open Approach */
"0FB20ZX" = "1" /* Excision of Left Lobe Liver, Open Approach, Diagnostic */
"0FB20ZZ" = "1" /* Excision of Left Lobe Liver, Open Approach */
"0FB40ZX" = "1" /* Excision of Gallbladder, Open Approach, Diagnostic */
"0FB40ZZ" = "1" /* Excision of Gallbladder, Open Approach */
"0FB50ZX" = "1" /* Excision of Right Hepatic Duct, Open Approach, Diagnostic */
"0FB50ZZ" = "1" /* Excision of Right Hepatic Duct, Open Approach */
"0FB60ZX" = "1" /* Excision of Left Hepatic Duct, Open Approach, Diagnostic */
"0FB60ZZ" = "1" /* Excision of Left Hepatic Duct, Open Approach */
"0FB80ZX" = "1" /* Excision of Cystic Duct, Open Approach, Diagnostic */
"0FB80ZZ" = "1" /* Excision of Cystic Duct, Open Approach */
"0FB90ZX" = "1" /* Excision of Common Bile Duct, Open Approach, Diagnostic */
"0FB90ZZ" = "1" /* Excision of Common Bile Duct, Open Approach */
"0FBC0ZX" = "1" /* Excision of Ampulla of Vater, Open Approach, Diagnostic */
"0FBC0ZZ" = "1" /* Excision of Ampulla of Vater, Open Approach */
"0FBD0ZX" = "1" /* Excision of Pancreatic Duct, Open Approach, Diagnostic */
"0FBD0ZZ" = "1" /* Excision of Pancreatic Duct, Open Approach */
"0FBF0ZX" = "1" /* Excision of Accessory Pancreatic Duct, Open Approach, Diagnostic */
"0FBF0ZZ" = "1" /* Excision of Accessory Pancreatic Duct, Open Approach */
"0FBG0ZX" = "1" /* Excision of Pancreas, Open Approach, Diagnostic */
"0FBG0ZZ" = "1" /* Excision of Pancreas, Open Approach */
"0FC00ZZ" = "1" /* Extirpation of Matter from Liver, Open Approach */
"0FC10ZZ" = "1" /* Extirpation of Matter from Right Lobe Liver, Open Approach */
"0FC20ZZ" = "1" /* Extirpation of Matter from Left Lobe Liver, Open Approach */
"0FC40ZZ" = "1" /* Extirpation of Matter from Gallbladder, Open Approach */
"0FC50ZZ" = "1" /* Extirpation of Matter from Right Hepatic Duct, Open Approach */
"0FC60ZZ" = "1" /* Extirpation of Matter from Left Hepatic Duct, Open Approach */
"0FC80ZZ" = "1" /* Extirpation of Matter from Cystic Duct, Open Approach */
"0FC90ZZ" = "1" /* Extirpation of Matter from Common Bile Duct, Open Approach */
"0FCC0ZZ" = "1" /* Extirpation of Matter from Ampulla of Vater, Open Approach */
"0FCD0ZZ" = "1" /* Extirpation of Matter from Pancreatic Duct, Open Approach */
"0FCF0ZZ" = "1" /* Extirpation of Matter from Accessory Pancreatic Duct, Open Approach */
"0FCG0ZZ" = "1" /* Extirpation of Matter from Pancreas, Open Approach */
"0FF40ZZ" = "1" /* Fragmentation in Gallbladder, Open Approach */
"0FF50ZZ" = "1" /* Fragmentation in Right Hepatic Duct, Open Approach */
"0FF60ZZ" = "1" /* Fragmentation in Left Hepatic Duct, Open Approach */
"0FF80ZZ" = "1" /* Fragmentation in Cystic Duct, Open Approach */
"0FF90ZZ" = "1" /* Fragmentation in Common Bile Duct, Open Approach */
"0FFC0ZZ" = "1" /* Fragmentation in Ampulla of Vater, Open Approach */
"0FFD0ZZ" = "1" /* Fragmentation in Pancreatic Duct, Open Approach */
"0FFF0ZZ" = "1" /* Fragmentation in Accessory Pancreatic Duct, Open Approach */
"0FH002Z" = "1" /* Insertion of Monitoring Device into Liver, Open Approach */
"0FH003Z" = "1" /* Insertion of Infusion Device into Liver, Open Approach */
"0FH102Z" = "1" /* Insertion of Monitoring Device into Right Lobe Liver, Open Approach */
"0FH103Z" = "1" /* Insertion of Infusion Device into Right Lobe Liver, Open Approach */
"0FH202Z" = "1" /* Insertion of Monitoring Device into Left Lobe Liver, Open Approach */
"0FH203Z" = "1" /* Insertion of Infusion Device into Left Lobe Liver, Open Approach */
"0FH402Z" = "1" /* Insertion of Monitoring Device into Gallbladder, Open Approach */
"0FH403Z" = "1" /* Insertion of Infusion Device into Gallbladder, Open Approach */
"0FHB01Z" = "1" /* Insertion of Radioactive Element into Hepatobiliary Duct, Open Approach */
"0FHB02Z" = "1" /* Insertion of Monitoring Device into Hepatobiliary Duct, Open Approach */
"0FHB03Z" = "1" /* Insertion of Infusion Device into Hepatobiliary Duct, Open Approach */
"0FHB0DZ" = "1" /* Insertion of Intraluminal Device into Hepatobiliary Duct, Open Approach */
"0FHD01Z" = "1" /* Insertion of Radioactive Element into Pancreatic Duct, Open Approach */
"0FHD02Z" = "1" /* Insertion of Monitoring Device into Pancreatic Duct, Open Approach */
"0FHD03Z" = "1" /* Insertion of Infusion Device into Pancreatic Duct, Open Approach */
"0FHD0DZ" = "1" /* Insertion of Intraluminal Device into Pancreatic Duct, Open Approach */
"0FHG02Z" = "1" /* Insertion of Monitoring Device into Pancreas, Open Approach */
"0FHG03Z" = "1" /* Insertion of Infusion Device into Pancreas, Open Approach */
"0FJ00ZZ" = "1" /* Inspection of Liver, Open Approach */
"0FJ40ZZ" = "1" /* Inspection of Gallbladder, Open Approach */
"0FJB0ZZ" = "1" /* Inspection of Hepatobiliary Duct, Open Approach */
"0FJD0ZZ" = "1" /* Inspection of Pancreatic Duct, Open Approach */
"0FJG0ZZ" = "1" /* Inspection of Pancreas, Open Approach */
"0FL50CZ" = "1" /* Occlusion of Right Hepatic Duct with Extraluminal Device, Open Approach */
"0FL50DZ" = "1" /* Occlusion of Right Hepatic Duct with Intraluminal Device, Open Approach */
"0FL50ZZ" = "1" /* Occlusion of Right Hepatic Duct, Open Approach */
"0FL60CZ" = "1" /* Occlusion of Left Hepatic Duct with Extraluminal Device, Open Approach */
"0FL60DZ" = "1" /* Occlusion of Left Hepatic Duct with Intraluminal Device, Open Approach */
"0FL60ZZ" = "1" /* Occlusion of Left Hepatic Duct, Open Approach */
"0FL80CZ" = "1" /* Occlusion of Cystic Duct with Extraluminal Device, Open Approach */
"0FL80DZ" = "1" /* Occlusion of Cystic Duct with Intraluminal Device, Open Approach */
"0FL80ZZ" = "1" /* Occlusion of Cystic Duct, Open Approach */
"0FL90CZ" = "1" /* Occlusion of Common Bile Duct with Extraluminal Device, Open Approach */
"0FL90DZ" = "1" /* Occlusion of Common Bile Duct with Intraluminal Device, Open Approach */
"0FL90ZZ" = "1" /* Occlusion of Common Bile Duct, Open Approach */
"0FLC0CZ" = "1" /* Occlusion of Ampulla of Vater with Extraluminal Device, Open Approach */
"0FLC0DZ" = "1" /* Occlusion of Ampulla of Vater with Intraluminal Device, Open Approach */
"0FLC0ZZ" = "1" /* Occlusion of Ampulla of Vater, Open Approach */
"0FLD0CZ" = "1" /* Occlusion of Pancreatic Duct with Extraluminal Device, Open Approach */
"0FLD0DZ" = "1" /* Occlusion of Pancreatic Duct with Intraluminal Device, Open Approach */
"0FLD0ZZ" = "1" /* Occlusion of Pancreatic Duct, Open Approach */
"0FLF0CZ" = "1" /* Occlusion of Accessory Pancreatic Duct with Extraluminal Device, Open Approach */
"0FLF0DZ" = "1" /* Occlusion of Accessory Pancreatic Duct with Intraluminal Device, Open Approach */
"0FLF0ZZ" = "1" /* Occlusion of Accessory Pancreatic Duct, Open Approach */
"0FM00ZZ" = "1" /* Reattachment of Liver, Open Approach */
"0FM10ZZ" = "1" /* Reattachment of Right Lobe Liver, Open Approach */
"0FM20ZZ" = "1" /* Reattachment of Left Lobe Liver, Open Approach */
"0FM40ZZ" = "1" /* Reattachment of Gallbladder, Open Approach */
"0FM50ZZ" = "1" /* Reattachment of Right Hepatic Duct, Open Approach */
"0FM60ZZ" = "1" /* Reattachment of Left Hepatic Duct, Open Approach */
"0FM80ZZ" = "1" /* Reattachment of Cystic Duct, Open Approach */
"0FM90ZZ" = "1" /* Reattachment of Common Bile Duct, Open Approach */
"0FMC0ZZ" = "1" /* Reattachment of Ampulla of Vater, Open Approach */
"0FMD0ZZ" = "1" /* Reattachment of Pancreatic Duct, Open Approach */
"0FMF0ZZ" = "1" /* Reattachment of Accessory Pancreatic Duct, Open Approach */
"0FMG0ZZ" = "1" /* Reattachment of Pancreas, Open Approach */
"0FN00ZZ" = "1" /* Release Liver, Open Approach */
"0FN10ZZ" = "1" /* Release Right Lobe Liver, Open Approach */
"0FN20ZZ" = "1" /* Release Left Lobe Liver, Open Approach */
"0FN40ZZ" = "1" /* Release Gallbladder, Open Approach */
"0FN50ZZ" = "1" /* Release Right Hepatic Duct, Open Approach */
"0FN60ZZ" = "1" /* Release Left Hepatic Duct, Open Approach */
"0FN80ZZ" = "1" /* Release Cystic Duct, Open Approach */
"0FN90ZZ" = "1" /* Release Common Bile Duct, Open Approach */
"0FNC0ZZ" = "1" /* Release Ampulla of Vater, Open Approach */
"0FND0ZZ" = "1" /* Release Pancreatic Duct, Open Approach */
"0FNF0ZZ" = "1" /* Release Accessory Pancreatic Duct, Open Approach */
"0FNG0ZZ" = "1" /* Release Pancreas, Open Approach */
"0FP000Z" = "1" /* Removal of Drainage Device from Liver, Open Approach */
"0FP002Z" = "1" /* Removal of Monitoring Device from Liver, Open Approach */
"0FP003Z" = "1" /* Removal of Infusion Device from Liver, Open Approach */
"0FP400Z" = "1" /* Removal of Drainage Device from Gallbladder, Open Approach */
"0FP402Z" = "1" /* Removal of Monitoring Device from Gallbladder, Open Approach */
"0FP403Z" = "1" /* Removal of Infusion Device from Gallbladder, Open Approach */
"0FP40DZ" = "1" /* Removal of Intraluminal Device from Gallbladder, Open Approach */
"0FPB00Z" = "1" /* Removal of Drainage Device from Hepatobiliary Duct, Open Approach */
"0FPB01Z" = "1" /* Removal of Radioactive Element from Hepatobiliary Duct, Open Approach */
"0FPB02Z" = "1" /* Removal of Monitoring Device from Hepatobiliary Duct, Open Approach */
"0FPB03Z" = "1" /* Removal of Infusion Device from Hepatobiliary Duct, Open Approach */
"0FPB07Z" = "1" /* Removal of Autologous Tissue Substitute from Hepatobiliary Duct, Open Approach */
"0FPB0CZ" = "1" /* Removal of Extraluminal Device from Hepatobiliary Duct, Open Approach */
"0FPB0DZ" = "1" /* Removal of Intraluminal Device from Hepatobiliary Duct, Open Approach */
"0FPB0JZ" = "1" /* Removal of Synthetic Substitute from Hepatobiliary Duct, Open Approach */
"0FPB0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Hepatobiliary Duct, Open Approach */
"0FPD00Z" = "1" /* Removal of Drainage Device from Pancreatic Duct, Open Approach */
"0FPD01Z" = "1" /* Removal of Radioactive Element from Pancreatic Duct, Open Approach */
"0FPD02Z" = "1" /* Removal of Monitoring Device from Pancreatic Duct, Open Approach */
"0FPD03Z" = "1" /* Removal of Infusion Device from Pancreatic Duct, Open Approach */
"0FPD07Z" = "1" /* Removal of Autologous Tissue Substitute from Pancreatic Duct, Open Approach */
"0FPD0CZ" = "1" /* Removal of Extraluminal Device from Pancreatic Duct, Open Approach */
"0FPD0DZ" = "1" /* Removal of Intraluminal Device from Pancreatic Duct, Open Approach */
"0FPD0JZ" = "1" /* Removal of Synthetic Substitute from Pancreatic Duct, Open Approach */
"0FPD0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Pancreatic Duct, Open Approach */
"0FPG00Z" = "1" /* Removal of Drainage Device from Pancreas, Open Approach */
"0FPG02Z" = "1" /* Removal of Monitoring Device from Pancreas, Open Approach */
"0FPG03Z" = "1" /* Removal of Infusion Device from Pancreas, Open Approach */
"0FPG0DZ" = "1" /* Removal of Intraluminal Device from Pancreas, Open Approach */
"0FQ00ZZ" = "1" /* Repair Liver, Open Approach */
"0FQ10ZZ" = "1" /* Repair Right Lobe Liver, Open Approach */
"0FQ20ZZ" = "1" /* Repair Left Lobe Liver, Open Approach */
"0FQ40ZZ" = "1" /* Repair Gallbladder, Open Approach */
"0FQ50ZZ" = "1" /* Repair Right Hepatic Duct, Open Approach */
"0FQ60ZZ" = "1" /* Repair Left Hepatic Duct, Open Approach */
"0FQ80ZZ" = "1" /* Repair Cystic Duct, Open Approach */
"0FQ90ZZ" = "1" /* Repair Common Bile Duct, Open Approach */
"0FQC0ZZ" = "1" /* Repair Ampulla of Vater, Open Approach */
"0FQD0ZZ" = "1" /* Repair Pancreatic Duct, Open Approach */
"0FQF0ZZ" = "1" /* Repair Accessory Pancreatic Duct, Open Approach */
"0FQG0ZZ" = "1" /* Repair Pancreas, Open Approach */
"0FR507Z" = "1" /* Replacement of Right Hepatic Duct with Autologous Tissue Substitute, Open Approach */
"0FR50JZ" = "1" /* Replacement of Right Hepatic Duct with Synthetic Substitute, Open Approach */
"0FR50KZ" = "1" /* Replacement of Right Hepatic Duct with Nonautologous Tissue Substitute, Open Approach */
"0FR607Z" = "1" /* Replacement of Left Hepatic Duct with Autologous Tissue Substitute, Open Approach */
"0FR60JZ" = "1" /* Replacement of Left Hepatic Duct with Synthetic Substitute, Open Approach */
"0FR60KZ" = "1" /* Replacement of Left Hepatic Duct with Nonautologous Tissue Substitute, Open Approach */
"0FR807Z" = "1" /* Replacement of Cystic Duct with Autologous Tissue Substitute, Open Approach */
"0FR80JZ" = "1" /* Replacement of Cystic Duct with Synthetic Substitute, Open Approach */
"0FR80KZ" = "1" /* Replacement of Cystic Duct with Nonautologous Tissue Substitute, Open Approach */
"0FR907Z" = "1" /* Replacement of Common Bile Duct with Autologous Tissue Substitute, Open Approach */
"0FR90JZ" = "1" /* Replacement of Common Bile Duct with Synthetic Substitute, Open Approach */
"0FR90KZ" = "1" /* Replacement of Common Bile Duct with Nonautologous Tissue Substitute, Open Approach */
"0FRC07Z" = "1" /* Replacement of Ampulla of Vater with Autologous Tissue Substitute, Open Approach */
"0FRC0JZ" = "1" /* Replacement of Ampulla of Vater with Synthetic Substitute, Open Approach */
"0FRC0KZ" = "1" /* Replacement of Ampulla of Vater with Nonautologous Tissue Substitute, Open Approach */
"0FRD07Z" = "1" /* Replacement of Pancreatic Duct with Autologous Tissue Substitute, Open Approach */
"0FRD0JZ" = "1" /* Replacement of Pancreatic Duct with Synthetic Substitute, Open Approach */
"0FRD0KZ" = "1" /* Replacement of Pancreatic Duct with Nonautologous Tissue Substitute, Open Approach */
"0FRF07Z" = "1" /* Replacement of Accessory Pancreatic Duct with Autologous Tissue Substitute, Open Approach */
"0FRF0JZ" = "1" /* Replacement of Accessory Pancreatic Duct with Synthetic Substitute, Open Approach */
"0FRF0KZ" = "1" /* Replacement of Accessory Pancreatic Duct with Nonautologous Tissue Substitute, Open Approach */
"0FS00ZZ" = "1" /* Reposition Liver, Open Approach */
"0FS40ZZ" = "1" /* Reposition Gallbladder, Open Approach */
"0FS50ZZ" = "1" /* Reposition Right Hepatic Duct, Open Approach */
"0FS60ZZ" = "1" /* Reposition Left Hepatic Duct, Open Approach */
"0FS80ZZ" = "1" /* Reposition Cystic Duct, Open Approach */
"0FS90ZZ" = "1" /* Reposition Common Bile Duct, Open Approach */
"0FSC0ZZ" = "1" /* Reposition Ampulla of Vater, Open Approach */
"0FSD0ZZ" = "1" /* Reposition Pancreatic Duct, Open Approach */
"0FSF0ZZ" = "1" /* Reposition Accessory Pancreatic Duct, Open Approach */
"0FSG0ZZ" = "1" /* Reposition Pancreas, Open Approach */
"0FT00ZZ" = "1" /* Resection of Liver, Open Approach */
"0FT10ZZ" = "1" /* Resection of Right Lobe Liver, Open Approach */
"0FT20ZZ" = "1" /* Resection of Left Lobe Liver, Open Approach */
"0FT40ZZ" = "1" /* Resection of Gallbladder, Open Approach */
"0FT50ZZ" = "1" /* Resection of Right Hepatic Duct, Open Approach */
"0FT60ZZ" = "1" /* Resection of Left Hepatic Duct, Open Approach */
"0FT80ZZ" = "1" /* Resection of Cystic Duct, Open Approach */
"0FT90ZZ" = "1" /* Resection of Common Bile Duct, Open Approach */
"0FTC0ZZ" = "1" /* Resection of Ampulla of Vater, Open Approach */
"0FTD0ZZ" = "1" /* Resection of Pancreatic Duct, Open Approach */
"0FTF0ZZ" = "1" /* Resection of Accessory Pancreatic Duct, Open Approach */
"0FTG0ZZ" = "1" /* Resection of Pancreas, Open Approach */
"0FU507Z" = "1" /* Supplement Right Hepatic Duct with Autologous Tissue Substitute, Open Approach */
"0FU50JZ" = "1" /* Supplement Right Hepatic Duct with Synthetic Substitute, Open Approach */
"0FU50KZ" = "1" /* Supplement Right Hepatic Duct with Nonautologous Tissue Substitute, Open Approach */
"0FU607Z" = "1" /* Supplement Left Hepatic Duct with Autologous Tissue Substitute, Open Approach */
"0FU60JZ" = "1" /* Supplement Left Hepatic Duct with Synthetic Substitute, Open Approach */
"0FU60KZ" = "1" /* Supplement Left Hepatic Duct with Nonautologous Tissue Substitute, Open Approach */
"0FU807Z" = "1" /* Supplement Cystic Duct with Autologous Tissue Substitute, Open Approach */
"0FU80JZ" = "1" /* Supplement Cystic Duct with Synthetic Substitute, Open Approach */
"0FU80KZ" = "1" /* Supplement Cystic Duct with Nonautologous Tissue Substitute, Open Approach */
"0FU907Z" = "1" /* Supplement Common Bile Duct with Autologous Tissue Substitute, Open Approach */
"0FU90JZ" = "1" /* Supplement Common Bile Duct with Synthetic Substitute, Open Approach */
"0FU90KZ" = "1" /* Supplement Common Bile Duct with Nonautologous Tissue Substitute, Open Approach */
"0FUC07Z" = "1" /* Supplement Ampulla of Vater with Autologous Tissue Substitute, Open Approach */
"0FUC0JZ" = "1" /* Supplement Ampulla of Vater with Synthetic Substitute, Open Approach */
"0FUC0KZ" = "1" /* Supplement Ampulla of Vater with Nonautologous Tissue Substitute, Open Approach */
"0FUD07Z" = "1" /* Supplement Pancreatic Duct with Autologous Tissue Substitute, Open Approach */
"0FUD0JZ" = "1" /* Supplement Pancreatic Duct with Synthetic Substitute, Open Approach */
"0FUD0KZ" = "1" /* Supplement Pancreatic Duct with Nonautologous Tissue Substitute, Open Approach */
"0FUF07Z" = "1" /* Supplement Accessory Pancreatic Duct with Autologous Tissue Substitute, Open Approach */
"0FUF0JZ" = "1" /* Supplement Accessory Pancreatic Duct with Synthetic Substitute, Open Approach */
"0FUF0KZ" = "1" /* Supplement Accessory Pancreatic Duct with Nonautologous Tissue Substitute, Open Approach */
"0FV50CZ" = "1" /* Restriction of Right Hepatic Duct with Extraluminal Device, Open Approach */
"0FV50DZ" = "1" /* Restriction of Right Hepatic Duct with Intraluminal Device, Open Approach */
"0FV50ZZ" = "1" /* Restriction of Right Hepatic Duct, Open Approach */
"0FV60CZ" = "1" /* Restriction of Left Hepatic Duct with Extraluminal Device, Open Approach */
"0FV60DZ" = "1" /* Restriction of Left Hepatic Duct with Intraluminal Device, Open Approach */
"0FV60ZZ" = "1" /* Restriction of Left Hepatic Duct, Open Approach */
"0FV80CZ" = "1" /* Restriction of Cystic Duct with Extraluminal Device, Open Approach */
"0FV80DZ" = "1" /* Restriction of Cystic Duct with Intraluminal Device, Open Approach */
"0FV80ZZ" = "1" /* Restriction of Cystic Duct, Open Approach */
"0FV90CZ" = "1" /* Restriction of Common Bile Duct with Extraluminal Device, Open Approach */
"0FV90DZ" = "1" /* Restriction of Common Bile Duct with Intraluminal Device, Open Approach */
"0FV90ZZ" = "1" /* Restriction of Common Bile Duct, Open Approach */
"0FVC0CZ" = "1" /* Restriction of Ampulla of Vater with Extraluminal Device, Open Approach */
"0FVC0DZ" = "1" /* Restriction of Ampulla of Vater with Intraluminal Device, Open Approach */
"0FVC0ZZ" = "1" /* Restriction of Ampulla of Vater, Open Approach */
"0FVD0CZ" = "1" /* Restriction of Pancreatic Duct with Extraluminal Device, Open Approach */
"0FVD0DZ" = "1" /* Restriction of Pancreatic Duct with Intraluminal Device, Open Approach */
"0FVD0ZZ" = "1" /* Restriction of Pancreatic Duct, Open Approach */
"0FVF0CZ" = "1" /* Restriction of Accessory Pancreatic Duct with Extraluminal Device, Open Approach */
"0FVF0DZ" = "1" /* Restriction of Accessory Pancreatic Duct with Intraluminal Device, Open Approach */
"0FVF0ZZ" = "1" /* Restriction of Accessory Pancreatic Duct, Open Approach */
"0FW000Z" = "1" /* Revision of Drainage Device in Liver, Open Approach */
"0FW002Z" = "1" /* Revision of Monitoring Device in Liver, Open Approach */
"0FW003Z" = "1" /* Revision of Infusion Device in Liver, Open Approach */
"0FW400Z" = "1" /* Revision of Drainage Device in Gallbladder, Open Approach */
"0FW402Z" = "1" /* Revision of Monitoring Device in Gallbladder, Open Approach */
"0FW403Z" = "1" /* Revision of Infusion Device in Gallbladder, Open Approach */
"0FW40DZ" = "1" /* Revision of Intraluminal Device in Gallbladder, Open Approach */
"0FWB00Z" = "1" /* Revision of Drainage Device in Hepatobiliary Duct, Open Approach */
"0FWB02Z" = "1" /* Revision of Monitoring Device in Hepatobiliary Duct, Open Approach */
"0FWB03Z" = "1" /* Revision of Infusion Device in Hepatobiliary Duct, Open Approach */
"0FWB07Z" = "1" /* Revision of Autologous Tissue Substitute in Hepatobiliary Duct, Open Approach */
"0FWB0CZ" = "1" /* Revision of Extraluminal Device in Hepatobiliary Duct, Open Approach */
"0FWB0DZ" = "1" /* Revision of Intraluminal Device in Hepatobiliary Duct, Open Approach */
"0FWB0JZ" = "1" /* Revision of Synthetic Substitute in Hepatobiliary Duct, Open Approach */
"0FWB0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Hepatobiliary Duct, Open Approach */
"0FWD00Z" = "1" /* Revision of Drainage Device in Pancreatic Duct, Open Approach */
"0FWD02Z" = "1" /* Revision of Monitoring Device in Pancreatic Duct, Open Approach */
"0FWD03Z" = "1" /* Revision of Infusion Device in Pancreatic Duct, Open Approach */
"0FWD07Z" = "1" /* Revision of Autologous Tissue Substitute in Pancreatic Duct, Open Approach */
"0FWD0CZ" = "1" /* Revision of Extraluminal Device in Pancreatic Duct, Open Approach */
"0FWD0DZ" = "1" /* Revision of Intraluminal Device in Pancreatic Duct, Open Approach */
"0FWD0JZ" = "1" /* Revision of Synthetic Substitute in Pancreatic Duct, Open Approach */
"0FWD0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Pancreatic Duct, Open Approach */
"0FWG00Z" = "1" /* Revision of Drainage Device in Pancreas, Open Approach */
"0FWG02Z" = "1" /* Revision of Monitoring Device in Pancreas, Open Approach */
"0FWG03Z" = "1" /* Revision of Infusion Device in Pancreas, Open Approach */
"0FWG0DZ" = "1" /* Revision of Intraluminal Device in Pancreas, Open Approach */
"0FY00Z0" = "1" /* Transplantation of Liver, Allogeneic, Open Approach */
"0FY00Z1" = "1" /* Transplantation of Liver, Syngeneic, Open Approach */
"0FY00Z2" = "1" /* Transplantation of Liver, Zooplastic, Open Approach */
"0FYG0Z0" = "1" /* Transplantation of Pancreas, Allogeneic, Open Approach */
"0FYG0Z1" = "1" /* Transplantation of Pancreas, Syngeneic, Open Approach */
"0FYG0Z2" = "1" /* Transplantation of Pancreas, Zooplastic, Open Approach */
"0G520ZZ" = "1" /* Destruction of Left Adrenal Gland, Open Approach */
"0G530ZZ" = "1" /* Destruction of Right Adrenal Gland, Open Approach */
"0G540ZZ" = "1" /* Destruction of Bilateral Adrenal Glands, Open Approach */
"0G9200Z" = "1" /* Drainage of Left Adrenal Gland with Drainage Device, Open Approach */
"0G920ZX" = "1" /* Drainage of Left Adrenal Gland, Open Approach, Diagnostic */
"0G920ZZ" = "1" /* Drainage of Left Adrenal Gland, Open Approach */
"0G9300Z" = "1" /* Drainage of Right Adrenal Gland with Drainage Device, Open Approach */
"0G930ZX" = "1" /* Drainage of Right Adrenal Gland, Open Approach, Diagnostic */
"0G930ZZ" = "1" /* Drainage of Right Adrenal Gland, Open Approach */
"0G9400Z" = "1" /* Drainage of Bilateral Adrenal Glands with Drainage Device, Open Approach */
"0G940ZX" = "1" /* Drainage of Bilateral Adrenal Glands, Open Approach, Diagnostic */
"0G940ZZ" = "1" /* Drainage of Bilateral Adrenal Glands, Open Approach */
"0GB20ZX" = "1" /* Excision of Left Adrenal Gland, Open Approach, Diagnostic */
"0GB20ZZ" = "1" /* Excision of Left Adrenal Gland, Open Approach */
"0GB30ZX" = "1" /* Excision of Right Adrenal Gland, Open Approach, Diagnostic */
"0GB30ZZ" = "1" /* Excision of Right Adrenal Gland, Open Approach */
"0GB40ZX" = "1" /* Excision of Bilateral Adrenal Glands, Open Approach, Diagnostic */
"0GB40ZZ" = "1" /* Excision of Bilateral Adrenal Glands, Open Approach */
"0GC20ZZ" = "1" /* Extirpation of Matter from Left Adrenal Gland, Open Approach */
"0GC30ZZ" = "1" /* Extirpation of Matter from Right Adrenal Gland, Open Approach */
"0GC40ZZ" = "1" /* Extirpation of Matter from Bilateral Adrenal Glands, Open Approach */
"0GM20ZZ" = "1" /* Reattachment of Left Adrenal Gland, Open Approach */
"0GM30ZZ" = "1" /* Reattachment of Right Adrenal Gland, Open Approach */
"0GN20ZZ" = "1" /* Release Left Adrenal Gland, Open Approach */
"0GN30ZZ" = "1" /* Release Right Adrenal Gland, Open Approach */
"0GN40ZZ" = "1" /* Release Bilateral Adrenal Glands, Open Approach */
"0GQ20ZZ" = "1" /* Repair Left Adrenal Gland, Open Approach */
"0GQ30ZZ" = "1" /* Repair Right Adrenal Gland, Open Approach */
"0GQ40ZZ" = "1" /* Repair Bilateral Adrenal Glands, Open Approach */
"0GS20ZZ" = "1" /* Reposition Left Adrenal Gland, Open Approach */
"0GS30ZZ" = "1" /* Reposition Right Adrenal Gland, Open Approach */
"0GT20ZZ" = "1" /* Resection of Left Adrenal Gland, Open Approach */
"0GT30ZZ" = "1" /* Resection of Right Adrenal Gland, Open Approach */
"0GT40ZZ" = "1" /* Resection of Bilateral Adrenal Glands, Open Approach */
"0SG0070" = "1" /* Fusion of Lumbar Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG00A0" = "1" /* Fusion of Lumbar Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0SG00J0" = "1" /* Fusion of Lumbar Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG00K0" = "1" /* Fusion of Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG00Z0" = "1" /* Fusion of Lumbar Vertebral Joint, Anterior Approach, Anterior Column, Open Approach */
"0SG1070" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG10A0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0SG10J0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG10K0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG10Z0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints, Anterior Approach, Anterior Column, Open Approach */
"0SG3070" = "1" /* Fusion of Lumbosacral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG30A0" = "1" /* Fusion of Lumbosacral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0SG30J0" = "1" /* Fusion of Lumbosacral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG30K0" = "1" /* Fusion of Lumbosacral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG30Z0" = "1" /* Fusion of Lumbosacral Joint, Anterior Approach, Anterior Column, Open Approach */
"0T13073" = "1" /* Bypass Right Kidney Pelvis to Right Kidney Pelvis with Autologous Tissue Substitute, Open Approach */
"0T13074" = "1" /* Bypass Right Kidney Pelvis to Left Kidney Pelvis with Autologous Tissue Substitute, Open Approach */
"0T13076" = "1" /* Bypass Right Kidney Pelvis to Right Ureter with Autologous Tissue Substitute, Open Approach */
"0T13077" = "1" /* Bypass Right Kidney Pelvis to Left Ureter with Autologous Tissue Substitute, Open Approach */
"0T13078" = "1" /* Bypass Right Kidney Pelvis to Colon with Autologous Tissue Substitute, Open Approach */
"0T13079" = "1" /* Bypass Right Kidney Pelvis to Colocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1307A" = "1" /* Bypass Right Kidney Pelvis to Ileum with Autologous Tissue Substitute, Open Approach */
"0T1307B" = "1" /* Bypass Right Kidney Pelvis to Bladder with Autologous Tissue Substitute, Open Approach */
"0T1307C" = "1" /* Bypass Right Kidney Pelvis to Ileocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1307D" = "1" /* Bypass Right Kidney Pelvis to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0T130J3" = "1" /* Bypass Right Kidney Pelvis to Right Kidney Pelvis with Synthetic Substitute, Open Approach */
"0T130J4" = "1" /* Bypass Right Kidney Pelvis to Left Kidney Pelvis with Synthetic Substitute, Open Approach */
"0T130J6" = "1" /* Bypass Right Kidney Pelvis to Right Ureter with Synthetic Substitute, Open Approach */
"0T130J7" = "1" /* Bypass Right Kidney Pelvis to Left Ureter with Synthetic Substitute, Open Approach */
"0T130J8" = "1" /* Bypass Right Kidney Pelvis to Colon with Synthetic Substitute, Open Approach */
"0T130J9" = "1" /* Bypass Right Kidney Pelvis to Colocutaneous with Synthetic Substitute, Open Approach */
"0T130JA" = "1" /* Bypass Right Kidney Pelvis to Ileum with Synthetic Substitute, Open Approach */
"0T130JB" = "1" /* Bypass Right Kidney Pelvis to Bladder with Synthetic Substitute, Open Approach */
"0T130JC" = "1" /* Bypass Right Kidney Pelvis to Ileocutaneous with Synthetic Substitute, Open Approach */
"0T130JD" = "1" /* Bypass Right Kidney Pelvis to Cutaneous with Synthetic Substitute, Open Approach */
"0T130K3" = "1" /* Bypass Right Kidney Pelvis to Right Kidney Pelvis with Nonautologous Tissue Substitute, Open Approach */
"0T130K4" = "1" /* Bypass Right Kidney Pelvis to Left Kidney Pelvis with Nonautologous Tissue Substitute, Open Approach */
"0T130K6" = "1" /* Bypass Right Kidney Pelvis to Right Ureter with Nonautologous Tissue Substitute, Open Approach */
"0T130K7" = "1" /* Bypass Right Kidney Pelvis to Left Ureter with Nonautologous Tissue Substitute, Open Approach */
"0T130K8" = "1" /* Bypass Right Kidney Pelvis to Colon with Nonautologous Tissue Substitute, Open Approach */
"0T130K9" = "1" /* Bypass Right Kidney Pelvis to Colocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T130KA" = "1" /* Bypass Right Kidney Pelvis to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0T130KB" = "1" /* Bypass Right Kidney Pelvis to Bladder with Nonautologous Tissue Substitute, Open Approach */
"0T130KC" = "1" /* Bypass Right Kidney Pelvis to Ileocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T130KD" = "1" /* Bypass Right Kidney Pelvis to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T130Z3" = "1" /* Bypass Right Kidney Pelvis to Right Kidney Pelvis, Open Approach */
"0T130Z4" = "1" /* Bypass Right Kidney Pelvis to Left Kidney Pelvis, Open Approach */
"0T130Z6" = "1" /* Bypass Right Kidney Pelvis to Right Ureter, Open Approach */
"0T130Z7" = "1" /* Bypass Right Kidney Pelvis to Left Ureter, Open Approach */
"0T130Z8" = "1" /* Bypass Right Kidney Pelvis to Colon, Open Approach */
"0T130Z9" = "1" /* Bypass Right Kidney Pelvis to Colocutaneous, Open Approach */
"0T130ZA" = "1" /* Bypass Right Kidney Pelvis to Ileum, Open Approach */
"0T130ZB" = "1" /* Bypass Right Kidney Pelvis to Bladder, Open Approach */
"0T130ZC" = "1" /* Bypass Right Kidney Pelvis to Ileocutaneous, Open Approach */
"0T130ZD" = "1" /* Bypass Right Kidney Pelvis to Cutaneous, Open Approach */
"0T14073" = "1" /* Bypass Left Kidney Pelvis to Right Kidney Pelvis with Autologous Tissue Substitute, Open Approach */
"0T14074" = "1" /* Bypass Left Kidney Pelvis to Left Kidney Pelvis with Autologous Tissue Substitute, Open Approach */
"0T14076" = "1" /* Bypass Left Kidney Pelvis to Right Ureter with Autologous Tissue Substitute, Open Approach */
"0T14077" = "1" /* Bypass Left Kidney Pelvis to Left Ureter with Autologous Tissue Substitute, Open Approach */
"0T14078" = "1" /* Bypass Left Kidney Pelvis to Colon with Autologous Tissue Substitute, Open Approach */
"0T14079" = "1" /* Bypass Left Kidney Pelvis to Colocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1407A" = "1" /* Bypass Left Kidney Pelvis to Ileum with Autologous Tissue Substitute, Open Approach */
"0T1407B" = "1" /* Bypass Left Kidney Pelvis to Bladder with Autologous Tissue Substitute, Open Approach */
"0T1407C" = "1" /* Bypass Left Kidney Pelvis to Ileocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1407D" = "1" /* Bypass Left Kidney Pelvis to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0T140J3" = "1" /* Bypass Left Kidney Pelvis to Right Kidney Pelvis with Synthetic Substitute, Open Approach */
"0T140J4" = "1" /* Bypass Left Kidney Pelvis to Left Kidney Pelvis with Synthetic Substitute, Open Approach */
"0T140J6" = "1" /* Bypass Left Kidney Pelvis to Right Ureter with Synthetic Substitute, Open Approach */
"0T140J7" = "1" /* Bypass Left Kidney Pelvis to Left Ureter with Synthetic Substitute, Open Approach */
"0T140J8" = "1" /* Bypass Left Kidney Pelvis to Colon with Synthetic Substitute, Open Approach */
"0T140J9" = "1" /* Bypass Left Kidney Pelvis to Colocutaneous with Synthetic Substitute, Open Approach */
"0T140JA" = "1" /* Bypass Left Kidney Pelvis to Ileum with Synthetic Substitute, Open Approach */
"0T140JB" = "1" /* Bypass Left Kidney Pelvis to Bladder with Synthetic Substitute, Open Approach */
"0T140JC" = "1" /* Bypass Left Kidney Pelvis to Ileocutaneous with Synthetic Substitute, Open Approach */
"0T140JD" = "1" /* Bypass Left Kidney Pelvis to Cutaneous with Synthetic Substitute, Open Approach */
"0T140K3" = "1" /* Bypass Left Kidney Pelvis to Right Kidney Pelvis with Nonautologous Tissue Substitute, Open Approach */
"0T140K4" = "1" /* Bypass Left Kidney Pelvis to Left Kidney Pelvis with Nonautologous Tissue Substitute, Open Approach */
"0T140K6" = "1" /* Bypass Left Kidney Pelvis to Right Ureter with Nonautologous Tissue Substitute, Open Approach */
"0T140K7" = "1" /* Bypass Left Kidney Pelvis to Left Ureter with Nonautologous Tissue Substitute, Open Approach */
"0T140K8" = "1" /* Bypass Left Kidney Pelvis to Colon with Nonautologous Tissue Substitute, Open Approach */
"0T140K9" = "1" /* Bypass Left Kidney Pelvis to Colocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T140KA" = "1" /* Bypass Left Kidney Pelvis to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0T140KB" = "1" /* Bypass Left Kidney Pelvis to Bladder with Nonautologous Tissue Substitute, Open Approach */
"0T140KC" = "1" /* Bypass Left Kidney Pelvis to Ileocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T140KD" = "1" /* Bypass Left Kidney Pelvis to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T140Z3" = "1" /* Bypass Left Kidney Pelvis to Right Kidney Pelvis, Open Approach */
"0T140Z4" = "1" /* Bypass Left Kidney Pelvis to Left Kidney Pelvis, Open Approach */
"0T140Z6" = "1" /* Bypass Left Kidney Pelvis to Right Ureter, Open Approach */
"0T140Z7" = "1" /* Bypass Left Kidney Pelvis to Left Ureter, Open Approach */
"0T140Z8" = "1" /* Bypass Left Kidney Pelvis to Colon, Open Approach */
"0T140Z9" = "1" /* Bypass Left Kidney Pelvis to Colocutaneous, Open Approach */
"0T140ZA" = "1" /* Bypass Left Kidney Pelvis to Ileum, Open Approach */
"0T140ZB" = "1" /* Bypass Left Kidney Pelvis to Bladder, Open Approach */
"0T140ZC" = "1" /* Bypass Left Kidney Pelvis to Ileocutaneous, Open Approach */
"0T140ZD" = "1" /* Bypass Left Kidney Pelvis to Cutaneous, Open Approach */
"0T16076" = "1" /* Bypass Right Ureter to Right Ureter with Autologous Tissue Substitute, Open Approach */
"0T16077" = "1" /* Bypass Right Ureter to Left Ureter with Autologous Tissue Substitute, Open Approach */
"0T16078" = "1" /* Bypass Right Ureter to Colon with Autologous Tissue Substitute, Open Approach */
"0T16079" = "1" /* Bypass Right Ureter to Colocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1607A" = "1" /* Bypass Right Ureter to Ileum with Autologous Tissue Substitute, Open Approach */
"0T1607B" = "1" /* Bypass Right Ureter to Bladder with Autologous Tissue Substitute, Open Approach */
"0T1607C" = "1" /* Bypass Right Ureter to Ileocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1607D" = "1" /* Bypass Right Ureter to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0T160J6" = "1" /* Bypass Right Ureter to Right Ureter with Synthetic Substitute, Open Approach */
"0T160J7" = "1" /* Bypass Right Ureter to Left Ureter with Synthetic Substitute, Open Approach */
"0T160J8" = "1" /* Bypass Right Ureter to Colon with Synthetic Substitute, Open Approach */
"0T160J9" = "1" /* Bypass Right Ureter to Colocutaneous with Synthetic Substitute, Open Approach */
"0T160JA" = "1" /* Bypass Right Ureter to Ileum with Synthetic Substitute, Open Approach */
"0T160JB" = "1" /* Bypass Right Ureter to Bladder with Synthetic Substitute, Open Approach */
"0T160JC" = "1" /* Bypass Right Ureter to Ileocutaneous with Synthetic Substitute, Open Approach */
"0T160JD" = "1" /* Bypass Right Ureter to Cutaneous with Synthetic Substitute, Open Approach */
"0T160K6" = "1" /* Bypass Right Ureter to Right Ureter with Nonautologous Tissue Substitute, Open Approach */
"0T160K7" = "1" /* Bypass Right Ureter to Left Ureter with Nonautologous Tissue Substitute, Open Approach */
"0T160K8" = "1" /* Bypass Right Ureter to Colon with Nonautologous Tissue Substitute, Open Approach */
"0T160K9" = "1" /* Bypass Right Ureter to Colocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T160KA" = "1" /* Bypass Right Ureter to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0T160KB" = "1" /* Bypass Right Ureter to Bladder with Nonautologous Tissue Substitute, Open Approach */
"0T160KC" = "1" /* Bypass Right Ureter to Ileocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T160KD" = "1" /* Bypass Right Ureter to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T160Z6" = "1" /* Bypass Right Ureter to Right Ureter, Open Approach */
"0T160Z7" = "1" /* Bypass Right Ureter to Left Ureter, Open Approach */
"0T160Z8" = "1" /* Bypass Right Ureter to Colon, Open Approach */
"0T160Z9" = "1" /* Bypass Right Ureter to Colocutaneous, Open Approach */
"0T160ZA" = "1" /* Bypass Right Ureter to Ileum, Open Approach */
"0T160ZB" = "1" /* Bypass Right Ureter to Bladder, Open Approach */
"0T160ZC" = "1" /* Bypass Right Ureter to Ileocutaneous, Open Approach */
"0T160ZD" = "1" /* Bypass Right Ureter to Cutaneous, Open Approach */
"0T17076" = "1" /* Bypass Left Ureter to Right Ureter with Autologous Tissue Substitute, Open Approach */
"0T17077" = "1" /* Bypass Left Ureter to Left Ureter with Autologous Tissue Substitute, Open Approach */
"0T17078" = "1" /* Bypass Left Ureter to Colon with Autologous Tissue Substitute, Open Approach */
"0T17079" = "1" /* Bypass Left Ureter to Colocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1707A" = "1" /* Bypass Left Ureter to Ileum with Autologous Tissue Substitute, Open Approach */
"0T1707B" = "1" /* Bypass Left Ureter to Bladder with Autologous Tissue Substitute, Open Approach */
"0T1707C" = "1" /* Bypass Left Ureter to Ileocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1707D" = "1" /* Bypass Left Ureter to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0T170J6" = "1" /* Bypass Left Ureter to Right Ureter with Synthetic Substitute, Open Approach */
"0T170J7" = "1" /* Bypass Left Ureter to Left Ureter with Synthetic Substitute, Open Approach */
"0T170J8" = "1" /* Bypass Left Ureter to Colon with Synthetic Substitute, Open Approach */
"0T170J9" = "1" /* Bypass Left Ureter to Colocutaneous with Synthetic Substitute, Open Approach */
"0T170JA" = "1" /* Bypass Left Ureter to Ileum with Synthetic Substitute, Open Approach */
"0T170JB" = "1" /* Bypass Left Ureter to Bladder with Synthetic Substitute, Open Approach */
"0T170JC" = "1" /* Bypass Left Ureter to Ileocutaneous with Synthetic Substitute, Open Approach */
"0T170JD" = "1" /* Bypass Left Ureter to Cutaneous with Synthetic Substitute, Open Approach */
"0T170K6" = "1" /* Bypass Left Ureter to Right Ureter with Nonautologous Tissue Substitute, Open Approach */
"0T170K7" = "1" /* Bypass Left Ureter to Left Ureter with Nonautologous Tissue Substitute, Open Approach */
"0T170K8" = "1" /* Bypass Left Ureter to Colon with Nonautologous Tissue Substitute, Open Approach */
"0T170K9" = "1" /* Bypass Left Ureter to Colocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T170KA" = "1" /* Bypass Left Ureter to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0T170KB" = "1" /* Bypass Left Ureter to Bladder with Nonautologous Tissue Substitute, Open Approach */
"0T170KC" = "1" /* Bypass Left Ureter to Ileocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T170KD" = "1" /* Bypass Left Ureter to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T170Z6" = "1" /* Bypass Left Ureter to Right Ureter, Open Approach */
"0T170Z7" = "1" /* Bypass Left Ureter to Left Ureter, Open Approach */
"0T170Z8" = "1" /* Bypass Left Ureter to Colon, Open Approach */
"0T170Z9" = "1" /* Bypass Left Ureter to Colocutaneous, Open Approach */
"0T170ZA" = "1" /* Bypass Left Ureter to Ileum, Open Approach */
"0T170ZB" = "1" /* Bypass Left Ureter to Bladder, Open Approach */
"0T170ZC" = "1" /* Bypass Left Ureter to Ileocutaneous, Open Approach */
"0T170ZD" = "1" /* Bypass Left Ureter to Cutaneous, Open Approach */
"0T18076" = "1" /* Bypass Bilateral Ureters to Right Ureter with Autologous Tissue Substitute, Open Approach */
"0T18077" = "1" /* Bypass Bilateral Ureters to Left Ureter with Autologous Tissue Substitute, Open Approach */
"0T18078" = "1" /* Bypass Bilateral Ureters to Colon with Autologous Tissue Substitute, Open Approach */
"0T18079" = "1" /* Bypass Bilateral Ureters to Colocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1807A" = "1" /* Bypass Bilateral Ureters to Ileum with Autologous Tissue Substitute, Open Approach */
"0T1807B" = "1" /* Bypass Bilateral Ureters to Bladder with Autologous Tissue Substitute, Open Approach */
"0T1807C" = "1" /* Bypass Bilateral Ureters to Ileocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1807D" = "1" /* Bypass Bilateral Ureters to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0T180J6" = "1" /* Bypass Bilateral Ureters to Right Ureter with Synthetic Substitute, Open Approach */
"0T180J7" = "1" /* Bypass Bilateral Ureters to Left Ureter with Synthetic Substitute, Open Approach */
"0T180J8" = "1" /* Bypass Bilateral Ureters to Colon with Synthetic Substitute, Open Approach */
"0T180J9" = "1" /* Bypass Bilateral Ureters to Colocutaneous with Synthetic Substitute, Open Approach */
"0T180JA" = "1" /* Bypass Bilateral Ureters to Ileum with Synthetic Substitute, Open Approach */
"0T180JB" = "1" /* Bypass Bilateral Ureters to Bladder with Synthetic Substitute, Open Approach */
"0T180JC" = "1" /* Bypass Bilateral Ureters to Ileocutaneous with Synthetic Substitute, Open Approach */
"0T180JD" = "1" /* Bypass Bilateral Ureters to Cutaneous with Synthetic Substitute, Open Approach */
"0T180K6" = "1" /* Bypass Bilateral Ureters to Right Ureter with Nonautologous Tissue Substitute, Open Approach */
"0T180K7" = "1" /* Bypass Bilateral Ureters to Left Ureter with Nonautologous Tissue Substitute, Open Approach */
"0T180K8" = "1" /* Bypass Bilateral Ureters to Colon with Nonautologous Tissue Substitute, Open Approach */
"0T180K9" = "1" /* Bypass Bilateral Ureters to Colocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T180KA" = "1" /* Bypass Bilateral Ureters to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0T180KB" = "1" /* Bypass Bilateral Ureters to Bladder with Nonautologous Tissue Substitute, Open Approach */
"0T180KC" = "1" /* Bypass Bilateral Ureters to Ileocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T180KD" = "1" /* Bypass Bilateral Ureters to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T180Z6" = "1" /* Bypass Bilateral Ureters to Right Ureter, Open Approach */
"0T180Z7" = "1" /* Bypass Bilateral Ureters to Left Ureter, Open Approach */
"0T180Z8" = "1" /* Bypass Bilateral Ureters to Colon, Open Approach */
"0T180Z9" = "1" /* Bypass Bilateral Ureters to Colocutaneous, Open Approach */
"0T180ZA" = "1" /* Bypass Bilateral Ureters to Ileum, Open Approach */
"0T180ZB" = "1" /* Bypass Bilateral Ureters to Bladder, Open Approach */
"0T180ZC" = "1" /* Bypass Bilateral Ureters to Ileocutaneous, Open Approach */
"0T180ZD" = "1" /* Bypass Bilateral Ureters to Cutaneous, Open Approach */
"0T1B079" = "1" /* Bypass Bladder to Colocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1B07C" = "1" /* Bypass Bladder to Ileocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1B07D" = "1" /* Bypass Bladder to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0T1B0J9" = "1" /* Bypass Bladder to Colocutaneous with Synthetic Substitute, Open Approach */
"0T1B0JC" = "1" /* Bypass Bladder to Ileocutaneous with Synthetic Substitute, Open Approach */
"0T1B0JD" = "1" /* Bypass Bladder to Cutaneous with Synthetic Substitute, Open Approach */
"0T1B0K9" = "1" /* Bypass Bladder to Colocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T1B0KC" = "1" /* Bypass Bladder to Ileocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T1B0KD" = "1" /* Bypass Bladder to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T1B0Z9" = "1" /* Bypass Bladder to Colocutaneous, Open Approach */
"0T1B0ZC" = "1" /* Bypass Bladder to Ileocutaneous, Open Approach */
"0T1B0ZD" = "1" /* Bypass Bladder to Cutaneous, Open Approach */
"0T500ZZ" = "1" /* Destruction of Right Kidney, Open Approach */
"0T510ZZ" = "1" /* Destruction of Left Kidney, Open Approach */
"0T530ZZ" = "1" /* Destruction of Right Kidney Pelvis, Open Approach */
"0T540ZZ" = "1" /* Destruction of Left Kidney Pelvis, Open Approach */
"0T560ZZ" = "1" /* Destruction of Right Ureter, Open Approach */
"0T570ZZ" = "1" /* Destruction of Left Ureter, Open Approach */
"0T5B0ZZ" = "1" /* Destruction of Bladder, Open Approach */
"0T730DZ" = "1" /* Dilation of Right Kidney Pelvis with Intraluminal Device, Open Approach */
"0T730ZZ" = "1" /* Dilation of Right Kidney Pelvis, Open Approach */
"0T740DZ" = "1" /* Dilation of Left Kidney Pelvis with Intraluminal Device, Open Approach */
"0T740ZZ" = "1" /* Dilation of Left Kidney Pelvis, Open Approach */
"0T760DZ" = "1" /* Dilation of Right Ureter with Intraluminal Device, Open Approach */
"0T760ZZ" = "1" /* Dilation of Right Ureter, Open Approach */
"0T770DZ" = "1" /* Dilation of Left Ureter with Intraluminal Device, Open Approach */
"0T770ZZ" = "1" /* Dilation of Left Ureter, Open Approach */
"0T780DZ" = "1" /* Dilation of Bilateral Ureters with Intraluminal Device, Open Approach */
"0T780ZZ" = "1" /* Dilation of Bilateral Ureters, Open Approach */
"0T7B0DZ" = "1" /* Dilation of Bladder with Intraluminal Device, Open Approach */
"0T7B0ZZ" = "1" /* Dilation of Bladder, Open Approach */
"0T820ZZ" = "1" /* Division of Bilateral Kidneys, Open Approach */
"0T9000Z" = "1" /* Drainage of Right Kidney with Drainage Device, Open Approach */
"0T900ZX" = "1" /* Drainage of Right Kidney, Open Approach, Diagnostic */
"0T900ZZ" = "1" /* Drainage of Right Kidney, Open Approach */
"0T9100Z" = "1" /* Drainage of Left Kidney with Drainage Device, Open Approach */
"0T910ZX" = "1" /* Drainage of Left Kidney, Open Approach, Diagnostic */
"0T910ZZ" = "1" /* Drainage of Left Kidney, Open Approach */
"0T9300Z" = "1" /* Drainage of Right Kidney Pelvis with Drainage Device, Open Approach */
"0T930ZX" = "1" /* Drainage of Right Kidney Pelvis, Open Approach, Diagnostic */
"0T930ZZ" = "1" /* Drainage of Right Kidney Pelvis, Open Approach */
"0T9400Z" = "1" /* Drainage of Left Kidney Pelvis with Drainage Device, Open Approach */
"0T940ZX" = "1" /* Drainage of Left Kidney Pelvis, Open Approach, Diagnostic */
"0T940ZZ" = "1" /* Drainage of Left Kidney Pelvis, Open Approach */
"0T9600Z" = "1" /* Drainage of Right Ureter with Drainage Device, Open Approach */
"0T960ZX" = "1" /* Drainage of Right Ureter, Open Approach, Diagnostic */
"0T960ZZ" = "1" /* Drainage of Right Ureter, Open Approach */
"0T9700Z" = "1" /* Drainage of Left Ureter with Drainage Device, Open Approach */
"0T970ZX" = "1" /* Drainage of Left Ureter, Open Approach, Diagnostic */
"0T970ZZ" = "1" /* Drainage of Left Ureter, Open Approach */
"0T9800Z" = "1" /* Drainage of Bilateral Ureters with Drainage Device, Open Approach */
"0T980ZX" = "1" /* Drainage of Bilateral Ureters, Open Approach, Diagnostic */
"0T980ZZ" = "1" /* Drainage of Bilateral Ureters, Open Approach */
"0T9B00Z" = "1" /* Drainage of Bladder with Drainage Device, Open Approach */
"0T9B0ZX" = "1" /* Drainage of Bladder, Open Approach, Diagnostic */
"0T9B0ZZ" = "1" /* Drainage of Bladder, Open Approach */
"0TB00ZX" = "1" /* Excision of Right Kidney, Open Approach, Diagnostic */
"0TB00ZZ" = "1" /* Excision of Right Kidney, Open Approach */
"0TB10ZX" = "1" /* Excision of Left Kidney, Open Approach, Diagnostic */
"0TB10ZZ" = "1" /* Excision of Left Kidney, Open Approach */
"0TB30ZX" = "1" /* Excision of Right Kidney Pelvis, Open Approach, Diagnostic */
"0TB30ZZ" = "1" /* Excision of Right Kidney Pelvis, Open Approach */
"0TB40ZX" = "1" /* Excision of Left Kidney Pelvis, Open Approach, Diagnostic */
"0TB40ZZ" = "1" /* Excision of Left Kidney Pelvis, Open Approach */
"0TB60ZX" = "1" /* Excision of Right Ureter, Open Approach, Diagnostic */
"0TB60ZZ" = "1" /* Excision of Right Ureter, Open Approach */
"0TB70ZX" = "1" /* Excision of Left Ureter, Open Approach, Diagnostic */
"0TB70ZZ" = "1" /* Excision of Left Ureter, Open Approach */
"0TBB0ZX" = "1" /* Excision of Bladder, Open Approach, Diagnostic */
"0TBB0ZZ" = "1" /* Excision of Bladder, Open Approach */
"0TC00ZZ" = "1" /* Extirpation of Matter from Right Kidney, Open Approach */
"0TC10ZZ" = "1" /* Extirpation of Matter from Left Kidney, Open Approach */
"0TC30ZZ" = "1" /* Extirpation of Matter from Right Kidney Pelvis, Open Approach */
"0TC40ZZ" = "1" /* Extirpation of Matter from Left Kidney Pelvis, Open Approach */
"0TC60ZZ" = "1" /* Extirpation of Matter from Right Ureter, Open Approach */
"0TC70ZZ" = "1" /* Extirpation of Matter from Left Ureter, Open Approach */
"0TCB0ZZ" = "1" /* Extirpation of Matter from Bladder, Open Approach */
"0TD00ZZ" = "1" /* Extraction of Right Kidney, Open Approach */
"0TD10ZZ" = "1" /* Extraction of Left Kidney, Open Approach */
"0TF30ZZ" = "1" /* Fragmentation in Right Kidney Pelvis, Open Approach */
"0TF40ZZ" = "1" /* Fragmentation in Left Kidney Pelvis, Open Approach */
"0TF60ZZ" = "1" /* Fragmentation in Right Ureter, Open Approach */
"0TF70ZZ" = "1" /* Fragmentation in Left Ureter, Open Approach */
"0TFB0ZZ" = "1" /* Fragmentation in Bladder, Open Approach */
"0TH502Z" = "1" /* Insertion of Monitoring Device into Kidney, Open Approach */
"0TH503Z" = "1" /* Insertion of Infusion Device into Kidney, Open Approach */
"0TH902Z" = "1" /* Insertion of Monitoring Device into Ureter, Open Approach */
"0TH903Z" = "1" /* Insertion of Infusion Device into Ureter, Open Approach */
"0TH90MZ" = "1" /* Insertion of Stimulator Lead into Ureter, Open Approach */
"0THB02Z" = "1" /* Insertion of Monitoring Device into Bladder, Open Approach */
"0THB03Z" = "1" /* Insertion of Infusion Device into Bladder, Open Approach */
"0THB0LZ" = "1" /* Insertion of Artificial Sphincter into Bladder, Open Approach */
"0THB0MZ" = "1" /* Insertion of Stimulator Lead into Bladder, Open Approach */
"0TJ50ZZ" = "1" /* Inspection of Kidney, Open Approach */
"0TJ90ZZ" = "1" /* Inspection of Ureter, Open Approach */
"0TJB0ZZ" = "1" /* Inspection of Bladder, Open Approach */
"0TL30CZ" = "1" /* Occlusion of Right Kidney Pelvis with Extraluminal Device, Open Approach */
"0TL30DZ" = "1" /* Occlusion of Right Kidney Pelvis with Intraluminal Device, Open Approach */
"0TL30ZZ" = "1" /* Occlusion of Right Kidney Pelvis, Open Approach */
"0TL40CZ" = "1" /* Occlusion of Left Kidney Pelvis with Extraluminal Device, Open Approach */
"0TL40DZ" = "1" /* Occlusion of Left Kidney Pelvis with Intraluminal Device, Open Approach */
"0TL40ZZ" = "1" /* Occlusion of Left Kidney Pelvis, Open Approach */
"0TL60CZ" = "1" /* Occlusion of Right Ureter with Extraluminal Device, Open Approach */
"0TL60DZ" = "1" /* Occlusion of Right Ureter with Intraluminal Device, Open Approach */
"0TL60ZZ" = "1" /* Occlusion of Right Ureter, Open Approach */
"0TL70CZ" = "1" /* Occlusion of Left Ureter with Extraluminal Device, Open Approach */
"0TL70DZ" = "1" /* Occlusion of Left Ureter with Intraluminal Device, Open Approach */
"0TL70ZZ" = "1" /* Occlusion of Left Ureter, Open Approach */
"0TLB0CZ" = "1" /* Occlusion of Bladder with Extraluminal Device, Open Approach */
"0TLB0DZ" = "1" /* Occlusion of Bladder with Intraluminal Device, Open Approach */
"0TLB0ZZ" = "1" /* Occlusion of Bladder, Open Approach */
"0TM00ZZ" = "1" /* Reattachment of Right Kidney, Open Approach */
"0TM10ZZ" = "1" /* Reattachment of Left Kidney, Open Approach */
"0TM20ZZ" = "1" /* Reattachment of Bilateral Kidneys, Open Approach */
"0TM30ZZ" = "1" /* Reattachment of Right Kidney Pelvis, Open Approach */
"0TM40ZZ" = "1" /* Reattachment of Left Kidney Pelvis, Open Approach */
"0TM60ZZ" = "1" /* Reattachment of Right Ureter, Open Approach */
"0TM70ZZ" = "1" /* Reattachment of Left Ureter, Open Approach */
"0TM80ZZ" = "1" /* Reattachment of Bilateral Ureters, Open Approach */
"0TMB0ZZ" = "1" /* Reattachment of Bladder, Open Approach */
"0TN00ZZ" = "1" /* Release Right Kidney, Open Approach */
"0TN10ZZ" = "1" /* Release Left Kidney, Open Approach */
"0TN30ZZ" = "1" /* Release Right Kidney Pelvis, Open Approach */
"0TN40ZZ" = "1" /* Release Left Kidney Pelvis, Open Approach */
"0TN60ZZ" = "1" /* Release Right Ureter, Open Approach */
"0TN70ZZ" = "1" /* Release Left Ureter, Open Approach */
"0TNB0ZZ" = "1" /* Release Bladder, Open Approach */
"0TP500Z" = "1" /* Removal of Drainage Device from Kidney, Open Approach */
"0TP502Z" = "1" /* Removal of Monitoring Device from Kidney, Open Approach */
"0TP503Z" = "1" /* Removal of Infusion Device from Kidney, Open Approach */
"0TP507Z" = "1" /* Removal of Autologous Tissue Substitute from Kidney, Open Approach */
"0TP50CZ" = "1" /* Removal of Extraluminal Device from Kidney, Open Approach */
"0TP50DZ" = "1" /* Removal of Intraluminal Device from Kidney, Open Approach */
"0TP50JZ" = "1" /* Removal of Synthetic Substitute from Kidney, Open Approach */
"0TP50KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Kidney, Open Approach */
"0TP900Z" = "1" /* Removal of Drainage Device from Ureter, Open Approach */
"0TP902Z" = "1" /* Removal of Monitoring Device from Ureter, Open Approach */
"0TP903Z" = "1" /* Removal of Infusion Device from Ureter, Open Approach */
"0TP907Z" = "1" /* Removal of Autologous Tissue Substitute from Ureter, Open Approach */
"0TP90CZ" = "1" /* Removal of Extraluminal Device from Ureter, Open Approach */
"0TP90DZ" = "1" /* Removal of Intraluminal Device from Ureter, Open Approach */
"0TP90JZ" = "1" /* Removal of Synthetic Substitute from Ureter, Open Approach */
"0TP90KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Ureter, Open Approach */
"0TP90MZ" = "1" /* Removal of Stimulator Lead from Ureter, Open Approach */
"0TPB00Z" = "1" /* Removal of Drainage Device from Bladder, Open Approach */
"0TPB02Z" = "1" /* Removal of Monitoring Device from Bladder, Open Approach */
"0TPB03Z" = "1" /* Removal of Infusion Device from Bladder, Open Approach */
"0TPB07Z" = "1" /* Removal of Autologous Tissue Substitute from Bladder, Open Approach */
"0TPB0CZ" = "1" /* Removal of Extraluminal Device from Bladder, Open Approach */
"0TPB0DZ" = "1" /* Removal of Intraluminal Device from Bladder, Open Approach */
"0TPB0JZ" = "1" /* Removal of Synthetic Substitute from Bladder, Open Approach */
"0TPB0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Bladder, Open Approach */
"0TPB0LZ" = "1" /* Removal of Artificial Sphincter from Bladder, Open Approach */
"0TPB0MZ" = "1" /* Removal of Stimulator Lead from Bladder, Open Approach */
"0TQ00ZZ" = "1" /* Repair Right Kidney, Open Approach */
"0TQ10ZZ" = "1" /* Repair Left Kidney, Open Approach */
"0TQ30ZZ" = "1" /* Repair Right Kidney Pelvis, Open Approach */
"0TQ40ZZ" = "1" /* Repair Left Kidney Pelvis, Open Approach */
"0TQ60ZZ" = "1" /* Repair Right Ureter, Open Approach */
"0TQ70ZZ" = "1" /* Repair Left Ureter, Open Approach */
"0TQB0ZZ" = "1" /* Repair Bladder, Open Approach */
"0TR307Z" = "1" /* Replacement of Right Kidney Pelvis with Autologous Tissue Substitute, Open Approach */
"0TR30JZ" = "1" /* Replacement of Right Kidney Pelvis with Synthetic Substitute, Open Approach */
"0TR30KZ" = "1" /* Replacement of Right Kidney Pelvis with Nonautologous Tissue Substitute, Open Approach */
"0TR407Z" = "1" /* Replacement of Left Kidney Pelvis with Autologous Tissue Substitute, Open Approach */
"0TR40JZ" = "1" /* Replacement of Left Kidney Pelvis with Synthetic Substitute, Open Approach */
"0TR40KZ" = "1" /* Replacement of Left Kidney Pelvis with Nonautologous Tissue Substitute, Open Approach */
"0TR607Z" = "1" /* Replacement of Right Ureter with Autologous Tissue Substitute, Open Approach */
"0TR60JZ" = "1" /* Replacement of Right Ureter with Synthetic Substitute, Open Approach */
"0TR60KZ" = "1" /* Replacement of Right Ureter with Nonautologous Tissue Substitute, Open Approach */
"0TR707Z" = "1" /* Replacement of Left Ureter with Autologous Tissue Substitute, Open Approach */
"0TR70JZ" = "1" /* Replacement of Left Ureter with Synthetic Substitute, Open Approach */
"0TR70KZ" = "1" /* Replacement of Left Ureter with Nonautologous Tissue Substitute, Open Approach */
"0TRB07Z" = "1" /* Replacement of Bladder with Autologous Tissue Substitute, Open Approach */
"0TRB0JZ" = "1" /* Replacement of Bladder with Synthetic Substitute, Open Approach */
"0TRB0KZ" = "1" /* Replacement of Bladder with Nonautologous Tissue Substitute, Open Approach */
"0TRC07Z" = "1" /* Replacement of Bladder Neck with Autologous Tissue Substitute, Open Approach */
"0TRC0JZ" = "1" /* Replacement of Bladder Neck with Synthetic Substitute, Open Approach */
"0TRC0KZ" = "1" /* Replacement of Bladder Neck with Nonautologous Tissue Substitute, Open Approach */
"0TS00ZZ" = "1" /* Reposition Right Kidney, Open Approach */
"0TS10ZZ" = "1" /* Reposition Left Kidney, Open Approach */
"0TS20ZZ" = "1" /* Reposition Bilateral Kidneys, Open Approach */
"0TS30ZZ" = "1" /* Reposition Right Kidney Pelvis, Open Approach */
"0TS40ZZ" = "1" /* Reposition Left Kidney Pelvis, Open Approach */
"0TS60ZZ" = "1" /* Reposition Right Ureter, Open Approach */
"0TS70ZZ" = "1" /* Reposition Left Ureter, Open Approach */
"0TS80ZZ" = "1" /* Reposition Bilateral Ureters, Open Approach */
"0TSB0ZZ" = "1" /* Reposition Bladder, Open Approach */
"0TT00ZZ" = "1" /* Resection of Right Kidney, Open Approach */
"0TT10ZZ" = "1" /* Resection of Left Kidney, Open Approach */
"0TT20ZZ" = "1" /* Resection of Bilateral Kidneys, Open Approach */
"0TT30ZZ" = "1" /* Resection of Right Kidney Pelvis, Open Approach */
"0TT40ZZ" = "1" /* Resection of Left Kidney Pelvis, Open Approach */
"0TT60ZZ" = "1" /* Resection of Right Ureter, Open Approach */
"0TT70ZZ" = "1" /* Resection of Left Ureter, Open Approach */
"0TTB0ZZ" = "1" /* Resection of Bladder, Open Approach */
"0TTD0ZZ" = "1" /* Resection of Urethra, Open Approach */
"0TU307Z" = "1" /* Supplement Right Kidney Pelvis with Autologous Tissue Substitute, Open Approach */
"0TU30JZ" = "1" /* Supplement Right Kidney Pelvis with Synthetic Substitute, Open Approach */
"0TU30KZ" = "1" /* Supplement Right Kidney Pelvis with Nonautologous Tissue Substitute, Open Approach */
"0TU407Z" = "1" /* Supplement Left Kidney Pelvis with Autologous Tissue Substitute, Open Approach */
"0TU40JZ" = "1" /* Supplement Left Kidney Pelvis with Synthetic Substitute, Open Approach */
"0TU40KZ" = "1" /* Supplement Left Kidney Pelvis with Nonautologous Tissue Substitute, Open Approach */
"0TU607Z" = "1" /* Supplement Right Ureter with Autologous Tissue Substitute, Open Approach */
"0TU60JZ" = "1" /* Supplement Right Ureter with Synthetic Substitute, Open Approach */
"0TU60KZ" = "1" /* Supplement Right Ureter with Nonautologous Tissue Substitute, Open Approach */
"0TU707Z" = "1" /* Supplement Left Ureter with Autologous Tissue Substitute, Open Approach */
"0TU70JZ" = "1" /* Supplement Left Ureter with Synthetic Substitute, Open Approach */
"0TU70KZ" = "1" /* Supplement Left Ureter with Nonautologous Tissue Substitute, Open Approach */
"0TUB07Z" = "1" /* Supplement Bladder with Autologous Tissue Substitute, Open Approach */
"0TUB0JZ" = "1" /* Supplement Bladder with Synthetic Substitute, Open Approach */
"0TUB0KZ" = "1" /* Supplement Bladder with Nonautologous Tissue Substitute, Open Approach */
"0TV30CZ" = "1" /* Restriction of Right Kidney Pelvis with Extraluminal Device, Open Approach */
"0TV30DZ" = "1" /* Restriction of Right Kidney Pelvis with Intraluminal Device, Open Approach */
"0TV30ZZ" = "1" /* Restriction of Right Kidney Pelvis, Open Approach */
"0TV40CZ" = "1" /* Restriction of Left Kidney Pelvis with Extraluminal Device, Open Approach */
"0TV40DZ" = "1" /* Restriction of Left Kidney Pelvis with Intraluminal Device, Open Approach */
"0TV40ZZ" = "1" /* Restriction of Left Kidney Pelvis, Open Approach */
"0TV60CZ" = "1" /* Restriction of Right Ureter with Extraluminal Device, Open Approach */
"0TV60DZ" = "1" /* Restriction of Right Ureter with Intraluminal Device, Open Approach */
"0TV60ZZ" = "1" /* Restriction of Right Ureter, Open Approach */
"0TV70CZ" = "1" /* Restriction of Left Ureter with Extraluminal Device, Open Approach */
"0TV70DZ" = "1" /* Restriction of Left Ureter with Intraluminal Device, Open Approach */
"0TV70ZZ" = "1" /* Restriction of Left Ureter, Open Approach */
"0TVB0CZ" = "1" /* Restriction of Bladder with Extraluminal Device, Open Approach */
"0TVB0DZ" = "1" /* Restriction of Bladder with Intraluminal Device, Open Approach */
"0TVB0ZZ" = "1" /* Restriction of Bladder, Open Approach */
"0TW500Z" = "1" /* Revision of Drainage Device in Kidney, Open Approach */
"0TW502Z" = "1" /* Revision of Monitoring Device in Kidney, Open Approach */
"0TW503Z" = "1" /* Revision of Infusion Device in Kidney, Open Approach */
"0TW507Z" = "1" /* Revision of Autologous Tissue Substitute in Kidney, Open Approach */
"0TW50CZ" = "1" /* Revision of Extraluminal Device in Kidney, Open Approach */
"0TW50DZ" = "1" /* Revision of Intraluminal Device in Kidney, Open Approach */
"0TW50JZ" = "1" /* Revision of Synthetic Substitute in Kidney, Open Approach */
"0TW50KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Kidney, Open Approach */
"0TW900Z" = "1" /* Revision of Drainage Device in Ureter, Open Approach */
"0TW902Z" = "1" /* Revision of Monitoring Device in Ureter, Open Approach */
"0TW903Z" = "1" /* Revision of Infusion Device in Ureter, Open Approach */
"0TW907Z" = "1" /* Revision of Autologous Tissue Substitute in Ureter, Open Approach */
"0TW90CZ" = "1" /* Revision of Extraluminal Device in Ureter, Open Approach */
"0TW90DZ" = "1" /* Revision of Intraluminal Device in Ureter, Open Approach */
"0TW90JZ" = "1" /* Revision of Synthetic Substitute in Ureter, Open Approach */
"0TW90KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Ureter, Open Approach */
"0TW90MZ" = "1" /* Revision of Stimulator Lead in Ureter, Open Approach */
"0TWB00Z" = "1" /* Revision of Drainage Device in Bladder, Open Approach */
"0TWB02Z" = "1" /* Revision of Monitoring Device in Bladder, Open Approach */
"0TWB03Z" = "1" /* Revision of Infusion Device in Bladder, Open Approach */
"0TWB07Z" = "1" /* Revision of Autologous Tissue Substitute in Bladder, Open Approach */
"0TWB0CZ" = "1" /* Revision of Extraluminal Device in Bladder, Open Approach */
"0TWB0DZ" = "1" /* Revision of Intraluminal Device in Bladder, Open Approach */
"0TWB0JZ" = "1" /* Revision of Synthetic Substitute in Bladder, Open Approach */
"0TWB0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Bladder, Open Approach */
"0TWB0LZ" = "1" /* Revision of Artificial Sphincter in Bladder, Open Approach */
"0TWB0MZ" = "1" /* Revision of Stimulator Lead in Bladder, Open Approach */
"0TY00Z0" = "1" /* Transplantation of Right Kidney, Allogeneic, Open Approach */
"0TY00Z1" = "1" /* Transplantation of Right Kidney, Syngeneic, Open Approach */
"0TY00Z2" = "1" /* Transplantation of Right Kidney, Zooplastic, Open Approach */
"0TY10Z0" = "1" /* Transplantation of Left Kidney, Allogeneic, Open Approach */
"0TY10Z1" = "1" /* Transplantation of Left Kidney, Syngeneic, Open Approach */
"0TY10Z2" = "1" /* Transplantation of Left Kidney, Zooplastic, Open Approach */
"0U15075" = "1" /* Bypass Right Fallopian Tube to Right Fallopian Tube with Autologous Tissue Substitute, Open Approach */
"0U15076" = "1" /* Bypass Right Fallopian Tube to Left Fallopian Tube with Autologous Tissue Substitute, Open Approach */
"0U15079" = "1" /* Bypass Right Fallopian Tube to Uterus with Autologous Tissue Substitute, Open Approach */
"0U150J5" = "1" /* Bypass Right Fallopian Tube to Right Fallopian Tube with Synthetic Substitute, Open Approach */
"0U150J6" = "1" /* Bypass Right Fallopian Tube to Left Fallopian Tube with Synthetic Substitute, Open Approach */
"0U150J9" = "1" /* Bypass Right Fallopian Tube to Uterus with Synthetic Substitute, Open Approach */
"0U150K5" = "1" /* Bypass Right Fallopian Tube to Right Fallopian Tube with Nonautologous Tissue Substitute, Open Approach */
"0U150K6" = "1" /* Bypass Right Fallopian Tube to Left Fallopian Tube with Nonautologous Tissue Substitute, Open Approach */
"0U150K9" = "1" /* Bypass Right Fallopian Tube to Uterus with Nonautologous Tissue Substitute, Open Approach */
"0U150Z5" = "1" /* Bypass Right Fallopian Tube to Right Fallopian Tube, Open Approach */
"0U150Z6" = "1" /* Bypass Right Fallopian Tube to Left Fallopian Tube, Open Approach */
"0U150Z9" = "1" /* Bypass Right Fallopian Tube to Uterus, Open Approach */
"0U16075" = "1" /* Bypass Left Fallopian Tube to Right Fallopian Tube with Autologous Tissue Substitute, Open Approach */
"0U16076" = "1" /* Bypass Left Fallopian Tube to Left Fallopian Tube with Autologous Tissue Substitute, Open Approach */
"0U16079" = "1" /* Bypass Left Fallopian Tube to Uterus with Autologous Tissue Substitute, Open Approach */
"0U160J5" = "1" /* Bypass Left Fallopian Tube to Right Fallopian Tube with Synthetic Substitute, Open Approach */
"0U160J6" = "1" /* Bypass Left Fallopian Tube to Left Fallopian Tube with Synthetic Substitute, Open Approach */
"0U160J9" = "1" /* Bypass Left Fallopian Tube to Uterus with Synthetic Substitute, Open Approach */
"0U160K5" = "1" /* Bypass Left Fallopian Tube to Right Fallopian Tube with Nonautologous Tissue Substitute, Open Approach */
"0U160K6" = "1" /* Bypass Left Fallopian Tube to Left Fallopian Tube with Nonautologous Tissue Substitute, Open Approach */
"0U160K9" = "1" /* Bypass Left Fallopian Tube to Uterus with Nonautologous Tissue Substitute, Open Approach */
"0U160Z5" = "1" /* Bypass Left Fallopian Tube to Right Fallopian Tube, Open Approach */
"0U160Z6" = "1" /* Bypass Left Fallopian Tube to Left Fallopian Tube, Open Approach */
"0U160Z9" = "1" /* Bypass Left Fallopian Tube to Uterus, Open Approach */
"0U500ZZ" = "1" /* Destruction of Right Ovary, Open Approach */
"0U510ZZ" = "1" /* Destruction of Left Ovary, Open Approach */
"0U520ZZ" = "1" /* Destruction of Bilateral Ovaries, Open Approach */
"0U540ZZ" = "1" /* Destruction of Uterine Supporting Structure, Open Approach */
"0U550ZZ" = "1" /* Destruction of Right Fallopian Tube, Open Approach */
"0U560ZZ" = "1" /* Destruction of Left Fallopian Tube, Open Approach */
"0U570ZZ" = "1" /* Destruction of Bilateral Fallopian Tubes, Open Approach */
"0U590ZZ" = "1" /* Destruction of Uterus, Open Approach */
"0U5B0ZZ" = "1" /* Destruction of Endometrium, Open Approach */
"0U5C0ZZ" = "1" /* Destruction of Cervix, Open Approach */
"0U750DZ" = "1" /* Dilation of Right Fallopian Tube with Intraluminal Device, Open Approach */
"0U750ZZ" = "1" /* Dilation of Right Fallopian Tube, Open Approach */
"0U760DZ" = "1" /* Dilation of Left Fallopian Tube with Intraluminal Device, Open Approach */
"0U760ZZ" = "1" /* Dilation of Left Fallopian Tube, Open Approach */
"0U770DZ" = "1" /* Dilation of Bilateral Fallopian Tubes with Intraluminal Device, Open Approach */
"0U770ZZ" = "1" /* Dilation of Bilateral Fallopian Tubes, Open Approach */
"0U790DZ" = "1" /* Dilation of Uterus with Intraluminal Device, Open Approach */
"0U790ZZ" = "1" /* Dilation of Uterus, Open Approach */
"0U7C0DZ" = "1" /* Dilation of Cervix with Intraluminal Device, Open Approach */
"0U7C0ZZ" = "1" /* Dilation of Cervix, Open Approach */
"0U800ZZ" = "1" /* Division of Right Ovary, Open Approach */
"0U810ZZ" = "1" /* Division of Left Ovary, Open Approach */
"0U820ZZ" = "1" /* Division of Bilateral Ovaries, Open Approach */
"0U840ZZ" = "1" /* Division of Uterine Supporting Structure, Open Approach */
"0U9000Z" = "1" /* Drainage of Right Ovary with Drainage Device, Open Approach */
"0U900ZX" = "1" /* Drainage of Right Ovary, Open Approach, Diagnostic */
"0U900ZZ" = "1" /* Drainage of Right Ovary, Open Approach */
"0U9100Z" = "1" /* Drainage of Left Ovary with Drainage Device, Open Approach */
"0U910ZX" = "1" /* Drainage of Left Ovary, Open Approach, Diagnostic */
"0U910ZZ" = "1" /* Drainage of Left Ovary, Open Approach */
"0U9200Z" = "1" /* Drainage of Bilateral Ovaries with Drainage Device, Open Approach */
"0U920ZX" = "1" /* Drainage of Bilateral Ovaries, Open Approach, Diagnostic */
"0U920ZZ" = "1" /* Drainage of Bilateral Ovaries, Open Approach */
"0U9400Z" = "1" /* Drainage of Uterine Supporting Structure with Drainage Device, Open Approach */
"0U940ZX" = "1" /* Drainage of Uterine Supporting Structure, Open Approach, Diagnostic */
"0U940ZZ" = "1" /* Drainage of Uterine Supporting Structure, Open Approach */
"0U9500Z" = "1" /* Drainage of Right Fallopian Tube with Drainage Device, Open Approach */
"0U950ZX" = "1" /* Drainage of Right Fallopian Tube, Open Approach, Diagnostic */
"0U950ZZ" = "1" /* Drainage of Right Fallopian Tube, Open Approach */
"0U9600Z" = "1" /* Drainage of Left Fallopian Tube with Drainage Device, Open Approach */
"0U960ZX" = "1" /* Drainage of Left Fallopian Tube, Open Approach, Diagnostic */
"0U960ZZ" = "1" /* Drainage of Left Fallopian Tube, Open Approach */
"0U9700Z" = "1" /* Drainage of Bilateral Fallopian Tubes with Drainage Device, Open Approach */
"0U970ZX" = "1" /* Drainage of Bilateral Fallopian Tubes, Open Approach, Diagnostic */
"0U970ZZ" = "1" /* Drainage of Bilateral Fallopian Tubes, Open Approach */
"0U9900Z" = "1" /* Drainage of Uterus with Drainage Device, Open Approach */
"0U990ZX" = "1" /* Drainage of Uterus, Open Approach, Diagnostic */
"0U990ZZ" = "1" /* Drainage of Uterus, Open Approach */
"0U9C00Z" = "1" /* Drainage of Cervix with Drainage Device, Open Approach */
"0U9C0ZX" = "1" /* Drainage of Cervix, Open Approach, Diagnostic */
"0U9C0ZZ" = "1" /* Drainage of Cervix, Open Approach */
"0UB00ZX" = "1" /* Excision of Right Ovary, Open Approach, Diagnostic */
"0UB00ZZ" = "1" /* Excision of Right Ovary, Open Approach */
"0UB10ZX" = "1" /* Excision of Left Ovary, Open Approach, Diagnostic */
"0UB10ZZ" = "1" /* Excision of Left Ovary, Open Approach */
"0UB20ZX" = "1" /* Excision of Bilateral Ovaries, Open Approach, Diagnostic */
"0UB20ZZ" = "1" /* Excision of Bilateral Ovaries, Open Approach */
"0UB40ZX" = "1" /* Excision of Uterine Supporting Structure, Open Approach, Diagnostic */
"0UB40ZZ" = "1" /* Excision of Uterine Supporting Structure, Open Approach */
"0UB50ZX" = "1" /* Excision of Right Fallopian Tube, Open Approach, Diagnostic */
"0UB50ZZ" = "1" /* Excision of Right Fallopian Tube, Open Approach */
"0UB60ZX" = "1" /* Excision of Left Fallopian Tube, Open Approach, Diagnostic */
"0UB60ZZ" = "1" /* Excision of Left Fallopian Tube, Open Approach */
"0UB70ZX" = "1" /* Excision of Bilateral Fallopian Tubes, Open Approach, Diagnostic */
"0UB70ZZ" = "1" /* Excision of Bilateral Fallopian Tubes, Open Approach */
"0UB90ZX" = "1" /* Excision of Uterus, Open Approach, Diagnostic */
"0UB90ZZ" = "1" /* Excision of Uterus, Open Approach */
"0UBC0ZX" = "1" /* Excision of Cervix, Open Approach, Diagnostic */
"0UBC0ZZ" = "1" /* Excision of Cervix, Open Approach */
"0UC00ZZ" = "1" /* Extirpation of Matter from Right Ovary, Open Approach */
"0UC10ZZ" = "1" /* Extirpation of Matter from Left Ovary, Open Approach */
"0UC20ZZ" = "1" /* Extirpation of Matter from Bilateral Ovaries, Open Approach */
"0UC40ZZ" = "1" /* Extirpation of Matter from Uterine Supporting Structure, Open Approach */
"0UC50ZZ" = "1" /* Extirpation of Matter from Right Fallopian Tube, Open Approach */
"0UC60ZZ" = "1" /* Extirpation of Matter from Left Fallopian Tube, Open Approach */
"0UC70ZZ" = "1" /* Extirpation of Matter from Bilateral Fallopian Tubes, Open Approach */
"0UC90ZZ" = "1" /* Extirpation of Matter from Uterus, Open Approach */
"0UCB0ZZ" = "1" /* Extirpation of Matter from Endometrium, Open Approach */
"0UCC0ZZ" = "1" /* Extirpation of Matter from Cervix, Open Approach */
"0UF50ZZ" = "1" /* Fragmentation in Right Fallopian Tube, Open Approach */
"0UF60ZZ" = "1" /* Fragmentation in Left Fallopian Tube, Open Approach */
"0UF70ZZ" = "1" /* Fragmentation in Bilateral Fallopian Tubes, Open Approach */
"0UF90ZZ" = "1" /* Fragmentation in Uterus, Open Approach */
"0UH303Z" = "1" /* Insertion of Infusion Device into Ovary, Open Approach */
"0UH803Z" = "1" /* Insertion of Infusion Device into Fallopian Tube, Open Approach */
"0UHC01Z" = "1" /* Insertion of Radioactive Element into Cervix, Open Approach */
"0UHD03Z" = "1" /* Insertion of Infusion Device into Uterus and Cervix, Open Approach */
"0UJ30ZZ" = "1" /* Inspection of Ovary, Open Approach */
"0UJ80ZZ" = "1" /* Inspection of Fallopian Tube, Open Approach */
"0UJD0ZZ" = "1" /* Inspection of Uterus and Cervix, Open Approach */
"0UL50CZ" = "1" /* Occlusion of Right Fallopian Tube with Extraluminal Device, Open Approach */
"0UL50DZ" = "1" /* Occlusion of Right Fallopian Tube with Intraluminal Device, Open Approach */
"0UL50ZZ" = "1" /* Occlusion of Right Fallopian Tube, Open Approach */
"0UL60CZ" = "1" /* Occlusion of Left Fallopian Tube with Extraluminal Device, Open Approach */
"0UL60DZ" = "1" /* Occlusion of Left Fallopian Tube with Intraluminal Device, Open Approach */
"0UL60ZZ" = "1" /* Occlusion of Left Fallopian Tube, Open Approach */
"0UL70CZ" = "1" /* Occlusion of Bilateral Fallopian Tubes with Extraluminal Device, Open Approach */
"0UL70DZ" = "1" /* Occlusion of Bilateral Fallopian Tubes with Intraluminal Device, Open Approach */
"0UL70ZZ" = "1" /* Occlusion of Bilateral Fallopian Tubes, Open Approach */
"0UM00ZZ" = "1" /* Reattachment of Right Ovary, Open Approach */
"0UM10ZZ" = "1" /* Reattachment of Left Ovary, Open Approach */
"0UM20ZZ" = "1" /* Reattachment of Bilateral Ovaries, Open Approach */
"0UM40ZZ" = "1" /* Reattachment of Uterine Supporting Structure, Open Approach */
"0UM50ZZ" = "1" /* Reattachment of Right Fallopian Tube, Open Approach */
"0UM60ZZ" = "1" /* Reattachment of Left Fallopian Tube, Open Approach */
"0UM70ZZ" = "1" /* Reattachment of Bilateral Fallopian Tubes, Open Approach */
"0UM90ZZ" = "1" /* Reattachment of Uterus, Open Approach */
"0UMC0ZZ" = "1" /* Reattachment of Cervix, Open Approach */
"0UN00ZZ" = "1" /* Release Right Ovary, Open Approach */
"0UN10ZZ" = "1" /* Release Left Ovary, Open Approach */
"0UN20ZZ" = "1" /* Release Bilateral Ovaries, Open Approach */
"0UN40ZZ" = "1" /* Release Uterine Supporting Structure, Open Approach */
"0UN50ZZ" = "1" /* Release Right Fallopian Tube, Open Approach */
"0UN60ZZ" = "1" /* Release Left Fallopian Tube, Open Approach */
"0UN70ZZ" = "1" /* Release Bilateral Fallopian Tubes, Open Approach */
"0UN90ZZ" = "1" /* Release Uterus, Open Approach */
"0UNC0ZZ" = "1" /* Release Cervix, Open Approach */
"0UP300Z" = "1" /* Removal of Drainage Device from Ovary, Open Approach */
"0UP303Z" = "1" /* Removal of Infusion Device from Ovary, Open Approach */
"0UP800Z" = "1" /* Removal of Drainage Device from Fallopian Tube, Open Approach */
"0UP803Z" = "1" /* Removal of Infusion Device from Fallopian Tube, Open Approach */
"0UP807Z" = "1" /* Removal of Autologous Tissue Substitute from Fallopian Tube, Open Approach */
"0UP80CZ" = "1" /* Removal of Extraluminal Device from Fallopian Tube, Open Approach */
"0UP80DZ" = "1" /* Removal of Intraluminal Device from Fallopian Tube, Open Approach */
"0UP80JZ" = "1" /* Removal of Synthetic Substitute from Fallopian Tube, Open Approach */
"0UP80KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Fallopian Tube, Open Approach */
"0UPD00Z" = "1" /* Removal of Drainage Device from Uterus and Cervix, Open Approach */
"0UPD01Z" = "1" /* Removal of Radioactive Element from Uterus and Cervix, Open Approach */
"0UPD03Z" = "1" /* Removal of Infusion Device from Uterus and Cervix, Open Approach */
"0UPD07Z" = "1" /* Removal of Autologous Tissue Substitute from Uterus and Cervix, Open Approach */
"0UPD0CZ" = "1" /* Removal of Extraluminal Device from Uterus and Cervix, Open Approach */
"0UPD0DZ" = "1" /* Removal of Intraluminal Device from Uterus and Cervix, Open Approach */
"0UPD0HZ" = "1" /* Removal of Contraceptive Device from Uterus and Cervix, Open Approach */
"0UPD0JZ" = "1" /* Removal of Synthetic Substitute from Uterus and Cervix, Open Approach */
"0UPD0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Uterus and Cervix, Open Approach */
"0UQ00ZZ" = "1" /* Repair Right Ovary, Open Approach */
"0UQ10ZZ" = "1" /* Repair Left Ovary, Open Approach */
"0UQ20ZZ" = "1" /* Repair Bilateral Ovaries, Open Approach */
"0UQ40ZZ" = "1" /* Repair Uterine Supporting Structure, Open Approach */
"0UQ50ZZ" = "1" /* Repair Right Fallopian Tube, Open Approach */
"0UQ60ZZ" = "1" /* Repair Left Fallopian Tube, Open Approach */
"0UQ70ZZ" = "1" /* Repair Bilateral Fallopian Tubes, Open Approach */
"0UQ90ZZ" = "1" /* Repair Uterus, Open Approach */
"0UQC0ZZ" = "1" /* Repair Cervix, Open Approach */
"0UQG0ZZ" = "1" /* Repair Vagina, Open Approach */
"0US00ZZ" = "1" /* Reposition Right Ovary, Open Approach */
"0US10ZZ" = "1" /* Reposition Left Ovary, Open Approach */
"0US20ZZ" = "1" /* Reposition Bilateral Ovaries, Open Approach */
"0US40ZZ" = "1" /* Reposition Uterine Supporting Structure, Open Approach */
"0US50ZZ" = "1" /* Reposition Right Fallopian Tube, Open Approach */
"0US60ZZ" = "1" /* Reposition Left Fallopian Tube, Open Approach */
"0US70ZZ" = "1" /* Reposition Bilateral Fallopian Tubes, Open Approach */
"0US90ZZ" = "1" /* Reposition Uterus, Open Approach */
"0USC0ZZ" = "1" /* Reposition Cervix, Open Approach */
"0UT00ZZ" = "1" /* Resection of Right Ovary, Open Approach */
"0UT10ZZ" = "1" /* Resection of Left Ovary, Open Approach */
"0UT20ZZ" = "1" /* Resection of Bilateral Ovaries, Open Approach */
"0UT40ZZ" = "1" /* Resection of Uterine Supporting Structure, Open Approach */
"0UT50ZZ" = "1" /* Resection of Right Fallopian Tube, Open Approach */
"0UT60ZZ" = "1" /* Resection of Left Fallopian Tube, Open Approach */
"0UT70ZZ" = "1" /* Resection of Bilateral Fallopian Tubes, Open Approach */
"0UT90ZZ" = "1" /* Resection of Uterus, Open Approach */
"0UTC0ZZ" = "1" /* Resection of Cervix, Open Approach */
"0UTG0ZZ" = "1" /* Resection of Vagina, Open Approach */
"0UU407Z" = "1" /* Supplement Uterine Supporting Structure with Autologous Tissue Substitute, Open Approach */
"0UU40JZ" = "1" /* Supplement Uterine Supporting Structure with Synthetic Substitute, Open Approach */
"0UU40KZ" = "1" /* Supplement Uterine Supporting Structure with Nonautologous Tissue Substitute, Open Approach */
"0UU507Z" = "1" /* Supplement Right Fallopian Tube with Autologous Tissue Substitute, Open Approach */
"0UU50JZ" = "1" /* Supplement Right Fallopian Tube with Synthetic Substitute, Open Approach */
"0UU50KZ" = "1" /* Supplement Right Fallopian Tube with Nonautologous Tissue Substitute, Open Approach */
"0UU607Z" = "1" /* Supplement Left Fallopian Tube with Autologous Tissue Substitute, Open Approach */
"0UU60JZ" = "1" /* Supplement Left Fallopian Tube with Synthetic Substitute, Open Approach */
"0UU60KZ" = "1" /* Supplement Left Fallopian Tube with Nonautologous Tissue Substitute, Open Approach */
"0UU707Z" = "1" /* Supplement Bilateral Fallopian Tubes with Autologous Tissue Substitute, Open Approach */
"0UU70JZ" = "1" /* Supplement Bilateral Fallopian Tubes with Synthetic Substitute, Open Approach */
"0UU70KZ" = "1" /* Supplement Bilateral Fallopian Tubes with Nonautologous Tissue Substitute, Open Approach */
"0UVC0CZ" = "1" /* Restriction of Cervix with Extraluminal Device, Open Approach */
"0UVC0DZ" = "1" /* Restriction of Cervix with Intraluminal Device, Open Approach */
"0UVC0ZZ" = "1" /* Restriction of Cervix, Open Approach */
"0UW300Z" = "1" /* Revision of Drainage Device in Ovary, Open Approach */
"0UW303Z" = "1" /* Revision of Infusion Device in Ovary, Open Approach */
"0UW800Z" = "1" /* Revision of Drainage Device in Fallopian Tube, Open Approach */
"0UW803Z" = "1" /* Revision of Infusion Device in Fallopian Tube, Open Approach */
"0UW807Z" = "1" /* Revision of Autologous Tissue Substitute in Fallopian Tube, Open Approach */
"0UW80CZ" = "1" /* Revision of Extraluminal Device in Fallopian Tube, Open Approach */
"0UW80DZ" = "1" /* Revision of Intraluminal Device in Fallopian Tube, Open Approach */
"0UW80JZ" = "1" /* Revision of Synthetic Substitute in Fallopian Tube, Open Approach */
"0UW80KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Fallopian Tube, Open Approach */
"0UWD00Z" = "1" /* Revision of Drainage Device in Uterus and Cervix, Open Approach */
"0UWD01Z" = "1" /* Revision of Radioactive Element in Uterus and Cervix, Open Approach */
"0UWD03Z" = "1" /* Revision of Infusion Device in Uterus and Cervix, Open Approach */
"0UWD07Z" = "1" /* Revision of Autologous Tissue Substitute in Uterus and Cervix, Open Approach */
"0UWD0CZ" = "1" /* Revision of Extraluminal Device in Uterus and Cervix, Open Approach */
"0UWD0DZ" = "1" /* Revision of Intraluminal Device in Uterus and Cervix, Open Approach */
"0UWD0HZ" = "1" /* Revision of Contraceptive Device in Uterus and Cervix, Open Approach */
"0UWD0JZ" = "1" /* Revision of Synthetic Substitute in Uterus and Cervix, Open Approach */
"0UWD0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Uterus and Cervix, Open Approach */
"0UY00Z0" = "1" /* Transplantation of Right Ovary, Allogeneic, Open Approach */
"0UY00Z1" = "1" /* Transplantation of Right Ovary, Syngeneic, Open Approach */
"0UY00Z2" = "1" /* Transplantation of Right Ovary, Zooplastic, Open Approach */
"0UY10Z0" = "1" /* Transplantation of Left Ovary, Allogeneic, Open Approach */
"0UY10Z1" = "1" /* Transplantation of Left Ovary, Syngeneic, Open Approach */
"0UY10Z2" = "1" /* Transplantation of Left Ovary, Zooplastic, Open Approach */
"0V500ZZ" = "1" /* Destruction of Prostate, Open Approach */
"0V510ZZ" = "1" /* Destruction of Right Seminal Vesicle, Open Approach */
"0V520ZZ" = "1" /* Destruction of Left Seminal Vesicle, Open Approach */
"0V530ZZ" = "1" /* Destruction of Bilateral Seminal Vesicles, Open Approach */
"0V9000Z" = "1" /* Drainage of Prostate with Drainage Device, Open Approach */
"0V900ZX" = "1" /* Drainage of Prostate, Open Approach, Diagnostic */
"0V900ZZ" = "1" /* Drainage of Prostate, Open Approach */
"0V9100Z" = "1" /* Drainage of Right Seminal Vesicle with Drainage Device, Open Approach */
"0V910ZX" = "1" /* Drainage of Right Seminal Vesicle, Open Approach, Diagnostic */
"0V910ZZ" = "1" /* Drainage of Right Seminal Vesicle, Open Approach */
"0V9200Z" = "1" /* Drainage of Left Seminal Vesicle with Drainage Device, Open Approach */
"0V920ZX" = "1" /* Drainage of Left Seminal Vesicle, Open Approach, Diagnostic */
"0V920ZZ" = "1" /* Drainage of Left Seminal Vesicle, Open Approach */
"0V9300Z" = "1" /* Drainage of Bilateral Seminal Vesicles with Drainage Device, Open Approach */
"0V930ZX" = "1" /* Drainage of Bilateral Seminal Vesicles, Open Approach, Diagnostic */
"0V930ZZ" = "1" /* Drainage of Bilateral Seminal Vesicles, Open Approach */
"0VB00ZX" = "1" /* Excision of Prostate, Open Approach, Diagnostic */
"0VB00ZZ" = "1" /* Excision of Prostate, Open Approach */
"0VB10ZX" = "1" /* Excision of Right Seminal Vesicle, Open Approach, Diagnostic */
"0VB10ZZ" = "1" /* Excision of Right Seminal Vesicle, Open Approach */
"0VB20ZX" = "1" /* Excision of Left Seminal Vesicle, Open Approach, Diagnostic */
"0VB20ZZ" = "1" /* Excision of Left Seminal Vesicle, Open Approach */
"0VB30ZX" = "1" /* Excision of Bilateral Seminal Vesicles, Open Approach, Diagnostic */
"0VB30ZZ" = "1" /* Excision of Bilateral Seminal Vesicles, Open Approach */
"0VC00ZZ" = "1" /* Extirpation of Matter from Prostate, Open Approach */
"0VC10ZZ" = "1" /* Extirpation of Matter from Right Seminal Vesicle, Open Approach */
"0VC20ZZ" = "1" /* Extirpation of Matter from Left Seminal Vesicle, Open Approach */
"0VC30ZZ" = "1" /* Extirpation of Matter from Bilateral Seminal Vesicles, Open Approach */
"0VH001Z" = "1" /* Insertion of Radioactive Element into Prostate, Open Approach */
"0VH403Z" = "1" /* Insertion of Infusion Device into Prostate and Seminal Vesicles, Open Approach */
"0VJ40ZZ" = "1" /* Inspection of Prostate and Seminal Vesicles, Open Approach */
"0VN00ZZ" = "1" /* Release Prostate, Open Approach */
"0VN10ZZ" = "1" /* Release Right Seminal Vesicle, Open Approach */
"0VN20ZZ" = "1" /* Release Left Seminal Vesicle, Open Approach */
"0VN30ZZ" = "1" /* Release Bilateral Seminal Vesicles, Open Approach */
"0VP400Z" = "1" /* Removal of Drainage Device from Prostate and Seminal Vesicles, Open Approach */
"0VP401Z" = "1" /* Removal of Radioactive Element from Prostate and Seminal Vesicles, Open Approach */
"0VP403Z" = "1" /* Removal of Infusion Device from Prostate and Seminal Vesicles, Open Approach */
"0VP407Z" = "1" /* Removal of Autologous Tissue Substitute from Prostate and Seminal Vesicles, Open Approach */
"0VP40JZ" = "1" /* Removal of Synthetic Substitute from Prostate and Seminal Vesicles, Open Approach */
"0VP40KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Prostate and Seminal Vesicles, Open Approach */
"0VQ00ZZ" = "1" /* Repair Prostate, Open Approach */
"0VQ10ZZ" = "1" /* Repair Right Seminal Vesicle, Open Approach */
"0VQ20ZZ" = "1" /* Repair Left Seminal Vesicle, Open Approach */
"0VQ30ZZ" = "1" /* Repair Bilateral Seminal Vesicles, Open Approach */
"0VT00ZZ" = "1" /* Resection of Prostate, Open Approach */
"0VT10ZZ" = "1" /* Resection of Right Seminal Vesicle, Open Approach */
"0VT20ZZ" = "1" /* Resection of Left Seminal Vesicle, Open Approach */
"0VT30ZZ" = "1" /* Resection of Bilateral Seminal Vesicles, Open Approach */
"0VU107Z" = "1" /* Supplement Right Seminal Vesicle with Autologous Tissue Substitute, Open Approach */
"0VU10JZ" = "1" /* Supplement Right Seminal Vesicle with Synthetic Substitute, Open Approach */
"0VU10KZ" = "1" /* Supplement Right Seminal Vesicle with Nonautologous Tissue Substitute, Open Approach */
"0VU207Z" = "1" /* Supplement Left Seminal Vesicle with Autologous Tissue Substitute, Open Approach */
"0VU20JZ" = "1" /* Supplement Left Seminal Vesicle with Synthetic Substitute, Open Approach */
"0VU20KZ" = "1" /* Supplement Left Seminal Vesicle with Nonautologous Tissue Substitute, Open Approach */
"0VU307Z" = "1" /* Supplement Bilateral Seminal Vesicles with Autologous Tissue Substitute, Open Approach */
"0VU30JZ" = "1" /* Supplement Bilateral Seminal Vesicles with Synthetic Substitute, Open Approach */
"0VU30KZ" = "1" /* Supplement Bilateral Seminal Vesicles with Nonautologous Tissue Substitute, Open Approach */
"0VW400Z" = "1" /* Revision of Drainage Device in Prostate and Seminal Vesicles, Open Approach */
"0VW403Z" = "1" /* Revision of Infusion Device in Prostate and Seminal Vesicles, Open Approach */
"0VW407Z" = "1" /* Revision of Autologous Tissue Substitute in Prostate and Seminal Vesicles, Open Approach */
"0VW40JZ" = "1" /* Revision of Synthetic Substitute in Prostate and Seminal Vesicles, Open Approach */
"0VW40KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Prostate and Seminal Vesicles, Open Approach */
"0W0F07Z" = "1" /* Alteration of Abdominal Wall with Autologous Tissue Substitute, Open Approach */
"0W0F0JZ" = "1" /* Alteration of Abdominal Wall with Synthetic Substitute, Open Approach */
"0W0F0KZ" = "1" /* Alteration of Abdominal Wall with Nonautologous Tissue Substitute, Open Approach */
"0W0F0ZZ" = "1" /* Alteration of Abdominal Wall, Open Approach */
"0W1G0J4" = "1" /* Bypass Peritoneal Cavity to Cutaneous with Synthetic Substitute, Open Approach */
"0W1G0J9" = "1" /* Bypass Peritoneal Cavity to Right Pleural Cavity with Synthetic Substitute, Open Approach */
"0W1G0JB" = "1" /* Bypass Peritoneal Cavity to Left Pleural Cavity with Synthetic Substitute, Open Approach */
"0W1G0JG" = "1" /* Bypass Peritoneal Cavity to Peritoneal Cavity with Synthetic Substitute, Open Approach */
"0W1G0JJ" = "1" /* Bypass Peritoneal Cavity to Pelvic Cavity with Synthetic Substitute, Open Approach */
"0W1G0JY" = "1" /* Bypass Peritoneal Cavity to Lower Vein with Synthetic Substitute, Open Approach */
"0W1J0J4" = "1" /* Bypass Pelvic Cavity to Cutaneous with Synthetic Substitute, Open Approach */
"0W1J0J9" = "1" /* Bypass Pelvic Cavity to Right Pleural Cavity with Synthetic Substitute, Open Approach */
"0W1J0JB" = "1" /* Bypass Pelvic Cavity to Left Pleural Cavity with Synthetic Substitute, Open Approach */
"0W1J0JG" = "1" /* Bypass Pelvic Cavity to Peritoneal Cavity with Synthetic Substitute, Open Approach */
"0W1J0JJ" = "1" /* Bypass Pelvic Cavity to Pelvic Cavity with Synthetic Substitute, Open Approach */
"0W1J0JY" = "1" /* Bypass Pelvic Cavity to Lower Vein with Synthetic Substitute, Open Approach */
"0W3F0ZZ" = "1" /* Control Bleeding in Abdominal Wall, Open Approach */
"0W3G0ZZ" = "1" /* Control Bleeding in Peritoneal Cavity, Open Approach */
"0W3H0ZZ" = "1" /* Control Bleeding in Retroperitoneum, Open Approach */
"0W3J0ZZ" = "1" /* Control Bleeding in Pelvic Cavity, Open Approach */
"0W3P0ZZ" = "1" /* Control Bleeding in Gastrointestinal Tract, Open Approach */
"0W3R0ZZ" = "1" /* Control Bleeding in Genitourinary Tract, Open Approach */
"0W9F00Z" = "1" /* Drainage of Abdominal Wall with Drainage Device, Open Approach */
"0W9F0ZX" = "1" /* Drainage of Abdominal Wall, Open Approach, Diagnostic */
"0W9F0ZZ" = "1" /* Drainage of Abdominal Wall, Open Approach */
"0W9G00Z" = "1" /* Drainage of Peritoneal Cavity with Drainage Device, Open Approach */
"0W9G0ZX" = "1" /* Drainage of Peritoneal Cavity, Open Approach, Diagnostic */
"0W9G0ZZ" = "1" /* Drainage of Peritoneal Cavity, Open Approach */
"0W9H00Z" = "1" /* Drainage of Retroperitoneum with Drainage Device, Open Approach */
"0W9H0ZX" = "1" /* Drainage of Retroperitoneum, Open Approach, Diagnostic */
"0W9H0ZZ" = "1" /* Drainage of Retroperitoneum, Open Approach */
"0W9J00Z" = "1" /* Drainage of Pelvic Cavity with Drainage Device, Open Approach */
"0W9J0ZX" = "1" /* Drainage of Pelvic Cavity, Open Approach, Diagnostic */
"0W9J0ZZ" = "1" /* Drainage of Pelvic Cavity, Open Approach */
"0WBF0ZX" = "1" /* Excision of Abdominal Wall, Open Approach, Diagnostic */
"0WBF0ZZ" = "1" /* Excision of Abdominal Wall, Open Approach */
"0WBH0ZX" = "1" /* Excision of Retroperitoneum, Open Approach, Diagnostic */
"0WBH0ZZ" = "1" /* Excision of Retroperitoneum, Open Approach */
"0WCG0ZZ" = "1" /* Extirpation of Matter from Peritoneal Cavity, Open Approach */
"0WCJ0ZZ" = "1" /* Extirpation of Matter from Pelvic Cavity, Open Approach */
"0WCP0ZZ" = "1" /* Extirpation of Matter from Gastrointestinal Tract, Open Approach */
"0WCR0ZZ" = "1" /* Extirpation of Matter from Genitourinary Tract, Open Approach */
"0WFG0ZZ" = "1" /* Fragmentation in Peritoneal Cavity, Open Approach */
"0WFJ0ZZ" = "1" /* Fragmentation in Pelvic Cavity, Open Approach */
"0WFP0ZZ" = "1" /* Fragmentation in Gastrointestinal Tract, Open Approach */
"0WFR0ZZ" = "1" /* Fragmentation in Genitourinary Tract, Open Approach */
"0WHF01Z" = "1" /* Insertion of Radioactive Element into Abdominal Wall, Open Approach */
"0WHF03Z" = "1" /* Insertion of Infusion Device into Abdominal Wall, Open Approach */
"0WHF0YZ" = "1" /* Insertion of Other Device into Abdominal Wall, Open Approach */
"0WHG01Z" = "1" /* Insertion of Radioactive Element into Peritoneal Cavity, Open Approach */
"0WHG03Z" = "1" /* Insertion of Infusion Device into Peritoneal Cavity, Open Approach */
"0WHG0YZ" = "1" /* Insertion of Other Device into Peritoneal Cavity, Open Approach */
"0WHH01Z" = "1" /* Insertion of Radioactive Element into Retroperitoneum, Open Approach */
"0WHH03Z" = "1" /* Insertion of Infusion Device into Retroperitoneum, Open Approach */
"0WHH0YZ" = "1" /* Insertion of Other Device into Retroperitoneum, Open Approach */
"0WHJ01Z" = "1" /* Insertion of Radioactive Element into Pelvic Cavity, Open Approach */
"0WHJ03Z" = "1" /* Insertion of Infusion Device into Pelvic Cavity, Open Approach */
"0WHJ0YZ" = "1" /* Insertion of Other Device into Pelvic Cavity, Open Approach */
"0WHP01Z" = "1" /* Insertion of Radioactive Element into Gastrointestinal Tract, Open Approach */
"0WHP03Z" = "1" /* Insertion of Infusion Device into Gastrointestinal Tract, Open Approach */
"0WHP0YZ" = "1" /* Insertion of Other Device into Gastrointestinal Tract, Open Approach */
"0WHR01Z" = "1" /* Insertion of Radioactive Element into Genitourinary Tract, Open Approach */
"0WHR03Z" = "1" /* Insertion of Infusion Device into Genitourinary Tract, Open Approach */
"0WHR0YZ" = "1" /* Insertion of Other Device into Genitourinary Tract, Open Approach */
"0WJF0ZZ" = "1" /* Inspection of Abdominal Wall, Open Approach */
"0WJG0ZZ" = "1" /* Inspection of Peritoneal Cavity, Open Approach */
"0WJH0ZZ" = "1" /* Inspection of Retroperitoneum, Open Approach */
"0WJJ0ZZ" = "1" /* Inspection of Pelvic Cavity, Open Approach */
"0WJP0ZZ" = "1" /* Inspection of Gastrointestinal Tract, Open Approach */
"0WJR0ZZ" = "1" /* Inspection of Genitourinary Tract, Open Approach */
"0WMF0ZZ" = "1" /* Reattachment of Abdominal Wall, Open Approach */
"0WPF00Z" = "1" /* Removal of Drainage Device from Abdominal Wall, Open Approach */
"0WPF01Z" = "1" /* Removal of Radioactive Element from Abdominal Wall, Open Approach */
"0WPF03Z" = "1" /* Removal of Infusion Device from Abdominal Wall, Open Approach */
"0WPF07Z" = "1" /* Removal of Autologous Tissue Substitute from Abdominal Wall, Open Approach */
"0WPF0JZ" = "1" /* Removal of Synthetic Substitute from Abdominal Wall, Open Approach */
"0WPF0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Abdominal Wall, Open Approach */
"0WPF0YZ" = "1" /* Removal of Other Device from Abdominal Wall, Open Approach */
"0WPG00Z" = "1" /* Removal of Drainage Device from Peritoneal Cavity, Open Approach */
"0WPG01Z" = "1" /* Removal of Radioactive Element from Peritoneal Cavity, Open Approach */
"0WPG03Z" = "1" /* Removal of Infusion Device from Peritoneal Cavity, Open Approach */
"0WPG0JZ" = "1" /* Removal of Synthetic Substitute from Peritoneal Cavity, Open Approach */
"0WPG0YZ" = "1" /* Removal of Other Device from Peritoneal Cavity, Open Approach */
"0WPH00Z" = "1" /* Removal of Drainage Device from Retroperitoneum, Open Approach */
"0WPH01Z" = "1" /* Removal of Radioactive Element from Retroperitoneum, Open Approach */
"0WPH03Z" = "1" /* Removal of Infusion Device from Retroperitoneum, Open Approach */
"0WPH0YZ" = "1" /* Removal of Other Device from Retroperitoneum, Open Approach */
"0WPJ00Z" = "1" /* Removal of Drainage Device from Pelvic Cavity, Open Approach */
"0WPJ01Z" = "1" /* Removal of Radioactive Element from Pelvic Cavity, Open Approach */
"0WPJ03Z" = "1" /* Removal of Infusion Device from Pelvic Cavity, Open Approach */
"0WPJ0JZ" = "1" /* Removal of Synthetic Substitute from Pelvic Cavity, Open Approach */
"0WPJ0YZ" = "1" /* Removal of Other Device from Pelvic Cavity, Open Approach */
"0WPP01Z" = "1" /* Removal of Radioactive Element from Gastrointestinal Tract, Open Approach */
"0WPP03Z" = "1" /* Removal of Infusion Device from Gastrointestinal Tract, Open Approach */
"0WPP0YZ" = "1" /* Removal of Other Device from Gastrointestinal Tract, Open Approach */
"0WPR01Z" = "1" /* Removal of Radioactive Element from Genitourinary Tract, Open Approach */
"0WPR03Z" = "1" /* Removal of Infusion Device from Genitourinary Tract, Open Approach */
"0WPR0YZ" = "1" /* Removal of Other Device from Genitourinary Tract, Open Approach */
"0WQF0ZZ" = "1" /* Repair Abdominal Wall, Open Approach */
"0WUF07Z" = "1" /* Supplement Abdominal Wall with Autologous Tissue Substitute, Open Approach */
"0WUF0JZ" = "1" /* Supplement Abdominal Wall with Synthetic Substitute, Open Approach */
"0WUF0KZ" = "1" /* Supplement Abdominal Wall with Nonautologous Tissue Substitute, Open Approach */
"0WWF00Z" = "1" /* Revision of Drainage Device in Abdominal Wall, Open Approach */
"0WWF01Z" = "1" /* Revision of Radioactive Element in Abdominal Wall, Open Approach */
"0WWF03Z" = "1" /* Revision of Infusion Device in Abdominal Wall, Open Approach */
"0WWF07Z" = "1" /* Revision of Autologous Tissue Substitute in Abdominal Wall, Open Approach */
"0WWF0JZ" = "1" /* Revision of Synthetic Substitute in Abdominal Wall, Open Approach */
"0WWF0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Abdominal Wall, Open Approach */
"0WWF0YZ" = "1" /* Revision of Other Device in Abdominal Wall, Open Approach */
"0WWG00Z" = "1" /* Revision of Drainage Device in Peritoneal Cavity, Open Approach */
"0WWG01Z" = "1" /* Revision of Radioactive Element in Peritoneal Cavity, Open Approach */
"0WWG03Z" = "1" /* Revision of Infusion Device in Peritoneal Cavity, Open Approach */
"0WWG0JZ" = "1" /* Revision of Synthetic Substitute in Peritoneal Cavity, Open Approach */
"0WWG0YZ" = "1" /* Revision of Other Device in Peritoneal Cavity, Open Approach */
"0WWH00Z" = "1" /* Revision of Drainage Device in Retroperitoneum, Open Approach */
"0WWH01Z" = "1" /* Revision of Radioactive Element in Retroperitoneum, Open Approach */
"0WWH03Z" = "1" /* Revision of Infusion Device in Retroperitoneum, Open Approach */
"0WWH0YZ" = "1" /* Revision of Other Device in Retroperitoneum, Open Approach */
"0WWJ00Z" = "1" /* Revision of Drainage Device in Pelvic Cavity, Open Approach */
"0WWJ01Z" = "1" /* Revision of Radioactive Element in Pelvic Cavity, Open Approach */
"0WWJ03Z" = "1" /* Revision of Infusion Device in Pelvic Cavity, Open Approach */
"0WWJ0JZ" = "1" /* Revision of Synthetic Substitute in Pelvic Cavity, Open Approach */
"0WWJ0YZ" = "1" /* Revision of Other Device in Pelvic Cavity, Open Approach */
"0WWP01Z" = "1" /* Revision of Radioactive Element in Gastrointestinal Tract, Open Approach */
"0WWP03Z" = "1" /* Revision of Infusion Device in Gastrointestinal Tract, Open Approach */
"0WWP0YZ" = "1" /* Revision of Other Device in Gastrointestinal Tract, Open Approach */
"0WWR01Z" = "1" /* Revision of Radioactive Element in Genitourinary Tract, Open Approach */
"0WWR03Z" = "1" /* Revision of Infusion Device in Genitourinary Tract, Open Approach */
"0WWR0YZ" = "1" /* Revision of Other Device in Genitourinary Tract, Open Approach */
"0Y350ZZ" = "1" /* Control Bleeding in Right Inguinal Region, Open Approach */
"0Y360ZZ" = "1" /* Control Bleeding in Left Inguinal Region, Open Approach */
"0Y9500Z" = "1" /* Drainage of Right Inguinal Region with Drainage Device, Open Approach */
"0Y950ZX" = "1" /* Drainage of Right Inguinal Region, Open Approach, Diagnostic */
"0Y950ZZ" = "1" /* Drainage of Right Inguinal Region, Open Approach */
"0Y9600Z" = "1" /* Drainage of Left Inguinal Region with Drainage Device, Open Approach */
"0Y960ZX" = "1" /* Drainage of Left Inguinal Region, Open Approach, Diagnostic */
"0Y960ZZ" = "1" /* Drainage of Left Inguinal Region, Open Approach */
"0YB50ZX" = "1" /* Excision of Right Inguinal Region, Open Approach, Diagnostic */
"0YB50ZZ" = "1" /* Excision of Right Inguinal Region, Open Approach */
"0YB60ZX" = "1" /* Excision of Left Inguinal Region, Open Approach, Diagnostic */
"0YB60ZZ" = "1" /* Excision of Left Inguinal Region, Open Approach */
"0YB70ZZ" = "1" /* Excision of Right Femoral Region, Open Approach */
"0YB80ZZ" = "1" /* Excision of Left Femoral Region, Open Approach */
"0YH501Z" = "1" /* Insertion of Radioactive Element into Right Inguinal Region, Open Approach */
"0YH503Z" = "1" /* Insertion of Infusion Device into Right Inguinal Region, Open Approach */
"0YH50YZ" = "1" /* Insertion of Other Device into Right Inguinal Region, Open Approach */
"0YH601Z" = "1" /* Insertion of Radioactive Element into Left Inguinal Region, Open Approach */
"0YH603Z" = "1" /* Insertion of Infusion Device into Left Inguinal Region, Open Approach */
"0YH60YZ" = "1" /* Insertion of Other Device into Left Inguinal Region, Open Approach */
"0YJ50ZZ" = "1" /* Inspection of Right Inguinal Region, Open Approach */
"0YJ60ZZ" = "1" /* Inspection of Left Inguinal Region, Open Approach */
"0YJ70ZZ" = "1" /* Inspection of Right Femoral Region, Open Approach */
"0YJA0ZZ" = "1" /* Inspection of Bilateral Inguinal Region, Open Approach */
"0YM50ZZ" = "1" /* Reattachment of Right Inguinal Region, Open Approach */
"0YM60ZZ" = "1" /* Reattachment of Left Inguinal Region, Open Approach */
"0YQ50ZZ" = "1" /* Repair Right Inguinal Region, Open Approach */
"0YQ60ZZ" = "1" /* Repair Left Inguinal Region, Open Approach */
"0YQ70ZZ" = "1" /* Repair Right Femoral Region, Open Approach */
"0YQ80ZZ" = "1" /* Repair Left Femoral Region, Open Approach */
"0YQA0ZZ" = "1" /* Repair Bilateral Inguinal Region, Open Approach */
"0YQE0ZZ" = "1" /* Repair Bilateral Femoral Region, Open Approach */
"0YU507Z" = "1" /* Supplement Right Inguinal Region with Autologous Tissue Substitute, Open Approach */
"0YU50JZ" = "1" /* Supplement Right Inguinal Region with Synthetic Substitute, Open Approach */
"0YU50KZ" = "1" /* Supplement Right Inguinal Region with Nonautologous Tissue Substitute, Open Approach */
"0YU607Z" = "1" /* Supplement Left Inguinal Region with Autologous Tissue Substitute, Open Approach */
"0YU60JZ" = "1" /* Supplement Left Inguinal Region with Synthetic Substitute, Open Approach */
"0YU60KZ" = "1" /* Supplement Left Inguinal Region with Nonautologous Tissue Substitute, Open Approach */
"0YU707Z" = "1" /* Supplement Right Femoral Region with Autologous Tissue Substitute, Open Approach */
"0YU70JZ" = "1" /* Supplement Right Femoral Region with Synthetic Substitute, Open Approach */
"0YU70KZ" = "1" /* Supplement Right Femoral Region with Nonautologous Tissue Substitute, Open Approach */
"0YU807Z" = "1" /* Supplement Left Femoral Region with Autologous Tissue Substitute, Open Approach */
"0YU80JZ" = "1" /* Supplement Left Femoral Region with Synthetic Substitute, Open Approach */
"0YU80KZ" = "1" /* Supplement Left Femoral Region with Nonautologous Tissue Substitute, Open Approach */
"0YUA07Z" = "1" /* Supplement Bilateral Inguinal Region with Autologous Tissue Substitute, Open Approach */
"0YUA0JZ" = "1" /* Supplement Bilateral Inguinal Region with Synthetic Substitute, Open Approach */
"0YUA0KZ" = "1" /* Supplement Bilateral Inguinal Region with Nonautologous Tissue Substitute, Open Approach */
"0YUE07Z" = "1" /* Supplement Bilateral Femoral Region with Autologous Tissue Substitute, Open Approach */
"0YUE0JZ" = "1" /* Supplement Bilateral Femoral Region with Synthetic Substitute, Open Approach */
"0YUE0KZ" = "1" /* Supplement Bilateral Femoral Region with Nonautologous Tissue Substitute, Open Approach */
Other = "0"
;

/* Procedure codeset ABDOMIPOTHER last updated 161201 for ICD10 v70rev0 */
Value $ABDOMIPOTHER
"008Q3ZZ" = "1" /* Division of Vagus Nerve, Percutaneous Approach */
"008Q4ZZ" = "1" /* Division of Vagus Nerve, Percutaneous Endoscopic Approach */
"01593ZZ" = "1" /* Destruction of Lumbar Plexus, Percutaneous Approach */
"01594ZZ" = "1" /* Destruction of Lumbar Plexus, Percutaneous Endoscopic Approach */
"015A3ZZ" = "1" /* Destruction of Lumbosacral Plexus, Percutaneous Approach */
"015A4ZZ" = "1" /* Destruction of Lumbosacral Plexus, Percutaneous Endoscopic Approach */
"015B3ZZ" = "1" /* Destruction of Lumbar Nerve, Percutaneous Approach */
"015B4ZZ" = "1" /* Destruction of Lumbar Nerve, Percutaneous Endoscopic Approach */
"015C3ZZ" = "1" /* Destruction of Pudendal Nerve, Percutaneous Approach */
"015C4ZZ" = "1" /* Destruction of Pudendal Nerve, Percutaneous Endoscopic Approach */
"015M3ZZ" = "1" /* Destruction of Abdominal Sympathetic Nerve, Percutaneous Approach */
"015M4ZZ" = "1" /* Destruction of Abdominal Sympathetic Nerve, Percutaneous Endoscopic Approach */
"015N3ZZ" = "1" /* Destruction of Lumbar Sympathetic Nerve, Percutaneous Approach */
"015N4ZZ" = "1" /* Destruction of Lumbar Sympathetic Nerve, Percutaneous Endoscopic Approach */
"015P3ZZ" = "1" /* Destruction of Sacral Sympathetic Nerve, Percutaneous Approach */
"015P4ZZ" = "1" /* Destruction of Sacral Sympathetic Nerve, Percutaneous Endoscopic Approach */
"015Q3ZZ" = "1" /* Destruction of Sacral Plexus, Percutaneous Approach */
"015Q4ZZ" = "1" /* Destruction of Sacral Plexus, Percutaneous Endoscopic Approach */
"015R3ZZ" = "1" /* Destruction of Sacral Nerve, Percutaneous Approach */
"015R4ZZ" = "1" /* Destruction of Sacral Nerve, Percutaneous Endoscopic Approach */
"01893ZZ" = "1" /* Division of Lumbar Plexus, Percutaneous Approach */
"01894ZZ" = "1" /* Division of Lumbar Plexus, Percutaneous Endoscopic Approach */
"018A3ZZ" = "1" /* Division of Lumbosacral Plexus, Percutaneous Approach */
"018A4ZZ" = "1" /* Division of Lumbosacral Plexus, Percutaneous Endoscopic Approach */
"018B3ZZ" = "1" /* Division of Lumbar Nerve, Percutaneous Approach */
"018B4ZZ" = "1" /* Division of Lumbar Nerve, Percutaneous Endoscopic Approach */
"018C3ZZ" = "1" /* Division of Pudendal Nerve, Percutaneous Approach */
"018C4ZZ" = "1" /* Division of Pudendal Nerve, Percutaneous Endoscopic Approach */
"018M3ZZ" = "1" /* Division of Abdominal Sympathetic Nerve, Percutaneous Approach */
"018M4ZZ" = "1" /* Division of Abdominal Sympathetic Nerve, Percutaneous Endoscopic Approach */
"018N3ZZ" = "1" /* Division of Lumbar Sympathetic Nerve, Percutaneous Approach */
"018N4ZZ" = "1" /* Division of Lumbar Sympathetic Nerve, Percutaneous Endoscopic Approach */
"018P3ZZ" = "1" /* Division of Sacral Sympathetic Nerve, Percutaneous Approach */
"018P4ZZ" = "1" /* Division of Sacral Sympathetic Nerve, Percutaneous Endoscopic Approach */
"018Q3ZZ" = "1" /* Division of Sacral Plexus, Percutaneous Approach */
"018Q4ZZ" = "1" /* Division of Sacral Plexus, Percutaneous Endoscopic Approach */
"018R3ZZ" = "1" /* Division of Sacral Nerve, Percutaneous Approach */
"018R4ZZ" = "1" /* Division of Sacral Nerve, Percutaneous Endoscopic Approach */
"019930Z" = "1" /* Drainage of Lumbar Plexus with Drainage Device, Percutaneous Approach */
"01993ZX" = "1" /* Drainage of Lumbar Plexus, Percutaneous Approach, Diagnostic */
"01993ZZ" = "1" /* Drainage of Lumbar Plexus, Percutaneous Approach */
"019940Z" = "1" /* Drainage of Lumbar Plexus with Drainage Device, Percutaneous Endoscopic Approach */
"01994ZX" = "1" /* Drainage of Lumbar Plexus, Percutaneous Endoscopic Approach, Diagnostic */
"01994ZZ" = "1" /* Drainage of Lumbar Plexus, Percutaneous Endoscopic Approach */
"019A30Z" = "1" /* Drainage of Lumbosacral Plexus with Drainage Device, Percutaneous Approach */
"019A3ZX" = "1" /* Drainage of Lumbosacral Plexus, Percutaneous Approach, Diagnostic */
"019A3ZZ" = "1" /* Drainage of Lumbosacral Plexus, Percutaneous Approach */
"019A40Z" = "1" /* Drainage of Lumbosacral Plexus with Drainage Device, Percutaneous Endoscopic Approach */
"019A4ZX" = "1" /* Drainage of Lumbosacral Plexus, Percutaneous Endoscopic Approach, Diagnostic */
"019A4ZZ" = "1" /* Drainage of Lumbosacral Plexus, Percutaneous Endoscopic Approach */
"019B30Z" = "1" /* Drainage of Lumbar Nerve with Drainage Device, Percutaneous Approach */
"019B3ZX" = "1" /* Drainage of Lumbar Nerve, Percutaneous Approach, Diagnostic */
"019B3ZZ" = "1" /* Drainage of Lumbar Nerve, Percutaneous Approach */
"019B40Z" = "1" /* Drainage of Lumbar Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"019B4ZX" = "1" /* Drainage of Lumbar Nerve, Percutaneous Endoscopic Approach, Diagnostic */
"019B4ZZ" = "1" /* Drainage of Lumbar Nerve, Percutaneous Endoscopic Approach */
"019C30Z" = "1" /* Drainage of Pudendal Nerve with Drainage Device, Percutaneous Approach */
"019C3ZX" = "1" /* Drainage of Pudendal Nerve, Percutaneous Approach, Diagnostic */
"019C3ZZ" = "1" /* Drainage of Pudendal Nerve, Percutaneous Approach */
"019C40Z" = "1" /* Drainage of Pudendal Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"019C4ZX" = "1" /* Drainage of Pudendal Nerve, Percutaneous Endoscopic Approach, Diagnostic */
"019C4ZZ" = "1" /* Drainage of Pudendal Nerve, Percutaneous Endoscopic Approach */
"019M30Z" = "1" /* Drainage of Abdominal Sympathetic Nerve with Drainage Device, Percutaneous Approach */
"019M3ZX" = "1" /* Drainage of Abdominal Sympathetic Nerve, Percutaneous Approach, Diagnostic */
"019M3ZZ" = "1" /* Drainage of Abdominal Sympathetic Nerve, Percutaneous Approach */
"019M40Z" = "1" /* Drainage of Abdominal Sympathetic Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"019M4ZX" = "1" /* Drainage of Abdominal Sympathetic Nerve, Percutaneous Endoscopic Approach, Diagnostic */
"019M4ZZ" = "1" /* Drainage of Abdominal Sympathetic Nerve, Percutaneous Endoscopic Approach */
"019N30Z" = "1" /* Drainage of Lumbar Sympathetic Nerve with Drainage Device, Percutaneous Approach */
"019N3ZX" = "1" /* Drainage of Lumbar Sympathetic Nerve, Percutaneous Approach, Diagnostic */
"019N3ZZ" = "1" /* Drainage of Lumbar Sympathetic Nerve, Percutaneous Approach */
"019N40Z" = "1" /* Drainage of Lumbar Sympathetic Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"019N4ZX" = "1" /* Drainage of Lumbar Sympathetic Nerve, Percutaneous Endoscopic Approach, Diagnostic */
"019N4ZZ" = "1" /* Drainage of Lumbar Sympathetic Nerve, Percutaneous Endoscopic Approach */
"019P30Z" = "1" /* Drainage of Sacral Sympathetic Nerve with Drainage Device, Percutaneous Approach */
"019P3ZX" = "1" /* Drainage of Sacral Sympathetic Nerve, Percutaneous Approach, Diagnostic */
"019P3ZZ" = "1" /* Drainage of Sacral Sympathetic Nerve, Percutaneous Approach */
"019P40Z" = "1" /* Drainage of Sacral Sympathetic Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"019P4ZX" = "1" /* Drainage of Sacral Sympathetic Nerve, Percutaneous Endoscopic Approach, Diagnostic */
"019P4ZZ" = "1" /* Drainage of Sacral Sympathetic Nerve, Percutaneous Endoscopic Approach */
"019Q30Z" = "1" /* Drainage of Sacral Plexus with Drainage Device, Percutaneous Approach */
"019Q3ZX" = "1" /* Drainage of Sacral Plexus, Percutaneous Approach, Diagnostic */
"019Q3ZZ" = "1" /* Drainage of Sacral Plexus, Percutaneous Approach */
"019Q40Z" = "1" /* Drainage of Sacral Plexus with Drainage Device, Percutaneous Endoscopic Approach */
"019Q4ZX" = "1" /* Drainage of Sacral Plexus, Percutaneous Endoscopic Approach, Diagnostic */
"019Q4ZZ" = "1" /* Drainage of Sacral Plexus, Percutaneous Endoscopic Approach */
"019R30Z" = "1" /* Drainage of Sacral Nerve with Drainage Device, Percutaneous Approach */
"019R3ZX" = "1" /* Drainage of Sacral Nerve, Percutaneous Approach, Diagnostic */
"019R3ZZ" = "1" /* Drainage of Sacral Nerve, Percutaneous Approach */
"019R40Z" = "1" /* Drainage of Sacral Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"019R4ZX" = "1" /* Drainage of Sacral Nerve, Percutaneous Endoscopic Approach, Diagnostic */
"019R4ZZ" = "1" /* Drainage of Sacral Nerve, Percutaneous Endoscopic Approach */
"01B93ZX" = "1" /* Excision of Lumbar Plexus, Percutaneous Approach, Diagnostic */
"01B93ZZ" = "1" /* Excision of Lumbar Plexus, Percutaneous Approach */
"01B94ZX" = "1" /* Excision of Lumbar Plexus, Percutaneous Endoscopic Approach, Diagnostic */
"01B94ZZ" = "1" /* Excision of Lumbar Plexus, Percutaneous Endoscopic Approach */
"01BA3ZX" = "1" /* Excision of Lumbosacral Plexus, Percutaneous Approach, Diagnostic */
"01BA3ZZ" = "1" /* Excision of Lumbosacral Plexus, Percutaneous Approach */
"01BA4ZX" = "1" /* Excision of Lumbosacral Plexus, Percutaneous Endoscopic Approach, Diagnostic */
"01BA4ZZ" = "1" /* Excision of Lumbosacral Plexus, Percutaneous Endoscopic Approach */
"01BB3ZX" = "1" /* Excision of Lumbar Nerve, Percutaneous Approach, Diagnostic */
"01BB3ZZ" = "1" /* Excision of Lumbar Nerve, Percutaneous Approach */
"01BB4ZX" = "1" /* Excision of Lumbar Nerve, Percutaneous Endoscopic Approach, Diagnostic */
"01BB4ZZ" = "1" /* Excision of Lumbar Nerve, Percutaneous Endoscopic Approach */
"01BC3ZX" = "1" /* Excision of Pudendal Nerve, Percutaneous Approach, Diagnostic */
"01BC3ZZ" = "1" /* Excision of Pudendal Nerve, Percutaneous Approach */
"01BC4ZX" = "1" /* Excision of Pudendal Nerve, Percutaneous Endoscopic Approach, Diagnostic */
"01BC4ZZ" = "1" /* Excision of Pudendal Nerve, Percutaneous Endoscopic Approach */
"01BM3ZX" = "1" /* Excision of Abdominal Sympathetic Nerve, Percutaneous Approach, Diagnostic */
"01BM3ZZ" = "1" /* Excision of Abdominal Sympathetic Nerve, Percutaneous Approach */
"01BM4ZX" = "1" /* Excision of Abdominal Sympathetic Nerve, Percutaneous Endoscopic Approach, Diagnostic */
"01BM4ZZ" = "1" /* Excision of Abdominal Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01BN3ZX" = "1" /* Excision of Lumbar Sympathetic Nerve, Percutaneous Approach, Diagnostic */
"01BN3ZZ" = "1" /* Excision of Lumbar Sympathetic Nerve, Percutaneous Approach */
"01BN4ZX" = "1" /* Excision of Lumbar Sympathetic Nerve, Percutaneous Endoscopic Approach, Diagnostic */
"01BN4ZZ" = "1" /* Excision of Lumbar Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01BP3ZX" = "1" /* Excision of Sacral Sympathetic Nerve, Percutaneous Approach, Diagnostic */
"01BP3ZZ" = "1" /* Excision of Sacral Sympathetic Nerve, Percutaneous Approach */
"01BP4ZX" = "1" /* Excision of Sacral Sympathetic Nerve, Percutaneous Endoscopic Approach, Diagnostic */
"01BP4ZZ" = "1" /* Excision of Sacral Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01BQ3ZX" = "1" /* Excision of Sacral Plexus, Percutaneous Approach, Diagnostic */
"01BQ3ZZ" = "1" /* Excision of Sacral Plexus, Percutaneous Approach */
"01BQ4ZX" = "1" /* Excision of Sacral Plexus, Percutaneous Endoscopic Approach, Diagnostic */
"01BQ4ZZ" = "1" /* Excision of Sacral Plexus, Percutaneous Endoscopic Approach */
"01BR3ZX" = "1" /* Excision of Sacral Nerve, Percutaneous Approach, Diagnostic */
"01BR3ZZ" = "1" /* Excision of Sacral Nerve, Percutaneous Approach */
"01BR4ZX" = "1" /* Excision of Sacral Nerve, Percutaneous Endoscopic Approach, Diagnostic */
"01BR4ZZ" = "1" /* Excision of Sacral Nerve, Percutaneous Endoscopic Approach */
"01C93ZZ" = "1" /* Extirpation of Matter from Lumbar Plexus, Percutaneous Approach */
"01C94ZZ" = "1" /* Extirpation of Matter from Lumbar Plexus, Percutaneous Endoscopic Approach */
"01CA3ZZ" = "1" /* Extirpation of Matter from Lumbosacral Plexus, Percutaneous Approach */
"01CA4ZZ" = "1" /* Extirpation of Matter from Lumbosacral Plexus, Percutaneous Endoscopic Approach */
"01CB3ZZ" = "1" /* Extirpation of Matter from Lumbar Nerve, Percutaneous Approach */
"01CB4ZZ" = "1" /* Extirpation of Matter from Lumbar Nerve, Percutaneous Endoscopic Approach */
"01CC3ZZ" = "1" /* Extirpation of Matter from Pudendal Nerve, Percutaneous Approach */
"01CC4ZZ" = "1" /* Extirpation of Matter from Pudendal Nerve, Percutaneous Endoscopic Approach */
"01CM3ZZ" = "1" /* Extirpation of Matter from Abdominal Sympathetic Nerve, Percutaneous Approach */
"01CM4ZZ" = "1" /* Extirpation of Matter from Abdominal Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01CN3ZZ" = "1" /* Extirpation of Matter from Lumbar Sympathetic Nerve, Percutaneous Approach */
"01CN4ZZ" = "1" /* Extirpation of Matter from Lumbar Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01CP3ZZ" = "1" /* Extirpation of Matter from Sacral Sympathetic Nerve, Percutaneous Approach */
"01CP4ZZ" = "1" /* Extirpation of Matter from Sacral Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01CQ3ZZ" = "1" /* Extirpation of Matter from Sacral Plexus, Percutaneous Approach */
"01CQ4ZZ" = "1" /* Extirpation of Matter from Sacral Plexus, Percutaneous Endoscopic Approach */
"01CR3ZZ" = "1" /* Extirpation of Matter from Sacral Nerve, Percutaneous Approach */
"01CR4ZZ" = "1" /* Extirpation of Matter from Sacral Nerve, Percutaneous Endoscopic Approach */
"01D93ZZ" = "1" /* Extraction of Lumbar Plexus, Percutaneous Approach */
"01D94ZZ" = "1" /* Extraction of Lumbar Plexus, Percutaneous Endoscopic Approach */
"01DA3ZZ" = "1" /* Extraction of Lumbosacral Plexus, Percutaneous Approach */
"01DA4ZZ" = "1" /* Extraction of Lumbosacral Plexus, Percutaneous Endoscopic Approach */
"01DB3ZZ" = "1" /* Extraction of Lumbar Nerve, Percutaneous Approach */
"01DB4ZZ" = "1" /* Extraction of Lumbar Nerve, Percutaneous Endoscopic Approach */
"01DC3ZZ" = "1" /* Extraction of Pudendal Nerve, Percutaneous Approach */
"01DC4ZZ" = "1" /* Extraction of Pudendal Nerve, Percutaneous Endoscopic Approach */
"01DM3ZZ" = "1" /* Extraction of Abdominal Sympathetic Nerve, Percutaneous Approach */
"01DM4ZZ" = "1" /* Extraction of Abdominal Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01DN3ZZ" = "1" /* Extraction of Lumbar Sympathetic Nerve, Percutaneous Approach */
"01DN4ZZ" = "1" /* Extraction of Lumbar Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01DP3ZZ" = "1" /* Extraction of Sacral Sympathetic Nerve, Percutaneous Approach */
"01DP4ZZ" = "1" /* Extraction of Sacral Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01DQ3ZZ" = "1" /* Extraction of Sacral Plexus, Percutaneous Approach */
"01DQ4ZZ" = "1" /* Extraction of Sacral Plexus, Percutaneous Endoscopic Approach */
"01DR3ZZ" = "1" /* Extraction of Sacral Nerve, Percutaneous Approach */
"01DR4ZZ" = "1" /* Extraction of Sacral Nerve, Percutaneous Endoscopic Approach */
"01N93ZZ" = "1" /* Release Lumbar Plexus, Percutaneous Approach */
"01N94ZZ" = "1" /* Release Lumbar Plexus, Percutaneous Endoscopic Approach */
"01NA3ZZ" = "1" /* Release Lumbosacral Plexus, Percutaneous Approach */
"01NA4ZZ" = "1" /* Release Lumbosacral Plexus, Percutaneous Endoscopic Approach */
"01NB3ZZ" = "1" /* Release Lumbar Nerve, Percutaneous Approach */
"01NB4ZZ" = "1" /* Release Lumbar Nerve, Percutaneous Endoscopic Approach */
"01NC3ZZ" = "1" /* Release Pudendal Nerve, Percutaneous Approach */
"01NC4ZZ" = "1" /* Release Pudendal Nerve, Percutaneous Endoscopic Approach */
"01NM3ZZ" = "1" /* Release Abdominal Sympathetic Nerve, Percutaneous Approach */
"01NM4ZZ" = "1" /* Release Abdominal Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01NN3ZZ" = "1" /* Release Lumbar Sympathetic Nerve, Percutaneous Approach */
"01NN4ZZ" = "1" /* Release Lumbar Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01NP3ZZ" = "1" /* Release Sacral Sympathetic Nerve, Percutaneous Approach */
"01NP4ZZ" = "1" /* Release Sacral Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01NQ3ZZ" = "1" /* Release Sacral Plexus, Percutaneous Approach */
"01NQ4ZZ" = "1" /* Release Sacral Plexus, Percutaneous Endoscopic Approach */
"01NR3ZZ" = "1" /* Release Sacral Nerve, Percutaneous Approach */
"01NR4ZZ" = "1" /* Release Sacral Nerve, Percutaneous Endoscopic Approach */
"01Q93ZZ" = "1" /* Repair Lumbar Plexus, Percutaneous Approach */
"01Q94ZZ" = "1" /* Repair Lumbar Plexus, Percutaneous Endoscopic Approach */
"01QA3ZZ" = "1" /* Repair Lumbosacral Plexus, Percutaneous Approach */
"01QA4ZZ" = "1" /* Repair Lumbosacral Plexus, Percutaneous Endoscopic Approach */
"01QB3ZZ" = "1" /* Repair Lumbar Nerve, Percutaneous Approach */
"01QB4ZZ" = "1" /* Repair Lumbar Nerve, Percutaneous Endoscopic Approach */
"01QC3ZZ" = "1" /* Repair Pudendal Nerve, Percutaneous Approach */
"01QC4ZZ" = "1" /* Repair Pudendal Nerve, Percutaneous Endoscopic Approach */
"01QM3ZZ" = "1" /* Repair Abdominal Sympathetic Nerve, Percutaneous Approach */
"01QM4ZZ" = "1" /* Repair Abdominal Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01QN3ZZ" = "1" /* Repair Lumbar Sympathetic Nerve, Percutaneous Approach */
"01QN4ZZ" = "1" /* Repair Lumbar Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01QP3ZZ" = "1" /* Repair Sacral Sympathetic Nerve, Percutaneous Approach */
"01QP4ZZ" = "1" /* Repair Sacral Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01QQ3ZZ" = "1" /* Repair Sacral Plexus, Percutaneous Approach */
"01QQ4ZZ" = "1" /* Repair Sacral Plexus, Percutaneous Endoscopic Approach */
"01QR3ZZ" = "1" /* Repair Sacral Nerve, Percutaneous Approach */
"01QR4ZZ" = "1" /* Repair Sacral Nerve, Percutaneous Endoscopic Approach */
"01S93ZZ" = "1" /* Reposition Lumbar Plexus, Percutaneous Approach */
"01S94ZZ" = "1" /* Reposition Lumbar Plexus, Percutaneous Endoscopic Approach */
"01SA3ZZ" = "1" /* Reposition Lumbosacral Plexus, Percutaneous Approach */
"01SA4ZZ" = "1" /* Reposition Lumbosacral Plexus, Percutaneous Endoscopic Approach */
"01SB3ZZ" = "1" /* Reposition Lumbar Nerve, Percutaneous Approach */
"01SB4ZZ" = "1" /* Reposition Lumbar Nerve, Percutaneous Endoscopic Approach */
"01SC3ZZ" = "1" /* Reposition Pudendal Nerve, Percutaneous Approach */
"01SC4ZZ" = "1" /* Reposition Pudendal Nerve, Percutaneous Endoscopic Approach */
"01SQ3ZZ" = "1" /* Reposition Sacral Plexus, Percutaneous Approach */
"01SQ4ZZ" = "1" /* Reposition Sacral Plexus, Percutaneous Endoscopic Approach */
"01SR3ZZ" = "1" /* Reposition Sacral Nerve, Percutaneous Approach */
"01SR4ZZ" = "1" /* Reposition Sacral Nerve, Percutaneous Endoscopic Approach */
"01UB37Z" = "1" /* Supplement Lumbar Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"01UB47Z" = "1" /* Supplement Lumbar Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"01UC37Z" = "1" /* Supplement Pudendal Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"01UC47Z" = "1" /* Supplement Pudendal Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"01UR37Z" = "1" /* Supplement Sacral Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"01UR47Z" = "1" /* Supplement Sacral Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"01XB4ZB" = "1" /* Transfer Lumbar Nerve to Lumbar Nerve, Percutaneous Endoscopic Approach */
"01XB4ZC" = "1" /* Transfer Lumbar Nerve to Perineal Nerve, Percutaneous Endoscopic Approach */
"01XC4ZB" = "1" /* Transfer Pudendal Nerve to Lumbar Nerve, Percutaneous Endoscopic Approach */
"01XC4ZC" = "1" /* Transfer Pudendal Nerve to Perineal Nerve, Percutaneous Endoscopic Approach */
"0410490" = "1" /* Bypass Abdominal Aorta to Abdominal Aorta with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0410491" = "1" /* Bypass Abdominal Aorta to Celiac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0410492" = "1" /* Bypass Abdominal Aorta to Mesenteric Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0410493" = "1" /* Bypass Abdominal Aorta to Right Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0410494" = "1" /* Bypass Abdominal Aorta to Left Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0410495" = "1" /* Bypass Abdominal Aorta to Bilateral Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0410496" = "1" /* Bypass Abdominal Aorta to Right Common Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0410497" = "1" /* Bypass Abdominal Aorta to Left Common Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0410498" = "1" /* Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0410499" = "1" /* Bypass Abdominal Aorta to Right Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049B" = "1" /* Bypass Abdominal Aorta to Left Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049C" = "1" /* Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049D" = "1" /* Bypass Abdominal Aorta to Right External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049F" = "1" /* Bypass Abdominal Aorta to Left External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049G" = "1" /* Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049H" = "1" /* Bypass Abdominal Aorta to Right Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049J" = "1" /* Bypass Abdominal Aorta to Left Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049K" = "1" /* Bypass Abdominal Aorta to Bilateral Femoral Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049Q" = "1" /* Bypass Abdominal Aorta to Lower Extremity Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049R" = "1" /* Bypass Abdominal Aorta to Lower Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"04104A0" = "1" /* Bypass Abdominal Aorta to Abdominal Aorta with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104A1" = "1" /* Bypass Abdominal Aorta to Celiac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104A2" = "1" /* Bypass Abdominal Aorta to Mesenteric Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104A3" = "1" /* Bypass Abdominal Aorta to Right Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104A4" = "1" /* Bypass Abdominal Aorta to Left Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104A5" = "1" /* Bypass Abdominal Aorta to Bilateral Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104A6" = "1" /* Bypass Abdominal Aorta to Right Common Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104A7" = "1" /* Bypass Abdominal Aorta to Left Common Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104A8" = "1" /* Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104A9" = "1" /* Bypass Abdominal Aorta to Right Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AB" = "1" /* Bypass Abdominal Aorta to Left Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AC" = "1" /* Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AD" = "1" /* Bypass Abdominal Aorta to Right External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AF" = "1" /* Bypass Abdominal Aorta to Left External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AG" = "1" /* Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AH" = "1" /* Bypass Abdominal Aorta to Right Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AJ" = "1" /* Bypass Abdominal Aorta to Left Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AK" = "1" /* Bypass Abdominal Aorta to Bilateral Femoral Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AQ" = "1" /* Bypass Abdominal Aorta to Lower Extremity Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AR" = "1" /* Bypass Abdominal Aorta to Lower Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104J0" = "1" /* Bypass Abdominal Aorta to Abdominal Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104J1" = "1" /* Bypass Abdominal Aorta to Celiac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104J2" = "1" /* Bypass Abdominal Aorta to Mesenteric Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104J3" = "1" /* Bypass Abdominal Aorta to Right Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104J4" = "1" /* Bypass Abdominal Aorta to Left Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104J5" = "1" /* Bypass Abdominal Aorta to Bilateral Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104J6" = "1" /* Bypass Abdominal Aorta to Right Common Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104J7" = "1" /* Bypass Abdominal Aorta to Left Common Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104J8" = "1" /* Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104J9" = "1" /* Bypass Abdominal Aorta to Right Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JB" = "1" /* Bypass Abdominal Aorta to Left Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JC" = "1" /* Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JD" = "1" /* Bypass Abdominal Aorta to Right External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JF" = "1" /* Bypass Abdominal Aorta to Left External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JG" = "1" /* Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JH" = "1" /* Bypass Abdominal Aorta to Right Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JJ" = "1" /* Bypass Abdominal Aorta to Left Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JK" = "1" /* Bypass Abdominal Aorta to Bilateral Femoral Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JQ" = "1" /* Bypass Abdominal Aorta to Lower Extremity Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JR" = "1" /* Bypass Abdominal Aorta to Lower Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104K0" = "1" /* Bypass Abdominal Aorta to Abdominal Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104K1" = "1" /* Bypass Abdominal Aorta to Celiac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104K2" = "1" /* Bypass Abdominal Aorta to Mesenteric Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104K3" = "1" /* Bypass Abdominal Aorta to Right Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104K4" = "1" /* Bypass Abdominal Aorta to Left Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104K5" = "1" /* Bypass Abdominal Aorta to Bilateral Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104K6" = "1" /* Bypass Abdominal Aorta to Right Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104K7" = "1" /* Bypass Abdominal Aorta to Left Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104K8" = "1" /* Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104K9" = "1" /* Bypass Abdominal Aorta to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KB" = "1" /* Bypass Abdominal Aorta to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KC" = "1" /* Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KD" = "1" /* Bypass Abdominal Aorta to Right External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KF" = "1" /* Bypass Abdominal Aorta to Left External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KG" = "1" /* Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KH" = "1" /* Bypass Abdominal Aorta to Right Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KJ" = "1" /* Bypass Abdominal Aorta to Left Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KK" = "1" /* Bypass Abdominal Aorta to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KQ" = "1" /* Bypass Abdominal Aorta to Lower Extremity Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KR" = "1" /* Bypass Abdominal Aorta to Lower Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104Z0" = "1" /* Bypass Abdominal Aorta to Abdominal Aorta, Percutaneous Endoscopic Approach */
"04104Z1" = "1" /* Bypass Abdominal Aorta to Celiac Artery, Percutaneous Endoscopic Approach */
"04104Z2" = "1" /* Bypass Abdominal Aorta to Mesenteric Artery, Percutaneous Endoscopic Approach */
"04104Z3" = "1" /* Bypass Abdominal Aorta to Right Renal Artery, Percutaneous Endoscopic Approach */
"04104Z4" = "1" /* Bypass Abdominal Aorta to Left Renal Artery, Percutaneous Endoscopic Approach */
"04104Z5" = "1" /* Bypass Abdominal Aorta to Bilateral Renal Artery, Percutaneous Endoscopic Approach */
"04104Z6" = "1" /* Bypass Abdominal Aorta to Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"04104Z7" = "1" /* Bypass Abdominal Aorta to Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"04104Z8" = "1" /* Bypass Abdominal Aorta to Bilateral Common Iliac Arteries, Percutaneous Endoscopic Approach */
"04104Z9" = "1" /* Bypass Abdominal Aorta to Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04104ZB" = "1" /* Bypass Abdominal Aorta to Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04104ZC" = "1" /* Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries, Percutaneous Endoscopic Approach */
"04104ZD" = "1" /* Bypass Abdominal Aorta to Right External Iliac Artery, Percutaneous Endoscopic Approach */
"04104ZF" = "1" /* Bypass Abdominal Aorta to Left External Iliac Artery, Percutaneous Endoscopic Approach */
"04104ZG" = "1" /* Bypass Abdominal Aorta to Bilateral External Iliac Arteries, Percutaneous Endoscopic Approach */
"04104ZH" = "1" /* Bypass Abdominal Aorta to Right Femoral Artery, Percutaneous Endoscopic Approach */
"04104ZJ" = "1" /* Bypass Abdominal Aorta to Left Femoral Artery, Percutaneous Endoscopic Approach */
"04104ZK" = "1" /* Bypass Abdominal Aorta to Bilateral Femoral Arteries, Percutaneous Endoscopic Approach */
"04104ZQ" = "1" /* Bypass Abdominal Aorta to Lower Extremity Artery, Percutaneous Endoscopic Approach */
"04104ZR" = "1" /* Bypass Abdominal Aorta to Lower Artery, Percutaneous Endoscopic Approach */
"0414493" = "1" /* Bypass Splenic Artery to Right Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0414494" = "1" /* Bypass Splenic Artery to Left Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0414495" = "1" /* Bypass Splenic Artery to Bilateral Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"04144A3" = "1" /* Bypass Splenic Artery to Right Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04144A4" = "1" /* Bypass Splenic Artery to Left Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04144A5" = "1" /* Bypass Splenic Artery to Bilateral Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04144J3" = "1" /* Bypass Splenic Artery to Right Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04144J4" = "1" /* Bypass Splenic Artery to Left Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04144J5" = "1" /* Bypass Splenic Artery to Bilateral Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04144K3" = "1" /* Bypass Splenic Artery to Right Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04144K4" = "1" /* Bypass Splenic Artery to Left Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04144K5" = "1" /* Bypass Splenic Artery to Bilateral Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04144Z3" = "1" /* Bypass Splenic Artery to Right Renal Artery, Percutaneous Endoscopic Approach */
"04144Z4" = "1" /* Bypass Splenic Artery to Left Renal Artery, Percutaneous Endoscopic Approach */
"04144Z5" = "1" /* Bypass Splenic Artery to Bilateral Renal Artery, Percutaneous Endoscopic Approach */
"041C490" = "1" /* Bypass Right Common Iliac Artery to Abdominal Aorta with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C491" = "1" /* Bypass Right Common Iliac Artery to Celiac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C492" = "1" /* Bypass Right Common Iliac Artery to Mesenteric Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C493" = "1" /* Bypass Right Common Iliac Artery to Right Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C494" = "1" /* Bypass Right Common Iliac Artery to Left Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C495" = "1" /* Bypass Right Common Iliac Artery to Bilateral Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C496" = "1" /* Bypass Right Common Iliac Artery to Right Common Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C497" = "1" /* Bypass Right Common Iliac Artery to Left Common Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C498" = "1" /* Bypass Right Common Iliac Artery to Bilateral Common Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C499" = "1" /* Bypass Right Common Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C49B" = "1" /* Bypass Right Common Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C49C" = "1" /* Bypass Right Common Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C49D" = "1" /* Bypass Right Common Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C49F" = "1" /* Bypass Right Common Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C49G" = "1" /* Bypass Right Common Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C49H" = "1" /* Bypass Right Common Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C49J" = "1" /* Bypass Right Common Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C49K" = "1" /* Bypass Right Common Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C49Q" = "1" /* Bypass Right Common Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C49R" = "1" /* Bypass Right Common Iliac Artery to Lower Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C4A0" = "1" /* Bypass Right Common Iliac Artery to Abdominal Aorta with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4A1" = "1" /* Bypass Right Common Iliac Artery to Celiac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4A2" = "1" /* Bypass Right Common Iliac Artery to Mesenteric Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4A3" = "1" /* Bypass Right Common Iliac Artery to Right Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4A4" = "1" /* Bypass Right Common Iliac Artery to Left Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4A5" = "1" /* Bypass Right Common Iliac Artery to Bilateral Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4A6" = "1" /* Bypass Right Common Iliac Artery to Right Common Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4A7" = "1" /* Bypass Right Common Iliac Artery to Left Common Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4A8" = "1" /* Bypass Right Common Iliac Artery to Bilateral Common Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4A9" = "1" /* Bypass Right Common Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4AB" = "1" /* Bypass Right Common Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4AC" = "1" /* Bypass Right Common Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4AD" = "1" /* Bypass Right Common Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4AF" = "1" /* Bypass Right Common Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4AG" = "1" /* Bypass Right Common Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4AH" = "1" /* Bypass Right Common Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4AJ" = "1" /* Bypass Right Common Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4AK" = "1" /* Bypass Right Common Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4AQ" = "1" /* Bypass Right Common Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4AR" = "1" /* Bypass Right Common Iliac Artery to Lower Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4J0" = "1" /* Bypass Right Common Iliac Artery to Abdominal Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4J1" = "1" /* Bypass Right Common Iliac Artery to Celiac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4J2" = "1" /* Bypass Right Common Iliac Artery to Mesenteric Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4J3" = "1" /* Bypass Right Common Iliac Artery to Right Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4J4" = "1" /* Bypass Right Common Iliac Artery to Left Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4J5" = "1" /* Bypass Right Common Iliac Artery to Bilateral Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4J6" = "1" /* Bypass Right Common Iliac Artery to Right Common Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4J7" = "1" /* Bypass Right Common Iliac Artery to Left Common Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4J8" = "1" /* Bypass Right Common Iliac Artery to Bilateral Common Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4J9" = "1" /* Bypass Right Common Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4JB" = "1" /* Bypass Right Common Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4JC" = "1" /* Bypass Right Common Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4JD" = "1" /* Bypass Right Common Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4JF" = "1" /* Bypass Right Common Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4JG" = "1" /* Bypass Right Common Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4JH" = "1" /* Bypass Right Common Iliac Artery to Right Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4JJ" = "1" /* Bypass Right Common Iliac Artery to Left Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4JK" = "1" /* Bypass Right Common Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4JQ" = "1" /* Bypass Right Common Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4JR" = "1" /* Bypass Right Common Iliac Artery to Lower Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4K0" = "1" /* Bypass Right Common Iliac Artery to Abdominal Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4K1" = "1" /* Bypass Right Common Iliac Artery to Celiac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4K2" = "1" /* Bypass Right Common Iliac Artery to Mesenteric Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4K3" = "1" /* Bypass Right Common Iliac Artery to Right Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4K4" = "1" /* Bypass Right Common Iliac Artery to Left Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4K5" = "1" /* Bypass Right Common Iliac Artery to Bilateral Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4K6" = "1" /* Bypass Right Common Iliac Artery to Right Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4K7" = "1" /* Bypass Right Common Iliac Artery to Left Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4K8" = "1" /* Bypass Right Common Iliac Artery to Bilateral Common Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4K9" = "1" /* Bypass Right Common Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4KB" = "1" /* Bypass Right Common Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4KC" = "1" /* Bypass Right Common Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4KD" = "1" /* Bypass Right Common Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4KF" = "1" /* Bypass Right Common Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4KG" = "1" /* Bypass Right Common Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4KH" = "1" /* Bypass Right Common Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4KJ" = "1" /* Bypass Right Common Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4KK" = "1" /* Bypass Right Common Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4KQ" = "1" /* Bypass Right Common Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4KR" = "1" /* Bypass Right Common Iliac Artery to Lower Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4Z0" = "1" /* Bypass Right Common Iliac Artery to Abdominal Aorta, Percutaneous Endoscopic Approach */
"041C4Z1" = "1" /* Bypass Right Common Iliac Artery to Celiac Artery, Percutaneous Endoscopic Approach */
"041C4Z2" = "1" /* Bypass Right Common Iliac Artery to Mesenteric Artery, Percutaneous Endoscopic Approach */
"041C4Z3" = "1" /* Bypass Right Common Iliac Artery to Right Renal Artery, Percutaneous Endoscopic Approach */
"041C4Z4" = "1" /* Bypass Right Common Iliac Artery to Left Renal Artery, Percutaneous Endoscopic Approach */
"041C4Z5" = "1" /* Bypass Right Common Iliac Artery to Bilateral Renal Artery, Percutaneous Endoscopic Approach */
"041C4Z6" = "1" /* Bypass Right Common Iliac Artery to Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"041C4Z7" = "1" /* Bypass Right Common Iliac Artery to Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"041C4Z8" = "1" /* Bypass Right Common Iliac Artery to Bilateral Common Iliac Arteries, Percutaneous Endoscopic Approach */
"041C4Z9" = "1" /* Bypass Right Common Iliac Artery to Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041C4ZB" = "1" /* Bypass Right Common Iliac Artery to Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041C4ZC" = "1" /* Bypass Right Common Iliac Artery to Bilateral Internal Iliac Arteries, Percutaneous Endoscopic Approach */
"041C4ZD" = "1" /* Bypass Right Common Iliac Artery to Right External Iliac Artery, Percutaneous Endoscopic Approach */
"041C4ZF" = "1" /* Bypass Right Common Iliac Artery to Left External Iliac Artery, Percutaneous Endoscopic Approach */
"041C4ZG" = "1" /* Bypass Right Common Iliac Artery to Bilateral External Iliac Arteries, Percutaneous Endoscopic Approach */
"041C4ZH" = "1" /* Bypass Right Common Iliac Artery to Right Femoral Artery, Percutaneous Endoscopic Approach */
"041C4ZJ" = "1" /* Bypass Right Common Iliac Artery to Left Femoral Artery, Percutaneous Endoscopic Approach */
"041C4ZK" = "1" /* Bypass Right Common Iliac Artery to Bilateral Femoral Arteries, Percutaneous Endoscopic Approach */
"041C4ZQ" = "1" /* Bypass Right Common Iliac Artery to Lower Extremity Artery, Percutaneous Endoscopic Approach */
"041C4ZR" = "1" /* Bypass Right Common Iliac Artery to Lower Artery, Percutaneous Endoscopic Approach */
"041D490" = "1" /* Bypass Left Common Iliac Artery to Abdominal Aorta with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D491" = "1" /* Bypass Left Common Iliac Artery to Celiac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D492" = "1" /* Bypass Left Common Iliac Artery to Mesenteric Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D493" = "1" /* Bypass Left Common Iliac Artery to Right Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D494" = "1" /* Bypass Left Common Iliac Artery to Left Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D495" = "1" /* Bypass Left Common Iliac Artery to Bilateral Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D496" = "1" /* Bypass Left Common Iliac Artery to Right Common Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D497" = "1" /* Bypass Left Common Iliac Artery to Left Common Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D498" = "1" /* Bypass Left Common Iliac Artery to Bilateral Common Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D499" = "1" /* Bypass Left Common Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D49B" = "1" /* Bypass Left Common Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D49C" = "1" /* Bypass Left Common Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D49D" = "1" /* Bypass Left Common Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D49F" = "1" /* Bypass Left Common Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D49G" = "1" /* Bypass Left Common Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D49H" = "1" /* Bypass Left Common Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D49J" = "1" /* Bypass Left Common Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D49K" = "1" /* Bypass Left Common Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D49Q" = "1" /* Bypass Left Common Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D49R" = "1" /* Bypass Left Common Iliac Artery to Lower Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D4A0" = "1" /* Bypass Left Common Iliac Artery to Abdominal Aorta with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4A1" = "1" /* Bypass Left Common Iliac Artery to Celiac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4A2" = "1" /* Bypass Left Common Iliac Artery to Mesenteric Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4A3" = "1" /* Bypass Left Common Iliac Artery to Right Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4A4" = "1" /* Bypass Left Common Iliac Artery to Left Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4A5" = "1" /* Bypass Left Common Iliac Artery to Bilateral Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4A6" = "1" /* Bypass Left Common Iliac Artery to Right Common Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4A7" = "1" /* Bypass Left Common Iliac Artery to Left Common Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4A8" = "1" /* Bypass Left Common Iliac Artery to Bilateral Common Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4A9" = "1" /* Bypass Left Common Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4AB" = "1" /* Bypass Left Common Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4AC" = "1" /* Bypass Left Common Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4AD" = "1" /* Bypass Left Common Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4AF" = "1" /* Bypass Left Common Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4AG" = "1" /* Bypass Left Common Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4AH" = "1" /* Bypass Left Common Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4AJ" = "1" /* Bypass Left Common Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4AK" = "1" /* Bypass Left Common Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4AQ" = "1" /* Bypass Left Common Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4AR" = "1" /* Bypass Left Common Iliac Artery to Lower Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4J0" = "1" /* Bypass Left Common Iliac Artery to Abdominal Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4J1" = "1" /* Bypass Left Common Iliac Artery to Celiac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4J2" = "1" /* Bypass Left Common Iliac Artery to Mesenteric Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4J3" = "1" /* Bypass Left Common Iliac Artery to Right Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4J4" = "1" /* Bypass Left Common Iliac Artery to Left Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4J5" = "1" /* Bypass Left Common Iliac Artery to Bilateral Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4J6" = "1" /* Bypass Left Common Iliac Artery to Right Common Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4J7" = "1" /* Bypass Left Common Iliac Artery to Left Common Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4J8" = "1" /* Bypass Left Common Iliac Artery to Bilateral Common Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4J9" = "1" /* Bypass Left Common Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4JB" = "1" /* Bypass Left Common Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4JC" = "1" /* Bypass Left Common Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4JD" = "1" /* Bypass Left Common Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4JF" = "1" /* Bypass Left Common Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4JG" = "1" /* Bypass Left Common Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4JH" = "1" /* Bypass Left Common Iliac Artery to Right Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4JJ" = "1" /* Bypass Left Common Iliac Artery to Left Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4JK" = "1" /* Bypass Left Common Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4JQ" = "1" /* Bypass Left Common Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4JR" = "1" /* Bypass Left Common Iliac Artery to Lower Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4K0" = "1" /* Bypass Left Common Iliac Artery to Abdominal Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4K1" = "1" /* Bypass Left Common Iliac Artery to Celiac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4K2" = "1" /* Bypass Left Common Iliac Artery to Mesenteric Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4K3" = "1" /* Bypass Left Common Iliac Artery to Right Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4K4" = "1" /* Bypass Left Common Iliac Artery to Left Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4K5" = "1" /* Bypass Left Common Iliac Artery to Bilateral Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4K6" = "1" /* Bypass Left Common Iliac Artery to Right Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4K7" = "1" /* Bypass Left Common Iliac Artery to Left Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4K8" = "1" /* Bypass Left Common Iliac Artery to Bilateral Common Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4K9" = "1" /* Bypass Left Common Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4KB" = "1" /* Bypass Left Common Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4KC" = "1" /* Bypass Left Common Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4KD" = "1" /* Bypass Left Common Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4KF" = "1" /* Bypass Left Common Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4KG" = "1" /* Bypass Left Common Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4KH" = "1" /* Bypass Left Common Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4KJ" = "1" /* Bypass Left Common Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4KK" = "1" /* Bypass Left Common Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4KQ" = "1" /* Bypass Left Common Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4KR" = "1" /* Bypass Left Common Iliac Artery to Lower Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4Z0" = "1" /* Bypass Left Common Iliac Artery to Abdominal Aorta, Percutaneous Endoscopic Approach */
"041D4Z1" = "1" /* Bypass Left Common Iliac Artery to Celiac Artery, Percutaneous Endoscopic Approach */
"041D4Z2" = "1" /* Bypass Left Common Iliac Artery to Mesenteric Artery, Percutaneous Endoscopic Approach */
"041D4Z3" = "1" /* Bypass Left Common Iliac Artery to Right Renal Artery, Percutaneous Endoscopic Approach */
"041D4Z4" = "1" /* Bypass Left Common Iliac Artery to Left Renal Artery, Percutaneous Endoscopic Approach */
"041D4Z5" = "1" /* Bypass Left Common Iliac Artery to Bilateral Renal Artery, Percutaneous Endoscopic Approach */
"041D4Z6" = "1" /* Bypass Left Common Iliac Artery to Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"041D4Z7" = "1" /* Bypass Left Common Iliac Artery to Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"041D4Z8" = "1" /* Bypass Left Common Iliac Artery to Bilateral Common Iliac Arteries, Percutaneous Endoscopic Approach */
"041D4Z9" = "1" /* Bypass Left Common Iliac Artery to Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041D4ZB" = "1" /* Bypass Left Common Iliac Artery to Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041D4ZC" = "1" /* Bypass Left Common Iliac Artery to Bilateral Internal Iliac Arteries, Percutaneous Endoscopic Approach */
"041D4ZD" = "1" /* Bypass Left Common Iliac Artery to Right External Iliac Artery, Percutaneous Endoscopic Approach */
"041D4ZF" = "1" /* Bypass Left Common Iliac Artery to Left External Iliac Artery, Percutaneous Endoscopic Approach */
"041D4ZG" = "1" /* Bypass Left Common Iliac Artery to Bilateral External Iliac Arteries, Percutaneous Endoscopic Approach */
"041D4ZH" = "1" /* Bypass Left Common Iliac Artery to Right Femoral Artery, Percutaneous Endoscopic Approach */
"041D4ZJ" = "1" /* Bypass Left Common Iliac Artery to Left Femoral Artery, Percutaneous Endoscopic Approach */
"041D4ZK" = "1" /* Bypass Left Common Iliac Artery to Bilateral Femoral Arteries, Percutaneous Endoscopic Approach */
"041D4ZQ" = "1" /* Bypass Left Common Iliac Artery to Lower Extremity Artery, Percutaneous Endoscopic Approach */
"041D4ZR" = "1" /* Bypass Left Common Iliac Artery to Lower Artery, Percutaneous Endoscopic Approach */
"041E499" = "1" /* Bypass Right Internal Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041E49B" = "1" /* Bypass Right Internal Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041E49C" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041E49D" = "1" /* Bypass Right Internal Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041E49F" = "1" /* Bypass Right Internal Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041E49G" = "1" /* Bypass Right Internal Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041E49H" = "1" /* Bypass Right Internal Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041E49J" = "1" /* Bypass Right Internal Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041E49K" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041E49P" = "1" /* Bypass Right Internal Iliac Artery to Foot Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041E49Q" = "1" /* Bypass Right Internal Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041E4A9" = "1" /* Bypass Right Internal Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041E4AB" = "1" /* Bypass Right Internal Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041E4AC" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041E4AD" = "1" /* Bypass Right Internal Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041E4AF" = "1" /* Bypass Right Internal Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041E4AG" = "1" /* Bypass Right Internal Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041E4AH" = "1" /* Bypass Right Internal Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041E4AJ" = "1" /* Bypass Right Internal Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041E4AK" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041E4AP" = "1" /* Bypass Right Internal Iliac Artery to Foot Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041E4AQ" = "1" /* Bypass Right Internal Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041E4J9" = "1" /* Bypass Right Internal Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041E4JB" = "1" /* Bypass Right Internal Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041E4JC" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041E4JD" = "1" /* Bypass Right Internal Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041E4JF" = "1" /* Bypass Right Internal Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041E4JG" = "1" /* Bypass Right Internal Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041E4JH" = "1" /* Bypass Right Internal Iliac Artery to Right Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041E4JJ" = "1" /* Bypass Right Internal Iliac Artery to Left Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041E4JK" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041E4JP" = "1" /* Bypass Right Internal Iliac Artery to Foot Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041E4JQ" = "1" /* Bypass Right Internal Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041E4K9" = "1" /* Bypass Right Internal Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041E4KB" = "1" /* Bypass Right Internal Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041E4KC" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041E4KD" = "1" /* Bypass Right Internal Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041E4KF" = "1" /* Bypass Right Internal Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041E4KG" = "1" /* Bypass Right Internal Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041E4KH" = "1" /* Bypass Right Internal Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041E4KJ" = "1" /* Bypass Right Internal Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041E4KK" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041E4KP" = "1" /* Bypass Right Internal Iliac Artery to Foot Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041E4KQ" = "1" /* Bypass Right Internal Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041E4Z9" = "1" /* Bypass Right Internal Iliac Artery to Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041E4ZB" = "1" /* Bypass Right Internal Iliac Artery to Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041E4ZC" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Internal Iliac Arteries, Percutaneous Endoscopic Approach */
"041E4ZD" = "1" /* Bypass Right Internal Iliac Artery to Right External Iliac Artery, Percutaneous Endoscopic Approach */
"041E4ZF" = "1" /* Bypass Right Internal Iliac Artery to Left External Iliac Artery, Percutaneous Endoscopic Approach */
"041E4ZG" = "1" /* Bypass Right Internal Iliac Artery to Bilateral External Iliac Arteries, Percutaneous Endoscopic Approach */
"041E4ZH" = "1" /* Bypass Right Internal Iliac Artery to Right Femoral Artery, Percutaneous Endoscopic Approach */
"041E4ZJ" = "1" /* Bypass Right Internal Iliac Artery to Left Femoral Artery, Percutaneous Endoscopic Approach */
"041E4ZK" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Femoral Arteries, Percutaneous Endoscopic Approach */
"041E4ZP" = "1" /* Bypass Right Internal Iliac Artery to Foot Artery, Percutaneous Endoscopic Approach */
"041E4ZQ" = "1" /* Bypass Right Internal Iliac Artery to Lower Extremity Artery, Percutaneous Endoscopic Approach */
"041F499" = "1" /* Bypass Left Internal Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041F49B" = "1" /* Bypass Left Internal Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041F49C" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041F49D" = "1" /* Bypass Left Internal Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041F49F" = "1" /* Bypass Left Internal Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041F49G" = "1" /* Bypass Left Internal Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041F49H" = "1" /* Bypass Left Internal Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041F49J" = "1" /* Bypass Left Internal Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041F49K" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041F49P" = "1" /* Bypass Left Internal Iliac Artery to Foot Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041F49Q" = "1" /* Bypass Left Internal Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041F4A9" = "1" /* Bypass Left Internal Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041F4AB" = "1" /* Bypass Left Internal Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041F4AC" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041F4AD" = "1" /* Bypass Left Internal Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041F4AF" = "1" /* Bypass Left Internal Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041F4AG" = "1" /* Bypass Left Internal Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041F4AH" = "1" /* Bypass Left Internal Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041F4AJ" = "1" /* Bypass Left Internal Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041F4AK" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041F4AP" = "1" /* Bypass Left Internal Iliac Artery to Foot Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041F4AQ" = "1" /* Bypass Left Internal Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041F4J9" = "1" /* Bypass Left Internal Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041F4JB" = "1" /* Bypass Left Internal Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041F4JC" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041F4JD" = "1" /* Bypass Left Internal Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041F4JF" = "1" /* Bypass Left Internal Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041F4JG" = "1" /* Bypass Left Internal Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041F4JH" = "1" /* Bypass Left Internal Iliac Artery to Right Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041F4JJ" = "1" /* Bypass Left Internal Iliac Artery to Left Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041F4JK" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041F4JP" = "1" /* Bypass Left Internal Iliac Artery to Foot Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041F4JQ" = "1" /* Bypass Left Internal Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041F4K9" = "1" /* Bypass Left Internal Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041F4KB" = "1" /* Bypass Left Internal Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041F4KC" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041F4KD" = "1" /* Bypass Left Internal Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041F4KF" = "1" /* Bypass Left Internal Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041F4KG" = "1" /* Bypass Left Internal Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041F4KH" = "1" /* Bypass Left Internal Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041F4KJ" = "1" /* Bypass Left Internal Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041F4KK" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041F4KP" = "1" /* Bypass Left Internal Iliac Artery to Foot Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041F4KQ" = "1" /* Bypass Left Internal Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041F4Z9" = "1" /* Bypass Left Internal Iliac Artery to Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041F4ZB" = "1" /* Bypass Left Internal Iliac Artery to Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041F4ZC" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Internal Iliac Arteries, Percutaneous Endoscopic Approach */
"041F4ZD" = "1" /* Bypass Left Internal Iliac Artery to Right External Iliac Artery, Percutaneous Endoscopic Approach */
"041F4ZF" = "1" /* Bypass Left Internal Iliac Artery to Left External Iliac Artery, Percutaneous Endoscopic Approach */
"041F4ZG" = "1" /* Bypass Left Internal Iliac Artery to Bilateral External Iliac Arteries, Percutaneous Endoscopic Approach */
"041F4ZH" = "1" /* Bypass Left Internal Iliac Artery to Right Femoral Artery, Percutaneous Endoscopic Approach */
"041F4ZJ" = "1" /* Bypass Left Internal Iliac Artery to Left Femoral Artery, Percutaneous Endoscopic Approach */
"041F4ZK" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Femoral Arteries, Percutaneous Endoscopic Approach */
"041F4ZP" = "1" /* Bypass Left Internal Iliac Artery to Foot Artery, Percutaneous Endoscopic Approach */
"041F4ZQ" = "1" /* Bypass Left Internal Iliac Artery to Lower Extremity Artery, Percutaneous Endoscopic Approach */
"041H499" = "1" /* Bypass Right External Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041H49B" = "1" /* Bypass Right External Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041H49C" = "1" /* Bypass Right External Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041H49D" = "1" /* Bypass Right External Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041H49F" = "1" /* Bypass Right External Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041H49G" = "1" /* Bypass Right External Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041H49H" = "1" /* Bypass Right External Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041H49J" = "1" /* Bypass Right External Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041H49K" = "1" /* Bypass Right External Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041H49P" = "1" /* Bypass Right External Iliac Artery to Foot Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041H49Q" = "1" /* Bypass Right External Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041H4A9" = "1" /* Bypass Right External Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041H4AB" = "1" /* Bypass Right External Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041H4AC" = "1" /* Bypass Right External Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041H4AD" = "1" /* Bypass Right External Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041H4AF" = "1" /* Bypass Right External Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041H4AG" = "1" /* Bypass Right External Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041H4AH" = "1" /* Bypass Right External Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041H4AJ" = "1" /* Bypass Right External Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041H4AK" = "1" /* Bypass Right External Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041H4AP" = "1" /* Bypass Right External Iliac Artery to Foot Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041H4AQ" = "1" /* Bypass Right External Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041H4J9" = "1" /* Bypass Right External Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041H4JB" = "1" /* Bypass Right External Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041H4JC" = "1" /* Bypass Right External Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041H4JD" = "1" /* Bypass Right External Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041H4JF" = "1" /* Bypass Right External Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041H4JG" = "1" /* Bypass Right External Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041H4JH" = "1" /* Bypass Right External Iliac Artery to Right Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041H4JJ" = "1" /* Bypass Right External Iliac Artery to Left Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041H4JK" = "1" /* Bypass Right External Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041H4JP" = "1" /* Bypass Right External Iliac Artery to Foot Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041H4JQ" = "1" /* Bypass Right External Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041H4K9" = "1" /* Bypass Right External Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041H4KB" = "1" /* Bypass Right External Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041H4KC" = "1" /* Bypass Right External Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041H4KD" = "1" /* Bypass Right External Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041H4KF" = "1" /* Bypass Right External Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041H4KG" = "1" /* Bypass Right External Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041H4KH" = "1" /* Bypass Right External Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041H4KJ" = "1" /* Bypass Right External Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041H4KK" = "1" /* Bypass Right External Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041H4KP" = "1" /* Bypass Right External Iliac Artery to Foot Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041H4KQ" = "1" /* Bypass Right External Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041H4Z9" = "1" /* Bypass Right External Iliac Artery to Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041H4ZB" = "1" /* Bypass Right External Iliac Artery to Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041H4ZC" = "1" /* Bypass Right External Iliac Artery to Bilateral Internal Iliac Arteries, Percutaneous Endoscopic Approach */
"041H4ZD" = "1" /* Bypass Right External Iliac Artery to Right External Iliac Artery, Percutaneous Endoscopic Approach */
"041H4ZF" = "1" /* Bypass Right External Iliac Artery to Left External Iliac Artery, Percutaneous Endoscopic Approach */
"041H4ZG" = "1" /* Bypass Right External Iliac Artery to Bilateral External Iliac Arteries, Percutaneous Endoscopic Approach */
"041H4ZH" = "1" /* Bypass Right External Iliac Artery to Right Femoral Artery, Percutaneous Endoscopic Approach */
"041H4ZJ" = "1" /* Bypass Right External Iliac Artery to Left Femoral Artery, Percutaneous Endoscopic Approach */
"041H4ZK" = "1" /* Bypass Right External Iliac Artery to Bilateral Femoral Arteries, Percutaneous Endoscopic Approach */
"041H4ZP" = "1" /* Bypass Right External Iliac Artery to Foot Artery, Percutaneous Endoscopic Approach */
"041H4ZQ" = "1" /* Bypass Right External Iliac Artery to Lower Extremity Artery, Percutaneous Endoscopic Approach */
"041J499" = "1" /* Bypass Left External Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041J49B" = "1" /* Bypass Left External Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041J49C" = "1" /* Bypass Left External Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041J49D" = "1" /* Bypass Left External Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041J49F" = "1" /* Bypass Left External Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041J49G" = "1" /* Bypass Left External Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041J49H" = "1" /* Bypass Left External Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041J49J" = "1" /* Bypass Left External Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041J49K" = "1" /* Bypass Left External Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041J49P" = "1" /* Bypass Left External Iliac Artery to Foot Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041J49Q" = "1" /* Bypass Left External Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041J4A9" = "1" /* Bypass Left External Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041J4AB" = "1" /* Bypass Left External Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041J4AC" = "1" /* Bypass Left External Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041J4AD" = "1" /* Bypass Left External Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041J4AF" = "1" /* Bypass Left External Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041J4AG" = "1" /* Bypass Left External Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041J4AH" = "1" /* Bypass Left External Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041J4AJ" = "1" /* Bypass Left External Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041J4AK" = "1" /* Bypass Left External Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041J4AP" = "1" /* Bypass Left External Iliac Artery to Foot Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041J4AQ" = "1" /* Bypass Left External Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041J4J9" = "1" /* Bypass Left External Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041J4JB" = "1" /* Bypass Left External Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041J4JC" = "1" /* Bypass Left External Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041J4JD" = "1" /* Bypass Left External Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041J4JF" = "1" /* Bypass Left External Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041J4JG" = "1" /* Bypass Left External Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041J4JH" = "1" /* Bypass Left External Iliac Artery to Right Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041J4JJ" = "1" /* Bypass Left External Iliac Artery to Left Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041J4JK" = "1" /* Bypass Left External Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041J4JP" = "1" /* Bypass Left External Iliac Artery to Foot Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041J4JQ" = "1" /* Bypass Left External Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041J4K9" = "1" /* Bypass Left External Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041J4KB" = "1" /* Bypass Left External Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041J4KC" = "1" /* Bypass Left External Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041J4KD" = "1" /* Bypass Left External Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041J4KF" = "1" /* Bypass Left External Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041J4KG" = "1" /* Bypass Left External Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041J4KH" = "1" /* Bypass Left External Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041J4KJ" = "1" /* Bypass Left External Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041J4KK" = "1" /* Bypass Left External Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041J4KP" = "1" /* Bypass Left External Iliac Artery to Foot Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041J4KQ" = "1" /* Bypass Left External Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041J4Z9" = "1" /* Bypass Left External Iliac Artery to Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041J4ZB" = "1" /* Bypass Left External Iliac Artery to Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041J4ZC" = "1" /* Bypass Left External Iliac Artery to Bilateral Internal Iliac Arteries, Percutaneous Endoscopic Approach */
"041J4ZD" = "1" /* Bypass Left External Iliac Artery to Right External Iliac Artery, Percutaneous Endoscopic Approach */
"041J4ZF" = "1" /* Bypass Left External Iliac Artery to Left External Iliac Artery, Percutaneous Endoscopic Approach */
"041J4ZG" = "1" /* Bypass Left External Iliac Artery to Bilateral External Iliac Arteries, Percutaneous Endoscopic Approach */
"041J4ZH" = "1" /* Bypass Left External Iliac Artery to Right Femoral Artery, Percutaneous Endoscopic Approach */
"041J4ZJ" = "1" /* Bypass Left External Iliac Artery to Left Femoral Artery, Percutaneous Endoscopic Approach */
"041J4ZK" = "1" /* Bypass Left External Iliac Artery to Bilateral Femoral Arteries, Percutaneous Endoscopic Approach */
"041J4ZP" = "1" /* Bypass Left External Iliac Artery to Foot Artery, Percutaneous Endoscopic Approach */
"041J4ZQ" = "1" /* Bypass Left External Iliac Artery to Lower Extremity Artery, Percutaneous Endoscopic Approach */
"04503ZZ" = "1" /* Destruction of Abdominal Aorta, Percutaneous Approach */
"04504ZZ" = "1" /* Destruction of Abdominal Aorta, Percutaneous Endoscopic Approach */
"04513ZZ" = "1" /* Destruction of Celiac Artery, Percutaneous Approach */
"04514ZZ" = "1" /* Destruction of Celiac Artery, Percutaneous Endoscopic Approach */
"04523ZZ" = "1" /* Destruction of Gastric Artery, Percutaneous Approach */
"04524ZZ" = "1" /* Destruction of Gastric Artery, Percutaneous Endoscopic Approach */
"04533ZZ" = "1" /* Destruction of Hepatic Artery, Percutaneous Approach */
"04534ZZ" = "1" /* Destruction of Hepatic Artery, Percutaneous Endoscopic Approach */
"04543ZZ" = "1" /* Destruction of Splenic Artery, Percutaneous Approach */
"04544ZZ" = "1" /* Destruction of Splenic Artery, Percutaneous Endoscopic Approach */
"04553ZZ" = "1" /* Destruction of Superior Mesenteric Artery, Percutaneous Approach */
"04554ZZ" = "1" /* Destruction of Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04563ZZ" = "1" /* Destruction of Right Colic Artery, Percutaneous Approach */
"04564ZZ" = "1" /* Destruction of Right Colic Artery, Percutaneous Endoscopic Approach */
"04573ZZ" = "1" /* Destruction of Left Colic Artery, Percutaneous Approach */
"04574ZZ" = "1" /* Destruction of Left Colic Artery, Percutaneous Endoscopic Approach */
"04583ZZ" = "1" /* Destruction of Middle Colic Artery, Percutaneous Approach */
"04584ZZ" = "1" /* Destruction of Middle Colic Artery, Percutaneous Endoscopic Approach */
"04593ZZ" = "1" /* Destruction of Right Renal Artery, Percutaneous Approach */
"04594ZZ" = "1" /* Destruction of Right Renal Artery, Percutaneous Endoscopic Approach */
"045A3ZZ" = "1" /* Destruction of Left Renal Artery, Percutaneous Approach */
"045A4ZZ" = "1" /* Destruction of Left Renal Artery, Percutaneous Endoscopic Approach */
"045B3ZZ" = "1" /* Destruction of Inferior Mesenteric Artery, Percutaneous Approach */
"045B4ZZ" = "1" /* Destruction of Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"045C3ZZ" = "1" /* Destruction of Right Common Iliac Artery, Percutaneous Approach */
"045C4ZZ" = "1" /* Destruction of Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"045D3ZZ" = "1" /* Destruction of Left Common Iliac Artery, Percutaneous Approach */
"045D4ZZ" = "1" /* Destruction of Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"045E3ZZ" = "1" /* Destruction of Right Internal Iliac Artery, Percutaneous Approach */
"045E4ZZ" = "1" /* Destruction of Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"045F3ZZ" = "1" /* Destruction of Left Internal Iliac Artery, Percutaneous Approach */
"045F4ZZ" = "1" /* Destruction of Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"045H3ZZ" = "1" /* Destruction of Right External Iliac Artery, Percutaneous Approach */
"045H4ZZ" = "1" /* Destruction of Right External Iliac Artery, Percutaneous Endoscopic Approach */
"045J3ZZ" = "1" /* Destruction of Left External Iliac Artery, Percutaneous Approach */
"045J4ZZ" = "1" /* Destruction of Left External Iliac Artery, Percutaneous Endoscopic Approach */
"0470446" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047044Z" = "1" /* Dilation of Abdominal Aorta with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0470456" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047045Z" = "1" /* Dilation of Abdominal Aorta with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0470466" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047046Z" = "1" /* Dilation of Abdominal Aorta with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0470476" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047047Z" = "1" /* Dilation of Abdominal Aorta with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"04704D6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"04704DZ" = "1" /* Dilation of Abdominal Aorta with Intraluminal Device, Percutaneous Endoscopic Approach */
"04704E6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04704EZ" = "1" /* Dilation of Abdominal Aorta with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04704F6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04704FZ" = "1" /* Dilation of Abdominal Aorta with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04704G6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04704GZ" = "1" /* Dilation of Abdominal Aorta with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04704Z6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, Percutaneous Endoscopic Approach */
"04704ZZ" = "1" /* Dilation of Abdominal Aorta, Percutaneous Endoscopic Approach */
"0471446" = "1" /* Dilation of Celiac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047144Z" = "1" /* Dilation of Celiac Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0471456" = "1" /* Dilation of Celiac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047145Z" = "1" /* Dilation of Celiac Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0471466" = "1" /* Dilation of Celiac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047146Z" = "1" /* Dilation of Celiac Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0471476" = "1" /* Dilation of Celiac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047147Z" = "1" /* Dilation of Celiac Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"04714D6" = "1" /* Dilation of Celiac Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"04714DZ" = "1" /* Dilation of Celiac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04714E6" = "1" /* Dilation of Celiac Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04714EZ" = "1" /* Dilation of Celiac Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04714F6" = "1" /* Dilation of Celiac Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04714FZ" = "1" /* Dilation of Celiac Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04714G6" = "1" /* Dilation of Celiac Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04714GZ" = "1" /* Dilation of Celiac Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04714Z6" = "1" /* Dilation of Celiac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04714ZZ" = "1" /* Dilation of Celiac Artery, Percutaneous Endoscopic Approach */
"0472446" = "1" /* Dilation of Gastric Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047244Z" = "1" /* Dilation of Gastric Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0472456" = "1" /* Dilation of Gastric Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047245Z" = "1" /* Dilation of Gastric Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0472466" = "1" /* Dilation of Gastric Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047246Z" = "1" /* Dilation of Gastric Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0472476" = "1" /* Dilation of Gastric Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047247Z" = "1" /* Dilation of Gastric Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"04724D6" = "1" /* Dilation of Gastric Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"04724DZ" = "1" /* Dilation of Gastric Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04724E6" = "1" /* Dilation of Gastric Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04724EZ" = "1" /* Dilation of Gastric Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04724F6" = "1" /* Dilation of Gastric Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04724FZ" = "1" /* Dilation of Gastric Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04724G6" = "1" /* Dilation of Gastric Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04724GZ" = "1" /* Dilation of Gastric Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04724Z6" = "1" /* Dilation of Gastric Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04724ZZ" = "1" /* Dilation of Gastric Artery, Percutaneous Endoscopic Approach */
"0473446" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047344Z" = "1" /* Dilation of Hepatic Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0473456" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047345Z" = "1" /* Dilation of Hepatic Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0473466" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047346Z" = "1" /* Dilation of Hepatic Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0473476" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047347Z" = "1" /* Dilation of Hepatic Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"04734D6" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"04734DZ" = "1" /* Dilation of Hepatic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04734E6" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04734EZ" = "1" /* Dilation of Hepatic Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04734F6" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04734FZ" = "1" /* Dilation of Hepatic Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04734G6" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04734GZ" = "1" /* Dilation of Hepatic Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04734Z6" = "1" /* Dilation of Hepatic Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04734ZZ" = "1" /* Dilation of Hepatic Artery, Percutaneous Endoscopic Approach */
"0474446" = "1" /* Dilation of Splenic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047444Z" = "1" /* Dilation of Splenic Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0474456" = "1" /* Dilation of Splenic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047445Z" = "1" /* Dilation of Splenic Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0474466" = "1" /* Dilation of Splenic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047446Z" = "1" /* Dilation of Splenic Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0474476" = "1" /* Dilation of Splenic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047447Z" = "1" /* Dilation of Splenic Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"04744D6" = "1" /* Dilation of Splenic Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"04744DZ" = "1" /* Dilation of Splenic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04744E6" = "1" /* Dilation of Splenic Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04744EZ" = "1" /* Dilation of Splenic Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04744F6" = "1" /* Dilation of Splenic Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04744FZ" = "1" /* Dilation of Splenic Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04744G6" = "1" /* Dilation of Splenic Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04744GZ" = "1" /* Dilation of Splenic Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04744Z6" = "1" /* Dilation of Splenic Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04744ZZ" = "1" /* Dilation of Splenic Artery, Percutaneous Endoscopic Approach */
"0475446" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047544Z" = "1" /* Dilation of Superior Mesenteric Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0475456" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047545Z" = "1" /* Dilation of Superior Mesenteric Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0475466" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047546Z" = "1" /* Dilation of Superior Mesenteric Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0475476" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047547Z" = "1" /* Dilation of Superior Mesenteric Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"04754D6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"04754DZ" = "1" /* Dilation of Superior Mesenteric Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04754E6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04754EZ" = "1" /* Dilation of Superior Mesenteric Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04754F6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04754FZ" = "1" /* Dilation of Superior Mesenteric Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04754G6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04754GZ" = "1" /* Dilation of Superior Mesenteric Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04754Z6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04754ZZ" = "1" /* Dilation of Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"0476446" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047644Z" = "1" /* Dilation of Right Colic Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0476456" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047645Z" = "1" /* Dilation of Right Colic Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0476466" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047646Z" = "1" /* Dilation of Right Colic Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0476476" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047647Z" = "1" /* Dilation of Right Colic Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"04764D6" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"04764DZ" = "1" /* Dilation of Right Colic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04764E6" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04764EZ" = "1" /* Dilation of Right Colic Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04764F6" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04764FZ" = "1" /* Dilation of Right Colic Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04764G6" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04764GZ" = "1" /* Dilation of Right Colic Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04764Z6" = "1" /* Dilation of Right Colic Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04764ZZ" = "1" /* Dilation of Right Colic Artery, Percutaneous Endoscopic Approach */
"0477446" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047744Z" = "1" /* Dilation of Left Colic Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0477456" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047745Z" = "1" /* Dilation of Left Colic Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0477466" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047746Z" = "1" /* Dilation of Left Colic Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0477476" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047747Z" = "1" /* Dilation of Left Colic Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"04774D6" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"04774DZ" = "1" /* Dilation of Left Colic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04774E6" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04774EZ" = "1" /* Dilation of Left Colic Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04774F6" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04774FZ" = "1" /* Dilation of Left Colic Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04774G6" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04774GZ" = "1" /* Dilation of Left Colic Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04774Z6" = "1" /* Dilation of Left Colic Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04774ZZ" = "1" /* Dilation of Left Colic Artery, Percutaneous Endoscopic Approach */
"0478446" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047844Z" = "1" /* Dilation of Middle Colic Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0478456" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047845Z" = "1" /* Dilation of Middle Colic Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0478466" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047846Z" = "1" /* Dilation of Middle Colic Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0478476" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047847Z" = "1" /* Dilation of Middle Colic Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"04784D6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"04784DZ" = "1" /* Dilation of Middle Colic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04784E6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04784EZ" = "1" /* Dilation of Middle Colic Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04784F6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04784FZ" = "1" /* Dilation of Middle Colic Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04784G6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04784GZ" = "1" /* Dilation of Middle Colic Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04784Z6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04784ZZ" = "1" /* Dilation of Middle Colic Artery, Percutaneous Endoscopic Approach */
"0479446" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047944Z" = "1" /* Dilation of Right Renal Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0479456" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047945Z" = "1" /* Dilation of Right Renal Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0479466" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047946Z" = "1" /* Dilation of Right Renal Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0479476" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047947Z" = "1" /* Dilation of Right Renal Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"04794D6" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"04794DZ" = "1" /* Dilation of Right Renal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04794E6" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04794EZ" = "1" /* Dilation of Right Renal Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04794F6" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04794FZ" = "1" /* Dilation of Right Renal Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04794G6" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04794GZ" = "1" /* Dilation of Right Renal Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04794Z6" = "1" /* Dilation of Right Renal Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04794ZZ" = "1" /* Dilation of Right Renal Artery, Percutaneous Endoscopic Approach */
"047A446" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047A44Z" = "1" /* Dilation of Left Renal Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047A456" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A45Z" = "1" /* Dilation of Left Renal Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A466" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A46Z" = "1" /* Dilation of Left Renal Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A476" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A47Z" = "1" /* Dilation of Left Renal Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A4D6" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047A4DZ" = "1" /* Dilation of Left Renal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047A4E6" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A4EZ" = "1" /* Dilation of Left Renal Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A4F6" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A4FZ" = "1" /* Dilation of Left Renal Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A4G6" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A4GZ" = "1" /* Dilation of Left Renal Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A4Z6" = "1" /* Dilation of Left Renal Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047A4ZZ" = "1" /* Dilation of Left Renal Artery, Percutaneous Endoscopic Approach */
"047B446" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047B44Z" = "1" /* Dilation of Inferior Mesenteric Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047B456" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B45Z" = "1" /* Dilation of Inferior Mesenteric Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B466" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B46Z" = "1" /* Dilation of Inferior Mesenteric Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B476" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B47Z" = "1" /* Dilation of Inferior Mesenteric Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B4D6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047B4DZ" = "1" /* Dilation of Inferior Mesenteric Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047B4E6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B4EZ" = "1" /* Dilation of Inferior Mesenteric Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B4F6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B4FZ" = "1" /* Dilation of Inferior Mesenteric Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B4G6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B4GZ" = "1" /* Dilation of Inferior Mesenteric Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B4Z6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047B4ZZ" = "1" /* Dilation of Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"047C446" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047C44Z" = "1" /* Dilation of Right Common Iliac Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047C456" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C45Z" = "1" /* Dilation of Right Common Iliac Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C466" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C46Z" = "1" /* Dilation of Right Common Iliac Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C476" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C47Z" = "1" /* Dilation of Right Common Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C4D6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047C4DZ" = "1" /* Dilation of Right Common Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047C4E6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C4EZ" = "1" /* Dilation of Right Common Iliac Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C4F6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C4FZ" = "1" /* Dilation of Right Common Iliac Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C4G6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C4GZ" = "1" /* Dilation of Right Common Iliac Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C4Z6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047C4ZZ" = "1" /* Dilation of Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"047D446" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047D44Z" = "1" /* Dilation of Left Common Iliac Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047D456" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D45Z" = "1" /* Dilation of Left Common Iliac Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D466" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D46Z" = "1" /* Dilation of Left Common Iliac Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D476" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D47Z" = "1" /* Dilation of Left Common Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D4D6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047D4DZ" = "1" /* Dilation of Left Common Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047D4E6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D4EZ" = "1" /* Dilation of Left Common Iliac Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D4F6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D4FZ" = "1" /* Dilation of Left Common Iliac Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D4G6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D4GZ" = "1" /* Dilation of Left Common Iliac Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D4Z6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047D4ZZ" = "1" /* Dilation of Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"047E446" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047E44Z" = "1" /* Dilation of Right Internal Iliac Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047E456" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E45Z" = "1" /* Dilation of Right Internal Iliac Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E466" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E46Z" = "1" /* Dilation of Right Internal Iliac Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E476" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E47Z" = "1" /* Dilation of Right Internal Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E4D6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047E4DZ" = "1" /* Dilation of Right Internal Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047E4E6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E4EZ" = "1" /* Dilation of Right Internal Iliac Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E4F6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E4FZ" = "1" /* Dilation of Right Internal Iliac Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E4G6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E4GZ" = "1" /* Dilation of Right Internal Iliac Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E4Z6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047E4ZZ" = "1" /* Dilation of Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"047F446" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047F44Z" = "1" /* Dilation of Left Internal Iliac Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047F456" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F45Z" = "1" /* Dilation of Left Internal Iliac Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F466" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F46Z" = "1" /* Dilation of Left Internal Iliac Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F476" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F47Z" = "1" /* Dilation of Left Internal Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F4D6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047F4DZ" = "1" /* Dilation of Left Internal Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047F4E6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F4EZ" = "1" /* Dilation of Left Internal Iliac Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F4F6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F4FZ" = "1" /* Dilation of Left Internal Iliac Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F4G6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F4GZ" = "1" /* Dilation of Left Internal Iliac Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F4Z6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047F4ZZ" = "1" /* Dilation of Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"047H446" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047H44Z" = "1" /* Dilation of Right External Iliac Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047H456" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H45Z" = "1" /* Dilation of Right External Iliac Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H466" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H46Z" = "1" /* Dilation of Right External Iliac Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H476" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H47Z" = "1" /* Dilation of Right External Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H4D6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047H4DZ" = "1" /* Dilation of Right External Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047H4E6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H4EZ" = "1" /* Dilation of Right External Iliac Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H4F6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H4FZ" = "1" /* Dilation of Right External Iliac Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H4G6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H4GZ" = "1" /* Dilation of Right External Iliac Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H4Z6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047H4ZZ" = "1" /* Dilation of Right External Iliac Artery, Percutaneous Endoscopic Approach */
"047J446" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047J44Z" = "1" /* Dilation of Left External Iliac Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047J456" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J45Z" = "1" /* Dilation of Left External Iliac Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J466" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J46Z" = "1" /* Dilation of Left External Iliac Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J476" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J47Z" = "1" /* Dilation of Left External Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J4D6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047J4DZ" = "1" /* Dilation of Left External Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047J4E6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J4EZ" = "1" /* Dilation of Left External Iliac Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J4F6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J4FZ" = "1" /* Dilation of Left External Iliac Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J4G6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J4GZ" = "1" /* Dilation of Left External Iliac Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J4Z6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047J4ZZ" = "1" /* Dilation of Left External Iliac Artery, Percutaneous Endoscopic Approach */
"049040Z" = "1" /* Drainage of Abdominal Aorta with Drainage Device, Percutaneous Endoscopic Approach */
"04904ZX" = "1" /* Drainage of Abdominal Aorta, Percutaneous Endoscopic Approach, Diagnostic */
"04904ZZ" = "1" /* Drainage of Abdominal Aorta, Percutaneous Endoscopic Approach */
"049140Z" = "1" /* Drainage of Celiac Artery with Drainage Device, Percutaneous Endoscopic Approach */
"04914ZX" = "1" /* Drainage of Celiac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04914ZZ" = "1" /* Drainage of Celiac Artery, Percutaneous Endoscopic Approach */
"049240Z" = "1" /* Drainage of Gastric Artery with Drainage Device, Percutaneous Endoscopic Approach */
"04924ZX" = "1" /* Drainage of Gastric Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04924ZZ" = "1" /* Drainage of Gastric Artery, Percutaneous Endoscopic Approach */
"049340Z" = "1" /* Drainage of Hepatic Artery with Drainage Device, Percutaneous Endoscopic Approach */
"04934ZX" = "1" /* Drainage of Hepatic Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04934ZZ" = "1" /* Drainage of Hepatic Artery, Percutaneous Endoscopic Approach */
"049440Z" = "1" /* Drainage of Splenic Artery with Drainage Device, Percutaneous Endoscopic Approach */
"04944ZX" = "1" /* Drainage of Splenic Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04944ZZ" = "1" /* Drainage of Splenic Artery, Percutaneous Endoscopic Approach */
"049540Z" = "1" /* Drainage of Superior Mesenteric Artery with Drainage Device, Percutaneous Endoscopic Approach */
"04954ZX" = "1" /* Drainage of Superior Mesenteric Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04954ZZ" = "1" /* Drainage of Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"049640Z" = "1" /* Drainage of Right Colic Artery with Drainage Device, Percutaneous Endoscopic Approach */
"04964ZX" = "1" /* Drainage of Right Colic Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04964ZZ" = "1" /* Drainage of Right Colic Artery, Percutaneous Endoscopic Approach */
"049740Z" = "1" /* Drainage of Left Colic Artery with Drainage Device, Percutaneous Endoscopic Approach */
"04974ZX" = "1" /* Drainage of Left Colic Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04974ZZ" = "1" /* Drainage of Left Colic Artery, Percutaneous Endoscopic Approach */
"049840Z" = "1" /* Drainage of Middle Colic Artery with Drainage Device, Percutaneous Endoscopic Approach */
"04984ZX" = "1" /* Drainage of Middle Colic Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04984ZZ" = "1" /* Drainage of Middle Colic Artery, Percutaneous Endoscopic Approach */
"049940Z" = "1" /* Drainage of Right Renal Artery with Drainage Device, Percutaneous Endoscopic Approach */
"04994ZX" = "1" /* Drainage of Right Renal Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04994ZZ" = "1" /* Drainage of Right Renal Artery, Percutaneous Endoscopic Approach */
"049A40Z" = "1" /* Drainage of Left Renal Artery with Drainage Device, Percutaneous Endoscopic Approach */
"049A4ZX" = "1" /* Drainage of Left Renal Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049A4ZZ" = "1" /* Drainage of Left Renal Artery, Percutaneous Endoscopic Approach */
"049B40Z" = "1" /* Drainage of Inferior Mesenteric Artery with Drainage Device, Percutaneous Endoscopic Approach */
"049B4ZX" = "1" /* Drainage of Inferior Mesenteric Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049B4ZZ" = "1" /* Drainage of Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"049C40Z" = "1" /* Drainage of Right Common Iliac Artery with Drainage Device, Percutaneous Endoscopic Approach */
"049C4ZX" = "1" /* Drainage of Right Common Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049C4ZZ" = "1" /* Drainage of Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"049D40Z" = "1" /* Drainage of Left Common Iliac Artery with Drainage Device, Percutaneous Endoscopic Approach */
"049D4ZX" = "1" /* Drainage of Left Common Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049D4ZZ" = "1" /* Drainage of Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"049E40Z" = "1" /* Drainage of Right Internal Iliac Artery with Drainage Device, Percutaneous Endoscopic Approach */
"049E4ZX" = "1" /* Drainage of Right Internal Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049E4ZZ" = "1" /* Drainage of Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"049F40Z" = "1" /* Drainage of Left Internal Iliac Artery with Drainage Device, Percutaneous Endoscopic Approach */
"049F4ZX" = "1" /* Drainage of Left Internal Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049F4ZZ" = "1" /* Drainage of Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"049H40Z" = "1" /* Drainage of Right External Iliac Artery with Drainage Device, Percutaneous Endoscopic Approach */
"049H4ZX" = "1" /* Drainage of Right External Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049H4ZZ" = "1" /* Drainage of Right External Iliac Artery, Percutaneous Endoscopic Approach */
"049J40Z" = "1" /* Drainage of Left External Iliac Artery with Drainage Device, Percutaneous Endoscopic Approach */
"049J4ZX" = "1" /* Drainage of Left External Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049J4ZZ" = "1" /* Drainage of Left External Iliac Artery, Percutaneous Endoscopic Approach */
"04B03ZX" = "1" /* Excision of Abdominal Aorta, Percutaneous Approach, Diagnostic */
"04B03ZZ" = "1" /* Excision of Abdominal Aorta, Percutaneous Approach */
"04B04ZX" = "1" /* Excision of Abdominal Aorta, Percutaneous Endoscopic Approach, Diagnostic */
"04B04ZZ" = "1" /* Excision of Abdominal Aorta, Percutaneous Endoscopic Approach */
"04B13ZX" = "1" /* Excision of Celiac Artery, Percutaneous Approach, Diagnostic */
"04B13ZZ" = "1" /* Excision of Celiac Artery, Percutaneous Approach */
"04B14ZX" = "1" /* Excision of Celiac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04B14ZZ" = "1" /* Excision of Celiac Artery, Percutaneous Endoscopic Approach */
"04B23ZX" = "1" /* Excision of Gastric Artery, Percutaneous Approach, Diagnostic */
"04B23ZZ" = "1" /* Excision of Gastric Artery, Percutaneous Approach */
"04B24ZX" = "1" /* Excision of Gastric Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04B24ZZ" = "1" /* Excision of Gastric Artery, Percutaneous Endoscopic Approach */
"04B33ZX" = "1" /* Excision of Hepatic Artery, Percutaneous Approach, Diagnostic */
"04B33ZZ" = "1" /* Excision of Hepatic Artery, Percutaneous Approach */
"04B34ZX" = "1" /* Excision of Hepatic Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04B34ZZ" = "1" /* Excision of Hepatic Artery, Percutaneous Endoscopic Approach */
"04B43ZX" = "1" /* Excision of Splenic Artery, Percutaneous Approach, Diagnostic */
"04B43ZZ" = "1" /* Excision of Splenic Artery, Percutaneous Approach */
"04B44ZX" = "1" /* Excision of Splenic Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04B44ZZ" = "1" /* Excision of Splenic Artery, Percutaneous Endoscopic Approach */
"04B53ZX" = "1" /* Excision of Superior Mesenteric Artery, Percutaneous Approach, Diagnostic */
"04B53ZZ" = "1" /* Excision of Superior Mesenteric Artery, Percutaneous Approach */
"04B54ZX" = "1" /* Excision of Superior Mesenteric Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04B54ZZ" = "1" /* Excision of Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04B63ZX" = "1" /* Excision of Right Colic Artery, Percutaneous Approach, Diagnostic */
"04B63ZZ" = "1" /* Excision of Right Colic Artery, Percutaneous Approach */
"04B64ZX" = "1" /* Excision of Right Colic Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04B64ZZ" = "1" /* Excision of Right Colic Artery, Percutaneous Endoscopic Approach */
"04B73ZX" = "1" /* Excision of Left Colic Artery, Percutaneous Approach, Diagnostic */
"04B73ZZ" = "1" /* Excision of Left Colic Artery, Percutaneous Approach */
"04B74ZX" = "1" /* Excision of Left Colic Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04B74ZZ" = "1" /* Excision of Left Colic Artery, Percutaneous Endoscopic Approach */
"04B83ZX" = "1" /* Excision of Middle Colic Artery, Percutaneous Approach, Diagnostic */
"04B83ZZ" = "1" /* Excision of Middle Colic Artery, Percutaneous Approach */
"04B84ZX" = "1" /* Excision of Middle Colic Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04B84ZZ" = "1" /* Excision of Middle Colic Artery, Percutaneous Endoscopic Approach */
"04B93ZX" = "1" /* Excision of Right Renal Artery, Percutaneous Approach, Diagnostic */
"04B93ZZ" = "1" /* Excision of Right Renal Artery, Percutaneous Approach */
"04B94ZX" = "1" /* Excision of Right Renal Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04B94ZZ" = "1" /* Excision of Right Renal Artery, Percutaneous Endoscopic Approach */
"04BA3ZX" = "1" /* Excision of Left Renal Artery, Percutaneous Approach, Diagnostic */
"04BA3ZZ" = "1" /* Excision of Left Renal Artery, Percutaneous Approach */
"04BA4ZX" = "1" /* Excision of Left Renal Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BA4ZZ" = "1" /* Excision of Left Renal Artery, Percutaneous Endoscopic Approach */
"04BB3ZX" = "1" /* Excision of Inferior Mesenteric Artery, Percutaneous Approach, Diagnostic */
"04BB3ZZ" = "1" /* Excision of Inferior Mesenteric Artery, Percutaneous Approach */
"04BB4ZX" = "1" /* Excision of Inferior Mesenteric Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BB4ZZ" = "1" /* Excision of Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04BC3ZX" = "1" /* Excision of Right Common Iliac Artery, Percutaneous Approach, Diagnostic */
"04BC3ZZ" = "1" /* Excision of Right Common Iliac Artery, Percutaneous Approach */
"04BC4ZX" = "1" /* Excision of Right Common Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BC4ZZ" = "1" /* Excision of Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"04BD3ZX" = "1" /* Excision of Left Common Iliac Artery, Percutaneous Approach, Diagnostic */
"04BD3ZZ" = "1" /* Excision of Left Common Iliac Artery, Percutaneous Approach */
"04BD4ZX" = "1" /* Excision of Left Common Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BD4ZZ" = "1" /* Excision of Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"04BE3ZX" = "1" /* Excision of Right Internal Iliac Artery, Percutaneous Approach, Diagnostic */
"04BE3ZZ" = "1" /* Excision of Right Internal Iliac Artery, Percutaneous Approach */
"04BE4ZX" = "1" /* Excision of Right Internal Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BE4ZZ" = "1" /* Excision of Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04BF3ZX" = "1" /* Excision of Left Internal Iliac Artery, Percutaneous Approach, Diagnostic */
"04BF3ZZ" = "1" /* Excision of Left Internal Iliac Artery, Percutaneous Approach */
"04BF4ZX" = "1" /* Excision of Left Internal Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BF4ZZ" = "1" /* Excision of Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04BH3ZX" = "1" /* Excision of Right External Iliac Artery, Percutaneous Approach, Diagnostic */
"04BH3ZZ" = "1" /* Excision of Right External Iliac Artery, Percutaneous Approach */
"04BH4ZX" = "1" /* Excision of Right External Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BH4ZZ" = "1" /* Excision of Right External Iliac Artery, Percutaneous Endoscopic Approach */
"04BJ3ZX" = "1" /* Excision of Left External Iliac Artery, Percutaneous Approach, Diagnostic */
"04BJ3ZZ" = "1" /* Excision of Left External Iliac Artery, Percutaneous Approach */
"04BJ4ZX" = "1" /* Excision of Left External Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BJ4ZZ" = "1" /* Excision of Left External Iliac Artery, Percutaneous Endoscopic Approach */
"04C04Z6" = "1" /* Extirpation of Matter from Abdominal Aorta, Bifurcation, Percutaneous Endoscopic Approach */
"04C04ZZ" = "1" /* Extirpation of Matter from Abdominal Aorta, Percutaneous Endoscopic Approach */
"04C14Z6" = "1" /* Extirpation of Matter from Celiac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04C14ZZ" = "1" /* Extirpation of Matter from Celiac Artery, Percutaneous Endoscopic Approach */
"04C24Z6" = "1" /* Extirpation of Matter from Gastric Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04C24ZZ" = "1" /* Extirpation of Matter from Gastric Artery, Percutaneous Endoscopic Approach */
"04C34Z6" = "1" /* Extirpation of Matter from Hepatic Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04C34ZZ" = "1" /* Extirpation of Matter from Hepatic Artery, Percutaneous Endoscopic Approach */
"04C44Z6" = "1" /* Extirpation of Matter from Splenic Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04C44ZZ" = "1" /* Extirpation of Matter from Splenic Artery, Percutaneous Endoscopic Approach */
"04C54Z6" = "1" /* Extirpation of Matter from Superior Mesenteric Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04C54ZZ" = "1" /* Extirpation of Matter from Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04C64Z6" = "1" /* Extirpation of Matter from Right Colic Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04C64ZZ" = "1" /* Extirpation of Matter from Right Colic Artery, Percutaneous Endoscopic Approach */
"04C74Z6" = "1" /* Extirpation of Matter from Left Colic Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04C74ZZ" = "1" /* Extirpation of Matter from Left Colic Artery, Percutaneous Endoscopic Approach */
"04C84Z6" = "1" /* Extirpation of Matter from Middle Colic Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04C84ZZ" = "1" /* Extirpation of Matter from Middle Colic Artery, Percutaneous Endoscopic Approach */
"04C94Z6" = "1" /* Extirpation of Matter from Right Renal Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04C94ZZ" = "1" /* Extirpation of Matter from Right Renal Artery, Percutaneous Endoscopic Approach */
"04CA4Z6" = "1" /* Extirpation of Matter from Left Renal Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CA4ZZ" = "1" /* Extirpation of Matter from Left Renal Artery, Percutaneous Endoscopic Approach */
"04CB4Z6" = "1" /* Extirpation of Matter from Inferior Mesenteric Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CB4ZZ" = "1" /* Extirpation of Matter from Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04CC4Z6" = "1" /* Extirpation of Matter from Right Common Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CC4ZZ" = "1" /* Extirpation of Matter from Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"04CD4Z6" = "1" /* Extirpation of Matter from Left Common Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CD4ZZ" = "1" /* Extirpation of Matter from Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"04CE4Z6" = "1" /* Extirpation of Matter from Right Internal Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CE4ZZ" = "1" /* Extirpation of Matter from Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04CF4Z6" = "1" /* Extirpation of Matter from Left Internal Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CF4ZZ" = "1" /* Extirpation of Matter from Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04CH4Z6" = "1" /* Extirpation of Matter from Right External Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CH4ZZ" = "1" /* Extirpation of Matter from Right External Iliac Artery, Percutaneous Endoscopic Approach */
"04CJ4Z6" = "1" /* Extirpation of Matter from Left External Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CJ4ZZ" = "1" /* Extirpation of Matter from Left External Iliac Artery, Percutaneous Endoscopic Approach */
"04H042Z" = "1" /* Insertion of Monitoring Device into Abdominal Aorta, Percutaneous Endoscopic Approach */
"04H043Z" = "1" /* Insertion of Infusion Device into Abdominal Aorta, Percutaneous Endoscopic Approach */
"04H04DZ" = "1" /* Insertion of Intraluminal Device into Abdominal Aorta, Percutaneous Endoscopic Approach */
"04H143Z" = "1" /* Insertion of Infusion Device into Celiac Artery, Percutaneous Endoscopic Approach */
"04H14DZ" = "1" /* Insertion of Intraluminal Device into Celiac Artery, Percutaneous Endoscopic Approach */
"04H243Z" = "1" /* Insertion of Infusion Device into Gastric Artery, Percutaneous Endoscopic Approach */
"04H24DZ" = "1" /* Insertion of Intraluminal Device into Gastric Artery, Percutaneous Endoscopic Approach */
"04H343Z" = "1" /* Insertion of Infusion Device into Hepatic Artery, Percutaneous Endoscopic Approach */
"04H34DZ" = "1" /* Insertion of Intraluminal Device into Hepatic Artery, Percutaneous Endoscopic Approach */
"04H443Z" = "1" /* Insertion of Infusion Device into Splenic Artery, Percutaneous Endoscopic Approach */
"04H44DZ" = "1" /* Insertion of Intraluminal Device into Splenic Artery, Percutaneous Endoscopic Approach */
"04H543Z" = "1" /* Insertion of Infusion Device into Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04H54DZ" = "1" /* Insertion of Intraluminal Device into Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04H643Z" = "1" /* Insertion of Infusion Device into Right Colic Artery, Percutaneous Endoscopic Approach */
"04H64DZ" = "1" /* Insertion of Intraluminal Device into Right Colic Artery, Percutaneous Endoscopic Approach */
"04H743Z" = "1" /* Insertion of Infusion Device into Left Colic Artery, Percutaneous Endoscopic Approach */
"04H74DZ" = "1" /* Insertion of Intraluminal Device into Left Colic Artery, Percutaneous Endoscopic Approach */
"04H843Z" = "1" /* Insertion of Infusion Device into Middle Colic Artery, Percutaneous Endoscopic Approach */
"04H84DZ" = "1" /* Insertion of Intraluminal Device into Middle Colic Artery, Percutaneous Endoscopic Approach */
"04H943Z" = "1" /* Insertion of Infusion Device into Right Renal Artery, Percutaneous Endoscopic Approach */
"04H94DZ" = "1" /* Insertion of Intraluminal Device into Right Renal Artery, Percutaneous Endoscopic Approach */
"04HA43Z" = "1" /* Insertion of Infusion Device into Left Renal Artery, Percutaneous Endoscopic Approach */
"04HA4DZ" = "1" /* Insertion of Intraluminal Device into Left Renal Artery, Percutaneous Endoscopic Approach */
"04HB43Z" = "1" /* Insertion of Infusion Device into Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04HB4DZ" = "1" /* Insertion of Intraluminal Device into Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04HC43Z" = "1" /* Insertion of Infusion Device into Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"04HC4DZ" = "1" /* Insertion of Intraluminal Device into Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"04HD43Z" = "1" /* Insertion of Infusion Device into Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"04HD4DZ" = "1" /* Insertion of Intraluminal Device into Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"04HE43Z" = "1" /* Insertion of Infusion Device into Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04HE4DZ" = "1" /* Insertion of Intraluminal Device into Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04HF43Z" = "1" /* Insertion of Infusion Device into Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04HF4DZ" = "1" /* Insertion of Intraluminal Device into Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04HH43Z" = "1" /* Insertion of Infusion Device into Right External Iliac Artery, Percutaneous Endoscopic Approach */
"04HH4DZ" = "1" /* Insertion of Intraluminal Device into Right External Iliac Artery, Percutaneous Endoscopic Approach */
"04HJ43Z" = "1" /* Insertion of Infusion Device into Left External Iliac Artery, Percutaneous Endoscopic Approach */
"04HJ4DZ" = "1" /* Insertion of Intraluminal Device into Left External Iliac Artery, Percutaneous Endoscopic Approach */
"04L03CZ" = "1" /* Occlusion of Abdominal Aorta with Extraluminal Device, Percutaneous Approach */
"04L04CZ" = "1" /* Occlusion of Abdominal Aorta with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L04DZ" = "1" /* Occlusion of Abdominal Aorta with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L04ZZ" = "1" /* Occlusion of Abdominal Aorta, Percutaneous Endoscopic Approach */
"04L13CZ" = "1" /* Occlusion of Celiac Artery with Extraluminal Device, Percutaneous Approach */
"04L14CZ" = "1" /* Occlusion of Celiac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L14DZ" = "1" /* Occlusion of Celiac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L14ZZ" = "1" /* Occlusion of Celiac Artery, Percutaneous Endoscopic Approach */
"04L23CZ" = "1" /* Occlusion of Gastric Artery with Extraluminal Device, Percutaneous Approach */
"04L24CZ" = "1" /* Occlusion of Gastric Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L24DZ" = "1" /* Occlusion of Gastric Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L24ZZ" = "1" /* Occlusion of Gastric Artery, Percutaneous Endoscopic Approach */
"04L33CZ" = "1" /* Occlusion of Hepatic Artery with Extraluminal Device, Percutaneous Approach */
"04L34CZ" = "1" /* Occlusion of Hepatic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L34DZ" = "1" /* Occlusion of Hepatic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L34ZZ" = "1" /* Occlusion of Hepatic Artery, Percutaneous Endoscopic Approach */
"04L43CZ" = "1" /* Occlusion of Splenic Artery with Extraluminal Device, Percutaneous Approach */
"04L44CZ" = "1" /* Occlusion of Splenic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L44DZ" = "1" /* Occlusion of Splenic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L44ZZ" = "1" /* Occlusion of Splenic Artery, Percutaneous Endoscopic Approach */
"04L53CZ" = "1" /* Occlusion of Superior Mesenteric Artery with Extraluminal Device, Percutaneous Approach */
"04L54CZ" = "1" /* Occlusion of Superior Mesenteric Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L54DZ" = "1" /* Occlusion of Superior Mesenteric Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L54ZZ" = "1" /* Occlusion of Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04L63CZ" = "1" /* Occlusion of Right Colic Artery with Extraluminal Device, Percutaneous Approach */
"04L64CZ" = "1" /* Occlusion of Right Colic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L64DZ" = "1" /* Occlusion of Right Colic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L64ZZ" = "1" /* Occlusion of Right Colic Artery, Percutaneous Endoscopic Approach */
"04L73CZ" = "1" /* Occlusion of Left Colic Artery with Extraluminal Device, Percutaneous Approach */
"04L74CZ" = "1" /* Occlusion of Left Colic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L74DZ" = "1" /* Occlusion of Left Colic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L74ZZ" = "1" /* Occlusion of Left Colic Artery, Percutaneous Endoscopic Approach */
"04L83CZ" = "1" /* Occlusion of Middle Colic Artery with Extraluminal Device, Percutaneous Approach */
"04L84CZ" = "1" /* Occlusion of Middle Colic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L84DZ" = "1" /* Occlusion of Middle Colic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L84ZZ" = "1" /* Occlusion of Middle Colic Artery, Percutaneous Endoscopic Approach */
"04L93CZ" = "1" /* Occlusion of Right Renal Artery with Extraluminal Device, Percutaneous Approach */
"04L94CZ" = "1" /* Occlusion of Right Renal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L94DZ" = "1" /* Occlusion of Right Renal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L94ZZ" = "1" /* Occlusion of Right Renal Artery, Percutaneous Endoscopic Approach */
"04LA3CZ" = "1" /* Occlusion of Left Renal Artery with Extraluminal Device, Percutaneous Approach */
"04LA4CZ" = "1" /* Occlusion of Left Renal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LA4DZ" = "1" /* Occlusion of Left Renal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LA4ZZ" = "1" /* Occlusion of Left Renal Artery, Percutaneous Endoscopic Approach */
"04LB3CZ" = "1" /* Occlusion of Inferior Mesenteric Artery with Extraluminal Device, Percutaneous Approach */
"04LB4CZ" = "1" /* Occlusion of Inferior Mesenteric Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LB4DZ" = "1" /* Occlusion of Inferior Mesenteric Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LB4ZZ" = "1" /* Occlusion of Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04LC3CZ" = "1" /* Occlusion of Right Common Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04LC4CZ" = "1" /* Occlusion of Right Common Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LC4DZ" = "1" /* Occlusion of Right Common Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LC4ZZ" = "1" /* Occlusion of Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"04LD3CZ" = "1" /* Occlusion of Left Common Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04LD4CZ" = "1" /* Occlusion of Left Common Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LD4DZ" = "1" /* Occlusion of Left Common Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LD4ZZ" = "1" /* Occlusion of Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"04LE3CT" = "1" /* Occlusion of Right Uterine Artery with Extraluminal Device, Percutaneous Approach */
"04LE3CZ" = "1" /* Occlusion of Right Internal Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04LE4CT" = "1" /* Occlusion of Right Uterine Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LE4CZ" = "1" /* Occlusion of Right Internal Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LE4DT" = "1" /* Occlusion of Right Uterine Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LE4DZ" = "1" /* Occlusion of Right Internal Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LE4ZT" = "1" /* Occlusion of Right Uterine Artery, Percutaneous Endoscopic Approach */
"04LE4ZZ" = "1" /* Occlusion of Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04LF3CU" = "1" /* Occlusion of Left Uterine Artery with Extraluminal Device, Percutaneous Approach */
"04LF3CZ" = "1" /* Occlusion of Left Internal Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04LF4CU" = "1" /* Occlusion of Left Uterine Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LF4CZ" = "1" /* Occlusion of Left Internal Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LF4DU" = "1" /* Occlusion of Left Uterine Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LF4DZ" = "1" /* Occlusion of Left Internal Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LF4ZU" = "1" /* Occlusion of Left Uterine Artery, Percutaneous Endoscopic Approach */
"04LF4ZZ" = "1" /* Occlusion of Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04LH3CZ" = "1" /* Occlusion of Right External Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04LH4CZ" = "1" /* Occlusion of Right External Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LH4DZ" = "1" /* Occlusion of Right External Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LH4ZZ" = "1" /* Occlusion of Right External Iliac Artery, Percutaneous Endoscopic Approach */
"04LJ3CZ" = "1" /* Occlusion of Left External Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04LJ4CZ" = "1" /* Occlusion of Left External Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LJ4DZ" = "1" /* Occlusion of Left External Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LJ4ZZ" = "1" /* Occlusion of Left External Iliac Artery, Percutaneous Endoscopic Approach */
"04N03ZZ" = "1" /* Release Abdominal Aorta, Percutaneous Approach */
"04N04ZZ" = "1" /* Release Abdominal Aorta, Percutaneous Endoscopic Approach */
"04N13ZZ" = "1" /* Release Celiac Artery, Percutaneous Approach */
"04N14ZZ" = "1" /* Release Celiac Artery, Percutaneous Endoscopic Approach */
"04N23ZZ" = "1" /* Release Gastric Artery, Percutaneous Approach */
"04N24ZZ" = "1" /* Release Gastric Artery, Percutaneous Endoscopic Approach */
"04N33ZZ" = "1" /* Release Hepatic Artery, Percutaneous Approach */
"04N34ZZ" = "1" /* Release Hepatic Artery, Percutaneous Endoscopic Approach */
"04N43ZZ" = "1" /* Release Splenic Artery, Percutaneous Approach */
"04N44ZZ" = "1" /* Release Splenic Artery, Percutaneous Endoscopic Approach */
"04N53ZZ" = "1" /* Release Superior Mesenteric Artery, Percutaneous Approach */
"04N54ZZ" = "1" /* Release Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04N63ZZ" = "1" /* Release Right Colic Artery, Percutaneous Approach */
"04N64ZZ" = "1" /* Release Right Colic Artery, Percutaneous Endoscopic Approach */
"04N73ZZ" = "1" /* Release Left Colic Artery, Percutaneous Approach */
"04N74ZZ" = "1" /* Release Left Colic Artery, Percutaneous Endoscopic Approach */
"04N83ZZ" = "1" /* Release Middle Colic Artery, Percutaneous Approach */
"04N84ZZ" = "1" /* Release Middle Colic Artery, Percutaneous Endoscopic Approach */
"04N93ZZ" = "1" /* Release Right Renal Artery, Percutaneous Approach */
"04N94ZZ" = "1" /* Release Right Renal Artery, Percutaneous Endoscopic Approach */
"04NA3ZZ" = "1" /* Release Left Renal Artery, Percutaneous Approach */
"04NA4ZZ" = "1" /* Release Left Renal Artery, Percutaneous Endoscopic Approach */
"04NB3ZZ" = "1" /* Release Inferior Mesenteric Artery, Percutaneous Approach */
"04NB4ZZ" = "1" /* Release Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04NC3ZZ" = "1" /* Release Right Common Iliac Artery, Percutaneous Approach */
"04NC4ZZ" = "1" /* Release Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"04ND3ZZ" = "1" /* Release Left Common Iliac Artery, Percutaneous Approach */
"04ND4ZZ" = "1" /* Release Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"04NE3ZZ" = "1" /* Release Right Internal Iliac Artery, Percutaneous Approach */
"04NE4ZZ" = "1" /* Release Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04NF3ZZ" = "1" /* Release Left Internal Iliac Artery, Percutaneous Approach */
"04NF4ZZ" = "1" /* Release Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04NH3ZZ" = "1" /* Release Right External Iliac Artery, Percutaneous Approach */
"04NH4ZZ" = "1" /* Release Right External Iliac Artery, Percutaneous Endoscopic Approach */
"04NJ3ZZ" = "1" /* Release Left External Iliac Artery, Percutaneous Approach */
"04NJ4ZZ" = "1" /* Release Left External Iliac Artery, Percutaneous Endoscopic Approach */
"04Q04ZZ" = "1" /* Repair Abdominal Aorta, Percutaneous Endoscopic Approach */
"04Q14ZZ" = "1" /* Repair Celiac Artery, Percutaneous Endoscopic Approach */
"04Q24ZZ" = "1" /* Repair Gastric Artery, Percutaneous Endoscopic Approach */
"04Q34ZZ" = "1" /* Repair Hepatic Artery, Percutaneous Endoscopic Approach */
"04Q44ZZ" = "1" /* Repair Splenic Artery, Percutaneous Endoscopic Approach */
"04Q54ZZ" = "1" /* Repair Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04Q64ZZ" = "1" /* Repair Right Colic Artery, Percutaneous Endoscopic Approach */
"04Q74ZZ" = "1" /* Repair Left Colic Artery, Percutaneous Endoscopic Approach */
"04Q84ZZ" = "1" /* Repair Middle Colic Artery, Percutaneous Endoscopic Approach */
"04Q94ZZ" = "1" /* Repair Right Renal Artery, Percutaneous Endoscopic Approach */
"04QA4ZZ" = "1" /* Repair Left Renal Artery, Percutaneous Endoscopic Approach */
"04QB4ZZ" = "1" /* Repair Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04QC4ZZ" = "1" /* Repair Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"04QD4ZZ" = "1" /* Repair Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"04QE4ZZ" = "1" /* Repair Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04QF4ZZ" = "1" /* Repair Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04QH4ZZ" = "1" /* Repair Right External Iliac Artery, Percutaneous Endoscopic Approach */
"04QJ4ZZ" = "1" /* Repair Left External Iliac Artery, Percutaneous Endoscopic Approach */
"04R047Z" = "1" /* Replacement of Abdominal Aorta with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R04JZ" = "1" /* Replacement of Abdominal Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04R04KZ" = "1" /* Replacement of Abdominal Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R147Z" = "1" /* Replacement of Celiac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R14JZ" = "1" /* Replacement of Celiac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04R14KZ" = "1" /* Replacement of Celiac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R247Z" = "1" /* Replacement of Gastric Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R24JZ" = "1" /* Replacement of Gastric Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04R24KZ" = "1" /* Replacement of Gastric Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R347Z" = "1" /* Replacement of Hepatic Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R34JZ" = "1" /* Replacement of Hepatic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04R34KZ" = "1" /* Replacement of Hepatic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R447Z" = "1" /* Replacement of Splenic Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R44JZ" = "1" /* Replacement of Splenic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04R44KZ" = "1" /* Replacement of Splenic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R547Z" = "1" /* Replacement of Superior Mesenteric Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R54JZ" = "1" /* Replacement of Superior Mesenteric Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04R54KZ" = "1" /* Replacement of Superior Mesenteric Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R647Z" = "1" /* Replacement of Right Colic Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R64JZ" = "1" /* Replacement of Right Colic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04R64KZ" = "1" /* Replacement of Right Colic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R747Z" = "1" /* Replacement of Left Colic Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R74JZ" = "1" /* Replacement of Left Colic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04R74KZ" = "1" /* Replacement of Left Colic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R847Z" = "1" /* Replacement of Middle Colic Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R84JZ" = "1" /* Replacement of Middle Colic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04R84KZ" = "1" /* Replacement of Middle Colic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R947Z" = "1" /* Replacement of Right Renal Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R94JZ" = "1" /* Replacement of Right Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04R94KZ" = "1" /* Replacement of Right Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RA47Z" = "1" /* Replacement of Left Renal Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RA4JZ" = "1" /* Replacement of Left Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RA4KZ" = "1" /* Replacement of Left Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RB47Z" = "1" /* Replacement of Inferior Mesenteric Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RB4JZ" = "1" /* Replacement of Inferior Mesenteric Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RB4KZ" = "1" /* Replacement of Inferior Mesenteric Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RC47Z" = "1" /* Replacement of Right Common Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RC4JZ" = "1" /* Replacement of Right Common Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RC4KZ" = "1" /* Replacement of Right Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RD47Z" = "1" /* Replacement of Left Common Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RD4JZ" = "1" /* Replacement of Left Common Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RD4KZ" = "1" /* Replacement of Left Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RE47Z" = "1" /* Replacement of Right Internal Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RE4JZ" = "1" /* Replacement of Right Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RE4KZ" = "1" /* Replacement of Right Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RF47Z" = "1" /* Replacement of Left Internal Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RF4JZ" = "1" /* Replacement of Left Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RF4KZ" = "1" /* Replacement of Left Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RH47Z" = "1" /* Replacement of Right External Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RH4JZ" = "1" /* Replacement of Right External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RH4KZ" = "1" /* Replacement of Right External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RJ47Z" = "1" /* Replacement of Left External Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RJ4JZ" = "1" /* Replacement of Left External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RJ4KZ" = "1" /* Replacement of Left External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04S03ZZ" = "1" /* Reposition Abdominal Aorta, Percutaneous Approach */
"04S04ZZ" = "1" /* Reposition Abdominal Aorta, Percutaneous Endoscopic Approach */
"04S13ZZ" = "1" /* Reposition Celiac Artery, Percutaneous Approach */
"04S14ZZ" = "1" /* Reposition Celiac Artery, Percutaneous Endoscopic Approach */
"04S23ZZ" = "1" /* Reposition Gastric Artery, Percutaneous Approach */
"04S24ZZ" = "1" /* Reposition Gastric Artery, Percutaneous Endoscopic Approach */
"04S33ZZ" = "1" /* Reposition Hepatic Artery, Percutaneous Approach */
"04S34ZZ" = "1" /* Reposition Hepatic Artery, Percutaneous Endoscopic Approach */
"04S43ZZ" = "1" /* Reposition Splenic Artery, Percutaneous Approach */
"04S44ZZ" = "1" /* Reposition Splenic Artery, Percutaneous Endoscopic Approach */
"04S53ZZ" = "1" /* Reposition Superior Mesenteric Artery, Percutaneous Approach */
"04S54ZZ" = "1" /* Reposition Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04S63ZZ" = "1" /* Reposition Right Colic Artery, Percutaneous Approach */
"04S64ZZ" = "1" /* Reposition Right Colic Artery, Percutaneous Endoscopic Approach */
"04S73ZZ" = "1" /* Reposition Left Colic Artery, Percutaneous Approach */
"04S74ZZ" = "1" /* Reposition Left Colic Artery, Percutaneous Endoscopic Approach */
"04S83ZZ" = "1" /* Reposition Middle Colic Artery, Percutaneous Approach */
"04S84ZZ" = "1" /* Reposition Middle Colic Artery, Percutaneous Endoscopic Approach */
"04S93ZZ" = "1" /* Reposition Right Renal Artery, Percutaneous Approach */
"04S94ZZ" = "1" /* Reposition Right Renal Artery, Percutaneous Endoscopic Approach */
"04SA3ZZ" = "1" /* Reposition Left Renal Artery, Percutaneous Approach */
"04SA4ZZ" = "1" /* Reposition Left Renal Artery, Percutaneous Endoscopic Approach */
"04SB3ZZ" = "1" /* Reposition Inferior Mesenteric Artery, Percutaneous Approach */
"04SB4ZZ" = "1" /* Reposition Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04SC3ZZ" = "1" /* Reposition Right Common Iliac Artery, Percutaneous Approach */
"04SC4ZZ" = "1" /* Reposition Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"04SD3ZZ" = "1" /* Reposition Left Common Iliac Artery, Percutaneous Approach */
"04SD4ZZ" = "1" /* Reposition Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"04SE3ZZ" = "1" /* Reposition Right Internal Iliac Artery, Percutaneous Approach */
"04SE4ZZ" = "1" /* Reposition Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04SF3ZZ" = "1" /* Reposition Left Internal Iliac Artery, Percutaneous Approach */
"04SF4ZZ" = "1" /* Reposition Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04SH3ZZ" = "1" /* Reposition Right External Iliac Artery, Percutaneous Approach */
"04SH4ZZ" = "1" /* Reposition Right External Iliac Artery, Percutaneous Endoscopic Approach */
"04SJ3ZZ" = "1" /* Reposition Left External Iliac Artery, Percutaneous Approach */
"04SJ4ZZ" = "1" /* Reposition Left External Iliac Artery, Percutaneous Endoscopic Approach */
"04U037Z" = "1" /* Supplement Abdominal Aorta with Autologous Tissue Substitute, Percutaneous Approach */
"04U03JZ" = "1" /* Supplement Abdominal Aorta with Synthetic Substitute, Percutaneous Approach */
"04U03KZ" = "1" /* Supplement Abdominal Aorta with Nonautologous Tissue Substitute, Percutaneous Approach */
"04U047Z" = "1" /* Supplement Abdominal Aorta with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U04JZ" = "1" /* Supplement Abdominal Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04U04KZ" = "1" /* Supplement Abdominal Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U137Z" = "1" /* Supplement Celiac Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04U13JZ" = "1" /* Supplement Celiac Artery with Synthetic Substitute, Percutaneous Approach */
"04U13KZ" = "1" /* Supplement Celiac Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04U147Z" = "1" /* Supplement Celiac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U14JZ" = "1" /* Supplement Celiac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04U14KZ" = "1" /* Supplement Celiac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U237Z" = "1" /* Supplement Gastric Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04U23JZ" = "1" /* Supplement Gastric Artery with Synthetic Substitute, Percutaneous Approach */
"04U23KZ" = "1" /* Supplement Gastric Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04U247Z" = "1" /* Supplement Gastric Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U24JZ" = "1" /* Supplement Gastric Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04U24KZ" = "1" /* Supplement Gastric Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U337Z" = "1" /* Supplement Hepatic Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04U33JZ" = "1" /* Supplement Hepatic Artery with Synthetic Substitute, Percutaneous Approach */
"04U33KZ" = "1" /* Supplement Hepatic Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04U347Z" = "1" /* Supplement Hepatic Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U34JZ" = "1" /* Supplement Hepatic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04U34KZ" = "1" /* Supplement Hepatic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U437Z" = "1" /* Supplement Splenic Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04U43JZ" = "1" /* Supplement Splenic Artery with Synthetic Substitute, Percutaneous Approach */
"04U43KZ" = "1" /* Supplement Splenic Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04U447Z" = "1" /* Supplement Splenic Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U44JZ" = "1" /* Supplement Splenic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04U44KZ" = "1" /* Supplement Splenic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U537Z" = "1" /* Supplement Superior Mesenteric Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04U53JZ" = "1" /* Supplement Superior Mesenteric Artery with Synthetic Substitute, Percutaneous Approach */
"04U53KZ" = "1" /* Supplement Superior Mesenteric Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04U547Z" = "1" /* Supplement Superior Mesenteric Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U54JZ" = "1" /* Supplement Superior Mesenteric Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04U54KZ" = "1" /* Supplement Superior Mesenteric Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U637Z" = "1" /* Supplement Right Colic Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04U63JZ" = "1" /* Supplement Right Colic Artery with Synthetic Substitute, Percutaneous Approach */
"04U63KZ" = "1" /* Supplement Right Colic Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04U647Z" = "1" /* Supplement Right Colic Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U64JZ" = "1" /* Supplement Right Colic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04U64KZ" = "1" /* Supplement Right Colic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U737Z" = "1" /* Supplement Left Colic Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04U73JZ" = "1" /* Supplement Left Colic Artery with Synthetic Substitute, Percutaneous Approach */
"04U73KZ" = "1" /* Supplement Left Colic Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04U747Z" = "1" /* Supplement Left Colic Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U74JZ" = "1" /* Supplement Left Colic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04U74KZ" = "1" /* Supplement Left Colic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U837Z" = "1" /* Supplement Middle Colic Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04U83JZ" = "1" /* Supplement Middle Colic Artery with Synthetic Substitute, Percutaneous Approach */
"04U83KZ" = "1" /* Supplement Middle Colic Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04U847Z" = "1" /* Supplement Middle Colic Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U84JZ" = "1" /* Supplement Middle Colic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04U84KZ" = "1" /* Supplement Middle Colic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U937Z" = "1" /* Supplement Right Renal Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04U93JZ" = "1" /* Supplement Right Renal Artery with Synthetic Substitute, Percutaneous Approach */
"04U93KZ" = "1" /* Supplement Right Renal Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04U947Z" = "1" /* Supplement Right Renal Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U94JZ" = "1" /* Supplement Right Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04U94KZ" = "1" /* Supplement Right Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UA37Z" = "1" /* Supplement Left Renal Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UA3JZ" = "1" /* Supplement Left Renal Artery with Synthetic Substitute, Percutaneous Approach */
"04UA3KZ" = "1" /* Supplement Left Renal Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UA47Z" = "1" /* Supplement Left Renal Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UA4JZ" = "1" /* Supplement Left Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UA4KZ" = "1" /* Supplement Left Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UB37Z" = "1" /* Supplement Inferior Mesenteric Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UB3JZ" = "1" /* Supplement Inferior Mesenteric Artery with Synthetic Substitute, Percutaneous Approach */
"04UB3KZ" = "1" /* Supplement Inferior Mesenteric Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UB47Z" = "1" /* Supplement Inferior Mesenteric Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UB4JZ" = "1" /* Supplement Inferior Mesenteric Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UB4KZ" = "1" /* Supplement Inferior Mesenteric Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UC37Z" = "1" /* Supplement Right Common Iliac Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UC3JZ" = "1" /* Supplement Right Common Iliac Artery with Synthetic Substitute, Percutaneous Approach */
"04UC3KZ" = "1" /* Supplement Right Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UC47Z" = "1" /* Supplement Right Common Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UC4JZ" = "1" /* Supplement Right Common Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UC4KZ" = "1" /* Supplement Right Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UD37Z" = "1" /* Supplement Left Common Iliac Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UD3JZ" = "1" /* Supplement Left Common Iliac Artery with Synthetic Substitute, Percutaneous Approach */
"04UD3KZ" = "1" /* Supplement Left Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UD47Z" = "1" /* Supplement Left Common Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UD4JZ" = "1" /* Supplement Left Common Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UD4KZ" = "1" /* Supplement Left Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UE37Z" = "1" /* Supplement Right Internal Iliac Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UE3JZ" = "1" /* Supplement Right Internal Iliac Artery with Synthetic Substitute, Percutaneous Approach */
"04UE3KZ" = "1" /* Supplement Right Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UE47Z" = "1" /* Supplement Right Internal Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UE4JZ" = "1" /* Supplement Right Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UE4KZ" = "1" /* Supplement Right Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UF37Z" = "1" /* Supplement Left Internal Iliac Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UF3JZ" = "1" /* Supplement Left Internal Iliac Artery with Synthetic Substitute, Percutaneous Approach */
"04UF3KZ" = "1" /* Supplement Left Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UF47Z" = "1" /* Supplement Left Internal Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UF4JZ" = "1" /* Supplement Left Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UF4KZ" = "1" /* Supplement Left Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UH37Z" = "1" /* Supplement Right External Iliac Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UH3JZ" = "1" /* Supplement Right External Iliac Artery with Synthetic Substitute, Percutaneous Approach */
"04UH3KZ" = "1" /* Supplement Right External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UH47Z" = "1" /* Supplement Right External Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UH4JZ" = "1" /* Supplement Right External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UH4KZ" = "1" /* Supplement Right External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UJ37Z" = "1" /* Supplement Left External Iliac Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UJ3JZ" = "1" /* Supplement Left External Iliac Artery with Synthetic Substitute, Percutaneous Approach */
"04UJ3KZ" = "1" /* Supplement Left External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UJ47Z" = "1" /* Supplement Left External Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UJ4JZ" = "1" /* Supplement Left External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UJ4KZ" = "1" /* Supplement Left External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04V03CZ" = "1" /* Restriction of Abdominal Aorta with Extraluminal Device, Percutaneous Approach */
"04V04C6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, with Extraluminal Device, Percutaneous Endoscopic Approach */
"04V04CZ" = "1" /* Restriction of Abdominal Aorta with Extraluminal Device, Percutaneous Endoscopic Approach */
"04V04D6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V04DJ" = "1" /* Restriction of Abdominal Aorta with Intraluminal Device, Temporary, Percutaneous Endoscopic Approach */
"04V04DZ" = "1" /* Restriction of Abdominal Aorta with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V04E6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Percutaneous Endoscopic Approach */
"04V04EZ" = "1" /* Restriction of Abdominal Aorta with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Percutaneous Endoscopic Approach */
"04V04F6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Percutaneous Endoscopic Approach */
"04V04FZ" = "1" /* Restriction of Abdominal Aorta with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Percutaneous Endoscopic Approach */
"04V04Z6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, Percutaneous Endoscopic Approach */
"04V04ZZ" = "1" /* Restriction of Abdominal Aorta, Percutaneous Endoscopic Approach */
"04V13CZ" = "1" /* Restriction of Celiac Artery with Extraluminal Device, Percutaneous Approach */
"04V14CZ" = "1" /* Restriction of Celiac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04V14DZ" = "1" /* Restriction of Celiac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V14ZZ" = "1" /* Restriction of Celiac Artery, Percutaneous Endoscopic Approach */
"04V23CZ" = "1" /* Restriction of Gastric Artery with Extraluminal Device, Percutaneous Approach */
"04V24CZ" = "1" /* Restriction of Gastric Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04V24DZ" = "1" /* Restriction of Gastric Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V24ZZ" = "1" /* Restriction of Gastric Artery, Percutaneous Endoscopic Approach */
"04V33CZ" = "1" /* Restriction of Hepatic Artery with Extraluminal Device, Percutaneous Approach */
"04V34CZ" = "1" /* Restriction of Hepatic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04V34DZ" = "1" /* Restriction of Hepatic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V34ZZ" = "1" /* Restriction of Hepatic Artery, Percutaneous Endoscopic Approach */
"04V43CZ" = "1" /* Restriction of Splenic Artery with Extraluminal Device, Percutaneous Approach */
"04V44CZ" = "1" /* Restriction of Splenic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04V44DZ" = "1" /* Restriction of Splenic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V44ZZ" = "1" /* Restriction of Splenic Artery, Percutaneous Endoscopic Approach */
"04V53CZ" = "1" /* Restriction of Superior Mesenteric Artery with Extraluminal Device, Percutaneous Approach */
"04V54CZ" = "1" /* Restriction of Superior Mesenteric Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04V54DZ" = "1" /* Restriction of Superior Mesenteric Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V54ZZ" = "1" /* Restriction of Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04V63CZ" = "1" /* Restriction of Right Colic Artery with Extraluminal Device, Percutaneous Approach */
"04V64CZ" = "1" /* Restriction of Right Colic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04V64DZ" = "1" /* Restriction of Right Colic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V64ZZ" = "1" /* Restriction of Right Colic Artery, Percutaneous Endoscopic Approach */
"04V73CZ" = "1" /* Restriction of Left Colic Artery with Extraluminal Device, Percutaneous Approach */
"04V74CZ" = "1" /* Restriction of Left Colic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04V74DZ" = "1" /* Restriction of Left Colic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V74ZZ" = "1" /* Restriction of Left Colic Artery, Percutaneous Endoscopic Approach */
"04V83CZ" = "1" /* Restriction of Middle Colic Artery with Extraluminal Device, Percutaneous Approach */
"04V84CZ" = "1" /* Restriction of Middle Colic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04V84DZ" = "1" /* Restriction of Middle Colic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V84ZZ" = "1" /* Restriction of Middle Colic Artery, Percutaneous Endoscopic Approach */
"04V93CZ" = "1" /* Restriction of Right Renal Artery with Extraluminal Device, Percutaneous Approach */
"04V94CZ" = "1" /* Restriction of Right Renal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04V94DZ" = "1" /* Restriction of Right Renal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V94ZZ" = "1" /* Restriction of Right Renal Artery, Percutaneous Endoscopic Approach */
"04VA3CZ" = "1" /* Restriction of Left Renal Artery with Extraluminal Device, Percutaneous Approach */
"04VA4CZ" = "1" /* Restriction of Left Renal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VA4DZ" = "1" /* Restriction of Left Renal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VA4ZZ" = "1" /* Restriction of Left Renal Artery, Percutaneous Endoscopic Approach */
"04VB3CZ" = "1" /* Restriction of Inferior Mesenteric Artery with Extraluminal Device, Percutaneous Approach */
"04VB4CZ" = "1" /* Restriction of Inferior Mesenteric Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VB4DZ" = "1" /* Restriction of Inferior Mesenteric Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VB4ZZ" = "1" /* Restriction of Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04VC3CZ" = "1" /* Restriction of Right Common Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04VC4CZ" = "1" /* Restriction of Right Common Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VC4DZ" = "1" /* Restriction of Right Common Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VC4EZ" = "1" /* Restriction of Right Common Iliac Artery with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Percutaneous Endoscopic Approach */
"04VC4FZ" = "1" /* Restriction of Right Common Iliac Artery with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Percutaneous Endoscopic Approach */
"04VC4ZZ" = "1" /* Restriction of Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"04VD3CZ" = "1" /* Restriction of Left Common Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04VD4CZ" = "1" /* Restriction of Left Common Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VD4DZ" = "1" /* Restriction of Left Common Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VD4EZ" = "1" /* Restriction of Left Common Iliac Artery with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Percutaneous Endoscopic Approach */
"04VD4FZ" = "1" /* Restriction of Left Common Iliac Artery with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Percutaneous Endoscopic Approach */
"04VD4ZZ" = "1" /* Restriction of Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"04VE3CZ" = "1" /* Restriction of Right Internal Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04VE4CZ" = "1" /* Restriction of Right Internal Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VE4DZ" = "1" /* Restriction of Right Internal Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VE4ZZ" = "1" /* Restriction of Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04VF3CZ" = "1" /* Restriction of Left Internal Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04VF4CZ" = "1" /* Restriction of Left Internal Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VF4DZ" = "1" /* Restriction of Left Internal Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VF4ZZ" = "1" /* Restriction of Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04VH3CZ" = "1" /* Restriction of Right External Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04VH4CZ" = "1" /* Restriction of Right External Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VH4DZ" = "1" /* Restriction of Right External Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VH4ZZ" = "1" /* Restriction of Right External Iliac Artery, Percutaneous Endoscopic Approach */
"04VJ3CZ" = "1" /* Restriction of Left External Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04VJ4CZ" = "1" /* Restriction of Left External Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VJ4DZ" = "1" /* Restriction of Left External Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VJ4ZZ" = "1" /* Restriction of Left External Iliac Artery, Percutaneous Endoscopic Approach */
"0610475" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0610476" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061047Y" = "1" /* Bypass Inferior Vena Cava to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0610495" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0610496" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061049Y" = "1" /* Bypass Inferior Vena Cava to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"06104A5" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06104A6" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06104AY" = "1" /* Bypass Inferior Vena Cava to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06104J5" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06104J6" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06104JY" = "1" /* Bypass Inferior Vena Cava to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06104K5" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06104K6" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06104KY" = "1" /* Bypass Inferior Vena Cava to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06104Z5" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06104Z6" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06104ZY" = "1" /* Bypass Inferior Vena Cava to Lower Vein, Percutaneous Endoscopic Approach */
"0611479" = "1" /* Bypass Splenic Vein to Right Renal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061147B" = "1" /* Bypass Splenic Vein to Left Renal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061147Y" = "1" /* Bypass Splenic Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0611499" = "1" /* Bypass Splenic Vein to Right Renal Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061149B" = "1" /* Bypass Splenic Vein to Left Renal Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061149Y" = "1" /* Bypass Splenic Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"06114A9" = "1" /* Bypass Splenic Vein to Right Renal Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06114AB" = "1" /* Bypass Splenic Vein to Left Renal Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06114AY" = "1" /* Bypass Splenic Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06114J9" = "1" /* Bypass Splenic Vein to Right Renal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06114JB" = "1" /* Bypass Splenic Vein to Left Renal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06114JY" = "1" /* Bypass Splenic Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06114K9" = "1" /* Bypass Splenic Vein to Right Renal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06114KB" = "1" /* Bypass Splenic Vein to Left Renal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06114KY" = "1" /* Bypass Splenic Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06114Z9" = "1" /* Bypass Splenic Vein to Right Renal Vein, Percutaneous Endoscopic Approach */
"06114ZB" = "1" /* Bypass Splenic Vein to Left Renal Vein, Percutaneous Endoscopic Approach */
"06114ZY" = "1" /* Bypass Splenic Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061247Y" = "1" /* Bypass Gastric Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061249Y" = "1" /* Bypass Gastric Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"06124AY" = "1" /* Bypass Gastric Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06124JY" = "1" /* Bypass Gastric Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06124KY" = "1" /* Bypass Gastric Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06124ZY" = "1" /* Bypass Gastric Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061347Y" = "1" /* Bypass Esophageal Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061349Y" = "1" /* Bypass Esophageal Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"06134AY" = "1" /* Bypass Esophageal Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06134JY" = "1" /* Bypass Esophageal Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06134KY" = "1" /* Bypass Esophageal Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06134ZY" = "1" /* Bypass Esophageal Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061447Y" = "1" /* Bypass Hepatic Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061449Y" = "1" /* Bypass Hepatic Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"06144AY" = "1" /* Bypass Hepatic Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06144JY" = "1" /* Bypass Hepatic Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06144KY" = "1" /* Bypass Hepatic Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06144ZY" = "1" /* Bypass Hepatic Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061547Y" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061549Y" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"06154AY" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06154JY" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06154KY" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06154ZY" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061647Y" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061649Y" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"06164AY" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06164JY" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06164KY" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06164ZY" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061747Y" = "1" /* Bypass Colic Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061749Y" = "1" /* Bypass Colic Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"06174AY" = "1" /* Bypass Colic Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06174JY" = "1" /* Bypass Colic Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06174KY" = "1" /* Bypass Colic Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06174ZY" = "1" /* Bypass Colic Vein to Lower Vein, Percutaneous Endoscopic Approach */
"0618479" = "1" /* Bypass Portal Vein to Right Renal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061847B" = "1" /* Bypass Portal Vein to Left Renal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061847Y" = "1" /* Bypass Portal Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0618499" = "1" /* Bypass Portal Vein to Right Renal Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061849B" = "1" /* Bypass Portal Vein to Left Renal Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061849Y" = "1" /* Bypass Portal Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"06184A9" = "1" /* Bypass Portal Vein to Right Renal Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06184AB" = "1" /* Bypass Portal Vein to Left Renal Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06184AY" = "1" /* Bypass Portal Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06184DY" = "1" /* Bypass Portal Vein to Lower Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06184J9" = "1" /* Bypass Portal Vein to Right Renal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06184JB" = "1" /* Bypass Portal Vein to Left Renal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06184JY" = "1" /* Bypass Portal Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06184K9" = "1" /* Bypass Portal Vein to Right Renal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06184KB" = "1" /* Bypass Portal Vein to Left Renal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06184KY" = "1" /* Bypass Portal Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06184Z9" = "1" /* Bypass Portal Vein to Right Renal Vein, Percutaneous Endoscopic Approach */
"06184ZB" = "1" /* Bypass Portal Vein to Left Renal Vein, Percutaneous Endoscopic Approach */
"06184ZY" = "1" /* Bypass Portal Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061947Y" = "1" /* Bypass Right Renal Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061949Y" = "1" /* Bypass Right Renal Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"06194AY" = "1" /* Bypass Right Renal Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06194JY" = "1" /* Bypass Right Renal Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06194KY" = "1" /* Bypass Right Renal Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06194ZY" = "1" /* Bypass Right Renal Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061B47Y" = "1" /* Bypass Left Renal Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061B49Y" = "1" /* Bypass Left Renal Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061B4AY" = "1" /* Bypass Left Renal Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"061B4JY" = "1" /* Bypass Left Renal Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"061B4KY" = "1" /* Bypass Left Renal Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061B4ZY" = "1" /* Bypass Left Renal Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061C47Y" = "1" /* Bypass Right Common Iliac Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061C49Y" = "1" /* Bypass Right Common Iliac Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061C4AY" = "1" /* Bypass Right Common Iliac Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"061C4JY" = "1" /* Bypass Right Common Iliac Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"061C4KY" = "1" /* Bypass Right Common Iliac Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061C4ZY" = "1" /* Bypass Right Common Iliac Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061D47Y" = "1" /* Bypass Left Common Iliac Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061D49Y" = "1" /* Bypass Left Common Iliac Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061D4AY" = "1" /* Bypass Left Common Iliac Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"061D4JY" = "1" /* Bypass Left Common Iliac Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"061D4KY" = "1" /* Bypass Left Common Iliac Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061D4ZY" = "1" /* Bypass Left Common Iliac Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061F47Y" = "1" /* Bypass Right External Iliac Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061F49Y" = "1" /* Bypass Right External Iliac Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061F4AY" = "1" /* Bypass Right External Iliac Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"061F4JY" = "1" /* Bypass Right External Iliac Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"061F4KY" = "1" /* Bypass Right External Iliac Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061F4ZY" = "1" /* Bypass Right External Iliac Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061G47Y" = "1" /* Bypass Left External Iliac Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061G49Y" = "1" /* Bypass Left External Iliac Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061G4AY" = "1" /* Bypass Left External Iliac Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"061G4JY" = "1" /* Bypass Left External Iliac Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"061G4KY" = "1" /* Bypass Left External Iliac Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061G4ZY" = "1" /* Bypass Left External Iliac Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061H47Y" = "1" /* Bypass Right Hypogastric Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061H49Y" = "1" /* Bypass Right Hypogastric Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061H4AY" = "1" /* Bypass Right Hypogastric Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"061H4JY" = "1" /* Bypass Right Hypogastric Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"061H4KY" = "1" /* Bypass Right Hypogastric Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061H4ZY" = "1" /* Bypass Right Hypogastric Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061J47Y" = "1" /* Bypass Left Hypogastric Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061J49Y" = "1" /* Bypass Left Hypogastric Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061J4AY" = "1" /* Bypass Left Hypogastric Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"061J4JY" = "1" /* Bypass Left Hypogastric Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"061J4KY" = "1" /* Bypass Left Hypogastric Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061J4ZY" = "1" /* Bypass Left Hypogastric Vein to Lower Vein, Percutaneous Endoscopic Approach */
"06503ZZ" = "1" /* Destruction of Inferior Vena Cava, Percutaneous Approach */
"06504ZZ" = "1" /* Destruction of Inferior Vena Cava, Percutaneous Endoscopic Approach */
"06513ZZ" = "1" /* Destruction of Splenic Vein, Percutaneous Approach */
"06514ZZ" = "1" /* Destruction of Splenic Vein, Percutaneous Endoscopic Approach */
"06523ZZ" = "1" /* Destruction of Gastric Vein, Percutaneous Approach */
"06524ZZ" = "1" /* Destruction of Gastric Vein, Percutaneous Endoscopic Approach */
"06533ZZ" = "1" /* Destruction of Esophageal Vein, Percutaneous Approach */
"06534ZZ" = "1" /* Destruction of Esophageal Vein, Percutaneous Endoscopic Approach */
"06543ZZ" = "1" /* Destruction of Hepatic Vein, Percutaneous Approach */
"06544ZZ" = "1" /* Destruction of Hepatic Vein, Percutaneous Endoscopic Approach */
"06553ZZ" = "1" /* Destruction of Superior Mesenteric Vein, Percutaneous Approach */
"06554ZZ" = "1" /* Destruction of Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06563ZZ" = "1" /* Destruction of Inferior Mesenteric Vein, Percutaneous Approach */
"06564ZZ" = "1" /* Destruction of Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06573ZZ" = "1" /* Destruction of Colic Vein, Percutaneous Approach */
"06574ZZ" = "1" /* Destruction of Colic Vein, Percutaneous Endoscopic Approach */
"06583ZZ" = "1" /* Destruction of Portal Vein, Percutaneous Approach */
"06584ZZ" = "1" /* Destruction of Portal Vein, Percutaneous Endoscopic Approach */
"06593ZZ" = "1" /* Destruction of Right Renal Vein, Percutaneous Approach */
"06594ZZ" = "1" /* Destruction of Right Renal Vein, Percutaneous Endoscopic Approach */
"065B3ZZ" = "1" /* Destruction of Left Renal Vein, Percutaneous Approach */
"065B4ZZ" = "1" /* Destruction of Left Renal Vein, Percutaneous Endoscopic Approach */
"065C3ZZ" = "1" /* Destruction of Right Common Iliac Vein, Percutaneous Approach */
"065C4ZZ" = "1" /* Destruction of Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"065D3ZZ" = "1" /* Destruction of Left Common Iliac Vein, Percutaneous Approach */
"065D4ZZ" = "1" /* Destruction of Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"065F3ZZ" = "1" /* Destruction of Right External Iliac Vein, Percutaneous Approach */
"065F4ZZ" = "1" /* Destruction of Right External Iliac Vein, Percutaneous Endoscopic Approach */
"065G3ZZ" = "1" /* Destruction of Left External Iliac Vein, Percutaneous Approach */
"065G4ZZ" = "1" /* Destruction of Left External Iliac Vein, Percutaneous Endoscopic Approach */
"065H3ZZ" = "1" /* Destruction of Right Hypogastric Vein, Percutaneous Approach */
"065H4ZZ" = "1" /* Destruction of Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"065J3ZZ" = "1" /* Destruction of Left Hypogastric Vein, Percutaneous Approach */
"065J4ZZ" = "1" /* Destruction of Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"06704DZ" = "1" /* Dilation of Inferior Vena Cava with Intraluminal Device, Percutaneous Endoscopic Approach */
"06704ZZ" = "1" /* Dilation of Inferior Vena Cava, Percutaneous Endoscopic Approach */
"06714DZ" = "1" /* Dilation of Splenic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06714ZZ" = "1" /* Dilation of Splenic Vein, Percutaneous Endoscopic Approach */
"06724DZ" = "1" /* Dilation of Gastric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06724ZZ" = "1" /* Dilation of Gastric Vein, Percutaneous Endoscopic Approach */
"06734DZ" = "1" /* Dilation of Esophageal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06734ZZ" = "1" /* Dilation of Esophageal Vein, Percutaneous Endoscopic Approach */
"06744DZ" = "1" /* Dilation of Hepatic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06744ZZ" = "1" /* Dilation of Hepatic Vein, Percutaneous Endoscopic Approach */
"06754DZ" = "1" /* Dilation of Superior Mesenteric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06754ZZ" = "1" /* Dilation of Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06764DZ" = "1" /* Dilation of Inferior Mesenteric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06764ZZ" = "1" /* Dilation of Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06774DZ" = "1" /* Dilation of Colic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06774ZZ" = "1" /* Dilation of Colic Vein, Percutaneous Endoscopic Approach */
"06784DZ" = "1" /* Dilation of Portal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06784ZZ" = "1" /* Dilation of Portal Vein, Percutaneous Endoscopic Approach */
"06794DZ" = "1" /* Dilation of Right Renal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06794ZZ" = "1" /* Dilation of Right Renal Vein, Percutaneous Endoscopic Approach */
"067B4DZ" = "1" /* Dilation of Left Renal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"067B4ZZ" = "1" /* Dilation of Left Renal Vein, Percutaneous Endoscopic Approach */
"067C4DZ" = "1" /* Dilation of Right Common Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"067C4ZZ" = "1" /* Dilation of Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"067D4DZ" = "1" /* Dilation of Left Common Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"067D4ZZ" = "1" /* Dilation of Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"067F4DZ" = "1" /* Dilation of Right External Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"067F4ZZ" = "1" /* Dilation of Right External Iliac Vein, Percutaneous Endoscopic Approach */
"067G4DZ" = "1" /* Dilation of Left External Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"067G4ZZ" = "1" /* Dilation of Left External Iliac Vein, Percutaneous Endoscopic Approach */
"067H4DZ" = "1" /* Dilation of Right Hypogastric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"067H4ZZ" = "1" /* Dilation of Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"067J4DZ" = "1" /* Dilation of Left Hypogastric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"067J4ZZ" = "1" /* Dilation of Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"069040Z" = "1" /* Drainage of Inferior Vena Cava with Drainage Device, Percutaneous Endoscopic Approach */
"06904ZX" = "1" /* Drainage of Inferior Vena Cava, Percutaneous Endoscopic Approach, Diagnostic */
"06904ZZ" = "1" /* Drainage of Inferior Vena Cava, Percutaneous Endoscopic Approach */
"069140Z" = "1" /* Drainage of Splenic Vein with Drainage Device, Percutaneous Endoscopic Approach */
"06914ZX" = "1" /* Drainage of Splenic Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06914ZZ" = "1" /* Drainage of Splenic Vein, Percutaneous Endoscopic Approach */
"069240Z" = "1" /* Drainage of Gastric Vein with Drainage Device, Percutaneous Endoscopic Approach */
"06924ZX" = "1" /* Drainage of Gastric Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06924ZZ" = "1" /* Drainage of Gastric Vein, Percutaneous Endoscopic Approach */
"069340Z" = "1" /* Drainage of Esophageal Vein with Drainage Device, Percutaneous Endoscopic Approach */
"06934ZX" = "1" /* Drainage of Esophageal Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06934ZZ" = "1" /* Drainage of Esophageal Vein, Percutaneous Endoscopic Approach */
"069440Z" = "1" /* Drainage of Hepatic Vein with Drainage Device, Percutaneous Endoscopic Approach */
"06944ZX" = "1" /* Drainage of Hepatic Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06944ZZ" = "1" /* Drainage of Hepatic Vein, Percutaneous Endoscopic Approach */
"069540Z" = "1" /* Drainage of Superior Mesenteric Vein with Drainage Device, Percutaneous Endoscopic Approach */
"06954ZX" = "1" /* Drainage of Superior Mesenteric Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06954ZZ" = "1" /* Drainage of Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"069640Z" = "1" /* Drainage of Inferior Mesenteric Vein with Drainage Device, Percutaneous Endoscopic Approach */
"06964ZX" = "1" /* Drainage of Inferior Mesenteric Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06964ZZ" = "1" /* Drainage of Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"069740Z" = "1" /* Drainage of Colic Vein with Drainage Device, Percutaneous Endoscopic Approach */
"06974ZX" = "1" /* Drainage of Colic Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06974ZZ" = "1" /* Drainage of Colic Vein, Percutaneous Endoscopic Approach */
"069840Z" = "1" /* Drainage of Portal Vein with Drainage Device, Percutaneous Endoscopic Approach */
"06984ZX" = "1" /* Drainage of Portal Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06984ZZ" = "1" /* Drainage of Portal Vein, Percutaneous Endoscopic Approach */
"069940Z" = "1" /* Drainage of Right Renal Vein with Drainage Device, Percutaneous Endoscopic Approach */
"06994ZX" = "1" /* Drainage of Right Renal Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06994ZZ" = "1" /* Drainage of Right Renal Vein, Percutaneous Endoscopic Approach */
"069B40Z" = "1" /* Drainage of Left Renal Vein with Drainage Device, Percutaneous Endoscopic Approach */
"069B4ZX" = "1" /* Drainage of Left Renal Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069B4ZZ" = "1" /* Drainage of Left Renal Vein, Percutaneous Endoscopic Approach */
"069C40Z" = "1" /* Drainage of Right Common Iliac Vein with Drainage Device, Percutaneous Endoscopic Approach */
"069C4ZX" = "1" /* Drainage of Right Common Iliac Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069C4ZZ" = "1" /* Drainage of Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"069D40Z" = "1" /* Drainage of Left Common Iliac Vein with Drainage Device, Percutaneous Endoscopic Approach */
"069D4ZX" = "1" /* Drainage of Left Common Iliac Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069D4ZZ" = "1" /* Drainage of Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"069F40Z" = "1" /* Drainage of Right External Iliac Vein with Drainage Device, Percutaneous Endoscopic Approach */
"069F4ZX" = "1" /* Drainage of Right External Iliac Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069F4ZZ" = "1" /* Drainage of Right External Iliac Vein, Percutaneous Endoscopic Approach */
"069G40Z" = "1" /* Drainage of Left External Iliac Vein with Drainage Device, Percutaneous Endoscopic Approach */
"069G4ZX" = "1" /* Drainage of Left External Iliac Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069G4ZZ" = "1" /* Drainage of Left External Iliac Vein, Percutaneous Endoscopic Approach */
"069H40Z" = "1" /* Drainage of Right Hypogastric Vein with Drainage Device, Percutaneous Endoscopic Approach */
"069H4ZX" = "1" /* Drainage of Right Hypogastric Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069H4ZZ" = "1" /* Drainage of Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"069J40Z" = "1" /* Drainage of Left Hypogastric Vein with Drainage Device, Percutaneous Endoscopic Approach */
"069J4ZX" = "1" /* Drainage of Left Hypogastric Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069J4ZZ" = "1" /* Drainage of Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"06B03ZX" = "1" /* Excision of Inferior Vena Cava, Percutaneous Approach, Diagnostic */
"06B03ZZ" = "1" /* Excision of Inferior Vena Cava, Percutaneous Approach */
"06B04ZX" = "1" /* Excision of Inferior Vena Cava, Percutaneous Endoscopic Approach, Diagnostic */
"06B04ZZ" = "1" /* Excision of Inferior Vena Cava, Percutaneous Endoscopic Approach */
"06B13ZX" = "1" /* Excision of Splenic Vein, Percutaneous Approach, Diagnostic */
"06B13ZZ" = "1" /* Excision of Splenic Vein, Percutaneous Approach */
"06B14ZX" = "1" /* Excision of Splenic Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06B14ZZ" = "1" /* Excision of Splenic Vein, Percutaneous Endoscopic Approach */
"06B23ZX" = "1" /* Excision of Gastric Vein, Percutaneous Approach, Diagnostic */
"06B23ZZ" = "1" /* Excision of Gastric Vein, Percutaneous Approach */
"06B24ZX" = "1" /* Excision of Gastric Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06B24ZZ" = "1" /* Excision of Gastric Vein, Percutaneous Endoscopic Approach */
"06B33ZX" = "1" /* Excision of Esophageal Vein, Percutaneous Approach, Diagnostic */
"06B33ZZ" = "1" /* Excision of Esophageal Vein, Percutaneous Approach */
"06B34ZX" = "1" /* Excision of Esophageal Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06B34ZZ" = "1" /* Excision of Esophageal Vein, Percutaneous Endoscopic Approach */
"06B43ZX" = "1" /* Excision of Hepatic Vein, Percutaneous Approach, Diagnostic */
"06B43ZZ" = "1" /* Excision of Hepatic Vein, Percutaneous Approach */
"06B44ZX" = "1" /* Excision of Hepatic Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06B44ZZ" = "1" /* Excision of Hepatic Vein, Percutaneous Endoscopic Approach */
"06B53ZX" = "1" /* Excision of Superior Mesenteric Vein, Percutaneous Approach, Diagnostic */
"06B53ZZ" = "1" /* Excision of Superior Mesenteric Vein, Percutaneous Approach */
"06B54ZX" = "1" /* Excision of Superior Mesenteric Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06B54ZZ" = "1" /* Excision of Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06B63ZX" = "1" /* Excision of Inferior Mesenteric Vein, Percutaneous Approach, Diagnostic */
"06B63ZZ" = "1" /* Excision of Inferior Mesenteric Vein, Percutaneous Approach */
"06B64ZX" = "1" /* Excision of Inferior Mesenteric Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06B64ZZ" = "1" /* Excision of Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06B73ZX" = "1" /* Excision of Colic Vein, Percutaneous Approach, Diagnostic */
"06B73ZZ" = "1" /* Excision of Colic Vein, Percutaneous Approach */
"06B74ZX" = "1" /* Excision of Colic Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06B74ZZ" = "1" /* Excision of Colic Vein, Percutaneous Endoscopic Approach */
"06B83ZX" = "1" /* Excision of Portal Vein, Percutaneous Approach, Diagnostic */
"06B83ZZ" = "1" /* Excision of Portal Vein, Percutaneous Approach */
"06B84ZX" = "1" /* Excision of Portal Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06B84ZZ" = "1" /* Excision of Portal Vein, Percutaneous Endoscopic Approach */
"06B93ZX" = "1" /* Excision of Right Renal Vein, Percutaneous Approach, Diagnostic */
"06B93ZZ" = "1" /* Excision of Right Renal Vein, Percutaneous Approach */
"06B94ZX" = "1" /* Excision of Right Renal Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06B94ZZ" = "1" /* Excision of Right Renal Vein, Percutaneous Endoscopic Approach */
"06BB3ZX" = "1" /* Excision of Left Renal Vein, Percutaneous Approach, Diagnostic */
"06BB3ZZ" = "1" /* Excision of Left Renal Vein, Percutaneous Approach */
"06BB4ZX" = "1" /* Excision of Left Renal Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06BB4ZZ" = "1" /* Excision of Left Renal Vein, Percutaneous Endoscopic Approach */
"06BC3ZX" = "1" /* Excision of Right Common Iliac Vein, Percutaneous Approach, Diagnostic */
"06BC3ZZ" = "1" /* Excision of Right Common Iliac Vein, Percutaneous Approach */
"06BC4ZX" = "1" /* Excision of Right Common Iliac Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06BC4ZZ" = "1" /* Excision of Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"06BD3ZX" = "1" /* Excision of Left Common Iliac Vein, Percutaneous Approach, Diagnostic */
"06BD3ZZ" = "1" /* Excision of Left Common Iliac Vein, Percutaneous Approach */
"06BD4ZX" = "1" /* Excision of Left Common Iliac Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06BD4ZZ" = "1" /* Excision of Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"06BF3ZX" = "1" /* Excision of Right External Iliac Vein, Percutaneous Approach, Diagnostic */
"06BF3ZZ" = "1" /* Excision of Right External Iliac Vein, Percutaneous Approach */
"06BF4ZX" = "1" /* Excision of Right External Iliac Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06BF4ZZ" = "1" /* Excision of Right External Iliac Vein, Percutaneous Endoscopic Approach */
"06BG3ZX" = "1" /* Excision of Left External Iliac Vein, Percutaneous Approach, Diagnostic */
"06BG3ZZ" = "1" /* Excision of Left External Iliac Vein, Percutaneous Approach */
"06BG4ZX" = "1" /* Excision of Left External Iliac Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06BG4ZZ" = "1" /* Excision of Left External Iliac Vein, Percutaneous Endoscopic Approach */
"06BH3ZX" = "1" /* Excision of Right Hypogastric Vein, Percutaneous Approach, Diagnostic */
"06BH3ZZ" = "1" /* Excision of Right Hypogastric Vein, Percutaneous Approach */
"06BH4ZX" = "1" /* Excision of Right Hypogastric Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06BH4ZZ" = "1" /* Excision of Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"06BJ3ZX" = "1" /* Excision of Left Hypogastric Vein, Percutaneous Approach, Diagnostic */
"06BJ3ZZ" = "1" /* Excision of Left Hypogastric Vein, Percutaneous Approach */
"06BJ4ZX" = "1" /* Excision of Left Hypogastric Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06BJ4ZZ" = "1" /* Excision of Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"06C04ZZ" = "1" /* Extirpation of Matter from Inferior Vena Cava, Percutaneous Endoscopic Approach */
"06C14ZZ" = "1" /* Extirpation of Matter from Splenic Vein, Percutaneous Endoscopic Approach */
"06C24ZZ" = "1" /* Extirpation of Matter from Gastric Vein, Percutaneous Endoscopic Approach */
"06C34ZZ" = "1" /* Extirpation of Matter from Esophageal Vein, Percutaneous Endoscopic Approach */
"06C44ZZ" = "1" /* Extirpation of Matter from Hepatic Vein, Percutaneous Endoscopic Approach */
"06C54ZZ" = "1" /* Extirpation of Matter from Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06C64ZZ" = "1" /* Extirpation of Matter from Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06C74ZZ" = "1" /* Extirpation of Matter from Colic Vein, Percutaneous Endoscopic Approach */
"06C84ZZ" = "1" /* Extirpation of Matter from Portal Vein, Percutaneous Endoscopic Approach */
"06C94ZZ" = "1" /* Extirpation of Matter from Right Renal Vein, Percutaneous Endoscopic Approach */
"06CB4ZZ" = "1" /* Extirpation of Matter from Left Renal Vein, Percutaneous Endoscopic Approach */
"06CC4ZZ" = "1" /* Extirpation of Matter from Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"06CD4ZZ" = "1" /* Extirpation of Matter from Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"06CF4ZZ" = "1" /* Extirpation of Matter from Right External Iliac Vein, Percutaneous Endoscopic Approach */
"06CG4ZZ" = "1" /* Extirpation of Matter from Left External Iliac Vein, Percutaneous Endoscopic Approach */
"06CH4ZZ" = "1" /* Extirpation of Matter from Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"06CJ4ZZ" = "1" /* Extirpation of Matter from Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"06H043Z" = "1" /* Insertion of Infusion Device into Inferior Vena Cava, Percutaneous Endoscopic Approach */
"06H04DZ" = "1" /* Insertion of Intraluminal Device into Inferior Vena Cava, Percutaneous Endoscopic Approach */
"06H143Z" = "1" /* Insertion of Infusion Device into Splenic Vein, Percutaneous Endoscopic Approach */
"06H14DZ" = "1" /* Insertion of Intraluminal Device into Splenic Vein, Percutaneous Endoscopic Approach */
"06H243Z" = "1" /* Insertion of Infusion Device into Gastric Vein, Percutaneous Endoscopic Approach */
"06H24DZ" = "1" /* Insertion of Intraluminal Device into Gastric Vein, Percutaneous Endoscopic Approach */
"06H343Z" = "1" /* Insertion of Infusion Device into Esophageal Vein, Percutaneous Endoscopic Approach */
"06H34DZ" = "1" /* Insertion of Intraluminal Device into Esophageal Vein, Percutaneous Endoscopic Approach */
"06H443Z" = "1" /* Insertion of Infusion Device into Hepatic Vein, Percutaneous Endoscopic Approach */
"06H44DZ" = "1" /* Insertion of Intraluminal Device into Hepatic Vein, Percutaneous Endoscopic Approach */
"06H543Z" = "1" /* Insertion of Infusion Device into Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06H54DZ" = "1" /* Insertion of Intraluminal Device into Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06H643Z" = "1" /* Insertion of Infusion Device into Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06H64DZ" = "1" /* Insertion of Intraluminal Device into Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06H743Z" = "1" /* Insertion of Infusion Device into Colic Vein, Percutaneous Endoscopic Approach */
"06H74DZ" = "1" /* Insertion of Intraluminal Device into Colic Vein, Percutaneous Endoscopic Approach */
"06H843Z" = "1" /* Insertion of Infusion Device into Portal Vein, Percutaneous Endoscopic Approach */
"06H84DZ" = "1" /* Insertion of Intraluminal Device into Portal Vein, Percutaneous Endoscopic Approach */
"06H943Z" = "1" /* Insertion of Infusion Device into Right Renal Vein, Percutaneous Endoscopic Approach */
"06H94DZ" = "1" /* Insertion of Intraluminal Device into Right Renal Vein, Percutaneous Endoscopic Approach */
"06HB43Z" = "1" /* Insertion of Infusion Device into Left Renal Vein, Percutaneous Endoscopic Approach */
"06HB4DZ" = "1" /* Insertion of Intraluminal Device into Left Renal Vein, Percutaneous Endoscopic Approach */
"06HC43Z" = "1" /* Insertion of Infusion Device into Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"06HC4DZ" = "1" /* Insertion of Intraluminal Device into Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"06HD43Z" = "1" /* Insertion of Infusion Device into Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"06HD4DZ" = "1" /* Insertion of Intraluminal Device into Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"06HF43Z" = "1" /* Insertion of Infusion Device into Right External Iliac Vein, Percutaneous Endoscopic Approach */
"06HF4DZ" = "1" /* Insertion of Intraluminal Device into Right External Iliac Vein, Percutaneous Endoscopic Approach */
"06HG43Z" = "1" /* Insertion of Infusion Device into Left External Iliac Vein, Percutaneous Endoscopic Approach */
"06HG4DZ" = "1" /* Insertion of Intraluminal Device into Left External Iliac Vein, Percutaneous Endoscopic Approach */
"06HH43Z" = "1" /* Insertion of Infusion Device into Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"06HH4DZ" = "1" /* Insertion of Intraluminal Device into Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"06HJ43Z" = "1" /* Insertion of Infusion Device into Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"06HJ4DZ" = "1" /* Insertion of Intraluminal Device into Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"06L03CZ" = "1" /* Occlusion of Inferior Vena Cava with Extraluminal Device, Percutaneous Approach */
"06L04CZ" = "1" /* Occlusion of Inferior Vena Cava with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L04DZ" = "1" /* Occlusion of Inferior Vena Cava with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L04ZZ" = "1" /* Occlusion of Inferior Vena Cava, Percutaneous Endoscopic Approach */
"06L13CZ" = "1" /* Occlusion of Splenic Vein with Extraluminal Device, Percutaneous Approach */
"06L14CZ" = "1" /* Occlusion of Splenic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L14DZ" = "1" /* Occlusion of Splenic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L14ZZ" = "1" /* Occlusion of Splenic Vein, Percutaneous Endoscopic Approach */
"06L23CZ" = "1" /* Occlusion of Gastric Vein with Extraluminal Device, Percutaneous Approach */
"06L24CZ" = "1" /* Occlusion of Gastric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L24DZ" = "1" /* Occlusion of Gastric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L24ZZ" = "1" /* Occlusion of Gastric Vein, Percutaneous Endoscopic Approach */
"06L33CZ" = "1" /* Occlusion of Esophageal Vein with Extraluminal Device, Percutaneous Approach */
"06L34CZ" = "1" /* Occlusion of Esophageal Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L34DZ" = "1" /* Occlusion of Esophageal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L34ZZ" = "1" /* Occlusion of Esophageal Vein, Percutaneous Endoscopic Approach */
"06L43CZ" = "1" /* Occlusion of Hepatic Vein with Extraluminal Device, Percutaneous Approach */
"06L44CZ" = "1" /* Occlusion of Hepatic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L44DZ" = "1" /* Occlusion of Hepatic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L44ZZ" = "1" /* Occlusion of Hepatic Vein, Percutaneous Endoscopic Approach */
"06L53CZ" = "1" /* Occlusion of Superior Mesenteric Vein with Extraluminal Device, Percutaneous Approach */
"06L54CZ" = "1" /* Occlusion of Superior Mesenteric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L54DZ" = "1" /* Occlusion of Superior Mesenteric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L54ZZ" = "1" /* Occlusion of Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06L63CZ" = "1" /* Occlusion of Inferior Mesenteric Vein with Extraluminal Device, Percutaneous Approach */
"06L64CZ" = "1" /* Occlusion of Inferior Mesenteric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L64DZ" = "1" /* Occlusion of Inferior Mesenteric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L64ZZ" = "1" /* Occlusion of Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06L73CZ" = "1" /* Occlusion of Colic Vein with Extraluminal Device, Percutaneous Approach */
"06L74CZ" = "1" /* Occlusion of Colic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L74DZ" = "1" /* Occlusion of Colic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L74ZZ" = "1" /* Occlusion of Colic Vein, Percutaneous Endoscopic Approach */
"06L83CZ" = "1" /* Occlusion of Portal Vein with Extraluminal Device, Percutaneous Approach */
"06L84CZ" = "1" /* Occlusion of Portal Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L84DZ" = "1" /* Occlusion of Portal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L84ZZ" = "1" /* Occlusion of Portal Vein, Percutaneous Endoscopic Approach */
"06L93CZ" = "1" /* Occlusion of Right Renal Vein with Extraluminal Device, Percutaneous Approach */
"06L94CZ" = "1" /* Occlusion of Right Renal Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L94DZ" = "1" /* Occlusion of Right Renal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L94ZZ" = "1" /* Occlusion of Right Renal Vein, Percutaneous Endoscopic Approach */
"06LB3CZ" = "1" /* Occlusion of Left Renal Vein with Extraluminal Device, Percutaneous Approach */
"06LB4CZ" = "1" /* Occlusion of Left Renal Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LB4DZ" = "1" /* Occlusion of Left Renal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LB4ZZ" = "1" /* Occlusion of Left Renal Vein, Percutaneous Endoscopic Approach */
"06LC3CZ" = "1" /* Occlusion of Right Common Iliac Vein with Extraluminal Device, Percutaneous Approach */
"06LC4CZ" = "1" /* Occlusion of Right Common Iliac Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LC4DZ" = "1" /* Occlusion of Right Common Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LC4ZZ" = "1" /* Occlusion of Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"06LD3CZ" = "1" /* Occlusion of Left Common Iliac Vein with Extraluminal Device, Percutaneous Approach */
"06LD4CZ" = "1" /* Occlusion of Left Common Iliac Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LD4DZ" = "1" /* Occlusion of Left Common Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LD4ZZ" = "1" /* Occlusion of Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"06LF3CZ" = "1" /* Occlusion of Right External Iliac Vein with Extraluminal Device, Percutaneous Approach */
"06LF4CZ" = "1" /* Occlusion of Right External Iliac Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LF4DZ" = "1" /* Occlusion of Right External Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LF4ZZ" = "1" /* Occlusion of Right External Iliac Vein, Percutaneous Endoscopic Approach */
"06LG3CZ" = "1" /* Occlusion of Left External Iliac Vein with Extraluminal Device, Percutaneous Approach */
"06LG4CZ" = "1" /* Occlusion of Left External Iliac Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LG4DZ" = "1" /* Occlusion of Left External Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LG4ZZ" = "1" /* Occlusion of Left External Iliac Vein, Percutaneous Endoscopic Approach */
"06LH3CZ" = "1" /* Occlusion of Right Hypogastric Vein with Extraluminal Device, Percutaneous Approach */
"06LH4CZ" = "1" /* Occlusion of Right Hypogastric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LH4DZ" = "1" /* Occlusion of Right Hypogastric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LH4ZZ" = "1" /* Occlusion of Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"06LJ3CZ" = "1" /* Occlusion of Left Hypogastric Vein with Extraluminal Device, Percutaneous Approach */
"06LJ4CZ" = "1" /* Occlusion of Left Hypogastric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LJ4DZ" = "1" /* Occlusion of Left Hypogastric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LJ4ZZ" = "1" /* Occlusion of Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"06N03ZZ" = "1" /* Release Inferior Vena Cava, Percutaneous Approach */
"06N04ZZ" = "1" /* Release Inferior Vena Cava, Percutaneous Endoscopic Approach */
"06N13ZZ" = "1" /* Release Splenic Vein, Percutaneous Approach */
"06N14ZZ" = "1" /* Release Splenic Vein, Percutaneous Endoscopic Approach */
"06N23ZZ" = "1" /* Release Gastric Vein, Percutaneous Approach */
"06N24ZZ" = "1" /* Release Gastric Vein, Percutaneous Endoscopic Approach */
"06N33ZZ" = "1" /* Release Esophageal Vein, Percutaneous Approach */
"06N34ZZ" = "1" /* Release Esophageal Vein, Percutaneous Endoscopic Approach */
"06N43ZZ" = "1" /* Release Hepatic Vein, Percutaneous Approach */
"06N44ZZ" = "1" /* Release Hepatic Vein, Percutaneous Endoscopic Approach */
"06N53ZZ" = "1" /* Release Superior Mesenteric Vein, Percutaneous Approach */
"06N54ZZ" = "1" /* Release Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06N63ZZ" = "1" /* Release Inferior Mesenteric Vein, Percutaneous Approach */
"06N64ZZ" = "1" /* Release Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06N73ZZ" = "1" /* Release Colic Vein, Percutaneous Approach */
"06N74ZZ" = "1" /* Release Colic Vein, Percutaneous Endoscopic Approach */
"06N83ZZ" = "1" /* Release Portal Vein, Percutaneous Approach */
"06N84ZZ" = "1" /* Release Portal Vein, Percutaneous Endoscopic Approach */
"06N93ZZ" = "1" /* Release Right Renal Vein, Percutaneous Approach */
"06N94ZZ" = "1" /* Release Right Renal Vein, Percutaneous Endoscopic Approach */
"06NB3ZZ" = "1" /* Release Left Renal Vein, Percutaneous Approach */
"06NB4ZZ" = "1" /* Release Left Renal Vein, Percutaneous Endoscopic Approach */
"06NC3ZZ" = "1" /* Release Right Common Iliac Vein, Percutaneous Approach */
"06NC4ZZ" = "1" /* Release Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"06ND3ZZ" = "1" /* Release Left Common Iliac Vein, Percutaneous Approach */
"06ND4ZZ" = "1" /* Release Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"06NF3ZZ" = "1" /* Release Right External Iliac Vein, Percutaneous Approach */
"06NF4ZZ" = "1" /* Release Right External Iliac Vein, Percutaneous Endoscopic Approach */
"06NG3ZZ" = "1" /* Release Left External Iliac Vein, Percutaneous Approach */
"06NG4ZZ" = "1" /* Release Left External Iliac Vein, Percutaneous Endoscopic Approach */
"06NH3ZZ" = "1" /* Release Right Hypogastric Vein, Percutaneous Approach */
"06NH4ZZ" = "1" /* Release Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"06NJ3ZZ" = "1" /* Release Left Hypogastric Vein, Percutaneous Approach */
"06NJ4ZZ" = "1" /* Release Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"06Q04ZZ" = "1" /* Repair Inferior Vena Cava, Percutaneous Endoscopic Approach */
"06Q14ZZ" = "1" /* Repair Splenic Vein, Percutaneous Endoscopic Approach */
"06Q24ZZ" = "1" /* Repair Gastric Vein, Percutaneous Endoscopic Approach */
"06Q34ZZ" = "1" /* Repair Esophageal Vein, Percutaneous Endoscopic Approach */
"06Q44ZZ" = "1" /* Repair Hepatic Vein, Percutaneous Endoscopic Approach */
"06Q54ZZ" = "1" /* Repair Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06Q64ZZ" = "1" /* Repair Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06Q74ZZ" = "1" /* Repair Colic Vein, Percutaneous Endoscopic Approach */
"06Q84ZZ" = "1" /* Repair Portal Vein, Percutaneous Endoscopic Approach */
"06Q94ZZ" = "1" /* Repair Right Renal Vein, Percutaneous Endoscopic Approach */
"06QB4ZZ" = "1" /* Repair Left Renal Vein, Percutaneous Endoscopic Approach */
"06QC4ZZ" = "1" /* Repair Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"06QD4ZZ" = "1" /* Repair Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"06QF4ZZ" = "1" /* Repair Right External Iliac Vein, Percutaneous Endoscopic Approach */
"06QG4ZZ" = "1" /* Repair Left External Iliac Vein, Percutaneous Endoscopic Approach */
"06QH4ZZ" = "1" /* Repair Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"06QJ4ZZ" = "1" /* Repair Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"06R047Z" = "1" /* Replacement of Inferior Vena Cava with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R04JZ" = "1" /* Replacement of Inferior Vena Cava with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06R04KZ" = "1" /* Replacement of Inferior Vena Cava with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R147Z" = "1" /* Replacement of Splenic Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R14JZ" = "1" /* Replacement of Splenic Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06R14KZ" = "1" /* Replacement of Splenic Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R247Z" = "1" /* Replacement of Gastric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R24JZ" = "1" /* Replacement of Gastric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06R24KZ" = "1" /* Replacement of Gastric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R347Z" = "1" /* Replacement of Esophageal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R34JZ" = "1" /* Replacement of Esophageal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06R34KZ" = "1" /* Replacement of Esophageal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R447Z" = "1" /* Replacement of Hepatic Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R44JZ" = "1" /* Replacement of Hepatic Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06R44KZ" = "1" /* Replacement of Hepatic Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R547Z" = "1" /* Replacement of Superior Mesenteric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R54JZ" = "1" /* Replacement of Superior Mesenteric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06R54KZ" = "1" /* Replacement of Superior Mesenteric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R647Z" = "1" /* Replacement of Inferior Mesenteric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R64JZ" = "1" /* Replacement of Inferior Mesenteric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06R64KZ" = "1" /* Replacement of Inferior Mesenteric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R747Z" = "1" /* Replacement of Colic Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R74JZ" = "1" /* Replacement of Colic Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06R74KZ" = "1" /* Replacement of Colic Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R847Z" = "1" /* Replacement of Portal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R84JZ" = "1" /* Replacement of Portal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06R84KZ" = "1" /* Replacement of Portal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R947Z" = "1" /* Replacement of Right Renal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R94JZ" = "1" /* Replacement of Right Renal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06R94KZ" = "1" /* Replacement of Right Renal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RB47Z" = "1" /* Replacement of Left Renal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RB4JZ" = "1" /* Replacement of Left Renal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06RB4KZ" = "1" /* Replacement of Left Renal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RC47Z" = "1" /* Replacement of Right Common Iliac Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RC4JZ" = "1" /* Replacement of Right Common Iliac Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06RC4KZ" = "1" /* Replacement of Right Common Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RD47Z" = "1" /* Replacement of Left Common Iliac Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RD4JZ" = "1" /* Replacement of Left Common Iliac Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06RD4KZ" = "1" /* Replacement of Left Common Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RF47Z" = "1" /* Replacement of Right External Iliac Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RF4JZ" = "1" /* Replacement of Right External Iliac Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06RF4KZ" = "1" /* Replacement of Right External Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RG47Z" = "1" /* Replacement of Left External Iliac Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RG4JZ" = "1" /* Replacement of Left External Iliac Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06RG4KZ" = "1" /* Replacement of Left External Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RH47Z" = "1" /* Replacement of Right Hypogastric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RH4JZ" = "1" /* Replacement of Right Hypogastric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06RH4KZ" = "1" /* Replacement of Right Hypogastric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RJ47Z" = "1" /* Replacement of Left Hypogastric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RJ4JZ" = "1" /* Replacement of Left Hypogastric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06RJ4KZ" = "1" /* Replacement of Left Hypogastric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06S03ZZ" = "1" /* Reposition Inferior Vena Cava, Percutaneous Approach */
"06S04ZZ" = "1" /* Reposition Inferior Vena Cava, Percutaneous Endoscopic Approach */
"06S13ZZ" = "1" /* Reposition Splenic Vein, Percutaneous Approach */
"06S14ZZ" = "1" /* Reposition Splenic Vein, Percutaneous Endoscopic Approach */
"06S23ZZ" = "1" /* Reposition Gastric Vein, Percutaneous Approach */
"06S24ZZ" = "1" /* Reposition Gastric Vein, Percutaneous Endoscopic Approach */
"06S33ZZ" = "1" /* Reposition Esophageal Vein, Percutaneous Approach */
"06S34ZZ" = "1" /* Reposition Esophageal Vein, Percutaneous Endoscopic Approach */
"06S43ZZ" = "1" /* Reposition Hepatic Vein, Percutaneous Approach */
"06S44ZZ" = "1" /* Reposition Hepatic Vein, Percutaneous Endoscopic Approach */
"06S53ZZ" = "1" /* Reposition Superior Mesenteric Vein, Percutaneous Approach */
"06S54ZZ" = "1" /* Reposition Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06S63ZZ" = "1" /* Reposition Inferior Mesenteric Vein, Percutaneous Approach */
"06S64ZZ" = "1" /* Reposition Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06S73ZZ" = "1" /* Reposition Colic Vein, Percutaneous Approach */
"06S74ZZ" = "1" /* Reposition Colic Vein, Percutaneous Endoscopic Approach */
"06S83ZZ" = "1" /* Reposition Portal Vein, Percutaneous Approach */
"06S84ZZ" = "1" /* Reposition Portal Vein, Percutaneous Endoscopic Approach */
"06S93ZZ" = "1" /* Reposition Right Renal Vein, Percutaneous Approach */
"06S94ZZ" = "1" /* Reposition Right Renal Vein, Percutaneous Endoscopic Approach */
"06SB3ZZ" = "1" /* Reposition Left Renal Vein, Percutaneous Approach */
"06SB4ZZ" = "1" /* Reposition Left Renal Vein, Percutaneous Endoscopic Approach */
"06SC3ZZ" = "1" /* Reposition Right Common Iliac Vein, Percutaneous Approach */
"06SC4ZZ" = "1" /* Reposition Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"06SD3ZZ" = "1" /* Reposition Left Common Iliac Vein, Percutaneous Approach */
"06SD4ZZ" = "1" /* Reposition Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"06SF3ZZ" = "1" /* Reposition Right External Iliac Vein, Percutaneous Approach */
"06SF4ZZ" = "1" /* Reposition Right External Iliac Vein, Percutaneous Endoscopic Approach */
"06SG3ZZ" = "1" /* Reposition Left External Iliac Vein, Percutaneous Approach */
"06SG4ZZ" = "1" /* Reposition Left External Iliac Vein, Percutaneous Endoscopic Approach */
"06SH3ZZ" = "1" /* Reposition Right Hypogastric Vein, Percutaneous Approach */
"06SH4ZZ" = "1" /* Reposition Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"06SJ3ZZ" = "1" /* Reposition Left Hypogastric Vein, Percutaneous Approach */
"06SJ4ZZ" = "1" /* Reposition Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"06U037Z" = "1" /* Supplement Inferior Vena Cava with Autologous Tissue Substitute, Percutaneous Approach */
"06U03JZ" = "1" /* Supplement Inferior Vena Cava with Synthetic Substitute, Percutaneous Approach */
"06U03KZ" = "1" /* Supplement Inferior Vena Cava with Nonautologous Tissue Substitute, Percutaneous Approach */
"06U047Z" = "1" /* Supplement Inferior Vena Cava with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U04JZ" = "1" /* Supplement Inferior Vena Cava with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06U04KZ" = "1" /* Supplement Inferior Vena Cava with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U137Z" = "1" /* Supplement Splenic Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06U13JZ" = "1" /* Supplement Splenic Vein with Synthetic Substitute, Percutaneous Approach */
"06U13KZ" = "1" /* Supplement Splenic Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06U147Z" = "1" /* Supplement Splenic Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U14JZ" = "1" /* Supplement Splenic Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06U14KZ" = "1" /* Supplement Splenic Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U237Z" = "1" /* Supplement Gastric Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06U23JZ" = "1" /* Supplement Gastric Vein with Synthetic Substitute, Percutaneous Approach */
"06U23KZ" = "1" /* Supplement Gastric Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06U247Z" = "1" /* Supplement Gastric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U24JZ" = "1" /* Supplement Gastric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06U24KZ" = "1" /* Supplement Gastric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U337Z" = "1" /* Supplement Esophageal Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06U33JZ" = "1" /* Supplement Esophageal Vein with Synthetic Substitute, Percutaneous Approach */
"06U33KZ" = "1" /* Supplement Esophageal Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06U347Z" = "1" /* Supplement Esophageal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U34JZ" = "1" /* Supplement Esophageal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06U34KZ" = "1" /* Supplement Esophageal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U437Z" = "1" /* Supplement Hepatic Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06U43JZ" = "1" /* Supplement Hepatic Vein with Synthetic Substitute, Percutaneous Approach */
"06U43KZ" = "1" /* Supplement Hepatic Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06U447Z" = "1" /* Supplement Hepatic Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U44JZ" = "1" /* Supplement Hepatic Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06U44KZ" = "1" /* Supplement Hepatic Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U537Z" = "1" /* Supplement Superior Mesenteric Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06U53JZ" = "1" /* Supplement Superior Mesenteric Vein with Synthetic Substitute, Percutaneous Approach */
"06U53KZ" = "1" /* Supplement Superior Mesenteric Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06U547Z" = "1" /* Supplement Superior Mesenteric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U54JZ" = "1" /* Supplement Superior Mesenteric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06U54KZ" = "1" /* Supplement Superior Mesenteric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U637Z" = "1" /* Supplement Inferior Mesenteric Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06U63JZ" = "1" /* Supplement Inferior Mesenteric Vein with Synthetic Substitute, Percutaneous Approach */
"06U63KZ" = "1" /* Supplement Inferior Mesenteric Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06U647Z" = "1" /* Supplement Inferior Mesenteric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U64JZ" = "1" /* Supplement Inferior Mesenteric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06U64KZ" = "1" /* Supplement Inferior Mesenteric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U737Z" = "1" /* Supplement Colic Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06U73JZ" = "1" /* Supplement Colic Vein with Synthetic Substitute, Percutaneous Approach */
"06U73KZ" = "1" /* Supplement Colic Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06U747Z" = "1" /* Supplement Colic Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U74JZ" = "1" /* Supplement Colic Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06U74KZ" = "1" /* Supplement Colic Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U837Z" = "1" /* Supplement Portal Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06U83JZ" = "1" /* Supplement Portal Vein with Synthetic Substitute, Percutaneous Approach */
"06U83KZ" = "1" /* Supplement Portal Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06U847Z" = "1" /* Supplement Portal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U84JZ" = "1" /* Supplement Portal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06U84KZ" = "1" /* Supplement Portal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U937Z" = "1" /* Supplement Right Renal Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06U93JZ" = "1" /* Supplement Right Renal Vein with Synthetic Substitute, Percutaneous Approach */
"06U93KZ" = "1" /* Supplement Right Renal Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06U947Z" = "1" /* Supplement Right Renal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U94JZ" = "1" /* Supplement Right Renal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06U94KZ" = "1" /* Supplement Right Renal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UB37Z" = "1" /* Supplement Left Renal Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06UB3JZ" = "1" /* Supplement Left Renal Vein with Synthetic Substitute, Percutaneous Approach */
"06UB3KZ" = "1" /* Supplement Left Renal Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06UB47Z" = "1" /* Supplement Left Renal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UB4JZ" = "1" /* Supplement Left Renal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06UB4KZ" = "1" /* Supplement Left Renal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UC37Z" = "1" /* Supplement Right Common Iliac Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06UC3JZ" = "1" /* Supplement Right Common Iliac Vein with Synthetic Substitute, Percutaneous Approach */
"06UC3KZ" = "1" /* Supplement Right Common Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06UC47Z" = "1" /* Supplement Right Common Iliac Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UC4JZ" = "1" /* Supplement Right Common Iliac Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06UC4KZ" = "1" /* Supplement Right Common Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UD37Z" = "1" /* Supplement Left Common Iliac Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06UD3JZ" = "1" /* Supplement Left Common Iliac Vein with Synthetic Substitute, Percutaneous Approach */
"06UD3KZ" = "1" /* Supplement Left Common Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06UD47Z" = "1" /* Supplement Left Common Iliac Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UD4JZ" = "1" /* Supplement Left Common Iliac Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06UD4KZ" = "1" /* Supplement Left Common Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UF37Z" = "1" /* Supplement Right External Iliac Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06UF3JZ" = "1" /* Supplement Right External Iliac Vein with Synthetic Substitute, Percutaneous Approach */
"06UF3KZ" = "1" /* Supplement Right External Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06UF47Z" = "1" /* Supplement Right External Iliac Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UF4JZ" = "1" /* Supplement Right External Iliac Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06UF4KZ" = "1" /* Supplement Right External Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UG37Z" = "1" /* Supplement Left External Iliac Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06UG3JZ" = "1" /* Supplement Left External Iliac Vein with Synthetic Substitute, Percutaneous Approach */
"06UG3KZ" = "1" /* Supplement Left External Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06UG47Z" = "1" /* Supplement Left External Iliac Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UG4JZ" = "1" /* Supplement Left External Iliac Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06UG4KZ" = "1" /* Supplement Left External Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UH37Z" = "1" /* Supplement Right Hypogastric Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06UH3JZ" = "1" /* Supplement Right Hypogastric Vein with Synthetic Substitute, Percutaneous Approach */
"06UH3KZ" = "1" /* Supplement Right Hypogastric Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06UH47Z" = "1" /* Supplement Right Hypogastric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UH4JZ" = "1" /* Supplement Right Hypogastric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06UH4KZ" = "1" /* Supplement Right Hypogastric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UJ37Z" = "1" /* Supplement Left Hypogastric Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06UJ3JZ" = "1" /* Supplement Left Hypogastric Vein with Synthetic Substitute, Percutaneous Approach */
"06UJ3KZ" = "1" /* Supplement Left Hypogastric Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06UJ47Z" = "1" /* Supplement Left Hypogastric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UJ4JZ" = "1" /* Supplement Left Hypogastric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06UJ4KZ" = "1" /* Supplement Left Hypogastric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06V03CZ" = "1" /* Restriction of Inferior Vena Cava with Extraluminal Device, Percutaneous Approach */
"06V04CZ" = "1" /* Restriction of Inferior Vena Cava with Extraluminal Device, Percutaneous Endoscopic Approach */
"06V04DZ" = "1" /* Restriction of Inferior Vena Cava with Intraluminal Device, Percutaneous Endoscopic Approach */
"06V04ZZ" = "1" /* Restriction of Inferior Vena Cava, Percutaneous Endoscopic Approach */
"06V13CZ" = "1" /* Restriction of Splenic Vein with Extraluminal Device, Percutaneous Approach */
"06V14CZ" = "1" /* Restriction of Splenic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06V14DZ" = "1" /* Restriction of Splenic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06V14ZZ" = "1" /* Restriction of Splenic Vein, Percutaneous Endoscopic Approach */
"06V23CZ" = "1" /* Restriction of Gastric Vein with Extraluminal Device, Percutaneous Approach */
"06V24CZ" = "1" /* Restriction of Gastric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06V24DZ" = "1" /* Restriction of Gastric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06V24ZZ" = "1" /* Restriction of Gastric Vein, Percutaneous Endoscopic Approach */
"06V33CZ" = "1" /* Restriction of Esophageal Vein with Extraluminal Device, Percutaneous Approach */
"06V34CZ" = "1" /* Restriction of Esophageal Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06V34DZ" = "1" /* Restriction of Esophageal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06V34ZZ" = "1" /* Restriction of Esophageal Vein, Percutaneous Endoscopic Approach */
"06V43CZ" = "1" /* Restriction of Hepatic Vein with Extraluminal Device, Percutaneous Approach */
"06V44CZ" = "1" /* Restriction of Hepatic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06V44DZ" = "1" /* Restriction of Hepatic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06V44ZZ" = "1" /* Restriction of Hepatic Vein, Percutaneous Endoscopic Approach */
"06V53CZ" = "1" /* Restriction of Superior Mesenteric Vein with Extraluminal Device, Percutaneous Approach */
"06V54CZ" = "1" /* Restriction of Superior Mesenteric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06V54DZ" = "1" /* Restriction of Superior Mesenteric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06V54ZZ" = "1" /* Restriction of Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06V63CZ" = "1" /* Restriction of Inferior Mesenteric Vein with Extraluminal Device, Percutaneous Approach */
"06V64CZ" = "1" /* Restriction of Inferior Mesenteric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06V64DZ" = "1" /* Restriction of Inferior Mesenteric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06V64ZZ" = "1" /* Restriction of Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06V73CZ" = "1" /* Restriction of Colic Vein with Extraluminal Device, Percutaneous Approach */
"06V74CZ" = "1" /* Restriction of Colic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06V74DZ" = "1" /* Restriction of Colic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06V74ZZ" = "1" /* Restriction of Colic Vein, Percutaneous Endoscopic Approach */
"06V83CZ" = "1" /* Restriction of Portal Vein with Extraluminal Device, Percutaneous Approach */
"06V84CZ" = "1" /* Restriction of Portal Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06V84DZ" = "1" /* Restriction of Portal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06V84ZZ" = "1" /* Restriction of Portal Vein, Percutaneous Endoscopic Approach */
"06V93CZ" = "1" /* Restriction of Right Renal Vein with Extraluminal Device, Percutaneous Approach */
"06V94CZ" = "1" /* Restriction of Right Renal Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06V94DZ" = "1" /* Restriction of Right Renal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06V94ZZ" = "1" /* Restriction of Right Renal Vein, Percutaneous Endoscopic Approach */
"06VB3CZ" = "1" /* Restriction of Left Renal Vein with Extraluminal Device, Percutaneous Approach */
"06VB4CZ" = "1" /* Restriction of Left Renal Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06VB4DZ" = "1" /* Restriction of Left Renal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06VB4ZZ" = "1" /* Restriction of Left Renal Vein, Percutaneous Endoscopic Approach */
"06VC3CZ" = "1" /* Restriction of Right Common Iliac Vein with Extraluminal Device, Percutaneous Approach */
"06VC4CZ" = "1" /* Restriction of Right Common Iliac Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06VC4DZ" = "1" /* Restriction of Right Common Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06VC4ZZ" = "1" /* Restriction of Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"06VD3CZ" = "1" /* Restriction of Left Common Iliac Vein with Extraluminal Device, Percutaneous Approach */
"06VD4CZ" = "1" /* Restriction of Left Common Iliac Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06VD4DZ" = "1" /* Restriction of Left Common Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06VD4ZZ" = "1" /* Restriction of Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"06VF3CZ" = "1" /* Restriction of Right External Iliac Vein with Extraluminal Device, Percutaneous Approach */
"06VF4CZ" = "1" /* Restriction of Right External Iliac Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06VF4DZ" = "1" /* Restriction of Right External Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06VF4ZZ" = "1" /* Restriction of Right External Iliac Vein, Percutaneous Endoscopic Approach */
"06VG3CZ" = "1" /* Restriction of Left External Iliac Vein with Extraluminal Device, Percutaneous Approach */
"06VG4CZ" = "1" /* Restriction of Left External Iliac Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06VG4DZ" = "1" /* Restriction of Left External Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06VG4ZZ" = "1" /* Restriction of Left External Iliac Vein, Percutaneous Endoscopic Approach */
"06VH3CZ" = "1" /* Restriction of Right Hypogastric Vein with Extraluminal Device, Percutaneous Approach */
"06VH4CZ" = "1" /* Restriction of Right Hypogastric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06VH4DZ" = "1" /* Restriction of Right Hypogastric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06VH4ZZ" = "1" /* Restriction of Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"06VJ3CZ" = "1" /* Restriction of Left Hypogastric Vein with Extraluminal Device, Percutaneous Approach */
"06VJ4CZ" = "1" /* Restriction of Left Hypogastric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06VJ4DZ" = "1" /* Restriction of Left Hypogastric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06VJ4ZZ" = "1" /* Restriction of Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"075B3ZZ" = "1" /* Destruction of Mesenteric Lymphatic, Percutaneous Approach */
"075B4ZZ" = "1" /* Destruction of Mesenteric Lymphatic, Percutaneous Endoscopic Approach */
"075C3ZZ" = "1" /* Destruction of Pelvis Lymphatic, Percutaneous Approach */
"075C4ZZ" = "1" /* Destruction of Pelvis Lymphatic, Percutaneous Endoscopic Approach */
"075D3ZZ" = "1" /* Destruction of Aortic Lymphatic, Percutaneous Approach */
"075D4ZZ" = "1" /* Destruction of Aortic Lymphatic, Percutaneous Endoscopic Approach */
"075P3ZZ" = "1" /* Destruction of Spleen, Percutaneous Approach */
"075P4ZZ" = "1" /* Destruction of Spleen, Percutaneous Endoscopic Approach */
"079B30Z" = "1" /* Drainage of Mesenteric Lymphatic with Drainage Device, Percutaneous Approach */
"079B3ZX" = "1" /* Drainage of Mesenteric Lymphatic, Percutaneous Approach, Diagnostic */
"079B3ZZ" = "1" /* Drainage of Mesenteric Lymphatic, Percutaneous Approach */
"079B40Z" = "1" /* Drainage of Mesenteric Lymphatic with Drainage Device, Percutaneous Endoscopic Approach */
"079B4ZX" = "1" /* Drainage of Mesenteric Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"079B4ZZ" = "1" /* Drainage of Mesenteric Lymphatic, Percutaneous Endoscopic Approach */
"079C30Z" = "1" /* Drainage of Pelvis Lymphatic with Drainage Device, Percutaneous Approach */
"079C3ZX" = "1" /* Drainage of Pelvis Lymphatic, Percutaneous Approach, Diagnostic */
"079C3ZZ" = "1" /* Drainage of Pelvis Lymphatic, Percutaneous Approach */
"079C40Z" = "1" /* Drainage of Pelvis Lymphatic with Drainage Device, Percutaneous Endoscopic Approach */
"079C4ZX" = "1" /* Drainage of Pelvis Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"079C4ZZ" = "1" /* Drainage of Pelvis Lymphatic, Percutaneous Endoscopic Approach */
"079D30Z" = "1" /* Drainage of Aortic Lymphatic with Drainage Device, Percutaneous Approach */
"079D3ZX" = "1" /* Drainage of Aortic Lymphatic, Percutaneous Approach, Diagnostic */
"079D3ZZ" = "1" /* Drainage of Aortic Lymphatic, Percutaneous Approach */
"079D40Z" = "1" /* Drainage of Aortic Lymphatic with Drainage Device, Percutaneous Endoscopic Approach */
"079D4ZX" = "1" /* Drainage of Aortic Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"079D4ZZ" = "1" /* Drainage of Aortic Lymphatic, Percutaneous Endoscopic Approach */
"079P30Z" = "1" /* Drainage of Spleen with Drainage Device, Percutaneous Approach */
"079P3ZX" = "1" /* Drainage of Spleen, Percutaneous Approach, Diagnostic */
"079P3ZZ" = "1" /* Drainage of Spleen, Percutaneous Approach */
"079P40Z" = "1" /* Drainage of Spleen with Drainage Device, Percutaneous Endoscopic Approach */
"079P4ZX" = "1" /* Drainage of Spleen, Percutaneous Endoscopic Approach, Diagnostic */
"079P4ZZ" = "1" /* Drainage of Spleen, Percutaneous Endoscopic Approach */
"07BB3ZX" = "1" /* Excision of Mesenteric Lymphatic, Percutaneous Approach, Diagnostic */
"07BB3ZZ" = "1" /* Excision of Mesenteric Lymphatic, Percutaneous Approach */
"07BB4ZX" = "1" /* Excision of Mesenteric Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07BB4ZZ" = "1" /* Excision of Mesenteric Lymphatic, Percutaneous Endoscopic Approach */
"07BC3ZX" = "1" /* Excision of Pelvis Lymphatic, Percutaneous Approach, Diagnostic */
"07BC3ZZ" = "1" /* Excision of Pelvis Lymphatic, Percutaneous Approach */
"07BC4ZX" = "1" /* Excision of Pelvis Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07BC4ZZ" = "1" /* Excision of Pelvis Lymphatic, Percutaneous Endoscopic Approach */
"07BD3ZX" = "1" /* Excision of Aortic Lymphatic, Percutaneous Approach, Diagnostic */
"07BD3ZZ" = "1" /* Excision of Aortic Lymphatic, Percutaneous Approach */
"07BD4ZX" = "1" /* Excision of Aortic Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07BD4ZZ" = "1" /* Excision of Aortic Lymphatic, Percutaneous Endoscopic Approach */
"07BP3ZX" = "1" /* Excision of Spleen, Percutaneous Approach, Diagnostic */
"07BP3ZZ" = "1" /* Excision of Spleen, Percutaneous Approach */
"07BP4ZX" = "1" /* Excision of Spleen, Percutaneous Endoscopic Approach, Diagnostic */
"07BP4ZZ" = "1" /* Excision of Spleen, Percutaneous Endoscopic Approach */
"07CB3ZZ" = "1" /* Extirpation of Matter from Mesenteric Lymphatic, Percutaneous Approach */
"07CB4ZZ" = "1" /* Extirpation of Matter from Mesenteric Lymphatic, Percutaneous Endoscopic Approach */
"07CC3ZZ" = "1" /* Extirpation of Matter from Pelvis Lymphatic, Percutaneous Approach */
"07CC4ZZ" = "1" /* Extirpation of Matter from Pelvis Lymphatic, Percutaneous Endoscopic Approach */
"07CD3ZZ" = "1" /* Extirpation of Matter from Aortic Lymphatic, Percutaneous Approach */
"07CD4ZZ" = "1" /* Extirpation of Matter from Aortic Lymphatic, Percutaneous Endoscopic Approach */
"07CP3ZZ" = "1" /* Extirpation of Matter from Spleen, Percutaneous Approach */
"07CP4ZZ" = "1" /* Extirpation of Matter from Spleen, Percutaneous Endoscopic Approach */
"07HP33Z" = "1" /* Insertion of Infusion Device into Spleen, Percutaneous Approach */
"07HP43Z" = "1" /* Insertion of Infusion Device into Spleen, Percutaneous Endoscopic Approach */
"07JP3ZZ" = "1" /* Inspection of Spleen, Percutaneous Approach */
"07JP4ZZ" = "1" /* Inspection of Spleen, Percutaneous Endoscopic Approach */
"07LB3CZ" = "1" /* Occlusion of Mesenteric Lymphatic with Extraluminal Device, Percutaneous Approach */
"07LB3DZ" = "1" /* Occlusion of Mesenteric Lymphatic with Intraluminal Device, Percutaneous Approach */
"07LB3ZZ" = "1" /* Occlusion of Mesenteric Lymphatic, Percutaneous Approach */
"07LB4CZ" = "1" /* Occlusion of Mesenteric Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07LB4DZ" = "1" /* Occlusion of Mesenteric Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07LB4ZZ" = "1" /* Occlusion of Mesenteric Lymphatic, Percutaneous Endoscopic Approach */
"07LC3CZ" = "1" /* Occlusion of Pelvis Lymphatic with Extraluminal Device, Percutaneous Approach */
"07LC3DZ" = "1" /* Occlusion of Pelvis Lymphatic with Intraluminal Device, Percutaneous Approach */
"07LC3ZZ" = "1" /* Occlusion of Pelvis Lymphatic, Percutaneous Approach */
"07LC4CZ" = "1" /* Occlusion of Pelvis Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07LC4DZ" = "1" /* Occlusion of Pelvis Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07LC4ZZ" = "1" /* Occlusion of Pelvis Lymphatic, Percutaneous Endoscopic Approach */
"07LD3CZ" = "1" /* Occlusion of Aortic Lymphatic with Extraluminal Device, Percutaneous Approach */
"07LD3DZ" = "1" /* Occlusion of Aortic Lymphatic with Intraluminal Device, Percutaneous Approach */
"07LD3ZZ" = "1" /* Occlusion of Aortic Lymphatic, Percutaneous Approach */
"07LD4CZ" = "1" /* Occlusion of Aortic Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07LD4DZ" = "1" /* Occlusion of Aortic Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07LD4ZZ" = "1" /* Occlusion of Aortic Lymphatic, Percutaneous Endoscopic Approach */
"07NB3ZZ" = "1" /* Release Mesenteric Lymphatic, Percutaneous Approach */
"07NB4ZZ" = "1" /* Release Mesenteric Lymphatic, Percutaneous Endoscopic Approach */
"07NC3ZZ" = "1" /* Release Pelvis Lymphatic, Percutaneous Approach */
"07NC4ZZ" = "1" /* Release Pelvis Lymphatic, Percutaneous Endoscopic Approach */
"07ND3ZZ" = "1" /* Release Aortic Lymphatic, Percutaneous Approach */
"07ND4ZZ" = "1" /* Release Aortic Lymphatic, Percutaneous Endoscopic Approach */
"07NP3ZZ" = "1" /* Release Spleen, Percutaneous Approach */
"07NP4ZZ" = "1" /* Release Spleen, Percutaneous Endoscopic Approach */
"07PP30Z" = "1" /* Removal of Drainage Device from Spleen, Percutaneous Approach */
"07PP33Z" = "1" /* Removal of Infusion Device from Spleen, Percutaneous Approach */
"07PP40Z" = "1" /* Removal of Drainage Device from Spleen, Percutaneous Endoscopic Approach */
"07PP43Z" = "1" /* Removal of Infusion Device from Spleen, Percutaneous Endoscopic Approach */
"07QB3ZZ" = "1" /* Repair Mesenteric Lymphatic, Percutaneous Approach */
"07QB4ZZ" = "1" /* Repair Mesenteric Lymphatic, Percutaneous Endoscopic Approach */
"07QC3ZZ" = "1" /* Repair Pelvis Lymphatic, Percutaneous Approach */
"07QC4ZZ" = "1" /* Repair Pelvis Lymphatic, Percutaneous Endoscopic Approach */
"07QD3ZZ" = "1" /* Repair Aortic Lymphatic, Percutaneous Approach */
"07QD4ZZ" = "1" /* Repair Aortic Lymphatic, Percutaneous Endoscopic Approach */
"07QP3ZZ" = "1" /* Repair Spleen, Percutaneous Approach */
"07QP4ZZ" = "1" /* Repair Spleen, Percutaneous Endoscopic Approach */
"07TB4ZZ" = "1" /* Resection of Mesenteric Lymphatic, Percutaneous Endoscopic Approach */
"07TC4ZZ" = "1" /* Resection of Pelvis Lymphatic, Percutaneous Endoscopic Approach */
"07TD4ZZ" = "1" /* Resection of Aortic Lymphatic, Percutaneous Endoscopic Approach */
"07TP4ZZ" = "1" /* Resection of Spleen, Percutaneous Endoscopic Approach */
"07UB47Z" = "1" /* Supplement Mesenteric Lymphatic with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UB4JZ" = "1" /* Supplement Mesenteric Lymphatic with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07UB4KZ" = "1" /* Supplement Mesenteric Lymphatic with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UC47Z" = "1" /* Supplement Pelvis Lymphatic with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UC4JZ" = "1" /* Supplement Pelvis Lymphatic with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07UC4KZ" = "1" /* Supplement Pelvis Lymphatic with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UD47Z" = "1" /* Supplement Aortic Lymphatic with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UD4JZ" = "1" /* Supplement Aortic Lymphatic with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07UD4KZ" = "1" /* Supplement Aortic Lymphatic with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07VB3CZ" = "1" /* Restriction of Mesenteric Lymphatic with Extraluminal Device, Percutaneous Approach */
"07VB3DZ" = "1" /* Restriction of Mesenteric Lymphatic with Intraluminal Device, Percutaneous Approach */
"07VB3ZZ" = "1" /* Restriction of Mesenteric Lymphatic, Percutaneous Approach */
"07VB4CZ" = "1" /* Restriction of Mesenteric Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07VB4DZ" = "1" /* Restriction of Mesenteric Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07VB4ZZ" = "1" /* Restriction of Mesenteric Lymphatic, Percutaneous Endoscopic Approach */
"07VC3CZ" = "1" /* Restriction of Pelvis Lymphatic with Extraluminal Device, Percutaneous Approach */
"07VC3DZ" = "1" /* Restriction of Pelvis Lymphatic with Intraluminal Device, Percutaneous Approach */
"07VC3ZZ" = "1" /* Restriction of Pelvis Lymphatic, Percutaneous Approach */
"07VC4CZ" = "1" /* Restriction of Pelvis Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07VC4DZ" = "1" /* Restriction of Pelvis Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07VC4ZZ" = "1" /* Restriction of Pelvis Lymphatic, Percutaneous Endoscopic Approach */
"07VD3CZ" = "1" /* Restriction of Aortic Lymphatic with Extraluminal Device, Percutaneous Approach */
"07VD3DZ" = "1" /* Restriction of Aortic Lymphatic with Intraluminal Device, Percutaneous Approach */
"07VD3ZZ" = "1" /* Restriction of Aortic Lymphatic, Percutaneous Approach */
"07VD4CZ" = "1" /* Restriction of Aortic Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07VD4DZ" = "1" /* Restriction of Aortic Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07VD4ZZ" = "1" /* Restriction of Aortic Lymphatic, Percutaneous Endoscopic Approach */
"07WP30Z" = "1" /* Revision of Drainage Device in Spleen, Percutaneous Approach */
"07WP33Z" = "1" /* Revision of Infusion Device in Spleen, Percutaneous Approach */
"07WP40Z" = "1" /* Revision of Drainage Device in Spleen, Percutaneous Endoscopic Approach */
"07WP43Z" = "1" /* Revision of Infusion Device in Spleen, Percutaneous Endoscopic Approach */
"0B5R3ZZ" = "1" /* Destruction of Right Diaphragm, Percutaneous Approach */
"0B5R4ZZ" = "1" /* Destruction of Right Diaphragm, Percutaneous Endoscopic Approach */
"0B5S3ZZ" = "1" /* Destruction of Left Diaphragm, Percutaneous Approach */
"0B5S4ZZ" = "1" /* Destruction of Left Diaphragm, Percutaneous Endoscopic Approach */
"0B9R30Z" = "1" /* Drainage of Right Diaphragm with Drainage Device, Percutaneous Approach */
"0B9R3ZX" = "1" /* Drainage of Right Diaphragm, Percutaneous Approach, Diagnostic */
"0B9R3ZZ" = "1" /* Drainage of Right Diaphragm, Percutaneous Approach */
"0B9R40Z" = "1" /* Drainage of Right Diaphragm with Drainage Device, Percutaneous Endoscopic Approach */
"0B9R4ZX" = "1" /* Drainage of Right Diaphragm, Percutaneous Endoscopic Approach, Diagnostic */
"0B9R4ZZ" = "1" /* Drainage of Right Diaphragm, Percutaneous Endoscopic Approach */
"0B9S30Z" = "1" /* Drainage of Left Diaphragm with Drainage Device, Percutaneous Approach */
"0B9S3ZX" = "1" /* Drainage of Left Diaphragm, Percutaneous Approach, Diagnostic */
"0B9S3ZZ" = "1" /* Drainage of Left Diaphragm, Percutaneous Approach */
"0B9S40Z" = "1" /* Drainage of Left Diaphragm with Drainage Device, Percutaneous Endoscopic Approach */
"0B9S4ZX" = "1" /* Drainage of Left Diaphragm, Percutaneous Endoscopic Approach, Diagnostic */
"0B9S4ZZ" = "1" /* Drainage of Left Diaphragm, Percutaneous Endoscopic Approach */
"0BBR3ZX" = "1" /* Excision of Right Diaphragm, Percutaneous Approach, Diagnostic */
"0BBR3ZZ" = "1" /* Excision of Right Diaphragm, Percutaneous Approach */
"0BBR4ZX" = "1" /* Excision of Right Diaphragm, Percutaneous Endoscopic Approach, Diagnostic */
"0BBR4ZZ" = "1" /* Excision of Right Diaphragm, Percutaneous Endoscopic Approach */
"0BBS3ZX" = "1" /* Excision of Left Diaphragm, Percutaneous Approach, Diagnostic */
"0BBS3ZZ" = "1" /* Excision of Left Diaphragm, Percutaneous Approach */
"0BBS4ZX" = "1" /* Excision of Left Diaphragm, Percutaneous Endoscopic Approach, Diagnostic */
"0BBS4ZZ" = "1" /* Excision of Left Diaphragm, Percutaneous Endoscopic Approach */
"0BCR3ZZ" = "1" /* Extirpation of Matter from Right Diaphragm, Percutaneous Approach */
"0BCR4ZZ" = "1" /* Extirpation of Matter from Right Diaphragm, Percutaneous Endoscopic Approach */
"0BCS3ZZ" = "1" /* Extirpation of Matter from Left Diaphragm, Percutaneous Approach */
"0BCS4ZZ" = "1" /* Extirpation of Matter from Left Diaphragm, Percutaneous Endoscopic Approach */
"0BHR32Z" = "1" /* Insertion of Monitoring Device into Right Diaphragm, Percutaneous Approach */
"0BHR3MZ" = "1" /* Insertion of Diaphragmatic Pacemaker Lead into Right Diaphragm, Percutaneous Approach */
"0BHR42Z" = "1" /* Insertion of Monitoring Device into Right Diaphragm, Percutaneous Endoscopic Approach */
"0BHR4MZ" = "1" /* Insertion of Diaphragmatic Pacemaker Lead into Right Diaphragm, Percutaneous Endoscopic Approach */
"0BHS32Z" = "1" /* Insertion of Monitoring Device into Left Diaphragm, Percutaneous Approach */
"0BHS3MZ" = "1" /* Insertion of Diaphragmatic Pacemaker Lead into Left Diaphragm, Percutaneous Approach */
"0BHS42Z" = "1" /* Insertion of Monitoring Device into Left Diaphragm, Percutaneous Endoscopic Approach */
"0BHS4MZ" = "1" /* Insertion of Diaphragmatic Pacemaker Lead into Left Diaphragm, Percutaneous Endoscopic Approach */
"0BJT3ZZ" = "1" /* Inspection of Diaphragm, Percutaneous Approach */
"0BJT4ZZ" = "1" /* Inspection of Diaphragm, Percutaneous Endoscopic Approach */
"0BNR3ZZ" = "1" /* Release Right Diaphragm, Percutaneous Approach */
"0BNR4ZZ" = "1" /* Release Right Diaphragm, Percutaneous Endoscopic Approach */
"0BNS3ZZ" = "1" /* Release Left Diaphragm, Percutaneous Approach */
"0BNS4ZZ" = "1" /* Release Left Diaphragm, Percutaneous Endoscopic Approach */
"0BPT30Z" = "1" /* Removal of Drainage Device from Diaphragm, Percutaneous Approach */
"0BPT32Z" = "1" /* Removal of Monitoring Device from Diaphragm, Percutaneous Approach */
"0BPT37Z" = "1" /* Removal of Autologous Tissue Substitute from Diaphragm, Percutaneous Approach */
"0BPT3JZ" = "1" /* Removal of Synthetic Substitute from Diaphragm, Percutaneous Approach */
"0BPT3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Diaphragm, Percutaneous Approach */
"0BPT3MZ" = "1" /* Removal of Diaphragmatic Pacemaker Lead from Diaphragm, Percutaneous Approach */
"0BPT40Z" = "1" /* Removal of Drainage Device from Diaphragm, Percutaneous Endoscopic Approach */
"0BPT42Z" = "1" /* Removal of Monitoring Device from Diaphragm, Percutaneous Endoscopic Approach */
"0BPT47Z" = "1" /* Removal of Autologous Tissue Substitute from Diaphragm, Percutaneous Endoscopic Approach */
"0BPT4JZ" = "1" /* Removal of Synthetic Substitute from Diaphragm, Percutaneous Endoscopic Approach */
"0BPT4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Diaphragm, Percutaneous Endoscopic Approach */
"0BPT4MZ" = "1" /* Removal of Diaphragmatic Pacemaker Lead from Diaphragm, Percutaneous Endoscopic Approach */
"0BQR3ZZ" = "1" /* Repair Right Diaphragm, Percutaneous Approach */
"0BQR4ZZ" = "1" /* Repair Right Diaphragm, Percutaneous Endoscopic Approach */
"0BQS3ZZ" = "1" /* Repair Left Diaphragm, Percutaneous Approach */
"0BQS4ZZ" = "1" /* Repair Left Diaphragm, Percutaneous Endoscopic Approach */
"0BTR4ZZ" = "1" /* Resection of Right Diaphragm, Percutaneous Endoscopic Approach */
"0BTS4ZZ" = "1" /* Resection of Left Diaphragm, Percutaneous Endoscopic Approach */
"0BUR47Z" = "1" /* Supplement Right Diaphragm with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BUR4JZ" = "1" /* Supplement Right Diaphragm with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BUR4KZ" = "1" /* Supplement Right Diaphragm with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BUS47Z" = "1" /* Supplement Left Diaphragm with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BUS4JZ" = "1" /* Supplement Left Diaphragm with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BUS4KZ" = "1" /* Supplement Left Diaphragm with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BWT30Z" = "1" /* Revision of Drainage Device in Diaphragm, Percutaneous Approach */
"0BWT32Z" = "1" /* Revision of Monitoring Device in Diaphragm, Percutaneous Approach */
"0BWT37Z" = "1" /* Revision of Autologous Tissue Substitute in Diaphragm, Percutaneous Approach */
"0BWT3JZ" = "1" /* Revision of Synthetic Substitute in Diaphragm, Percutaneous Approach */
"0BWT3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Diaphragm, Percutaneous Approach */
"0BWT3MZ" = "1" /* Revision of Diaphragmatic Pacemaker Lead in Diaphragm, Percutaneous Approach */
"0BWT40Z" = "1" /* Revision of Drainage Device in Diaphragm, Percutaneous Endoscopic Approach */
"0BWT42Z" = "1" /* Revision of Monitoring Device in Diaphragm, Percutaneous Endoscopic Approach */
"0BWT47Z" = "1" /* Revision of Autologous Tissue Substitute in Diaphragm, Percutaneous Endoscopic Approach */
"0BWT4JZ" = "1" /* Revision of Synthetic Substitute in Diaphragm, Percutaneous Endoscopic Approach */
"0BWT4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Diaphragm, Percutaneous Endoscopic Approach */
"0BWT4MZ" = "1" /* Revision of Diaphragmatic Pacemaker Lead in Diaphragm, Percutaneous Endoscopic Approach */
"0D11476" = "1" /* Bypass Upper Esophagus to Stomach with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D11479" = "1" /* Bypass Upper Esophagus to Duodenum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1147A" = "1" /* Bypass Upper Esophagus to Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1147B" = "1" /* Bypass Upper Esophagus to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D114J6" = "1" /* Bypass Upper Esophagus to Stomach with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D114J9" = "1" /* Bypass Upper Esophagus to Duodenum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D114JA" = "1" /* Bypass Upper Esophagus to Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D114JB" = "1" /* Bypass Upper Esophagus to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D114K6" = "1" /* Bypass Upper Esophagus to Stomach with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D114K9" = "1" /* Bypass Upper Esophagus to Duodenum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D114KA" = "1" /* Bypass Upper Esophagus to Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D114KB" = "1" /* Bypass Upper Esophagus to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D114Z6" = "1" /* Bypass Upper Esophagus to Stomach, Percutaneous Endoscopic Approach */
"0D114Z9" = "1" /* Bypass Upper Esophagus to Duodenum, Percutaneous Endoscopic Approach */
"0D114ZA" = "1" /* Bypass Upper Esophagus to Jejunum, Percutaneous Endoscopic Approach */
"0D114ZB" = "1" /* Bypass Upper Esophagus to Ileum, Percutaneous Endoscopic Approach */
"0D12476" = "1" /* Bypass Middle Esophagus to Stomach with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D12479" = "1" /* Bypass Middle Esophagus to Duodenum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1247A" = "1" /* Bypass Middle Esophagus to Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1247B" = "1" /* Bypass Middle Esophagus to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D124J6" = "1" /* Bypass Middle Esophagus to Stomach with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D124J9" = "1" /* Bypass Middle Esophagus to Duodenum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D124JA" = "1" /* Bypass Middle Esophagus to Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D124JB" = "1" /* Bypass Middle Esophagus to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D124K6" = "1" /* Bypass Middle Esophagus to Stomach with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D124K9" = "1" /* Bypass Middle Esophagus to Duodenum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D124KA" = "1" /* Bypass Middle Esophagus to Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D124KB" = "1" /* Bypass Middle Esophagus to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D124Z6" = "1" /* Bypass Middle Esophagus to Stomach, Percutaneous Endoscopic Approach */
"0D124Z9" = "1" /* Bypass Middle Esophagus to Duodenum, Percutaneous Endoscopic Approach */
"0D124ZA" = "1" /* Bypass Middle Esophagus to Jejunum, Percutaneous Endoscopic Approach */
"0D124ZB" = "1" /* Bypass Middle Esophagus to Ileum, Percutaneous Endoscopic Approach */
"0D133J4" = "1" /* Bypass Lower Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D13474" = "1" /* Bypass Lower Esophagus to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D13476" = "1" /* Bypass Lower Esophagus to Stomach with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D13479" = "1" /* Bypass Lower Esophagus to Duodenum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1347A" = "1" /* Bypass Lower Esophagus to Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1347B" = "1" /* Bypass Lower Esophagus to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134J4" = "1" /* Bypass Lower Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D134J6" = "1" /* Bypass Lower Esophagus to Stomach with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D134J9" = "1" /* Bypass Lower Esophagus to Duodenum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D134JA" = "1" /* Bypass Lower Esophagus to Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D134JB" = "1" /* Bypass Lower Esophagus to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D134K4" = "1" /* Bypass Lower Esophagus to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134K6" = "1" /* Bypass Lower Esophagus to Stomach with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134K9" = "1" /* Bypass Lower Esophagus to Duodenum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134KA" = "1" /* Bypass Lower Esophagus to Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134KB" = "1" /* Bypass Lower Esophagus to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134Z4" = "1" /* Bypass Lower Esophagus to Cutaneous, Percutaneous Endoscopic Approach */
"0D134Z6" = "1" /* Bypass Lower Esophagus to Stomach, Percutaneous Endoscopic Approach */
"0D134Z9" = "1" /* Bypass Lower Esophagus to Duodenum, Percutaneous Endoscopic Approach */
"0D134ZA" = "1" /* Bypass Lower Esophagus to Jejunum, Percutaneous Endoscopic Approach */
"0D134ZB" = "1" /* Bypass Lower Esophagus to Ileum, Percutaneous Endoscopic Approach */
"0D15476" = "1" /* Bypass Esophagus to Stomach with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D15479" = "1" /* Bypass Esophagus to Duodenum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1547A" = "1" /* Bypass Esophagus to Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1547B" = "1" /* Bypass Esophagus to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D154J6" = "1" /* Bypass Esophagus to Stomach with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D154J9" = "1" /* Bypass Esophagus to Duodenum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D154JA" = "1" /* Bypass Esophagus to Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D154JB" = "1" /* Bypass Esophagus to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D154K6" = "1" /* Bypass Esophagus to Stomach with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D154K9" = "1" /* Bypass Esophagus to Duodenum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D154KA" = "1" /* Bypass Esophagus to Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D154KB" = "1" /* Bypass Esophagus to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D154Z6" = "1" /* Bypass Esophagus to Stomach, Percutaneous Endoscopic Approach */
"0D154Z9" = "1" /* Bypass Esophagus to Duodenum, Percutaneous Endoscopic Approach */
"0D154ZA" = "1" /* Bypass Esophagus to Jejunum, Percutaneous Endoscopic Approach */
"0D154ZB" = "1" /* Bypass Esophagus to Ileum, Percutaneous Endoscopic Approach */
"0D163J4" = "1" /* Bypass Stomach to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D16474" = "1" /* Bypass Stomach to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D16479" = "1" /* Bypass Stomach to Duodenum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1647A" = "1" /* Bypass Stomach to Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1647B" = "1" /* Bypass Stomach to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1647L" = "1" /* Bypass Stomach to Transverse Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D164J4" = "1" /* Bypass Stomach to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D164J9" = "1" /* Bypass Stomach to Duodenum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D164JA" = "1" /* Bypass Stomach to Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D164JB" = "1" /* Bypass Stomach to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D164JL" = "1" /* Bypass Stomach to Transverse Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D164K4" = "1" /* Bypass Stomach to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D164K9" = "1" /* Bypass Stomach to Duodenum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D164KA" = "1" /* Bypass Stomach to Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D164KB" = "1" /* Bypass Stomach to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D164KL" = "1" /* Bypass Stomach to Transverse Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D164Z4" = "1" /* Bypass Stomach to Cutaneous, Percutaneous Endoscopic Approach */
"0D164Z9" = "1" /* Bypass Stomach to Duodenum, Percutaneous Endoscopic Approach */
"0D164ZA" = "1" /* Bypass Stomach to Jejunum, Percutaneous Endoscopic Approach */
"0D164ZB" = "1" /* Bypass Stomach to Ileum, Percutaneous Endoscopic Approach */
"0D164ZL" = "1" /* Bypass Stomach to Transverse Colon, Percutaneous Endoscopic Approach */
"0D193J4" = "1" /* Bypass Duodenum to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D19474" = "1" /* Bypass Duodenum to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D19479" = "1" /* Bypass Duodenum to Duodenum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1947A" = "1" /* Bypass Duodenum to Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1947B" = "1" /* Bypass Duodenum to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1947L" = "1" /* Bypass Duodenum to Transverse Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D194J4" = "1" /* Bypass Duodenum to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D194J9" = "1" /* Bypass Duodenum to Duodenum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D194JA" = "1" /* Bypass Duodenum to Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D194JB" = "1" /* Bypass Duodenum to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D194JL" = "1" /* Bypass Duodenum to Transverse Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D194K4" = "1" /* Bypass Duodenum to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D194K9" = "1" /* Bypass Duodenum to Duodenum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D194KA" = "1" /* Bypass Duodenum to Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D194KB" = "1" /* Bypass Duodenum to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D194KL" = "1" /* Bypass Duodenum to Transverse Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D194Z4" = "1" /* Bypass Duodenum to Cutaneous, Percutaneous Endoscopic Approach */
"0D194Z9" = "1" /* Bypass Duodenum to Duodenum, Percutaneous Endoscopic Approach */
"0D194ZA" = "1" /* Bypass Duodenum to Jejunum, Percutaneous Endoscopic Approach */
"0D194ZB" = "1" /* Bypass Duodenum to Ileum, Percutaneous Endoscopic Approach */
"0D194ZL" = "1" /* Bypass Duodenum to Transverse Colon, Percutaneous Endoscopic Approach */
"0D1A3J4" = "1" /* Bypass Jejunum to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D1A474" = "1" /* Bypass Jejunum to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A47A" = "1" /* Bypass Jejunum to Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A47B" = "1" /* Bypass Jejunum to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A47H" = "1" /* Bypass Jejunum to Cecum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A47K" = "1" /* Bypass Jejunum to Ascending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A47L" = "1" /* Bypass Jejunum to Transverse Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A47M" = "1" /* Bypass Jejunum to Descending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A47N" = "1" /* Bypass Jejunum to Sigmoid Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A47P" = "1" /* Bypass Jejunum to Rectum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A47Q" = "1" /* Bypass Jejunum to Anus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A4J4" = "1" /* Bypass Jejunum to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1A4JA" = "1" /* Bypass Jejunum to Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1A4JB" = "1" /* Bypass Jejunum to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1A4JH" = "1" /* Bypass Jejunum to Cecum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1A4JK" = "1" /* Bypass Jejunum to Ascending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1A4JL" = "1" /* Bypass Jejunum to Transverse Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1A4JM" = "1" /* Bypass Jejunum to Descending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1A4JN" = "1" /* Bypass Jejunum to Sigmoid Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1A4JP" = "1" /* Bypass Jejunum to Rectum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1A4JQ" = "1" /* Bypass Jejunum to Anus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1A4K4" = "1" /* Bypass Jejunum to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A4KA" = "1" /* Bypass Jejunum to Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A4KB" = "1" /* Bypass Jejunum to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A4KH" = "1" /* Bypass Jejunum to Cecum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A4KK" = "1" /* Bypass Jejunum to Ascending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A4KL" = "1" /* Bypass Jejunum to Transverse Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A4KM" = "1" /* Bypass Jejunum to Descending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A4KN" = "1" /* Bypass Jejunum to Sigmoid Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A4KP" = "1" /* Bypass Jejunum to Rectum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A4KQ" = "1" /* Bypass Jejunum to Anus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A4Z4" = "1" /* Bypass Jejunum to Cutaneous, Percutaneous Endoscopic Approach */
"0D1A4ZA" = "1" /* Bypass Jejunum to Jejunum, Percutaneous Endoscopic Approach */
"0D1A4ZB" = "1" /* Bypass Jejunum to Ileum, Percutaneous Endoscopic Approach */
"0D1A4ZH" = "1" /* Bypass Jejunum to Cecum, Percutaneous Endoscopic Approach */
"0D1A4ZK" = "1" /* Bypass Jejunum to Ascending Colon, Percutaneous Endoscopic Approach */
"0D1A4ZL" = "1" /* Bypass Jejunum to Transverse Colon, Percutaneous Endoscopic Approach */
"0D1A4ZM" = "1" /* Bypass Jejunum to Descending Colon, Percutaneous Endoscopic Approach */
"0D1A4ZN" = "1" /* Bypass Jejunum to Sigmoid Colon, Percutaneous Endoscopic Approach */
"0D1A4ZP" = "1" /* Bypass Jejunum to Rectum, Percutaneous Endoscopic Approach */
"0D1A4ZQ" = "1" /* Bypass Jejunum to Anus, Percutaneous Endoscopic Approach */
"0D1B3J4" = "1" /* Bypass Ileum to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D1B474" = "1" /* Bypass Ileum to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B47B" = "1" /* Bypass Ileum to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B47H" = "1" /* Bypass Ileum to Cecum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B47K" = "1" /* Bypass Ileum to Ascending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B47L" = "1" /* Bypass Ileum to Transverse Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B47M" = "1" /* Bypass Ileum to Descending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B47N" = "1" /* Bypass Ileum to Sigmoid Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B47P" = "1" /* Bypass Ileum to Rectum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B47Q" = "1" /* Bypass Ileum to Anus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B4J4" = "1" /* Bypass Ileum to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1B4JB" = "1" /* Bypass Ileum to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1B4JH" = "1" /* Bypass Ileum to Cecum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1B4JK" = "1" /* Bypass Ileum to Ascending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1B4JL" = "1" /* Bypass Ileum to Transverse Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1B4JM" = "1" /* Bypass Ileum to Descending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1B4JN" = "1" /* Bypass Ileum to Sigmoid Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1B4JP" = "1" /* Bypass Ileum to Rectum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1B4JQ" = "1" /* Bypass Ileum to Anus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1B4K4" = "1" /* Bypass Ileum to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B4KB" = "1" /* Bypass Ileum to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B4KH" = "1" /* Bypass Ileum to Cecum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B4KK" = "1" /* Bypass Ileum to Ascending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B4KL" = "1" /* Bypass Ileum to Transverse Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B4KM" = "1" /* Bypass Ileum to Descending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B4KN" = "1" /* Bypass Ileum to Sigmoid Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B4KP" = "1" /* Bypass Ileum to Rectum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B4KQ" = "1" /* Bypass Ileum to Anus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B4Z4" = "1" /* Bypass Ileum to Cutaneous, Percutaneous Endoscopic Approach */
"0D1B4ZB" = "1" /* Bypass Ileum to Ileum, Percutaneous Endoscopic Approach */
"0D1B4ZH" = "1" /* Bypass Ileum to Cecum, Percutaneous Endoscopic Approach */
"0D1B4ZK" = "1" /* Bypass Ileum to Ascending Colon, Percutaneous Endoscopic Approach */
"0D1B4ZL" = "1" /* Bypass Ileum to Transverse Colon, Percutaneous Endoscopic Approach */
"0D1B4ZM" = "1" /* Bypass Ileum to Descending Colon, Percutaneous Endoscopic Approach */
"0D1B4ZN" = "1" /* Bypass Ileum to Sigmoid Colon, Percutaneous Endoscopic Approach */
"0D1B4ZP" = "1" /* Bypass Ileum to Rectum, Percutaneous Endoscopic Approach */
"0D1B4ZQ" = "1" /* Bypass Ileum to Anus, Percutaneous Endoscopic Approach */
"0D1H3J4" = "1" /* Bypass Cecum to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D1H474" = "1" /* Bypass Cecum to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H47H" = "1" /* Bypass Cecum to Cecum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H47K" = "1" /* Bypass Cecum to Ascending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H47L" = "1" /* Bypass Cecum to Transverse Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H47M" = "1" /* Bypass Cecum to Descending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H47N" = "1" /* Bypass Cecum to Sigmoid Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H47P" = "1" /* Bypass Cecum to Rectum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H4J4" = "1" /* Bypass Cecum to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1H4JH" = "1" /* Bypass Cecum to Cecum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1H4JK" = "1" /* Bypass Cecum to Ascending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1H4JL" = "1" /* Bypass Cecum to Transverse Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1H4JM" = "1" /* Bypass Cecum to Descending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1H4JN" = "1" /* Bypass Cecum to Sigmoid Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1H4JP" = "1" /* Bypass Cecum to Rectum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1H4K4" = "1" /* Bypass Cecum to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H4KH" = "1" /* Bypass Cecum to Cecum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H4KK" = "1" /* Bypass Cecum to Ascending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H4KL" = "1" /* Bypass Cecum to Transverse Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H4KM" = "1" /* Bypass Cecum to Descending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H4KN" = "1" /* Bypass Cecum to Sigmoid Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H4KP" = "1" /* Bypass Cecum to Rectum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H4Z4" = "1" /* Bypass Cecum to Cutaneous, Percutaneous Endoscopic Approach */
"0D1H4ZH" = "1" /* Bypass Cecum to Cecum, Percutaneous Endoscopic Approach */
"0D1H4ZK" = "1" /* Bypass Cecum to Ascending Colon, Percutaneous Endoscopic Approach */
"0D1H4ZL" = "1" /* Bypass Cecum to Transverse Colon, Percutaneous Endoscopic Approach */
"0D1H4ZM" = "1" /* Bypass Cecum to Descending Colon, Percutaneous Endoscopic Approach */
"0D1H4ZN" = "1" /* Bypass Cecum to Sigmoid Colon, Percutaneous Endoscopic Approach */
"0D1H4ZP" = "1" /* Bypass Cecum to Rectum, Percutaneous Endoscopic Approach */
"0D1K3J4" = "1" /* Bypass Ascending Colon to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D1K474" = "1" /* Bypass Ascending Colon to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K47K" = "1" /* Bypass Ascending Colon to Ascending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K47L" = "1" /* Bypass Ascending Colon to Transverse Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K47M" = "1" /* Bypass Ascending Colon to Descending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K47N" = "1" /* Bypass Ascending Colon to Sigmoid Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K47P" = "1" /* Bypass Ascending Colon to Rectum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K4J4" = "1" /* Bypass Ascending Colon to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1K4JK" = "1" /* Bypass Ascending Colon to Ascending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1K4JL" = "1" /* Bypass Ascending Colon to Transverse Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1K4JM" = "1" /* Bypass Ascending Colon to Descending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1K4JN" = "1" /* Bypass Ascending Colon to Sigmoid Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1K4JP" = "1" /* Bypass Ascending Colon to Rectum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1K4K4" = "1" /* Bypass Ascending Colon to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K4KK" = "1" /* Bypass Ascending Colon to Ascending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K4KL" = "1" /* Bypass Ascending Colon to Transverse Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K4KM" = "1" /* Bypass Ascending Colon to Descending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K4KN" = "1" /* Bypass Ascending Colon to Sigmoid Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K4KP" = "1" /* Bypass Ascending Colon to Rectum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K4Z4" = "1" /* Bypass Ascending Colon to Cutaneous, Percutaneous Endoscopic Approach */
"0D1K4ZK" = "1" /* Bypass Ascending Colon to Ascending Colon, Percutaneous Endoscopic Approach */
"0D1K4ZL" = "1" /* Bypass Ascending Colon to Transverse Colon, Percutaneous Endoscopic Approach */
"0D1K4ZM" = "1" /* Bypass Ascending Colon to Descending Colon, Percutaneous Endoscopic Approach */
"0D1K4ZN" = "1" /* Bypass Ascending Colon to Sigmoid Colon, Percutaneous Endoscopic Approach */
"0D1K4ZP" = "1" /* Bypass Ascending Colon to Rectum, Percutaneous Endoscopic Approach */
"0D1L3J4" = "1" /* Bypass Transverse Colon to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D1L474" = "1" /* Bypass Transverse Colon to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1L47L" = "1" /* Bypass Transverse Colon to Transverse Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1L47M" = "1" /* Bypass Transverse Colon to Descending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1L47N" = "1" /* Bypass Transverse Colon to Sigmoid Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1L47P" = "1" /* Bypass Transverse Colon to Rectum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1L4J4" = "1" /* Bypass Transverse Colon to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1L4JL" = "1" /* Bypass Transverse Colon to Transverse Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1L4JM" = "1" /* Bypass Transverse Colon to Descending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1L4JN" = "1" /* Bypass Transverse Colon to Sigmoid Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1L4JP" = "1" /* Bypass Transverse Colon to Rectum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1L4K4" = "1" /* Bypass Transverse Colon to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1L4KL" = "1" /* Bypass Transverse Colon to Transverse Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1L4KM" = "1" /* Bypass Transverse Colon to Descending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1L4KN" = "1" /* Bypass Transverse Colon to Sigmoid Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1L4KP" = "1" /* Bypass Transverse Colon to Rectum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1L4Z4" = "1" /* Bypass Transverse Colon to Cutaneous, Percutaneous Endoscopic Approach */
"0D1L4ZL" = "1" /* Bypass Transverse Colon to Transverse Colon, Percutaneous Endoscopic Approach */
"0D1L4ZM" = "1" /* Bypass Transverse Colon to Descending Colon, Percutaneous Endoscopic Approach */
"0D1L4ZN" = "1" /* Bypass Transverse Colon to Sigmoid Colon, Percutaneous Endoscopic Approach */
"0D1L4ZP" = "1" /* Bypass Transverse Colon to Rectum, Percutaneous Endoscopic Approach */
"0D1M3J4" = "1" /* Bypass Descending Colon to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D1M474" = "1" /* Bypass Descending Colon to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1M47M" = "1" /* Bypass Descending Colon to Descending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1M47N" = "1" /* Bypass Descending Colon to Sigmoid Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1M47P" = "1" /* Bypass Descending Colon to Rectum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1M4J4" = "1" /* Bypass Descending Colon to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1M4JM" = "1" /* Bypass Descending Colon to Descending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1M4JN" = "1" /* Bypass Descending Colon to Sigmoid Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1M4JP" = "1" /* Bypass Descending Colon to Rectum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1M4K4" = "1" /* Bypass Descending Colon to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1M4KM" = "1" /* Bypass Descending Colon to Descending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1M4KN" = "1" /* Bypass Descending Colon to Sigmoid Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1M4KP" = "1" /* Bypass Descending Colon to Rectum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1M4Z4" = "1" /* Bypass Descending Colon to Cutaneous, Percutaneous Endoscopic Approach */
"0D1M4ZM" = "1" /* Bypass Descending Colon to Descending Colon, Percutaneous Endoscopic Approach */
"0D1M4ZN" = "1" /* Bypass Descending Colon to Sigmoid Colon, Percutaneous Endoscopic Approach */
"0D1M4ZP" = "1" /* Bypass Descending Colon to Rectum, Percutaneous Endoscopic Approach */
"0D1N3J4" = "1" /* Bypass Sigmoid Colon to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D1N474" = "1" /* Bypass Sigmoid Colon to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1N47N" = "1" /* Bypass Sigmoid Colon to Sigmoid Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1N47P" = "1" /* Bypass Sigmoid Colon to Rectum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1N4J4" = "1" /* Bypass Sigmoid Colon to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1N4JN" = "1" /* Bypass Sigmoid Colon to Sigmoid Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1N4JP" = "1" /* Bypass Sigmoid Colon to Rectum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1N4K4" = "1" /* Bypass Sigmoid Colon to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1N4KN" = "1" /* Bypass Sigmoid Colon to Sigmoid Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1N4KP" = "1" /* Bypass Sigmoid Colon to Rectum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1N4Z4" = "1" /* Bypass Sigmoid Colon to Cutaneous, Percutaneous Endoscopic Approach */
"0D1N4ZN" = "1" /* Bypass Sigmoid Colon to Sigmoid Colon, Percutaneous Endoscopic Approach */
"0D1N4ZP" = "1" /* Bypass Sigmoid Colon to Rectum, Percutaneous Endoscopic Approach */
"0D533ZZ" = "1" /* Destruction of Lower Esophagus, Percutaneous Approach */
"0D534ZZ" = "1" /* Destruction of Lower Esophagus, Percutaneous Endoscopic Approach */
"0D543ZZ" = "1" /* Destruction of Esophagogastric Junction, Percutaneous Approach */
"0D544ZZ" = "1" /* Destruction of Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0D563ZZ" = "1" /* Destruction of Stomach, Percutaneous Approach */
"0D564ZZ" = "1" /* Destruction of Stomach, Percutaneous Endoscopic Approach */
"0D573ZZ" = "1" /* Destruction of Stomach, Pylorus, Percutaneous Approach */
"0D574ZZ" = "1" /* Destruction of Stomach, Pylorus, Percutaneous Endoscopic Approach */
"0D583ZZ" = "1" /* Destruction of Small Intestine, Percutaneous Approach */
"0D584ZZ" = "1" /* Destruction of Small Intestine, Percutaneous Endoscopic Approach */
"0D593ZZ" = "1" /* Destruction of Duodenum, Percutaneous Approach */
"0D594ZZ" = "1" /* Destruction of Duodenum, Percutaneous Endoscopic Approach */
"0D5A3ZZ" = "1" /* Destruction of Jejunum, Percutaneous Approach */
"0D5A4ZZ" = "1" /* Destruction of Jejunum, Percutaneous Endoscopic Approach */
"0D5B3ZZ" = "1" /* Destruction of Ileum, Percutaneous Approach */
"0D5B4ZZ" = "1" /* Destruction of Ileum, Percutaneous Endoscopic Approach */
"0D5C3ZZ" = "1" /* Destruction of Ileocecal Valve, Percutaneous Approach */
"0D5C4ZZ" = "1" /* Destruction of Ileocecal Valve, Percutaneous Endoscopic Approach */
"0D5E3ZZ" = "1" /* Destruction of Large Intestine, Percutaneous Approach */
"0D5E4ZZ" = "1" /* Destruction of Large Intestine, Percutaneous Endoscopic Approach */
"0D5F3ZZ" = "1" /* Destruction of Right Large Intestine, Percutaneous Approach */
"0D5F4ZZ" = "1" /* Destruction of Right Large Intestine, Percutaneous Endoscopic Approach */
"0D5G3ZZ" = "1" /* Destruction of Left Large Intestine, Percutaneous Approach */
"0D5G4ZZ" = "1" /* Destruction of Left Large Intestine, Percutaneous Endoscopic Approach */
"0D5H3ZZ" = "1" /* Destruction of Cecum, Percutaneous Approach */
"0D5H4ZZ" = "1" /* Destruction of Cecum, Percutaneous Endoscopic Approach */
"0D5J3ZZ" = "1" /* Destruction of Appendix, Percutaneous Approach */
"0D5J4ZZ" = "1" /* Destruction of Appendix, Percutaneous Endoscopic Approach */
"0D5K3ZZ" = "1" /* Destruction of Ascending Colon, Percutaneous Approach */
"0D5K4ZZ" = "1" /* Destruction of Ascending Colon, Percutaneous Endoscopic Approach */
"0D5L3ZZ" = "1" /* Destruction of Transverse Colon, Percutaneous Approach */
"0D5L4ZZ" = "1" /* Destruction of Transverse Colon, Percutaneous Endoscopic Approach */
"0D5M3ZZ" = "1" /* Destruction of Descending Colon, Percutaneous Approach */
"0D5M4ZZ" = "1" /* Destruction of Descending Colon, Percutaneous Endoscopic Approach */
"0D5N3ZZ" = "1" /* Destruction of Sigmoid Colon, Percutaneous Approach */
"0D5N4ZZ" = "1" /* Destruction of Sigmoid Colon, Percutaneous Endoscopic Approach */
"0D5P3ZZ" = "1" /* Destruction of Rectum, Percutaneous Approach */
"0D5P4ZZ" = "1" /* Destruction of Rectum, Percutaneous Endoscopic Approach */
"0D5S3ZZ" = "1" /* Destruction of Greater Omentum, Percutaneous Approach */
"0D5S4ZZ" = "1" /* Destruction of Greater Omentum, Percutaneous Endoscopic Approach */
"0D5T3ZZ" = "1" /* Destruction of Lesser Omentum, Percutaneous Approach */
"0D5T4ZZ" = "1" /* Destruction of Lesser Omentum, Percutaneous Endoscopic Approach */
"0D5V3ZZ" = "1" /* Destruction of Mesentery, Percutaneous Approach */
"0D5V4ZZ" = "1" /* Destruction of Mesentery, Percutaneous Endoscopic Approach */
"0D5W3ZZ" = "1" /* Destruction of Peritoneum, Percutaneous Approach */
"0D5W4ZZ" = "1" /* Destruction of Peritoneum, Percutaneous Endoscopic Approach */
"0D743DZ" = "1" /* Dilation of Esophagogastric Junction with Intraluminal Device, Percutaneous Approach */
"0D743ZZ" = "1" /* Dilation of Esophagogastric Junction, Percutaneous Approach */
"0D744DZ" = "1" /* Dilation of Esophagogastric Junction with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D744ZZ" = "1" /* Dilation of Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0D763DZ" = "1" /* Dilation of Stomach with Intraluminal Device, Percutaneous Approach */
"0D763ZZ" = "1" /* Dilation of Stomach, Percutaneous Approach */
"0D764DZ" = "1" /* Dilation of Stomach with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D764ZZ" = "1" /* Dilation of Stomach, Percutaneous Endoscopic Approach */
"0D773DZ" = "1" /* Dilation of Stomach, Pylorus with Intraluminal Device, Percutaneous Approach */
"0D773ZZ" = "1" /* Dilation of Stomach, Pylorus, Percutaneous Approach */
"0D774DZ" = "1" /* Dilation of Stomach, Pylorus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D774ZZ" = "1" /* Dilation of Stomach, Pylorus, Percutaneous Endoscopic Approach */
"0D783DZ" = "1" /* Dilation of Small Intestine with Intraluminal Device, Percutaneous Approach */
"0D783ZZ" = "1" /* Dilation of Small Intestine, Percutaneous Approach */
"0D784DZ" = "1" /* Dilation of Small Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D784ZZ" = "1" /* Dilation of Small Intestine, Percutaneous Endoscopic Approach */
"0D793DZ" = "1" /* Dilation of Duodenum with Intraluminal Device, Percutaneous Approach */
"0D793ZZ" = "1" /* Dilation of Duodenum, Percutaneous Approach */
"0D794DZ" = "1" /* Dilation of Duodenum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D794ZZ" = "1" /* Dilation of Duodenum, Percutaneous Endoscopic Approach */
"0D7A3DZ" = "1" /* Dilation of Jejunum with Intraluminal Device, Percutaneous Approach */
"0D7A3ZZ" = "1" /* Dilation of Jejunum, Percutaneous Approach */
"0D7A4DZ" = "1" /* Dilation of Jejunum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D7A4ZZ" = "1" /* Dilation of Jejunum, Percutaneous Endoscopic Approach */
"0D7B3DZ" = "1" /* Dilation of Ileum with Intraluminal Device, Percutaneous Approach */
"0D7B3ZZ" = "1" /* Dilation of Ileum, Percutaneous Approach */
"0D7B4DZ" = "1" /* Dilation of Ileum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D7B4ZZ" = "1" /* Dilation of Ileum, Percutaneous Endoscopic Approach */
"0D7C3DZ" = "1" /* Dilation of Ileocecal Valve with Intraluminal Device, Percutaneous Approach */
"0D7C3ZZ" = "1" /* Dilation of Ileocecal Valve, Percutaneous Approach */
"0D7C4DZ" = "1" /* Dilation of Ileocecal Valve with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D7C4ZZ" = "1" /* Dilation of Ileocecal Valve, Percutaneous Endoscopic Approach */
"0D7E3DZ" = "1" /* Dilation of Large Intestine with Intraluminal Device, Percutaneous Approach */
"0D7E3ZZ" = "1" /* Dilation of Large Intestine, Percutaneous Approach */
"0D7E4DZ" = "1" /* Dilation of Large Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D7E4ZZ" = "1" /* Dilation of Large Intestine, Percutaneous Endoscopic Approach */
"0D7F3DZ" = "1" /* Dilation of Right Large Intestine with Intraluminal Device, Percutaneous Approach */
"0D7F3ZZ" = "1" /* Dilation of Right Large Intestine, Percutaneous Approach */
"0D7F4DZ" = "1" /* Dilation of Right Large Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D7F4ZZ" = "1" /* Dilation of Right Large Intestine, Percutaneous Endoscopic Approach */
"0D7G3DZ" = "1" /* Dilation of Left Large Intestine with Intraluminal Device, Percutaneous Approach */
"0D7G3ZZ" = "1" /* Dilation of Left Large Intestine, Percutaneous Approach */
"0D7G4DZ" = "1" /* Dilation of Left Large Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D7G4ZZ" = "1" /* Dilation of Left Large Intestine, Percutaneous Endoscopic Approach */
"0D7H3DZ" = "1" /* Dilation of Cecum with Intraluminal Device, Percutaneous Approach */
"0D7H3ZZ" = "1" /* Dilation of Cecum, Percutaneous Approach */
"0D7H4DZ" = "1" /* Dilation of Cecum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D7H4ZZ" = "1" /* Dilation of Cecum, Percutaneous Endoscopic Approach */
"0D7K3DZ" = "1" /* Dilation of Ascending Colon with Intraluminal Device, Percutaneous Approach */
"0D7K3ZZ" = "1" /* Dilation of Ascending Colon, Percutaneous Approach */
"0D7K4DZ" = "1" /* Dilation of Ascending Colon with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D7K4ZZ" = "1" /* Dilation of Ascending Colon, Percutaneous Endoscopic Approach */
"0D7L3DZ" = "1" /* Dilation of Transverse Colon with Intraluminal Device, Percutaneous Approach */
"0D7L3ZZ" = "1" /* Dilation of Transverse Colon, Percutaneous Approach */
"0D7L4DZ" = "1" /* Dilation of Transverse Colon with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D7L4ZZ" = "1" /* Dilation of Transverse Colon, Percutaneous Endoscopic Approach */
"0D7M3DZ" = "1" /* Dilation of Descending Colon with Intraluminal Device, Percutaneous Approach */
"0D7M3ZZ" = "1" /* Dilation of Descending Colon, Percutaneous Approach */
"0D7M4DZ" = "1" /* Dilation of Descending Colon with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D7M4ZZ" = "1" /* Dilation of Descending Colon, Percutaneous Endoscopic Approach */
"0D7N3DZ" = "1" /* Dilation of Sigmoid Colon with Intraluminal Device, Percutaneous Approach */
"0D7N3ZZ" = "1" /* Dilation of Sigmoid Colon, Percutaneous Approach */
"0D7N4DZ" = "1" /* Dilation of Sigmoid Colon with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D7N4ZZ" = "1" /* Dilation of Sigmoid Colon, Percutaneous Endoscopic Approach */
"0D7P3DZ" = "1" /* Dilation of Rectum with Intraluminal Device, Percutaneous Approach */
"0D7P3ZZ" = "1" /* Dilation of Rectum, Percutaneous Approach */
"0D7P4DZ" = "1" /* Dilation of Rectum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D7P4ZZ" = "1" /* Dilation of Rectum, Percutaneous Endoscopic Approach */
"0D843ZZ" = "1" /* Division of Esophagogastric Junction, Percutaneous Approach */
"0D844ZZ" = "1" /* Division of Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0D873ZZ" = "1" /* Division of Stomach, Pylorus, Percutaneous Approach */
"0D874ZZ" = "1" /* Division of Stomach, Pylorus, Percutaneous Endoscopic Approach */
"0D9430Z" = "1" /* Drainage of Esophagogastric Junction with Drainage Device, Percutaneous Approach */
"0D943ZX" = "1" /* Drainage of Esophagogastric Junction, Percutaneous Approach, Diagnostic */
"0D943ZZ" = "1" /* Drainage of Esophagogastric Junction, Percutaneous Approach */
"0D9440Z" = "1" /* Drainage of Esophagogastric Junction with Drainage Device, Percutaneous Endoscopic Approach */
"0D944ZX" = "1" /* Drainage of Esophagogastric Junction, Percutaneous Endoscopic Approach, Diagnostic */
"0D944ZZ" = "1" /* Drainage of Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0D9630Z" = "1" /* Drainage of Stomach with Drainage Device, Percutaneous Approach */
"0D963ZX" = "1" /* Drainage of Stomach, Percutaneous Approach, Diagnostic */
"0D963ZZ" = "1" /* Drainage of Stomach, Percutaneous Approach */
"0D9640Z" = "1" /* Drainage of Stomach with Drainage Device, Percutaneous Endoscopic Approach */
"0D964ZX" = "1" /* Drainage of Stomach, Percutaneous Endoscopic Approach, Diagnostic */
"0D964ZZ" = "1" /* Drainage of Stomach, Percutaneous Endoscopic Approach */
"0D9730Z" = "1" /* Drainage of Stomach, Pylorus with Drainage Device, Percutaneous Approach */
"0D973ZX" = "1" /* Drainage of Stomach, Pylorus, Percutaneous Approach, Diagnostic */
"0D973ZZ" = "1" /* Drainage of Stomach, Pylorus, Percutaneous Approach */
"0D9740Z" = "1" /* Drainage of Stomach, Pylorus with Drainage Device, Percutaneous Endoscopic Approach */
"0D974ZX" = "1" /* Drainage of Stomach, Pylorus, Percutaneous Endoscopic Approach, Diagnostic */
"0D974ZZ" = "1" /* Drainage of Stomach, Pylorus, Percutaneous Endoscopic Approach */
"0D9830Z" = "1" /* Drainage of Small Intestine with Drainage Device, Percutaneous Approach */
"0D983ZX" = "1" /* Drainage of Small Intestine, Percutaneous Approach, Diagnostic */
"0D983ZZ" = "1" /* Drainage of Small Intestine, Percutaneous Approach */
"0D9840Z" = "1" /* Drainage of Small Intestine with Drainage Device, Percutaneous Endoscopic Approach */
"0D984ZX" = "1" /* Drainage of Small Intestine, Percutaneous Endoscopic Approach, Diagnostic */
"0D984ZZ" = "1" /* Drainage of Small Intestine, Percutaneous Endoscopic Approach */
"0D9930Z" = "1" /* Drainage of Duodenum with Drainage Device, Percutaneous Approach */
"0D993ZX" = "1" /* Drainage of Duodenum, Percutaneous Approach, Diagnostic */
"0D993ZZ" = "1" /* Drainage of Duodenum, Percutaneous Approach */
"0D9940Z" = "1" /* Drainage of Duodenum with Drainage Device, Percutaneous Endoscopic Approach */
"0D994ZX" = "1" /* Drainage of Duodenum, Percutaneous Endoscopic Approach, Diagnostic */
"0D994ZZ" = "1" /* Drainage of Duodenum, Percutaneous Endoscopic Approach */
"0D9A30Z" = "1" /* Drainage of Jejunum with Drainage Device, Percutaneous Approach */
"0D9A3ZX" = "1" /* Drainage of Jejunum, Percutaneous Approach, Diagnostic */
"0D9A3ZZ" = "1" /* Drainage of Jejunum, Percutaneous Approach */
"0D9A40Z" = "1" /* Drainage of Jejunum with Drainage Device, Percutaneous Endoscopic Approach */
"0D9A4ZX" = "1" /* Drainage of Jejunum, Percutaneous Endoscopic Approach, Diagnostic */
"0D9A4ZZ" = "1" /* Drainage of Jejunum, Percutaneous Endoscopic Approach */
"0D9B30Z" = "1" /* Drainage of Ileum with Drainage Device, Percutaneous Approach */
"0D9B3ZX" = "1" /* Drainage of Ileum, Percutaneous Approach, Diagnostic */
"0D9B3ZZ" = "1" /* Drainage of Ileum, Percutaneous Approach */
"0D9B40Z" = "1" /* Drainage of Ileum with Drainage Device, Percutaneous Endoscopic Approach */
"0D9B4ZX" = "1" /* Drainage of Ileum, Percutaneous Endoscopic Approach, Diagnostic */
"0D9B4ZZ" = "1" /* Drainage of Ileum, Percutaneous Endoscopic Approach */
"0D9C30Z" = "1" /* Drainage of Ileocecal Valve with Drainage Device, Percutaneous Approach */
"0D9C3ZX" = "1" /* Drainage of Ileocecal Valve, Percutaneous Approach, Diagnostic */
"0D9C3ZZ" = "1" /* Drainage of Ileocecal Valve, Percutaneous Approach */
"0D9C40Z" = "1" /* Drainage of Ileocecal Valve with Drainage Device, Percutaneous Endoscopic Approach */
"0D9C4ZX" = "1" /* Drainage of Ileocecal Valve, Percutaneous Endoscopic Approach, Diagnostic */
"0D9C4ZZ" = "1" /* Drainage of Ileocecal Valve, Percutaneous Endoscopic Approach */
"0D9E30Z" = "1" /* Drainage of Large Intestine with Drainage Device, Percutaneous Approach */
"0D9E3ZX" = "1" /* Drainage of Large Intestine, Percutaneous Approach, Diagnostic */
"0D9E3ZZ" = "1" /* Drainage of Large Intestine, Percutaneous Approach */
"0D9E40Z" = "1" /* Drainage of Large Intestine with Drainage Device, Percutaneous Endoscopic Approach */
"0D9E4ZX" = "1" /* Drainage of Large Intestine, Percutaneous Endoscopic Approach, Diagnostic */
"0D9E4ZZ" = "1" /* Drainage of Large Intestine, Percutaneous Endoscopic Approach */
"0D9F30Z" = "1" /* Drainage of Right Large Intestine with Drainage Device, Percutaneous Approach */
"0D9F3ZX" = "1" /* Drainage of Right Large Intestine, Percutaneous Approach, Diagnostic */
"0D9F3ZZ" = "1" /* Drainage of Right Large Intestine, Percutaneous Approach */
"0D9F40Z" = "1" /* Drainage of Right Large Intestine with Drainage Device, Percutaneous Endoscopic Approach */
"0D9F4ZX" = "1" /* Drainage of Right Large Intestine, Percutaneous Endoscopic Approach, Diagnostic */
"0D9F4ZZ" = "1" /* Drainage of Right Large Intestine, Percutaneous Endoscopic Approach */
"0D9G30Z" = "1" /* Drainage of Left Large Intestine with Drainage Device, Percutaneous Approach */
"0D9G3ZX" = "1" /* Drainage of Left Large Intestine, Percutaneous Approach, Diagnostic */
"0D9G3ZZ" = "1" /* Drainage of Left Large Intestine, Percutaneous Approach */
"0D9G40Z" = "1" /* Drainage of Left Large Intestine with Drainage Device, Percutaneous Endoscopic Approach */
"0D9G4ZX" = "1" /* Drainage of Left Large Intestine, Percutaneous Endoscopic Approach, Diagnostic */
"0D9G4ZZ" = "1" /* Drainage of Left Large Intestine, Percutaneous Endoscopic Approach */
"0D9H30Z" = "1" /* Drainage of Cecum with Drainage Device, Percutaneous Approach */
"0D9H3ZX" = "1" /* Drainage of Cecum, Percutaneous Approach, Diagnostic */
"0D9H3ZZ" = "1" /* Drainage of Cecum, Percutaneous Approach */
"0D9H40Z" = "1" /* Drainage of Cecum with Drainage Device, Percutaneous Endoscopic Approach */
"0D9H4ZX" = "1" /* Drainage of Cecum, Percutaneous Endoscopic Approach, Diagnostic */
"0D9H4ZZ" = "1" /* Drainage of Cecum, Percutaneous Endoscopic Approach */
"0D9J30Z" = "1" /* Drainage of Appendix with Drainage Device, Percutaneous Approach */
"0D9J3ZX" = "1" /* Drainage of Appendix, Percutaneous Approach, Diagnostic */
"0D9J3ZZ" = "1" /* Drainage of Appendix, Percutaneous Approach */
"0D9J40Z" = "1" /* Drainage of Appendix with Drainage Device, Percutaneous Endoscopic Approach */
"0D9J4ZX" = "1" /* Drainage of Appendix, Percutaneous Endoscopic Approach, Diagnostic */
"0D9J4ZZ" = "1" /* Drainage of Appendix, Percutaneous Endoscopic Approach */
"0D9K30Z" = "1" /* Drainage of Ascending Colon with Drainage Device, Percutaneous Approach */
"0D9K3ZX" = "1" /* Drainage of Ascending Colon, Percutaneous Approach, Diagnostic */
"0D9K3ZZ" = "1" /* Drainage of Ascending Colon, Percutaneous Approach */
"0D9K40Z" = "1" /* Drainage of Ascending Colon with Drainage Device, Percutaneous Endoscopic Approach */
"0D9K4ZX" = "1" /* Drainage of Ascending Colon, Percutaneous Endoscopic Approach, Diagnostic */
"0D9K4ZZ" = "1" /* Drainage of Ascending Colon, Percutaneous Endoscopic Approach */
"0D9L30Z" = "1" /* Drainage of Transverse Colon with Drainage Device, Percutaneous Approach */
"0D9L3ZX" = "1" /* Drainage of Transverse Colon, Percutaneous Approach, Diagnostic */
"0D9L3ZZ" = "1" /* Drainage of Transverse Colon, Percutaneous Approach */
"0D9L40Z" = "1" /* Drainage of Transverse Colon with Drainage Device, Percutaneous Endoscopic Approach */
"0D9L4ZX" = "1" /* Drainage of Transverse Colon, Percutaneous Endoscopic Approach, Diagnostic */
"0D9L4ZZ" = "1" /* Drainage of Transverse Colon, Percutaneous Endoscopic Approach */
"0D9M30Z" = "1" /* Drainage of Descending Colon with Drainage Device, Percutaneous Approach */
"0D9M3ZX" = "1" /* Drainage of Descending Colon, Percutaneous Approach, Diagnostic */
"0D9M3ZZ" = "1" /* Drainage of Descending Colon, Percutaneous Approach */
"0D9M40Z" = "1" /* Drainage of Descending Colon with Drainage Device, Percutaneous Endoscopic Approach */
"0D9M4ZX" = "1" /* Drainage of Descending Colon, Percutaneous Endoscopic Approach, Diagnostic */
"0D9M4ZZ" = "1" /* Drainage of Descending Colon, Percutaneous Endoscopic Approach */
"0D9N30Z" = "1" /* Drainage of Sigmoid Colon with Drainage Device, Percutaneous Approach */
"0D9N3ZX" = "1" /* Drainage of Sigmoid Colon, Percutaneous Approach, Diagnostic */
"0D9N3ZZ" = "1" /* Drainage of Sigmoid Colon, Percutaneous Approach */
"0D9N40Z" = "1" /* Drainage of Sigmoid Colon with Drainage Device, Percutaneous Endoscopic Approach */
"0D9N4ZX" = "1" /* Drainage of Sigmoid Colon, Percutaneous Endoscopic Approach, Diagnostic */
"0D9N4ZZ" = "1" /* Drainage of Sigmoid Colon, Percutaneous Endoscopic Approach */
"0D9P30Z" = "1" /* Drainage of Rectum with Drainage Device, Percutaneous Approach */
"0D9P3ZX" = "1" /* Drainage of Rectum, Percutaneous Approach, Diagnostic */
"0D9P3ZZ" = "1" /* Drainage of Rectum, Percutaneous Approach */
"0D9P40Z" = "1" /* Drainage of Rectum with Drainage Device, Percutaneous Endoscopic Approach */
"0D9P4ZX" = "1" /* Drainage of Rectum, Percutaneous Endoscopic Approach, Diagnostic */
"0D9P4ZZ" = "1" /* Drainage of Rectum, Percutaneous Endoscopic Approach */
"0D9S30Z" = "1" /* Drainage of Greater Omentum with Drainage Device, Percutaneous Approach */
"0D9S3ZX" = "1" /* Drainage of Greater Omentum, Percutaneous Approach, Diagnostic */
"0D9S3ZZ" = "1" /* Drainage of Greater Omentum, Percutaneous Approach */
"0D9S40Z" = "1" /* Drainage of Greater Omentum with Drainage Device, Percutaneous Endoscopic Approach */
"0D9S4ZX" = "1" /* Drainage of Greater Omentum, Percutaneous Endoscopic Approach, Diagnostic */
"0D9S4ZZ" = "1" /* Drainage of Greater Omentum, Percutaneous Endoscopic Approach */
"0D9T30Z" = "1" /* Drainage of Lesser Omentum with Drainage Device, Percutaneous Approach */
"0D9T3ZX" = "1" /* Drainage of Lesser Omentum, Percutaneous Approach, Diagnostic */
"0D9T3ZZ" = "1" /* Drainage of Lesser Omentum, Percutaneous Approach */
"0D9T40Z" = "1" /* Drainage of Lesser Omentum with Drainage Device, Percutaneous Endoscopic Approach */
"0D9T4ZX" = "1" /* Drainage of Lesser Omentum, Percutaneous Endoscopic Approach, Diagnostic */
"0D9T4ZZ" = "1" /* Drainage of Lesser Omentum, Percutaneous Endoscopic Approach */
"0D9V30Z" = "1" /* Drainage of Mesentery with Drainage Device, Percutaneous Approach */
"0D9V3ZX" = "1" /* Drainage of Mesentery, Percutaneous Approach, Diagnostic */
"0D9V3ZZ" = "1" /* Drainage of Mesentery, Percutaneous Approach */
"0D9V40Z" = "1" /* Drainage of Mesentery with Drainage Device, Percutaneous Endoscopic Approach */
"0D9V4ZX" = "1" /* Drainage of Mesentery, Percutaneous Endoscopic Approach, Diagnostic */
"0D9V4ZZ" = "1" /* Drainage of Mesentery, Percutaneous Endoscopic Approach */
"0D9W30Z" = "1" /* Drainage of Peritoneum with Drainage Device, Percutaneous Approach */
"0D9W3ZX" = "1" /* Drainage of Peritoneum, Percutaneous Approach, Diagnostic */
"0D9W3ZZ" = "1" /* Drainage of Peritoneum, Percutaneous Approach */
"0D9W40Z" = "1" /* Drainage of Peritoneum with Drainage Device, Percutaneous Endoscopic Approach */
"0D9W4ZX" = "1" /* Drainage of Peritoneum, Percutaneous Endoscopic Approach, Diagnostic */
"0D9W4ZZ" = "1" /* Drainage of Peritoneum, Percutaneous Endoscopic Approach */
"0DB13ZX" = "1" /* Excision of Upper Esophagus, Percutaneous Approach, Diagnostic */
"0DB14ZX" = "1" /* Excision of Upper Esophagus, Percutaneous Endoscopic Approach, Diagnostic */
"0DB14ZZ" = "1" /* Excision of Upper Esophagus, Percutaneous Endoscopic Approach */
"0DB23ZX" = "1" /* Excision of Middle Esophagus, Percutaneous Approach, Diagnostic */
"0DB24ZX" = "1" /* Excision of Middle Esophagus, Percutaneous Endoscopic Approach, Diagnostic */
"0DB24ZZ" = "1" /* Excision of Middle Esophagus, Percutaneous Endoscopic Approach */
"0DB33ZX" = "1" /* Excision of Lower Esophagus, Percutaneous Approach, Diagnostic */
"0DB33ZZ" = "1" /* Excision of Lower Esophagus, Percutaneous Approach */
"0DB34ZX" = "1" /* Excision of Lower Esophagus, Percutaneous Endoscopic Approach, Diagnostic */
"0DB34ZZ" = "1" /* Excision of Lower Esophagus, Percutaneous Endoscopic Approach */
"0DB43ZX" = "1" /* Excision of Esophagogastric Junction, Percutaneous Approach, Diagnostic */
"0DB43ZZ" = "1" /* Excision of Esophagogastric Junction, Percutaneous Approach */
"0DB44ZX" = "1" /* Excision of Esophagogastric Junction, Percutaneous Endoscopic Approach, Diagnostic */
"0DB44ZZ" = "1" /* Excision of Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0DB53ZX" = "1" /* Excision of Esophagus, Percutaneous Approach, Diagnostic */
"0DB53ZZ" = "1" /* Excision of Esophagus, Percutaneous Approach */
"0DB54ZX" = "1" /* Excision of Esophagus, Percutaneous Endoscopic Approach, Diagnostic */
"0DB54ZZ" = "1" /* Excision of Esophagus, Percutaneous Endoscopic Approach */
"0DB63Z3" = "1" /* Excision of Stomach, Percutaneous Approach, Vertical */
"0DB63ZX" = "1" /* Excision of Stomach, Percutaneous Approach, Diagnostic */
"0DB63ZZ" = "1" /* Excision of Stomach, Percutaneous Approach */
"0DB64Z3" = "1" /* Excision of Stomach, Percutaneous Endoscopic Approach, Vertical */
"0DB64ZX" = "1" /* Excision of Stomach, Percutaneous Endoscopic Approach, Diagnostic */
"0DB64ZZ" = "1" /* Excision of Stomach, Percutaneous Endoscopic Approach */
"0DB73ZX" = "1" /* Excision of Stomach, Pylorus, Percutaneous Approach, Diagnostic */
"0DB73ZZ" = "1" /* Excision of Stomach, Pylorus, Percutaneous Approach */
"0DB74ZX" = "1" /* Excision of Stomach, Pylorus, Percutaneous Endoscopic Approach, Diagnostic */
"0DB74ZZ" = "1" /* Excision of Stomach, Pylorus, Percutaneous Endoscopic Approach */
"0DB83ZX" = "1" /* Excision of Small Intestine, Percutaneous Approach, Diagnostic */
"0DB83ZZ" = "1" /* Excision of Small Intestine, Percutaneous Approach */
"0DB84ZX" = "1" /* Excision of Small Intestine, Percutaneous Endoscopic Approach, Diagnostic */
"0DB84ZZ" = "1" /* Excision of Small Intestine, Percutaneous Endoscopic Approach */
"0DB93ZX" = "1" /* Excision of Duodenum, Percutaneous Approach, Diagnostic */
"0DB93ZZ" = "1" /* Excision of Duodenum, Percutaneous Approach */
"0DB94ZX" = "1" /* Excision of Duodenum, Percutaneous Endoscopic Approach, Diagnostic */
"0DB94ZZ" = "1" /* Excision of Duodenum, Percutaneous Endoscopic Approach */
"0DBA3ZX" = "1" /* Excision of Jejunum, Percutaneous Approach, Diagnostic */
"0DBA3ZZ" = "1" /* Excision of Jejunum, Percutaneous Approach */
"0DBA4ZX" = "1" /* Excision of Jejunum, Percutaneous Endoscopic Approach, Diagnostic */
"0DBA4ZZ" = "1" /* Excision of Jejunum, Percutaneous Endoscopic Approach */
"0DBB3ZX" = "1" /* Excision of Ileum, Percutaneous Approach, Diagnostic */
"0DBB3ZZ" = "1" /* Excision of Ileum, Percutaneous Approach */
"0DBB4ZX" = "1" /* Excision of Ileum, Percutaneous Endoscopic Approach, Diagnostic */
"0DBB4ZZ" = "1" /* Excision of Ileum, Percutaneous Endoscopic Approach */
"0DBC3ZX" = "1" /* Excision of Ileocecal Valve, Percutaneous Approach, Diagnostic */
"0DBC3ZZ" = "1" /* Excision of Ileocecal Valve, Percutaneous Approach */
"0DBC4ZX" = "1" /* Excision of Ileocecal Valve, Percutaneous Endoscopic Approach, Diagnostic */
"0DBC4ZZ" = "1" /* Excision of Ileocecal Valve, Percutaneous Endoscopic Approach */
"0DBE3ZX" = "1" /* Excision of Large Intestine, Percutaneous Approach, Diagnostic */
"0DBE3ZZ" = "1" /* Excision of Large Intestine, Percutaneous Approach */
"0DBE4ZX" = "1" /* Excision of Large Intestine, Percutaneous Endoscopic Approach, Diagnostic */
"0DBE4ZZ" = "1" /* Excision of Large Intestine, Percutaneous Endoscopic Approach */
"0DBF3ZX" = "1" /* Excision of Right Large Intestine, Percutaneous Approach, Diagnostic */
"0DBF3ZZ" = "1" /* Excision of Right Large Intestine, Percutaneous Approach */
"0DBF4ZX" = "1" /* Excision of Right Large Intestine, Percutaneous Endoscopic Approach, Diagnostic */
"0DBF4ZZ" = "1" /* Excision of Right Large Intestine, Percutaneous Endoscopic Approach */
"0DBG3ZX" = "1" /* Excision of Left Large Intestine, Percutaneous Approach, Diagnostic */
"0DBG3ZZ" = "1" /* Excision of Left Large Intestine, Percutaneous Approach */
"0DBG4ZX" = "1" /* Excision of Left Large Intestine, Percutaneous Endoscopic Approach, Diagnostic */
"0DBG4ZZ" = "1" /* Excision of Left Large Intestine, Percutaneous Endoscopic Approach */
"0DBH3ZX" = "1" /* Excision of Cecum, Percutaneous Approach, Diagnostic */
"0DBH3ZZ" = "1" /* Excision of Cecum, Percutaneous Approach */
"0DBH4ZX" = "1" /* Excision of Cecum, Percutaneous Endoscopic Approach, Diagnostic */
"0DBH4ZZ" = "1" /* Excision of Cecum, Percutaneous Endoscopic Approach */
"0DBJ3ZX" = "1" /* Excision of Appendix, Percutaneous Approach, Diagnostic */
"0DBJ3ZZ" = "1" /* Excision of Appendix, Percutaneous Approach */
"0DBJ4ZX" = "1" /* Excision of Appendix, Percutaneous Endoscopic Approach, Diagnostic */
"0DBJ4ZZ" = "1" /* Excision of Appendix, Percutaneous Endoscopic Approach */
"0DBK3ZX" = "1" /* Excision of Ascending Colon, Percutaneous Approach, Diagnostic */
"0DBK3ZZ" = "1" /* Excision of Ascending Colon, Percutaneous Approach */
"0DBK4ZX" = "1" /* Excision of Ascending Colon, Percutaneous Endoscopic Approach, Diagnostic */
"0DBK4ZZ" = "1" /* Excision of Ascending Colon, Percutaneous Endoscopic Approach */
"0DBL3ZX" = "1" /* Excision of Transverse Colon, Percutaneous Approach, Diagnostic */
"0DBL3ZZ" = "1" /* Excision of Transverse Colon, Percutaneous Approach */
"0DBL4ZX" = "1" /* Excision of Transverse Colon, Percutaneous Endoscopic Approach, Diagnostic */
"0DBL4ZZ" = "1" /* Excision of Transverse Colon, Percutaneous Endoscopic Approach */
"0DBM3ZX" = "1" /* Excision of Descending Colon, Percutaneous Approach, Diagnostic */
"0DBM3ZZ" = "1" /* Excision of Descending Colon, Percutaneous Approach */
"0DBM4ZX" = "1" /* Excision of Descending Colon, Percutaneous Endoscopic Approach, Diagnostic */
"0DBM4ZZ" = "1" /* Excision of Descending Colon, Percutaneous Endoscopic Approach */
"0DBN3ZX" = "1" /* Excision of Sigmoid Colon, Percutaneous Approach, Diagnostic */
"0DBN3ZZ" = "1" /* Excision of Sigmoid Colon, Percutaneous Approach */
"0DBN4ZX" = "1" /* Excision of Sigmoid Colon, Percutaneous Endoscopic Approach, Diagnostic */
"0DBN4ZZ" = "1" /* Excision of Sigmoid Colon, Percutaneous Endoscopic Approach */
"0DBP3ZX" = "1" /* Excision of Rectum, Percutaneous Approach, Diagnostic */
"0DBP3ZZ" = "1" /* Excision of Rectum, Percutaneous Approach */
"0DBP4ZX" = "1" /* Excision of Rectum, Percutaneous Endoscopic Approach, Diagnostic */
"0DBP4ZZ" = "1" /* Excision of Rectum, Percutaneous Endoscopic Approach */
"0DBS3ZX" = "1" /* Excision of Greater Omentum, Percutaneous Approach, Diagnostic */
"0DBS3ZZ" = "1" /* Excision of Greater Omentum, Percutaneous Approach */
"0DBS4ZX" = "1" /* Excision of Greater Omentum, Percutaneous Endoscopic Approach, Diagnostic */
"0DBS4ZZ" = "1" /* Excision of Greater Omentum, Percutaneous Endoscopic Approach */
"0DBT3ZX" = "1" /* Excision of Lesser Omentum, Percutaneous Approach, Diagnostic */
"0DBT3ZZ" = "1" /* Excision of Lesser Omentum, Percutaneous Approach */
"0DBT4ZX" = "1" /* Excision of Lesser Omentum, Percutaneous Endoscopic Approach, Diagnostic */
"0DBT4ZZ" = "1" /* Excision of Lesser Omentum, Percutaneous Endoscopic Approach */
"0DBV3ZX" = "1" /* Excision of Mesentery, Percutaneous Approach, Diagnostic */
"0DBV3ZZ" = "1" /* Excision of Mesentery, Percutaneous Approach */
"0DBV4ZX" = "1" /* Excision of Mesentery, Percutaneous Endoscopic Approach, Diagnostic */
"0DBV4ZZ" = "1" /* Excision of Mesentery, Percutaneous Endoscopic Approach */
"0DBW3ZX" = "1" /* Excision of Peritoneum, Percutaneous Approach, Diagnostic */
"0DBW3ZZ" = "1" /* Excision of Peritoneum, Percutaneous Approach */
"0DBW4ZX" = "1" /* Excision of Peritoneum, Percutaneous Endoscopic Approach, Diagnostic */
"0DBW4ZZ" = "1" /* Excision of Peritoneum, Percutaneous Endoscopic Approach */
"0DC43ZZ" = "1" /* Extirpation of Matter from Esophagogastric Junction, Percutaneous Approach */
"0DC44ZZ" = "1" /* Extirpation of Matter from Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0DC63ZZ" = "1" /* Extirpation of Matter from Stomach, Percutaneous Approach */
"0DC64ZZ" = "1" /* Extirpation of Matter from Stomach, Percutaneous Endoscopic Approach */
"0DC73ZZ" = "1" /* Extirpation of Matter from Stomach, Pylorus, Percutaneous Approach */
"0DC74ZZ" = "1" /* Extirpation of Matter from Stomach, Pylorus, Percutaneous Endoscopic Approach */
"0DC83ZZ" = "1" /* Extirpation of Matter from Small Intestine, Percutaneous Approach */
"0DC84ZZ" = "1" /* Extirpation of Matter from Small Intestine, Percutaneous Endoscopic Approach */
"0DC93ZZ" = "1" /* Extirpation of Matter from Duodenum, Percutaneous Approach */
"0DC94ZZ" = "1" /* Extirpation of Matter from Duodenum, Percutaneous Endoscopic Approach */
"0DCA3ZZ" = "1" /* Extirpation of Matter from Jejunum, Percutaneous Approach */
"0DCA4ZZ" = "1" /* Extirpation of Matter from Jejunum, Percutaneous Endoscopic Approach */
"0DCB3ZZ" = "1" /* Extirpation of Matter from Ileum, Percutaneous Approach */
"0DCB4ZZ" = "1" /* Extirpation of Matter from Ileum, Percutaneous Endoscopic Approach */
"0DCC3ZZ" = "1" /* Extirpation of Matter from Ileocecal Valve, Percutaneous Approach */
"0DCC4ZZ" = "1" /* Extirpation of Matter from Ileocecal Valve, Percutaneous Endoscopic Approach */
"0DCE3ZZ" = "1" /* Extirpation of Matter from Large Intestine, Percutaneous Approach */
"0DCE4ZZ" = "1" /* Extirpation of Matter from Large Intestine, Percutaneous Endoscopic Approach */
"0DCF3ZZ" = "1" /* Extirpation of Matter from Right Large Intestine, Percutaneous Approach */
"0DCF4ZZ" = "1" /* Extirpation of Matter from Right Large Intestine, Percutaneous Endoscopic Approach */
"0DCG3ZZ" = "1" /* Extirpation of Matter from Left Large Intestine, Percutaneous Approach */
"0DCG4ZZ" = "1" /* Extirpation of Matter from Left Large Intestine, Percutaneous Endoscopic Approach */
"0DCH3ZZ" = "1" /* Extirpation of Matter from Cecum, Percutaneous Approach */
"0DCH4ZZ" = "1" /* Extirpation of Matter from Cecum, Percutaneous Endoscopic Approach */
"0DCJ3ZZ" = "1" /* Extirpation of Matter from Appendix, Percutaneous Approach */
"0DCJ4ZZ" = "1" /* Extirpation of Matter from Appendix, Percutaneous Endoscopic Approach */
"0DCK3ZZ" = "1" /* Extirpation of Matter from Ascending Colon, Percutaneous Approach */
"0DCK4ZZ" = "1" /* Extirpation of Matter from Ascending Colon, Percutaneous Endoscopic Approach */
"0DCL3ZZ" = "1" /* Extirpation of Matter from Transverse Colon, Percutaneous Approach */
"0DCL4ZZ" = "1" /* Extirpation of Matter from Transverse Colon, Percutaneous Endoscopic Approach */
"0DCM3ZZ" = "1" /* Extirpation of Matter from Descending Colon, Percutaneous Approach */
"0DCM4ZZ" = "1" /* Extirpation of Matter from Descending Colon, Percutaneous Endoscopic Approach */
"0DCN3ZZ" = "1" /* Extirpation of Matter from Sigmoid Colon, Percutaneous Approach */
"0DCN4ZZ" = "1" /* Extirpation of Matter from Sigmoid Colon, Percutaneous Endoscopic Approach */
"0DCP3ZZ" = "1" /* Extirpation of Matter from Rectum, Percutaneous Approach */
"0DCP4ZZ" = "1" /* Extirpation of Matter from Rectum, Percutaneous Endoscopic Approach */
"0DCS3ZZ" = "1" /* Extirpation of Matter from Greater Omentum, Percutaneous Approach */
"0DCS4ZZ" = "1" /* Extirpation of Matter from Greater Omentum, Percutaneous Endoscopic Approach */
"0DCT3ZZ" = "1" /* Extirpation of Matter from Lesser Omentum, Percutaneous Approach */
"0DCT4ZZ" = "1" /* Extirpation of Matter from Lesser Omentum, Percutaneous Endoscopic Approach */
"0DCV3ZZ" = "1" /* Extirpation of Matter from Mesentery, Percutaneous Approach */
"0DCV4ZZ" = "1" /* Extirpation of Matter from Mesentery, Percutaneous Endoscopic Approach */
"0DCW3ZZ" = "1" /* Extirpation of Matter from Peritoneum, Percutaneous Approach */
"0DCW4ZZ" = "1" /* Extirpation of Matter from Peritoneum, Percutaneous Endoscopic Approach */
"0DF63ZZ" = "1" /* Fragmentation in Stomach, Percutaneous Approach */
"0DF64ZZ" = "1" /* Fragmentation in Stomach, Percutaneous Endoscopic Approach */
"0DF83ZZ" = "1" /* Fragmentation in Small Intestine, Percutaneous Approach */
"0DF84ZZ" = "1" /* Fragmentation in Small Intestine, Percutaneous Endoscopic Approach */
"0DF93ZZ" = "1" /* Fragmentation in Duodenum, Percutaneous Approach */
"0DF94ZZ" = "1" /* Fragmentation in Duodenum, Percutaneous Endoscopic Approach */
"0DFA3ZZ" = "1" /* Fragmentation in Jejunum, Percutaneous Approach */
"0DFA4ZZ" = "1" /* Fragmentation in Jejunum, Percutaneous Endoscopic Approach */
"0DFB3ZZ" = "1" /* Fragmentation in Ileum, Percutaneous Approach */
"0DFB4ZZ" = "1" /* Fragmentation in Ileum, Percutaneous Endoscopic Approach */
"0DFE3ZZ" = "1" /* Fragmentation in Large Intestine, Percutaneous Approach */
"0DFE4ZZ" = "1" /* Fragmentation in Large Intestine, Percutaneous Endoscopic Approach */
"0DFF3ZZ" = "1" /* Fragmentation in Right Large Intestine, Percutaneous Approach */
"0DFF4ZZ" = "1" /* Fragmentation in Right Large Intestine, Percutaneous Endoscopic Approach */
"0DFG3ZZ" = "1" /* Fragmentation in Left Large Intestine, Percutaneous Approach */
"0DFG4ZZ" = "1" /* Fragmentation in Left Large Intestine, Percutaneous Endoscopic Approach */
"0DFH3ZZ" = "1" /* Fragmentation in Cecum, Percutaneous Approach */
"0DFH4ZZ" = "1" /* Fragmentation in Cecum, Percutaneous Endoscopic Approach */
"0DFJ3ZZ" = "1" /* Fragmentation in Appendix, Percutaneous Approach */
"0DFJ4ZZ" = "1" /* Fragmentation in Appendix, Percutaneous Endoscopic Approach */
"0DFK3ZZ" = "1" /* Fragmentation in Ascending Colon, Percutaneous Approach */
"0DFK4ZZ" = "1" /* Fragmentation in Ascending Colon, Percutaneous Endoscopic Approach */
"0DFL3ZZ" = "1" /* Fragmentation in Transverse Colon, Percutaneous Approach */
"0DFL4ZZ" = "1" /* Fragmentation in Transverse Colon, Percutaneous Endoscopic Approach */
"0DFM3ZZ" = "1" /* Fragmentation in Descending Colon, Percutaneous Approach */
"0DFM4ZZ" = "1" /* Fragmentation in Descending Colon, Percutaneous Endoscopic Approach */
"0DFN3ZZ" = "1" /* Fragmentation in Sigmoid Colon, Percutaneous Approach */
"0DFN4ZZ" = "1" /* Fragmentation in Sigmoid Colon, Percutaneous Endoscopic Approach */
"0DFP3ZZ" = "1" /* Fragmentation in Rectum, Percutaneous Approach */
"0DFP4ZZ" = "1" /* Fragmentation in Rectum, Percutaneous Endoscopic Approach */
"0DH632Z" = "1" /* Insertion of Monitoring Device into Stomach, Percutaneous Approach */
"0DH633Z" = "1" /* Insertion of Infusion Device into Stomach, Percutaneous Approach */
"0DH63DZ" = "1" /* Insertion of Intraluminal Device into Stomach, Percutaneous Approach */
"0DH63MZ" = "1" /* Insertion of Stimulator Lead into Stomach, Percutaneous Approach */
"0DH63UZ" = "1" /* Insertion of Feeding Device into Stomach, Percutaneous Approach */
"0DH642Z" = "1" /* Insertion of Monitoring Device into Stomach, Percutaneous Endoscopic Approach */
"0DH643Z" = "1" /* Insertion of Infusion Device into Stomach, Percutaneous Endoscopic Approach */
"0DH64DZ" = "1" /* Insertion of Intraluminal Device into Stomach, Percutaneous Endoscopic Approach */
"0DH64MZ" = "1" /* Insertion of Stimulator Lead into Stomach, Percutaneous Endoscopic Approach */
"0DH64UZ" = "1" /* Insertion of Feeding Device into Stomach, Percutaneous Endoscopic Approach */
"0DH832Z" = "1" /* Insertion of Monitoring Device into Small Intestine, Percutaneous Approach */
"0DH833Z" = "1" /* Insertion of Infusion Device into Small Intestine, Percutaneous Approach */
"0DH83DZ" = "1" /* Insertion of Intraluminal Device into Small Intestine, Percutaneous Approach */
"0DH83UZ" = "1" /* Insertion of Feeding Device into Small Intestine, Percutaneous Approach */
"0DH842Z" = "1" /* Insertion of Monitoring Device into Small Intestine, Percutaneous Endoscopic Approach */
"0DH843Z" = "1" /* Insertion of Infusion Device into Small Intestine, Percutaneous Endoscopic Approach */
"0DH84DZ" = "1" /* Insertion of Intraluminal Device into Small Intestine, Percutaneous Endoscopic Approach */
"0DH84UZ" = "1" /* Insertion of Feeding Device into Small Intestine, Percutaneous Endoscopic Approach */
"0DH932Z" = "1" /* Insertion of Monitoring Device into Duodenum, Percutaneous Approach */
"0DH933Z" = "1" /* Insertion of Infusion Device into Duodenum, Percutaneous Approach */
"0DH93DZ" = "1" /* Insertion of Intraluminal Device into Duodenum, Percutaneous Approach */
"0DH93UZ" = "1" /* Insertion of Feeding Device into Duodenum, Percutaneous Approach */
"0DH942Z" = "1" /* Insertion of Monitoring Device into Duodenum, Percutaneous Endoscopic Approach */
"0DH943Z" = "1" /* Insertion of Infusion Device into Duodenum, Percutaneous Endoscopic Approach */
"0DH94DZ" = "1" /* Insertion of Intraluminal Device into Duodenum, Percutaneous Endoscopic Approach */
"0DH94UZ" = "1" /* Insertion of Feeding Device into Duodenum, Percutaneous Endoscopic Approach */
"0DHA32Z" = "1" /* Insertion of Monitoring Device into Jejunum, Percutaneous Approach */
"0DHA33Z" = "1" /* Insertion of Infusion Device into Jejunum, Percutaneous Approach */
"0DHA3DZ" = "1" /* Insertion of Intraluminal Device into Jejunum, Percutaneous Approach */
"0DHA3UZ" = "1" /* Insertion of Feeding Device into Jejunum, Percutaneous Approach */
"0DHA42Z" = "1" /* Insertion of Monitoring Device into Jejunum, Percutaneous Endoscopic Approach */
"0DHA43Z" = "1" /* Insertion of Infusion Device into Jejunum, Percutaneous Endoscopic Approach */
"0DHA4DZ" = "1" /* Insertion of Intraluminal Device into Jejunum, Percutaneous Endoscopic Approach */
"0DHA4UZ" = "1" /* Insertion of Feeding Device into Jejunum, Percutaneous Endoscopic Approach */
"0DHB32Z" = "1" /* Insertion of Monitoring Device into Ileum, Percutaneous Approach */
"0DHB33Z" = "1" /* Insertion of Infusion Device into Ileum, Percutaneous Approach */
"0DHB3DZ" = "1" /* Insertion of Intraluminal Device into Ileum, Percutaneous Approach */
"0DHB3UZ" = "1" /* Insertion of Feeding Device into Ileum, Percutaneous Approach */
"0DHB42Z" = "1" /* Insertion of Monitoring Device into Ileum, Percutaneous Endoscopic Approach */
"0DHB43Z" = "1" /* Insertion of Infusion Device into Ileum, Percutaneous Endoscopic Approach */
"0DHB4DZ" = "1" /* Insertion of Intraluminal Device into Ileum, Percutaneous Endoscopic Approach */
"0DHB4UZ" = "1" /* Insertion of Feeding Device into Ileum, Percutaneous Endoscopic Approach */
"0DHE3DZ" = "1" /* Insertion of Intraluminal Device into Large Intestine, Percutaneous Approach */
"0DHE4DZ" = "1" /* Insertion of Intraluminal Device into Large Intestine, Percutaneous Endoscopic Approach */
"0DHP31Z" = "1" /* Insertion of Radioactive Element into Rectum, Percutaneous Approach */
"0DHP3DZ" = "1" /* Insertion of Intraluminal Device into Rectum, Percutaneous Approach */
"0DHP41Z" = "1" /* Insertion of Radioactive Element into Rectum, Percutaneous Endoscopic Approach */
"0DHP4DZ" = "1" /* Insertion of Intraluminal Device into Rectum, Percutaneous Endoscopic Approach */
"0DJ03ZZ" = "1" /* Inspection of Upper Intestinal Tract, Percutaneous Approach */
"0DJ04ZZ" = "1" /* Inspection of Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DJ63ZZ" = "1" /* Inspection of Stomach, Percutaneous Approach */
"0DJ64ZZ" = "1" /* Inspection of Stomach, Percutaneous Endoscopic Approach */
"0DJD3ZZ" = "1" /* Inspection of Lower Intestinal Tract, Percutaneous Approach */
"0DJD4ZZ" = "1" /* Inspection of Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DJU3ZZ" = "1" /* Inspection of Omentum, Percutaneous Approach */
"0DJU4ZZ" = "1" /* Inspection of Omentum, Percutaneous Endoscopic Approach */
"0DJV3ZZ" = "1" /* Inspection of Mesentery, Percutaneous Approach */
"0DJV4ZZ" = "1" /* Inspection of Mesentery, Percutaneous Endoscopic Approach */
"0DJW3ZZ" = "1" /* Inspection of Peritoneum, Percutaneous Approach */
"0DJW4ZZ" = "1" /* Inspection of Peritoneum, Percutaneous Endoscopic Approach */
"0DL43CZ" = "1" /* Occlusion of Esophagogastric Junction with Extraluminal Device, Percutaneous Approach */
"0DL43DZ" = "1" /* Occlusion of Esophagogastric Junction with Intraluminal Device, Percutaneous Approach */
"0DL43ZZ" = "1" /* Occlusion of Esophagogastric Junction, Percutaneous Approach */
"0DL44CZ" = "1" /* Occlusion of Esophagogastric Junction with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DL44DZ" = "1" /* Occlusion of Esophagogastric Junction with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DL44ZZ" = "1" /* Occlusion of Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0DL63CZ" = "1" /* Occlusion of Stomach with Extraluminal Device, Percutaneous Approach */
"0DL63DZ" = "1" /* Occlusion of Stomach with Intraluminal Device, Percutaneous Approach */
"0DL63ZZ" = "1" /* Occlusion of Stomach, Percutaneous Approach */
"0DL64CZ" = "1" /* Occlusion of Stomach with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DL64DZ" = "1" /* Occlusion of Stomach with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DL64ZZ" = "1" /* Occlusion of Stomach, Percutaneous Endoscopic Approach */
"0DL73CZ" = "1" /* Occlusion of Stomach, Pylorus with Extraluminal Device, Percutaneous Approach */
"0DL73DZ" = "1" /* Occlusion of Stomach, Pylorus with Intraluminal Device, Percutaneous Approach */
"0DL73ZZ" = "1" /* Occlusion of Stomach, Pylorus, Percutaneous Approach */
"0DL74CZ" = "1" /* Occlusion of Stomach, Pylorus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DL74DZ" = "1" /* Occlusion of Stomach, Pylorus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DL74ZZ" = "1" /* Occlusion of Stomach, Pylorus, Percutaneous Endoscopic Approach */
"0DL83CZ" = "1" /* Occlusion of Small Intestine with Extraluminal Device, Percutaneous Approach */
"0DL83DZ" = "1" /* Occlusion of Small Intestine with Intraluminal Device, Percutaneous Approach */
"0DL83ZZ" = "1" /* Occlusion of Small Intestine, Percutaneous Approach */
"0DL84CZ" = "1" /* Occlusion of Small Intestine with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DL84DZ" = "1" /* Occlusion of Small Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DL84ZZ" = "1" /* Occlusion of Small Intestine, Percutaneous Endoscopic Approach */
"0DL93CZ" = "1" /* Occlusion of Duodenum with Extraluminal Device, Percutaneous Approach */
"0DL93DZ" = "1" /* Occlusion of Duodenum with Intraluminal Device, Percutaneous Approach */
"0DL93ZZ" = "1" /* Occlusion of Duodenum, Percutaneous Approach */
"0DL94CZ" = "1" /* Occlusion of Duodenum with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DL94DZ" = "1" /* Occlusion of Duodenum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DL94ZZ" = "1" /* Occlusion of Duodenum, Percutaneous Endoscopic Approach */
"0DLA3CZ" = "1" /* Occlusion of Jejunum with Extraluminal Device, Percutaneous Approach */
"0DLA3DZ" = "1" /* Occlusion of Jejunum with Intraluminal Device, Percutaneous Approach */
"0DLA3ZZ" = "1" /* Occlusion of Jejunum, Percutaneous Approach */
"0DLA4CZ" = "1" /* Occlusion of Jejunum with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLA4DZ" = "1" /* Occlusion of Jejunum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLA4ZZ" = "1" /* Occlusion of Jejunum, Percutaneous Endoscopic Approach */
"0DLB3CZ" = "1" /* Occlusion of Ileum with Extraluminal Device, Percutaneous Approach */
"0DLB3DZ" = "1" /* Occlusion of Ileum with Intraluminal Device, Percutaneous Approach */
"0DLB3ZZ" = "1" /* Occlusion of Ileum, Percutaneous Approach */
"0DLB4CZ" = "1" /* Occlusion of Ileum with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLB4DZ" = "1" /* Occlusion of Ileum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLB4ZZ" = "1" /* Occlusion of Ileum, Percutaneous Endoscopic Approach */
"0DLC3CZ" = "1" /* Occlusion of Ileocecal Valve with Extraluminal Device, Percutaneous Approach */
"0DLC3DZ" = "1" /* Occlusion of Ileocecal Valve with Intraluminal Device, Percutaneous Approach */
"0DLC3ZZ" = "1" /* Occlusion of Ileocecal Valve, Percutaneous Approach */
"0DLC4CZ" = "1" /* Occlusion of Ileocecal Valve with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLC4DZ" = "1" /* Occlusion of Ileocecal Valve with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLC4ZZ" = "1" /* Occlusion of Ileocecal Valve, Percutaneous Endoscopic Approach */
"0DLE3CZ" = "1" /* Occlusion of Large Intestine with Extraluminal Device, Percutaneous Approach */
"0DLE3DZ" = "1" /* Occlusion of Large Intestine with Intraluminal Device, Percutaneous Approach */
"0DLE3ZZ" = "1" /* Occlusion of Large Intestine, Percutaneous Approach */
"0DLE4CZ" = "1" /* Occlusion of Large Intestine with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLE4DZ" = "1" /* Occlusion of Large Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLE4ZZ" = "1" /* Occlusion of Large Intestine, Percutaneous Endoscopic Approach */
"0DLF3CZ" = "1" /* Occlusion of Right Large Intestine with Extraluminal Device, Percutaneous Approach */
"0DLF3DZ" = "1" /* Occlusion of Right Large Intestine with Intraluminal Device, Percutaneous Approach */
"0DLF3ZZ" = "1" /* Occlusion of Right Large Intestine, Percutaneous Approach */
"0DLF4CZ" = "1" /* Occlusion of Right Large Intestine with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLF4DZ" = "1" /* Occlusion of Right Large Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLF4ZZ" = "1" /* Occlusion of Right Large Intestine, Percutaneous Endoscopic Approach */
"0DLG3CZ" = "1" /* Occlusion of Left Large Intestine with Extraluminal Device, Percutaneous Approach */
"0DLG3DZ" = "1" /* Occlusion of Left Large Intestine with Intraluminal Device, Percutaneous Approach */
"0DLG3ZZ" = "1" /* Occlusion of Left Large Intestine, Percutaneous Approach */
"0DLG4CZ" = "1" /* Occlusion of Left Large Intestine with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLG4DZ" = "1" /* Occlusion of Left Large Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLG4ZZ" = "1" /* Occlusion of Left Large Intestine, Percutaneous Endoscopic Approach */
"0DLH3CZ" = "1" /* Occlusion of Cecum with Extraluminal Device, Percutaneous Approach */
"0DLH3DZ" = "1" /* Occlusion of Cecum with Intraluminal Device, Percutaneous Approach */
"0DLH3ZZ" = "1" /* Occlusion of Cecum, Percutaneous Approach */
"0DLH4CZ" = "1" /* Occlusion of Cecum with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLH4DZ" = "1" /* Occlusion of Cecum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLH4ZZ" = "1" /* Occlusion of Cecum, Percutaneous Endoscopic Approach */
"0DLK3CZ" = "1" /* Occlusion of Ascending Colon with Extraluminal Device, Percutaneous Approach */
"0DLK3DZ" = "1" /* Occlusion of Ascending Colon with Intraluminal Device, Percutaneous Approach */
"0DLK3ZZ" = "1" /* Occlusion of Ascending Colon, Percutaneous Approach */
"0DLK4CZ" = "1" /* Occlusion of Ascending Colon with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLK4DZ" = "1" /* Occlusion of Ascending Colon with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLK4ZZ" = "1" /* Occlusion of Ascending Colon, Percutaneous Endoscopic Approach */
"0DLL3CZ" = "1" /* Occlusion of Transverse Colon with Extraluminal Device, Percutaneous Approach */
"0DLL3DZ" = "1" /* Occlusion of Transverse Colon with Intraluminal Device, Percutaneous Approach */
"0DLL3ZZ" = "1" /* Occlusion of Transverse Colon, Percutaneous Approach */
"0DLL4CZ" = "1" /* Occlusion of Transverse Colon with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLL4DZ" = "1" /* Occlusion of Transverse Colon with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLL4ZZ" = "1" /* Occlusion of Transverse Colon, Percutaneous Endoscopic Approach */
"0DLM3CZ" = "1" /* Occlusion of Descending Colon with Extraluminal Device, Percutaneous Approach */
"0DLM3DZ" = "1" /* Occlusion of Descending Colon with Intraluminal Device, Percutaneous Approach */
"0DLM3ZZ" = "1" /* Occlusion of Descending Colon, Percutaneous Approach */
"0DLM4CZ" = "1" /* Occlusion of Descending Colon with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLM4DZ" = "1" /* Occlusion of Descending Colon with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLM4ZZ" = "1" /* Occlusion of Descending Colon, Percutaneous Endoscopic Approach */
"0DLN3CZ" = "1" /* Occlusion of Sigmoid Colon with Extraluminal Device, Percutaneous Approach */
"0DLN3DZ" = "1" /* Occlusion of Sigmoid Colon with Intraluminal Device, Percutaneous Approach */
"0DLN3ZZ" = "1" /* Occlusion of Sigmoid Colon, Percutaneous Approach */
"0DLN4CZ" = "1" /* Occlusion of Sigmoid Colon with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLN4DZ" = "1" /* Occlusion of Sigmoid Colon with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLN4ZZ" = "1" /* Occlusion of Sigmoid Colon, Percutaneous Endoscopic Approach */
"0DLP3CZ" = "1" /* Occlusion of Rectum with Extraluminal Device, Percutaneous Approach */
"0DLP3DZ" = "1" /* Occlusion of Rectum with Intraluminal Device, Percutaneous Approach */
"0DLP3ZZ" = "1" /* Occlusion of Rectum, Percutaneous Approach */
"0DLP4CZ" = "1" /* Occlusion of Rectum with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLP4DZ" = "1" /* Occlusion of Rectum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLP4ZZ" = "1" /* Occlusion of Rectum, Percutaneous Endoscopic Approach */
"0DM64ZZ" = "1" /* Reattachment of Stomach, Percutaneous Endoscopic Approach */
"0DM84ZZ" = "1" /* Reattachment of Small Intestine, Percutaneous Endoscopic Approach */
"0DM94ZZ" = "1" /* Reattachment of Duodenum, Percutaneous Endoscopic Approach */
"0DMA4ZZ" = "1" /* Reattachment of Jejunum, Percutaneous Endoscopic Approach */
"0DMB4ZZ" = "1" /* Reattachment of Ileum, Percutaneous Endoscopic Approach */
"0DME4ZZ" = "1" /* Reattachment of Large Intestine, Percutaneous Endoscopic Approach */
"0DMF4ZZ" = "1" /* Reattachment of Right Large Intestine, Percutaneous Endoscopic Approach */
"0DMG4ZZ" = "1" /* Reattachment of Left Large Intestine, Percutaneous Endoscopic Approach */
"0DMH4ZZ" = "1" /* Reattachment of Cecum, Percutaneous Endoscopic Approach */
"0DMK4ZZ" = "1" /* Reattachment of Ascending Colon, Percutaneous Endoscopic Approach */
"0DML4ZZ" = "1" /* Reattachment of Transverse Colon, Percutaneous Endoscopic Approach */
"0DMM4ZZ" = "1" /* Reattachment of Descending Colon, Percutaneous Endoscopic Approach */
"0DMN4ZZ" = "1" /* Reattachment of Sigmoid Colon, Percutaneous Endoscopic Approach */
"0DMP4ZZ" = "1" /* Reattachment of Rectum, Percutaneous Endoscopic Approach */
"0DN43ZZ" = "1" /* Release Esophagogastric Junction, Percutaneous Approach */
"0DN44ZZ" = "1" /* Release Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0DN63ZZ" = "1" /* Release Stomach, Percutaneous Approach */
"0DN64ZZ" = "1" /* Release Stomach, Percutaneous Endoscopic Approach */
"0DN73ZZ" = "1" /* Release Stomach, Pylorus, Percutaneous Approach */
"0DN74ZZ" = "1" /* Release Stomach, Pylorus, Percutaneous Endoscopic Approach */
"0DN83ZZ" = "1" /* Release Small Intestine, Percutaneous Approach */
"0DN84ZZ" = "1" /* Release Small Intestine, Percutaneous Endoscopic Approach */
"0DN93ZZ" = "1" /* Release Duodenum, Percutaneous Approach */
"0DN94ZZ" = "1" /* Release Duodenum, Percutaneous Endoscopic Approach */
"0DNA3ZZ" = "1" /* Release Jejunum, Percutaneous Approach */
"0DNA4ZZ" = "1" /* Release Jejunum, Percutaneous Endoscopic Approach */
"0DNB3ZZ" = "1" /* Release Ileum, Percutaneous Approach */
"0DNB4ZZ" = "1" /* Release Ileum, Percutaneous Endoscopic Approach */
"0DNC3ZZ" = "1" /* Release Ileocecal Valve, Percutaneous Approach */
"0DNC4ZZ" = "1" /* Release Ileocecal Valve, Percutaneous Endoscopic Approach */
"0DNE3ZZ" = "1" /* Release Large Intestine, Percutaneous Approach */
"0DNE4ZZ" = "1" /* Release Large Intestine, Percutaneous Endoscopic Approach */
"0DNF3ZZ" = "1" /* Release Right Large Intestine, Percutaneous Approach */
"0DNF4ZZ" = "1" /* Release Right Large Intestine, Percutaneous Endoscopic Approach */
"0DNG3ZZ" = "1" /* Release Left Large Intestine, Percutaneous Approach */
"0DNG4ZZ" = "1" /* Release Left Large Intestine, Percutaneous Endoscopic Approach */
"0DNH3ZZ" = "1" /* Release Cecum, Percutaneous Approach */
"0DNH4ZZ" = "1" /* Release Cecum, Percutaneous Endoscopic Approach */
"0DNJ3ZZ" = "1" /* Release Appendix, Percutaneous Approach */
"0DNJ4ZZ" = "1" /* Release Appendix, Percutaneous Endoscopic Approach */
"0DNK3ZZ" = "1" /* Release Ascending Colon, Percutaneous Approach */
"0DNK4ZZ" = "1" /* Release Ascending Colon, Percutaneous Endoscopic Approach */
"0DNL3ZZ" = "1" /* Release Transverse Colon, Percutaneous Approach */
"0DNL4ZZ" = "1" /* Release Transverse Colon, Percutaneous Endoscopic Approach */
"0DNM3ZZ" = "1" /* Release Descending Colon, Percutaneous Approach */
"0DNM4ZZ" = "1" /* Release Descending Colon, Percutaneous Endoscopic Approach */
"0DNN3ZZ" = "1" /* Release Sigmoid Colon, Percutaneous Approach */
"0DNN4ZZ" = "1" /* Release Sigmoid Colon, Percutaneous Endoscopic Approach */
"0DNP3ZZ" = "1" /* Release Rectum, Percutaneous Approach */
"0DNP4ZZ" = "1" /* Release Rectum, Percutaneous Endoscopic Approach */
"0DNS3ZZ" = "1" /* Release Greater Omentum, Percutaneous Approach */
"0DNS4ZZ" = "1" /* Release Greater Omentum, Percutaneous Endoscopic Approach */
"0DNT3ZZ" = "1" /* Release Lesser Omentum, Percutaneous Approach */
"0DNT4ZZ" = "1" /* Release Lesser Omentum, Percutaneous Endoscopic Approach */
"0DNV3ZZ" = "1" /* Release Mesentery, Percutaneous Approach */
"0DNV4ZZ" = "1" /* Release Mesentery, Percutaneous Endoscopic Approach */
"0DNW3ZZ" = "1" /* Release Peritoneum, Percutaneous Approach */
"0DNW4ZZ" = "1" /* Release Peritoneum, Percutaneous Endoscopic Approach */
"0DP030Z" = "1" /* Removal of Drainage Device from Upper Intestinal Tract, Percutaneous Approach */
"0DP032Z" = "1" /* Removal of Monitoring Device from Upper Intestinal Tract, Percutaneous Approach */
"0DP033Z" = "1" /* Removal of Infusion Device from Upper Intestinal Tract, Percutaneous Approach */
"0DP037Z" = "1" /* Removal of Autologous Tissue Substitute from Upper Intestinal Tract, Percutaneous Approach */
"0DP03CZ" = "1" /* Removal of Extraluminal Device from Upper Intestinal Tract, Percutaneous Approach */
"0DP03DZ" = "1" /* Removal of Intraluminal Device from Upper Intestinal Tract, Percutaneous Approach */
"0DP03JZ" = "1" /* Removal of Synthetic Substitute from Upper Intestinal Tract, Percutaneous Approach */
"0DP03KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Upper Intestinal Tract, Percutaneous Approach */
"0DP03UZ" = "1" /* Removal of Feeding Device from Upper Intestinal Tract, Percutaneous Approach */
"0DP040Z" = "1" /* Removal of Drainage Device from Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DP042Z" = "1" /* Removal of Monitoring Device from Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DP043Z" = "1" /* Removal of Infusion Device from Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DP047Z" = "1" /* Removal of Autologous Tissue Substitute from Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DP04CZ" = "1" /* Removal of Extraluminal Device from Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DP04DZ" = "1" /* Removal of Intraluminal Device from Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DP04JZ" = "1" /* Removal of Synthetic Substitute from Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DP04KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DP04UZ" = "1" /* Removal of Feeding Device from Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DP630Z" = "1" /* Removal of Drainage Device from Stomach, Percutaneous Approach */
"0DP632Z" = "1" /* Removal of Monitoring Device from Stomach, Percutaneous Approach */
"0DP633Z" = "1" /* Removal of Infusion Device from Stomach, Percutaneous Approach */
"0DP637Z" = "1" /* Removal of Autologous Tissue Substitute from Stomach, Percutaneous Approach */
"0DP63CZ" = "1" /* Removal of Extraluminal Device from Stomach, Percutaneous Approach */
"0DP63DZ" = "1" /* Removal of Intraluminal Device from Stomach, Percutaneous Approach */
"0DP63JZ" = "1" /* Removal of Synthetic Substitute from Stomach, Percutaneous Approach */
"0DP63KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Stomach, Percutaneous Approach */
"0DP63MZ" = "1" /* Removal of Stimulator Lead from Stomach, Percutaneous Approach */
"0DP63UZ" = "1" /* Removal of Feeding Device from Stomach, Percutaneous Approach */
"0DP640Z" = "1" /* Removal of Drainage Device from Stomach, Percutaneous Endoscopic Approach */
"0DP642Z" = "1" /* Removal of Monitoring Device from Stomach, Percutaneous Endoscopic Approach */
"0DP643Z" = "1" /* Removal of Infusion Device from Stomach, Percutaneous Endoscopic Approach */
"0DP647Z" = "1" /* Removal of Autologous Tissue Substitute from Stomach, Percutaneous Endoscopic Approach */
"0DP64CZ" = "1" /* Removal of Extraluminal Device from Stomach, Percutaneous Endoscopic Approach */
"0DP64DZ" = "1" /* Removal of Intraluminal Device from Stomach, Percutaneous Endoscopic Approach */
"0DP64JZ" = "1" /* Removal of Synthetic Substitute from Stomach, Percutaneous Endoscopic Approach */
"0DP64KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Stomach, Percutaneous Endoscopic Approach */
"0DP64MZ" = "1" /* Removal of Stimulator Lead from Stomach, Percutaneous Endoscopic Approach */
"0DP64UZ" = "1" /* Removal of Feeding Device from Stomach, Percutaneous Endoscopic Approach */
"0DPD30Z" = "1" /* Removal of Drainage Device from Lower Intestinal Tract, Percutaneous Approach */
"0DPD32Z" = "1" /* Removal of Monitoring Device from Lower Intestinal Tract, Percutaneous Approach */
"0DPD33Z" = "1" /* Removal of Infusion Device from Lower Intestinal Tract, Percutaneous Approach */
"0DPD37Z" = "1" /* Removal of Autologous Tissue Substitute from Lower Intestinal Tract, Percutaneous Approach */
"0DPD3CZ" = "1" /* Removal of Extraluminal Device from Lower Intestinal Tract, Percutaneous Approach */
"0DPD3DZ" = "1" /* Removal of Intraluminal Device from Lower Intestinal Tract, Percutaneous Approach */
"0DPD3JZ" = "1" /* Removal of Synthetic Substitute from Lower Intestinal Tract, Percutaneous Approach */
"0DPD3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lower Intestinal Tract, Percutaneous Approach */
"0DPD3UZ" = "1" /* Removal of Feeding Device from Lower Intestinal Tract, Percutaneous Approach */
"0DPD40Z" = "1" /* Removal of Drainage Device from Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DPD42Z" = "1" /* Removal of Monitoring Device from Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DPD43Z" = "1" /* Removal of Infusion Device from Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DPD47Z" = "1" /* Removal of Autologous Tissue Substitute from Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DPD4CZ" = "1" /* Removal of Extraluminal Device from Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DPD4DZ" = "1" /* Removal of Intraluminal Device from Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DPD4JZ" = "1" /* Removal of Synthetic Substitute from Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DPD4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DPD4UZ" = "1" /* Removal of Feeding Device from Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DPP31Z" = "1" /* Removal of Radioactive Element from Rectum, Percutaneous Approach */
"0DPP41Z" = "1" /* Removal of Radioactive Element from Rectum, Percutaneous Endoscopic Approach */
"0DPU30Z" = "1" /* Removal of Drainage Device from Omentum, Percutaneous Approach */
"0DPU31Z" = "1" /* Removal of Radioactive Element from Omentum, Percutaneous Approach */
"0DPU37Z" = "1" /* Removal of Autologous Tissue Substitute from Omentum, Percutaneous Approach */
"0DPU3JZ" = "1" /* Removal of Synthetic Substitute from Omentum, Percutaneous Approach */
"0DPU3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Omentum, Percutaneous Approach */
"0DPU40Z" = "1" /* Removal of Drainage Device from Omentum, Percutaneous Endoscopic Approach */
"0DPU41Z" = "1" /* Removal of Radioactive Element from Omentum, Percutaneous Endoscopic Approach */
"0DPU47Z" = "1" /* Removal of Autologous Tissue Substitute from Omentum, Percutaneous Endoscopic Approach */
"0DPU4JZ" = "1" /* Removal of Synthetic Substitute from Omentum, Percutaneous Endoscopic Approach */
"0DPU4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Omentum, Percutaneous Endoscopic Approach */
"0DPV30Z" = "1" /* Removal of Drainage Device from Mesentery, Percutaneous Approach */
"0DPV31Z" = "1" /* Removal of Radioactive Element from Mesentery, Percutaneous Approach */
"0DPV37Z" = "1" /* Removal of Autologous Tissue Substitute from Mesentery, Percutaneous Approach */
"0DPV3JZ" = "1" /* Removal of Synthetic Substitute from Mesentery, Percutaneous Approach */
"0DPV3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Mesentery, Percutaneous Approach */
"0DPV40Z" = "1" /* Removal of Drainage Device from Mesentery, Percutaneous Endoscopic Approach */
"0DPV41Z" = "1" /* Removal of Radioactive Element from Mesentery, Percutaneous Endoscopic Approach */
"0DPV47Z" = "1" /* Removal of Autologous Tissue Substitute from Mesentery, Percutaneous Endoscopic Approach */
"0DPV4JZ" = "1" /* Removal of Synthetic Substitute from Mesentery, Percutaneous Endoscopic Approach */
"0DPV4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Mesentery, Percutaneous Endoscopic Approach */
"0DPW30Z" = "1" /* Removal of Drainage Device from Peritoneum, Percutaneous Approach */
"0DPW31Z" = "1" /* Removal of Radioactive Element from Peritoneum, Percutaneous Approach */
"0DPW37Z" = "1" /* Removal of Autologous Tissue Substitute from Peritoneum, Percutaneous Approach */
"0DPW3JZ" = "1" /* Removal of Synthetic Substitute from Peritoneum, Percutaneous Approach */
"0DPW3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Peritoneum, Percutaneous Approach */
"0DPW40Z" = "1" /* Removal of Drainage Device from Peritoneum, Percutaneous Endoscopic Approach */
"0DPW41Z" = "1" /* Removal of Radioactive Element from Peritoneum, Percutaneous Endoscopic Approach */
"0DPW47Z" = "1" /* Removal of Autologous Tissue Substitute from Peritoneum, Percutaneous Endoscopic Approach */
"0DPW4JZ" = "1" /* Removal of Synthetic Substitute from Peritoneum, Percutaneous Endoscopic Approach */
"0DPW4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Peritoneum, Percutaneous Endoscopic Approach */
"0DQ43ZZ" = "1" /* Repair Esophagogastric Junction, Percutaneous Approach */
"0DQ44ZZ" = "1" /* Repair Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0DQ63ZZ" = "1" /* Repair Stomach, Percutaneous Approach */
"0DQ64ZZ" = "1" /* Repair Stomach, Percutaneous Endoscopic Approach */
"0DQ73ZZ" = "1" /* Repair Stomach, Pylorus, Percutaneous Approach */
"0DQ74ZZ" = "1" /* Repair Stomach, Pylorus, Percutaneous Endoscopic Approach */
"0DQ83ZZ" = "1" /* Repair Small Intestine, Percutaneous Approach */
"0DQ84ZZ" = "1" /* Repair Small Intestine, Percutaneous Endoscopic Approach */
"0DQ93ZZ" = "1" /* Repair Duodenum, Percutaneous Approach */
"0DQ94ZZ" = "1" /* Repair Duodenum, Percutaneous Endoscopic Approach */
"0DQA3ZZ" = "1" /* Repair Jejunum, Percutaneous Approach */
"0DQA4ZZ" = "1" /* Repair Jejunum, Percutaneous Endoscopic Approach */
"0DQB3ZZ" = "1" /* Repair Ileum, Percutaneous Approach */
"0DQB4ZZ" = "1" /* Repair Ileum, Percutaneous Endoscopic Approach */
"0DQC3ZZ" = "1" /* Repair Ileocecal Valve, Percutaneous Approach */
"0DQC4ZZ" = "1" /* Repair Ileocecal Valve, Percutaneous Endoscopic Approach */
"0DQE3ZZ" = "1" /* Repair Large Intestine, Percutaneous Approach */
"0DQE4ZZ" = "1" /* Repair Large Intestine, Percutaneous Endoscopic Approach */
"0DQF3ZZ" = "1" /* Repair Right Large Intestine, Percutaneous Approach */
"0DQF4ZZ" = "1" /* Repair Right Large Intestine, Percutaneous Endoscopic Approach */
"0DQG3ZZ" = "1" /* Repair Left Large Intestine, Percutaneous Approach */
"0DQG4ZZ" = "1" /* Repair Left Large Intestine, Percutaneous Endoscopic Approach */
"0DQH3ZZ" = "1" /* Repair Cecum, Percutaneous Approach */
"0DQH4ZZ" = "1" /* Repair Cecum, Percutaneous Endoscopic Approach */
"0DQJ3ZZ" = "1" /* Repair Appendix, Percutaneous Approach */
"0DQJ4ZZ" = "1" /* Repair Appendix, Percutaneous Endoscopic Approach */
"0DQK3ZZ" = "1" /* Repair Ascending Colon, Percutaneous Approach */
"0DQK4ZZ" = "1" /* Repair Ascending Colon, Percutaneous Endoscopic Approach */
"0DQL3ZZ" = "1" /* Repair Transverse Colon, Percutaneous Approach */
"0DQL4ZZ" = "1" /* Repair Transverse Colon, Percutaneous Endoscopic Approach */
"0DQM3ZZ" = "1" /* Repair Descending Colon, Percutaneous Approach */
"0DQM4ZZ" = "1" /* Repair Descending Colon, Percutaneous Endoscopic Approach */
"0DQN3ZZ" = "1" /* Repair Sigmoid Colon, Percutaneous Approach */
"0DQN4ZZ" = "1" /* Repair Sigmoid Colon, Percutaneous Endoscopic Approach */
"0DQP3ZZ" = "1" /* Repair Rectum, Percutaneous Approach */
"0DQP4ZZ" = "1" /* Repair Rectum, Percutaneous Endoscopic Approach */
"0DQS3ZZ" = "1" /* Repair Greater Omentum, Percutaneous Approach */
"0DQS4ZZ" = "1" /* Repair Greater Omentum, Percutaneous Endoscopic Approach */
"0DQT3ZZ" = "1" /* Repair Lesser Omentum, Percutaneous Approach */
"0DQT4ZZ" = "1" /* Repair Lesser Omentum, Percutaneous Endoscopic Approach */
"0DQV3ZZ" = "1" /* Repair Mesentery, Percutaneous Approach */
"0DQV4ZZ" = "1" /* Repair Mesentery, Percutaneous Endoscopic Approach */
"0DQW3ZZ" = "1" /* Repair Peritoneum, Percutaneous Approach */
"0DQW4ZZ" = "1" /* Repair Peritoneum, Percutaneous Endoscopic Approach */
"0DRS47Z" = "1" /* Replacement of Greater Omentum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DRS4JZ" = "1" /* Replacement of Greater Omentum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DRS4KZ" = "1" /* Replacement of Greater Omentum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DRT47Z" = "1" /* Replacement of Lesser Omentum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DRT4JZ" = "1" /* Replacement of Lesser Omentum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DRT4KZ" = "1" /* Replacement of Lesser Omentum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DRV47Z" = "1" /* Replacement of Mesentery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DRV4JZ" = "1" /* Replacement of Mesentery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DRV4KZ" = "1" /* Replacement of Mesentery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DRW47Z" = "1" /* Replacement of Peritoneum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DRW4JZ" = "1" /* Replacement of Peritoneum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DRW4KZ" = "1" /* Replacement of Peritoneum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DS64ZZ" = "1" /* Reposition Stomach, Percutaneous Endoscopic Approach */
"0DS94ZZ" = "1" /* Reposition Duodenum, Percutaneous Endoscopic Approach */
"0DSA4ZZ" = "1" /* Reposition Jejunum, Percutaneous Endoscopic Approach */
"0DSB4ZZ" = "1" /* Reposition Ileum, Percutaneous Endoscopic Approach */
"0DSH4ZZ" = "1" /* Reposition Cecum, Percutaneous Endoscopic Approach */
"0DSK4ZZ" = "1" /* Reposition Ascending Colon, Percutaneous Endoscopic Approach */
"0DSL4ZZ" = "1" /* Reposition Transverse Colon, Percutaneous Endoscopic Approach */
"0DSM4ZZ" = "1" /* Reposition Descending Colon, Percutaneous Endoscopic Approach */
"0DSN4ZZ" = "1" /* Reposition Sigmoid Colon, Percutaneous Endoscopic Approach */
"0DSP4ZZ" = "1" /* Reposition Rectum, Percutaneous Endoscopic Approach */
"0DT14ZZ" = "1" /* Resection of Upper Esophagus, Percutaneous Endoscopic Approach */
"0DT24ZZ" = "1" /* Resection of Middle Esophagus, Percutaneous Endoscopic Approach */
"0DT34ZZ" = "1" /* Resection of Lower Esophagus, Percutaneous Endoscopic Approach */
"0DT44ZZ" = "1" /* Resection of Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0DT54ZZ" = "1" /* Resection of Esophagus, Percutaneous Endoscopic Approach */
"0DT64ZZ" = "1" /* Resection of Stomach, Percutaneous Endoscopic Approach */
"0DT74ZZ" = "1" /* Resection of Stomach, Pylorus, Percutaneous Endoscopic Approach */
"0DT84ZZ" = "1" /* Resection of Small Intestine, Percutaneous Endoscopic Approach */
"0DT94ZZ" = "1" /* Resection of Duodenum, Percutaneous Endoscopic Approach */
"0DTA4ZZ" = "1" /* Resection of Jejunum, Percutaneous Endoscopic Approach */
"0DTB4ZZ" = "1" /* Resection of Ileum, Percutaneous Endoscopic Approach */
"0DTC4ZZ" = "1" /* Resection of Ileocecal Valve, Percutaneous Endoscopic Approach */
"0DTE4ZZ" = "1" /* Resection of Large Intestine, Percutaneous Endoscopic Approach */
"0DTF4ZZ" = "1" /* Resection of Right Large Intestine, Percutaneous Endoscopic Approach */
"0DTG4ZZ" = "1" /* Resection of Left Large Intestine, Percutaneous Endoscopic Approach */
"0DTH4ZZ" = "1" /* Resection of Cecum, Percutaneous Endoscopic Approach */
"0DTJ4ZZ" = "1" /* Resection of Appendix, Percutaneous Endoscopic Approach */
"0DTK4ZZ" = "1" /* Resection of Ascending Colon, Percutaneous Endoscopic Approach */
"0DTL4ZZ" = "1" /* Resection of Transverse Colon, Percutaneous Endoscopic Approach */
"0DTM4ZZ" = "1" /* Resection of Descending Colon, Percutaneous Endoscopic Approach */
"0DTN4ZZ" = "1" /* Resection of Sigmoid Colon, Percutaneous Endoscopic Approach */
"0DTP4ZZ" = "1" /* Resection of Rectum, Percutaneous Endoscopic Approach */
"0DTS4ZZ" = "1" /* Resection of Greater Omentum, Percutaneous Endoscopic Approach */
"0DTT4ZZ" = "1" /* Resection of Lesser Omentum, Percutaneous Endoscopic Approach */
"0DU447Z" = "1" /* Supplement Esophagogastric Junction with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU44JZ" = "1" /* Supplement Esophagogastric Junction with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DU44KZ" = "1" /* Supplement Esophagogastric Junction with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU647Z" = "1" /* Supplement Stomach with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU64JZ" = "1" /* Supplement Stomach with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DU64KZ" = "1" /* Supplement Stomach with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU747Z" = "1" /* Supplement Stomach, Pylorus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU74JZ" = "1" /* Supplement Stomach, Pylorus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DU74KZ" = "1" /* Supplement Stomach, Pylorus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU847Z" = "1" /* Supplement Small Intestine with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU84JZ" = "1" /* Supplement Small Intestine with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DU84KZ" = "1" /* Supplement Small Intestine with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU947Z" = "1" /* Supplement Duodenum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU94JZ" = "1" /* Supplement Duodenum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DU94KZ" = "1" /* Supplement Duodenum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUA47Z" = "1" /* Supplement Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUA4JZ" = "1" /* Supplement Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUA4KZ" = "1" /* Supplement Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUB47Z" = "1" /* Supplement Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUB4JZ" = "1" /* Supplement Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUB4KZ" = "1" /* Supplement Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUC47Z" = "1" /* Supplement Ileocecal Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUC4JZ" = "1" /* Supplement Ileocecal Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUC4KZ" = "1" /* Supplement Ileocecal Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUE47Z" = "1" /* Supplement Large Intestine with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUE4JZ" = "1" /* Supplement Large Intestine with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUE4KZ" = "1" /* Supplement Large Intestine with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUF47Z" = "1" /* Supplement Right Large Intestine with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUF4JZ" = "1" /* Supplement Right Large Intestine with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUF4KZ" = "1" /* Supplement Right Large Intestine with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUG47Z" = "1" /* Supplement Left Large Intestine with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUG4JZ" = "1" /* Supplement Left Large Intestine with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUG4KZ" = "1" /* Supplement Left Large Intestine with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUH47Z" = "1" /* Supplement Cecum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUH4JZ" = "1" /* Supplement Cecum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUH4KZ" = "1" /* Supplement Cecum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUK47Z" = "1" /* Supplement Ascending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUK4JZ" = "1" /* Supplement Ascending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUK4KZ" = "1" /* Supplement Ascending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUL47Z" = "1" /* Supplement Transverse Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUL4JZ" = "1" /* Supplement Transverse Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUL4KZ" = "1" /* Supplement Transverse Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUM47Z" = "1" /* Supplement Descending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUM4JZ" = "1" /* Supplement Descending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUM4KZ" = "1" /* Supplement Descending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUN47Z" = "1" /* Supplement Sigmoid Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUN4JZ" = "1" /* Supplement Sigmoid Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUN4KZ" = "1" /* Supplement Sigmoid Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUP47Z" = "1" /* Supplement Rectum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUP4JZ" = "1" /* Supplement Rectum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUP4KZ" = "1" /* Supplement Rectum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUS47Z" = "1" /* Supplement Greater Omentum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUS4JZ" = "1" /* Supplement Greater Omentum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUS4KZ" = "1" /* Supplement Greater Omentum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUT47Z" = "1" /* Supplement Lesser Omentum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUT4JZ" = "1" /* Supplement Lesser Omentum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUT4KZ" = "1" /* Supplement Lesser Omentum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUV47Z" = "1" /* Supplement Mesentery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUV4JZ" = "1" /* Supplement Mesentery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUV4KZ" = "1" /* Supplement Mesentery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUW47Z" = "1" /* Supplement Peritoneum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUW4JZ" = "1" /* Supplement Peritoneum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUW4KZ" = "1" /* Supplement Peritoneum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DV43CZ" = "1" /* Restriction of Esophagogastric Junction with Extraluminal Device, Percutaneous Approach */
"0DV43DZ" = "1" /* Restriction of Esophagogastric Junction with Intraluminal Device, Percutaneous Approach */
"0DV43ZZ" = "1" /* Restriction of Esophagogastric Junction, Percutaneous Approach */
"0DV44CZ" = "1" /* Restriction of Esophagogastric Junction with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DV44DZ" = "1" /* Restriction of Esophagogastric Junction with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DV44ZZ" = "1" /* Restriction of Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0DV63CZ" = "1" /* Restriction of Stomach with Extraluminal Device, Percutaneous Approach */
"0DV63DZ" = "1" /* Restriction of Stomach with Intraluminal Device, Percutaneous Approach */
"0DV63ZZ" = "1" /* Restriction of Stomach, Percutaneous Approach */
"0DV64CZ" = "1" /* Restriction of Stomach with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DV64DZ" = "1" /* Restriction of Stomach with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DV64ZZ" = "1" /* Restriction of Stomach, Percutaneous Endoscopic Approach */
"0DV73CZ" = "1" /* Restriction of Stomach, Pylorus with Extraluminal Device, Percutaneous Approach */
"0DV73DZ" = "1" /* Restriction of Stomach, Pylorus with Intraluminal Device, Percutaneous Approach */
"0DV73ZZ" = "1" /* Restriction of Stomach, Pylorus, Percutaneous Approach */
"0DV74CZ" = "1" /* Restriction of Stomach, Pylorus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DV74DZ" = "1" /* Restriction of Stomach, Pylorus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DV74ZZ" = "1" /* Restriction of Stomach, Pylorus, Percutaneous Endoscopic Approach */
"0DV83CZ" = "1" /* Restriction of Small Intestine with Extraluminal Device, Percutaneous Approach */
"0DV83DZ" = "1" /* Restriction of Small Intestine with Intraluminal Device, Percutaneous Approach */
"0DV83ZZ" = "1" /* Restriction of Small Intestine, Percutaneous Approach */
"0DV84CZ" = "1" /* Restriction of Small Intestine with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DV84DZ" = "1" /* Restriction of Small Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DV84ZZ" = "1" /* Restriction of Small Intestine, Percutaneous Endoscopic Approach */
"0DV93CZ" = "1" /* Restriction of Duodenum with Extraluminal Device, Percutaneous Approach */
"0DV93DZ" = "1" /* Restriction of Duodenum with Intraluminal Device, Percutaneous Approach */
"0DV93ZZ" = "1" /* Restriction of Duodenum, Percutaneous Approach */
"0DV94CZ" = "1" /* Restriction of Duodenum with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DV94DZ" = "1" /* Restriction of Duodenum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DV94ZZ" = "1" /* Restriction of Duodenum, Percutaneous Endoscopic Approach */
"0DVA3CZ" = "1" /* Restriction of Jejunum with Extraluminal Device, Percutaneous Approach */
"0DVA3DZ" = "1" /* Restriction of Jejunum with Intraluminal Device, Percutaneous Approach */
"0DVA3ZZ" = "1" /* Restriction of Jejunum, Percutaneous Approach */
"0DVA4CZ" = "1" /* Restriction of Jejunum with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVA4DZ" = "1" /* Restriction of Jejunum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVA4ZZ" = "1" /* Restriction of Jejunum, Percutaneous Endoscopic Approach */
"0DVB3CZ" = "1" /* Restriction of Ileum with Extraluminal Device, Percutaneous Approach */
"0DVB3DZ" = "1" /* Restriction of Ileum with Intraluminal Device, Percutaneous Approach */
"0DVB3ZZ" = "1" /* Restriction of Ileum, Percutaneous Approach */
"0DVB4CZ" = "1" /* Restriction of Ileum with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVB4DZ" = "1" /* Restriction of Ileum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVB4ZZ" = "1" /* Restriction of Ileum, Percutaneous Endoscopic Approach */
"0DVC3CZ" = "1" /* Restriction of Ileocecal Valve with Extraluminal Device, Percutaneous Approach */
"0DVC3DZ" = "1" /* Restriction of Ileocecal Valve with Intraluminal Device, Percutaneous Approach */
"0DVC3ZZ" = "1" /* Restriction of Ileocecal Valve, Percutaneous Approach */
"0DVC4CZ" = "1" /* Restriction of Ileocecal Valve with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVC4DZ" = "1" /* Restriction of Ileocecal Valve with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVC4ZZ" = "1" /* Restriction of Ileocecal Valve, Percutaneous Endoscopic Approach */
"0DVE3CZ" = "1" /* Restriction of Large Intestine with Extraluminal Device, Percutaneous Approach */
"0DVE3DZ" = "1" /* Restriction of Large Intestine with Intraluminal Device, Percutaneous Approach */
"0DVE3ZZ" = "1" /* Restriction of Large Intestine, Percutaneous Approach */
"0DVE4CZ" = "1" /* Restriction of Large Intestine with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVE4DZ" = "1" /* Restriction of Large Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVE4ZZ" = "1" /* Restriction of Large Intestine, Percutaneous Endoscopic Approach */
"0DVF3CZ" = "1" /* Restriction of Right Large Intestine with Extraluminal Device, Percutaneous Approach */
"0DVF3DZ" = "1" /* Restriction of Right Large Intestine with Intraluminal Device, Percutaneous Approach */
"0DVF3ZZ" = "1" /* Restriction of Right Large Intestine, Percutaneous Approach */
"0DVF4CZ" = "1" /* Restriction of Right Large Intestine with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVF4DZ" = "1" /* Restriction of Right Large Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVF4ZZ" = "1" /* Restriction of Right Large Intestine, Percutaneous Endoscopic Approach */
"0DVG3CZ" = "1" /* Restriction of Left Large Intestine with Extraluminal Device, Percutaneous Approach */
"0DVG3DZ" = "1" /* Restriction of Left Large Intestine with Intraluminal Device, Percutaneous Approach */
"0DVG3ZZ" = "1" /* Restriction of Left Large Intestine, Percutaneous Approach */
"0DVG4CZ" = "1" /* Restriction of Left Large Intestine with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVG4DZ" = "1" /* Restriction of Left Large Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVG4ZZ" = "1" /* Restriction of Left Large Intestine, Percutaneous Endoscopic Approach */
"0DVH3CZ" = "1" /* Restriction of Cecum with Extraluminal Device, Percutaneous Approach */
"0DVH3DZ" = "1" /* Restriction of Cecum with Intraluminal Device, Percutaneous Approach */
"0DVH3ZZ" = "1" /* Restriction of Cecum, Percutaneous Approach */
"0DVH4CZ" = "1" /* Restriction of Cecum with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVH4DZ" = "1" /* Restriction of Cecum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVH4ZZ" = "1" /* Restriction of Cecum, Percutaneous Endoscopic Approach */
"0DVK3CZ" = "1" /* Restriction of Ascending Colon with Extraluminal Device, Percutaneous Approach */
"0DVK3DZ" = "1" /* Restriction of Ascending Colon with Intraluminal Device, Percutaneous Approach */
"0DVK3ZZ" = "1" /* Restriction of Ascending Colon, Percutaneous Approach */
"0DVK4CZ" = "1" /* Restriction of Ascending Colon with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVK4DZ" = "1" /* Restriction of Ascending Colon with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVK4ZZ" = "1" /* Restriction of Ascending Colon, Percutaneous Endoscopic Approach */
"0DVL3CZ" = "1" /* Restriction of Transverse Colon with Extraluminal Device, Percutaneous Approach */
"0DVL3DZ" = "1" /* Restriction of Transverse Colon with Intraluminal Device, Percutaneous Approach */
"0DVL3ZZ" = "1" /* Restriction of Transverse Colon, Percutaneous Approach */
"0DVL4CZ" = "1" /* Restriction of Transverse Colon with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVL4DZ" = "1" /* Restriction of Transverse Colon with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVL4ZZ" = "1" /* Restriction of Transverse Colon, Percutaneous Endoscopic Approach */
"0DVM3CZ" = "1" /* Restriction of Descending Colon with Extraluminal Device, Percutaneous Approach */
"0DVM3DZ" = "1" /* Restriction of Descending Colon with Intraluminal Device, Percutaneous Approach */
"0DVM3ZZ" = "1" /* Restriction of Descending Colon, Percutaneous Approach */
"0DVM4CZ" = "1" /* Restriction of Descending Colon with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVM4DZ" = "1" /* Restriction of Descending Colon with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVM4ZZ" = "1" /* Restriction of Descending Colon, Percutaneous Endoscopic Approach */
"0DVN3CZ" = "1" /* Restriction of Sigmoid Colon with Extraluminal Device, Percutaneous Approach */
"0DVN3DZ" = "1" /* Restriction of Sigmoid Colon with Intraluminal Device, Percutaneous Approach */
"0DVN3ZZ" = "1" /* Restriction of Sigmoid Colon, Percutaneous Approach */
"0DVN4CZ" = "1" /* Restriction of Sigmoid Colon with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVN4DZ" = "1" /* Restriction of Sigmoid Colon with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVN4ZZ" = "1" /* Restriction of Sigmoid Colon, Percutaneous Endoscopic Approach */
"0DVP3CZ" = "1" /* Restriction of Rectum with Extraluminal Device, Percutaneous Approach */
"0DVP3DZ" = "1" /* Restriction of Rectum with Intraluminal Device, Percutaneous Approach */
"0DVP3ZZ" = "1" /* Restriction of Rectum, Percutaneous Approach */
"0DVP4CZ" = "1" /* Restriction of Rectum with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVP4DZ" = "1" /* Restriction of Rectum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVP4ZZ" = "1" /* Restriction of Rectum, Percutaneous Endoscopic Approach */
"0DW030Z" = "1" /* Revision of Drainage Device in Upper Intestinal Tract, Percutaneous Approach */
"0DW032Z" = "1" /* Revision of Monitoring Device in Upper Intestinal Tract, Percutaneous Approach */
"0DW033Z" = "1" /* Revision of Infusion Device in Upper Intestinal Tract, Percutaneous Approach */
"0DW037Z" = "1" /* Revision of Autologous Tissue Substitute in Upper Intestinal Tract, Percutaneous Approach */
"0DW03CZ" = "1" /* Revision of Extraluminal Device in Upper Intestinal Tract, Percutaneous Approach */
"0DW03DZ" = "1" /* Revision of Intraluminal Device in Upper Intestinal Tract, Percutaneous Approach */
"0DW03JZ" = "1" /* Revision of Synthetic Substitute in Upper Intestinal Tract, Percutaneous Approach */
"0DW03KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Intestinal Tract, Percutaneous Approach */
"0DW03UZ" = "1" /* Revision of Feeding Device in Upper Intestinal Tract, Percutaneous Approach */
"0DW040Z" = "1" /* Revision of Drainage Device in Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DW042Z" = "1" /* Revision of Monitoring Device in Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DW043Z" = "1" /* Revision of Infusion Device in Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DW047Z" = "1" /* Revision of Autologous Tissue Substitute in Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DW04CZ" = "1" /* Revision of Extraluminal Device in Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DW04DZ" = "1" /* Revision of Intraluminal Device in Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DW04JZ" = "1" /* Revision of Synthetic Substitute in Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DW04KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DW04UZ" = "1" /* Revision of Feeding Device in Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DW630Z" = "1" /* Revision of Drainage Device in Stomach, Percutaneous Approach */
"0DW632Z" = "1" /* Revision of Monitoring Device in Stomach, Percutaneous Approach */
"0DW633Z" = "1" /* Revision of Infusion Device in Stomach, Percutaneous Approach */
"0DW637Z" = "1" /* Revision of Autologous Tissue Substitute in Stomach, Percutaneous Approach */
"0DW63CZ" = "1" /* Revision of Extraluminal Device in Stomach, Percutaneous Approach */
"0DW63DZ" = "1" /* Revision of Intraluminal Device in Stomach, Percutaneous Approach */
"0DW63JZ" = "1" /* Revision of Synthetic Substitute in Stomach, Percutaneous Approach */
"0DW63KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Stomach, Percutaneous Approach */
"0DW63MZ" = "1" /* Revision of Stimulator Lead in Stomach, Percutaneous Approach */
"0DW63UZ" = "1" /* Revision of Feeding Device in Stomach, Percutaneous Approach */
"0DW640Z" = "1" /* Revision of Drainage Device in Stomach, Percutaneous Endoscopic Approach */
"0DW642Z" = "1" /* Revision of Monitoring Device in Stomach, Percutaneous Endoscopic Approach */
"0DW643Z" = "1" /* Revision of Infusion Device in Stomach, Percutaneous Endoscopic Approach */
"0DW647Z" = "1" /* Revision of Autologous Tissue Substitute in Stomach, Percutaneous Endoscopic Approach */
"0DW64CZ" = "1" /* Revision of Extraluminal Device in Stomach, Percutaneous Endoscopic Approach */
"0DW64DZ" = "1" /* Revision of Intraluminal Device in Stomach, Percutaneous Endoscopic Approach */
"0DW64JZ" = "1" /* Revision of Synthetic Substitute in Stomach, Percutaneous Endoscopic Approach */
"0DW64KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Stomach, Percutaneous Endoscopic Approach */
"0DW64MZ" = "1" /* Revision of Stimulator Lead in Stomach, Percutaneous Endoscopic Approach */
"0DW64UZ" = "1" /* Revision of Feeding Device in Stomach, Percutaneous Endoscopic Approach */
"0DW847Z" = "1" /* Revision of Autologous Tissue Substitute in Small Intestine, Percutaneous Endoscopic Approach */
"0DW84JZ" = "1" /* Revision of Synthetic Substitute in Small Intestine, Percutaneous Endoscopic Approach */
"0DW84KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Small Intestine, Percutaneous Endoscopic Approach */
"0DWD30Z" = "1" /* Revision of Drainage Device in Lower Intestinal Tract, Percutaneous Approach */
"0DWD32Z" = "1" /* Revision of Monitoring Device in Lower Intestinal Tract, Percutaneous Approach */
"0DWD33Z" = "1" /* Revision of Infusion Device in Lower Intestinal Tract, Percutaneous Approach */
"0DWD37Z" = "1" /* Revision of Autologous Tissue Substitute in Lower Intestinal Tract, Percutaneous Approach */
"0DWD3CZ" = "1" /* Revision of Extraluminal Device in Lower Intestinal Tract, Percutaneous Approach */
"0DWD3DZ" = "1" /* Revision of Intraluminal Device in Lower Intestinal Tract, Percutaneous Approach */
"0DWD3JZ" = "1" /* Revision of Synthetic Substitute in Lower Intestinal Tract, Percutaneous Approach */
"0DWD3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Intestinal Tract, Percutaneous Approach */
"0DWD3UZ" = "1" /* Revision of Feeding Device in Lower Intestinal Tract, Percutaneous Approach */
"0DWD40Z" = "1" /* Revision of Drainage Device in Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DWD42Z" = "1" /* Revision of Monitoring Device in Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DWD43Z" = "1" /* Revision of Infusion Device in Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DWD47Z" = "1" /* Revision of Autologous Tissue Substitute in Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DWD4CZ" = "1" /* Revision of Extraluminal Device in Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DWD4DZ" = "1" /* Revision of Intraluminal Device in Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DWD4JZ" = "1" /* Revision of Synthetic Substitute in Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DWD4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DWD4UZ" = "1" /* Revision of Feeding Device in Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DWE47Z" = "1" /* Revision of Autologous Tissue Substitute in Large Intestine, Percutaneous Endoscopic Approach */
"0DWE4JZ" = "1" /* Revision of Synthetic Substitute in Large Intestine, Percutaneous Endoscopic Approach */
"0DWE4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Large Intestine, Percutaneous Endoscopic Approach */
"0DWU30Z" = "1" /* Revision of Drainage Device in Omentum, Percutaneous Approach */
"0DWU37Z" = "1" /* Revision of Autologous Tissue Substitute in Omentum, Percutaneous Approach */
"0DWU3JZ" = "1" /* Revision of Synthetic Substitute in Omentum, Percutaneous Approach */
"0DWU3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Omentum, Percutaneous Approach */
"0DWU40Z" = "1" /* Revision of Drainage Device in Omentum, Percutaneous Endoscopic Approach */
"0DWU47Z" = "1" /* Revision of Autologous Tissue Substitute in Omentum, Percutaneous Endoscopic Approach */
"0DWU4JZ" = "1" /* Revision of Synthetic Substitute in Omentum, Percutaneous Endoscopic Approach */
"0DWU4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Omentum, Percutaneous Endoscopic Approach */
"0DWV30Z" = "1" /* Revision of Drainage Device in Mesentery, Percutaneous Approach */
"0DWV37Z" = "1" /* Revision of Autologous Tissue Substitute in Mesentery, Percutaneous Approach */
"0DWV3JZ" = "1" /* Revision of Synthetic Substitute in Mesentery, Percutaneous Approach */
"0DWV3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mesentery, Percutaneous Approach */
"0DWV40Z" = "1" /* Revision of Drainage Device in Mesentery, Percutaneous Endoscopic Approach */
"0DWV47Z" = "1" /* Revision of Autologous Tissue Substitute in Mesentery, Percutaneous Endoscopic Approach */
"0DWV4JZ" = "1" /* Revision of Synthetic Substitute in Mesentery, Percutaneous Endoscopic Approach */
"0DWV4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mesentery, Percutaneous Endoscopic Approach */
"0DWW30Z" = "1" /* Revision of Drainage Device in Peritoneum, Percutaneous Approach */
"0DWW37Z" = "1" /* Revision of Autologous Tissue Substitute in Peritoneum, Percutaneous Approach */
"0DWW3JZ" = "1" /* Revision of Synthetic Substitute in Peritoneum, Percutaneous Approach */
"0DWW3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Peritoneum, Percutaneous Approach */
"0DWW40Z" = "1" /* Revision of Drainage Device in Peritoneum, Percutaneous Endoscopic Approach */
"0DWW47Z" = "1" /* Revision of Autologous Tissue Substitute in Peritoneum, Percutaneous Endoscopic Approach */
"0DWW4JZ" = "1" /* Revision of Synthetic Substitute in Peritoneum, Percutaneous Endoscopic Approach */
"0DWW4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Peritoneum, Percutaneous Endoscopic Approach */
"0DX64Z5" = "1" /* Transfer Stomach to Esophagus, Percutaneous Endoscopic Approach */
"0DX84Z5" = "1" /* Transfer Small Intestine to Esophagus, Percutaneous Endoscopic Approach */
"0DXE4Z5" = "1" /* Transfer Large Intestine to Esophagus, Percutaneous Endoscopic Approach */
"0F144D3" = "1" /* Bypass Gallbladder to Duodenum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F144D4" = "1" /* Bypass Gallbladder to Stomach with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F144D5" = "1" /* Bypass Gallbladder to Right Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F144D6" = "1" /* Bypass Gallbladder to Left Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F144D7" = "1" /* Bypass Gallbladder to Caudate Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F144D8" = "1" /* Bypass Gallbladder to Cystic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F144D9" = "1" /* Bypass Gallbladder to Common Bile Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F144DB" = "1" /* Bypass Gallbladder to Small Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F144Z3" = "1" /* Bypass Gallbladder to Duodenum, Percutaneous Endoscopic Approach */
"0F144Z4" = "1" /* Bypass Gallbladder to Stomach, Percutaneous Endoscopic Approach */
"0F144Z5" = "1" /* Bypass Gallbladder to Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0F144Z6" = "1" /* Bypass Gallbladder to Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0F144Z7" = "1" /* Bypass Gallbladder to Caudate Hepatic Duct, Percutaneous Endoscopic Approach */
"0F144Z8" = "1" /* Bypass Gallbladder to Cystic Duct, Percutaneous Endoscopic Approach */
"0F144Z9" = "1" /* Bypass Gallbladder to Common Bile Duct, Percutaneous Endoscopic Approach */
"0F144ZB" = "1" /* Bypass Gallbladder to Small Intestine, Percutaneous Endoscopic Approach */
"0F154D3" = "1" /* Bypass Right Hepatic Duct to Duodenum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F154D4" = "1" /* Bypass Right Hepatic Duct to Stomach with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F154D5" = "1" /* Bypass Right Hepatic Duct to Right Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F154D6" = "1" /* Bypass Right Hepatic Duct to Left Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F154D7" = "1" /* Bypass Right Hepatic Duct to Caudate Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F154D8" = "1" /* Bypass Right Hepatic Duct to Cystic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F154D9" = "1" /* Bypass Right Hepatic Duct to Common Bile Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F154DB" = "1" /* Bypass Right Hepatic Duct to Small Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F154Z3" = "1" /* Bypass Right Hepatic Duct to Duodenum, Percutaneous Endoscopic Approach */
"0F154Z4" = "1" /* Bypass Right Hepatic Duct to Stomach, Percutaneous Endoscopic Approach */
"0F154Z5" = "1" /* Bypass Right Hepatic Duct to Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0F154Z6" = "1" /* Bypass Right Hepatic Duct to Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0F154Z7" = "1" /* Bypass Right Hepatic Duct to Caudate Hepatic Duct, Percutaneous Endoscopic Approach */
"0F154Z8" = "1" /* Bypass Right Hepatic Duct to Cystic Duct, Percutaneous Endoscopic Approach */
"0F154Z9" = "1" /* Bypass Right Hepatic Duct to Common Bile Duct, Percutaneous Endoscopic Approach */
"0F154ZB" = "1" /* Bypass Right Hepatic Duct to Small Intestine, Percutaneous Endoscopic Approach */
"0F164D3" = "1" /* Bypass Left Hepatic Duct to Duodenum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F164D4" = "1" /* Bypass Left Hepatic Duct to Stomach with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F164D5" = "1" /* Bypass Left Hepatic Duct to Right Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F164D6" = "1" /* Bypass Left Hepatic Duct to Left Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F164D7" = "1" /* Bypass Left Hepatic Duct to Caudate Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F164D8" = "1" /* Bypass Left Hepatic Duct to Cystic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F164D9" = "1" /* Bypass Left Hepatic Duct to Common Bile Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F164DB" = "1" /* Bypass Left Hepatic Duct to Small Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F164Z3" = "1" /* Bypass Left Hepatic Duct to Duodenum, Percutaneous Endoscopic Approach */
"0F164Z4" = "1" /* Bypass Left Hepatic Duct to Stomach, Percutaneous Endoscopic Approach */
"0F164Z5" = "1" /* Bypass Left Hepatic Duct to Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0F164Z6" = "1" /* Bypass Left Hepatic Duct to Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0F164Z7" = "1" /* Bypass Left Hepatic Duct to Caudate Hepatic Duct, Percutaneous Endoscopic Approach */
"0F164Z8" = "1" /* Bypass Left Hepatic Duct to Cystic Duct, Percutaneous Endoscopic Approach */
"0F164Z9" = "1" /* Bypass Left Hepatic Duct to Common Bile Duct, Percutaneous Endoscopic Approach */
"0F164ZB" = "1" /* Bypass Left Hepatic Duct to Small Intestine, Percutaneous Endoscopic Approach */
"0F184D3" = "1" /* Bypass Cystic Duct to Duodenum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F184D4" = "1" /* Bypass Cystic Duct to Stomach with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F184D5" = "1" /* Bypass Cystic Duct to Right Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F184D6" = "1" /* Bypass Cystic Duct to Left Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F184D7" = "1" /* Bypass Cystic Duct to Caudate Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F184D8" = "1" /* Bypass Cystic Duct to Cystic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F184D9" = "1" /* Bypass Cystic Duct to Common Bile Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F184DB" = "1" /* Bypass Cystic Duct to Small Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F184Z3" = "1" /* Bypass Cystic Duct to Duodenum, Percutaneous Endoscopic Approach */
"0F184Z4" = "1" /* Bypass Cystic Duct to Stomach, Percutaneous Endoscopic Approach */
"0F184Z5" = "1" /* Bypass Cystic Duct to Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0F184Z6" = "1" /* Bypass Cystic Duct to Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0F184Z7" = "1" /* Bypass Cystic Duct to Caudate Hepatic Duct, Percutaneous Endoscopic Approach */
"0F184Z8" = "1" /* Bypass Cystic Duct to Cystic Duct, Percutaneous Endoscopic Approach */
"0F184Z9" = "1" /* Bypass Cystic Duct to Common Bile Duct, Percutaneous Endoscopic Approach */
"0F184ZB" = "1" /* Bypass Cystic Duct to Small Intestine, Percutaneous Endoscopic Approach */
"0F194D3" = "1" /* Bypass Common Bile Duct to Duodenum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F194D4" = "1" /* Bypass Common Bile Duct to Stomach with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F194D5" = "1" /* Bypass Common Bile Duct to Right Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F194D6" = "1" /* Bypass Common Bile Duct to Left Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F194D7" = "1" /* Bypass Common Bile Duct to Caudate Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F194D8" = "1" /* Bypass Common Bile Duct to Cystic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F194D9" = "1" /* Bypass Common Bile Duct to Common Bile Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F194DB" = "1" /* Bypass Common Bile Duct to Small Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F194Z3" = "1" /* Bypass Common Bile Duct to Duodenum, Percutaneous Endoscopic Approach */
"0F194Z4" = "1" /* Bypass Common Bile Duct to Stomach, Percutaneous Endoscopic Approach */
"0F194Z5" = "1" /* Bypass Common Bile Duct to Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0F194Z6" = "1" /* Bypass Common Bile Duct to Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0F194Z7" = "1" /* Bypass Common Bile Duct to Caudate Hepatic Duct, Percutaneous Endoscopic Approach */
"0F194Z8" = "1" /* Bypass Common Bile Duct to Cystic Duct, Percutaneous Endoscopic Approach */
"0F194Z9" = "1" /* Bypass Common Bile Duct to Common Bile Duct, Percutaneous Endoscopic Approach */
"0F194ZB" = "1" /* Bypass Common Bile Duct to Small Intestine, Percutaneous Endoscopic Approach */
"0F1D4D3" = "1" /* Bypass Pancreatic Duct to Duodenum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F1D4DB" = "1" /* Bypass Pancreatic Duct to Small Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F1D4DC" = "1" /* Bypass Pancreatic Duct to Large Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F1D4Z3" = "1" /* Bypass Pancreatic Duct to Duodenum, Percutaneous Endoscopic Approach */
"0F1D4ZB" = "1" /* Bypass Pancreatic Duct to Small Intestine, Percutaneous Endoscopic Approach */
"0F1D4ZC" = "1" /* Bypass Pancreatic Duct to Large Intestine, Percutaneous Endoscopic Approach */
"0F1F4D3" = "1" /* Bypass Accessory Pancreatic Duct to Duodenum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F1F4DB" = "1" /* Bypass Accessory Pancreatic Duct to Small Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F1F4DC" = "1" /* Bypass Accessory Pancreatic Duct to Large Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F1F4Z3" = "1" /* Bypass Accessory Pancreatic Duct to Duodenum, Percutaneous Endoscopic Approach */
"0F1F4ZB" = "1" /* Bypass Accessory Pancreatic Duct to Small Intestine, Percutaneous Endoscopic Approach */
"0F1F4ZC" = "1" /* Bypass Accessory Pancreatic Duct to Large Intestine, Percutaneous Endoscopic Approach */
"0F1G4D3" = "1" /* Bypass Pancreas to Duodenum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F1G4DB" = "1" /* Bypass Pancreas to Small Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F1G4DC" = "1" /* Bypass Pancreas to Large Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F1G4Z3" = "1" /* Bypass Pancreas to Duodenum, Percutaneous Endoscopic Approach */
"0F1G4ZB" = "1" /* Bypass Pancreas to Small Intestine, Percutaneous Endoscopic Approach */
"0F1G4ZC" = "1" /* Bypass Pancreas to Large Intestine, Percutaneous Endoscopic Approach */
"0F503ZZ" = "1" /* Destruction of Liver, Percutaneous Approach */
"0F504ZZ" = "1" /* Destruction of Liver, Percutaneous Endoscopic Approach */
"0F513ZZ" = "1" /* Destruction of Right Lobe Liver, Percutaneous Approach */
"0F514ZZ" = "1" /* Destruction of Right Lobe Liver, Percutaneous Endoscopic Approach */
"0F523ZZ" = "1" /* Destruction of Left Lobe Liver, Percutaneous Approach */
"0F524ZZ" = "1" /* Destruction of Left Lobe Liver, Percutaneous Endoscopic Approach */
"0F543ZZ" = "1" /* Destruction of Gallbladder, Percutaneous Approach */
"0F544ZZ" = "1" /* Destruction of Gallbladder, Percutaneous Endoscopic Approach */
"0F553ZZ" = "1" /* Destruction of Right Hepatic Duct, Percutaneous Approach */
"0F554ZZ" = "1" /* Destruction of Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0F563ZZ" = "1" /* Destruction of Left Hepatic Duct, Percutaneous Approach */
"0F564ZZ" = "1" /* Destruction of Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0F583ZZ" = "1" /* Destruction of Cystic Duct, Percutaneous Approach */
"0F584ZZ" = "1" /* Destruction of Cystic Duct, Percutaneous Endoscopic Approach */
"0F593ZZ" = "1" /* Destruction of Common Bile Duct, Percutaneous Approach */
"0F594ZZ" = "1" /* Destruction of Common Bile Duct, Percutaneous Endoscopic Approach */
"0F5C3ZZ" = "1" /* Destruction of Ampulla of Vater, Percutaneous Approach */
"0F5C4ZZ" = "1" /* Destruction of Ampulla of Vater, Percutaneous Endoscopic Approach */
"0F5D3ZZ" = "1" /* Destruction of Pancreatic Duct, Percutaneous Approach */
"0F5D4ZZ" = "1" /* Destruction of Pancreatic Duct, Percutaneous Endoscopic Approach */
"0F5F3ZZ" = "1" /* Destruction of Accessory Pancreatic Duct, Percutaneous Approach */
"0F5F4ZZ" = "1" /* Destruction of Accessory Pancreatic Duct, Percutaneous Endoscopic Approach */
"0F5G3ZZ" = "1" /* Destruction of Pancreas, Percutaneous Approach */
"0F5G4ZZ" = "1" /* Destruction of Pancreas, Percutaneous Endoscopic Approach */
"0F753DZ" = "1" /* Dilation of Right Hepatic Duct with Intraluminal Device, Percutaneous Approach */
"0F753ZZ" = "1" /* Dilation of Right Hepatic Duct, Percutaneous Approach */
"0F754DZ" = "1" /* Dilation of Right Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F754ZZ" = "1" /* Dilation of Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0F763DZ" = "1" /* Dilation of Left Hepatic Duct with Intraluminal Device, Percutaneous Approach */
"0F763ZZ" = "1" /* Dilation of Left Hepatic Duct, Percutaneous Approach */
"0F764DZ" = "1" /* Dilation of Left Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F764ZZ" = "1" /* Dilation of Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0F783DZ" = "1" /* Dilation of Cystic Duct with Intraluminal Device, Percutaneous Approach */
"0F783ZZ" = "1" /* Dilation of Cystic Duct, Percutaneous Approach */
"0F784DZ" = "1" /* Dilation of Cystic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F784ZZ" = "1" /* Dilation of Cystic Duct, Percutaneous Endoscopic Approach */
"0F793DZ" = "1" /* Dilation of Common Bile Duct with Intraluminal Device, Percutaneous Approach */
"0F793ZZ" = "1" /* Dilation of Common Bile Duct, Percutaneous Approach */
"0F794DZ" = "1" /* Dilation of Common Bile Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F794ZZ" = "1" /* Dilation of Common Bile Duct, Percutaneous Endoscopic Approach */
"0F7C3DZ" = "1" /* Dilation of Ampulla of Vater with Intraluminal Device, Percutaneous Approach */
"0F7C3ZZ" = "1" /* Dilation of Ampulla of Vater, Percutaneous Approach */
"0F7C4DZ" = "1" /* Dilation of Ampulla of Vater with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F7C4ZZ" = "1" /* Dilation of Ampulla of Vater, Percutaneous Endoscopic Approach */
"0F7D3DZ" = "1" /* Dilation of Pancreatic Duct with Intraluminal Device, Percutaneous Approach */
"0F7D3ZZ" = "1" /* Dilation of Pancreatic Duct, Percutaneous Approach */
"0F7D4DZ" = "1" /* Dilation of Pancreatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F7D4ZZ" = "1" /* Dilation of Pancreatic Duct, Percutaneous Endoscopic Approach */
"0F7F3DZ" = "1" /* Dilation of Accessory Pancreatic Duct with Intraluminal Device, Percutaneous Approach */
"0F7F3ZZ" = "1" /* Dilation of Accessory Pancreatic Duct, Percutaneous Approach */
"0F7F4DZ" = "1" /* Dilation of Accessory Pancreatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F7F4ZZ" = "1" /* Dilation of Accessory Pancreatic Duct, Percutaneous Endoscopic Approach */
"0F8G3ZZ" = "1" /* Division of Pancreas, Percutaneous Approach */
"0F8G4ZZ" = "1" /* Division of Pancreas, Percutaneous Endoscopic Approach */
"0F9030Z" = "1" /* Drainage of Liver with Drainage Device, Percutaneous Approach */
"0F903ZX" = "1" /* Drainage of Liver, Percutaneous Approach, Diagnostic */
"0F903ZZ" = "1" /* Drainage of Liver, Percutaneous Approach */
"0F9040Z" = "1" /* Drainage of Liver with Drainage Device, Percutaneous Endoscopic Approach */
"0F904ZX" = "1" /* Drainage of Liver, Percutaneous Endoscopic Approach, Diagnostic */
"0F904ZZ" = "1" /* Drainage of Liver, Percutaneous Endoscopic Approach */
"0F9130Z" = "1" /* Drainage of Right Lobe Liver with Drainage Device, Percutaneous Approach */
"0F913ZX" = "1" /* Drainage of Right Lobe Liver, Percutaneous Approach, Diagnostic */
"0F913ZZ" = "1" /* Drainage of Right Lobe Liver, Percutaneous Approach */
"0F9140Z" = "1" /* Drainage of Right Lobe Liver with Drainage Device, Percutaneous Endoscopic Approach */
"0F914ZX" = "1" /* Drainage of Right Lobe Liver, Percutaneous Endoscopic Approach, Diagnostic */
"0F914ZZ" = "1" /* Drainage of Right Lobe Liver, Percutaneous Endoscopic Approach */
"0F9230Z" = "1" /* Drainage of Left Lobe Liver with Drainage Device, Percutaneous Approach */
"0F923ZX" = "1" /* Drainage of Left Lobe Liver, Percutaneous Approach, Diagnostic */
"0F923ZZ" = "1" /* Drainage of Left Lobe Liver, Percutaneous Approach */
"0F9240Z" = "1" /* Drainage of Left Lobe Liver with Drainage Device, Percutaneous Endoscopic Approach */
"0F924ZX" = "1" /* Drainage of Left Lobe Liver, Percutaneous Endoscopic Approach, Diagnostic */
"0F924ZZ" = "1" /* Drainage of Left Lobe Liver, Percutaneous Endoscopic Approach */
"0F9430Z" = "1" /* Drainage of Gallbladder with Drainage Device, Percutaneous Approach */
"0F943ZX" = "1" /* Drainage of Gallbladder, Percutaneous Approach, Diagnostic */
"0F943ZZ" = "1" /* Drainage of Gallbladder, Percutaneous Approach */
"0F9440Z" = "1" /* Drainage of Gallbladder with Drainage Device, Percutaneous Endoscopic Approach */
"0F944ZX" = "1" /* Drainage of Gallbladder, Percutaneous Endoscopic Approach, Diagnostic */
"0F944ZZ" = "1" /* Drainage of Gallbladder, Percutaneous Endoscopic Approach */
"0F9530Z" = "1" /* Drainage of Right Hepatic Duct with Drainage Device, Percutaneous Approach */
"0F953ZX" = "1" /* Drainage of Right Hepatic Duct, Percutaneous Approach, Diagnostic */
"0F953ZZ" = "1" /* Drainage of Right Hepatic Duct, Percutaneous Approach */
"0F9540Z" = "1" /* Drainage of Right Hepatic Duct with Drainage Device, Percutaneous Endoscopic Approach */
"0F954ZX" = "1" /* Drainage of Right Hepatic Duct, Percutaneous Endoscopic Approach, Diagnostic */
"0F954ZZ" = "1" /* Drainage of Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0F9630Z" = "1" /* Drainage of Left Hepatic Duct with Drainage Device, Percutaneous Approach */
"0F963ZX" = "1" /* Drainage of Left Hepatic Duct, Percutaneous Approach, Diagnostic */
"0F963ZZ" = "1" /* Drainage of Left Hepatic Duct, Percutaneous Approach */
"0F9640Z" = "1" /* Drainage of Left Hepatic Duct with Drainage Device, Percutaneous Endoscopic Approach */
"0F964ZX" = "1" /* Drainage of Left Hepatic Duct, Percutaneous Endoscopic Approach, Diagnostic */
"0F964ZZ" = "1" /* Drainage of Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0F9830Z" = "1" /* Drainage of Cystic Duct with Drainage Device, Percutaneous Approach */
"0F983ZX" = "1" /* Drainage of Cystic Duct, Percutaneous Approach, Diagnostic */
"0F983ZZ" = "1" /* Drainage of Cystic Duct, Percutaneous Approach */
"0F9840Z" = "1" /* Drainage of Cystic Duct with Drainage Device, Percutaneous Endoscopic Approach */
"0F984ZX" = "1" /* Drainage of Cystic Duct, Percutaneous Endoscopic Approach, Diagnostic */
"0F984ZZ" = "1" /* Drainage of Cystic Duct, Percutaneous Endoscopic Approach */
"0F9930Z" = "1" /* Drainage of Common Bile Duct with Drainage Device, Percutaneous Approach */
"0F993ZX" = "1" /* Drainage of Common Bile Duct, Percutaneous Approach, Diagnostic */
"0F993ZZ" = "1" /* Drainage of Common Bile Duct, Percutaneous Approach */
"0F9940Z" = "1" /* Drainage of Common Bile Duct with Drainage Device, Percutaneous Endoscopic Approach */
"0F994ZX" = "1" /* Drainage of Common Bile Duct, Percutaneous Endoscopic Approach, Diagnostic */
"0F994ZZ" = "1" /* Drainage of Common Bile Duct, Percutaneous Endoscopic Approach */
"0F9C30Z" = "1" /* Drainage of Ampulla of Vater with Drainage Device, Percutaneous Approach */
"0F9C3ZX" = "1" /* Drainage of Ampulla of Vater, Percutaneous Approach, Diagnostic */
"0F9C3ZZ" = "1" /* Drainage of Ampulla of Vater, Percutaneous Approach */
"0F9C40Z" = "1" /* Drainage of Ampulla of Vater with Drainage Device, Percutaneous Endoscopic Approach */
"0F9C4ZX" = "1" /* Drainage of Ampulla of Vater, Percutaneous Endoscopic Approach, Diagnostic */
"0F9C4ZZ" = "1" /* Drainage of Ampulla of Vater, Percutaneous Endoscopic Approach */
"0F9D30Z" = "1" /* Drainage of Pancreatic Duct with Drainage Device, Percutaneous Approach */
"0F9D3ZX" = "1" /* Drainage of Pancreatic Duct, Percutaneous Approach, Diagnostic */
"0F9D3ZZ" = "1" /* Drainage of Pancreatic Duct, Percutaneous Approach */
"0F9D40Z" = "1" /* Drainage of Pancreatic Duct with Drainage Device, Percutaneous Endoscopic Approach */
"0F9D4ZX" = "1" /* Drainage of Pancreatic Duct, Percutaneous Endoscopic Approach, Diagnostic */
"0F9D4ZZ" = "1" /* Drainage of Pancreatic Duct, Percutaneous Endoscopic Approach */
"0F9F30Z" = "1" /* Drainage of Accessory Pancreatic Duct with Drainage Device, Percutaneous Approach */
"0F9F3ZX" = "1" /* Drainage of Accessory Pancreatic Duct, Percutaneous Approach, Diagnostic */
"0F9F3ZZ" = "1" /* Drainage of Accessory Pancreatic Duct, Percutaneous Approach */
"0F9F40Z" = "1" /* Drainage of Accessory Pancreatic Duct with Drainage Device, Percutaneous Endoscopic Approach */
"0F9F4ZX" = "1" /* Drainage of Accessory Pancreatic Duct, Percutaneous Endoscopic Approach, Diagnostic */
"0F9F4ZZ" = "1" /* Drainage of Accessory Pancreatic Duct, Percutaneous Endoscopic Approach */
"0F9G30Z" = "1" /* Drainage of Pancreas with Drainage Device, Percutaneous Approach */
"0F9G3ZX" = "1" /* Drainage of Pancreas, Percutaneous Approach, Diagnostic */
"0F9G3ZZ" = "1" /* Drainage of Pancreas, Percutaneous Approach */
"0F9G40Z" = "1" /* Drainage of Pancreas with Drainage Device, Percutaneous Endoscopic Approach */
"0F9G4ZX" = "1" /* Drainage of Pancreas, Percutaneous Endoscopic Approach, Diagnostic */
"0F9G4ZZ" = "1" /* Drainage of Pancreas, Percutaneous Endoscopic Approach */
"0FB03ZX" = "1" /* Excision of Liver, Percutaneous Approach, Diagnostic */
"0FB03ZZ" = "1" /* Excision of Liver, Percutaneous Approach */
"0FB04ZX" = "1" /* Excision of Liver, Percutaneous Endoscopic Approach, Diagnostic */
"0FB04ZZ" = "1" /* Excision of Liver, Percutaneous Endoscopic Approach */
"0FB13ZX" = "1" /* Excision of Right Lobe Liver, Percutaneous Approach, Diagnostic */
"0FB13ZZ" = "1" /* Excision of Right Lobe Liver, Percutaneous Approach */
"0FB14ZX" = "1" /* Excision of Right Lobe Liver, Percutaneous Endoscopic Approach, Diagnostic */
"0FB14ZZ" = "1" /* Excision of Right Lobe Liver, Percutaneous Endoscopic Approach */
"0FB23ZX" = "1" /* Excision of Left Lobe Liver, Percutaneous Approach, Diagnostic */
"0FB23ZZ" = "1" /* Excision of Left Lobe Liver, Percutaneous Approach */
"0FB24ZX" = "1" /* Excision of Left Lobe Liver, Percutaneous Endoscopic Approach, Diagnostic */
"0FB24ZZ" = "1" /* Excision of Left Lobe Liver, Percutaneous Endoscopic Approach */
"0FB43ZX" = "1" /* Excision of Gallbladder, Percutaneous Approach, Diagnostic */
"0FB43ZZ" = "1" /* Excision of Gallbladder, Percutaneous Approach */
"0FB44ZX" = "1" /* Excision of Gallbladder, Percutaneous Endoscopic Approach, Diagnostic */
"0FB44ZZ" = "1" /* Excision of Gallbladder, Percutaneous Endoscopic Approach */
"0FB53ZX" = "1" /* Excision of Right Hepatic Duct, Percutaneous Approach, Diagnostic */
"0FB53ZZ" = "1" /* Excision of Right Hepatic Duct, Percutaneous Approach */
"0FB54ZX" = "1" /* Excision of Right Hepatic Duct, Percutaneous Endoscopic Approach, Diagnostic */
"0FB54ZZ" = "1" /* Excision of Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0FB63ZX" = "1" /* Excision of Left Hepatic Duct, Percutaneous Approach, Diagnostic */
"0FB63ZZ" = "1" /* Excision of Left Hepatic Duct, Percutaneous Approach */
"0FB64ZX" = "1" /* Excision of Left Hepatic Duct, Percutaneous Endoscopic Approach, Diagnostic */
"0FB64ZZ" = "1" /* Excision of Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0FB83ZX" = "1" /* Excision of Cystic Duct, Percutaneous Approach, Diagnostic */
"0FB83ZZ" = "1" /* Excision of Cystic Duct, Percutaneous Approach */
"0FB84ZX" = "1" /* Excision of Cystic Duct, Percutaneous Endoscopic Approach, Diagnostic */
"0FB84ZZ" = "1" /* Excision of Cystic Duct, Percutaneous Endoscopic Approach */
"0FB93ZX" = "1" /* Excision of Common Bile Duct, Percutaneous Approach, Diagnostic */
"0FB93ZZ" = "1" /* Excision of Common Bile Duct, Percutaneous Approach */
"0FB94ZX" = "1" /* Excision of Common Bile Duct, Percutaneous Endoscopic Approach, Diagnostic */
"0FB94ZZ" = "1" /* Excision of Common Bile Duct, Percutaneous Endoscopic Approach */
"0FBC3ZX" = "1" /* Excision of Ampulla of Vater, Percutaneous Approach, Diagnostic */
"0FBC3ZZ" = "1" /* Excision of Ampulla of Vater, Percutaneous Approach */
"0FBC4ZX" = "1" /* Excision of Ampulla of Vater, Percutaneous Endoscopic Approach, Diagnostic */
"0FBC4ZZ" = "1" /* Excision of Ampulla of Vater, Percutaneous Endoscopic Approach */
"0FBD3ZX" = "1" /* Excision of Pancreatic Duct, Percutaneous Approach, Diagnostic */
"0FBD3ZZ" = "1" /* Excision of Pancreatic Duct, Percutaneous Approach */
"0FBD4ZX" = "1" /* Excision of Pancreatic Duct, Percutaneous Endoscopic Approach, Diagnostic */
"0FBD4ZZ" = "1" /* Excision of Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FBF3ZX" = "1" /* Excision of Accessory Pancreatic Duct, Percutaneous Approach, Diagnostic */
"0FBF3ZZ" = "1" /* Excision of Accessory Pancreatic Duct, Percutaneous Approach */
"0FBF4ZX" = "1" /* Excision of Accessory Pancreatic Duct, Percutaneous Endoscopic Approach, Diagnostic */
"0FBF4ZZ" = "1" /* Excision of Accessory Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FBG3ZX" = "1" /* Excision of Pancreas, Percutaneous Approach, Diagnostic */
"0FBG3ZZ" = "1" /* Excision of Pancreas, Percutaneous Approach */
"0FBG4ZX" = "1" /* Excision of Pancreas, Percutaneous Endoscopic Approach, Diagnostic */
"0FBG4ZZ" = "1" /* Excision of Pancreas, Percutaneous Endoscopic Approach */
"0FC03ZZ" = "1" /* Extirpation of Matter from Liver, Percutaneous Approach */
"0FC04ZZ" = "1" /* Extirpation of Matter from Liver, Percutaneous Endoscopic Approach */
"0FC13ZZ" = "1" /* Extirpation of Matter from Right Lobe Liver, Percutaneous Approach */
"0FC14ZZ" = "1" /* Extirpation of Matter from Right Lobe Liver, Percutaneous Endoscopic Approach */
"0FC23ZZ" = "1" /* Extirpation of Matter from Left Lobe Liver, Percutaneous Approach */
"0FC24ZZ" = "1" /* Extirpation of Matter from Left Lobe Liver, Percutaneous Endoscopic Approach */
"0FC43ZZ" = "1" /* Extirpation of Matter from Gallbladder, Percutaneous Approach */
"0FC44ZZ" = "1" /* Extirpation of Matter from Gallbladder, Percutaneous Endoscopic Approach */
"0FC53ZZ" = "1" /* Extirpation of Matter from Right Hepatic Duct, Percutaneous Approach */
"0FC54ZZ" = "1" /* Extirpation of Matter from Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0FC63ZZ" = "1" /* Extirpation of Matter from Left Hepatic Duct, Percutaneous Approach */
"0FC64ZZ" = "1" /* Extirpation of Matter from Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0FC83ZZ" = "1" /* Extirpation of Matter from Cystic Duct, Percutaneous Approach */
"0FC84ZZ" = "1" /* Extirpation of Matter from Cystic Duct, Percutaneous Endoscopic Approach */
"0FC93ZZ" = "1" /* Extirpation of Matter from Common Bile Duct, Percutaneous Approach */
"0FC94ZZ" = "1" /* Extirpation of Matter from Common Bile Duct, Percutaneous Endoscopic Approach */
"0FCC3ZZ" = "1" /* Extirpation of Matter from Ampulla of Vater, Percutaneous Approach */
"0FCC4ZZ" = "1" /* Extirpation of Matter from Ampulla of Vater, Percutaneous Endoscopic Approach */
"0FCD3ZZ" = "1" /* Extirpation of Matter from Pancreatic Duct, Percutaneous Approach */
"0FCD4ZZ" = "1" /* Extirpation of Matter from Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FCF3ZZ" = "1" /* Extirpation of Matter from Accessory Pancreatic Duct, Percutaneous Approach */
"0FCF4ZZ" = "1" /* Extirpation of Matter from Accessory Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FCG3ZZ" = "1" /* Extirpation of Matter from Pancreas, Percutaneous Approach */
"0FCG4ZZ" = "1" /* Extirpation of Matter from Pancreas, Percutaneous Endoscopic Approach */
"0FF43ZZ" = "1" /* Fragmentation in Gallbladder, Percutaneous Approach */
"0FF44ZZ" = "1" /* Fragmentation in Gallbladder, Percutaneous Endoscopic Approach */
"0FF53ZZ" = "1" /* Fragmentation in Right Hepatic Duct, Percutaneous Approach */
"0FF54ZZ" = "1" /* Fragmentation in Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0FF63ZZ" = "1" /* Fragmentation in Left Hepatic Duct, Percutaneous Approach */
"0FF64ZZ" = "1" /* Fragmentation in Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0FF83ZZ" = "1" /* Fragmentation in Cystic Duct, Percutaneous Approach */
"0FF84ZZ" = "1" /* Fragmentation in Cystic Duct, Percutaneous Endoscopic Approach */
"0FF93ZZ" = "1" /* Fragmentation in Common Bile Duct, Percutaneous Approach */
"0FF94ZZ" = "1" /* Fragmentation in Common Bile Duct, Percutaneous Endoscopic Approach */
"0FFC3ZZ" = "1" /* Fragmentation in Ampulla of Vater, Percutaneous Approach */
"0FFC4ZZ" = "1" /* Fragmentation in Ampulla of Vater, Percutaneous Endoscopic Approach */
"0FFD3ZZ" = "1" /* Fragmentation in Pancreatic Duct, Percutaneous Approach */
"0FFD4ZZ" = "1" /* Fragmentation in Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FFF3ZZ" = "1" /* Fragmentation in Accessory Pancreatic Duct, Percutaneous Approach */
"0FFF4ZZ" = "1" /* Fragmentation in Accessory Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FH032Z" = "1" /* Insertion of Monitoring Device into Liver, Percutaneous Approach */
"0FH033Z" = "1" /* Insertion of Infusion Device into Liver, Percutaneous Approach */
"0FH042Z" = "1" /* Insertion of Monitoring Device into Liver, Percutaneous Endoscopic Approach */
"0FH043Z" = "1" /* Insertion of Infusion Device into Liver, Percutaneous Endoscopic Approach */
"0FH132Z" = "1" /* Insertion of Monitoring Device into Right Lobe Liver, Percutaneous Approach */
"0FH133Z" = "1" /* Insertion of Infusion Device into Right Lobe Liver, Percutaneous Approach */
"0FH142Z" = "1" /* Insertion of Monitoring Device into Right Lobe Liver, Percutaneous Endoscopic Approach */
"0FH143Z" = "1" /* Insertion of Infusion Device into Right Lobe Liver, Percutaneous Endoscopic Approach */
"0FH232Z" = "1" /* Insertion of Monitoring Device into Left Lobe Liver, Percutaneous Approach */
"0FH233Z" = "1" /* Insertion of Infusion Device into Left Lobe Liver, Percutaneous Approach */
"0FH242Z" = "1" /* Insertion of Monitoring Device into Left Lobe Liver, Percutaneous Endoscopic Approach */
"0FH243Z" = "1" /* Insertion of Infusion Device into Left Lobe Liver, Percutaneous Endoscopic Approach */
"0FH432Z" = "1" /* Insertion of Monitoring Device into Gallbladder, Percutaneous Approach */
"0FH433Z" = "1" /* Insertion of Infusion Device into Gallbladder, Percutaneous Approach */
"0FH442Z" = "1" /* Insertion of Monitoring Device into Gallbladder, Percutaneous Endoscopic Approach */
"0FH443Z" = "1" /* Insertion of Infusion Device into Gallbladder, Percutaneous Endoscopic Approach */
"0FHB31Z" = "1" /* Insertion of Radioactive Element into Hepatobiliary Duct, Percutaneous Approach */
"0FHB32Z" = "1" /* Insertion of Monitoring Device into Hepatobiliary Duct, Percutaneous Approach */
"0FHB33Z" = "1" /* Insertion of Infusion Device into Hepatobiliary Duct, Percutaneous Approach */
"0FHB3DZ" = "1" /* Insertion of Intraluminal Device into Hepatobiliary Duct, Percutaneous Approach */
"0FHB41Z" = "1" /* Insertion of Radioactive Element into Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FHB42Z" = "1" /* Insertion of Monitoring Device into Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FHB43Z" = "1" /* Insertion of Infusion Device into Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FHB4DZ" = "1" /* Insertion of Intraluminal Device into Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FHD31Z" = "1" /* Insertion of Radioactive Element into Pancreatic Duct, Percutaneous Approach */
"0FHD32Z" = "1" /* Insertion of Monitoring Device into Pancreatic Duct, Percutaneous Approach */
"0FHD33Z" = "1" /* Insertion of Infusion Device into Pancreatic Duct, Percutaneous Approach */
"0FHD3DZ" = "1" /* Insertion of Intraluminal Device into Pancreatic Duct, Percutaneous Approach */
"0FHD41Z" = "1" /* Insertion of Radioactive Element into Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FHD42Z" = "1" /* Insertion of Monitoring Device into Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FHD43Z" = "1" /* Insertion of Infusion Device into Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FHD4DZ" = "1" /* Insertion of Intraluminal Device into Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FHG32Z" = "1" /* Insertion of Monitoring Device into Pancreas, Percutaneous Approach */
"0FHG33Z" = "1" /* Insertion of Infusion Device into Pancreas, Percutaneous Approach */
"0FHG42Z" = "1" /* Insertion of Monitoring Device into Pancreas, Percutaneous Endoscopic Approach */
"0FHG43Z" = "1" /* Insertion of Infusion Device into Pancreas, Percutaneous Endoscopic Approach */
"0FJ03ZZ" = "1" /* Inspection of Liver, Percutaneous Approach */
"0FJ04ZZ" = "1" /* Inspection of Liver, Percutaneous Endoscopic Approach */
"0FJ43ZZ" = "1" /* Inspection of Gallbladder, Percutaneous Approach */
"0FJ44ZZ" = "1" /* Inspection of Gallbladder, Percutaneous Endoscopic Approach */
"0FJB3ZZ" = "1" /* Inspection of Hepatobiliary Duct, Percutaneous Approach */
"0FJB4ZZ" = "1" /* Inspection of Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FJD3ZZ" = "1" /* Inspection of Pancreatic Duct, Percutaneous Approach */
"0FJD4ZZ" = "1" /* Inspection of Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FJG3ZZ" = "1" /* Inspection of Pancreas, Percutaneous Approach */
"0FJG4ZZ" = "1" /* Inspection of Pancreas, Percutaneous Endoscopic Approach */
"0FL53CZ" = "1" /* Occlusion of Right Hepatic Duct with Extraluminal Device, Percutaneous Approach */
"0FL53DZ" = "1" /* Occlusion of Right Hepatic Duct with Intraluminal Device, Percutaneous Approach */
"0FL53ZZ" = "1" /* Occlusion of Right Hepatic Duct, Percutaneous Approach */
"0FL54CZ" = "1" /* Occlusion of Right Hepatic Duct with Extraluminal Device, Percutaneous Endoscopic Approach */
"0FL54DZ" = "1" /* Occlusion of Right Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0FL54ZZ" = "1" /* Occlusion of Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0FL63CZ" = "1" /* Occlusion of Left Hepatic Duct with Extraluminal Device, Percutaneous Approach */
"0FL63DZ" = "1" /* Occlusion of Left Hepatic Duct with Intraluminal Device, Percutaneous Approach */
"0FL63ZZ" = "1" /* Occlusion of Left Hepatic Duct, Percutaneous Approach */
"0FL64CZ" = "1" /* Occlusion of Left Hepatic Duct with Extraluminal Device, Percutaneous Endoscopic Approach */
"0FL64DZ" = "1" /* Occlusion of Left Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0FL64ZZ" = "1" /* Occlusion of Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0FL83CZ" = "1" /* Occlusion of Cystic Duct with Extraluminal Device, Percutaneous Approach */
"0FL83DZ" = "1" /* Occlusion of Cystic Duct with Intraluminal Device, Percutaneous Approach */
"0FL83ZZ" = "1" /* Occlusion of Cystic Duct, Percutaneous Approach */
"0FL84CZ" = "1" /* Occlusion of Cystic Duct with Extraluminal Device, Percutaneous Endoscopic Approach */
"0FL84DZ" = "1" /* Occlusion of Cystic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0FL84ZZ" = "1" /* Occlusion of Cystic Duct, Percutaneous Endoscopic Approach */
"0FL93CZ" = "1" /* Occlusion of Common Bile Duct with Extraluminal Device, Percutaneous Approach */
"0FL93DZ" = "1" /* Occlusion of Common Bile Duct with Intraluminal Device, Percutaneous Approach */
"0FL93ZZ" = "1" /* Occlusion of Common Bile Duct, Percutaneous Approach */
"0FL94CZ" = "1" /* Occlusion of Common Bile Duct with Extraluminal Device, Percutaneous Endoscopic Approach */
"0FL94DZ" = "1" /* Occlusion of Common Bile Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0FL94ZZ" = "1" /* Occlusion of Common Bile Duct, Percutaneous Endoscopic Approach */
"0FLC3CZ" = "1" /* Occlusion of Ampulla of Vater with Extraluminal Device, Percutaneous Approach */
"0FLC3DZ" = "1" /* Occlusion of Ampulla of Vater with Intraluminal Device, Percutaneous Approach */
"0FLC3ZZ" = "1" /* Occlusion of Ampulla of Vater, Percutaneous Approach */
"0FLC4CZ" = "1" /* Occlusion of Ampulla of Vater with Extraluminal Device, Percutaneous Endoscopic Approach */
"0FLC4DZ" = "1" /* Occlusion of Ampulla of Vater with Intraluminal Device, Percutaneous Endoscopic Approach */
"0FLC4ZZ" = "1" /* Occlusion of Ampulla of Vater, Percutaneous Endoscopic Approach */
"0FLD3CZ" = "1" /* Occlusion of Pancreatic Duct with Extraluminal Device, Percutaneous Approach */
"0FLD3DZ" = "1" /* Occlusion of Pancreatic Duct with Intraluminal Device, Percutaneous Approach */
"0FLD3ZZ" = "1" /* Occlusion of Pancreatic Duct, Percutaneous Approach */
"0FLD4CZ" = "1" /* Occlusion of Pancreatic Duct with Extraluminal Device, Percutaneous Endoscopic Approach */
"0FLD4DZ" = "1" /* Occlusion of Pancreatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0FLD4ZZ" = "1" /* Occlusion of Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FLF3CZ" = "1" /* Occlusion of Accessory Pancreatic Duct with Extraluminal Device, Percutaneous Approach */
"0FLF3DZ" = "1" /* Occlusion of Accessory Pancreatic Duct with Intraluminal Device, Percutaneous Approach */
"0FLF3ZZ" = "1" /* Occlusion of Accessory Pancreatic Duct, Percutaneous Approach */
"0FLF4CZ" = "1" /* Occlusion of Accessory Pancreatic Duct with Extraluminal Device, Percutaneous Endoscopic Approach */
"0FLF4DZ" = "1" /* Occlusion of Accessory Pancreatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0FLF4ZZ" = "1" /* Occlusion of Accessory Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FM04ZZ" = "1" /* Reattachment of Liver, Percutaneous Endoscopic Approach */
"0FM14ZZ" = "1" /* Reattachment of Right Lobe Liver, Percutaneous Endoscopic Approach */
"0FM24ZZ" = "1" /* Reattachment of Left Lobe Liver, Percutaneous Endoscopic Approach */
"0FM44ZZ" = "1" /* Reattachment of Gallbladder, Percutaneous Endoscopic Approach */
"0FM54ZZ" = "1" /* Reattachment of Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0FM64ZZ" = "1" /* Reattachment of Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0FM84ZZ" = "1" /* Reattachment of Cystic Duct, Percutaneous Endoscopic Approach */
"0FM94ZZ" = "1" /* Reattachment of Common Bile Duct, Percutaneous Endoscopic Approach */
"0FMC4ZZ" = "1" /* Reattachment of Ampulla of Vater, Percutaneous Endoscopic Approach */
"0FMD4ZZ" = "1" /* Reattachment of Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FMF4ZZ" = "1" /* Reattachment of Accessory Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FMG4ZZ" = "1" /* Reattachment of Pancreas, Percutaneous Endoscopic Approach */
"0FN03ZZ" = "1" /* Release Liver, Percutaneous Approach */
"0FN04ZZ" = "1" /* Release Liver, Percutaneous Endoscopic Approach */
"0FN13ZZ" = "1" /* Release Right Lobe Liver, Percutaneous Approach */
"0FN14ZZ" = "1" /* Release Right Lobe Liver, Percutaneous Endoscopic Approach */
"0FN23ZZ" = "1" /* Release Left Lobe Liver, Percutaneous Approach */
"0FN24ZZ" = "1" /* Release Left Lobe Liver, Percutaneous Endoscopic Approach */
"0FN43ZZ" = "1" /* Release Gallbladder, Percutaneous Approach */
"0FN44ZZ" = "1" /* Release Gallbladder, Percutaneous Endoscopic Approach */
"0FN53ZZ" = "1" /* Release Right Hepatic Duct, Percutaneous Approach */
"0FN54ZZ" = "1" /* Release Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0FN63ZZ" = "1" /* Release Left Hepatic Duct, Percutaneous Approach */
"0FN64ZZ" = "1" /* Release Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0FN83ZZ" = "1" /* Release Cystic Duct, Percutaneous Approach */
"0FN84ZZ" = "1" /* Release Cystic Duct, Percutaneous Endoscopic Approach */
"0FN93ZZ" = "1" /* Release Common Bile Duct, Percutaneous Approach */
"0FN94ZZ" = "1" /* Release Common Bile Duct, Percutaneous Endoscopic Approach */
"0FNC3ZZ" = "1" /* Release Ampulla of Vater, Percutaneous Approach */
"0FNC4ZZ" = "1" /* Release Ampulla of Vater, Percutaneous Endoscopic Approach */
"0FND3ZZ" = "1" /* Release Pancreatic Duct, Percutaneous Approach */
"0FND4ZZ" = "1" /* Release Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FNF3ZZ" = "1" /* Release Accessory Pancreatic Duct, Percutaneous Approach */
"0FNF4ZZ" = "1" /* Release Accessory Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FNG3ZZ" = "1" /* Release Pancreas, Percutaneous Approach */
"0FNG4ZZ" = "1" /* Release Pancreas, Percutaneous Endoscopic Approach */
"0FP030Z" = "1" /* Removal of Drainage Device from Liver, Percutaneous Approach */
"0FP032Z" = "1" /* Removal of Monitoring Device from Liver, Percutaneous Approach */
"0FP033Z" = "1" /* Removal of Infusion Device from Liver, Percutaneous Approach */
"0FP040Z" = "1" /* Removal of Drainage Device from Liver, Percutaneous Endoscopic Approach */
"0FP042Z" = "1" /* Removal of Monitoring Device from Liver, Percutaneous Endoscopic Approach */
"0FP043Z" = "1" /* Removal of Infusion Device from Liver, Percutaneous Endoscopic Approach */
"0FP430Z" = "1" /* Removal of Drainage Device from Gallbladder, Percutaneous Approach */
"0FP432Z" = "1" /* Removal of Monitoring Device from Gallbladder, Percutaneous Approach */
"0FP433Z" = "1" /* Removal of Infusion Device from Gallbladder, Percutaneous Approach */
"0FP43DZ" = "1" /* Removal of Intraluminal Device from Gallbladder, Percutaneous Approach */
"0FP440Z" = "1" /* Removal of Drainage Device from Gallbladder, Percutaneous Endoscopic Approach */
"0FP442Z" = "1" /* Removal of Monitoring Device from Gallbladder, Percutaneous Endoscopic Approach */
"0FP443Z" = "1" /* Removal of Infusion Device from Gallbladder, Percutaneous Endoscopic Approach */
"0FP44DZ" = "1" /* Removal of Intraluminal Device from Gallbladder, Percutaneous Endoscopic Approach */
"0FPB30Z" = "1" /* Removal of Drainage Device from Hepatobiliary Duct, Percutaneous Approach */
"0FPB31Z" = "1" /* Removal of Radioactive Element from Hepatobiliary Duct, Percutaneous Approach */
"0FPB32Z" = "1" /* Removal of Monitoring Device from Hepatobiliary Duct, Percutaneous Approach */
"0FPB33Z" = "1" /* Removal of Infusion Device from Hepatobiliary Duct, Percutaneous Approach */
"0FPB37Z" = "1" /* Removal of Autologous Tissue Substitute from Hepatobiliary Duct, Percutaneous Approach */
"0FPB3CZ" = "1" /* Removal of Extraluminal Device from Hepatobiliary Duct, Percutaneous Approach */
"0FPB3DZ" = "1" /* Removal of Intraluminal Device from Hepatobiliary Duct, Percutaneous Approach */
"0FPB3JZ" = "1" /* Removal of Synthetic Substitute from Hepatobiliary Duct, Percutaneous Approach */
"0FPB3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Hepatobiliary Duct, Percutaneous Approach */
"0FPB40Z" = "1" /* Removal of Drainage Device from Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FPB41Z" = "1" /* Removal of Radioactive Element from Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FPB42Z" = "1" /* Removal of Monitoring Device from Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FPB43Z" = "1" /* Removal of Infusion Device from Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FPB47Z" = "1" /* Removal of Autologous Tissue Substitute from Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FPB4CZ" = "1" /* Removal of Extraluminal Device from Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FPB4DZ" = "1" /* Removal of Intraluminal Device from Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FPB4JZ" = "1" /* Removal of Synthetic Substitute from Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FPB4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FPD30Z" = "1" /* Removal of Drainage Device from Pancreatic Duct, Percutaneous Approach */
"0FPD31Z" = "1" /* Removal of Radioactive Element from Pancreatic Duct, Percutaneous Approach */
"0FPD32Z" = "1" /* Removal of Monitoring Device from Pancreatic Duct, Percutaneous Approach */
"0FPD33Z" = "1" /* Removal of Infusion Device from Pancreatic Duct, Percutaneous Approach */
"0FPD37Z" = "1" /* Removal of Autologous Tissue Substitute from Pancreatic Duct, Percutaneous Approach */
"0FPD3CZ" = "1" /* Removal of Extraluminal Device from Pancreatic Duct, Percutaneous Approach */
"0FPD3DZ" = "1" /* Removal of Intraluminal Device from Pancreatic Duct, Percutaneous Approach */
"0FPD3JZ" = "1" /* Removal of Synthetic Substitute from Pancreatic Duct, Percutaneous Approach */
"0FPD3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Pancreatic Duct, Percutaneous Approach */
"0FPD40Z" = "1" /* Removal of Drainage Device from Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FPD41Z" = "1" /* Removal of Radioactive Element from Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FPD42Z" = "1" /* Removal of Monitoring Device from Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FPD43Z" = "1" /* Removal of Infusion Device from Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FPD47Z" = "1" /* Removal of Autologous Tissue Substitute from Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FPD4CZ" = "1" /* Removal of Extraluminal Device from Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FPD4DZ" = "1" /* Removal of Intraluminal Device from Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FPD4JZ" = "1" /* Removal of Synthetic Substitute from Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FPD4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FPG30Z" = "1" /* Removal of Drainage Device from Pancreas, Percutaneous Approach */
"0FPG32Z" = "1" /* Removal of Monitoring Device from Pancreas, Percutaneous Approach */
"0FPG33Z" = "1" /* Removal of Infusion Device from Pancreas, Percutaneous Approach */
"0FPG3DZ" = "1" /* Removal of Intraluminal Device from Pancreas, Percutaneous Approach */
"0FPG40Z" = "1" /* Removal of Drainage Device from Pancreas, Percutaneous Endoscopic Approach */
"0FPG42Z" = "1" /* Removal of Monitoring Device from Pancreas, Percutaneous Endoscopic Approach */
"0FPG43Z" = "1" /* Removal of Infusion Device from Pancreas, Percutaneous Endoscopic Approach */
"0FPG4DZ" = "1" /* Removal of Intraluminal Device from Pancreas, Percutaneous Endoscopic Approach */
"0FQ03ZZ" = "1" /* Repair Liver, Percutaneous Approach */
"0FQ04ZZ" = "1" /* Repair Liver, Percutaneous Endoscopic Approach */
"0FQ13ZZ" = "1" /* Repair Right Lobe Liver, Percutaneous Approach */
"0FQ14ZZ" = "1" /* Repair Right Lobe Liver, Percutaneous Endoscopic Approach */
"0FQ23ZZ" = "1" /* Repair Left Lobe Liver, Percutaneous Approach */
"0FQ24ZZ" = "1" /* Repair Left Lobe Liver, Percutaneous Endoscopic Approach */
"0FQ43ZZ" = "1" /* Repair Gallbladder, Percutaneous Approach */
"0FQ44ZZ" = "1" /* Repair Gallbladder, Percutaneous Endoscopic Approach */
"0FQ53ZZ" = "1" /* Repair Right Hepatic Duct, Percutaneous Approach */
"0FQ54ZZ" = "1" /* Repair Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0FQ63ZZ" = "1" /* Repair Left Hepatic Duct, Percutaneous Approach */
"0FQ64ZZ" = "1" /* Repair Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0FQ83ZZ" = "1" /* Repair Cystic Duct, Percutaneous Approach */
"0FQ84ZZ" = "1" /* Repair Cystic Duct, Percutaneous Endoscopic Approach */
"0FQ93ZZ" = "1" /* Repair Common Bile Duct, Percutaneous Approach */
"0FQ94ZZ" = "1" /* Repair Common Bile Duct, Percutaneous Endoscopic Approach */
"0FQC3ZZ" = "1" /* Repair Ampulla of Vater, Percutaneous Approach */
"0FQC4ZZ" = "1" /* Repair Ampulla of Vater, Percutaneous Endoscopic Approach */
"0FQD3ZZ" = "1" /* Repair Pancreatic Duct, Percutaneous Approach */
"0FQD4ZZ" = "1" /* Repair Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FQF3ZZ" = "1" /* Repair Accessory Pancreatic Duct, Percutaneous Approach */
"0FQF4ZZ" = "1" /* Repair Accessory Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FQG3ZZ" = "1" /* Repair Pancreas, Percutaneous Approach */
"0FQG4ZZ" = "1" /* Repair Pancreas, Percutaneous Endoscopic Approach */
"0FR547Z" = "1" /* Replacement of Right Hepatic Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FR54JZ" = "1" /* Replacement of Right Hepatic Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FR54KZ" = "1" /* Replacement of Right Hepatic Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FR647Z" = "1" /* Replacement of Left Hepatic Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FR64JZ" = "1" /* Replacement of Left Hepatic Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FR64KZ" = "1" /* Replacement of Left Hepatic Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FR847Z" = "1" /* Replacement of Cystic Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FR84JZ" = "1" /* Replacement of Cystic Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FR84KZ" = "1" /* Replacement of Cystic Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FR947Z" = "1" /* Replacement of Common Bile Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FR94JZ" = "1" /* Replacement of Common Bile Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FR94KZ" = "1" /* Replacement of Common Bile Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FRC47Z" = "1" /* Replacement of Ampulla of Vater with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FRC4JZ" = "1" /* Replacement of Ampulla of Vater with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FRC4KZ" = "1" /* Replacement of Ampulla of Vater with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FRD47Z" = "1" /* Replacement of Pancreatic Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FRD4JZ" = "1" /* Replacement of Pancreatic Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FRD4KZ" = "1" /* Replacement of Pancreatic Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FRF47Z" = "1" /* Replacement of Accessory Pancreatic Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FRF4JZ" = "1" /* Replacement of Accessory Pancreatic Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FRF4KZ" = "1" /* Replacement of Accessory Pancreatic Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FS04ZZ" = "1" /* Reposition Liver, Percutaneous Endoscopic Approach */
"0FS44ZZ" = "1" /* Reposition Gallbladder, Percutaneous Endoscopic Approach */
"0FS54ZZ" = "1" /* Reposition Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0FS64ZZ" = "1" /* Reposition Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0FS84ZZ" = "1" /* Reposition Cystic Duct, Percutaneous Endoscopic Approach */
"0FS94ZZ" = "1" /* Reposition Common Bile Duct, Percutaneous Endoscopic Approach */
"0FSC4ZZ" = "1" /* Reposition Ampulla of Vater, Percutaneous Endoscopic Approach */
"0FSD4ZZ" = "1" /* Reposition Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FSF4ZZ" = "1" /* Reposition Accessory Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FSG4ZZ" = "1" /* Reposition Pancreas, Percutaneous Endoscopic Approach */
"0FT04ZZ" = "1" /* Resection of Liver, Percutaneous Endoscopic Approach */
"0FT14ZZ" = "1" /* Resection of Right Lobe Liver, Percutaneous Endoscopic Approach */
"0FT24ZZ" = "1" /* Resection of Left Lobe Liver, Percutaneous Endoscopic Approach */
"0FT44ZZ" = "1" /* Resection of Gallbladder, Percutaneous Endoscopic Approach */
"0FT54ZZ" = "1" /* Resection of Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0FT64ZZ" = "1" /* Resection of Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0FT84ZZ" = "1" /* Resection of Cystic Duct, Percutaneous Endoscopic Approach */
"0FT94ZZ" = "1" /* Resection of Common Bile Duct, Percutaneous Endoscopic Approach */
"0FTC4ZZ" = "1" /* Resection of Ampulla of Vater, Percutaneous Endoscopic Approach */
"0FTD4ZZ" = "1" /* Resection of Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FTF4ZZ" = "1" /* Resection of Accessory Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FTG4ZZ" = "1" /* Resection of Pancreas, Percutaneous Endoscopic Approach */
"0FU537Z" = "1" /* Supplement Right Hepatic Duct with Autologous Tissue Substitute, Percutaneous Approach */
"0FU53JZ" = "1" /* Supplement Right Hepatic Duct with Synthetic Substitute, Percutaneous Approach */
"0FU53KZ" = "1" /* Supplement Right Hepatic Duct with Nonautologous Tissue Substitute, Percutaneous Approach */
"0FU547Z" = "1" /* Supplement Right Hepatic Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FU54JZ" = "1" /* Supplement Right Hepatic Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FU54KZ" = "1" /* Supplement Right Hepatic Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FU637Z" = "1" /* Supplement Left Hepatic Duct with Autologous Tissue Substitute, Percutaneous Approach */
"0FU63JZ" = "1" /* Supplement Left Hepatic Duct with Synthetic Substitute, Percutaneous Approach */
"0FU63KZ" = "1" /* Supplement Left Hepatic Duct with Nonautologous Tissue Substitute, Percutaneous Approach */
"0FU647Z" = "1" /* Supplement Left Hepatic Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FU64JZ" = "1" /* Supplement Left Hepatic Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FU64KZ" = "1" /* Supplement Left Hepatic Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FU837Z" = "1" /* Supplement Cystic Duct with Autologous Tissue Substitute, Percutaneous Approach */
"0FU83JZ" = "1" /* Supplement Cystic Duct with Synthetic Substitute, Percutaneous Approach */
"0FU83KZ" = "1" /* Supplement Cystic Duct with Nonautologous Tissue Substitute, Percutaneous Approach */
"0FU847Z" = "1" /* Supplement Cystic Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FU84JZ" = "1" /* Supplement Cystic Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FU84KZ" = "1" /* Supplement Cystic Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FU937Z" = "1" /* Supplement Common Bile Duct with Autologous Tissue Substitute, Percutaneous Approach */
"0FU93JZ" = "1" /* Supplement Common Bile Duct with Synthetic Substitute, Percutaneous Approach */
"0FU93KZ" = "1" /* Supplement Common Bile Duct with Nonautologous Tissue Substitute, Percutaneous Approach */
"0FU947Z" = "1" /* Supplement Common Bile Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FU94JZ" = "1" /* Supplement Common Bile Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FU94KZ" = "1" /* Supplement Common Bile Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FUC37Z" = "1" /* Supplement Ampulla of Vater with Autologous Tissue Substitute, Percutaneous Approach */
"0FUC3JZ" = "1" /* Supplement Ampulla of Vater with Synthetic Substitute, Percutaneous Approach */
"0FUC3KZ" = "1" /* Supplement Ampulla of Vater with Nonautologous Tissue Substitute, Percutaneous Approach */
"0FUC47Z" = "1" /* Supplement Ampulla of Vater with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FUC4JZ" = "1" /* Supplement Ampulla of Vater with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FUC4KZ" = "1" /* Supplement Ampulla of Vater with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FUD37Z" = "1" /* Supplement Pancreatic Duct with Autologous Tissue Substitute, Percutaneous Approach */
"0FUD3JZ" = "1" /* Supplement Pancreatic Duct with Synthetic Substitute, Percutaneous Approach */
"0FUD3KZ" = "1" /* Supplement Pancreatic Duct with Nonautologous Tissue Substitute, Percutaneous Approach */
"0FUD47Z" = "1" /* Supplement Pancreatic Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FUD4JZ" = "1" /* Supplement Pancreatic Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FUD4KZ" = "1" /* Supplement Pancreatic Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FUF37Z" = "1" /* Supplement Accessory Pancreatic Duct with Autologous Tissue Substitute, Percutaneous Approach */
"0FUF3JZ" = "1" /* Supplement Accessory Pancreatic Duct with Synthetic Substitute, Percutaneous Approach */
"0FUF3KZ" = "1" /* Supplement Accessory Pancreatic Duct with Nonautologous Tissue Substitute, Percutaneous Approach */
"0FUF47Z" = "1" /* Supplement Accessory Pancreatic Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FUF4JZ" = "1" /* Supplement Accessory Pancreatic Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FUF4KZ" = "1" /* Supplement Accessory Pancreatic Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FV53CZ" = "1" /* Restriction of Right Hepatic Duct with Extraluminal Device, Percutaneous Approach */
"0FV53DZ" = "1" /* Restriction of Right Hepatic Duct with Intraluminal Device, Percutaneous Approach */
"0FV53ZZ" = "1" /* Restriction of Right Hepatic Duct, Percutaneous Approach */
"0FV54CZ" = "1" /* Restriction of Right Hepatic Duct with Extraluminal Device, Percutaneous Endoscopic Approach */
"0FV54DZ" = "1" /* Restriction of Right Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0FV54ZZ" = "1" /* Restriction of Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0FV63CZ" = "1" /* Restriction of Left Hepatic Duct with Extraluminal Device, Percutaneous Approach */
"0FV63DZ" = "1" /* Restriction of Left Hepatic Duct with Intraluminal Device, Percutaneous Approach */
"0FV63ZZ" = "1" /* Restriction of Left Hepatic Duct, Percutaneous Approach */
"0FV64CZ" = "1" /* Restriction of Left Hepatic Duct with Extraluminal Device, Percutaneous Endoscopic Approach */
"0FV64DZ" = "1" /* Restriction of Left Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0FV64ZZ" = "1" /* Restriction of Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0FV83CZ" = "1" /* Restriction of Cystic Duct with Extraluminal Device, Percutaneous Approach */
"0FV83DZ" = "1" /* Restriction of Cystic Duct with Intraluminal Device, Percutaneous Approach */
"0FV83ZZ" = "1" /* Restriction of Cystic Duct, Percutaneous Approach */
"0FV84CZ" = "1" /* Restriction of Cystic Duct with Extraluminal Device, Percutaneous Endoscopic Approach */
"0FV84DZ" = "1" /* Restriction of Cystic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0FV84ZZ" = "1" /* Restriction of Cystic Duct, Percutaneous Endoscopic Approach */
"0FV93CZ" = "1" /* Restriction of Common Bile Duct with Extraluminal Device, Percutaneous Approach */
"0FV93DZ" = "1" /* Restriction of Common Bile Duct with Intraluminal Device, Percutaneous Approach */
"0FV93ZZ" = "1" /* Restriction of Common Bile Duct, Percutaneous Approach */
"0FV94CZ" = "1" /* Restriction of Common Bile Duct with Extraluminal Device, Percutaneous Endoscopic Approach */
"0FV94DZ" = "1" /* Restriction of Common Bile Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0FV94ZZ" = "1" /* Restriction of Common Bile Duct, Percutaneous Endoscopic Approach */
"0FVC3CZ" = "1" /* Restriction of Ampulla of Vater with Extraluminal Device, Percutaneous Approach */
"0FVC3DZ" = "1" /* Restriction of Ampulla of Vater with Intraluminal Device, Percutaneous Approach */
"0FVC3ZZ" = "1" /* Restriction of Ampulla of Vater, Percutaneous Approach */
"0FVC4CZ" = "1" /* Restriction of Ampulla of Vater with Extraluminal Device, Percutaneous Endoscopic Approach */
"0FVC4DZ" = "1" /* Restriction of Ampulla of Vater with Intraluminal Device, Percutaneous Endoscopic Approach */
"0FVC4ZZ" = "1" /* Restriction of Ampulla of Vater, Percutaneous Endoscopic Approach */
"0FVD3CZ" = "1" /* Restriction of Pancreatic Duct with Extraluminal Device, Percutaneous Approach */
"0FVD3DZ" = "1" /* Restriction of Pancreatic Duct with Intraluminal Device, Percutaneous Approach */
"0FVD3ZZ" = "1" /* Restriction of Pancreatic Duct, Percutaneous Approach */
"0FVD4CZ" = "1" /* Restriction of Pancreatic Duct with Extraluminal Device, Percutaneous Endoscopic Approach */
"0FVD4DZ" = "1" /* Restriction of Pancreatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0FVD4ZZ" = "1" /* Restriction of Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FVF3CZ" = "1" /* Restriction of Accessory Pancreatic Duct with Extraluminal Device, Percutaneous Approach */
"0FVF3DZ" = "1" /* Restriction of Accessory Pancreatic Duct with Intraluminal Device, Percutaneous Approach */
"0FVF3ZZ" = "1" /* Restriction of Accessory Pancreatic Duct, Percutaneous Approach */
"0FVF4CZ" = "1" /* Restriction of Accessory Pancreatic Duct with Extraluminal Device, Percutaneous Endoscopic Approach */
"0FVF4DZ" = "1" /* Restriction of Accessory Pancreatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0FVF4ZZ" = "1" /* Restriction of Accessory Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FW030Z" = "1" /* Revision of Drainage Device in Liver, Percutaneous Approach */
"0FW032Z" = "1" /* Revision of Monitoring Device in Liver, Percutaneous Approach */
"0FW033Z" = "1" /* Revision of Infusion Device in Liver, Percutaneous Approach */
"0FW040Z" = "1" /* Revision of Drainage Device in Liver, Percutaneous Endoscopic Approach */
"0FW042Z" = "1" /* Revision of Monitoring Device in Liver, Percutaneous Endoscopic Approach */
"0FW043Z" = "1" /* Revision of Infusion Device in Liver, Percutaneous Endoscopic Approach */
"0FW430Z" = "1" /* Revision of Drainage Device in Gallbladder, Percutaneous Approach */
"0FW432Z" = "1" /* Revision of Monitoring Device in Gallbladder, Percutaneous Approach */
"0FW433Z" = "1" /* Revision of Infusion Device in Gallbladder, Percutaneous Approach */
"0FW43DZ" = "1" /* Revision of Intraluminal Device in Gallbladder, Percutaneous Approach */
"0FW440Z" = "1" /* Revision of Drainage Device in Gallbladder, Percutaneous Endoscopic Approach */
"0FW442Z" = "1" /* Revision of Monitoring Device in Gallbladder, Percutaneous Endoscopic Approach */
"0FW443Z" = "1" /* Revision of Infusion Device in Gallbladder, Percutaneous Endoscopic Approach */
"0FW44DZ" = "1" /* Revision of Intraluminal Device in Gallbladder, Percutaneous Endoscopic Approach */
"0FWB30Z" = "1" /* Revision of Drainage Device in Hepatobiliary Duct, Percutaneous Approach */
"0FWB32Z" = "1" /* Revision of Monitoring Device in Hepatobiliary Duct, Percutaneous Approach */
"0FWB33Z" = "1" /* Revision of Infusion Device in Hepatobiliary Duct, Percutaneous Approach */
"0FWB37Z" = "1" /* Revision of Autologous Tissue Substitute in Hepatobiliary Duct, Percutaneous Approach */
"0FWB3CZ" = "1" /* Revision of Extraluminal Device in Hepatobiliary Duct, Percutaneous Approach */
"0FWB3DZ" = "1" /* Revision of Intraluminal Device in Hepatobiliary Duct, Percutaneous Approach */
"0FWB3JZ" = "1" /* Revision of Synthetic Substitute in Hepatobiliary Duct, Percutaneous Approach */
"0FWB3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Hepatobiliary Duct, Percutaneous Approach */
"0FWB40Z" = "1" /* Revision of Drainage Device in Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FWB42Z" = "1" /* Revision of Monitoring Device in Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FWB43Z" = "1" /* Revision of Infusion Device in Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FWB47Z" = "1" /* Revision of Autologous Tissue Substitute in Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FWB4CZ" = "1" /* Revision of Extraluminal Device in Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FWB4DZ" = "1" /* Revision of Intraluminal Device in Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FWB4JZ" = "1" /* Revision of Synthetic Substitute in Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FWB4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FWD30Z" = "1" /* Revision of Drainage Device in Pancreatic Duct, Percutaneous Approach */
"0FWD32Z" = "1" /* Revision of Monitoring Device in Pancreatic Duct, Percutaneous Approach */
"0FWD33Z" = "1" /* Revision of Infusion Device in Pancreatic Duct, Percutaneous Approach */
"0FWD37Z" = "1" /* Revision of Autologous Tissue Substitute in Pancreatic Duct, Percutaneous Approach */
"0FWD3CZ" = "1" /* Revision of Extraluminal Device in Pancreatic Duct, Percutaneous Approach */
"0FWD3DZ" = "1" /* Revision of Intraluminal Device in Pancreatic Duct, Percutaneous Approach */
"0FWD3JZ" = "1" /* Revision of Synthetic Substitute in Pancreatic Duct, Percutaneous Approach */
"0FWD3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Pancreatic Duct, Percutaneous Approach */
"0FWD40Z" = "1" /* Revision of Drainage Device in Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FWD42Z" = "1" /* Revision of Monitoring Device in Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FWD43Z" = "1" /* Revision of Infusion Device in Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FWD47Z" = "1" /* Revision of Autologous Tissue Substitute in Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FWD4CZ" = "1" /* Revision of Extraluminal Device in Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FWD4DZ" = "1" /* Revision of Intraluminal Device in Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FWD4JZ" = "1" /* Revision of Synthetic Substitute in Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FWD4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FWG30Z" = "1" /* Revision of Drainage Device in Pancreas, Percutaneous Approach */
"0FWG32Z" = "1" /* Revision of Monitoring Device in Pancreas, Percutaneous Approach */
"0FWG33Z" = "1" /* Revision of Infusion Device in Pancreas, Percutaneous Approach */
"0FWG3DZ" = "1" /* Revision of Intraluminal Device in Pancreas, Percutaneous Approach */
"0FWG40Z" = "1" /* Revision of Drainage Device in Pancreas, Percutaneous Endoscopic Approach */
"0FWG42Z" = "1" /* Revision of Monitoring Device in Pancreas, Percutaneous Endoscopic Approach */
"0FWG43Z" = "1" /* Revision of Infusion Device in Pancreas, Percutaneous Endoscopic Approach */
"0FWG4DZ" = "1" /* Revision of Intraluminal Device in Pancreas, Percutaneous Endoscopic Approach */
"0G523ZZ" = "1" /* Destruction of Left Adrenal Gland, Percutaneous Approach */
"0G524ZZ" = "1" /* Destruction of Left Adrenal Gland, Percutaneous Endoscopic Approach */
"0G533ZZ" = "1" /* Destruction of Right Adrenal Gland, Percutaneous Approach */
"0G534ZZ" = "1" /* Destruction of Right Adrenal Gland, Percutaneous Endoscopic Approach */
"0G543ZZ" = "1" /* Destruction of Bilateral Adrenal Glands, Percutaneous Approach */
"0G544ZZ" = "1" /* Destruction of Bilateral Adrenal Glands, Percutaneous Endoscopic Approach */
"0G9230Z" = "1" /* Drainage of Left Adrenal Gland with Drainage Device, Percutaneous Approach */
"0G923ZX" = "1" /* Drainage of Left Adrenal Gland, Percutaneous Approach, Diagnostic */
"0G923ZZ" = "1" /* Drainage of Left Adrenal Gland, Percutaneous Approach */
"0G9240Z" = "1" /* Drainage of Left Adrenal Gland with Drainage Device, Percutaneous Endoscopic Approach */
"0G924ZX" = "1" /* Drainage of Left Adrenal Gland, Percutaneous Endoscopic Approach, Diagnostic */
"0G924ZZ" = "1" /* Drainage of Left Adrenal Gland, Percutaneous Endoscopic Approach */
"0G9330Z" = "1" /* Drainage of Right Adrenal Gland with Drainage Device, Percutaneous Approach */
"0G933ZX" = "1" /* Drainage of Right Adrenal Gland, Percutaneous Approach, Diagnostic */
"0G933ZZ" = "1" /* Drainage of Right Adrenal Gland, Percutaneous Approach */
"0G9340Z" = "1" /* Drainage of Right Adrenal Gland with Drainage Device, Percutaneous Endoscopic Approach */
"0G934ZX" = "1" /* Drainage of Right Adrenal Gland, Percutaneous Endoscopic Approach, Diagnostic */
"0G934ZZ" = "1" /* Drainage of Right Adrenal Gland, Percutaneous Endoscopic Approach */
"0G9430Z" = "1" /* Drainage of Bilateral Adrenal Glands with Drainage Device, Percutaneous Approach */
"0G943ZX" = "1" /* Drainage of Bilateral Adrenal Glands, Percutaneous Approach, Diagnostic */
"0G943ZZ" = "1" /* Drainage of Bilateral Adrenal Glands, Percutaneous Approach */
"0G9440Z" = "1" /* Drainage of Bilateral Adrenal Glands with Drainage Device, Percutaneous Endoscopic Approach */
"0G944ZX" = "1" /* Drainage of Bilateral Adrenal Glands, Percutaneous Endoscopic Approach, Diagnostic */
"0G944ZZ" = "1" /* Drainage of Bilateral Adrenal Glands, Percutaneous Endoscopic Approach */
"0GB23ZX" = "1" /* Excision of Left Adrenal Gland, Percutaneous Approach, Diagnostic */
"0GB23ZZ" = "1" /* Excision of Left Adrenal Gland, Percutaneous Approach */
"0GB24ZX" = "1" /* Excision of Left Adrenal Gland, Percutaneous Endoscopic Approach, Diagnostic */
"0GB24ZZ" = "1" /* Excision of Left Adrenal Gland, Percutaneous Endoscopic Approach */
"0GB33ZX" = "1" /* Excision of Right Adrenal Gland, Percutaneous Approach, Diagnostic */
"0GB33ZZ" = "1" /* Excision of Right Adrenal Gland, Percutaneous Approach */
"0GB34ZX" = "1" /* Excision of Right Adrenal Gland, Percutaneous Endoscopic Approach, Diagnostic */
"0GB34ZZ" = "1" /* Excision of Right Adrenal Gland, Percutaneous Endoscopic Approach */
"0GB43ZX" = "1" /* Excision of Bilateral Adrenal Glands, Percutaneous Approach, Diagnostic */
"0GB43ZZ" = "1" /* Excision of Bilateral Adrenal Glands, Percutaneous Approach */
"0GB44ZX" = "1" /* Excision of Bilateral Adrenal Glands, Percutaneous Endoscopic Approach, Diagnostic */
"0GB44ZZ" = "1" /* Excision of Bilateral Adrenal Glands, Percutaneous Endoscopic Approach */
"0GC23ZZ" = "1" /* Extirpation of Matter from Left Adrenal Gland, Percutaneous Approach */
"0GC24ZZ" = "1" /* Extirpation of Matter from Left Adrenal Gland, Percutaneous Endoscopic Approach */
"0GC33ZZ" = "1" /* Extirpation of Matter from Right Adrenal Gland, Percutaneous Approach */
"0GC34ZZ" = "1" /* Extirpation of Matter from Right Adrenal Gland, Percutaneous Endoscopic Approach */
"0GC43ZZ" = "1" /* Extirpation of Matter from Bilateral Adrenal Glands, Percutaneous Approach */
"0GC44ZZ" = "1" /* Extirpation of Matter from Bilateral Adrenal Glands, Percutaneous Endoscopic Approach */
"0GM24ZZ" = "1" /* Reattachment of Left Adrenal Gland, Percutaneous Endoscopic Approach */
"0GM34ZZ" = "1" /* Reattachment of Right Adrenal Gland, Percutaneous Endoscopic Approach */
"0GN23ZZ" = "1" /* Release Left Adrenal Gland, Percutaneous Approach */
"0GN24ZZ" = "1" /* Release Left Adrenal Gland, Percutaneous Endoscopic Approach */
"0GN33ZZ" = "1" /* Release Right Adrenal Gland, Percutaneous Approach */
"0GN34ZZ" = "1" /* Release Right Adrenal Gland, Percutaneous Endoscopic Approach */
"0GN43ZZ" = "1" /* Release Bilateral Adrenal Glands, Percutaneous Approach */
"0GN44ZZ" = "1" /* Release Bilateral Adrenal Glands, Percutaneous Endoscopic Approach */
"0GQ23ZZ" = "1" /* Repair Left Adrenal Gland, Percutaneous Approach */
"0GQ24ZZ" = "1" /* Repair Left Adrenal Gland, Percutaneous Endoscopic Approach */
"0GQ33ZZ" = "1" /* Repair Right Adrenal Gland, Percutaneous Approach */
"0GQ34ZZ" = "1" /* Repair Right Adrenal Gland, Percutaneous Endoscopic Approach */
"0GQ43ZZ" = "1" /* Repair Bilateral Adrenal Glands, Percutaneous Approach */
"0GQ44ZZ" = "1" /* Repair Bilateral Adrenal Glands, Percutaneous Endoscopic Approach */
"0GS24ZZ" = "1" /* Reposition Left Adrenal Gland, Percutaneous Endoscopic Approach */
"0GS34ZZ" = "1" /* Reposition Right Adrenal Gland, Percutaneous Endoscopic Approach */
"0GT24ZZ" = "1" /* Resection of Left Adrenal Gland, Percutaneous Endoscopic Approach */
"0GT34ZZ" = "1" /* Resection of Right Adrenal Gland, Percutaneous Endoscopic Approach */
"0GT44ZZ" = "1" /* Resection of Bilateral Adrenal Glands, Percutaneous Endoscopic Approach */
"0SG0370" = "1" /* Fusion of Lumbar Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG03A0" = "1" /* Fusion of Lumbar Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG03J0" = "1" /* Fusion of Lumbar Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG03K0" = "1" /* Fusion of Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG03Z0" = "1" /* Fusion of Lumbar Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG0470" = "1" /* Fusion of Lumbar Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG04A0" = "1" /* Fusion of Lumbar Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG04J0" = "1" /* Fusion of Lumbar Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG04K0" = "1" /* Fusion of Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG04Z0" = "1" /* Fusion of Lumbar Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG1370" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG13A0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG13J0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG13K0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG13Z0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG1470" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic App */
"0SG14A0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG14J0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG14K0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic */
"0SG14Z0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG3370" = "1" /* Fusion of Lumbosacral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG33A0" = "1" /* Fusion of Lumbosacral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG33J0" = "1" /* Fusion of Lumbosacral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG33K0" = "1" /* Fusion of Lumbosacral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG33Z0" = "1" /* Fusion of Lumbosacral Joint, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG3470" = "1" /* Fusion of Lumbosacral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG34A0" = "1" /* Fusion of Lumbosacral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG34J0" = "1" /* Fusion of Lumbosacral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG34K0" = "1" /* Fusion of Lumbosacral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG34Z0" = "1" /* Fusion of Lumbosacral Joint, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0T133JD" = "1" /* Bypass Right Kidney Pelvis to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0T13473" = "1" /* Bypass Right Kidney Pelvis to Right Kidney Pelvis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T13474" = "1" /* Bypass Right Kidney Pelvis to Left Kidney Pelvis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T13476" = "1" /* Bypass Right Kidney Pelvis to Right Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T13477" = "1" /* Bypass Right Kidney Pelvis to Left Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T13478" = "1" /* Bypass Right Kidney Pelvis to Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T13479" = "1" /* Bypass Right Kidney Pelvis to Colocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1347A" = "1" /* Bypass Right Kidney Pelvis to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1347B" = "1" /* Bypass Right Kidney Pelvis to Bladder with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1347C" = "1" /* Bypass Right Kidney Pelvis to Ileocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1347D" = "1" /* Bypass Right Kidney Pelvis to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T134J3" = "1" /* Bypass Right Kidney Pelvis to Right Kidney Pelvis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T134J4" = "1" /* Bypass Right Kidney Pelvis to Left Kidney Pelvis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T134J6" = "1" /* Bypass Right Kidney Pelvis to Right Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T134J7" = "1" /* Bypass Right Kidney Pelvis to Left Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T134J8" = "1" /* Bypass Right Kidney Pelvis to Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T134J9" = "1" /* Bypass Right Kidney Pelvis to Colocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T134JA" = "1" /* Bypass Right Kidney Pelvis to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T134JB" = "1" /* Bypass Right Kidney Pelvis to Bladder with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T134JC" = "1" /* Bypass Right Kidney Pelvis to Ileocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T134JD" = "1" /* Bypass Right Kidney Pelvis to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T134K3" = "1" /* Bypass Right Kidney Pelvis to Right Kidney Pelvis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T134K4" = "1" /* Bypass Right Kidney Pelvis to Left Kidney Pelvis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T134K6" = "1" /* Bypass Right Kidney Pelvis to Right Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T134K7" = "1" /* Bypass Right Kidney Pelvis to Left Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T134K8" = "1" /* Bypass Right Kidney Pelvis to Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T134K9" = "1" /* Bypass Right Kidney Pelvis to Colocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T134KA" = "1" /* Bypass Right Kidney Pelvis to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T134KB" = "1" /* Bypass Right Kidney Pelvis to Bladder with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T134KC" = "1" /* Bypass Right Kidney Pelvis to Ileocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T134KD" = "1" /* Bypass Right Kidney Pelvis to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T134Z3" = "1" /* Bypass Right Kidney Pelvis to Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0T134Z4" = "1" /* Bypass Right Kidney Pelvis to Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0T134Z6" = "1" /* Bypass Right Kidney Pelvis to Right Ureter, Percutaneous Endoscopic Approach */
"0T134Z7" = "1" /* Bypass Right Kidney Pelvis to Left Ureter, Percutaneous Endoscopic Approach */
"0T134Z8" = "1" /* Bypass Right Kidney Pelvis to Colon, Percutaneous Endoscopic Approach */
"0T134Z9" = "1" /* Bypass Right Kidney Pelvis to Colocutaneous, Percutaneous Endoscopic Approach */
"0T134ZA" = "1" /* Bypass Right Kidney Pelvis to Ileum, Percutaneous Endoscopic Approach */
"0T134ZB" = "1" /* Bypass Right Kidney Pelvis to Bladder, Percutaneous Endoscopic Approach */
"0T134ZC" = "1" /* Bypass Right Kidney Pelvis to Ileocutaneous, Percutaneous Endoscopic Approach */
"0T134ZD" = "1" /* Bypass Right Kidney Pelvis to Cutaneous, Percutaneous Endoscopic Approach */
"0T143JD" = "1" /* Bypass Left Kidney Pelvis to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0T14473" = "1" /* Bypass Left Kidney Pelvis to Right Kidney Pelvis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T14474" = "1" /* Bypass Left Kidney Pelvis to Left Kidney Pelvis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T14476" = "1" /* Bypass Left Kidney Pelvis to Right Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T14477" = "1" /* Bypass Left Kidney Pelvis to Left Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T14478" = "1" /* Bypass Left Kidney Pelvis to Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T14479" = "1" /* Bypass Left Kidney Pelvis to Colocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1447A" = "1" /* Bypass Left Kidney Pelvis to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1447B" = "1" /* Bypass Left Kidney Pelvis to Bladder with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1447C" = "1" /* Bypass Left Kidney Pelvis to Ileocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1447D" = "1" /* Bypass Left Kidney Pelvis to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T144J3" = "1" /* Bypass Left Kidney Pelvis to Right Kidney Pelvis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T144J4" = "1" /* Bypass Left Kidney Pelvis to Left Kidney Pelvis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T144J6" = "1" /* Bypass Left Kidney Pelvis to Right Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T144J7" = "1" /* Bypass Left Kidney Pelvis to Left Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T144J8" = "1" /* Bypass Left Kidney Pelvis to Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T144J9" = "1" /* Bypass Left Kidney Pelvis to Colocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T144JA" = "1" /* Bypass Left Kidney Pelvis to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T144JB" = "1" /* Bypass Left Kidney Pelvis to Bladder with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T144JC" = "1" /* Bypass Left Kidney Pelvis to Ileocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T144JD" = "1" /* Bypass Left Kidney Pelvis to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T144K3" = "1" /* Bypass Left Kidney Pelvis to Right Kidney Pelvis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T144K4" = "1" /* Bypass Left Kidney Pelvis to Left Kidney Pelvis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T144K6" = "1" /* Bypass Left Kidney Pelvis to Right Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T144K7" = "1" /* Bypass Left Kidney Pelvis to Left Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T144K8" = "1" /* Bypass Left Kidney Pelvis to Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T144K9" = "1" /* Bypass Left Kidney Pelvis to Colocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T144KA" = "1" /* Bypass Left Kidney Pelvis to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T144KB" = "1" /* Bypass Left Kidney Pelvis to Bladder with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T144KC" = "1" /* Bypass Left Kidney Pelvis to Ileocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T144KD" = "1" /* Bypass Left Kidney Pelvis to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T144Z3" = "1" /* Bypass Left Kidney Pelvis to Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0T144Z4" = "1" /* Bypass Left Kidney Pelvis to Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0T144Z6" = "1" /* Bypass Left Kidney Pelvis to Right Ureter, Percutaneous Endoscopic Approach */
"0T144Z7" = "1" /* Bypass Left Kidney Pelvis to Left Ureter, Percutaneous Endoscopic Approach */
"0T144Z8" = "1" /* Bypass Left Kidney Pelvis to Colon, Percutaneous Endoscopic Approach */
"0T144Z9" = "1" /* Bypass Left Kidney Pelvis to Colocutaneous, Percutaneous Endoscopic Approach */
"0T144ZA" = "1" /* Bypass Left Kidney Pelvis to Ileum, Percutaneous Endoscopic Approach */
"0T144ZB" = "1" /* Bypass Left Kidney Pelvis to Bladder, Percutaneous Endoscopic Approach */
"0T144ZC" = "1" /* Bypass Left Kidney Pelvis to Ileocutaneous, Percutaneous Endoscopic Approach */
"0T144ZD" = "1" /* Bypass Left Kidney Pelvis to Cutaneous, Percutaneous Endoscopic Approach */
"0T163JD" = "1" /* Bypass Right Ureter to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0T16476" = "1" /* Bypass Right Ureter to Right Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T16477" = "1" /* Bypass Right Ureter to Left Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T16478" = "1" /* Bypass Right Ureter to Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T16479" = "1" /* Bypass Right Ureter to Colocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1647A" = "1" /* Bypass Right Ureter to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1647B" = "1" /* Bypass Right Ureter to Bladder with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1647C" = "1" /* Bypass Right Ureter to Ileocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1647D" = "1" /* Bypass Right Ureter to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T164J6" = "1" /* Bypass Right Ureter to Right Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T164J7" = "1" /* Bypass Right Ureter to Left Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T164J8" = "1" /* Bypass Right Ureter to Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T164J9" = "1" /* Bypass Right Ureter to Colocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T164JA" = "1" /* Bypass Right Ureter to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T164JB" = "1" /* Bypass Right Ureter to Bladder with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T164JC" = "1" /* Bypass Right Ureter to Ileocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T164JD" = "1" /* Bypass Right Ureter to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T164K6" = "1" /* Bypass Right Ureter to Right Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T164K7" = "1" /* Bypass Right Ureter to Left Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T164K8" = "1" /* Bypass Right Ureter to Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T164K9" = "1" /* Bypass Right Ureter to Colocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T164KA" = "1" /* Bypass Right Ureter to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T164KB" = "1" /* Bypass Right Ureter to Bladder with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T164KC" = "1" /* Bypass Right Ureter to Ileocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T164KD" = "1" /* Bypass Right Ureter to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T164Z6" = "1" /* Bypass Right Ureter to Right Ureter, Percutaneous Endoscopic Approach */
"0T164Z7" = "1" /* Bypass Right Ureter to Left Ureter, Percutaneous Endoscopic Approach */
"0T164Z8" = "1" /* Bypass Right Ureter to Colon, Percutaneous Endoscopic Approach */
"0T164Z9" = "1" /* Bypass Right Ureter to Colocutaneous, Percutaneous Endoscopic Approach */
"0T164ZA" = "1" /* Bypass Right Ureter to Ileum, Percutaneous Endoscopic Approach */
"0T164ZB" = "1" /* Bypass Right Ureter to Bladder, Percutaneous Endoscopic Approach */
"0T164ZC" = "1" /* Bypass Right Ureter to Ileocutaneous, Percutaneous Endoscopic Approach */
"0T164ZD" = "1" /* Bypass Right Ureter to Cutaneous, Percutaneous Endoscopic Approach */
"0T173JD" = "1" /* Bypass Left Ureter to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0T17476" = "1" /* Bypass Left Ureter to Right Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T17477" = "1" /* Bypass Left Ureter to Left Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T17478" = "1" /* Bypass Left Ureter to Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T17479" = "1" /* Bypass Left Ureter to Colocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1747A" = "1" /* Bypass Left Ureter to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1747B" = "1" /* Bypass Left Ureter to Bladder with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1747C" = "1" /* Bypass Left Ureter to Ileocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1747D" = "1" /* Bypass Left Ureter to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T174J6" = "1" /* Bypass Left Ureter to Right Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T174J7" = "1" /* Bypass Left Ureter to Left Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T174J8" = "1" /* Bypass Left Ureter to Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T174J9" = "1" /* Bypass Left Ureter to Colocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T174JA" = "1" /* Bypass Left Ureter to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T174JB" = "1" /* Bypass Left Ureter to Bladder with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T174JC" = "1" /* Bypass Left Ureter to Ileocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T174JD" = "1" /* Bypass Left Ureter to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T174K6" = "1" /* Bypass Left Ureter to Right Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T174K7" = "1" /* Bypass Left Ureter to Left Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T174K8" = "1" /* Bypass Left Ureter to Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T174K9" = "1" /* Bypass Left Ureter to Colocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T174KA" = "1" /* Bypass Left Ureter to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T174KB" = "1" /* Bypass Left Ureter to Bladder with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T174KC" = "1" /* Bypass Left Ureter to Ileocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T174KD" = "1" /* Bypass Left Ureter to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T174Z6" = "1" /* Bypass Left Ureter to Right Ureter, Percutaneous Endoscopic Approach */
"0T174Z7" = "1" /* Bypass Left Ureter to Left Ureter, Percutaneous Endoscopic Approach */
"0T174Z8" = "1" /* Bypass Left Ureter to Colon, Percutaneous Endoscopic Approach */
"0T174Z9" = "1" /* Bypass Left Ureter to Colocutaneous, Percutaneous Endoscopic Approach */
"0T174ZA" = "1" /* Bypass Left Ureter to Ileum, Percutaneous Endoscopic Approach */
"0T174ZB" = "1" /* Bypass Left Ureter to Bladder, Percutaneous Endoscopic Approach */
"0T174ZC" = "1" /* Bypass Left Ureter to Ileocutaneous, Percutaneous Endoscopic Approach */
"0T174ZD" = "1" /* Bypass Left Ureter to Cutaneous, Percutaneous Endoscopic Approach */
"0T183JD" = "1" /* Bypass Bilateral Ureters to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0T18476" = "1" /* Bypass Bilateral Ureters to Right Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T18477" = "1" /* Bypass Bilateral Ureters to Left Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T18478" = "1" /* Bypass Bilateral Ureters to Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T18479" = "1" /* Bypass Bilateral Ureters to Colocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1847A" = "1" /* Bypass Bilateral Ureters to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1847B" = "1" /* Bypass Bilateral Ureters to Bladder with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1847C" = "1" /* Bypass Bilateral Ureters to Ileocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1847D" = "1" /* Bypass Bilateral Ureters to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T184J6" = "1" /* Bypass Bilateral Ureters to Right Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T184J7" = "1" /* Bypass Bilateral Ureters to Left Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T184J8" = "1" /* Bypass Bilateral Ureters to Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T184J9" = "1" /* Bypass Bilateral Ureters to Colocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T184JA" = "1" /* Bypass Bilateral Ureters to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T184JB" = "1" /* Bypass Bilateral Ureters to Bladder with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T184JC" = "1" /* Bypass Bilateral Ureters to Ileocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T184JD" = "1" /* Bypass Bilateral Ureters to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T184K6" = "1" /* Bypass Bilateral Ureters to Right Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T184K7" = "1" /* Bypass Bilateral Ureters to Left Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T184K8" = "1" /* Bypass Bilateral Ureters to Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T184K9" = "1" /* Bypass Bilateral Ureters to Colocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T184KA" = "1" /* Bypass Bilateral Ureters to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T184KB" = "1" /* Bypass Bilateral Ureters to Bladder with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T184KC" = "1" /* Bypass Bilateral Ureters to Ileocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T184KD" = "1" /* Bypass Bilateral Ureters to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T184Z6" = "1" /* Bypass Bilateral Ureters to Right Ureter, Percutaneous Endoscopic Approach */
"0T184Z7" = "1" /* Bypass Bilateral Ureters to Left Ureter, Percutaneous Endoscopic Approach */
"0T184Z8" = "1" /* Bypass Bilateral Ureters to Colon, Percutaneous Endoscopic Approach */
"0T184Z9" = "1" /* Bypass Bilateral Ureters to Colocutaneous, Percutaneous Endoscopic Approach */
"0T184ZA" = "1" /* Bypass Bilateral Ureters to Ileum, Percutaneous Endoscopic Approach */
"0T184ZB" = "1" /* Bypass Bilateral Ureters to Bladder, Percutaneous Endoscopic Approach */
"0T184ZC" = "1" /* Bypass Bilateral Ureters to Ileocutaneous, Percutaneous Endoscopic Approach */
"0T184ZD" = "1" /* Bypass Bilateral Ureters to Cutaneous, Percutaneous Endoscopic Approach */
"0T1B3JD" = "1" /* Bypass Bladder to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0T1B479" = "1" /* Bypass Bladder to Colocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1B47C" = "1" /* Bypass Bladder to Ileocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1B47D" = "1" /* Bypass Bladder to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1B4J9" = "1" /* Bypass Bladder to Colocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T1B4JC" = "1" /* Bypass Bladder to Ileocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T1B4JD" = "1" /* Bypass Bladder to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T1B4K9" = "1" /* Bypass Bladder to Colocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1B4KC" = "1" /* Bypass Bladder to Ileocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1B4KD" = "1" /* Bypass Bladder to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1B4Z9" = "1" /* Bypass Bladder to Colocutaneous, Percutaneous Endoscopic Approach */
"0T1B4ZC" = "1" /* Bypass Bladder to Ileocutaneous, Percutaneous Endoscopic Approach */
"0T1B4ZD" = "1" /* Bypass Bladder to Cutaneous, Percutaneous Endoscopic Approach */
"0T503ZZ" = "1" /* Destruction of Right Kidney, Percutaneous Approach */
"0T504ZZ" = "1" /* Destruction of Right Kidney, Percutaneous Endoscopic Approach */
"0T513ZZ" = "1" /* Destruction of Left Kidney, Percutaneous Approach */
"0T514ZZ" = "1" /* Destruction of Left Kidney, Percutaneous Endoscopic Approach */
"0T533ZZ" = "1" /* Destruction of Right Kidney Pelvis, Percutaneous Approach */
"0T534ZZ" = "1" /* Destruction of Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0T543ZZ" = "1" /* Destruction of Left Kidney Pelvis, Percutaneous Approach */
"0T544ZZ" = "1" /* Destruction of Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0T563ZZ" = "1" /* Destruction of Right Ureter, Percutaneous Approach */
"0T564ZZ" = "1" /* Destruction of Right Ureter, Percutaneous Endoscopic Approach */
"0T573ZZ" = "1" /* Destruction of Left Ureter, Percutaneous Approach */
"0T574ZZ" = "1" /* Destruction of Left Ureter, Percutaneous Endoscopic Approach */
"0T5B3ZZ" = "1" /* Destruction of Bladder, Percutaneous Approach */
"0T5B4ZZ" = "1" /* Destruction of Bladder, Percutaneous Endoscopic Approach */
"0T733DZ" = "1" /* Dilation of Right Kidney Pelvis with Intraluminal Device, Percutaneous Approach */
"0T733ZZ" = "1" /* Dilation of Right Kidney Pelvis, Percutaneous Approach */
"0T734DZ" = "1" /* Dilation of Right Kidney Pelvis with Intraluminal Device, Percutaneous Endoscopic Approach */
"0T734ZZ" = "1" /* Dilation of Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0T743DZ" = "1" /* Dilation of Left Kidney Pelvis with Intraluminal Device, Percutaneous Approach */
"0T743ZZ" = "1" /* Dilation of Left Kidney Pelvis, Percutaneous Approach */
"0T744DZ" = "1" /* Dilation of Left Kidney Pelvis with Intraluminal Device, Percutaneous Endoscopic Approach */
"0T744ZZ" = "1" /* Dilation of Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0T763DZ" = "1" /* Dilation of Right Ureter with Intraluminal Device, Percutaneous Approach */
"0T763ZZ" = "1" /* Dilation of Right Ureter, Percutaneous Approach */
"0T764DZ" = "1" /* Dilation of Right Ureter with Intraluminal Device, Percutaneous Endoscopic Approach */
"0T764ZZ" = "1" /* Dilation of Right Ureter, Percutaneous Endoscopic Approach */
"0T773DZ" = "1" /* Dilation of Left Ureter with Intraluminal Device, Percutaneous Approach */
"0T773ZZ" = "1" /* Dilation of Left Ureter, Percutaneous Approach */
"0T774DZ" = "1" /* Dilation of Left Ureter with Intraluminal Device, Percutaneous Endoscopic Approach */
"0T774ZZ" = "1" /* Dilation of Left Ureter, Percutaneous Endoscopic Approach */
"0T783DZ" = "1" /* Dilation of Bilateral Ureters with Intraluminal Device, Percutaneous Approach */
"0T783ZZ" = "1" /* Dilation of Bilateral Ureters, Percutaneous Approach */
"0T784DZ" = "1" /* Dilation of Bilateral Ureters with Intraluminal Device, Percutaneous Endoscopic Approach */
"0T784ZZ" = "1" /* Dilation of Bilateral Ureters, Percutaneous Endoscopic Approach */
"0T7B3DZ" = "1" /* Dilation of Bladder with Intraluminal Device, Percutaneous Approach */
"0T7B3ZZ" = "1" /* Dilation of Bladder, Percutaneous Approach */
"0T7B4DZ" = "1" /* Dilation of Bladder with Intraluminal Device, Percutaneous Endoscopic Approach */
"0T7B4ZZ" = "1" /* Dilation of Bladder, Percutaneous Endoscopic Approach */
"0T823ZZ" = "1" /* Division of Bilateral Kidneys, Percutaneous Approach */
"0T824ZZ" = "1" /* Division of Bilateral Kidneys, Percutaneous Endoscopic Approach */
"0T9030Z" = "1" /* Drainage of Right Kidney with Drainage Device, Percutaneous Approach */
"0T903ZX" = "1" /* Drainage of Right Kidney, Percutaneous Approach, Diagnostic */
"0T903ZZ" = "1" /* Drainage of Right Kidney, Percutaneous Approach */
"0T9040Z" = "1" /* Drainage of Right Kidney with Drainage Device, Percutaneous Endoscopic Approach */
"0T904ZX" = "1" /* Drainage of Right Kidney, Percutaneous Endoscopic Approach, Diagnostic */
"0T904ZZ" = "1" /* Drainage of Right Kidney, Percutaneous Endoscopic Approach */
"0T9130Z" = "1" /* Drainage of Left Kidney with Drainage Device, Percutaneous Approach */
"0T913ZX" = "1" /* Drainage of Left Kidney, Percutaneous Approach, Diagnostic */
"0T913ZZ" = "1" /* Drainage of Left Kidney, Percutaneous Approach */
"0T9140Z" = "1" /* Drainage of Left Kidney with Drainage Device, Percutaneous Endoscopic Approach */
"0T914ZX" = "1" /* Drainage of Left Kidney, Percutaneous Endoscopic Approach, Diagnostic */
"0T914ZZ" = "1" /* Drainage of Left Kidney, Percutaneous Endoscopic Approach */
"0T9330Z" = "1" /* Drainage of Right Kidney Pelvis with Drainage Device, Percutaneous Approach */
"0T933ZX" = "1" /* Drainage of Right Kidney Pelvis, Percutaneous Approach, Diagnostic */
"0T933ZZ" = "1" /* Drainage of Right Kidney Pelvis, Percutaneous Approach */
"0T9340Z" = "1" /* Drainage of Right Kidney Pelvis with Drainage Device, Percutaneous Endoscopic Approach */
"0T934ZX" = "1" /* Drainage of Right Kidney Pelvis, Percutaneous Endoscopic Approach, Diagnostic */
"0T934ZZ" = "1" /* Drainage of Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0T9430Z" = "1" /* Drainage of Left Kidney Pelvis with Drainage Device, Percutaneous Approach */
"0T943ZX" = "1" /* Drainage of Left Kidney Pelvis, Percutaneous Approach, Diagnostic */
"0T943ZZ" = "1" /* Drainage of Left Kidney Pelvis, Percutaneous Approach */
"0T9440Z" = "1" /* Drainage of Left Kidney Pelvis with Drainage Device, Percutaneous Endoscopic Approach */
"0T944ZX" = "1" /* Drainage of Left Kidney Pelvis, Percutaneous Endoscopic Approach, Diagnostic */
"0T944ZZ" = "1" /* Drainage of Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0T9630Z" = "1" /* Drainage of Right Ureter with Drainage Device, Percutaneous Approach */
"0T963ZX" = "1" /* Drainage of Right Ureter, Percutaneous Approach, Diagnostic */
"0T963ZZ" = "1" /* Drainage of Right Ureter, Percutaneous Approach */
"0T9640Z" = "1" /* Drainage of Right Ureter with Drainage Device, Percutaneous Endoscopic Approach */
"0T964ZX" = "1" /* Drainage of Right Ureter, Percutaneous Endoscopic Approach, Diagnostic */
"0T964ZZ" = "1" /* Drainage of Right Ureter, Percutaneous Endoscopic Approach */
"0T9730Z" = "1" /* Drainage of Left Ureter with Drainage Device, Percutaneous Approach */
"0T973ZX" = "1" /* Drainage of Left Ureter, Percutaneous Approach, Diagnostic */
"0T973ZZ" = "1" /* Drainage of Left Ureter, Percutaneous Approach */
"0T9740Z" = "1" /* Drainage of Left Ureter with Drainage Device, Percutaneous Endoscopic Approach */
"0T974ZX" = "1" /* Drainage of Left Ureter, Percutaneous Endoscopic Approach, Diagnostic */
"0T974ZZ" = "1" /* Drainage of Left Ureter, Percutaneous Endoscopic Approach */
"0T9830Z" = "1" /* Drainage of Bilateral Ureters with Drainage Device, Percutaneous Approach */
"0T983ZX" = "1" /* Drainage of Bilateral Ureters, Percutaneous Approach, Diagnostic */
"0T983ZZ" = "1" /* Drainage of Bilateral Ureters, Percutaneous Approach */
"0T9840Z" = "1" /* Drainage of Bilateral Ureters with Drainage Device, Percutaneous Endoscopic Approach */
"0T984ZX" = "1" /* Drainage of Bilateral Ureters, Percutaneous Endoscopic Approach, Diagnostic */
"0T984ZZ" = "1" /* Drainage of Bilateral Ureters, Percutaneous Endoscopic Approach */
"0T9B30Z" = "1" /* Drainage of Bladder with Drainage Device, Percutaneous Approach */
"0T9B3ZX" = "1" /* Drainage of Bladder, Percutaneous Approach, Diagnostic */
"0T9B3ZZ" = "1" /* Drainage of Bladder, Percutaneous Approach */
"0T9B40Z" = "1" /* Drainage of Bladder with Drainage Device, Percutaneous Endoscopic Approach */
"0T9B4ZX" = "1" /* Drainage of Bladder, Percutaneous Endoscopic Approach, Diagnostic */
"0T9B4ZZ" = "1" /* Drainage of Bladder, Percutaneous Endoscopic Approach */
"0TB03ZX" = "1" /* Excision of Right Kidney, Percutaneous Approach, Diagnostic */
"0TB03ZZ" = "1" /* Excision of Right Kidney, Percutaneous Approach */
"0TB04ZX" = "1" /* Excision of Right Kidney, Percutaneous Endoscopic Approach, Diagnostic */
"0TB04ZZ" = "1" /* Excision of Right Kidney, Percutaneous Endoscopic Approach */
"0TB13ZX" = "1" /* Excision of Left Kidney, Percutaneous Approach, Diagnostic */
"0TB13ZZ" = "1" /* Excision of Left Kidney, Percutaneous Approach */
"0TB14ZX" = "1" /* Excision of Left Kidney, Percutaneous Endoscopic Approach, Diagnostic */
"0TB14ZZ" = "1" /* Excision of Left Kidney, Percutaneous Endoscopic Approach */
"0TB33ZX" = "1" /* Excision of Right Kidney Pelvis, Percutaneous Approach, Diagnostic */
"0TB33ZZ" = "1" /* Excision of Right Kidney Pelvis, Percutaneous Approach */
"0TB34ZX" = "1" /* Excision of Right Kidney Pelvis, Percutaneous Endoscopic Approach, Diagnostic */
"0TB34ZZ" = "1" /* Excision of Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TB43ZX" = "1" /* Excision of Left Kidney Pelvis, Percutaneous Approach, Diagnostic */
"0TB43ZZ" = "1" /* Excision of Left Kidney Pelvis, Percutaneous Approach */
"0TB44ZX" = "1" /* Excision of Left Kidney Pelvis, Percutaneous Endoscopic Approach, Diagnostic */
"0TB44ZZ" = "1" /* Excision of Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TB63ZX" = "1" /* Excision of Right Ureter, Percutaneous Approach, Diagnostic */
"0TB63ZZ" = "1" /* Excision of Right Ureter, Percutaneous Approach */
"0TB64ZX" = "1" /* Excision of Right Ureter, Percutaneous Endoscopic Approach, Diagnostic */
"0TB64ZZ" = "1" /* Excision of Right Ureter, Percutaneous Endoscopic Approach */
"0TB73ZX" = "1" /* Excision of Left Ureter, Percutaneous Approach, Diagnostic */
"0TB73ZZ" = "1" /* Excision of Left Ureter, Percutaneous Approach */
"0TB74ZX" = "1" /* Excision of Left Ureter, Percutaneous Endoscopic Approach, Diagnostic */
"0TB74ZZ" = "1" /* Excision of Left Ureter, Percutaneous Endoscopic Approach */
"0TBB3ZX" = "1" /* Excision of Bladder, Percutaneous Approach, Diagnostic */
"0TBB3ZZ" = "1" /* Excision of Bladder, Percutaneous Approach */
"0TBB4ZX" = "1" /* Excision of Bladder, Percutaneous Endoscopic Approach, Diagnostic */
"0TBB4ZZ" = "1" /* Excision of Bladder, Percutaneous Endoscopic Approach */
"0TC03ZZ" = "1" /* Extirpation of Matter from Right Kidney, Percutaneous Approach */
"0TC04ZZ" = "1" /* Extirpation of Matter from Right Kidney, Percutaneous Endoscopic Approach */
"0TC13ZZ" = "1" /* Extirpation of Matter from Left Kidney, Percutaneous Approach */
"0TC14ZZ" = "1" /* Extirpation of Matter from Left Kidney, Percutaneous Endoscopic Approach */
"0TC33ZZ" = "1" /* Extirpation of Matter from Right Kidney Pelvis, Percutaneous Approach */
"0TC34ZZ" = "1" /* Extirpation of Matter from Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TC43ZZ" = "1" /* Extirpation of Matter from Left Kidney Pelvis, Percutaneous Approach */
"0TC44ZZ" = "1" /* Extirpation of Matter from Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TC63ZZ" = "1" /* Extirpation of Matter from Right Ureter, Percutaneous Approach */
"0TC64ZZ" = "1" /* Extirpation of Matter from Right Ureter, Percutaneous Endoscopic Approach */
"0TC73ZZ" = "1" /* Extirpation of Matter from Left Ureter, Percutaneous Approach */
"0TC74ZZ" = "1" /* Extirpation of Matter from Left Ureter, Percutaneous Endoscopic Approach */
"0TCB3ZZ" = "1" /* Extirpation of Matter from Bladder, Percutaneous Approach */
"0TCB4ZZ" = "1" /* Extirpation of Matter from Bladder, Percutaneous Endoscopic Approach */
"0TD03ZZ" = "1" /* Extraction of Right Kidney, Percutaneous Approach */
"0TD04ZZ" = "1" /* Extraction of Right Kidney, Percutaneous Endoscopic Approach */
"0TD13ZZ" = "1" /* Extraction of Left Kidney, Percutaneous Approach */
"0TD14ZZ" = "1" /* Extraction of Left Kidney, Percutaneous Endoscopic Approach */
"0TF33ZZ" = "1" /* Fragmentation in Right Kidney Pelvis, Percutaneous Approach */
"0TF34ZZ" = "1" /* Fragmentation in Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TF43ZZ" = "1" /* Fragmentation in Left Kidney Pelvis, Percutaneous Approach */
"0TF44ZZ" = "1" /* Fragmentation in Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TF63ZZ" = "1" /* Fragmentation in Right Ureter, Percutaneous Approach */
"0TF64ZZ" = "1" /* Fragmentation in Right Ureter, Percutaneous Endoscopic Approach */
"0TF73ZZ" = "1" /* Fragmentation in Left Ureter, Percutaneous Approach */
"0TF74ZZ" = "1" /* Fragmentation in Left Ureter, Percutaneous Endoscopic Approach */
"0TFB3ZZ" = "1" /* Fragmentation in Bladder, Percutaneous Approach */
"0TFB4ZZ" = "1" /* Fragmentation in Bladder, Percutaneous Endoscopic Approach */
"0TH532Z" = "1" /* Insertion of Monitoring Device into Kidney, Percutaneous Approach */
"0TH533Z" = "1" /* Insertion of Infusion Device into Kidney, Percutaneous Approach */
"0TH542Z" = "1" /* Insertion of Monitoring Device into Kidney, Percutaneous Endoscopic Approach */
"0TH543Z" = "1" /* Insertion of Infusion Device into Kidney, Percutaneous Endoscopic Approach */
"0TH932Z" = "1" /* Insertion of Monitoring Device into Ureter, Percutaneous Approach */
"0TH933Z" = "1" /* Insertion of Infusion Device into Ureter, Percutaneous Approach */
"0TH93MZ" = "1" /* Insertion of Stimulator Lead into Ureter, Percutaneous Approach */
"0TH942Z" = "1" /* Insertion of Monitoring Device into Ureter, Percutaneous Endoscopic Approach */
"0TH943Z" = "1" /* Insertion of Infusion Device into Ureter, Percutaneous Endoscopic Approach */
"0TH94MZ" = "1" /* Insertion of Stimulator Lead into Ureter, Percutaneous Endoscopic Approach */
"0THB32Z" = "1" /* Insertion of Monitoring Device into Bladder, Percutaneous Approach */
"0THB33Z" = "1" /* Insertion of Infusion Device into Bladder, Percutaneous Approach */
"0THB3LZ" = "1" /* Insertion of Artificial Sphincter into Bladder, Percutaneous Approach */
"0THB3MZ" = "1" /* Insertion of Stimulator Lead into Bladder, Percutaneous Approach */
"0THB42Z" = "1" /* Insertion of Monitoring Device into Bladder, Percutaneous Endoscopic Approach */
"0THB43Z" = "1" /* Insertion of Infusion Device into Bladder, Percutaneous Endoscopic Approach */
"0THB4LZ" = "1" /* Insertion of Artificial Sphincter into Bladder, Percutaneous Endoscopic Approach */
"0THB4MZ" = "1" /* Insertion of Stimulator Lead into Bladder, Percutaneous Endoscopic Approach */
"0TJ53ZZ" = "1" /* Inspection of Kidney, Percutaneous Approach */
"0TJ54ZZ" = "1" /* Inspection of Kidney, Percutaneous Endoscopic Approach */
"0TJ93ZZ" = "1" /* Inspection of Ureter, Percutaneous Approach */
"0TJ94ZZ" = "1" /* Inspection of Ureter, Percutaneous Endoscopic Approach */
"0TJB3ZZ" = "1" /* Inspection of Bladder, Percutaneous Approach */
"0TJB4ZZ" = "1" /* Inspection of Bladder, Percutaneous Endoscopic Approach */
"0TL33CZ" = "1" /* Occlusion of Right Kidney Pelvis with Extraluminal Device, Percutaneous Approach */
"0TL33DZ" = "1" /* Occlusion of Right Kidney Pelvis with Intraluminal Device, Percutaneous Approach */
"0TL33ZZ" = "1" /* Occlusion of Right Kidney Pelvis, Percutaneous Approach */
"0TL34CZ" = "1" /* Occlusion of Right Kidney Pelvis with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TL34DZ" = "1" /* Occlusion of Right Kidney Pelvis with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TL34ZZ" = "1" /* Occlusion of Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TL43CZ" = "1" /* Occlusion of Left Kidney Pelvis with Extraluminal Device, Percutaneous Approach */
"0TL43DZ" = "1" /* Occlusion of Left Kidney Pelvis with Intraluminal Device, Percutaneous Approach */
"0TL43ZZ" = "1" /* Occlusion of Left Kidney Pelvis, Percutaneous Approach */
"0TL44CZ" = "1" /* Occlusion of Left Kidney Pelvis with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TL44DZ" = "1" /* Occlusion of Left Kidney Pelvis with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TL44ZZ" = "1" /* Occlusion of Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TL63CZ" = "1" /* Occlusion of Right Ureter with Extraluminal Device, Percutaneous Approach */
"0TL63DZ" = "1" /* Occlusion of Right Ureter with Intraluminal Device, Percutaneous Approach */
"0TL63ZZ" = "1" /* Occlusion of Right Ureter, Percutaneous Approach */
"0TL64CZ" = "1" /* Occlusion of Right Ureter with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TL64DZ" = "1" /* Occlusion of Right Ureter with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TL64ZZ" = "1" /* Occlusion of Right Ureter, Percutaneous Endoscopic Approach */
"0TL73CZ" = "1" /* Occlusion of Left Ureter with Extraluminal Device, Percutaneous Approach */
"0TL73DZ" = "1" /* Occlusion of Left Ureter with Intraluminal Device, Percutaneous Approach */
"0TL73ZZ" = "1" /* Occlusion of Left Ureter, Percutaneous Approach */
"0TL74CZ" = "1" /* Occlusion of Left Ureter with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TL74DZ" = "1" /* Occlusion of Left Ureter with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TL74ZZ" = "1" /* Occlusion of Left Ureter, Percutaneous Endoscopic Approach */
"0TLB3CZ" = "1" /* Occlusion of Bladder with Extraluminal Device, Percutaneous Approach */
"0TLB3DZ" = "1" /* Occlusion of Bladder with Intraluminal Device, Percutaneous Approach */
"0TLB3ZZ" = "1" /* Occlusion of Bladder, Percutaneous Approach */
"0TLB4CZ" = "1" /* Occlusion of Bladder with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TLB4DZ" = "1" /* Occlusion of Bladder with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TLB4ZZ" = "1" /* Occlusion of Bladder, Percutaneous Endoscopic Approach */
"0TM04ZZ" = "1" /* Reattachment of Right Kidney, Percutaneous Endoscopic Approach */
"0TM14ZZ" = "1" /* Reattachment of Left Kidney, Percutaneous Endoscopic Approach */
"0TM24ZZ" = "1" /* Reattachment of Bilateral Kidneys, Percutaneous Endoscopic Approach */
"0TM34ZZ" = "1" /* Reattachment of Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TM44ZZ" = "1" /* Reattachment of Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TM64ZZ" = "1" /* Reattachment of Right Ureter, Percutaneous Endoscopic Approach */
"0TM74ZZ" = "1" /* Reattachment of Left Ureter, Percutaneous Endoscopic Approach */
"0TM84ZZ" = "1" /* Reattachment of Bilateral Ureters, Percutaneous Endoscopic Approach */
"0TMB4ZZ" = "1" /* Reattachment of Bladder, Percutaneous Endoscopic Approach */
"0TN03ZZ" = "1" /* Release Right Kidney, Percutaneous Approach */
"0TN04ZZ" = "1" /* Release Right Kidney, Percutaneous Endoscopic Approach */
"0TN13ZZ" = "1" /* Release Left Kidney, Percutaneous Approach */
"0TN14ZZ" = "1" /* Release Left Kidney, Percutaneous Endoscopic Approach */
"0TN33ZZ" = "1" /* Release Right Kidney Pelvis, Percutaneous Approach */
"0TN34ZZ" = "1" /* Release Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TN43ZZ" = "1" /* Release Left Kidney Pelvis, Percutaneous Approach */
"0TN44ZZ" = "1" /* Release Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TN63ZZ" = "1" /* Release Right Ureter, Percutaneous Approach */
"0TN64ZZ" = "1" /* Release Right Ureter, Percutaneous Endoscopic Approach */
"0TN73ZZ" = "1" /* Release Left Ureter, Percutaneous Approach */
"0TN74ZZ" = "1" /* Release Left Ureter, Percutaneous Endoscopic Approach */
"0TNB3ZZ" = "1" /* Release Bladder, Percutaneous Approach */
"0TNB4ZZ" = "1" /* Release Bladder, Percutaneous Endoscopic Approach */
"0TP530Z" = "1" /* Removal of Drainage Device from Kidney, Percutaneous Approach */
"0TP532Z" = "1" /* Removal of Monitoring Device from Kidney, Percutaneous Approach */
"0TP533Z" = "1" /* Removal of Infusion Device from Kidney, Percutaneous Approach */
"0TP537Z" = "1" /* Removal of Autologous Tissue Substitute from Kidney, Percutaneous Approach */
"0TP53CZ" = "1" /* Removal of Extraluminal Device from Kidney, Percutaneous Approach */
"0TP53DZ" = "1" /* Removal of Intraluminal Device from Kidney, Percutaneous Approach */
"0TP53JZ" = "1" /* Removal of Synthetic Substitute from Kidney, Percutaneous Approach */
"0TP53KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Kidney, Percutaneous Approach */
"0TP540Z" = "1" /* Removal of Drainage Device from Kidney, Percutaneous Endoscopic Approach */
"0TP542Z" = "1" /* Removal of Monitoring Device from Kidney, Percutaneous Endoscopic Approach */
"0TP543Z" = "1" /* Removal of Infusion Device from Kidney, Percutaneous Endoscopic Approach */
"0TP547Z" = "1" /* Removal of Autologous Tissue Substitute from Kidney, Percutaneous Endoscopic Approach */
"0TP54CZ" = "1" /* Removal of Extraluminal Device from Kidney, Percutaneous Endoscopic Approach */
"0TP54DZ" = "1" /* Removal of Intraluminal Device from Kidney, Percutaneous Endoscopic Approach */
"0TP54JZ" = "1" /* Removal of Synthetic Substitute from Kidney, Percutaneous Endoscopic Approach */
"0TP54KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Kidney, Percutaneous Endoscopic Approach */
"0TP930Z" = "1" /* Removal of Drainage Device from Ureter, Percutaneous Approach */
"0TP932Z" = "1" /* Removal of Monitoring Device from Ureter, Percutaneous Approach */
"0TP933Z" = "1" /* Removal of Infusion Device from Ureter, Percutaneous Approach */
"0TP937Z" = "1" /* Removal of Autologous Tissue Substitute from Ureter, Percutaneous Approach */
"0TP93CZ" = "1" /* Removal of Extraluminal Device from Ureter, Percutaneous Approach */
"0TP93DZ" = "1" /* Removal of Intraluminal Device from Ureter, Percutaneous Approach */
"0TP93JZ" = "1" /* Removal of Synthetic Substitute from Ureter, Percutaneous Approach */
"0TP93KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Ureter, Percutaneous Approach */
"0TP93MZ" = "1" /* Removal of Stimulator Lead from Ureter, Percutaneous Approach */
"0TP940Z" = "1" /* Removal of Drainage Device from Ureter, Percutaneous Endoscopic Approach */
"0TP942Z" = "1" /* Removal of Monitoring Device from Ureter, Percutaneous Endoscopic Approach */
"0TP943Z" = "1" /* Removal of Infusion Device from Ureter, Percutaneous Endoscopic Approach */
"0TP947Z" = "1" /* Removal of Autologous Tissue Substitute from Ureter, Percutaneous Endoscopic Approach */
"0TP94CZ" = "1" /* Removal of Extraluminal Device from Ureter, Percutaneous Endoscopic Approach */
"0TP94DZ" = "1" /* Removal of Intraluminal Device from Ureter, Percutaneous Endoscopic Approach */
"0TP94JZ" = "1" /* Removal of Synthetic Substitute from Ureter, Percutaneous Endoscopic Approach */
"0TP94KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Ureter, Percutaneous Endoscopic Approach */
"0TP94MZ" = "1" /* Removal of Stimulator Lead from Ureter, Percutaneous Endoscopic Approach */
"0TPB30Z" = "1" /* Removal of Drainage Device from Bladder, Percutaneous Approach */
"0TPB32Z" = "1" /* Removal of Monitoring Device from Bladder, Percutaneous Approach */
"0TPB33Z" = "1" /* Removal of Infusion Device from Bladder, Percutaneous Approach */
"0TPB37Z" = "1" /* Removal of Autologous Tissue Substitute from Bladder, Percutaneous Approach */
"0TPB3CZ" = "1" /* Removal of Extraluminal Device from Bladder, Percutaneous Approach */
"0TPB3DZ" = "1" /* Removal of Intraluminal Device from Bladder, Percutaneous Approach */
"0TPB3JZ" = "1" /* Removal of Synthetic Substitute from Bladder, Percutaneous Approach */
"0TPB3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Bladder, Percutaneous Approach */
"0TPB3LZ" = "1" /* Removal of Artificial Sphincter from Bladder, Percutaneous Approach */
"0TPB3MZ" = "1" /* Removal of Stimulator Lead from Bladder, Percutaneous Approach */
"0TPB40Z" = "1" /* Removal of Drainage Device from Bladder, Percutaneous Endoscopic Approach */
"0TPB42Z" = "1" /* Removal of Monitoring Device from Bladder, Percutaneous Endoscopic Approach */
"0TPB43Z" = "1" /* Removal of Infusion Device from Bladder, Percutaneous Endoscopic Approach */
"0TPB47Z" = "1" /* Removal of Autologous Tissue Substitute from Bladder, Percutaneous Endoscopic Approach */
"0TPB4CZ" = "1" /* Removal of Extraluminal Device from Bladder, Percutaneous Endoscopic Approach */
"0TPB4DZ" = "1" /* Removal of Intraluminal Device from Bladder, Percutaneous Endoscopic Approach */
"0TPB4JZ" = "1" /* Removal of Synthetic Substitute from Bladder, Percutaneous Endoscopic Approach */
"0TPB4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Bladder, Percutaneous Endoscopic Approach */
"0TPB4LZ" = "1" /* Removal of Artificial Sphincter from Bladder, Percutaneous Endoscopic Approach */
"0TPB4MZ" = "1" /* Removal of Stimulator Lead from Bladder, Percutaneous Endoscopic Approach */
"0TQ03ZZ" = "1" /* Repair Right Kidney, Percutaneous Approach */
"0TQ04ZZ" = "1" /* Repair Right Kidney, Percutaneous Endoscopic Approach */
"0TQ13ZZ" = "1" /* Repair Left Kidney, Percutaneous Approach */
"0TQ14ZZ" = "1" /* Repair Left Kidney, Percutaneous Endoscopic Approach */
"0TQ33ZZ" = "1" /* Repair Right Kidney Pelvis, Percutaneous Approach */
"0TQ34ZZ" = "1" /* Repair Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TQ43ZZ" = "1" /* Repair Left Kidney Pelvis, Percutaneous Approach */
"0TQ44ZZ" = "1" /* Repair Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TQ63ZZ" = "1" /* Repair Right Ureter, Percutaneous Approach */
"0TQ64ZZ" = "1" /* Repair Right Ureter, Percutaneous Endoscopic Approach */
"0TQ73ZZ" = "1" /* Repair Left Ureter, Percutaneous Approach */
"0TQ74ZZ" = "1" /* Repair Left Ureter, Percutaneous Endoscopic Approach */
"0TQB3ZZ" = "1" /* Repair Bladder, Percutaneous Approach */
"0TQB4ZZ" = "1" /* Repair Bladder, Percutaneous Endoscopic Approach */
"0TR347Z" = "1" /* Replacement of Right Kidney Pelvis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TR34JZ" = "1" /* Replacement of Right Kidney Pelvis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TR34KZ" = "1" /* Replacement of Right Kidney Pelvis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TR447Z" = "1" /* Replacement of Left Kidney Pelvis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TR44JZ" = "1" /* Replacement of Left Kidney Pelvis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TR44KZ" = "1" /* Replacement of Left Kidney Pelvis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TR647Z" = "1" /* Replacement of Right Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TR64JZ" = "1" /* Replacement of Right Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TR64KZ" = "1" /* Replacement of Right Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TR747Z" = "1" /* Replacement of Left Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TR74JZ" = "1" /* Replacement of Left Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TR74KZ" = "1" /* Replacement of Left Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TRB47Z" = "1" /* Replacement of Bladder with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TRB4JZ" = "1" /* Replacement of Bladder with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TRB4KZ" = "1" /* Replacement of Bladder with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TRC47Z" = "1" /* Replacement of Bladder Neck with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TRC4JZ" = "1" /* Replacement of Bladder Neck with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TRC4KZ" = "1" /* Replacement of Bladder Neck with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TS04ZZ" = "1" /* Reposition Right Kidney, Percutaneous Endoscopic Approach */
"0TS14ZZ" = "1" /* Reposition Left Kidney, Percutaneous Endoscopic Approach */
"0TS24ZZ" = "1" /* Reposition Bilateral Kidneys, Percutaneous Endoscopic Approach */
"0TS34ZZ" = "1" /* Reposition Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TS44ZZ" = "1" /* Reposition Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TS64ZZ" = "1" /* Reposition Right Ureter, Percutaneous Endoscopic Approach */
"0TS74ZZ" = "1" /* Reposition Left Ureter, Percutaneous Endoscopic Approach */
"0TS84ZZ" = "1" /* Reposition Bilateral Ureters, Percutaneous Endoscopic Approach */
"0TSB4ZZ" = "1" /* Reposition Bladder, Percutaneous Endoscopic Approach */
"0TT04ZZ" = "1" /* Resection of Right Kidney, Percutaneous Endoscopic Approach */
"0TT14ZZ" = "1" /* Resection of Left Kidney, Percutaneous Endoscopic Approach */
"0TT24ZZ" = "1" /* Resection of Bilateral Kidneys, Percutaneous Endoscopic Approach */
"0TT34ZZ" = "1" /* Resection of Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TT44ZZ" = "1" /* Resection of Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TT64ZZ" = "1" /* Resection of Right Ureter, Percutaneous Endoscopic Approach */
"0TT74ZZ" = "1" /* Resection of Left Ureter, Percutaneous Endoscopic Approach */
"0TTB4ZZ" = "1" /* Resection of Bladder, Percutaneous Endoscopic Approach */
"0TTD4ZZ" = "1" /* Resection of Urethra, Percutaneous Endoscopic Approach */
"0TU347Z" = "1" /* Supplement Right Kidney Pelvis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TU34JZ" = "1" /* Supplement Right Kidney Pelvis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TU34KZ" = "1" /* Supplement Right Kidney Pelvis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TU447Z" = "1" /* Supplement Left Kidney Pelvis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TU44JZ" = "1" /* Supplement Left Kidney Pelvis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TU44KZ" = "1" /* Supplement Left Kidney Pelvis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TU647Z" = "1" /* Supplement Right Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TU64JZ" = "1" /* Supplement Right Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TU64KZ" = "1" /* Supplement Right Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TU747Z" = "1" /* Supplement Left Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TU74JZ" = "1" /* Supplement Left Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TU74KZ" = "1" /* Supplement Left Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TUB47Z" = "1" /* Supplement Bladder with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TUB4JZ" = "1" /* Supplement Bladder with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TUB4KZ" = "1" /* Supplement Bladder with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TV33CZ" = "1" /* Restriction of Right Kidney Pelvis with Extraluminal Device, Percutaneous Approach */
"0TV33DZ" = "1" /* Restriction of Right Kidney Pelvis with Intraluminal Device, Percutaneous Approach */
"0TV33ZZ" = "1" /* Restriction of Right Kidney Pelvis, Percutaneous Approach */
"0TV34CZ" = "1" /* Restriction of Right Kidney Pelvis with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TV34DZ" = "1" /* Restriction of Right Kidney Pelvis with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TV34ZZ" = "1" /* Restriction of Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TV43CZ" = "1" /* Restriction of Left Kidney Pelvis with Extraluminal Device, Percutaneous Approach */
"0TV43DZ" = "1" /* Restriction of Left Kidney Pelvis with Intraluminal Device, Percutaneous Approach */
"0TV43ZZ" = "1" /* Restriction of Left Kidney Pelvis, Percutaneous Approach */
"0TV44CZ" = "1" /* Restriction of Left Kidney Pelvis with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TV44DZ" = "1" /* Restriction of Left Kidney Pelvis with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TV44ZZ" = "1" /* Restriction of Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TV63CZ" = "1" /* Restriction of Right Ureter with Extraluminal Device, Percutaneous Approach */
"0TV63DZ" = "1" /* Restriction of Right Ureter with Intraluminal Device, Percutaneous Approach */
"0TV63ZZ" = "1" /* Restriction of Right Ureter, Percutaneous Approach */
"0TV64CZ" = "1" /* Restriction of Right Ureter with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TV64DZ" = "1" /* Restriction of Right Ureter with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TV64ZZ" = "1" /* Restriction of Right Ureter, Percutaneous Endoscopic Approach */
"0TV73CZ" = "1" /* Restriction of Left Ureter with Extraluminal Device, Percutaneous Approach */
"0TV73DZ" = "1" /* Restriction of Left Ureter with Intraluminal Device, Percutaneous Approach */
"0TV73ZZ" = "1" /* Restriction of Left Ureter, Percutaneous Approach */
"0TV74CZ" = "1" /* Restriction of Left Ureter with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TV74DZ" = "1" /* Restriction of Left Ureter with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TV74ZZ" = "1" /* Restriction of Left Ureter, Percutaneous Endoscopic Approach */
"0TVB3CZ" = "1" /* Restriction of Bladder with Extraluminal Device, Percutaneous Approach */
"0TVB3DZ" = "1" /* Restriction of Bladder with Intraluminal Device, Percutaneous Approach */
"0TVB3ZZ" = "1" /* Restriction of Bladder, Percutaneous Approach */
"0TVB4CZ" = "1" /* Restriction of Bladder with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TVB4DZ" = "1" /* Restriction of Bladder with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TVB4ZZ" = "1" /* Restriction of Bladder, Percutaneous Endoscopic Approach */
"0TW530Z" = "1" /* Revision of Drainage Device in Kidney, Percutaneous Approach */
"0TW532Z" = "1" /* Revision of Monitoring Device in Kidney, Percutaneous Approach */
"0TW533Z" = "1" /* Revision of Infusion Device in Kidney, Percutaneous Approach */
"0TW537Z" = "1" /* Revision of Autologous Tissue Substitute in Kidney, Percutaneous Approach */
"0TW53CZ" = "1" /* Revision of Extraluminal Device in Kidney, Percutaneous Approach */
"0TW53DZ" = "1" /* Revision of Intraluminal Device in Kidney, Percutaneous Approach */
"0TW53JZ" = "1" /* Revision of Synthetic Substitute in Kidney, Percutaneous Approach */
"0TW53KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Kidney, Percutaneous Approach */
"0TW540Z" = "1" /* Revision of Drainage Device in Kidney, Percutaneous Endoscopic Approach */
"0TW542Z" = "1" /* Revision of Monitoring Device in Kidney, Percutaneous Endoscopic Approach */
"0TW543Z" = "1" /* Revision of Infusion Device in Kidney, Percutaneous Endoscopic Approach */
"0TW547Z" = "1" /* Revision of Autologous Tissue Substitute in Kidney, Percutaneous Endoscopic Approach */
"0TW54CZ" = "1" /* Revision of Extraluminal Device in Kidney, Percutaneous Endoscopic Approach */
"0TW54DZ" = "1" /* Revision of Intraluminal Device in Kidney, Percutaneous Endoscopic Approach */
"0TW54JZ" = "1" /* Revision of Synthetic Substitute in Kidney, Percutaneous Endoscopic Approach */
"0TW54KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Kidney, Percutaneous Endoscopic Approach */
"0TW930Z" = "1" /* Revision of Drainage Device in Ureter, Percutaneous Approach */
"0TW932Z" = "1" /* Revision of Monitoring Device in Ureter, Percutaneous Approach */
"0TW933Z" = "1" /* Revision of Infusion Device in Ureter, Percutaneous Approach */
"0TW937Z" = "1" /* Revision of Autologous Tissue Substitute in Ureter, Percutaneous Approach */
"0TW93CZ" = "1" /* Revision of Extraluminal Device in Ureter, Percutaneous Approach */
"0TW93DZ" = "1" /* Revision of Intraluminal Device in Ureter, Percutaneous Approach */
"0TW93JZ" = "1" /* Revision of Synthetic Substitute in Ureter, Percutaneous Approach */
"0TW93KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Ureter, Percutaneous Approach */
"0TW93MZ" = "1" /* Revision of Stimulator Lead in Ureter, Percutaneous Approach */
"0TW940Z" = "1" /* Revision of Drainage Device in Ureter, Percutaneous Endoscopic Approach */
"0TW942Z" = "1" /* Revision of Monitoring Device in Ureter, Percutaneous Endoscopic Approach */
"0TW943Z" = "1" /* Revision of Infusion Device in Ureter, Percutaneous Endoscopic Approach */
"0TW947Z" = "1" /* Revision of Autologous Tissue Substitute in Ureter, Percutaneous Endoscopic Approach */
"0TW94CZ" = "1" /* Revision of Extraluminal Device in Ureter, Percutaneous Endoscopic Approach */
"0TW94DZ" = "1" /* Revision of Intraluminal Device in Ureter, Percutaneous Endoscopic Approach */
"0TW94JZ" = "1" /* Revision of Synthetic Substitute in Ureter, Percutaneous Endoscopic Approach */
"0TW94KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Ureter, Percutaneous Endoscopic Approach */
"0TW94MZ" = "1" /* Revision of Stimulator Lead in Ureter, Percutaneous Endoscopic Approach */
"0TWB30Z" = "1" /* Revision of Drainage Device in Bladder, Percutaneous Approach */
"0TWB32Z" = "1" /* Revision of Monitoring Device in Bladder, Percutaneous Approach */
"0TWB33Z" = "1" /* Revision of Infusion Device in Bladder, Percutaneous Approach */
"0TWB37Z" = "1" /* Revision of Autologous Tissue Substitute in Bladder, Percutaneous Approach */
"0TWB3CZ" = "1" /* Revision of Extraluminal Device in Bladder, Percutaneous Approach */
"0TWB3DZ" = "1" /* Revision of Intraluminal Device in Bladder, Percutaneous Approach */
"0TWB3JZ" = "1" /* Revision of Synthetic Substitute in Bladder, Percutaneous Approach */
"0TWB3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Bladder, Percutaneous Approach */
"0TWB3LZ" = "1" /* Revision of Artificial Sphincter in Bladder, Percutaneous Approach */
"0TWB3MZ" = "1" /* Revision of Stimulator Lead in Bladder, Percutaneous Approach */
"0TWB40Z" = "1" /* Revision of Drainage Device in Bladder, Percutaneous Endoscopic Approach */
"0TWB42Z" = "1" /* Revision of Monitoring Device in Bladder, Percutaneous Endoscopic Approach */
"0TWB43Z" = "1" /* Revision of Infusion Device in Bladder, Percutaneous Endoscopic Approach */
"0TWB47Z" = "1" /* Revision of Autologous Tissue Substitute in Bladder, Percutaneous Endoscopic Approach */
"0TWB4CZ" = "1" /* Revision of Extraluminal Device in Bladder, Percutaneous Endoscopic Approach */
"0TWB4DZ" = "1" /* Revision of Intraluminal Device in Bladder, Percutaneous Endoscopic Approach */
"0TWB4JZ" = "1" /* Revision of Synthetic Substitute in Bladder, Percutaneous Endoscopic Approach */
"0TWB4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Bladder, Percutaneous Endoscopic Approach */
"0TWB4LZ" = "1" /* Revision of Artificial Sphincter in Bladder, Percutaneous Endoscopic Approach */
"0TWB4MZ" = "1" /* Revision of Stimulator Lead in Bladder, Percutaneous Endoscopic Approach */
"0U15475" = "1" /* Bypass Right Fallopian Tube to Right Fallopian Tube with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U15476" = "1" /* Bypass Right Fallopian Tube to Left Fallopian Tube with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U15479" = "1" /* Bypass Right Fallopian Tube to Uterus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U154J5" = "1" /* Bypass Right Fallopian Tube to Right Fallopian Tube with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0U154J6" = "1" /* Bypass Right Fallopian Tube to Left Fallopian Tube with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0U154J9" = "1" /* Bypass Right Fallopian Tube to Uterus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0U154K5" = "1" /* Bypass Right Fallopian Tube to Right Fallopian Tube with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U154K6" = "1" /* Bypass Right Fallopian Tube to Left Fallopian Tube with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U154K9" = "1" /* Bypass Right Fallopian Tube to Uterus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U154Z5" = "1" /* Bypass Right Fallopian Tube to Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0U154Z6" = "1" /* Bypass Right Fallopian Tube to Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0U154Z9" = "1" /* Bypass Right Fallopian Tube to Uterus, Percutaneous Endoscopic Approach */
"0U16475" = "1" /* Bypass Left Fallopian Tube to Right Fallopian Tube with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U16476" = "1" /* Bypass Left Fallopian Tube to Left Fallopian Tube with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U16479" = "1" /* Bypass Left Fallopian Tube to Uterus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U164J5" = "1" /* Bypass Left Fallopian Tube to Right Fallopian Tube with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0U164J6" = "1" /* Bypass Left Fallopian Tube to Left Fallopian Tube with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0U164J9" = "1" /* Bypass Left Fallopian Tube to Uterus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0U164K5" = "1" /* Bypass Left Fallopian Tube to Right Fallopian Tube with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U164K6" = "1" /* Bypass Left Fallopian Tube to Left Fallopian Tube with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U164K9" = "1" /* Bypass Left Fallopian Tube to Uterus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U164Z5" = "1" /* Bypass Left Fallopian Tube to Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0U164Z6" = "1" /* Bypass Left Fallopian Tube to Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0U164Z9" = "1" /* Bypass Left Fallopian Tube to Uterus, Percutaneous Endoscopic Approach */
"0U503ZZ" = "1" /* Destruction of Right Ovary, Percutaneous Approach */
"0U504ZZ" = "1" /* Destruction of Right Ovary, Percutaneous Endoscopic Approach */
"0U513ZZ" = "1" /* Destruction of Left Ovary, Percutaneous Approach */
"0U514ZZ" = "1" /* Destruction of Left Ovary, Percutaneous Endoscopic Approach */
"0U523ZZ" = "1" /* Destruction of Bilateral Ovaries, Percutaneous Approach */
"0U524ZZ" = "1" /* Destruction of Bilateral Ovaries, Percutaneous Endoscopic Approach */
"0U543ZZ" = "1" /* Destruction of Uterine Supporting Structure, Percutaneous Approach */
"0U544ZZ" = "1" /* Destruction of Uterine Supporting Structure, Percutaneous Endoscopic Approach */
"0U553ZZ" = "1" /* Destruction of Right Fallopian Tube, Percutaneous Approach */
"0U554ZZ" = "1" /* Destruction of Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0U563ZZ" = "1" /* Destruction of Left Fallopian Tube, Percutaneous Approach */
"0U564ZZ" = "1" /* Destruction of Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0U573ZZ" = "1" /* Destruction of Bilateral Fallopian Tubes, Percutaneous Approach */
"0U574ZZ" = "1" /* Destruction of Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0U593ZZ" = "1" /* Destruction of Uterus, Percutaneous Approach */
"0U594ZZ" = "1" /* Destruction of Uterus, Percutaneous Endoscopic Approach */
"0U5B3ZZ" = "1" /* Destruction of Endometrium, Percutaneous Approach */
"0U5B4ZZ" = "1" /* Destruction of Endometrium, Percutaneous Endoscopic Approach */
"0U5C3ZZ" = "1" /* Destruction of Cervix, Percutaneous Approach */
"0U5C4ZZ" = "1" /* Destruction of Cervix, Percutaneous Endoscopic Approach */
"0U753DZ" = "1" /* Dilation of Right Fallopian Tube with Intraluminal Device, Percutaneous Approach */
"0U753ZZ" = "1" /* Dilation of Right Fallopian Tube, Percutaneous Approach */
"0U754DZ" = "1" /* Dilation of Right Fallopian Tube with Intraluminal Device, Percutaneous Endoscopic Approach */
"0U754ZZ" = "1" /* Dilation of Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0U763DZ" = "1" /* Dilation of Left Fallopian Tube with Intraluminal Device, Percutaneous Approach */
"0U763ZZ" = "1" /* Dilation of Left Fallopian Tube, Percutaneous Approach */
"0U764DZ" = "1" /* Dilation of Left Fallopian Tube with Intraluminal Device, Percutaneous Endoscopic Approach */
"0U764ZZ" = "1" /* Dilation of Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0U773DZ" = "1" /* Dilation of Bilateral Fallopian Tubes with Intraluminal Device, Percutaneous Approach */
"0U773ZZ" = "1" /* Dilation of Bilateral Fallopian Tubes, Percutaneous Approach */
"0U774DZ" = "1" /* Dilation of Bilateral Fallopian Tubes with Intraluminal Device, Percutaneous Endoscopic Approach */
"0U774ZZ" = "1" /* Dilation of Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0U793DZ" = "1" /* Dilation of Uterus with Intraluminal Device, Percutaneous Approach */
"0U793ZZ" = "1" /* Dilation of Uterus, Percutaneous Approach */
"0U794DZ" = "1" /* Dilation of Uterus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0U794ZZ" = "1" /* Dilation of Uterus, Percutaneous Endoscopic Approach */
"0U7C3DZ" = "1" /* Dilation of Cervix with Intraluminal Device, Percutaneous Approach */
"0U7C3ZZ" = "1" /* Dilation of Cervix, Percutaneous Approach */
"0U7C4DZ" = "1" /* Dilation of Cervix with Intraluminal Device, Percutaneous Endoscopic Approach */
"0U7C4ZZ" = "1" /* Dilation of Cervix, Percutaneous Endoscopic Approach */
"0U803ZZ" = "1" /* Division of Right Ovary, Percutaneous Approach */
"0U804ZZ" = "1" /* Division of Right Ovary, Percutaneous Endoscopic Approach */
"0U813ZZ" = "1" /* Division of Left Ovary, Percutaneous Approach */
"0U814ZZ" = "1" /* Division of Left Ovary, Percutaneous Endoscopic Approach */
"0U823ZZ" = "1" /* Division of Bilateral Ovaries, Percutaneous Approach */
"0U824ZZ" = "1" /* Division of Bilateral Ovaries, Percutaneous Endoscopic Approach */
"0U843ZZ" = "1" /* Division of Uterine Supporting Structure, Percutaneous Approach */
"0U844ZZ" = "1" /* Division of Uterine Supporting Structure, Percutaneous Endoscopic Approach */
"0U9030Z" = "1" /* Drainage of Right Ovary with Drainage Device, Percutaneous Approach */
"0U903ZX" = "1" /* Drainage of Right Ovary, Percutaneous Approach, Diagnostic */
"0U903ZZ" = "1" /* Drainage of Right Ovary, Percutaneous Approach */
"0U9040Z" = "1" /* Drainage of Right Ovary with Drainage Device, Percutaneous Endoscopic Approach */
"0U904ZX" = "1" /* Drainage of Right Ovary, Percutaneous Endoscopic Approach, Diagnostic */
"0U904ZZ" = "1" /* Drainage of Right Ovary, Percutaneous Endoscopic Approach */
"0U9130Z" = "1" /* Drainage of Left Ovary with Drainage Device, Percutaneous Approach */
"0U913ZX" = "1" /* Drainage of Left Ovary, Percutaneous Approach, Diagnostic */
"0U913ZZ" = "1" /* Drainage of Left Ovary, Percutaneous Approach */
"0U9140Z" = "1" /* Drainage of Left Ovary with Drainage Device, Percutaneous Endoscopic Approach */
"0U914ZX" = "1" /* Drainage of Left Ovary, Percutaneous Endoscopic Approach, Diagnostic */
"0U914ZZ" = "1" /* Drainage of Left Ovary, Percutaneous Endoscopic Approach */
"0U9230Z" = "1" /* Drainage of Bilateral Ovaries with Drainage Device, Percutaneous Approach */
"0U923ZX" = "1" /* Drainage of Bilateral Ovaries, Percutaneous Approach, Diagnostic */
"0U923ZZ" = "1" /* Drainage of Bilateral Ovaries, Percutaneous Approach */
"0U9240Z" = "1" /* Drainage of Bilateral Ovaries with Drainage Device, Percutaneous Endoscopic Approach */
"0U924ZX" = "1" /* Drainage of Bilateral Ovaries, Percutaneous Endoscopic Approach, Diagnostic */
"0U924ZZ" = "1" /* Drainage of Bilateral Ovaries, Percutaneous Endoscopic Approach */
"0U9430Z" = "1" /* Drainage of Uterine Supporting Structure with Drainage Device, Percutaneous Approach */
"0U943ZX" = "1" /* Drainage of Uterine Supporting Structure, Percutaneous Approach, Diagnostic */
"0U943ZZ" = "1" /* Drainage of Uterine Supporting Structure, Percutaneous Approach */
"0U9440Z" = "1" /* Drainage of Uterine Supporting Structure with Drainage Device, Percutaneous Endoscopic Approach */
"0U944ZX" = "1" /* Drainage of Uterine Supporting Structure, Percutaneous Endoscopic Approach, Diagnostic */
"0U944ZZ" = "1" /* Drainage of Uterine Supporting Structure, Percutaneous Endoscopic Approach */
"0U9530Z" = "1" /* Drainage of Right Fallopian Tube with Drainage Device, Percutaneous Approach */
"0U953ZX" = "1" /* Drainage of Right Fallopian Tube, Percutaneous Approach, Diagnostic */
"0U953ZZ" = "1" /* Drainage of Right Fallopian Tube, Percutaneous Approach */
"0U9540Z" = "1" /* Drainage of Right Fallopian Tube with Drainage Device, Percutaneous Endoscopic Approach */
"0U954ZX" = "1" /* Drainage of Right Fallopian Tube, Percutaneous Endoscopic Approach, Diagnostic */
"0U954ZZ" = "1" /* Drainage of Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0U9630Z" = "1" /* Drainage of Left Fallopian Tube with Drainage Device, Percutaneous Approach */
"0U963ZX" = "1" /* Drainage of Left Fallopian Tube, Percutaneous Approach, Diagnostic */
"0U963ZZ" = "1" /* Drainage of Left Fallopian Tube, Percutaneous Approach */
"0U9640Z" = "1" /* Drainage of Left Fallopian Tube with Drainage Device, Percutaneous Endoscopic Approach */
"0U964ZX" = "1" /* Drainage of Left Fallopian Tube, Percutaneous Endoscopic Approach, Diagnostic */
"0U964ZZ" = "1" /* Drainage of Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0U9730Z" = "1" /* Drainage of Bilateral Fallopian Tubes with Drainage Device, Percutaneous Approach */
"0U973ZX" = "1" /* Drainage of Bilateral Fallopian Tubes, Percutaneous Approach, Diagnostic */
"0U973ZZ" = "1" /* Drainage of Bilateral Fallopian Tubes, Percutaneous Approach */
"0U9740Z" = "1" /* Drainage of Bilateral Fallopian Tubes with Drainage Device, Percutaneous Endoscopic Approach */
"0U974ZX" = "1" /* Drainage of Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach, Diagnostic */
"0U974ZZ" = "1" /* Drainage of Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0U9930Z" = "1" /* Drainage of Uterus with Drainage Device, Percutaneous Approach */
"0U993ZX" = "1" /* Drainage of Uterus, Percutaneous Approach, Diagnostic */
"0U993ZZ" = "1" /* Drainage of Uterus, Percutaneous Approach */
"0U9940Z" = "1" /* Drainage of Uterus with Drainage Device, Percutaneous Endoscopic Approach */
"0U994ZX" = "1" /* Drainage of Uterus, Percutaneous Endoscopic Approach, Diagnostic */
"0U994ZZ" = "1" /* Drainage of Uterus, Percutaneous Endoscopic Approach */
"0U9C30Z" = "1" /* Drainage of Cervix with Drainage Device, Percutaneous Approach */
"0U9C3ZX" = "1" /* Drainage of Cervix, Percutaneous Approach, Diagnostic */
"0U9C3ZZ" = "1" /* Drainage of Cervix, Percutaneous Approach */
"0U9C40Z" = "1" /* Drainage of Cervix with Drainage Device, Percutaneous Endoscopic Approach */
"0U9C4ZX" = "1" /* Drainage of Cervix, Percutaneous Endoscopic Approach, Diagnostic */
"0U9C4ZZ" = "1" /* Drainage of Cervix, Percutaneous Endoscopic Approach */
"0UB03ZX" = "1" /* Excision of Right Ovary, Percutaneous Approach, Diagnostic */
"0UB03ZZ" = "1" /* Excision of Right Ovary, Percutaneous Approach */
"0UB04ZX" = "1" /* Excision of Right Ovary, Percutaneous Endoscopic Approach, Diagnostic */
"0UB04ZZ" = "1" /* Excision of Right Ovary, Percutaneous Endoscopic Approach */
"0UB13ZX" = "1" /* Excision of Left Ovary, Percutaneous Approach, Diagnostic */
"0UB13ZZ" = "1" /* Excision of Left Ovary, Percutaneous Approach */
"0UB14ZX" = "1" /* Excision of Left Ovary, Percutaneous Endoscopic Approach, Diagnostic */
"0UB14ZZ" = "1" /* Excision of Left Ovary, Percutaneous Endoscopic Approach */
"0UB23ZX" = "1" /* Excision of Bilateral Ovaries, Percutaneous Approach, Diagnostic */
"0UB23ZZ" = "1" /* Excision of Bilateral Ovaries, Percutaneous Approach */
"0UB24ZX" = "1" /* Excision of Bilateral Ovaries, Percutaneous Endoscopic Approach, Diagnostic */
"0UB24ZZ" = "1" /* Excision of Bilateral Ovaries, Percutaneous Endoscopic Approach */
"0UB43ZX" = "1" /* Excision of Uterine Supporting Structure, Percutaneous Approach, Diagnostic */
"0UB43ZZ" = "1" /* Excision of Uterine Supporting Structure, Percutaneous Approach */
"0UB44ZX" = "1" /* Excision of Uterine Supporting Structure, Percutaneous Endoscopic Approach, Diagnostic */
"0UB44ZZ" = "1" /* Excision of Uterine Supporting Structure, Percutaneous Endoscopic Approach */
"0UB53ZX" = "1" /* Excision of Right Fallopian Tube, Percutaneous Approach, Diagnostic */
"0UB53ZZ" = "1" /* Excision of Right Fallopian Tube, Percutaneous Approach */
"0UB54ZX" = "1" /* Excision of Right Fallopian Tube, Percutaneous Endoscopic Approach, Diagnostic */
"0UB54ZZ" = "1" /* Excision of Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0UB63ZX" = "1" /* Excision of Left Fallopian Tube, Percutaneous Approach, Diagnostic */
"0UB63ZZ" = "1" /* Excision of Left Fallopian Tube, Percutaneous Approach */
"0UB64ZX" = "1" /* Excision of Left Fallopian Tube, Percutaneous Endoscopic Approach, Diagnostic */
"0UB64ZZ" = "1" /* Excision of Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0UB73ZX" = "1" /* Excision of Bilateral Fallopian Tubes, Percutaneous Approach, Diagnostic */
"0UB73ZZ" = "1" /* Excision of Bilateral Fallopian Tubes, Percutaneous Approach */
"0UB74ZX" = "1" /* Excision of Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach, Diagnostic */
"0UB74ZZ" = "1" /* Excision of Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0UB93ZX" = "1" /* Excision of Uterus, Percutaneous Approach, Diagnostic */
"0UB93ZZ" = "1" /* Excision of Uterus, Percutaneous Approach */
"0UB94ZX" = "1" /* Excision of Uterus, Percutaneous Endoscopic Approach, Diagnostic */
"0UB94ZZ" = "1" /* Excision of Uterus, Percutaneous Endoscopic Approach */
"0UBC3ZX" = "1" /* Excision of Cervix, Percutaneous Approach, Diagnostic */
"0UBC3ZZ" = "1" /* Excision of Cervix, Percutaneous Approach */
"0UBC4ZX" = "1" /* Excision of Cervix, Percutaneous Endoscopic Approach, Diagnostic */
"0UBC4ZZ" = "1" /* Excision of Cervix, Percutaneous Endoscopic Approach */
"0UC03ZZ" = "1" /* Extirpation of Matter from Right Ovary, Percutaneous Approach */
"0UC04ZZ" = "1" /* Extirpation of Matter from Right Ovary, Percutaneous Endoscopic Approach */
"0UC13ZZ" = "1" /* Extirpation of Matter from Left Ovary, Percutaneous Approach */
"0UC14ZZ" = "1" /* Extirpation of Matter from Left Ovary, Percutaneous Endoscopic Approach */
"0UC23ZZ" = "1" /* Extirpation of Matter from Bilateral Ovaries, Percutaneous Approach */
"0UC24ZZ" = "1" /* Extirpation of Matter from Bilateral Ovaries, Percutaneous Endoscopic Approach */
"0UC43ZZ" = "1" /* Extirpation of Matter from Uterine Supporting Structure, Percutaneous Approach */
"0UC44ZZ" = "1" /* Extirpation of Matter from Uterine Supporting Structure, Percutaneous Endoscopic Approach */
"0UC53ZZ" = "1" /* Extirpation of Matter from Right Fallopian Tube, Percutaneous Approach */
"0UC54ZZ" = "1" /* Extirpation of Matter from Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0UC63ZZ" = "1" /* Extirpation of Matter from Left Fallopian Tube, Percutaneous Approach */
"0UC64ZZ" = "1" /* Extirpation of Matter from Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0UC73ZZ" = "1" /* Extirpation of Matter from Bilateral Fallopian Tubes, Percutaneous Approach */
"0UC74ZZ" = "1" /* Extirpation of Matter from Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0UC93ZZ" = "1" /* Extirpation of Matter from Uterus, Percutaneous Approach */
"0UC94ZZ" = "1" /* Extirpation of Matter from Uterus, Percutaneous Endoscopic Approach */
"0UCB3ZZ" = "1" /* Extirpation of Matter from Endometrium, Percutaneous Approach */
"0UCB4ZZ" = "1" /* Extirpation of Matter from Endometrium, Percutaneous Endoscopic Approach */
"0UCC3ZZ" = "1" /* Extirpation of Matter from Cervix, Percutaneous Approach */
"0UCC4ZZ" = "1" /* Extirpation of Matter from Cervix, Percutaneous Endoscopic Approach */
"0UF53ZZ" = "1" /* Fragmentation in Right Fallopian Tube, Percutaneous Approach */
"0UF54ZZ" = "1" /* Fragmentation in Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0UF63ZZ" = "1" /* Fragmentation in Left Fallopian Tube, Percutaneous Approach */
"0UF64ZZ" = "1" /* Fragmentation in Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0UF73ZZ" = "1" /* Fragmentation in Bilateral Fallopian Tubes, Percutaneous Approach */
"0UF74ZZ" = "1" /* Fragmentation in Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0UF93ZZ" = "1" /* Fragmentation in Uterus, Percutaneous Approach */
"0UF94ZZ" = "1" /* Fragmentation in Uterus, Percutaneous Endoscopic Approach */
"0UH333Z" = "1" /* Insertion of Infusion Device into Ovary, Percutaneous Approach */
"0UH343Z" = "1" /* Insertion of Infusion Device into Ovary, Percutaneous Endoscopic Approach */
"0UH833Z" = "1" /* Insertion of Infusion Device into Fallopian Tube, Percutaneous Approach */
"0UH843Z" = "1" /* Insertion of Infusion Device into Fallopian Tube, Percutaneous Endoscopic Approach */
"0UHC31Z" = "1" /* Insertion of Radioactive Element into Cervix, Percutaneous Approach */
"0UHC41Z" = "1" /* Insertion of Radioactive Element into Cervix, Percutaneous Endoscopic Approach */
"0UHD33Z" = "1" /* Insertion of Infusion Device into Uterus and Cervix, Percutaneous Approach */
"0UHD43Z" = "1" /* Insertion of Infusion Device into Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UJ33ZZ" = "1" /* Inspection of Ovary, Percutaneous Approach */
"0UJ34ZZ" = "1" /* Inspection of Ovary, Percutaneous Endoscopic Approach */
"0UJ83ZZ" = "1" /* Inspection of Fallopian Tube, Percutaneous Approach */
"0UJ84ZZ" = "1" /* Inspection of Fallopian Tube, Percutaneous Endoscopic Approach */
"0UJD3ZZ" = "1" /* Inspection of Uterus and Cervix, Percutaneous Approach */
"0UJD4ZZ" = "1" /* Inspection of Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UL53CZ" = "1" /* Occlusion of Right Fallopian Tube with Extraluminal Device, Percutaneous Approach */
"0UL53DZ" = "1" /* Occlusion of Right Fallopian Tube with Intraluminal Device, Percutaneous Approach */
"0UL53ZZ" = "1" /* Occlusion of Right Fallopian Tube, Percutaneous Approach */
"0UL54CZ" = "1" /* Occlusion of Right Fallopian Tube with Extraluminal Device, Percutaneous Endoscopic Approach */
"0UL54DZ" = "1" /* Occlusion of Right Fallopian Tube with Intraluminal Device, Percutaneous Endoscopic Approach */
"0UL54ZZ" = "1" /* Occlusion of Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0UL63CZ" = "1" /* Occlusion of Left Fallopian Tube with Extraluminal Device, Percutaneous Approach */
"0UL63DZ" = "1" /* Occlusion of Left Fallopian Tube with Intraluminal Device, Percutaneous Approach */
"0UL63ZZ" = "1" /* Occlusion of Left Fallopian Tube, Percutaneous Approach */
"0UL64CZ" = "1" /* Occlusion of Left Fallopian Tube with Extraluminal Device, Percutaneous Endoscopic Approach */
"0UL64DZ" = "1" /* Occlusion of Left Fallopian Tube with Intraluminal Device, Percutaneous Endoscopic Approach */
"0UL64ZZ" = "1" /* Occlusion of Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0UL73CZ" = "1" /* Occlusion of Bilateral Fallopian Tubes with Extraluminal Device, Percutaneous Approach */
"0UL73DZ" = "1" /* Occlusion of Bilateral Fallopian Tubes with Intraluminal Device, Percutaneous Approach */
"0UL73ZZ" = "1" /* Occlusion of Bilateral Fallopian Tubes, Percutaneous Approach */
"0UL74CZ" = "1" /* Occlusion of Bilateral Fallopian Tubes with Extraluminal Device, Percutaneous Endoscopic Approach */
"0UL74DZ" = "1" /* Occlusion of Bilateral Fallopian Tubes with Intraluminal Device, Percutaneous Endoscopic Approach */
"0UL74ZZ" = "1" /* Occlusion of Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0UM04ZZ" = "1" /* Reattachment of Right Ovary, Percutaneous Endoscopic Approach */
"0UM14ZZ" = "1" /* Reattachment of Left Ovary, Percutaneous Endoscopic Approach */
"0UM24ZZ" = "1" /* Reattachment of Bilateral Ovaries, Percutaneous Endoscopic Approach */
"0UM44ZZ" = "1" /* Reattachment of Uterine Supporting Structure, Percutaneous Endoscopic Approach */
"0UM54ZZ" = "1" /* Reattachment of Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0UM64ZZ" = "1" /* Reattachment of Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0UM74ZZ" = "1" /* Reattachment of Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0UM94ZZ" = "1" /* Reattachment of Uterus, Percutaneous Endoscopic Approach */
"0UMC4ZZ" = "1" /* Reattachment of Cervix, Percutaneous Endoscopic Approach */
"0UN03ZZ" = "1" /* Release Right Ovary, Percutaneous Approach */
"0UN04ZZ" = "1" /* Release Right Ovary, Percutaneous Endoscopic Approach */
"0UN13ZZ" = "1" /* Release Left Ovary, Percutaneous Approach */
"0UN14ZZ" = "1" /* Release Left Ovary, Percutaneous Endoscopic Approach */
"0UN23ZZ" = "1" /* Release Bilateral Ovaries, Percutaneous Approach */
"0UN24ZZ" = "1" /* Release Bilateral Ovaries, Percutaneous Endoscopic Approach */
"0UN43ZZ" = "1" /* Release Uterine Supporting Structure, Percutaneous Approach */
"0UN44ZZ" = "1" /* Release Uterine Supporting Structure, Percutaneous Endoscopic Approach */
"0UN53ZZ" = "1" /* Release Right Fallopian Tube, Percutaneous Approach */
"0UN54ZZ" = "1" /* Release Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0UN63ZZ" = "1" /* Release Left Fallopian Tube, Percutaneous Approach */
"0UN64ZZ" = "1" /* Release Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0UN73ZZ" = "1" /* Release Bilateral Fallopian Tubes, Percutaneous Approach */
"0UN74ZZ" = "1" /* Release Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0UN93ZZ" = "1" /* Release Uterus, Percutaneous Approach */
"0UN94ZZ" = "1" /* Release Uterus, Percutaneous Endoscopic Approach */
"0UNC3ZZ" = "1" /* Release Cervix, Percutaneous Approach */
"0UNC4ZZ" = "1" /* Release Cervix, Percutaneous Endoscopic Approach */
"0UP330Z" = "1" /* Removal of Drainage Device from Ovary, Percutaneous Approach */
"0UP333Z" = "1" /* Removal of Infusion Device from Ovary, Percutaneous Approach */
"0UP340Z" = "1" /* Removal of Drainage Device from Ovary, Percutaneous Endoscopic Approach */
"0UP343Z" = "1" /* Removal of Infusion Device from Ovary, Percutaneous Endoscopic Approach */
"0UP830Z" = "1" /* Removal of Drainage Device from Fallopian Tube, Percutaneous Approach */
"0UP833Z" = "1" /* Removal of Infusion Device from Fallopian Tube, Percutaneous Approach */
"0UP837Z" = "1" /* Removal of Autologous Tissue Substitute from Fallopian Tube, Percutaneous Approach */
"0UP83CZ" = "1" /* Removal of Extraluminal Device from Fallopian Tube, Percutaneous Approach */
"0UP83DZ" = "1" /* Removal of Intraluminal Device from Fallopian Tube, Percutaneous Approach */
"0UP83JZ" = "1" /* Removal of Synthetic Substitute from Fallopian Tube, Percutaneous Approach */
"0UP83KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Fallopian Tube, Percutaneous Approach */
"0UP840Z" = "1" /* Removal of Drainage Device from Fallopian Tube, Percutaneous Endoscopic Approach */
"0UP843Z" = "1" /* Removal of Infusion Device from Fallopian Tube, Percutaneous Endoscopic Approach */
"0UP847Z" = "1" /* Removal of Autologous Tissue Substitute from Fallopian Tube, Percutaneous Endoscopic Approach */
"0UP84CZ" = "1" /* Removal of Extraluminal Device from Fallopian Tube, Percutaneous Endoscopic Approach */
"0UP84DZ" = "1" /* Removal of Intraluminal Device from Fallopian Tube, Percutaneous Endoscopic Approach */
"0UP84JZ" = "1" /* Removal of Synthetic Substitute from Fallopian Tube, Percutaneous Endoscopic Approach */
"0UP84KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Fallopian Tube, Percutaneous Endoscopic Approach */
"0UPD30Z" = "1" /* Removal of Drainage Device from Uterus and Cervix, Percutaneous Approach */
"0UPD31Z" = "1" /* Removal of Radioactive Element from Uterus and Cervix, Percutaneous Approach */
"0UPD33Z" = "1" /* Removal of Infusion Device from Uterus and Cervix, Percutaneous Approach */
"0UPD37Z" = "1" /* Removal of Autologous Tissue Substitute from Uterus and Cervix, Percutaneous Approach */
"0UPD3CZ" = "1" /* Removal of Extraluminal Device from Uterus and Cervix, Percutaneous Approach */
"0UPD3DZ" = "1" /* Removal of Intraluminal Device from Uterus and Cervix, Percutaneous Approach */
"0UPD3HZ" = "1" /* Removal of Contraceptive Device from Uterus and Cervix, Percutaneous Approach */
"0UPD3JZ" = "1" /* Removal of Synthetic Substitute from Uterus and Cervix, Percutaneous Approach */
"0UPD3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Uterus and Cervix, Percutaneous Approach */
"0UPD40Z" = "1" /* Removal of Drainage Device from Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UPD41Z" = "1" /* Removal of Radioactive Element from Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UPD43Z" = "1" /* Removal of Infusion Device from Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UPD47Z" = "1" /* Removal of Autologous Tissue Substitute from Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UPD4CZ" = "1" /* Removal of Extraluminal Device from Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UPD4DZ" = "1" /* Removal of Intraluminal Device from Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UPD4HZ" = "1" /* Removal of Contraceptive Device from Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UPD4JZ" = "1" /* Removal of Synthetic Substitute from Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UPD4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UQ03ZZ" = "1" /* Repair Right Ovary, Percutaneous Approach */
"0UQ04ZZ" = "1" /* Repair Right Ovary, Percutaneous Endoscopic Approach */
"0UQ13ZZ" = "1" /* Repair Left Ovary, Percutaneous Approach */
"0UQ14ZZ" = "1" /* Repair Left Ovary, Percutaneous Endoscopic Approach */
"0UQ23ZZ" = "1" /* Repair Bilateral Ovaries, Percutaneous Approach */
"0UQ24ZZ" = "1" /* Repair Bilateral Ovaries, Percutaneous Endoscopic Approach */
"0UQ43ZZ" = "1" /* Repair Uterine Supporting Structure, Percutaneous Approach */
"0UQ44ZZ" = "1" /* Repair Uterine Supporting Structure, Percutaneous Endoscopic Approach */
"0UQ53ZZ" = "1" /* Repair Right Fallopian Tube, Percutaneous Approach */
"0UQ54ZZ" = "1" /* Repair Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0UQ63ZZ" = "1" /* Repair Left Fallopian Tube, Percutaneous Approach */
"0UQ64ZZ" = "1" /* Repair Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0UQ73ZZ" = "1" /* Repair Bilateral Fallopian Tubes, Percutaneous Approach */
"0UQ74ZZ" = "1" /* Repair Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0UQ93ZZ" = "1" /* Repair Uterus, Percutaneous Approach */
"0UQ94ZZ" = "1" /* Repair Uterus, Percutaneous Endoscopic Approach */
"0UQC3ZZ" = "1" /* Repair Cervix, Percutaneous Approach */
"0UQC4ZZ" = "1" /* Repair Cervix, Percutaneous Endoscopic Approach */
"0UQG3ZZ" = "1" /* Repair Vagina, Percutaneous Approach */
"0UQG4ZZ" = "1" /* Repair Vagina, Percutaneous Endoscopic Approach */
"0US04ZZ" = "1" /* Reposition Right Ovary, Percutaneous Endoscopic Approach */
"0US14ZZ" = "1" /* Reposition Left Ovary, Percutaneous Endoscopic Approach */
"0US24ZZ" = "1" /* Reposition Bilateral Ovaries, Percutaneous Endoscopic Approach */
"0US44ZZ" = "1" /* Reposition Uterine Supporting Structure, Percutaneous Endoscopic Approach */
"0US54ZZ" = "1" /* Reposition Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0US64ZZ" = "1" /* Reposition Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0US74ZZ" = "1" /* Reposition Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0US94ZZ" = "1" /* Reposition Uterus, Percutaneous Endoscopic Approach */
"0USC4ZZ" = "1" /* Reposition Cervix, Percutaneous Endoscopic Approach */
"0UT04ZZ" = "1" /* Resection of Right Ovary, Percutaneous Endoscopic Approach */
"0UT0FZZ" = "1" /* Resection of Right Ovary, Via Natural or Artificial Opening With Percutaneous Endoscopic Assistance */
"0UT14ZZ" = "1" /* Resection of Left Ovary, Percutaneous Endoscopic Approach */
"0UT1FZZ" = "1" /* Resection of Left Ovary, Via Natural or Artificial Opening With Percutaneous Endoscopic Assistance */
"0UT24ZZ" = "1" /* Resection of Bilateral Ovaries, Percutaneous Endoscopic Approach */
"0UT2FZZ" = "1" /* Resection of Bilateral Ovaries, Via Natural or Artificial Opening With Percutaneous Endoscopic Assistance */
"0UT44ZZ" = "1" /* Resection of Uterine Supporting Structure, Percutaneous Endoscopic Approach */
"0UT54ZZ" = "1" /* Resection of Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0UT5FZZ" = "1" /* Resection of Right Fallopian Tube, Via Natural or Artificial Opening With Percutaneous Endoscopic Assistance */
"0UT64ZZ" = "1" /* Resection of Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0UT6FZZ" = "1" /* Resection of Left Fallopian Tube, Via Natural or Artificial Opening With Percutaneous Endoscopic Assistance */
"0UT74ZZ" = "1" /* Resection of Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0UT7FZZ" = "1" /* Resection of Bilateral Fallopian Tubes, Via Natural or Artificial Opening With Percutaneous Endoscopic Assistance */
"0UT94ZZ" = "1" /* Resection of Uterus, Percutaneous Endoscopic Approach */
"0UT9FZZ" = "1" /* Resection of Uterus, Via Natural or Artificial Opening With Percutaneous Endoscopic Assistance */
"0UTC4ZZ" = "1" /* Resection of Cervix, Percutaneous Endoscopic Approach */
"0UU447Z" = "1" /* Supplement Uterine Supporting Structure with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0UU44JZ" = "1" /* Supplement Uterine Supporting Structure with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0UU44KZ" = "1" /* Supplement Uterine Supporting Structure with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0UU547Z" = "1" /* Supplement Right Fallopian Tube with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0UU54JZ" = "1" /* Supplement Right Fallopian Tube with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0UU54KZ" = "1" /* Supplement Right Fallopian Tube with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0UU647Z" = "1" /* Supplement Left Fallopian Tube with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0UU64JZ" = "1" /* Supplement Left Fallopian Tube with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0UU64KZ" = "1" /* Supplement Left Fallopian Tube with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0UU747Z" = "1" /* Supplement Bilateral Fallopian Tubes with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0UU74JZ" = "1" /* Supplement Bilateral Fallopian Tubes with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0UU74KZ" = "1" /* Supplement Bilateral Fallopian Tubes with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0UVC3CZ" = "1" /* Restriction of Cervix with Extraluminal Device, Percutaneous Approach */
"0UVC3DZ" = "1" /* Restriction of Cervix with Intraluminal Device, Percutaneous Approach */
"0UVC3ZZ" = "1" /* Restriction of Cervix, Percutaneous Approach */
"0UVC4CZ" = "1" /* Restriction of Cervix with Extraluminal Device, Percutaneous Endoscopic Approach */
"0UVC4DZ" = "1" /* Restriction of Cervix with Intraluminal Device, Percutaneous Endoscopic Approach */
"0UVC4ZZ" = "1" /* Restriction of Cervix, Percutaneous Endoscopic Approach */
"0UW330Z" = "1" /* Revision of Drainage Device in Ovary, Percutaneous Approach */
"0UW333Z" = "1" /* Revision of Infusion Device in Ovary, Percutaneous Approach */
"0UW340Z" = "1" /* Revision of Drainage Device in Ovary, Percutaneous Endoscopic Approach */
"0UW343Z" = "1" /* Revision of Infusion Device in Ovary, Percutaneous Endoscopic Approach */
"0UW830Z" = "1" /* Revision of Drainage Device in Fallopian Tube, Percutaneous Approach */
"0UW833Z" = "1" /* Revision of Infusion Device in Fallopian Tube, Percutaneous Approach */
"0UW837Z" = "1" /* Revision of Autologous Tissue Substitute in Fallopian Tube, Percutaneous Approach */
"0UW83CZ" = "1" /* Revision of Extraluminal Device in Fallopian Tube, Percutaneous Approach */
"0UW83DZ" = "1" /* Revision of Intraluminal Device in Fallopian Tube, Percutaneous Approach */
"0UW83JZ" = "1" /* Revision of Synthetic Substitute in Fallopian Tube, Percutaneous Approach */
"0UW83KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Fallopian Tube, Percutaneous Approach */
"0UW840Z" = "1" /* Revision of Drainage Device in Fallopian Tube, Percutaneous Endoscopic Approach */
"0UW843Z" = "1" /* Revision of Infusion Device in Fallopian Tube, Percutaneous Endoscopic Approach */
"0UW847Z" = "1" /* Revision of Autologous Tissue Substitute in Fallopian Tube, Percutaneous Endoscopic Approach */
"0UW84CZ" = "1" /* Revision of Extraluminal Device in Fallopian Tube, Percutaneous Endoscopic Approach */
"0UW84DZ" = "1" /* Revision of Intraluminal Device in Fallopian Tube, Percutaneous Endoscopic Approach */
"0UW84JZ" = "1" /* Revision of Synthetic Substitute in Fallopian Tube, Percutaneous Endoscopic Approach */
"0UW84KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Fallopian Tube, Percutaneous Endoscopic Approach */
"0UWD30Z" = "1" /* Revision of Drainage Device in Uterus and Cervix, Percutaneous Approach */
"0UWD31Z" = "1" /* Revision of Radioactive Element in Uterus and Cervix, Percutaneous Approach */
"0UWD33Z" = "1" /* Revision of Infusion Device in Uterus and Cervix, Percutaneous Approach */
"0UWD37Z" = "1" /* Revision of Autologous Tissue Substitute in Uterus and Cervix, Percutaneous Approach */
"0UWD3CZ" = "1" /* Revision of Extraluminal Device in Uterus and Cervix, Percutaneous Approach */
"0UWD3DZ" = "1" /* Revision of Intraluminal Device in Uterus and Cervix, Percutaneous Approach */
"0UWD3HZ" = "1" /* Revision of Contraceptive Device in Uterus and Cervix, Percutaneous Approach */
"0UWD3JZ" = "1" /* Revision of Synthetic Substitute in Uterus and Cervix, Percutaneous Approach */
"0UWD3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Uterus and Cervix, Percutaneous Approach */
"0UWD40Z" = "1" /* Revision of Drainage Device in Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UWD41Z" = "1" /* Revision of Radioactive Element in Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UWD43Z" = "1" /* Revision of Infusion Device in Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UWD47Z" = "1" /* Revision of Autologous Tissue Substitute in Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UWD4CZ" = "1" /* Revision of Extraluminal Device in Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UWD4DZ" = "1" /* Revision of Intraluminal Device in Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UWD4HZ" = "1" /* Revision of Contraceptive Device in Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UWD4JZ" = "1" /* Revision of Synthetic Substitute in Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UWD4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Uterus and Cervix, Percutaneous Endoscopic Approach */
"0V503ZZ" = "1" /* Destruction of Prostate, Percutaneous Approach */
"0V504ZZ" = "1" /* Destruction of Prostate, Percutaneous Endoscopic Approach */
"0V513ZZ" = "1" /* Destruction of Right Seminal Vesicle, Percutaneous Approach */
"0V514ZZ" = "1" /* Destruction of Right Seminal Vesicle, Percutaneous Endoscopic Approach */
"0V523ZZ" = "1" /* Destruction of Left Seminal Vesicle, Percutaneous Approach */
"0V524ZZ" = "1" /* Destruction of Left Seminal Vesicle, Percutaneous Endoscopic Approach */
"0V533ZZ" = "1" /* Destruction of Bilateral Seminal Vesicles, Percutaneous Approach */
"0V534ZZ" = "1" /* Destruction of Bilateral Seminal Vesicles, Percutaneous Endoscopic Approach */
"0V9030Z" = "1" /* Drainage of Prostate with Drainage Device, Percutaneous Approach */
"0V903ZX" = "1" /* Drainage of Prostate, Percutaneous Approach, Diagnostic */
"0V903ZZ" = "1" /* Drainage of Prostate, Percutaneous Approach */
"0V9040Z" = "1" /* Drainage of Prostate with Drainage Device, Percutaneous Endoscopic Approach */
"0V904ZX" = "1" /* Drainage of Prostate, Percutaneous Endoscopic Approach, Diagnostic */
"0V904ZZ" = "1" /* Drainage of Prostate, Percutaneous Endoscopic Approach */
"0V9130Z" = "1" /* Drainage of Right Seminal Vesicle with Drainage Device, Percutaneous Approach */
"0V913ZX" = "1" /* Drainage of Right Seminal Vesicle, Percutaneous Approach, Diagnostic */
"0V913ZZ" = "1" /* Drainage of Right Seminal Vesicle, Percutaneous Approach */
"0V9140Z" = "1" /* Drainage of Right Seminal Vesicle with Drainage Device, Percutaneous Endoscopic Approach */
"0V914ZX" = "1" /* Drainage of Right Seminal Vesicle, Percutaneous Endoscopic Approach, Diagnostic */
"0V914ZZ" = "1" /* Drainage of Right Seminal Vesicle, Percutaneous Endoscopic Approach */
"0V9230Z" = "1" /* Drainage of Left Seminal Vesicle with Drainage Device, Percutaneous Approach */
"0V923ZX" = "1" /* Drainage of Left Seminal Vesicle, Percutaneous Approach, Diagnostic */
"0V923ZZ" = "1" /* Drainage of Left Seminal Vesicle, Percutaneous Approach */
"0V9240Z" = "1" /* Drainage of Left Seminal Vesicle with Drainage Device, Percutaneous Endoscopic Approach */
"0V924ZX" = "1" /* Drainage of Left Seminal Vesicle, Percutaneous Endoscopic Approach, Diagnostic */
"0V924ZZ" = "1" /* Drainage of Left Seminal Vesicle, Percutaneous Endoscopic Approach */
"0V9330Z" = "1" /* Drainage of Bilateral Seminal Vesicles with Drainage Device, Percutaneous Approach */
"0V933ZX" = "1" /* Drainage of Bilateral Seminal Vesicles, Percutaneous Approach, Diagnostic */
"0V933ZZ" = "1" /* Drainage of Bilateral Seminal Vesicles, Percutaneous Approach */
"0V9340Z" = "1" /* Drainage of Bilateral Seminal Vesicles with Drainage Device, Percutaneous Endoscopic Approach */
"0V934ZX" = "1" /* Drainage of Bilateral Seminal Vesicles, Percutaneous Endoscopic Approach, Diagnostic */
"0V934ZZ" = "1" /* Drainage of Bilateral Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VB03ZX" = "1" /* Excision of Prostate, Percutaneous Approach, Diagnostic */
"0VB03ZZ" = "1" /* Excision of Prostate, Percutaneous Approach */
"0VB04ZX" = "1" /* Excision of Prostate, Percutaneous Endoscopic Approach, Diagnostic */
"0VB04ZZ" = "1" /* Excision of Prostate, Percutaneous Endoscopic Approach */
"0VB13ZX" = "1" /* Excision of Right Seminal Vesicle, Percutaneous Approach, Diagnostic */
"0VB13ZZ" = "1" /* Excision of Right Seminal Vesicle, Percutaneous Approach */
"0VB14ZX" = "1" /* Excision of Right Seminal Vesicle, Percutaneous Endoscopic Approach, Diagnostic */
"0VB14ZZ" = "1" /* Excision of Right Seminal Vesicle, Percutaneous Endoscopic Approach */
"0VB23ZX" = "1" /* Excision of Left Seminal Vesicle, Percutaneous Approach, Diagnostic */
"0VB23ZZ" = "1" /* Excision of Left Seminal Vesicle, Percutaneous Approach */
"0VB24ZX" = "1" /* Excision of Left Seminal Vesicle, Percutaneous Endoscopic Approach, Diagnostic */
"0VB24ZZ" = "1" /* Excision of Left Seminal Vesicle, Percutaneous Endoscopic Approach */
"0VB33ZX" = "1" /* Excision of Bilateral Seminal Vesicles, Percutaneous Approach, Diagnostic */
"0VB33ZZ" = "1" /* Excision of Bilateral Seminal Vesicles, Percutaneous Approach */
"0VB34ZX" = "1" /* Excision of Bilateral Seminal Vesicles, Percutaneous Endoscopic Approach, Diagnostic */
"0VB34ZZ" = "1" /* Excision of Bilateral Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VC03ZZ" = "1" /* Extirpation of Matter from Prostate, Percutaneous Approach */
"0VC04ZZ" = "1" /* Extirpation of Matter from Prostate, Percutaneous Endoscopic Approach */
"0VC13ZZ" = "1" /* Extirpation of Matter from Right Seminal Vesicle, Percutaneous Approach */
"0VC14ZZ" = "1" /* Extirpation of Matter from Right Seminal Vesicle, Percutaneous Endoscopic Approach */
"0VC23ZZ" = "1" /* Extirpation of Matter from Left Seminal Vesicle, Percutaneous Approach */
"0VC24ZZ" = "1" /* Extirpation of Matter from Left Seminal Vesicle, Percutaneous Endoscopic Approach */
"0VC33ZZ" = "1" /* Extirpation of Matter from Bilateral Seminal Vesicles, Percutaneous Approach */
"0VC34ZZ" = "1" /* Extirpation of Matter from Bilateral Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VH031Z" = "1" /* Insertion of Radioactive Element into Prostate, Percutaneous Approach */
"0VH041Z" = "1" /* Insertion of Radioactive Element into Prostate, Percutaneous Endoscopic Approach */
"0VH433Z" = "1" /* Insertion of Infusion Device into Prostate and Seminal Vesicles, Percutaneous Approach */
"0VH443Z" = "1" /* Insertion of Infusion Device into Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VJ43ZZ" = "1" /* Inspection of Prostate and Seminal Vesicles, Percutaneous Approach */
"0VJ44ZZ" = "1" /* Inspection of Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VN03ZZ" = "1" /* Release Prostate, Percutaneous Approach */
"0VN04ZZ" = "1" /* Release Prostate, Percutaneous Endoscopic Approach */
"0VN13ZZ" = "1" /* Release Right Seminal Vesicle, Percutaneous Approach */
"0VN14ZZ" = "1" /* Release Right Seminal Vesicle, Percutaneous Endoscopic Approach */
"0VN23ZZ" = "1" /* Release Left Seminal Vesicle, Percutaneous Approach */
"0VN24ZZ" = "1" /* Release Left Seminal Vesicle, Percutaneous Endoscopic Approach */
"0VN33ZZ" = "1" /* Release Bilateral Seminal Vesicles, Percutaneous Approach */
"0VN34ZZ" = "1" /* Release Bilateral Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VP430Z" = "1" /* Removal of Drainage Device from Prostate and Seminal Vesicles, Percutaneous Approach */
"0VP431Z" = "1" /* Removal of Radioactive Element from Prostate and Seminal Vesicles, Percutaneous Approach */
"0VP433Z" = "1" /* Removal of Infusion Device from Prostate and Seminal Vesicles, Percutaneous Approach */
"0VP437Z" = "1" /* Removal of Autologous Tissue Substitute from Prostate and Seminal Vesicles, Percutaneous Approach */
"0VP43JZ" = "1" /* Removal of Synthetic Substitute from Prostate and Seminal Vesicles, Percutaneous Approach */
"0VP43KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Prostate and Seminal Vesicles, Percutaneous Approach */
"0VP440Z" = "1" /* Removal of Drainage Device from Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VP441Z" = "1" /* Removal of Radioactive Element from Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VP443Z" = "1" /* Removal of Infusion Device from Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VP447Z" = "1" /* Removal of Autologous Tissue Substitute from Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VP44JZ" = "1" /* Removal of Synthetic Substitute from Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VP44KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VQ03ZZ" = "1" /* Repair Prostate, Percutaneous Approach */
"0VQ04ZZ" = "1" /* Repair Prostate, Percutaneous Endoscopic Approach */
"0VQ13ZZ" = "1" /* Repair Right Seminal Vesicle, Percutaneous Approach */
"0VQ14ZZ" = "1" /* Repair Right Seminal Vesicle, Percutaneous Endoscopic Approach */
"0VQ23ZZ" = "1" /* Repair Left Seminal Vesicle, Percutaneous Approach */
"0VQ24ZZ" = "1" /* Repair Left Seminal Vesicle, Percutaneous Endoscopic Approach */
"0VQ33ZZ" = "1" /* Repair Bilateral Seminal Vesicles, Percutaneous Approach */
"0VQ34ZZ" = "1" /* Repair Bilateral Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VT04ZZ" = "1" /* Resection of Prostate, Percutaneous Endoscopic Approach */
"0VT14ZZ" = "1" /* Resection of Right Seminal Vesicle, Percutaneous Endoscopic Approach */
"0VT24ZZ" = "1" /* Resection of Left Seminal Vesicle, Percutaneous Endoscopic Approach */
"0VT34ZZ" = "1" /* Resection of Bilateral Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VU147Z" = "1" /* Supplement Right Seminal Vesicle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VU14JZ" = "1" /* Supplement Right Seminal Vesicle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0VU14KZ" = "1" /* Supplement Right Seminal Vesicle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VU247Z" = "1" /* Supplement Left Seminal Vesicle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VU24JZ" = "1" /* Supplement Left Seminal Vesicle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0VU24KZ" = "1" /* Supplement Left Seminal Vesicle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VU347Z" = "1" /* Supplement Bilateral Seminal Vesicles with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VU34JZ" = "1" /* Supplement Bilateral Seminal Vesicles with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0VU34KZ" = "1" /* Supplement Bilateral Seminal Vesicles with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VW430Z" = "1" /* Revision of Drainage Device in Prostate and Seminal Vesicles, Percutaneous Approach */
"0VW433Z" = "1" /* Revision of Infusion Device in Prostate and Seminal Vesicles, Percutaneous Approach */
"0VW437Z" = "1" /* Revision of Autologous Tissue Substitute in Prostate and Seminal Vesicles, Percutaneous Approach */
"0VW43JZ" = "1" /* Revision of Synthetic Substitute in Prostate and Seminal Vesicles, Percutaneous Approach */
"0VW43KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Prostate and Seminal Vesicles, Percutaneous Approach */
"0VW440Z" = "1" /* Revision of Drainage Device in Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VW443Z" = "1" /* Revision of Infusion Device in Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VW447Z" = "1" /* Revision of Autologous Tissue Substitute in Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VW44JZ" = "1" /* Revision of Synthetic Substitute in Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VW44KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0W0F37Z" = "1" /* Alteration of Abdominal Wall with Autologous Tissue Substitute, Percutaneous Approach */
"0W0F3JZ" = "1" /* Alteration of Abdominal Wall with Synthetic Substitute, Percutaneous Approach */
"0W0F3KZ" = "1" /* Alteration of Abdominal Wall with Nonautologous Tissue Substitute, Percutaneous Approach */
"0W0F3ZZ" = "1" /* Alteration of Abdominal Wall, Percutaneous Approach */
"0W0F47Z" = "1" /* Alteration of Abdominal Wall with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W0F4JZ" = "1" /* Alteration of Abdominal Wall with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W0F4KZ" = "1" /* Alteration of Abdominal Wall with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W0F4ZZ" = "1" /* Alteration of Abdominal Wall, Percutaneous Endoscopic Approach */
"0W1G3J4" = "1" /* Bypass Peritoneal Cavity to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0W1G4J4" = "1" /* Bypass Peritoneal Cavity to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1G4J9" = "1" /* Bypass Peritoneal Cavity to Right Pleural Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1G4JB" = "1" /* Bypass Peritoneal Cavity to Left Pleural Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1G4JG" = "1" /* Bypass Peritoneal Cavity to Peritoneal Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1G4JJ" = "1" /* Bypass Peritoneal Cavity to Pelvic Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1G4JY" = "1" /* Bypass Peritoneal Cavity to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1J3J4" = "1" /* Bypass Pelvic Cavity to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0W1J4J4" = "1" /* Bypass Pelvic Cavity to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1J4J9" = "1" /* Bypass Pelvic Cavity to Right Pleural Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1J4JB" = "1" /* Bypass Pelvic Cavity to Left Pleural Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1J4JG" = "1" /* Bypass Pelvic Cavity to Peritoneal Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1J4JJ" = "1" /* Bypass Pelvic Cavity to Pelvic Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1J4JY" = "1" /* Bypass Pelvic Cavity to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W3F3ZZ" = "1" /* Control Bleeding in Abdominal Wall, Percutaneous Approach */
"0W3F4ZZ" = "1" /* Control Bleeding in Abdominal Wall, Percutaneous Endoscopic Approach */
"0W3G3ZZ" = "1" /* Control Bleeding in Peritoneal Cavity, Percutaneous Approach */
"0W3G4ZZ" = "1" /* Control Bleeding in Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0W3H3ZZ" = "1" /* Control Bleeding in Retroperitoneum, Percutaneous Approach */
"0W3H4ZZ" = "1" /* Control Bleeding in Retroperitoneum, Percutaneous Endoscopic Approach */
"0W3J3ZZ" = "1" /* Control Bleeding in Pelvic Cavity, Percutaneous Approach */
"0W3J4ZZ" = "1" /* Control Bleeding in Pelvic Cavity, Percutaneous Endoscopic Approach */
"0W3P3ZZ" = "1" /* Control Bleeding in Gastrointestinal Tract, Percutaneous Approach */
"0W3P4ZZ" = "1" /* Control Bleeding in Gastrointestinal Tract, Percutaneous Endoscopic Approach */
"0W3R3ZZ" = "1" /* Control Bleeding in Genitourinary Tract, Percutaneous Approach */
"0W3R4ZZ" = "1" /* Control Bleeding in Genitourinary Tract, Percutaneous Endoscopic Approach */
"0W9F30Z" = "1" /* Drainage of Abdominal Wall with Drainage Device, Percutaneous Approach */
"0W9F3ZX" = "1" /* Drainage of Abdominal Wall, Percutaneous Approach, Diagnostic */
"0W9F3ZZ" = "1" /* Drainage of Abdominal Wall, Percutaneous Approach */
"0W9F40Z" = "1" /* Drainage of Abdominal Wall with Drainage Device, Percutaneous Endoscopic Approach */
"0W9F4ZX" = "1" /* Drainage of Abdominal Wall, Percutaneous Endoscopic Approach, Diagnostic */
"0W9F4ZZ" = "1" /* Drainage of Abdominal Wall, Percutaneous Endoscopic Approach */
"0W9G30Z" = "1" /* Drainage of Peritoneal Cavity with Drainage Device, Percutaneous Approach */
"0W9G3ZX" = "1" /* Drainage of Peritoneal Cavity, Percutaneous Approach, Diagnostic */
"0W9G3ZZ" = "1" /* Drainage of Peritoneal Cavity, Percutaneous Approach */
"0W9G40Z" = "1" /* Drainage of Peritoneal Cavity with Drainage Device, Percutaneous Endoscopic Approach */
"0W9G4ZX" = "1" /* Drainage of Peritoneal Cavity, Percutaneous Endoscopic Approach, Diagnostic */
"0W9G4ZZ" = "1" /* Drainage of Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0W9H30Z" = "1" /* Drainage of Retroperitoneum with Drainage Device, Percutaneous Approach */
"0W9H3ZX" = "1" /* Drainage of Retroperitoneum, Percutaneous Approach, Diagnostic */
"0W9H3ZZ" = "1" /* Drainage of Retroperitoneum, Percutaneous Approach */
"0W9H40Z" = "1" /* Drainage of Retroperitoneum with Drainage Device, Percutaneous Endoscopic Approach */
"0W9H4ZX" = "1" /* Drainage of Retroperitoneum, Percutaneous Endoscopic Approach, Diagnostic */
"0W9H4ZZ" = "1" /* Drainage of Retroperitoneum, Percutaneous Endoscopic Approach */
"0W9J30Z" = "1" /* Drainage of Pelvic Cavity with Drainage Device, Percutaneous Approach */
"0W9J3ZX" = "1" /* Drainage of Pelvic Cavity, Percutaneous Approach, Diagnostic */
"0W9J3ZZ" = "1" /* Drainage of Pelvic Cavity, Percutaneous Approach */
"0W9J40Z" = "1" /* Drainage of Pelvic Cavity with Drainage Device, Percutaneous Endoscopic Approach */
"0W9J4ZX" = "1" /* Drainage of Pelvic Cavity, Percutaneous Endoscopic Approach, Diagnostic */
"0W9J4ZZ" = "1" /* Drainage of Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WBF3ZX" = "1" /* Excision of Abdominal Wall, Percutaneous Approach, Diagnostic */
"0WBF3ZZ" = "1" /* Excision of Abdominal Wall, Percutaneous Approach */
"0WBF4ZX" = "1" /* Excision of Abdominal Wall, Percutaneous Endoscopic Approach, Diagnostic */
"0WBF4ZZ" = "1" /* Excision of Abdominal Wall, Percutaneous Endoscopic Approach */
"0WBFXZ2" = "1" /* Excision of Abdominal Wall, Stoma, External Approach */
"0WBFXZX" = "1" /* Excision of Abdominal Wall, External Approach, Diagnostic */
"0WBFXZZ" = "1" /* Excision of Abdominal Wall, External Approach */
"0WBH3ZX" = "1" /* Excision of Retroperitoneum, Percutaneous Approach, Diagnostic */
"0WBH3ZZ" = "1" /* Excision of Retroperitoneum, Percutaneous Approach */
"0WBH4ZX" = "1" /* Excision of Retroperitoneum, Percutaneous Endoscopic Approach, Diagnostic */
"0WBH4ZZ" = "1" /* Excision of Retroperitoneum, Percutaneous Endoscopic Approach */
"0WCG3ZZ" = "1" /* Extirpation of Matter from Peritoneal Cavity, Percutaneous Approach */
"0WCG4ZZ" = "1" /* Extirpation of Matter from Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WCJ3ZZ" = "1" /* Extirpation of Matter from Pelvic Cavity, Percutaneous Approach */
"0WCJ4ZZ" = "1" /* Extirpation of Matter from Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WCP3ZZ" = "1" /* Extirpation of Matter from Gastrointestinal Tract, Percutaneous Approach */
"0WCP4ZZ" = "1" /* Extirpation of Matter from Gastrointestinal Tract, Percutaneous Endoscopic Approach */
"0WCR3ZZ" = "1" /* Extirpation of Matter from Genitourinary Tract, Percutaneous Approach */
"0WCR4ZZ" = "1" /* Extirpation of Matter from Genitourinary Tract, Percutaneous Endoscopic Approach */
"0WFG3ZZ" = "1" /* Fragmentation in Peritoneal Cavity, Percutaneous Approach */
"0WFG4ZZ" = "1" /* Fragmentation in Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WFJ3ZZ" = "1" /* Fragmentation in Pelvic Cavity, Percutaneous Approach */
"0WFJ4ZZ" = "1" /* Fragmentation in Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WFP3ZZ" = "1" /* Fragmentation in Gastrointestinal Tract, Percutaneous Approach */
"0WFP4ZZ" = "1" /* Fragmentation in Gastrointestinal Tract, Percutaneous Endoscopic Approach */
"0WFR3ZZ" = "1" /* Fragmentation in Genitourinary Tract, Percutaneous Approach */
"0WFR4ZZ" = "1" /* Fragmentation in Genitourinary Tract, Percutaneous Endoscopic Approach */
"0WHF31Z" = "1" /* Insertion of Radioactive Element into Abdominal Wall, Percutaneous Approach */
"0WHF33Z" = "1" /* Insertion of Infusion Device into Abdominal Wall, Percutaneous Approach */
"0WHF3YZ" = "1" /* Insertion of Other Device into Abdominal Wall, Percutaneous Approach */
"0WHF41Z" = "1" /* Insertion of Radioactive Element into Abdominal Wall, Percutaneous Endoscopic Approach */
"0WHF43Z" = "1" /* Insertion of Infusion Device into Abdominal Wall, Percutaneous Endoscopic Approach */
"0WHF4YZ" = "1" /* Insertion of Other Device into Abdominal Wall, Percutaneous Endoscopic Approach */
"0WHG31Z" = "1" /* Insertion of Radioactive Element into Peritoneal Cavity, Percutaneous Approach */
"0WHG33Z" = "1" /* Insertion of Infusion Device into Peritoneal Cavity, Percutaneous Approach */
"0WHG3YZ" = "1" /* Insertion of Other Device into Peritoneal Cavity, Percutaneous Approach */
"0WHG41Z" = "1" /* Insertion of Radioactive Element into Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WHG43Z" = "1" /* Insertion of Infusion Device into Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WHG4YZ" = "1" /* Insertion of Other Device into Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WHH31Z" = "1" /* Insertion of Radioactive Element into Retroperitoneum, Percutaneous Approach */
"0WHH33Z" = "1" /* Insertion of Infusion Device into Retroperitoneum, Percutaneous Approach */
"0WHH3YZ" = "1" /* Insertion of Other Device into Retroperitoneum, Percutaneous Approach */
"0WHH41Z" = "1" /* Insertion of Radioactive Element into Retroperitoneum, Percutaneous Endoscopic Approach */
"0WHH43Z" = "1" /* Insertion of Infusion Device into Retroperitoneum, Percutaneous Endoscopic Approach */
"0WHH4YZ" = "1" /* Insertion of Other Device into Retroperitoneum, Percutaneous Endoscopic Approach */
"0WHJ31Z" = "1" /* Insertion of Radioactive Element into Pelvic Cavity, Percutaneous Approach */
"0WHJ33Z" = "1" /* Insertion of Infusion Device into Pelvic Cavity, Percutaneous Approach */
"0WHJ3YZ" = "1" /* Insertion of Other Device into Pelvic Cavity, Percutaneous Approach */
"0WHJ41Z" = "1" /* Insertion of Radioactive Element into Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WHJ43Z" = "1" /* Insertion of Infusion Device into Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WHJ4YZ" = "1" /* Insertion of Other Device into Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WHP31Z" = "1" /* Insertion of Radioactive Element into Gastrointestinal Tract, Percutaneous Approach */
"0WHP33Z" = "1" /* Insertion of Infusion Device into Gastrointestinal Tract, Percutaneous Approach */
"0WHP3YZ" = "1" /* Insertion of Other Device into Gastrointestinal Tract, Percutaneous Approach */
"0WHP41Z" = "1" /* Insertion of Radioactive Element into Gastrointestinal Tract, Percutaneous Endoscopic Approach */
"0WHP43Z" = "1" /* Insertion of Infusion Device into Gastrointestinal Tract, Percutaneous Endoscopic Approach */
"0WHP4YZ" = "1" /* Insertion of Other Device into Gastrointestinal Tract, Percutaneous Endoscopic Approach */
"0WHR31Z" = "1" /* Insertion of Radioactive Element into Genitourinary Tract, Percutaneous Approach */
"0WHR33Z" = "1" /* Insertion of Infusion Device into Genitourinary Tract, Percutaneous Approach */
"0WHR3YZ" = "1" /* Insertion of Other Device into Genitourinary Tract, Percutaneous Approach */
"0WHR41Z" = "1" /* Insertion of Radioactive Element into Genitourinary Tract, Percutaneous Endoscopic Approach */
"0WHR43Z" = "1" /* Insertion of Infusion Device into Genitourinary Tract, Percutaneous Endoscopic Approach */
"0WHR4YZ" = "1" /* Insertion of Other Device into Genitourinary Tract, Percutaneous Endoscopic Approach */
"0WJF3ZZ" = "1" /* Inspection of Abdominal Wall, Percutaneous Approach */
"0WJF4ZZ" = "1" /* Inspection of Abdominal Wall, Percutaneous Endoscopic Approach */
"0WJG3ZZ" = "1" /* Inspection of Peritoneal Cavity, Percutaneous Approach */
"0WJG4ZZ" = "1" /* Inspection of Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WJH3ZZ" = "1" /* Inspection of Retroperitoneum, Percutaneous Approach */
"0WJH4ZZ" = "1" /* Inspection of Retroperitoneum, Percutaneous Endoscopic Approach */
"0WJJ3ZZ" = "1" /* Inspection of Pelvic Cavity, Percutaneous Approach */
"0WJJ4ZZ" = "1" /* Inspection of Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WJP3ZZ" = "1" /* Inspection of Gastrointestinal Tract, Percutaneous Approach */
"0WJP4ZZ" = "1" /* Inspection of Gastrointestinal Tract, Percutaneous Endoscopic Approach */
"0WJR3ZZ" = "1" /* Inspection of Genitourinary Tract, Percutaneous Approach */
"0WJR4ZZ" = "1" /* Inspection of Genitourinary Tract, Percutaneous Endoscopic Approach */
"0WPF30Z" = "1" /* Removal of Drainage Device from Abdominal Wall, Percutaneous Approach */
"0WPF31Z" = "1" /* Removal of Radioactive Element from Abdominal Wall, Percutaneous Approach */
"0WPF33Z" = "1" /* Removal of Infusion Device from Abdominal Wall, Percutaneous Approach */
"0WPF37Z" = "1" /* Removal of Autologous Tissue Substitute from Abdominal Wall, Percutaneous Approach */
"0WPF3JZ" = "1" /* Removal of Synthetic Substitute from Abdominal Wall, Percutaneous Approach */
"0WPF3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Abdominal Wall, Percutaneous Approach */
"0WPF3YZ" = "1" /* Removal of Other Device from Abdominal Wall, Percutaneous Approach */
"0WPF40Z" = "1" /* Removal of Drainage Device from Abdominal Wall, Percutaneous Endoscopic Approach */
"0WPF41Z" = "1" /* Removal of Radioactive Element from Abdominal Wall, Percutaneous Endoscopic Approach */
"0WPF43Z" = "1" /* Removal of Infusion Device from Abdominal Wall, Percutaneous Endoscopic Approach */
"0WPF47Z" = "1" /* Removal of Autologous Tissue Substitute from Abdominal Wall, Percutaneous Endoscopic Approach */
"0WPF4JZ" = "1" /* Removal of Synthetic Substitute from Abdominal Wall, Percutaneous Endoscopic Approach */
"0WPF4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Abdominal Wall, Percutaneous Endoscopic Approach */
"0WPF4YZ" = "1" /* Removal of Other Device from Abdominal Wall, Percutaneous Endoscopic Approach */
"0WPG30Z" = "1" /* Removal of Drainage Device from Peritoneal Cavity, Percutaneous Approach */
"0WPG31Z" = "1" /* Removal of Radioactive Element from Peritoneal Cavity, Percutaneous Approach */
"0WPG33Z" = "1" /* Removal of Infusion Device from Peritoneal Cavity, Percutaneous Approach */
"0WPG3JZ" = "1" /* Removal of Synthetic Substitute from Peritoneal Cavity, Percutaneous Approach */
"0WPG3YZ" = "1" /* Removal of Other Device from Peritoneal Cavity, Percutaneous Approach */
"0WPG40Z" = "1" /* Removal of Drainage Device from Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WPG41Z" = "1" /* Removal of Radioactive Element from Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WPG43Z" = "1" /* Removal of Infusion Device from Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WPG4JZ" = "1" /* Removal of Synthetic Substitute from Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WPG4YZ" = "1" /* Removal of Other Device from Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WPH30Z" = "1" /* Removal of Drainage Device from Retroperitoneum, Percutaneous Approach */
"0WPH31Z" = "1" /* Removal of Radioactive Element from Retroperitoneum, Percutaneous Approach */
"0WPH33Z" = "1" /* Removal of Infusion Device from Retroperitoneum, Percutaneous Approach */
"0WPH3YZ" = "1" /* Removal of Other Device from Retroperitoneum, Percutaneous Approach */
"0WPH40Z" = "1" /* Removal of Drainage Device from Retroperitoneum, Percutaneous Endoscopic Approach */
"0WPH41Z" = "1" /* Removal of Radioactive Element from Retroperitoneum, Percutaneous Endoscopic Approach */
"0WPH43Z" = "1" /* Removal of Infusion Device from Retroperitoneum, Percutaneous Endoscopic Approach */
"0WPH4YZ" = "1" /* Removal of Other Device from Retroperitoneum, Percutaneous Endoscopic Approach */
"0WPJ30Z" = "1" /* Removal of Drainage Device from Pelvic Cavity, Percutaneous Approach */
"0WPJ31Z" = "1" /* Removal of Radioactive Element from Pelvic Cavity, Percutaneous Approach */
"0WPJ33Z" = "1" /* Removal of Infusion Device from Pelvic Cavity, Percutaneous Approach */
"0WPJ3JZ" = "1" /* Removal of Synthetic Substitute from Pelvic Cavity, Percutaneous Approach */
"0WPJ3YZ" = "1" /* Removal of Other Device from Pelvic Cavity, Percutaneous Approach */
"0WPJ40Z" = "1" /* Removal of Drainage Device from Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WPJ41Z" = "1" /* Removal of Radioactive Element from Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WPJ43Z" = "1" /* Removal of Infusion Device from Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WPJ4JZ" = "1" /* Removal of Synthetic Substitute from Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WPJ4YZ" = "1" /* Removal of Other Device from Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WPP31Z" = "1" /* Removal of Radioactive Element from Gastrointestinal Tract, Percutaneous Approach */
"0WPP33Z" = "1" /* Removal of Infusion Device from Gastrointestinal Tract, Percutaneous Approach */
"0WPP3YZ" = "1" /* Removal of Other Device from Gastrointestinal Tract, Percutaneous Approach */
"0WPP41Z" = "1" /* Removal of Radioactive Element from Gastrointestinal Tract, Percutaneous Endoscopic Approach */
"0WPP43Z" = "1" /* Removal of Infusion Device from Gastrointestinal Tract, Percutaneous Endoscopic Approach */
"0WPP4YZ" = "1" /* Removal of Other Device from Gastrointestinal Tract, Percutaneous Endoscopic Approach */
"0WPR31Z" = "1" /* Removal of Radioactive Element from Genitourinary Tract, Percutaneous Approach */
"0WPR33Z" = "1" /* Removal of Infusion Device from Genitourinary Tract, Percutaneous Approach */
"0WPR3YZ" = "1" /* Removal of Other Device from Genitourinary Tract, Percutaneous Approach */
"0WPR41Z" = "1" /* Removal of Radioactive Element from Genitourinary Tract, Percutaneous Endoscopic Approach */
"0WPR43Z" = "1" /* Removal of Infusion Device from Genitourinary Tract, Percutaneous Endoscopic Approach */
"0WPR4YZ" = "1" /* Removal of Other Device from Genitourinary Tract, Percutaneous Endoscopic Approach */
"0WQF3ZZ" = "1" /* Repair Abdominal Wall, Percutaneous Approach */
"0WQF4ZZ" = "1" /* Repair Abdominal Wall, Percutaneous Endoscopic Approach */
"0WQFXZ2" = "1" /* Repair Abdominal Wall, Stoma, External Approach */
"0WQFXZZ" = "1" /* Repair Abdominal Wall, External Approach */
"0WUF47Z" = "1" /* Supplement Abdominal Wall with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WUF4JZ" = "1" /* Supplement Abdominal Wall with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0WUF4KZ" = "1" /* Supplement Abdominal Wall with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WWF30Z" = "1" /* Revision of Drainage Device in Abdominal Wall, Percutaneous Approach */
"0WWF31Z" = "1" /* Revision of Radioactive Element in Abdominal Wall, Percutaneous Approach */
"0WWF33Z" = "1" /* Revision of Infusion Device in Abdominal Wall, Percutaneous Approach */
"0WWF37Z" = "1" /* Revision of Autologous Tissue Substitute in Abdominal Wall, Percutaneous Approach */
"0WWF3JZ" = "1" /* Revision of Synthetic Substitute in Abdominal Wall, Percutaneous Approach */
"0WWF3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Abdominal Wall, Percutaneous Approach */
"0WWF3YZ" = "1" /* Revision of Other Device in Abdominal Wall, Percutaneous Approach */
"0WWF40Z" = "1" /* Revision of Drainage Device in Abdominal Wall, Percutaneous Endoscopic Approach */
"0WWF41Z" = "1" /* Revision of Radioactive Element in Abdominal Wall, Percutaneous Endoscopic Approach */
"0WWF43Z" = "1" /* Revision of Infusion Device in Abdominal Wall, Percutaneous Endoscopic Approach */
"0WWF47Z" = "1" /* Revision of Autologous Tissue Substitute in Abdominal Wall, Percutaneous Endoscopic Approach */
"0WWF4JZ" = "1" /* Revision of Synthetic Substitute in Abdominal Wall, Percutaneous Endoscopic Approach */
"0WWF4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Abdominal Wall, Percutaneous Endoscopic Approach */
"0WWF4YZ" = "1" /* Revision of Other Device in Abdominal Wall, Percutaneous Endoscopic Approach */
"0WWG30Z" = "1" /* Revision of Drainage Device in Peritoneal Cavity, Percutaneous Approach */
"0WWG31Z" = "1" /* Revision of Radioactive Element in Peritoneal Cavity, Percutaneous Approach */
"0WWG33Z" = "1" /* Revision of Infusion Device in Peritoneal Cavity, Percutaneous Approach */
"0WWG3JZ" = "1" /* Revision of Synthetic Substitute in Peritoneal Cavity, Percutaneous Approach */
"0WWG3YZ" = "1" /* Revision of Other Device in Peritoneal Cavity, Percutaneous Approach */
"0WWG40Z" = "1" /* Revision of Drainage Device in Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WWG41Z" = "1" /* Revision of Radioactive Element in Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WWG43Z" = "1" /* Revision of Infusion Device in Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WWG4JZ" = "1" /* Revision of Synthetic Substitute in Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WWG4YZ" = "1" /* Revision of Other Device in Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WWH30Z" = "1" /* Revision of Drainage Device in Retroperitoneum, Percutaneous Approach */
"0WWH31Z" = "1" /* Revision of Radioactive Element in Retroperitoneum, Percutaneous Approach */
"0WWH33Z" = "1" /* Revision of Infusion Device in Retroperitoneum, Percutaneous Approach */
"0WWH3YZ" = "1" /* Revision of Other Device in Retroperitoneum, Percutaneous Approach */
"0WWH40Z" = "1" /* Revision of Drainage Device in Retroperitoneum, Percutaneous Endoscopic Approach */
"0WWH41Z" = "1" /* Revision of Radioactive Element in Retroperitoneum, Percutaneous Endoscopic Approach */
"0WWH43Z" = "1" /* Revision of Infusion Device in Retroperitoneum, Percutaneous Endoscopic Approach */
"0WWH4YZ" = "1" /* Revision of Other Device in Retroperitoneum, Percutaneous Endoscopic Approach */
"0WWJ30Z" = "1" /* Revision of Drainage Device in Pelvic Cavity, Percutaneous Approach */
"0WWJ31Z" = "1" /* Revision of Radioactive Element in Pelvic Cavity, Percutaneous Approach */
"0WWJ33Z" = "1" /* Revision of Infusion Device in Pelvic Cavity, Percutaneous Approach */
"0WWJ3JZ" = "1" /* Revision of Synthetic Substitute in Pelvic Cavity, Percutaneous Approach */
"0WWJ3YZ" = "1" /* Revision of Other Device in Pelvic Cavity, Percutaneous Approach */
"0WWJ40Z" = "1" /* Revision of Drainage Device in Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WWJ41Z" = "1" /* Revision of Radioactive Element in Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WWJ43Z" = "1" /* Revision of Infusion Device in Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WWJ4JZ" = "1" /* Revision of Synthetic Substitute in Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WWJ4YZ" = "1" /* Revision of Other Device in Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WWP31Z" = "1" /* Revision of Radioactive Element in Gastrointestinal Tract, Percutaneous Approach */
"0WWP33Z" = "1" /* Revision of Infusion Device in Gastrointestinal Tract, Percutaneous Approach */
"0WWP3YZ" = "1" /* Revision of Other Device in Gastrointestinal Tract, Percutaneous Approach */
"0WWP41Z" = "1" /* Revision of Radioactive Element in Gastrointestinal Tract, Percutaneous Endoscopic Approach */
"0WWP43Z" = "1" /* Revision of Infusion Device in Gastrointestinal Tract, Percutaneous Endoscopic Approach */
"0WWP4YZ" = "1" /* Revision of Other Device in Gastrointestinal Tract, Percutaneous Endoscopic Approach */
"0WWR31Z" = "1" /* Revision of Radioactive Element in Genitourinary Tract, Percutaneous Approach */
"0WWR33Z" = "1" /* Revision of Infusion Device in Genitourinary Tract, Percutaneous Approach */
"0WWR3YZ" = "1" /* Revision of Other Device in Genitourinary Tract, Percutaneous Approach */
"0WWR41Z" = "1" /* Revision of Radioactive Element in Genitourinary Tract, Percutaneous Endoscopic Approach */
"0WWR43Z" = "1" /* Revision of Infusion Device in Genitourinary Tract, Percutaneous Endoscopic Approach */
"0WWR4YZ" = "1" /* Revision of Other Device in Genitourinary Tract, Percutaneous Endoscopic Approach */
"0Y353ZZ" = "1" /* Control Bleeding in Right Inguinal Region, Percutaneous Approach */
"0Y354ZZ" = "1" /* Control Bleeding in Right Inguinal Region, Percutaneous Endoscopic Approach */
"0Y363ZZ" = "1" /* Control Bleeding in Left Inguinal Region, Percutaneous Approach */
"0Y364ZZ" = "1" /* Control Bleeding in Left Inguinal Region, Percutaneous Endoscopic Approach */
"0Y9530Z" = "1" /* Drainage of Right Inguinal Region with Drainage Device, Percutaneous Approach */
"0Y953ZX" = "1" /* Drainage of Right Inguinal Region, Percutaneous Approach, Diagnostic */
"0Y953ZZ" = "1" /* Drainage of Right Inguinal Region, Percutaneous Approach */
"0Y9540Z" = "1" /* Drainage of Right Inguinal Region with Drainage Device, Percutaneous Endoscopic Approach */
"0Y954ZX" = "1" /* Drainage of Right Inguinal Region, Percutaneous Endoscopic Approach, Diagnostic */
"0Y954ZZ" = "1" /* Drainage of Right Inguinal Region, Percutaneous Endoscopic Approach */
"0Y9630Z" = "1" /* Drainage of Left Inguinal Region with Drainage Device, Percutaneous Approach */
"0Y963ZX" = "1" /* Drainage of Left Inguinal Region, Percutaneous Approach, Diagnostic */
"0Y963ZZ" = "1" /* Drainage of Left Inguinal Region, Percutaneous Approach */
"0Y9640Z" = "1" /* Drainage of Left Inguinal Region with Drainage Device, Percutaneous Endoscopic Approach */
"0Y964ZX" = "1" /* Drainage of Left Inguinal Region, Percutaneous Endoscopic Approach, Diagnostic */
"0Y964ZZ" = "1" /* Drainage of Left Inguinal Region, Percutaneous Endoscopic Approach */
"0YB53ZX" = "1" /* Excision of Right Inguinal Region, Percutaneous Approach, Diagnostic */
"0YB53ZZ" = "1" /* Excision of Right Inguinal Region, Percutaneous Approach */
"0YB54ZX" = "1" /* Excision of Right Inguinal Region, Percutaneous Endoscopic Approach, Diagnostic */
"0YB54ZZ" = "1" /* Excision of Right Inguinal Region, Percutaneous Endoscopic Approach */
"0YB63ZX" = "1" /* Excision of Left Inguinal Region, Percutaneous Approach, Diagnostic */
"0YB63ZZ" = "1" /* Excision of Left Inguinal Region, Percutaneous Approach */
"0YB64ZX" = "1" /* Excision of Left Inguinal Region, Percutaneous Endoscopic Approach, Diagnostic */
"0YB64ZZ" = "1" /* Excision of Left Inguinal Region, Percutaneous Endoscopic Approach */
"0YB73ZZ" = "1" /* Excision of Right Femoral Region, Percutaneous Approach */
"0YB74ZZ" = "1" /* Excision of Right Femoral Region, Percutaneous Endoscopic Approach */
"0YB83ZZ" = "1" /* Excision of Left Femoral Region, Percutaneous Approach */
"0YB84ZZ" = "1" /* Excision of Left Femoral Region, Percutaneous Endoscopic Approach */
"0YH531Z" = "1" /* Insertion of Radioactive Element into Right Inguinal Region, Percutaneous Approach */
"0YH533Z" = "1" /* Insertion of Infusion Device into Right Inguinal Region, Percutaneous Approach */
"0YH53YZ" = "1" /* Insertion of Other Device into Right Inguinal Region, Percutaneous Approach */
"0YH541Z" = "1" /* Insertion of Radioactive Element into Right Inguinal Region, Percutaneous Endoscopic Approach */
"0YH543Z" = "1" /* Insertion of Infusion Device into Right Inguinal Region, Percutaneous Endoscopic Approach */
"0YH54YZ" = "1" /* Insertion of Other Device into Right Inguinal Region, Percutaneous Endoscopic Approach */
"0YH631Z" = "1" /* Insertion of Radioactive Element into Left Inguinal Region, Percutaneous Approach */
"0YH633Z" = "1" /* Insertion of Infusion Device into Left Inguinal Region, Percutaneous Approach */
"0YH63YZ" = "1" /* Insertion of Other Device into Left Inguinal Region, Percutaneous Approach */
"0YH641Z" = "1" /* Insertion of Radioactive Element into Left Inguinal Region, Percutaneous Endoscopic Approach */
"0YH643Z" = "1" /* Insertion of Infusion Device into Left Inguinal Region, Percutaneous Endoscopic Approach */
"0YH64YZ" = "1" /* Insertion of Other Device into Left Inguinal Region, Percutaneous Endoscopic Approach */
"0YJ53ZZ" = "1" /* Inspection of Right Inguinal Region, Percutaneous Approach */
"0YJ54ZZ" = "1" /* Inspection of Right Inguinal Region, Percutaneous Endoscopic Approach */
"0YJ63ZZ" = "1" /* Inspection of Left Inguinal Region, Percutaneous Approach */
"0YJ64ZZ" = "1" /* Inspection of Left Inguinal Region, Percutaneous Endoscopic Approach */
"0YJA3ZZ" = "1" /* Inspection of Bilateral Inguinal Region, Percutaneous Approach */
"0YJA4ZZ" = "1" /* Inspection of Bilateral Inguinal Region, Percutaneous Endoscopic Approach */
"0YQ53ZZ" = "1" /* Repair Right Inguinal Region, Percutaneous Approach */
"0YQ54ZZ" = "1" /* Repair Right Inguinal Region, Percutaneous Endoscopic Approach */
"0YQ63ZZ" = "1" /* Repair Left Inguinal Region, Percutaneous Approach */
"0YQ64ZZ" = "1" /* Repair Left Inguinal Region, Percutaneous Endoscopic Approach */
"0YQ73ZZ" = "1" /* Repair Right Femoral Region, Percutaneous Approach */
"0YQ74ZZ" = "1" /* Repair Right Femoral Region, Percutaneous Endoscopic Approach */
"0YQ83ZZ" = "1" /* Repair Left Femoral Region, Percutaneous Approach */
"0YQ84ZZ" = "1" /* Repair Left Femoral Region, Percutaneous Endoscopic Approach */
"0YQA3ZZ" = "1" /* Repair Bilateral Inguinal Region, Percutaneous Approach */
"0YQA4ZZ" = "1" /* Repair Bilateral Inguinal Region, Percutaneous Endoscopic Approach */
"0YQE3ZZ" = "1" /* Repair Bilateral Femoral Region, Percutaneous Approach */
"0YQE4ZZ" = "1" /* Repair Bilateral Femoral Region, Percutaneous Endoscopic Approach */
"0YU547Z" = "1" /* Supplement Right Inguinal Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YU54JZ" = "1" /* Supplement Right Inguinal Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YU54KZ" = "1" /* Supplement Right Inguinal Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YU647Z" = "1" /* Supplement Left Inguinal Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YU64JZ" = "1" /* Supplement Left Inguinal Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YU64KZ" = "1" /* Supplement Left Inguinal Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YU747Z" = "1" /* Supplement Right Femoral Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YU74JZ" = "1" /* Supplement Right Femoral Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YU74KZ" = "1" /* Supplement Right Femoral Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YU847Z" = "1" /* Supplement Left Femoral Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YU84JZ" = "1" /* Supplement Left Femoral Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YU84KZ" = "1" /* Supplement Left Femoral Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUA47Z" = "1" /* Supplement Bilateral Inguinal Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUA4JZ" = "1" /* Supplement Bilateral Inguinal Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUA4KZ" = "1" /* Supplement Bilateral Inguinal Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUE47Z" = "1" /* Supplement Bilateral Femoral Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUE4JZ" = "1" /* Supplement Bilateral Femoral Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUE4KZ" = "1" /* Supplement Bilateral Femoral Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
Other = "0"
;

/* Procedure codeset CARDSIP last updated 161203 for ICD10 v70rev0 */
Value $CARDSIP
"0210083" = "1" /* Bypass Coronary Artery, One Artery from Coronary Artery with Zooplastic Tissue, Open Approach */
"0210088" = "1" /* Bypass Coronary Artery, One Artery from Right Internal Mammary with Zooplastic Tissue, Open Approach */
"0210089" = "1" /* Bypass Coronary Artery, One Artery from Left Internal Mammary with Zooplastic Tissue, Open Approach */
"021008C" = "1" /* Bypass Coronary Artery, One Artery from Thoracic Artery with Zooplastic Tissue, Open Approach */
"021008F" = "1" /* Bypass Coronary Artery, One Artery from Abdominal Artery with Zooplastic Tissue, Open Approach */
"021008W" = "1" /* Bypass Coronary Artery, One Artery from Aorta with Zooplastic Tissue, Open Approach */
"0210093" = "1" /* Bypass Coronary Artery, One Site from Coronary Artery with Autologous Venous Tissue, Open Approach */
"0210098" = "1" /* Bypass Coronary Artery, One Site from Right Internal Mammary with Autologous Venous Tissue, Open Approach */
"0210099" = "1" /* Bypass Coronary Artery, One Site from Left Internal Mammary with Autologous Venous Tissue, Open Approach */
"021009C" = "1" /* Bypass Coronary Artery, One Site from Thoracic Artery with Autologous Venous Tissue, Open Approach */
"021009F" = "1" /* Bypass Coronary Artery, One Site from Abdominal Artery with Autologous Venous Tissue, Open Approach */
"021009W" = "1" /* Bypass Coronary Artery, One Site from Aorta with Autologous Venous Tissue, Open Approach */
"02100A3" = "1" /* Bypass Coronary Artery, One Site from Coronary Artery with Autologous Arterial Tissue, Open Approach */
"02100A8" = "1" /* Bypass Coronary Artery, One Site from Right Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02100A9" = "1" /* Bypass Coronary Artery, One Site from Left Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02100AC" = "1" /* Bypass Coronary Artery, One Site from Thoracic Artery with Autologous Arterial Tissue, Open Approach */
"02100AF" = "1" /* Bypass Coronary Artery, One Site from Abdominal Artery with Autologous Arterial Tissue, Open Approach */
"02100AW" = "1" /* Bypass Coronary Artery, One Site from Aorta with Autologous Arterial Tissue, Open Approach */
"02100J3" = "1" /* Bypass Coronary Artery, One Site from Coronary Artery with Synthetic Substitute, Open Approach */
"02100J8" = "1" /* Bypass Coronary Artery, One Site from Right Internal Mammary with Synthetic Substitute, Open Approach */
"02100J9" = "1" /* Bypass Coronary Artery, One Site from Left Internal Mammary with Synthetic Substitute, Open Approach */
"02100JC" = "1" /* Bypass Coronary Artery, One Site from Thoracic Artery with Synthetic Substitute, Open Approach */
"02100JF" = "1" /* Bypass Coronary Artery, One Site from Abdominal Artery with Synthetic Substitute, Open Approach */
"02100JW" = "1" /* Bypass Coronary Artery, One Site from Aorta with Synthetic Substitute, Open Approach */
"02100K3" = "1" /* Bypass Coronary Artery, One Site from Coronary Artery with Nonautologous Tissue Substitute, Open Approach */
"02100K8" = "1" /* Bypass Coronary Artery, One Site from Right Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02100K9" = "1" /* Bypass Coronary Artery, One Site from Left Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02100KC" = "1" /* Bypass Coronary Artery, One Site from Thoracic Artery with Nonautologous Tissue Substitute, Open Approach */
"02100KF" = "1" /* Bypass Coronary Artery, One Site from Abdominal Artery with Nonautologous Tissue Substitute, Open Approach */
"02100KW" = "1" /* Bypass Coronary Artery, One Site from Aorta with Nonautologous Tissue Substitute, Open Approach */
"02100Z3" = "1" /* Bypass Coronary Artery, One Site from Coronary Artery, Open Approach */
"02100Z8" = "1" /* Bypass Coronary Artery, One Site from Right Internal Mammary, Open Approach */
"02100Z9" = "1" /* Bypass Coronary Artery, One Site from Left Internal Mammary, Open Approach */
"02100ZC" = "1" /* Bypass Coronary Artery, One Site from Thoracic Artery, Open Approach */
"02100ZF" = "1" /* Bypass Coronary Artery, One Site from Abdominal Artery, Open Approach */
"0210444" = "1" /* Bypass Coronary Artery, One Site from Coronary Vein with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0210483" = "1" /* Bypass Coronary Artery, One Artery from Coronary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0210488" = "1" /* Bypass Coronary Artery, One Artery from Right Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0210489" = "1" /* Bypass Coronary Artery, One Artery from Left Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021048C" = "1" /* Bypass Coronary Artery, One Artery from Thoracic Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021048F" = "1" /* Bypass Coronary Artery, One Artery from Abdominal Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021048W" = "1" /* Bypass Coronary Artery, One Artery from Aorta with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0210493" = "1" /* Bypass Coronary Artery, One Site from Coronary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0210498" = "1" /* Bypass Coronary Artery, One Site from Right Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0210499" = "1" /* Bypass Coronary Artery, One Site from Left Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021049C" = "1" /* Bypass Coronary Artery, One Site from Thoracic Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021049F" = "1" /* Bypass Coronary Artery, One Site from Abdominal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021049W" = "1" /* Bypass Coronary Artery, One Site from Aorta with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"02104A3" = "1" /* Bypass Coronary Artery, One Site from Coronary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104A8" = "1" /* Bypass Coronary Artery, One Site from Right Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104A9" = "1" /* Bypass Coronary Artery, One Site from Left Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104AC" = "1" /* Bypass Coronary Artery, One Site from Thoracic Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104AF" = "1" /* Bypass Coronary Artery, One Site from Abdominal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104AW" = "1" /* Bypass Coronary Artery, One Site from Aorta with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104D4" = "1" /* Bypass Coronary Artery, One Site from Coronary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"02104J3" = "1" /* Bypass Coronary Artery, One Site from Coronary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104J8" = "1" /* Bypass Coronary Artery, One Site from Right Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104J9" = "1" /* Bypass Coronary Artery, One Site from Left Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104JC" = "1" /* Bypass Coronary Artery, One Site from Thoracic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104JF" = "1" /* Bypass Coronary Artery, One Site from Abdominal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104JW" = "1" /* Bypass Coronary Artery, One Site from Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104K3" = "1" /* Bypass Coronary Artery, One Site from Coronary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104K8" = "1" /* Bypass Coronary Artery, One Site from Right Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104K9" = "1" /* Bypass Coronary Artery, One Site from Left Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104KC" = "1" /* Bypass Coronary Artery, One Site from Thoracic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104KF" = "1" /* Bypass Coronary Artery, One Site from Abdominal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104KW" = "1" /* Bypass Coronary Artery, One Site from Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104Z3" = "1" /* Bypass Coronary Artery, One Site from Coronary Artery, Percutaneous Endoscopic Approach */
"02104Z8" = "1" /* Bypass Coronary Artery, One Site from Right Internal Mammary, Percutaneous Endoscopic Approach */
"02104Z9" = "1" /* Bypass Coronary Artery, One Site from Left Internal Mammary, Percutaneous Endoscopic Approach */
"02104ZC" = "1" /* Bypass Coronary Artery, One Site from Thoracic Artery, Percutaneous Endoscopic Approach */
"02104ZF" = "1" /* Bypass Coronary Artery, One Site from Abdominal Artery, Percutaneous Endoscopic Approach */
"0211083" = "1" /* Bypass Coronary Artery, Two Arteries from Coronary Artery with Zooplastic Tissue, Open Approach */
"0211088" = "1" /* Bypass Coronary Artery, Two Arteries from Right Internal Mammary with Zooplastic Tissue, Open Approach */
"0211089" = "1" /* Bypass Coronary Artery, Two Arteries from Left Internal Mammary with Zooplastic Tissue, Open Approach */
"021108C" = "1" /* Bypass Coronary Artery, Two Arteries from Thoracic Artery with Zooplastic Tissue, Open Approach */
"021108F" = "1" /* Bypass Coronary Artery, Two Arteries from Abdominal Artery with Zooplastic Tissue, Open Approach */
"021108W" = "1" /* Bypass Coronary Artery, Two Arteries from Aorta with Zooplastic Tissue, Open Approach */
"0211093" = "1" /* Bypass Coronary Artery, Two Sites from Coronary Artery with Autologous Venous Tissue, Open Approach */
"0211098" = "1" /* Bypass Coronary Artery, Two Sites from Right Internal Mammary with Autologous Venous Tissue, Open Approach */
"0211099" = "1" /* Bypass Coronary Artery, Two Sites from Left Internal Mammary with Autologous Venous Tissue, Open Approach */
"021109C" = "1" /* Bypass Coronary Artery, Two Sites from Thoracic Artery with Autologous Venous Tissue, Open Approach */
"021109F" = "1" /* Bypass Coronary Artery, Two Sites from Abdominal Artery with Autologous Venous Tissue, Open Approach */
"021109W" = "1" /* Bypass Coronary Artery, Two Sites from Aorta with Autologous Venous Tissue, Open Approach */
"02110A3" = "1" /* Bypass Coronary Artery, Two Sites from Coronary Artery with Autologous Arterial Tissue, Open Approach */
"02110A8" = "1" /* Bypass Coronary Artery, Two Sites from Right Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02110A9" = "1" /* Bypass Coronary Artery, Two Sites from Left Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02110AC" = "1" /* Bypass Coronary Artery, Two Sites from Thoracic Artery with Autologous Arterial Tissue, Open Approach */
"02110AF" = "1" /* Bypass Coronary Artery, Two Sites from Abdominal Artery with Autologous Arterial Tissue, Open Approach */
"02110AW" = "1" /* Bypass Coronary Artery, Two Sites from Aorta with Autologous Arterial Tissue, Open Approach */
"02110J3" = "1" /* Bypass Coronary Artery, Two Sites from Coronary Artery with Synthetic Substitute, Open Approach */
"02110J8" = "1" /* Bypass Coronary Artery, Two Sites from Right Internal Mammary with Synthetic Substitute, Open Approach */
"02110J9" = "1" /* Bypass Coronary Artery, Two Sites from Left Internal Mammary with Synthetic Substitute, Open Approach */
"02110JC" = "1" /* Bypass Coronary Artery, Two Sites from Thoracic Artery with Synthetic Substitute, Open Approach */
"02110JF" = "1" /* Bypass Coronary Artery, Two Sites from Abdominal Artery with Synthetic Substitute, Open Approach */
"02110JW" = "1" /* Bypass Coronary Artery, Two Sites from Aorta with Synthetic Substitute, Open Approach */
"02110K3" = "1" /* Bypass Coronary Artery, Two Sites from Coronary Artery with Nonautologous Tissue Substitute, Open Approach */
"02110K8" = "1" /* Bypass Coronary Artery, Two Sites from Right Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02110K9" = "1" /* Bypass Coronary Artery, Two Sites from Left Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02110KC" = "1" /* Bypass Coronary Artery, Two Sites from Thoracic Artery with Nonautologous Tissue Substitute, Open Approach */
"02110KF" = "1" /* Bypass Coronary Artery, Two Sites from Abdominal Artery with Nonautologous Tissue Substitute, Open Approach */
"02110KW" = "1" /* Bypass Coronary Artery, Two Sites from Aorta with Nonautologous Tissue Substitute, Open Approach */
"02110Z3" = "1" /* Bypass Coronary Artery, Two Sites from Coronary Artery, Open Approach */
"02110Z8" = "1" /* Bypass Coronary Artery, Two Sites from Right Internal Mammary, Open Approach */
"02110Z9" = "1" /* Bypass Coronary Artery, Two Sites from Left Internal Mammary, Open Approach */
"02110ZC" = "1" /* Bypass Coronary Artery, Two Sites from Thoracic Artery, Open Approach */
"02110ZF" = "1" /* Bypass Coronary Artery, Two Sites from Abdominal Artery, Open Approach */
"0211444" = "1" /* Bypass Coronary Artery, Two Sites from Coronary Vein with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0211483" = "1" /* Bypass Coronary Artery, Two Arteries from Coronary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0211488" = "1" /* Bypass Coronary Artery, Two Arteries from Right Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0211489" = "1" /* Bypass Coronary Artery, Two Arteries from Left Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021148C" = "1" /* Bypass Coronary Artery, Two Arteries from Thoracic Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021148F" = "1" /* Bypass Coronary Artery, Two Arteries from Abdominal Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021148W" = "1" /* Bypass Coronary Artery, Two Arteries from Aorta with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0211493" = "1" /* Bypass Coronary Artery, Two Sites from Coronary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0211498" = "1" /* Bypass Coronary Artery, Two Sites from Right Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0211499" = "1" /* Bypass Coronary Artery, Two Sites from Left Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021149C" = "1" /* Bypass Coronary Artery, Two Sites from Thoracic Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021149F" = "1" /* Bypass Coronary Artery, Two Sites from Abdominal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021149W" = "1" /* Bypass Coronary Artery, Two Sites from Aorta with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"02114A3" = "1" /* Bypass Coronary Artery, Two Sites from Coronary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114A8" = "1" /* Bypass Coronary Artery, Two Sites from Right Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114A9" = "1" /* Bypass Coronary Artery, Two Sites from Left Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114AC" = "1" /* Bypass Coronary Artery, Two Sites from Thoracic Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114AF" = "1" /* Bypass Coronary Artery, Two Sites from Abdominal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114AW" = "1" /* Bypass Coronary Artery, Two Sites from Aorta with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114D4" = "1" /* Bypass Coronary Artery, Two Sites from Coronary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"02114J3" = "1" /* Bypass Coronary Artery, Two Sites from Coronary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114J8" = "1" /* Bypass Coronary Artery, Two Sites from Right Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114J9" = "1" /* Bypass Coronary Artery, Two Sites from Left Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114JC" = "1" /* Bypass Coronary Artery, Two Sites from Thoracic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114JF" = "1" /* Bypass Coronary Artery, Two Sites from Abdominal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114JW" = "1" /* Bypass Coronary Artery, Two Sites from Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114K3" = "1" /* Bypass Coronary Artery, Two Sites from Coronary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114K8" = "1" /* Bypass Coronary Artery, Two Sites from Right Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114K9" = "1" /* Bypass Coronary Artery, Two Sites from Left Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114KC" = "1" /* Bypass Coronary Artery, Two Sites from Thoracic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114KF" = "1" /* Bypass Coronary Artery, Two Sites from Abdominal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114KW" = "1" /* Bypass Coronary Artery, Two Sites from Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114Z3" = "1" /* Bypass Coronary Artery, Two Sites from Coronary Artery, Percutaneous Endoscopic Approach */
"02114Z8" = "1" /* Bypass Coronary Artery, Two Sites from Right Internal Mammary, Percutaneous Endoscopic Approach */
"02114Z9" = "1" /* Bypass Coronary Artery, Two Sites from Left Internal Mammary, Percutaneous Endoscopic Approach */
"02114ZC" = "1" /* Bypass Coronary Artery, Two Sites from Thoracic Artery, Percutaneous Endoscopic Approach */
"02114ZF" = "1" /* Bypass Coronary Artery, Two Sites from Abdominal Artery, Percutaneous Endoscopic Approach */
"0212083" = "1" /* Bypass Coronary Artery, Three Arteries from Coronary Artery with Zooplastic Tissue, Open Approach */
"0212088" = "1" /* Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Zooplastic Tissue, Open Approach */
"0212089" = "1" /* Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Zooplastic Tissue, Open Approach */
"021208C" = "1" /* Bypass Coronary Artery, Three Arteries from Thoracic Artery with Zooplastic Tissue, Open Approach */
"021208F" = "1" /* Bypass Coronary Artery, Three Arteries from Abdominal Artery with Zooplastic Tissue, Open Approach */
"021208W" = "1" /* Bypass Coronary Artery, Three Arteries from Aorta with Zooplastic Tissue, Open Approach */
"0212093" = "1" /* Bypass Coronary Artery, Three Sites from Coronary Artery with Autologous Venous Tissue, Open Approach */
"0212098" = "1" /* Bypass Coronary Artery, Three Sites from Right Internal Mammary with Autologous Venous Tissue, Open Approach */
"0212099" = "1" /* Bypass Coronary Artery, Three Sites from Left Internal Mammary with Autologous Venous Tissue, Open Approach */
"021209C" = "1" /* Bypass Coronary Artery, Three Sites from Thoracic Artery with Autologous Venous Tissue, Open Approach */
"021209F" = "1" /* Bypass Coronary Artery, Three Sites from Abdominal Artery with Autologous Venous Tissue, Open Approach */
"021209W" = "1" /* Bypass Coronary Artery, Three Sites from Aorta with Autologous Venous Tissue, Open Approach */
"02120A3" = "1" /* Bypass Coronary Artery, Three Sites from Coronary Artery with Autologous Arterial Tissue, Open Approach */
"02120A8" = "1" /* Bypass Coronary Artery, Three Sites from Right Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02120A9" = "1" /* Bypass Coronary Artery, Three Sites from Left Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02120AC" = "1" /* Bypass Coronary Artery, Three Sites from Thoracic Artery with Autologous Arterial Tissue, Open Approach */
"02120AF" = "1" /* Bypass Coronary Artery, Three Sites from Abdominal Artery with Autologous Arterial Tissue, Open Approach */
"02120AW" = "1" /* Bypass Coronary Artery, Three Sites from Aorta with Autologous Arterial Tissue, Open Approach */
"02120J3" = "1" /* Bypass Coronary Artery, Three Sites from Coronary Artery with Synthetic Substitute, Open Approach */
"02120J8" = "1" /* Bypass Coronary Artery, Three Sites from Right Internal Mammary with Synthetic Substitute, Open Approach */
"02120J9" = "1" /* Bypass Coronary Artery, Three Sites from Left Internal Mammary with Synthetic Substitute, Open Approach */
"02120JC" = "1" /* Bypass Coronary Artery, Three Sites from Thoracic Artery with Synthetic Substitute, Open Approach */
"02120JF" = "1" /* Bypass Coronary Artery, Three Sites from Abdominal Artery with Synthetic Substitute, Open Approach */
"02120JW" = "1" /* Bypass Coronary Artery, Three Sites from Aorta with Synthetic Substitute, Open Approach */
"02120K3" = "1" /* Bypass Coronary Artery, Three Sites from Coronary Artery with Nonautologous Tissue Substitute, Open Approach */
"02120K8" = "1" /* Bypass Coronary Artery, Three Sites from Right Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02120K9" = "1" /* Bypass Coronary Artery, Three Sites from Left Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02120KC" = "1" /* Bypass Coronary Artery, Three Sites from Thoracic Artery with Nonautologous Tissue Substitute, Open Approach */
"02120KF" = "1" /* Bypass Coronary Artery, Three Sites from Abdominal Artery with Nonautologous Tissue Substitute, Open Approach */
"02120KW" = "1" /* Bypass Coronary Artery, Three Sites from Aorta with Nonautologous Tissue Substitute, Open Approach */
"02120Z3" = "1" /* Bypass Coronary Artery, Three Sites from Coronary Artery, Open Approach */
"02120Z8" = "1" /* Bypass Coronary Artery, Three Sites from Right Internal Mammary, Open Approach */
"02120Z9" = "1" /* Bypass Coronary Artery, Three Sites from Left Internal Mammary, Open Approach */
"02120ZC" = "1" /* Bypass Coronary Artery, Three Sites from Thoracic Artery, Open Approach */
"02120ZF" = "1" /* Bypass Coronary Artery, Three Sites from Abdominal Artery, Open Approach */
"0212444" = "1" /* Bypass Coronary Artery, Three Sites from Coronary Vein with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0212483" = "1" /* Bypass Coronary Artery, Three Arteries from Coronary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0212488" = "1" /* Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0212489" = "1" /* Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021248C" = "1" /* Bypass Coronary Artery, Three Arteries from Thoracic Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021248F" = "1" /* Bypass Coronary Artery, Three Arteries from Abdominal Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021248W" = "1" /* Bypass Coronary Artery, Three Arteries from Aorta with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0212493" = "1" /* Bypass Coronary Artery, Three Sites from Coronary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0212498" = "1" /* Bypass Coronary Artery, Three Sites from Right Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0212499" = "1" /* Bypass Coronary Artery, Three Sites from Left Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021249C" = "1" /* Bypass Coronary Artery, Three Sites from Thoracic Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021249F" = "1" /* Bypass Coronary Artery, Three Sites from Abdominal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021249W" = "1" /* Bypass Coronary Artery, Three Sites from Aorta with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"02124A3" = "1" /* Bypass Coronary Artery, Three Sites from Coronary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124A8" = "1" /* Bypass Coronary Artery, Three Sites from Right Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124A9" = "1" /* Bypass Coronary Artery, Three Sites from Left Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124AC" = "1" /* Bypass Coronary Artery, Three Sites from Thoracic Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124AF" = "1" /* Bypass Coronary Artery, Three Sites from Abdominal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124AW" = "1" /* Bypass Coronary Artery, Three Sites from Aorta with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124D4" = "1" /* Bypass Coronary Artery, Three Sites from Coronary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"02124J3" = "1" /* Bypass Coronary Artery, Three Sites from Coronary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124J8" = "1" /* Bypass Coronary Artery, Three Sites from Right Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124J9" = "1" /* Bypass Coronary Artery, Three Sites from Left Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124JC" = "1" /* Bypass Coronary Artery, Three Sites from Thoracic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124JF" = "1" /* Bypass Coronary Artery, Three Sites from Abdominal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124JW" = "1" /* Bypass Coronary Artery, Three Sites from Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124K3" = "1" /* Bypass Coronary Artery, Three Sites from Coronary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124K8" = "1" /* Bypass Coronary Artery, Three Sites from Right Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124K9" = "1" /* Bypass Coronary Artery, Three Sites from Left Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124KC" = "1" /* Bypass Coronary Artery, Three Sites from Thoracic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124KF" = "1" /* Bypass Coronary Artery, Three Sites from Abdominal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124KW" = "1" /* Bypass Coronary Artery, Three Sites from Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124Z3" = "1" /* Bypass Coronary Artery, Three Sites from Coronary Artery, Percutaneous Endoscopic Approach */
"02124Z8" = "1" /* Bypass Coronary Artery, Three Sites from Right Internal Mammary, Percutaneous Endoscopic Approach */
"02124Z9" = "1" /* Bypass Coronary Artery, Three Sites from Left Internal Mammary, Percutaneous Endoscopic Approach */
"02124ZC" = "1" /* Bypass Coronary Artery, Three Sites from Thoracic Artery, Percutaneous Endoscopic Approach */
"02124ZF" = "1" /* Bypass Coronary Artery, Three Sites from Abdominal Artery, Percutaneous Endoscopic Approach */
"0213083" = "1" /* Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Zooplastic Tissue, Open Approach */
"0213088" = "1" /* Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Zooplastic Tissue, Open Approach */
"0213089" = "1" /* Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Zooplastic Tissue, Open Approach */
"021308C" = "1" /* Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Zooplastic Tissue, Open Approach */
"021308F" = "1" /* Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Zooplastic Tissue, Open Approach */
"021308W" = "1" /* Bypass Coronary Artery, Four or More Arteries from Aorta with Zooplastic Tissue, Open Approach */
"0213093" = "1" /* Bypass Coronary Artery, Four or More Sites from Coronary Artery with Autologous Venous Tissue, Open Approach */
"0213098" = "1" /* Bypass Coronary Artery, Four or More Sites from Right Internal Mammary with Autologous Venous Tissue, Open Approach */
"0213099" = "1" /* Bypass Coronary Artery, Four or More Sites from Left Internal Mammary with Autologous Venous Tissue, Open Approach */
"021309C" = "1" /* Bypass Coronary Artery, Four or More Sites from Thoracic Artery with Autologous Venous Tissue, Open Approach */
"021309F" = "1" /* Bypass Coronary Artery, Four or More Sites from Abdominal Artery with Autologous Venous Tissue, Open Approach */
"021309W" = "1" /* Bypass Coronary Artery, Four or More Sites from Aorta with Autologous Venous Tissue, Open Approach */
"02130A3" = "1" /* Bypass Coronary Artery, Four or More Sites from Coronary Artery with Autologous Arterial Tissue, Open Approach */
"02130A8" = "1" /* Bypass Coronary Artery, Four or More Sites from Right Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02130A9" = "1" /* Bypass Coronary Artery, Four or More Sites from Left Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02130AC" = "1" /* Bypass Coronary Artery, Four or More Sites from Thoracic Artery with Autologous Arterial Tissue, Open Approach */
"02130AF" = "1" /* Bypass Coronary Artery, Four or More Sites from Abdominal Artery with Autologous Arterial Tissue, Open Approach */
"02130AW" = "1" /* Bypass Coronary Artery, Four or More Sites from Aorta with Autologous Arterial Tissue, Open Approach */
"02130J3" = "1" /* Bypass Coronary Artery, Four or More Sites from Coronary Artery with Synthetic Substitute, Open Approach */
"02130J8" = "1" /* Bypass Coronary Artery, Four or More Sites from Right Internal Mammary with Synthetic Substitute, Open Approach */
"02130J9" = "1" /* Bypass Coronary Artery, Four or More Sites from Left Internal Mammary with Synthetic Substitute, Open Approach */
"02130JC" = "1" /* Bypass Coronary Artery, Four or More Sites from Thoracic Artery with Synthetic Substitute, Open Approach */
"02130JF" = "1" /* Bypass Coronary Artery, Four or More Sites from Abdominal Artery with Synthetic Substitute, Open Approach */
"02130JW" = "1" /* Bypass Coronary Artery, Four or More Sites from Aorta with Synthetic Substitute, Open Approach */
"02130K3" = "1" /* Bypass Coronary Artery, Four or More Sites from Coronary Artery with Nonautologous Tissue Substitute, Open Approach */
"02130K8" = "1" /* Bypass Coronary Artery, Four or More Sites from Right Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02130K9" = "1" /* Bypass Coronary Artery, Four or More Sites from Left Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02130KC" = "1" /* Bypass Coronary Artery, Four or More Sites from Thoracic Artery with Nonautologous Tissue Substitute, Open Approach */
"02130KF" = "1" /* Bypass Coronary Artery, Four or More Sites from Abdominal Artery with Nonautologous Tissue Substitute, Open Approach */
"02130KW" = "1" /* Bypass Coronary Artery, Four or More Sites from Aorta with Nonautologous Tissue Substitute, Open Approach */
"02130Z3" = "1" /* Bypass Coronary Artery, Four or More Sites from Coronary Artery, Open Approach */
"02130Z8" = "1" /* Bypass Coronary Artery, Four or More Sites from Right Internal Mammary, Open Approach */
"02130Z9" = "1" /* Bypass Coronary Artery, Four or More Sites from Left Internal Mammary, Open Approach */
"02130ZC" = "1" /* Bypass Coronary Artery, Four or More Sites from Thoracic Artery, Open Approach */
"02130ZF" = "1" /* Bypass Coronary Artery, Four or More Sites from Abdominal Artery, Open Approach */
"0213444" = "1" /* Bypass Coronary Artery, Four or More Sites from Coronary Vein with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0213483" = "1" /* Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0213488" = "1" /* Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0213489" = "1" /* Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021348C" = "1" /* Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021348F" = "1" /* Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021348W" = "1" /* Bypass Coronary Artery, Four or More Arteries from Aorta with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0213493" = "1" /* Bypass Coronary Artery, Four or More Sites from Coronary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0213498" = "1" /* Bypass Coronary Artery, Four or More Sites from Right Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0213499" = "1" /* Bypass Coronary Artery, Four or More Sites from Left Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021349C" = "1" /* Bypass Coronary Artery, Four or More Sites from Thoracic Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021349F" = "1" /* Bypass Coronary Artery, Four or More Sites from Abdominal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021349W" = "1" /* Bypass Coronary Artery, Four or More Sites from Aorta with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"02134A3" = "1" /* Bypass Coronary Artery, Four or More Sites from Coronary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134A8" = "1" /* Bypass Coronary Artery, Four or More Sites from Right Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134A9" = "1" /* Bypass Coronary Artery, Four or More Sites from Left Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134AC" = "1" /* Bypass Coronary Artery, Four or More Sites from Thoracic Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134AF" = "1" /* Bypass Coronary Artery, Four or More Sites from Abdominal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134AW" = "1" /* Bypass Coronary Artery, Four or More Sites from Aorta with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134D4" = "1" /* Bypass Coronary Artery, Four or More Sites from Coronary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"02134J3" = "1" /* Bypass Coronary Artery, Four or More Sites from Coronary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134J8" = "1" /* Bypass Coronary Artery, Four or More Sites from Right Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134J9" = "1" /* Bypass Coronary Artery, Four or More Sites from Left Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134JC" = "1" /* Bypass Coronary Artery, Four or More Sites from Thoracic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134JF" = "1" /* Bypass Coronary Artery, Four or More Sites from Abdominal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134JW" = "1" /* Bypass Coronary Artery, Four or More Sites from Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134K3" = "1" /* Bypass Coronary Artery, Four or More Sites from Coronary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134K8" = "1" /* Bypass Coronary Artery, Four or More Sites from Right Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134K9" = "1" /* Bypass Coronary Artery, Four or More Sites from Left Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134KC" = "1" /* Bypass Coronary Artery, Four or More Sites from Thoracic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134KF" = "1" /* Bypass Coronary Artery, Four or More Sites from Abdominal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134KW" = "1" /* Bypass Coronary Artery, Four or More Sites from Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134Z3" = "1" /* Bypass Coronary Artery, Four or More Sites from Coronary Artery, Percutaneous Endoscopic Approach */
"02134Z8" = "1" /* Bypass Coronary Artery, Four or More Sites from Right Internal Mammary, Percutaneous Endoscopic Approach */
"02134Z9" = "1" /* Bypass Coronary Artery, Four or More Sites from Left Internal Mammary, Percutaneous Endoscopic Approach */
"02134ZC" = "1" /* Bypass Coronary Artery, Four or More Sites from Thoracic Artery, Percutaneous Endoscopic Approach */
"02134ZF" = "1" /* Bypass Coronary Artery, Four or More Sites from Abdominal Artery, Percutaneous Endoscopic Approach */
"021608P" = "1" /* Bypass Right Atrium to Pulmonary Trunk with Zooplastic Tissue, Open Approach */
"021608Q" = "1" /* Bypass Right Atrium to Right Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021608R" = "1" /* Bypass Right Atrium to Left Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021609P" = "1" /* Bypass Right Atrium to Pulmonary Trunk with Autologous Venous Tissue, Open Approach */
"021609Q" = "1" /* Bypass Right Atrium to Right Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021609R" = "1" /* Bypass Right Atrium to Left Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"02160AP" = "1" /* Bypass Right Atrium to Pulmonary Trunk with Autologous Arterial Tissue, Open Approach */
"02160AQ" = "1" /* Bypass Right Atrium to Right Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"02160AR" = "1" /* Bypass Right Atrium to Left Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"02160JP" = "1" /* Bypass Right Atrium to Pulmonary Trunk with Synthetic Substitute, Open Approach */
"02160JQ" = "1" /* Bypass Right Atrium to Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"02160JR" = "1" /* Bypass Right Atrium to Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"02160KP" = "1" /* Bypass Right Atrium to Pulmonary Trunk with Nonautologous Tissue Substitute, Open Approach */
"02160KQ" = "1" /* Bypass Right Atrium to Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"02160KR" = "1" /* Bypass Right Atrium to Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"02160Z7" = "1" /* Bypass Right Atrium to Left Atrium, Open Approach */
"02160ZP" = "1" /* Bypass Right Atrium to Pulmonary Trunk, Open Approach */
"02160ZQ" = "1" /* Bypass Right Atrium to Right Pulmonary Artery, Open Approach */
"02160ZR" = "1" /* Bypass Right Atrium to Left Pulmonary Artery, Open Approach */
"021648P" = "1" /* Bypass Right Atrium to Pulmonary Trunk with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021648Q" = "1" /* Bypass Right Atrium to Right Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021648R" = "1" /* Bypass Right Atrium to Left Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021649P" = "1" /* Bypass Right Atrium to Pulmonary Trunk with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021649Q" = "1" /* Bypass Right Atrium to Right Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021649R" = "1" /* Bypass Right Atrium to Left Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"02164AP" = "1" /* Bypass Right Atrium to Pulmonary Trunk with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02164AQ" = "1" /* Bypass Right Atrium to Right Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02164AR" = "1" /* Bypass Right Atrium to Left Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02164JP" = "1" /* Bypass Right Atrium to Pulmonary Trunk with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02164JQ" = "1" /* Bypass Right Atrium to Right Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02164JR" = "1" /* Bypass Right Atrium to Left Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02164KP" = "1" /* Bypass Right Atrium to Pulmonary Trunk with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02164KQ" = "1" /* Bypass Right Atrium to Right Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02164KR" = "1" /* Bypass Right Atrium to Left Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02164Z7" = "1" /* Bypass Right Atrium to Left Atrium, Percutaneous Endoscopic Approach */
"02164ZP" = "1" /* Bypass Right Atrium to Pulmonary Trunk, Percutaneous Endoscopic Approach */
"02164ZQ" = "1" /* Bypass Right Atrium to Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"02164ZR" = "1" /* Bypass Right Atrium to Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"021708P" = "1" /* Bypass Left Atrium to Pulmonary Trunk with Zooplastic Tissue, Open Approach */
"021708Q" = "1" /* Bypass Left Atrium to Right Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021708R" = "1" /* Bypass Left Atrium to Left Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021709P" = "1" /* Bypass Left Atrium to Pulmonary Trunk with Autologous Venous Tissue, Open Approach */
"021709Q" = "1" /* Bypass Left Atrium to Right Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021709R" = "1" /* Bypass Left Atrium to Left Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021709S" = "1" /* Bypass Left Atrium to Right Pulmonary Vein with Autologous Venous Tissue, Open Approach */
"021709T" = "1" /* Bypass Left Atrium to Left Pulmonary Vein with Autologous Venous Tissue, Open Approach */
"021709U" = "1" /* Bypass Left Atrium to Pulmonary Vein Confluence with Autologous Venous Tissue, Open Approach */
"02170AP" = "1" /* Bypass Left Atrium to Pulmonary Trunk with Autologous Arterial Tissue, Open Approach */
"02170AQ" = "1" /* Bypass Left Atrium to Right Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"02170AR" = "1" /* Bypass Left Atrium to Left Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"02170AS" = "1" /* Bypass Left Atrium to Right Pulmonary Vein with Autologous Arterial Tissue, Open Approach */
"02170AT" = "1" /* Bypass Left Atrium to Left Pulmonary Vein with Autologous Arterial Tissue, Open Approach */
"02170AU" = "1" /* Bypass Left Atrium to Pulmonary Vein Confluence with Autologous Arterial Tissue, Open Approach */
"02170JP" = "1" /* Bypass Left Atrium to Pulmonary Trunk with Synthetic Substitute, Open Approach */
"02170JQ" = "1" /* Bypass Left Atrium to Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"02170JR" = "1" /* Bypass Left Atrium to Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"02170JS" = "1" /* Bypass Left Atrium to Right Pulmonary Vein with Synthetic Substitute, Open Approach */
"02170JT" = "1" /* Bypass Left Atrium to Left Pulmonary Vein with Synthetic Substitute, Open Approach */
"02170JU" = "1" /* Bypass Left Atrium to Pulmonary Vein Confluence with Synthetic Substitute, Open Approach */
"02170KP" = "1" /* Bypass Left Atrium to Pulmonary Trunk with Nonautologous Tissue Substitute, Open Approach */
"02170KQ" = "1" /* Bypass Left Atrium to Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"02170KR" = "1" /* Bypass Left Atrium to Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"02170KS" = "1" /* Bypass Left Atrium to Right Pulmonary Vein with Nonautologous Tissue Substitute, Open Approach */
"02170KT" = "1" /* Bypass Left Atrium to Left Pulmonary Vein with Nonautologous Tissue Substitute, Open Approach */
"02170KU" = "1" /* Bypass Left Atrium to Pulmonary Vein Confluence with Nonautologous Tissue Substitute, Open Approach */
"02170ZP" = "1" /* Bypass Left Atrium to Pulmonary Trunk, Open Approach */
"02170ZQ" = "1" /* Bypass Left Atrium to Right Pulmonary Artery, Open Approach */
"02170ZR" = "1" /* Bypass Left Atrium to Left Pulmonary Artery, Open Approach */
"02170ZS" = "1" /* Bypass Left Atrium to Right Pulmonary Vein, Open Approach */
"02170ZT" = "1" /* Bypass Left Atrium to Left Pulmonary Vein, Open Approach */
"02170ZU" = "1" /* Bypass Left Atrium to Pulmonary Vein Confluence, Open Approach */
"021748P" = "1" /* Bypass Left Atrium to Pulmonary Trunk with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021748Q" = "1" /* Bypass Left Atrium to Right Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021748R" = "1" /* Bypass Left Atrium to Left Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021749P" = "1" /* Bypass Left Atrium to Pulmonary Trunk with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021749Q" = "1" /* Bypass Left Atrium to Right Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021749R" = "1" /* Bypass Left Atrium to Left Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021749S" = "1" /* Bypass Left Atrium to Right Pulmonary Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021749T" = "1" /* Bypass Left Atrium to Left Pulmonary Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021749U" = "1" /* Bypass Left Atrium to Pulmonary Vein Confluence with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"02174AP" = "1" /* Bypass Left Atrium to Pulmonary Trunk with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02174AQ" = "1" /* Bypass Left Atrium to Right Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02174AR" = "1" /* Bypass Left Atrium to Left Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02174AS" = "1" /* Bypass Left Atrium to Right Pulmonary Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02174AT" = "1" /* Bypass Left Atrium to Left Pulmonary Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02174AU" = "1" /* Bypass Left Atrium to Pulmonary Vein Confluence with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02174JP" = "1" /* Bypass Left Atrium to Pulmonary Trunk with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02174JQ" = "1" /* Bypass Left Atrium to Right Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02174JR" = "1" /* Bypass Left Atrium to Left Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02174JS" = "1" /* Bypass Left Atrium to Right Pulmonary Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02174JT" = "1" /* Bypass Left Atrium to Left Pulmonary Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02174JU" = "1" /* Bypass Left Atrium to Pulmonary Vein Confluence with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02174KP" = "1" /* Bypass Left Atrium to Pulmonary Trunk with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02174KQ" = "1" /* Bypass Left Atrium to Right Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02174KR" = "1" /* Bypass Left Atrium to Left Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02174KS" = "1" /* Bypass Left Atrium to Right Pulmonary Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02174KT" = "1" /* Bypass Left Atrium to Left Pulmonary Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02174KU" = "1" /* Bypass Left Atrium to Pulmonary Vein Confluence with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02174ZP" = "1" /* Bypass Left Atrium to Pulmonary Trunk, Percutaneous Endoscopic Approach */
"02174ZQ" = "1" /* Bypass Left Atrium to Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"02174ZR" = "1" /* Bypass Left Atrium to Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"02174ZS" = "1" /* Bypass Left Atrium to Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"02174ZT" = "1" /* Bypass Left Atrium to Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"02174ZU" = "1" /* Bypass Left Atrium to Pulmonary Vein Confluence, Percutaneous Endoscopic Approach */
"021K08P" = "1" /* Bypass Right Ventricle to Pulmonary Trunk with Zooplastic Tissue, Open Approach */
"021K08Q" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021K08R" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021K09P" = "1" /* Bypass Right Ventricle to Pulmonary Trunk with Autologous Venous Tissue, Open Approach */
"021K09Q" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021K09R" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021K0AP" = "1" /* Bypass Right Ventricle to Pulmonary Trunk with Autologous Arterial Tissue, Open Approach */
"021K0AQ" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021K0AR" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021K0JP" = "1" /* Bypass Right Ventricle to Pulmonary Trunk with Synthetic Substitute, Open Approach */
"021K0JQ" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"021K0JR" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"021K0KP" = "1" /* Bypass Right Ventricle to Pulmonary Trunk with Nonautologous Tissue Substitute, Open Approach */
"021K0KQ" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021K0KR" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021K0Z5" = "1" /* Bypass Right Ventricle to Coronary Circulation, Open Approach */
"021K0Z8" = "1" /* Bypass Right Ventricle to Right Internal Mammary, Open Approach */
"021K0Z9" = "1" /* Bypass Right Ventricle to Left Internal Mammary, Open Approach */
"021K0ZC" = "1" /* Bypass Right Ventricle to Thoracic Artery, Open Approach */
"021K0ZF" = "1" /* Bypass Right Ventricle to Abdominal Artery, Open Approach */
"021K0ZP" = "1" /* Bypass Right Ventricle to Pulmonary Trunk, Open Approach */
"021K0ZQ" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery, Open Approach */
"021K0ZR" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery, Open Approach */
"021K0ZW" = "1" /* Bypass Right Ventricle to Aorta, Open Approach */
"021K48P" = "1" /* Bypass Right Ventricle to Pulmonary Trunk with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021K48Q" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021K48R" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021K49P" = "1" /* Bypass Right Ventricle to Pulmonary Trunk with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021K49Q" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021K49R" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021K4AP" = "1" /* Bypass Right Ventricle to Pulmonary Trunk with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021K4AQ" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021K4AR" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021K4JP" = "1" /* Bypass Right Ventricle to Pulmonary Trunk with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021K4JQ" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021K4JR" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021K4KP" = "1" /* Bypass Right Ventricle to Pulmonary Trunk with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021K4KQ" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021K4KR" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021K4Z5" = "1" /* Bypass Right Ventricle to Coronary Circulation, Percutaneous Endoscopic Approach */
"021K4Z8" = "1" /* Bypass Right Ventricle to Right Internal Mammary, Percutaneous Endoscopic Approach */
"021K4Z9" = "1" /* Bypass Right Ventricle to Left Internal Mammary, Percutaneous Endoscopic Approach */
"021K4ZC" = "1" /* Bypass Right Ventricle to Thoracic Artery, Percutaneous Endoscopic Approach */
"021K4ZF" = "1" /* Bypass Right Ventricle to Abdominal Artery, Percutaneous Endoscopic Approach */
"021K4ZP" = "1" /* Bypass Right Ventricle to Pulmonary Trunk, Percutaneous Endoscopic Approach */
"021K4ZQ" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"021K4ZR" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"021K4ZW" = "1" /* Bypass Right Ventricle to Aorta, Percutaneous Endoscopic Approach */
"021L08P" = "1" /* Bypass Left Ventricle to Pulmonary Trunk with Zooplastic Tissue, Open Approach */
"021L08Q" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021L08R" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021L09P" = "1" /* Bypass Left Ventricle to Pulmonary Trunk with Autologous Venous Tissue, Open Approach */
"021L09Q" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021L09R" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021L0AP" = "1" /* Bypass Left Ventricle to Pulmonary Trunk with Autologous Arterial Tissue, Open Approach */
"021L0AQ" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021L0AR" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021L0JP" = "1" /* Bypass Left Ventricle to Pulmonary Trunk with Synthetic Substitute, Open Approach */
"021L0JQ" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"021L0JR" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"021L0KP" = "1" /* Bypass Left Ventricle to Pulmonary Trunk with Nonautologous Tissue Substitute, Open Approach */
"021L0KQ" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021L0KR" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021L0Z5" = "1" /* Bypass Left Ventricle to Coronary Circulation, Open Approach */
"021L0Z8" = "1" /* Bypass Left Ventricle to Right Internal Mammary, Open Approach */
"021L0Z9" = "1" /* Bypass Left Ventricle to Left Internal Mammary, Open Approach */
"021L0ZC" = "1" /* Bypass Left Ventricle to Thoracic Artery, Open Approach */
"021L0ZF" = "1" /* Bypass Left Ventricle to Abdominal Artery, Open Approach */
"021L0ZP" = "1" /* Bypass Left Ventricle to Pulmonary Trunk, Open Approach */
"021L0ZQ" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery, Open Approach */
"021L0ZR" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery, Open Approach */
"021L0ZW" = "1" /* Bypass Left Ventricle to Aorta, Open Approach */
"021L48P" = "1" /* Bypass Left Ventricle to Pulmonary Trunk with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021L48Q" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021L48R" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021L49P" = "1" /* Bypass Left Ventricle to Pulmonary Trunk with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021L49Q" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021L49R" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021L4AP" = "1" /* Bypass Left Ventricle to Pulmonary Trunk with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021L4AQ" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021L4AR" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021L4JP" = "1" /* Bypass Left Ventricle to Pulmonary Trunk with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021L4JQ" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021L4JR" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021L4KP" = "1" /* Bypass Left Ventricle to Pulmonary Trunk with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021L4KQ" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021L4KR" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021L4Z5" = "1" /* Bypass Left Ventricle to Coronary Circulation, Percutaneous Endoscopic Approach */
"021L4Z8" = "1" /* Bypass Left Ventricle to Right Internal Mammary, Percutaneous Endoscopic Approach */
"021L4Z9" = "1" /* Bypass Left Ventricle to Left Internal Mammary, Percutaneous Endoscopic Approach */
"021L4ZC" = "1" /* Bypass Left Ventricle to Thoracic Artery, Percutaneous Endoscopic Approach */
"021L4ZF" = "1" /* Bypass Left Ventricle to Abdominal Artery, Percutaneous Endoscopic Approach */
"021L4ZP" = "1" /* Bypass Left Ventricle to Pulmonary Trunk, Percutaneous Endoscopic Approach */
"021L4ZQ" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"021L4ZR" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"021L4ZW" = "1" /* Bypass Left Ventricle to Aorta, Percutaneous Endoscopic Approach */
"021V08P" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk with Zooplastic Tissue, Open Approach */
"021V08Q" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021V08R" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021V09P" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk with Autologous Venous Tissue, Open Approach */
"021V09Q" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021V09R" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021V09S" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Vein with Autologous Venous Tissue, Open Approach */
"021V09T" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Vein with Autologous Venous Tissue, Open Approach */
"021V09U" = "1" /* Bypass Superior Vena Cava to Pulmonary Vein Confluence with Autologous Venous Tissue, Open Approach */
"021V0AP" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk with Autologous Arterial Tissue, Open Approach */
"021V0AQ" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021V0AR" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021V0AS" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Vein with Autologous Arterial Tissue, Open Approach */
"021V0AT" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Vein with Autologous Arterial Tissue, Open Approach */
"021V0AU" = "1" /* Bypass Superior Vena Cava to Pulmonary Vein Confluence with Autologous Arterial Tissue, Open Approach */
"021V0JP" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk with Synthetic Substitute, Open Approach */
"021V0JQ" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"021V0JR" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"021V0JS" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Vein with Synthetic Substitute, Open Approach */
"021V0JT" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Vein with Synthetic Substitute, Open Approach */
"021V0JU" = "1" /* Bypass Superior Vena Cava to Pulmonary Vein Confluence with Synthetic Substitute, Open Approach */
"021V0KP" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk with Nonautologous Tissue Substitute, Open Approach */
"021V0KQ" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021V0KR" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021V0KS" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Vein with Nonautologous Tissue Substitute, Open Approach */
"021V0KT" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Vein with Nonautologous Tissue Substitute, Open Approach */
"021V0KU" = "1" /* Bypass Superior Vena Cava to Pulmonary Vein Confluence with Nonautologous Tissue Substitute, Open Approach */
"021V0ZP" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk, Open Approach */
"021V0ZQ" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery, Open Approach */
"021V0ZR" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery, Open Approach */
"021V0ZS" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Vein, Open Approach */
"021V0ZT" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Vein, Open Approach */
"021V0ZU" = "1" /* Bypass Superior Vena Cava to Pulmonary Vein Confluence, Open Approach */
"021V48P" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021V48Q" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021V48R" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021V49P" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021V49Q" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021V49R" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021V49S" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021V49T" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021V49U" = "1" /* Bypass Superior Vena Cava to Pulmonary Vein Confluence with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021V4AP" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021V4AQ" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021V4AR" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021V4AS" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021V4AT" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021V4AU" = "1" /* Bypass Superior Vena Cava to Pulmonary Vein Confluence with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021V4JP" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021V4JQ" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021V4JR" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021V4JS" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021V4JT" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021V4JU" = "1" /* Bypass Superior Vena Cava to Pulmonary Vein Confluence with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021V4KP" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021V4KQ" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021V4KR" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021V4KS" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021V4KT" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021V4KU" = "1" /* Bypass Superior Vena Cava to Pulmonary Vein Confluence with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021V4ZP" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk, Percutaneous Endoscopic Approach */
"021V4ZQ" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"021V4ZR" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"021V4ZS" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"021V4ZT" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"021V4ZU" = "1" /* Bypass Superior Vena Cava to Pulmonary Vein Confluence, Percutaneous Endoscopic Approach */
"021W08B" = "1" /* Bypass Thoracic Aorta, Descending to Subclavian with Zooplastic Tissue, Open Approach */
"021W08D" = "1" /* Bypass Thoracic Aorta, Descending to Carotid with Zooplastic Tissue, Open Approach */
"021W08P" = "1" /* Bypass Thoracic Aorta, Descending to Pulmonary Trunk with Zooplastic Tissue, Open Approach */
"021W08Q" = "1" /* Bypass Thoracic Aorta, Descending to Right Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021W08R" = "1" /* Bypass Thoracic Aorta, Descending to Left Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021W09B" = "1" /* Bypass Thoracic Aorta to Subclavian with Autologous Venous Tissue, Open Approach */
"021W09D" = "1" /* Bypass Thoracic Aorta to Carotid with Autologous Venous Tissue, Open Approach */
"021W09P" = "1" /* Bypass Thoracic Aorta to Pulmonary Trunk with Autologous Venous Tissue, Open Approach */
"021W09Q" = "1" /* Bypass Thoracic Aorta to Right Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021W09R" = "1" /* Bypass Thoracic Aorta to Left Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021W0AB" = "1" /* Bypass Thoracic Aorta to Subclavian with Autologous Arterial Tissue, Open Approach */
"021W0AD" = "1" /* Bypass Thoracic Aorta to Carotid with Autologous Arterial Tissue, Open Approach */
"021W0AP" = "1" /* Bypass Thoracic Aorta to Pulmonary Trunk with Autologous Arterial Tissue, Open Approach */
"021W0AQ" = "1" /* Bypass Thoracic Aorta to Right Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021W0AR" = "1" /* Bypass Thoracic Aorta to Left Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021W0JB" = "1" /* Bypass Thoracic Aorta to Subclavian with Synthetic Substitute, Open Approach */
"021W0JD" = "1" /* Bypass Thoracic Aorta to Carotid with Synthetic Substitute, Open Approach */
"021W0JP" = "1" /* Bypass Thoracic Aorta to Pulmonary Trunk with Synthetic Substitute, Open Approach */
"021W0JQ" = "1" /* Bypass Thoracic Aorta to Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"021W0JR" = "1" /* Bypass Thoracic Aorta to Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"021W0KB" = "1" /* Bypass Thoracic Aorta to Subclavian with Nonautologous Tissue Substitute, Open Approach */
"021W0KD" = "1" /* Bypass Thoracic Aorta to Carotid with Nonautologous Tissue Substitute, Open Approach */
"021W0KP" = "1" /* Bypass Thoracic Aorta to Pulmonary Trunk with Nonautologous Tissue Substitute, Open Approach */
"021W0KQ" = "1" /* Bypass Thoracic Aorta to Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021W0KR" = "1" /* Bypass Thoracic Aorta to Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021W0ZB" = "1" /* Bypass Thoracic Aorta to Subclavian, Open Approach */
"021W0ZD" = "1" /* Bypass Thoracic Aorta to Carotid, Open Approach */
"021W0ZP" = "1" /* Bypass Thoracic Aorta to Pulmonary Trunk, Open Approach */
"021W0ZQ" = "1" /* Bypass Thoracic Aorta to Right Pulmonary Artery, Open Approach */
"021W0ZR" = "1" /* Bypass Thoracic Aorta to Left Pulmonary Artery, Open Approach */
"021W48B" = "1" /* Bypass Thoracic Aorta, Descending to Subclavian with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021W48D" = "1" /* Bypass Thoracic Aorta, Descending to Carotid with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021W48P" = "1" /* Bypass Thoracic Aorta, Descending to Pulmonary Trunk with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021W48Q" = "1" /* Bypass Thoracic Aorta, Descending to Right Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021W48R" = "1" /* Bypass Thoracic Aorta, Descending to Left Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021W49B" = "1" /* Bypass Thoracic Aorta to Subclavian with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021W49D" = "1" /* Bypass Thoracic Aorta to Carotid with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021W49P" = "1" /* Bypass Thoracic Aorta to Pulmonary Trunk with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021W49Q" = "1" /* Bypass Thoracic Aorta to Right Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021W49R" = "1" /* Bypass Thoracic Aorta to Left Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021W4AB" = "1" /* Bypass Thoracic Aorta to Subclavian with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021W4AD" = "1" /* Bypass Thoracic Aorta to Carotid with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021W4AP" = "1" /* Bypass Thoracic Aorta to Pulmonary Trunk with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021W4AQ" = "1" /* Bypass Thoracic Aorta to Right Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021W4AR" = "1" /* Bypass Thoracic Aorta to Left Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021W4JB" = "1" /* Bypass Thoracic Aorta to Subclavian with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021W4JD" = "1" /* Bypass Thoracic Aorta to Carotid with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021W4JP" = "1" /* Bypass Thoracic Aorta to Pulmonary Trunk with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021W4JQ" = "1" /* Bypass Thoracic Aorta to Right Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021W4JR" = "1" /* Bypass Thoracic Aorta to Left Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021W4KB" = "1" /* Bypass Thoracic Aorta to Subclavian with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021W4KD" = "1" /* Bypass Thoracic Aorta to Carotid with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021W4KP" = "1" /* Bypass Thoracic Aorta to Pulmonary Trunk with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021W4KQ" = "1" /* Bypass Thoracic Aorta to Right Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021W4KR" = "1" /* Bypass Thoracic Aorta to Left Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021W4ZB" = "1" /* Bypass Thoracic Aorta to Subclavian, Percutaneous Endoscopic Approach */
"021W4ZD" = "1" /* Bypass Thoracic Aorta to Carotid, Percutaneous Endoscopic Approach */
"021W4ZP" = "1" /* Bypass Thoracic Aorta to Pulmonary Trunk, Percutaneous Endoscopic Approach */
"021W4ZQ" = "1" /* Bypass Thoracic Aorta to Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"021W4ZR" = "1" /* Bypass Thoracic Aorta to Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"021X08B" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian with Zooplastic Tissue, Open Approach */
"021X08D" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid with Zooplastic Tissue, Open Approach */
"021X08P" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk with Zooplastic Tissue, Open Approach */
"021X08Q" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021X08R" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021X09B" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian with Autologous Venous Tissue, Open Approach */
"021X09D" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid with Autologous Venous Tissue, Open Approach */
"021X09P" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk with Autologous Venous Tissue, Open Approach */
"021X09Q" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021X09R" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021X0AB" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian with Autologous Arterial Tissue, Open Approach */
"021X0AD" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid with Autologous Arterial Tissue, Open Approach */
"021X0AP" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk with Autologous Arterial Tissue, Open Approach */
"021X0AQ" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021X0AR" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021X0JB" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian with Synthetic Substitute, Open Approach */
"021X0JD" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid with Synthetic Substitute, Open Approach */
"021X0JP" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk with Synthetic Substitute, Open Approach */
"021X0JQ" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"021X0JR" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"021X0KB" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian with Nonautologous Tissue Substitute, Open Approach */
"021X0KD" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid with Nonautologous Tissue Substitute, Open Approach */
"021X0KP" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk with Nonautologous Tissue Substitute, Open Approach */
"021X0KQ" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021X0KR" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021X0ZB" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian, Open Approach */
"021X0ZD" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid, Open Approach */
"021X0ZP" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk, Open Approach */
"021X0ZQ" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery, Open Approach */
"021X0ZR" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery, Open Approach */
"021X48B" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021X48D" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021X48P" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021X48Q" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021X48R" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021X49B" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021X49D" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021X49P" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021X49Q" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021X49R" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021X4AB" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021X4AD" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021X4AP" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021X4AQ" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021X4AR" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021X4JB" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021X4JD" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021X4JP" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021X4JQ" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021X4JR" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021X4KB" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021X4KD" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021X4KP" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021X4KQ" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021X4KR" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021X4ZB" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian, Percutaneous Endoscopic Approach */
"021X4ZD" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid, Percutaneous Endoscopic Approach */
"021X4ZP" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk, Percutaneous Endoscopic Approach */
"021X4ZQ" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"021X4ZR" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"024F07J" = "1" /* Creation of Aortic Valve from Truncal Valve using Autologous Tissue Substitute, Open Approach */
"024F08J" = "1" /* Creation of Aortic Valve from Truncal Valve using Zooplastic Tissue, Open Approach */
"024F0JJ" = "1" /* Creation of Aortic Valve from Truncal Valve using Synthetic Substitute, Open Approach */
"024F0KJ" = "1" /* Creation of Aortic Valve from Truncal Valve using Nonautologous Tissue Substitute, Open Approach */
"024G072" = "1" /* Creation of Mitral Valve from Common Atrioventricular Valve using Autologous Tissue Substitute, Open Approach */
"024G082" = "1" /* Creation of Mitral Valve from Common Atrioventricular Valve using Zooplastic Tissue, Open Approach */
"024G0J2" = "1" /* Creation of Mitral Valve from Common Atrioventricular Valve using Synthetic Substitute, Open Approach */
"024G0K2" = "1" /* Creation of Mitral Valve from Common Atrioventricular Valve using Nonautologous Tissue Substitute, Open Approach */
"024J072" = "1" /* Creation of Tricuspid Valve from Common Atrioventricular Valve using Autologous Tissue Substitute, Open Approach */
"024J082" = "1" /* Creation of Tricuspid Valve from Common Atrioventricular Valve using Zooplastic Tissue, Open Approach */
"024J0J2" = "1" /* Creation of Tricuspid Valve from Common Atrioventricular Valve using Synthetic Substitute, Open Approach */
"024J0K2" = "1" /* Creation of Tricuspid Valve from Common Atrioventricular Valve using Nonautologous Tissue Substitute, Open Approach */
"02540ZZ" = "1" /* Destruction of Coronary Vein, Open Approach */
"02544ZZ" = "1" /* Destruction of Coronary Vein, Percutaneous Endoscopic Approach */
"02550ZZ" = "1" /* Destruction of Atrial Septum, Open Approach */
"02554ZZ" = "1" /* Destruction of Atrial Septum, Percutaneous Endoscopic Approach */
"02560ZZ" = "1" /* Destruction of Right Atrium, Open Approach */
"02564ZZ" = "1" /* Destruction of Right Atrium, Percutaneous Endoscopic Approach */
"02570ZK" = "1" /* Destruction of Left Atrial Appendage, Open Approach */
"02570ZZ" = "1" /* Destruction of Left Atrium, Open Approach */
"02574ZK" = "1" /* Destruction of Left Atrial Appendage, Percutaneous Endoscopic Approach */
"02574ZZ" = "1" /* Destruction of Left Atrium, Percutaneous Endoscopic Approach */
"02580ZZ" = "1" /* Destruction of Conduction Mechanism, Open Approach */
"02584ZZ" = "1" /* Destruction of Conduction Mechanism, Percutaneous Endoscopic Approach */
"02590ZZ" = "1" /* Destruction of Chordae Tendineae, Open Approach */
"02594ZZ" = "1" /* Destruction of Chordae Tendineae, Percutaneous Endoscopic Approach */
"025D0ZZ" = "1" /* Destruction of Papillary Muscle, Open Approach */
"025D4ZZ" = "1" /* Destruction of Papillary Muscle, Percutaneous Endoscopic Approach */
"025F0ZZ" = "1" /* Destruction of Aortic Valve, Open Approach */
"025F4ZZ" = "1" /* Destruction of Aortic Valve, Percutaneous Endoscopic Approach */
"025G0ZZ" = "1" /* Destruction of Mitral Valve, Open Approach */
"025G4ZZ" = "1" /* Destruction of Mitral Valve, Percutaneous Endoscopic Approach */
"025H0ZZ" = "1" /* Destruction of Pulmonary Valve, Open Approach */
"025H4ZZ" = "1" /* Destruction of Pulmonary Valve, Percutaneous Endoscopic Approach */
"025J0ZZ" = "1" /* Destruction of Tricuspid Valve, Open Approach */
"025J4ZZ" = "1" /* Destruction of Tricuspid Valve, Percutaneous Endoscopic Approach */
"025K0ZZ" = "1" /* Destruction of Right Ventricle, Open Approach */
"025K4ZZ" = "1" /* Destruction of Right Ventricle, Percutaneous Endoscopic Approach */
"025L0ZZ" = "1" /* Destruction of Left Ventricle, Open Approach */
"025L4ZZ" = "1" /* Destruction of Left Ventricle, Percutaneous Endoscopic Approach */
"025M0ZZ" = "1" /* Destruction of Ventricular Septum, Open Approach */
"025M4ZZ" = "1" /* Destruction of Ventricular Septum, Percutaneous Endoscopic Approach */
"025N0ZZ" = "1" /* Destruction of Pericardium, Open Approach */
"025N3ZZ" = "1" /* Destruction of Pericardium, Percutaneous Approach */
"025N4ZZ" = "1" /* Destruction of Pericardium, Percutaneous Endoscopic Approach */
"025P0ZZ" = "1" /* Destruction of Pulmonary Trunk, Open Approach */
"025P4ZZ" = "1" /* Destruction of Pulmonary Trunk, Percutaneous Endoscopic Approach */
"025Q0ZZ" = "1" /* Destruction of Right Pulmonary Artery, Open Approach */
"025Q4ZZ" = "1" /* Destruction of Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"025R0ZZ" = "1" /* Destruction of Left Pulmonary Artery, Open Approach */
"025R4ZZ" = "1" /* Destruction of Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"025S0ZZ" = "1" /* Destruction of Right Pulmonary Vein, Open Approach */
"025S4ZZ" = "1" /* Destruction of Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"025T0ZZ" = "1" /* Destruction of Left Pulmonary Vein, Open Approach */
"025T4ZZ" = "1" /* Destruction of Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"025V0ZZ" = "1" /* Destruction of Superior Vena Cava, Open Approach */
"025V4ZZ" = "1" /* Destruction of Superior Vena Cava, Percutaneous Endoscopic Approach */
"025W0ZZ" = "1" /* Destruction of Thoracic Aorta, Open Approach */
"025W4ZZ" = "1" /* Destruction of Thoracic Aorta, Percutaneous Endoscopic Approach */
"025X0ZZ" = "1" /* Destruction of Thoracic Aorta, Ascending/Arch, Open Approach */
"025X4ZZ" = "1" /* Destruction of Thoracic Aorta, Ascending/Arch, Percutaneous Endoscopic Approach */
"0270046" = "1" /* Dilation of Coronary Artery, One Site, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"027004Z" = "1" /* Dilation of Coronary Artery, One Site with Drug-eluting Intraluminal Device, Open Approach */
"0270056" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"027005Z" = "1" /* Dilation of Coronary Artery, One Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0270066" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"027006Z" = "1" /* Dilation of Coronary Artery, One Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0270076" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"027007Z" = "1" /* Dilation of Coronary Artery, One Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"02700D6" = "1" /* Dilation of Coronary Artery, One Site, Bifurcation, with Intraluminal Device, Open Approach */
"02700DZ" = "1" /* Dilation of Coronary Artery, One Site with Intraluminal Device, Open Approach */
"02700E6" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"02700EZ" = "1" /* Dilation of Coronary Artery, One Artery with Two Intraluminal Devices, Open Approach */
"02700F6" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"02700FZ" = "1" /* Dilation of Coronary Artery, One Artery with Three Intraluminal Devices, Open Approach */
"02700G6" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"02700GZ" = "1" /* Dilation of Coronary Artery, One Artery with Four or More Intraluminal Devices, Open Approach */
"02700T6" = "1" /* Dilation of Coronary Artery, One Site, Bifurcation, with Radioactive Intraluminal Device, Open Approach */
"02700TZ" = "1" /* Dilation of Coronary Artery, One Site with Radioactive Intraluminal Device, Open Approach */
"02700Z6" = "1" /* Dilation of Coronary Artery, One Site, Bifurcation, Open Approach */
"02700ZZ" = "1" /* Dilation of Coronary Artery, One Site, Open Approach */
"0271046" = "1" /* Dilation of Coronary Artery, Two Sites, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"027104Z" = "1" /* Dilation of Coronary Artery, Two Sites with Drug-eluting Intraluminal Device, Open Approach */
"0271056" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"027105Z" = "1" /* Dilation of Coronary Artery, Two Arteries with Two Drug-eluting Intraluminal Devices, Open Approach */
"0271066" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"027106Z" = "1" /* Dilation of Coronary Artery, Two Arteries with Three Drug-eluting Intraluminal Devices, Open Approach */
"0271076" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"027107Z" = "1" /* Dilation of Coronary Artery, Two Arteries with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"02710D6" = "1" /* Dilation of Coronary Artery, Two Sites, Bifurcation, with Intraluminal Device, Open Approach */
"02710DZ" = "1" /* Dilation of Coronary Artery, Two Sites with Intraluminal Device, Open Approach */
"02710E6" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Two Intraluminal Devices, Open Approach */
"02710EZ" = "1" /* Dilation of Coronary Artery, Two Arteries with Two Intraluminal Devices, Open Approach */
"02710F6" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Three Intraluminal Devices, Open Approach */
"02710FZ" = "1" /* Dilation of Coronary Artery, Two Arteries with Three Intraluminal Devices, Open Approach */
"02710G6" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"02710GZ" = "1" /* Dilation of Coronary Artery, Two Arteries with Four or More Intraluminal Devices, Open Approach */
"02710T6" = "1" /* Dilation of Coronary Artery, Two Sites, Bifurcation, with Radioactive Intraluminal Device, Open Approach */
"02710TZ" = "1" /* Dilation of Coronary Artery, Two Sites with Radioactive Intraluminal Device, Open Approach */
"02710Z6" = "1" /* Dilation of Coronary Artery, Two Sites, Bifurcation, Open Approach */
"02710ZZ" = "1" /* Dilation of Coronary Artery, Two Sites, Open Approach */
"0272046" = "1" /* Dilation of Coronary Artery, Three Sites, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"027204Z" = "1" /* Dilation of Coronary Artery, Three Sites with Drug-eluting Intraluminal Device, Open Approach */
"0272056" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"027205Z" = "1" /* Dilation of Coronary Artery, Three Arteries with Two Drug-eluting Intraluminal Devices, Open Approach */
"0272066" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"027206Z" = "1" /* Dilation of Coronary Artery, Three Arteries with Three Drug-eluting Intraluminal Devices, Open Approach */
"0272076" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"027207Z" = "1" /* Dilation of Coronary Artery, Three Arteries with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"02720D6" = "1" /* Dilation of Coronary Artery, Three Sites, Bifurcation, with Intraluminal Device, Open Approach */
"02720DZ" = "1" /* Dilation of Coronary Artery, Three Sites with Intraluminal Device, Open Approach */
"02720E6" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Two Intraluminal Devices, Open Approach */
"02720EZ" = "1" /* Dilation of Coronary Artery, Three Arteries with Two Intraluminal Devices, Open Approach */
"02720F6" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Three Intraluminal Devices, Open Approach */
"02720FZ" = "1" /* Dilation of Coronary Artery, Three Arteries with Three Intraluminal Devices, Open Approach */
"02720G6" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"02720GZ" = "1" /* Dilation of Coronary Artery, Three Arteries with Four or More Intraluminal Devices, Open Approach */
"02720T6" = "1" /* Dilation of Coronary Artery, Three Sites, Bifurcation, with Radioactive Intraluminal Device, Open Approach */
"02720TZ" = "1" /* Dilation of Coronary Artery, Three Sites with Radioactive Intraluminal Device, Open Approach */
"02720Z6" = "1" /* Dilation of Coronary Artery, Three Sites, Bifurcation, Open Approach */
"02720ZZ" = "1" /* Dilation of Coronary Artery, Three Sites, Open Approach */
"0273046" = "1" /* Dilation of Coronary Artery, Four or More Sites, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"027304Z" = "1" /* Dilation of Coronary Artery, Four or More Sites with Drug-eluting Intraluminal Device, Open Approach */
"0273056" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"027305Z" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Two Drug-eluting Intraluminal Devices, Open Approach */
"0273066" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"027306Z" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Three Drug-eluting Intraluminal Devices, Open Approach */
"0273076" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"027307Z" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"02730D6" = "1" /* Dilation of Coronary Artery, Four or More Sites, Bifurcation, with Intraluminal Device, Open Approach */
"02730DZ" = "1" /* Dilation of Coronary Artery, Four or More Sites with Intraluminal Device, Open Approach */
"02730E6" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Two Intraluminal Devices, Open Approach */
"02730EZ" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Two Intraluminal Devices, Open Approach */
"02730F6" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Three Intraluminal Devices, Open Approach */
"02730FZ" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Three Intraluminal Devices, Open Approach */
"02730G6" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"02730GZ" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Four or More Intraluminal Devices, Open Approach */
"02730T6" = "1" /* Dilation of Coronary Artery, Four or More Sites, Bifurcation, with Radioactive Intraluminal Device, Open Approach */
"02730TZ" = "1" /* Dilation of Coronary Artery, Four or More Sites with Radioactive Intraluminal Device, Open Approach */
"02730Z6" = "1" /* Dilation of Coronary Artery, Four or More Sites, Bifurcation, Open Approach */
"02730ZZ" = "1" /* Dilation of Coronary Artery, Four or More Sites, Open Approach */
"027F04Z" = "1" /* Dilation of Aortic Valve with Drug-eluting Intraluminal Device, Open Approach */
"027F0DZ" = "1" /* Dilation of Aortic Valve with Intraluminal Device, Open Approach */
"027F0ZZ" = "1" /* Dilation of Aortic Valve, Open Approach */
"027G04Z" = "1" /* Dilation of Mitral Valve with Drug-eluting Intraluminal Device, Open Approach */
"027G0DZ" = "1" /* Dilation of Mitral Valve with Intraluminal Device, Open Approach */
"027G0ZZ" = "1" /* Dilation of Mitral Valve, Open Approach */
"027H04Z" = "1" /* Dilation of Pulmonary Valve with Drug-eluting Intraluminal Device, Open Approach */
"027H0DZ" = "1" /* Dilation of Pulmonary Valve with Intraluminal Device, Open Approach */
"027H0ZZ" = "1" /* Dilation of Pulmonary Valve, Open Approach */
"027J04Z" = "1" /* Dilation of Tricuspid Valve with Drug-eluting Intraluminal Device, Open Approach */
"027J0DZ" = "1" /* Dilation of Tricuspid Valve with Intraluminal Device, Open Approach */
"027J0ZZ" = "1" /* Dilation of Tricuspid Valve, Open Approach */
"027K04Z" = "1" /* Dilation of Right Ventricle with Drug-eluting Intraluminal Device, Open Approach */
"027K0DZ" = "1" /* Dilation of Right Ventricle with Intraluminal Device, Open Approach */
"027K0ZZ" = "1" /* Dilation of Right Ventricle, Open Approach */
"027K44Z" = "1" /* Dilation of Right Ventricle with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027K4DZ" = "1" /* Dilation of Right Ventricle with Intraluminal Device, Percutaneous Endoscopic Approach */
"027K4ZZ" = "1" /* Dilation of Right Ventricle, Percutaneous Endoscopic Approach */
"027R04T" = "1" /* Dilation of Ductus Arteriosus with Drug-eluting Intraluminal Device, Open Approach */
"027R0DT" = "1" /* Dilation of Ductus Arteriosus with Intraluminal Device, Open Approach */
"027R0ZT" = "1" /* Dilation of Ductus Arteriosus, Open Approach */
"027R44T" = "1" /* Dilation of Ductus Arteriosus with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027R4DT" = "1" /* Dilation of Ductus Arteriosus with Intraluminal Device, Percutaneous Endoscopic Approach */
"027R4ZT" = "1" /* Dilation of Ductus Arteriosus, Percutaneous Endoscopic Approach */
"02890ZZ" = "1" /* Division of Chordae Tendineae, Open Approach */
"02894ZZ" = "1" /* Division of Chordae Tendineae, Percutaneous Endoscopic Approach */
"028D0ZZ" = "1" /* Division of Papillary Muscle, Open Approach */
"028D4ZZ" = "1" /* Division of Papillary Muscle, Percutaneous Endoscopic Approach */
"02B40ZZ" = "1" /* Excision of Coronary Vein, Open Approach */
"02B44ZZ" = "1" /* Excision of Coronary Vein, Percutaneous Endoscopic Approach */
"02B50ZZ" = "1" /* Excision of Atrial Septum, Open Approach */
"02B54ZZ" = "1" /* Excision of Atrial Septum, Percutaneous Endoscopic Approach */
"02B60ZZ" = "1" /* Excision of Right Atrium, Open Approach */
"02B64ZZ" = "1" /* Excision of Right Atrium, Percutaneous Endoscopic Approach */
"02B70ZK" = "1" /* Excision of Left Atrial Appendage, Open Approach */
"02B70ZZ" = "1" /* Excision of Left Atrium, Open Approach */
"02B74ZK" = "1" /* Excision of Left Atrial Appendage, Percutaneous Endoscopic Approach */
"02B74ZZ" = "1" /* Excision of Left Atrium, Percutaneous Endoscopic Approach */
"02B80ZZ" = "1" /* Excision of Conduction Mechanism, Open Approach */
"02B84ZZ" = "1" /* Excision of Conduction Mechanism, Percutaneous Endoscopic Approach */
"02B90ZZ" = "1" /* Excision of Chordae Tendineae, Open Approach */
"02B94ZZ" = "1" /* Excision of Chordae Tendineae, Percutaneous Endoscopic Approach */
"02BD0ZZ" = "1" /* Excision of Papillary Muscle, Open Approach */
"02BD4ZZ" = "1" /* Excision of Papillary Muscle, Percutaneous Endoscopic Approach */
"02BF0ZZ" = "1" /* Excision of Aortic Valve, Open Approach */
"02BF4ZZ" = "1" /* Excision of Aortic Valve, Percutaneous Endoscopic Approach */
"02BG0ZZ" = "1" /* Excision of Mitral Valve, Open Approach */
"02BG4ZZ" = "1" /* Excision of Mitral Valve, Percutaneous Endoscopic Approach */
"02BH0ZZ" = "1" /* Excision of Pulmonary Valve, Open Approach */
"02BH4ZZ" = "1" /* Excision of Pulmonary Valve, Percutaneous Endoscopic Approach */
"02BJ0ZZ" = "1" /* Excision of Tricuspid Valve, Open Approach */
"02BJ4ZZ" = "1" /* Excision of Tricuspid Valve, Percutaneous Endoscopic Approach */
"02BK0ZZ" = "1" /* Excision of Right Ventricle, Open Approach */
"02BK4ZZ" = "1" /* Excision of Right Ventricle, Percutaneous Endoscopic Approach */
"02BL0ZZ" = "1" /* Excision of Left Ventricle, Open Approach */
"02BL4ZZ" = "1" /* Excision of Left Ventricle, Percutaneous Endoscopic Approach */
"02BM0ZZ" = "1" /* Excision of Ventricular Septum, Open Approach */
"02BM4ZZ" = "1" /* Excision of Ventricular Septum, Percutaneous Endoscopic Approach */
"02BN0ZZ" = "1" /* Excision of Pericardium, Open Approach */
"02BN3ZZ" = "1" /* Excision of Pericardium, Percutaneous Approach */
"02BN4ZZ" = "1" /* Excision of Pericardium, Percutaneous Endoscopic Approach */
"02BP0ZZ" = "1" /* Excision of Pulmonary Trunk, Open Approach */
"02BP4ZZ" = "1" /* Excision of Pulmonary Trunk, Percutaneous Endoscopic Approach */
"02BQ0ZZ" = "1" /* Excision of Right Pulmonary Artery, Open Approach */
"02BQ4ZZ" = "1" /* Excision of Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"02BR0ZZ" = "1" /* Excision of Left Pulmonary Artery, Open Approach */
"02BR4ZZ" = "1" /* Excision of Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"02BS0ZZ" = "1" /* Excision of Right Pulmonary Vein, Open Approach */
"02BS4ZZ" = "1" /* Excision of Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"02BT0ZZ" = "1" /* Excision of Left Pulmonary Vein, Open Approach */
"02BT4ZZ" = "1" /* Excision of Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"02BV0ZZ" = "1" /* Excision of Superior Vena Cava, Open Approach */
"02BV4ZZ" = "1" /* Excision of Superior Vena Cava, Percutaneous Endoscopic Approach */
"02C00Z6" = "1" /* Extirpation of Matter from Coronary Artery, One Artery, Bifurcation, Open Approach */
"02C00ZZ" = "1" /* Extirpation of Matter from Coronary Artery, One Site, Open Approach */
"02C10Z6" = "1" /* Extirpation of Matter from Coronary Artery, Two Arteries, Bifurcation, Open Approach */
"02C10ZZ" = "1" /* Extirpation of Matter from Coronary Artery, Two Sites, Open Approach */
"02C20Z6" = "1" /* Extirpation of Matter from Coronary Artery, Three Arteries, Bifurcation, Open Approach */
"02C20ZZ" = "1" /* Extirpation of Matter from Coronary Artery, Three Sites, Open Approach */
"02C30Z6" = "1" /* Extirpation of Matter from Coronary Artery, Four or More Arteries, Bifurcation, Open Approach */
"02C30ZZ" = "1" /* Extirpation of Matter from Coronary Artery, Four or More Sites, Open Approach */
"02C40ZZ" = "1" /* Extirpation of Matter from Coronary Vein, Open Approach */
"02C44ZZ" = "1" /* Extirpation of Matter from Coronary Vein, Percutaneous Endoscopic Approach */
"02C50ZZ" = "1" /* Extirpation of Matter from Atrial Septum, Open Approach */
"02C54ZZ" = "1" /* Extirpation of Matter from Atrial Septum, Percutaneous Endoscopic Approach */
"02C60ZZ" = "1" /* Extirpation of Matter from Right Atrium, Open Approach */
"02C64ZZ" = "1" /* Extirpation of Matter from Right Atrium, Percutaneous Endoscopic Approach */
"02C70ZZ" = "1" /* Extirpation of Matter from Left Atrium, Open Approach */
"02C74ZZ" = "1" /* Extirpation of Matter from Left Atrium, Percutaneous Endoscopic Approach */
"02C80ZZ" = "1" /* Extirpation of Matter from Conduction Mechanism, Open Approach */
"02C84ZZ" = "1" /* Extirpation of Matter from Conduction Mechanism, Percutaneous Endoscopic Approach */
"02C90ZZ" = "1" /* Extirpation of Matter from Chordae Tendineae, Open Approach */
"02C94ZZ" = "1" /* Extirpation of Matter from Chordae Tendineae, Percutaneous Endoscopic Approach */
"02CD0ZZ" = "1" /* Extirpation of Matter from Papillary Muscle, Open Approach */
"02CD4ZZ" = "1" /* Extirpation of Matter from Papillary Muscle, Percutaneous Endoscopic Approach */
"02CF0ZZ" = "1" /* Extirpation of Matter from Aortic Valve, Open Approach */
"02CG0ZZ" = "1" /* Extirpation of Matter from Mitral Valve, Open Approach */
"02CH0ZZ" = "1" /* Extirpation of Matter from Pulmonary Valve, Open Approach */
"02CJ0ZZ" = "1" /* Extirpation of Matter from Tricuspid Valve, Open Approach */
"02CK0ZZ" = "1" /* Extirpation of Matter from Right Ventricle, Open Approach */
"02CK4ZZ" = "1" /* Extirpation of Matter from Right Ventricle, Percutaneous Endoscopic Approach */
"02CL0ZZ" = "1" /* Extirpation of Matter from Left Ventricle, Open Approach */
"02CL4ZZ" = "1" /* Extirpation of Matter from Left Ventricle, Percutaneous Endoscopic Approach */
"02CM0ZZ" = "1" /* Extirpation of Matter from Ventricular Septum, Open Approach */
"02CM4ZZ" = "1" /* Extirpation of Matter from Ventricular Septum, Percutaneous Endoscopic Approach */
"02CN0ZZ" = "1" /* Extirpation of Matter from Pericardium, Open Approach */
"02CN3ZZ" = "1" /* Extirpation of Matter from Pericardium, Percutaneous Approach */
"02CN4ZZ" = "1" /* Extirpation of Matter from Pericardium, Percutaneous Endoscopic Approach */
"02CP0ZZ" = "1" /* Extirpation of Matter from Pulmonary Trunk, Open Approach */
"02CP4ZZ" = "1" /* Extirpation of Matter from Pulmonary Trunk, Percutaneous Endoscopic Approach */
"02CQ0ZZ" = "1" /* Extirpation of Matter from Right Pulmonary Artery, Open Approach */
"02CQ4ZZ" = "1" /* Extirpation of Matter from Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"02CR0ZZ" = "1" /* Extirpation of Matter from Left Pulmonary Artery, Open Approach */
"02CR4ZZ" = "1" /* Extirpation of Matter from Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"02CS0ZZ" = "1" /* Extirpation of Matter from Right Pulmonary Vein, Open Approach */
"02CS4ZZ" = "1" /* Extirpation of Matter from Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"02CT0ZZ" = "1" /* Extirpation of Matter from Left Pulmonary Vein, Open Approach */
"02CT4ZZ" = "1" /* Extirpation of Matter from Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"02CV0ZZ" = "1" /* Extirpation of Matter from Superior Vena Cava, Open Approach */
"02CV4ZZ" = "1" /* Extirpation of Matter from Superior Vena Cava, Percutaneous Endoscopic Approach */
"02CW0ZZ" = "1" /* Extirpation of Matter from Thoracic Aorta, Open Approach */
"02CW4ZZ" = "1" /* Extirpation of Matter from Thoracic Aorta, Percutaneous Endoscopic Approach */
"02CX0ZZ" = "1" /* Extirpation of Matter from Thoracic Aorta, Ascending/Arch, Open Approach */
"02CX4ZZ" = "1" /* Extirpation of Matter from Thoracic Aorta, Ascending/Arch, Percutaneous Endoscopic Approach */
"02FN0ZZ" = "1" /* Fragmentation in Pericardium, Open Approach */
"02FN3ZZ" = "1" /* Fragmentation in Pericardium, Percutaneous Approach */
"02FN4ZZ" = "1" /* Fragmentation in Pericardium, Percutaneous Endoscopic Approach */
"02H402Z" = "1" /* Insertion of Monitoring Device into Coronary Vein, Open Approach */
"02H403Z" = "1" /* Insertion of Infusion Device into Coronary Vein, Open Approach */
"02H40DZ" = "1" /* Insertion of Intraluminal Device into Coronary Vein, Open Approach */
"02H40NZ" = "1" /* Insertion of Intracardiac Pacemaker into Coronary Vein, Open Approach */
"02H442Z" = "1" /* Insertion of Monitoring Device into Coronary Vein, Percutaneous Endoscopic Approach */
"02H443Z" = "1" /* Insertion of Infusion Device into Coronary Vein, Percutaneous Endoscopic Approach */
"02H44DZ" = "1" /* Insertion of Intraluminal Device into Coronary Vein, Percutaneous Endoscopic Approach */
"02H44NZ" = "1" /* Insertion of Intracardiac Pacemaker into Coronary Vein, Percutaneous Endoscopic Approach */
"02H602Z" = "1" /* Insertion of Monitoring Device into Right Atrium, Open Approach */
"02H603Z" = "1" /* Insertion of Infusion Device into Right Atrium, Open Approach */
"02H60DZ" = "1" /* Insertion of Intraluminal Device into Right Atrium, Open Approach */
"02H60NZ" = "1" /* Insertion of Intracardiac Pacemaker into Right Atrium, Open Approach */
"02H642Z" = "1" /* Insertion of Monitoring Device into Right Atrium, Percutaneous Endoscopic Approach */
"02H643Z" = "1" /* Insertion of Infusion Device into Right Atrium, Percutaneous Endoscopic Approach */
"02H64DZ" = "1" /* Insertion of Intraluminal Device into Right Atrium, Percutaneous Endoscopic Approach */
"02H64NZ" = "1" /* Insertion of Intracardiac Pacemaker into Right Atrium, Percutaneous Endoscopic Approach */
"02H702Z" = "1" /* Insertion of Monitoring Device into Left Atrium, Open Approach */
"02H703Z" = "1" /* Insertion of Infusion Device into Left Atrium, Open Approach */
"02H70DZ" = "1" /* Insertion of Intraluminal Device into Left Atrium, Open Approach */
"02H70NZ" = "1" /* Insertion of Intracardiac Pacemaker into Left Atrium, Open Approach */
"02H742Z" = "1" /* Insertion of Monitoring Device into Left Atrium, Percutaneous Endoscopic Approach */
"02H743Z" = "1" /* Insertion of Infusion Device into Left Atrium, Percutaneous Endoscopic Approach */
"02H74DZ" = "1" /* Insertion of Intraluminal Device into Left Atrium, Percutaneous Endoscopic Approach */
"02H74NZ" = "1" /* Insertion of Intracardiac Pacemaker into Left Atrium, Percutaneous Endoscopic Approach */
"02HA0QZ" = "1" /* Insertion of Implantable Heart Assist System into Heart, Open Approach */
"02HA0RS" = "1" /* Insertion of Biventricular External Heart Assist System into Heart, Open Approach */
"02HA0RZ" = "1" /* Insertion of External Heart Assist System into Heart, Open Approach */
"02HA4QZ" = "1" /* Insertion of Implantable Heart Assist System into Heart, Percutaneous Endoscopic Approach */
"02HA4RS" = "1" /* Insertion of Biventricular External Heart Assist System into Heart, Percutaneous Endoscopic Approach */
"02HA4RZ" = "1" /* Insertion of External Heart Assist System into Heart, Percutaneous Endoscopic Approach */
"02HK03Z" = "1" /* Insertion of Infusion Device into Right Ventricle, Open Approach */
"02HK0DZ" = "1" /* Insertion of Intraluminal Device into Right Ventricle, Open Approach */
"02HK0NZ" = "1" /* Insertion of Intracardiac Pacemaker into Right Ventricle, Open Approach */
"02HK43Z" = "1" /* Insertion of Infusion Device into Right Ventricle, Percutaneous Endoscopic Approach */
"02HK4DZ" = "1" /* Insertion of Intraluminal Device into Right Ventricle, Percutaneous Endoscopic Approach */
"02HK4NZ" = "1" /* Insertion of Intracardiac Pacemaker into Right Ventricle, Percutaneous Endoscopic Approach */
"02HL02Z" = "1" /* Insertion of Monitoring Device into Left Ventricle, Open Approach */
"02HL03Z" = "1" /* Insertion of Infusion Device into Left Ventricle, Open Approach */
"02HL0DZ" = "1" /* Insertion of Intraluminal Device into Left Ventricle, Open Approach */
"02HL0NZ" = "1" /* Insertion of Intracardiac Pacemaker into Left Ventricle, Open Approach */
"02HL42Z" = "1" /* Insertion of Monitoring Device into Left Ventricle, Percutaneous Endoscopic Approach */
"02HL43Z" = "1" /* Insertion of Infusion Device into Left Ventricle, Percutaneous Endoscopic Approach */
"02HL4DZ" = "1" /* Insertion of Intraluminal Device into Left Ventricle, Percutaneous Endoscopic Approach */
"02HL4NZ" = "1" /* Insertion of Intracardiac Pacemaker into Left Ventricle, Percutaneous Endoscopic Approach */
"02HN00Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Pericardium, Open Approach */
"02HN02Z" = "1" /* Insertion of Monitoring Device into Pericardium, Open Approach */
"02HN0MZ" = "1" /* Insertion of Cardiac Lead into Pericardium, Open Approach */
"02HN30Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Pericardium, Percutaneous Approach */
"02HN32Z" = "1" /* Insertion of Monitoring Device into Pericardium, Percutaneous Approach */
"02HN3MZ" = "1" /* Insertion of Cardiac Lead into Pericardium, Percutaneous Approach */
"02HN40Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Pericardium, Percutaneous Endoscopic Approach */
"02HN42Z" = "1" /* Insertion of Monitoring Device into Pericardium, Percutaneous Endoscopic Approach */
"02HN4MZ" = "1" /* Insertion of Cardiac Lead into Pericardium, Percutaneous Endoscopic Approach */
"02HP0DZ" = "1" /* Insertion of Intraluminal Device into Pulmonary Trunk, Open Approach */
"02HP4DZ" = "1" /* Insertion of Intraluminal Device into Pulmonary Trunk, Percutaneous Endoscopic Approach */
"02HQ0DZ" = "1" /* Insertion of Intraluminal Device into Right Pulmonary Artery, Open Approach */
"02HQ4DZ" = "1" /* Insertion of Intraluminal Device into Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"02HR0DZ" = "1" /* Insertion of Intraluminal Device into Left Pulmonary Artery, Open Approach */
"02HR4DZ" = "1" /* Insertion of Intraluminal Device into Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"02HS02Z" = "1" /* Insertion of Monitoring Device into Right Pulmonary Vein, Open Approach */
"02HS0DZ" = "1" /* Insertion of Intraluminal Device into Right Pulmonary Vein, Open Approach */
"02HS42Z" = "1" /* Insertion of Monitoring Device into Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"02HS4DZ" = "1" /* Insertion of Intraluminal Device into Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"02HT02Z" = "1" /* Insertion of Monitoring Device into Left Pulmonary Vein, Open Approach */
"02HT0DZ" = "1" /* Insertion of Intraluminal Device into Left Pulmonary Vein, Open Approach */
"02HT42Z" = "1" /* Insertion of Monitoring Device into Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"02HT4DZ" = "1" /* Insertion of Intraluminal Device into Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"02HW02Z" = "1" /* Insertion of Monitoring Device into Thoracic Aorta, Open Approach */
"02HW0DZ" = "1" /* Insertion of Intraluminal Device into Thoracic Aorta, Open Approach */
"02HW42Z" = "1" /* Insertion of Monitoring Device into Thoracic Aorta, Percutaneous Endoscopic Approach */
"02HW4DZ" = "1" /* Insertion of Intraluminal Device into Thoracic Aorta, Percutaneous Endoscopic Approach */
"02HX02Z" = "1" /* Insertion of Monitoring Device into Thoracic Aorta, Ascending/Arch, Open Approach */
"02HX0DZ" = "1" /* Insertion of Intraluminal Device into Thoracic Aorta, Ascending/Arch, Open Approach */
"02HX42Z" = "1" /* Insertion of Monitoring Device into Thoracic Aorta, Ascending/Arch, Percutaneous Endoscopic Approach */
"02HX4DZ" = "1" /* Insertion of Intraluminal Device into Thoracic Aorta, Ascending/Arch, Percutaneous Endoscopic Approach */
"02L70CK" = "1" /* Occlusion of Left Atrial Appendage with Extraluminal Device, Open Approach */
"02L70ZK" = "1" /* Occlusion of Left Atrial Appendage, Open Approach */
"02L73CK" = "1" /* Occlusion of Left Atrial Appendage with Extraluminal Device, Percutaneous Approach */
"02L74CK" = "1" /* Occlusion of Left Atrial Appendage with Extraluminal Device, Percutaneous Endoscopic Approach */
"02L74ZK" = "1" /* Occlusion of Left Atrial Appendage, Percutaneous Endoscopic Approach */
"02LR0CT" = "1" /* Occlusion of Ductus Arteriosus with Extraluminal Device, Open Approach */
"02LR0ZT" = "1" /* Occlusion of Ductus Arteriosus, Open Approach */
"02LR3CT" = "1" /* Occlusion of Ductus Arteriosus with Extraluminal Device, Percutaneous Approach */
"02LR4CT" = "1" /* Occlusion of Ductus Arteriosus with Extraluminal Device, Percutaneous Endoscopic Approach */
"02LR4ZT" = "1" /* Occlusion of Ductus Arteriosus, Percutaneous Endoscopic Approach */
"02LS0CZ" = "1" /* Occlusion of Right Pulmonary Vein with Extraluminal Device, Open Approach */
"02LS0ZZ" = "1" /* Occlusion of Right Pulmonary Vein, Open Approach */
"02LS3CZ" = "1" /* Occlusion of Right Pulmonary Vein with Extraluminal Device, Percutaneous Approach */
"02LS4CZ" = "1" /* Occlusion of Right Pulmonary Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"02LS4ZZ" = "1" /* Occlusion of Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"02LT0CZ" = "1" /* Occlusion of Left Pulmonary Vein with Extraluminal Device, Open Approach */
"02LT0ZZ" = "1" /* Occlusion of Left Pulmonary Vein, Open Approach */
"02LT3CZ" = "1" /* Occlusion of Left Pulmonary Vein with Extraluminal Device, Percutaneous Approach */
"02LT4CZ" = "1" /* Occlusion of Left Pulmonary Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"02LT4ZZ" = "1" /* Occlusion of Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"02N40ZZ" = "1" /* Release Coronary Vein, Open Approach */
"02N44ZZ" = "1" /* Release Coronary Vein, Percutaneous Endoscopic Approach */
"02N50ZZ" = "1" /* Release Atrial Septum, Open Approach */
"02N54ZZ" = "1" /* Release Atrial Septum, Percutaneous Endoscopic Approach */
"02N60ZZ" = "1" /* Release Right Atrium, Open Approach */
"02N64ZZ" = "1" /* Release Right Atrium, Percutaneous Endoscopic Approach */
"02N70ZZ" = "1" /* Release Left Atrium, Open Approach */
"02N74ZZ" = "1" /* Release Left Atrium, Percutaneous Endoscopic Approach */
"02N80ZZ" = "1" /* Release Conduction Mechanism, Open Approach */
"02N84ZZ" = "1" /* Release Conduction Mechanism, Percutaneous Endoscopic Approach */
"02N90ZZ" = "1" /* Release Chordae Tendineae, Open Approach */
"02N94ZZ" = "1" /* Release Chordae Tendineae, Percutaneous Endoscopic Approach */
"02ND0ZZ" = "1" /* Release Papillary Muscle, Open Approach */
"02ND4ZZ" = "1" /* Release Papillary Muscle, Percutaneous Endoscopic Approach */
"02NF0ZZ" = "1" /* Release Aortic Valve, Open Approach */
"02NG0ZZ" = "1" /* Release Mitral Valve, Open Approach */
"02NH0ZZ" = "1" /* Release Pulmonary Valve, Open Approach */
"02NJ0ZZ" = "1" /* Release Tricuspid Valve, Open Approach */
"02NK0ZZ" = "1" /* Release Right Ventricle, Open Approach */
"02NK4ZZ" = "1" /* Release Right Ventricle, Percutaneous Endoscopic Approach */
"02NL0ZZ" = "1" /* Release Left Ventricle, Open Approach */
"02NL4ZZ" = "1" /* Release Left Ventricle, Percutaneous Endoscopic Approach */
"02NM0ZZ" = "1" /* Release Ventricular Septum, Open Approach */
"02NM4ZZ" = "1" /* Release Ventricular Septum, Percutaneous Endoscopic Approach */
"02NN0ZZ" = "1" /* Release Pericardium, Open Approach */
"02NN3ZZ" = "1" /* Release Pericardium, Percutaneous Approach */
"02NN4ZZ" = "1" /* Release Pericardium, Percutaneous Endoscopic Approach */
"02PA02Z" = "1" /* Removal of Monitoring Device from Heart, Open Approach */
"02PA03Z" = "1" /* Removal of Infusion Device from Heart, Open Approach */
"02PA07Z" = "1" /* Removal of Autologous Tissue Substitute from Heart, Open Approach */
"02PA08Z" = "1" /* Removal of Zooplastic Tissue from Heart, Open Approach */
"02PA0CZ" = "1" /* Removal of Extraluminal Device from Heart, Open Approach */
"02PA0DZ" = "1" /* Removal of Intraluminal Device from Heart, Open Approach */
"02PA0JZ" = "1" /* Removal of Synthetic Substitute from Heart, Open Approach */
"02PA0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Heart, Open Approach */
"02PA0NZ" = "1" /* Removal of Intracardiac Pacemaker from Heart, Open Approach */
"02PA0QZ" = "1" /* Removal of Implantable Heart Assist System from Heart, Open Approach */
"02PA0RZ" = "1" /* Removal of External Heart Assist System from Heart, Open Approach */
"02PA3CZ" = "1" /* Removal of Extraluminal Device from Heart, Percutaneous Approach */
"02PA3QZ" = "1" /* Removal of Implantable Heart Assist System from Heart, Percutaneous Approach */
"02PA3RZ" = "1" /* Removal of External Heart Assist System from Heart, Percutaneous Approach */
"02PA42Z" = "1" /* Removal of Monitoring Device from Heart, Percutaneous Endoscopic Approach */
"02PA43Z" = "1" /* Removal of Infusion Device from Heart, Percutaneous Endoscopic Approach */
"02PA47Z" = "1" /* Removal of Autologous Tissue Substitute from Heart, Percutaneous Endoscopic Approach */
"02PA48Z" = "1" /* Removal of Zooplastic Tissue from Heart, Percutaneous Endoscopic Approach */
"02PA4CZ" = "1" /* Removal of Extraluminal Device from Heart, Percutaneous Endoscopic Approach */
"02PA4DZ" = "1" /* Removal of Intraluminal Device from Heart, Percutaneous Endoscopic Approach */
"02PA4JZ" = "1" /* Removal of Synthetic Substitute from Heart, Percutaneous Endoscopic Approach */
"02PA4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Heart, Percutaneous Endoscopic Approach */
"02PA4NZ" = "1" /* Removal of Intracardiac Pacemaker from Heart, Percutaneous Endoscopic Approach */
"02PA4QZ" = "1" /* Removal of Implantable Heart Assist System from Heart, Percutaneous Endoscopic Approach */
"02PA4RZ" = "1" /* Removal of External Heart Assist System from Heart, Percutaneous Endoscopic Approach */
"02PY02Z" = "1" /* Removal of Monitoring Device from Great Vessel, Open Approach */
"02PY03Z" = "1" /* Removal of Infusion Device from Great Vessel, Open Approach */
"02PY07Z" = "1" /* Removal of Autologous Tissue Substitute from Great Vessel, Open Approach */
"02PY08Z" = "1" /* Removal of Zooplastic Tissue from Great Vessel, Open Approach */
"02PY0CZ" = "1" /* Removal of Extraluminal Device from Great Vessel, Open Approach */
"02PY0DZ" = "1" /* Removal of Intraluminal Device from Great Vessel, Open Approach */
"02PY0JZ" = "1" /* Removal of Synthetic Substitute from Great Vessel, Open Approach */
"02PY0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Great Vessel, Open Approach */
"02PY3CZ" = "1" /* Removal of Extraluminal Device from Great Vessel, Percutaneous Approach */
"02PY42Z" = "1" /* Removal of Monitoring Device from Great Vessel, Percutaneous Endoscopic Approach */
"02PY43Z" = "1" /* Removal of Infusion Device from Great Vessel, Percutaneous Endoscopic Approach */
"02PY47Z" = "1" /* Removal of Autologous Tissue Substitute from Great Vessel, Percutaneous Endoscopic Approach */
"02PY48Z" = "1" /* Removal of Zooplastic Tissue from Great Vessel, Percutaneous Endoscopic Approach */
"02PY4CZ" = "1" /* Removal of Extraluminal Device from Great Vessel, Percutaneous Endoscopic Approach */
"02PY4DZ" = "1" /* Removal of Intraluminal Device from Great Vessel, Percutaneous Endoscopic Approach */
"02PY4JZ" = "1" /* Removal of Synthetic Substitute from Great Vessel, Percutaneous Endoscopic Approach */
"02PY4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Great Vessel, Percutaneous Endoscopic Approach */
"02Q00ZZ" = "1" /* Repair Coronary Artery, One Site, Open Approach */
"02Q04ZZ" = "1" /* Repair Coronary Artery, One Site, Percutaneous Endoscopic Approach */
"02Q10ZZ" = "1" /* Repair Coronary Artery, Two Sites, Open Approach */
"02Q14ZZ" = "1" /* Repair Coronary Artery, Two Sites, Percutaneous Endoscopic Approach */
"02Q20ZZ" = "1" /* Repair Coronary Artery, Three Sites, Open Approach */
"02Q24ZZ" = "1" /* Repair Coronary Artery, Three Sites, Percutaneous Endoscopic Approach */
"02Q30ZZ" = "1" /* Repair Coronary Artery, Four or More Sites, Open Approach */
"02Q34ZZ" = "1" /* Repair Coronary Artery, Four or More Sites, Percutaneous Endoscopic Approach */
"02Q40ZZ" = "1" /* Repair Coronary Vein, Open Approach */
"02Q44ZZ" = "1" /* Repair Coronary Vein, Percutaneous Endoscopic Approach */
"02Q50ZZ" = "1" /* Repair Atrial Septum, Open Approach */
"02Q54ZZ" = "1" /* Repair Atrial Septum, Percutaneous Endoscopic Approach */
"02Q60ZZ" = "1" /* Repair Right Atrium, Open Approach */
"02Q64ZZ" = "1" /* Repair Right Atrium, Percutaneous Endoscopic Approach */
"02Q70ZZ" = "1" /* Repair Left Atrium, Open Approach */
"02Q74ZZ" = "1" /* Repair Left Atrium, Percutaneous Endoscopic Approach */
"02Q80ZZ" = "1" /* Repair Conduction Mechanism, Open Approach */
"02Q84ZZ" = "1" /* Repair Conduction Mechanism, Percutaneous Endoscopic Approach */
"02Q90ZZ" = "1" /* Repair Chordae Tendineae, Open Approach */
"02Q94ZZ" = "1" /* Repair Chordae Tendineae, Percutaneous Endoscopic Approach */
"02QA0ZZ" = "1" /* Repair Heart, Open Approach */
"02QA4ZZ" = "1" /* Repair Heart, Percutaneous Endoscopic Approach */
"02QB0ZZ" = "1" /* Repair Right Heart, Open Approach */
"02QB4ZZ" = "1" /* Repair Right Heart, Percutaneous Endoscopic Approach */
"02QC0ZZ" = "1" /* Repair Left Heart, Open Approach */
"02QC4ZZ" = "1" /* Repair Left Heart, Percutaneous Endoscopic Approach */
"02QD0ZZ" = "1" /* Repair Papillary Muscle, Open Approach */
"02QD4ZZ" = "1" /* Repair Papillary Muscle, Percutaneous Endoscopic Approach */
"02QF0ZJ" = "1" /* Repair Aortic Valve created from Truncal Valve, Open Approach */
"02QF0ZZ" = "1" /* Repair Aortic Valve, Open Approach */
"02QF4ZJ" = "1" /* Repair Aortic Valve created from Truncal Valve, Percutaneous Endoscopic Approach */
"02QF4ZZ" = "1" /* Repair Aortic Valve, Percutaneous Endoscopic Approach */
"02QG0ZE" = "1" /* Repair Mitral Valve created from Left Atrioventricular Valve, Open Approach */
"02QG0ZZ" = "1" /* Repair Mitral Valve, Open Approach */
"02QG4ZE" = "1" /* Repair Mitral Valve created from Left Atrioventricular Valve, Percutaneous Endoscopic Approach */
"02QG4ZZ" = "1" /* Repair Mitral Valve, Percutaneous Endoscopic Approach */
"02QH0ZZ" = "1" /* Repair Pulmonary Valve, Open Approach */
"02QH4ZZ" = "1" /* Repair Pulmonary Valve, Percutaneous Endoscopic Approach */
"02QJ0ZG" = "1" /* Repair Tricuspid Valve created from Right Atrioventricular Valve, Open Approach */
"02QJ0ZZ" = "1" /* Repair Tricuspid Valve, Open Approach */
"02QJ4ZG" = "1" /* Repair Tricuspid Valve created from Right Atrioventricular Valve, Percutaneous Endoscopic Approach */
"02QJ4ZZ" = "1" /* Repair Tricuspid Valve, Percutaneous Endoscopic Approach */
"02QK0ZZ" = "1" /* Repair Right Ventricle, Open Approach */
"02QK4ZZ" = "1" /* Repair Right Ventricle, Percutaneous Endoscopic Approach */
"02QL0ZZ" = "1" /* Repair Left Ventricle, Open Approach */
"02QL4ZZ" = "1" /* Repair Left Ventricle, Percutaneous Endoscopic Approach */
"02QM0ZZ" = "1" /* Repair Ventricular Septum, Open Approach */
"02QM4ZZ" = "1" /* Repair Ventricular Septum, Percutaneous Endoscopic Approach */
"02QN0ZZ" = "1" /* Repair Pericardium, Open Approach */
"02QN3ZZ" = "1" /* Repair Pericardium, Percutaneous Approach */
"02QN4ZZ" = "1" /* Repair Pericardium, Percutaneous Endoscopic Approach */
"02R507Z" = "1" /* Replacement of Atrial Septum with Autologous Tissue Substitute, Open Approach */
"02R508Z" = "1" /* Replacement of Atrial Septum with Zooplastic Tissue, Open Approach */
"02R50JZ" = "1" /* Replacement of Atrial Septum with Synthetic Substitute, Open Approach */
"02R50KZ" = "1" /* Replacement of Atrial Septum with Nonautologous Tissue Substitute, Open Approach */
"02R547Z" = "1" /* Replacement of Atrial Septum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02R548Z" = "1" /* Replacement of Atrial Septum with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02R54JZ" = "1" /* Replacement of Atrial Septum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02R54KZ" = "1" /* Replacement of Atrial Septum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02R607Z" = "1" /* Replacement of Right Atrium with Autologous Tissue Substitute, Open Approach */
"02R608Z" = "1" /* Replacement of Right Atrium with Zooplastic Tissue, Open Approach */
"02R60JZ" = "1" /* Replacement of Right Atrium with Synthetic Substitute, Open Approach */
"02R60KZ" = "1" /* Replacement of Right Atrium with Nonautologous Tissue Substitute, Open Approach */
"02R647Z" = "1" /* Replacement of Right Atrium with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02R648Z" = "1" /* Replacement of Right Atrium with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02R64JZ" = "1" /* Replacement of Right Atrium with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02R64KZ" = "1" /* Replacement of Right Atrium with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02R707Z" = "1" /* Replacement of Left Atrium with Autologous Tissue Substitute, Open Approach */
"02R708Z" = "1" /* Replacement of Left Atrium with Zooplastic Tissue, Open Approach */
"02R70JZ" = "1" /* Replacement of Left Atrium with Synthetic Substitute, Open Approach */
"02R70KZ" = "1" /* Replacement of Left Atrium with Nonautologous Tissue Substitute, Open Approach */
"02R747Z" = "1" /* Replacement of Left Atrium with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02R748Z" = "1" /* Replacement of Left Atrium with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02R74JZ" = "1" /* Replacement of Left Atrium with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02R74KZ" = "1" /* Replacement of Left Atrium with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02R907Z" = "1" /* Replacement of Chordae Tendineae with Autologous Tissue Substitute, Open Approach */
"02R908Z" = "1" /* Replacement of Chordae Tendineae with Zooplastic Tissue, Open Approach */
"02R90JZ" = "1" /* Replacement of Chordae Tendineae with Synthetic Substitute, Open Approach */
"02R90KZ" = "1" /* Replacement of Chordae Tendineae with Nonautologous Tissue Substitute, Open Approach */
"02R947Z" = "1" /* Replacement of Chordae Tendineae with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02R948Z" = "1" /* Replacement of Chordae Tendineae with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02R94JZ" = "1" /* Replacement of Chordae Tendineae with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02R94KZ" = "1" /* Replacement of Chordae Tendineae with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RD07Z" = "1" /* Replacement of Papillary Muscle with Autologous Tissue Substitute, Open Approach */
"02RD08Z" = "1" /* Replacement of Papillary Muscle with Zooplastic Tissue, Open Approach */
"02RD0JZ" = "1" /* Replacement of Papillary Muscle with Synthetic Substitute, Open Approach */
"02RD0KZ" = "1" /* Replacement of Papillary Muscle with Nonautologous Tissue Substitute, Open Approach */
"02RD47Z" = "1" /* Replacement of Papillary Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RD48Z" = "1" /* Replacement of Papillary Muscle with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RD4JZ" = "1" /* Replacement of Papillary Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RD4KZ" = "1" /* Replacement of Papillary Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RF07Z" = "1" /* Replacement of Aortic Valve with Autologous Tissue Substitute, Open Approach */
"02RF08Z" = "1" /* Replacement of Aortic Valve with Zooplastic Tissue, Open Approach */
"02RF0JZ" = "1" /* Replacement of Aortic Valve with Synthetic Substitute, Open Approach */
"02RF0KZ" = "1" /* Replacement of Aortic Valve with Nonautologous Tissue Substitute, Open Approach */
"02RF47Z" = "1" /* Replacement of Aortic Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RF48Z" = "1" /* Replacement of Aortic Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RF4JZ" = "1" /* Replacement of Aortic Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RF4KZ" = "1" /* Replacement of Aortic Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RG07Z" = "1" /* Replacement of Mitral Valve with Autologous Tissue Substitute, Open Approach */
"02RG08Z" = "1" /* Replacement of Mitral Valve with Zooplastic Tissue, Open Approach */
"02RG0JZ" = "1" /* Replacement of Mitral Valve with Synthetic Substitute, Open Approach */
"02RG0KZ" = "1" /* Replacement of Mitral Valve with Nonautologous Tissue Substitute, Open Approach */
"02RG47Z" = "1" /* Replacement of Mitral Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RG48Z" = "1" /* Replacement of Mitral Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RG4JZ" = "1" /* Replacement of Mitral Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RG4KZ" = "1" /* Replacement of Mitral Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RH07Z" = "1" /* Replacement of Pulmonary Valve with Autologous Tissue Substitute, Open Approach */
"02RH08Z" = "1" /* Replacement of Pulmonary Valve with Zooplastic Tissue, Open Approach */
"02RH0JZ" = "1" /* Replacement of Pulmonary Valve with Synthetic Substitute, Open Approach */
"02RH0KZ" = "1" /* Replacement of Pulmonary Valve with Nonautologous Tissue Substitute, Open Approach */
"02RH47Z" = "1" /* Replacement of Pulmonary Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RH48Z" = "1" /* Replacement of Pulmonary Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RH4JZ" = "1" /* Replacement of Pulmonary Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RH4KZ" = "1" /* Replacement of Pulmonary Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RJ07Z" = "1" /* Replacement of Tricuspid Valve with Autologous Tissue Substitute, Open Approach */
"02RJ08Z" = "1" /* Replacement of Tricuspid Valve with Zooplastic Tissue, Open Approach */
"02RJ0JZ" = "1" /* Replacement of Tricuspid Valve with Synthetic Substitute, Open Approach */
"02RJ0KZ" = "1" /* Replacement of Tricuspid Valve with Nonautologous Tissue Substitute, Open Approach */
"02RJ47Z" = "1" /* Replacement of Tricuspid Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RJ48Z" = "1" /* Replacement of Tricuspid Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RJ4JZ" = "1" /* Replacement of Tricuspid Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RJ4KZ" = "1" /* Replacement of Tricuspid Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RK07Z" = "1" /* Replacement of Right Ventricle with Autologous Tissue Substitute, Open Approach */
"02RK08Z" = "1" /* Replacement of Right Ventricle with Zooplastic Tissue, Open Approach */
"02RK0JZ" = "1" /* Replacement of Right Ventricle with Synthetic Substitute, Open Approach */
"02RK0KZ" = "1" /* Replacement of Right Ventricle with Nonautologous Tissue Substitute, Open Approach */
"02RK47Z" = "1" /* Replacement of Right Ventricle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RK48Z" = "1" /* Replacement of Right Ventricle with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RK4JZ" = "1" /* Replacement of Right Ventricle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RK4KZ" = "1" /* Replacement of Right Ventricle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RL07Z" = "1" /* Replacement of Left Ventricle with Autologous Tissue Substitute, Open Approach */
"02RL08Z" = "1" /* Replacement of Left Ventricle with Zooplastic Tissue, Open Approach */
"02RL0JZ" = "1" /* Replacement of Left Ventricle with Synthetic Substitute, Open Approach */
"02RL0KZ" = "1" /* Replacement of Left Ventricle with Nonautologous Tissue Substitute, Open Approach */
"02RL47Z" = "1" /* Replacement of Left Ventricle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RL48Z" = "1" /* Replacement of Left Ventricle with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RL4JZ" = "1" /* Replacement of Left Ventricle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RL4KZ" = "1" /* Replacement of Left Ventricle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RM07Z" = "1" /* Replacement of Ventricular Septum with Autologous Tissue Substitute, Open Approach */
"02RM08Z" = "1" /* Replacement of Ventricular Septum with Zooplastic Tissue, Open Approach */
"02RM0JZ" = "1" /* Replacement of Ventricular Septum with Synthetic Substitute, Open Approach */
"02RM0KZ" = "1" /* Replacement of Ventricular Septum with Nonautologous Tissue Substitute, Open Approach */
"02RM47Z" = "1" /* Replacement of Ventricular Septum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RM48Z" = "1" /* Replacement of Ventricular Septum with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RM4JZ" = "1" /* Replacement of Ventricular Septum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RM4KZ" = "1" /* Replacement of Ventricular Septum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RN07Z" = "1" /* Replacement of Pericardium with Autologous Tissue Substitute, Open Approach */
"02RN08Z" = "1" /* Replacement of Pericardium with Zooplastic Tissue, Open Approach */
"02RN0JZ" = "1" /* Replacement of Pericardium with Synthetic Substitute, Open Approach */
"02RN0KZ" = "1" /* Replacement of Pericardium with Nonautologous Tissue Substitute, Open Approach */
"02RN47Z" = "1" /* Replacement of Pericardium with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RN48Z" = "1" /* Replacement of Pericardium with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RN4JZ" = "1" /* Replacement of Pericardium with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RN4KZ" = "1" /* Replacement of Pericardium with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RP07Z" = "1" /* Replacement of Pulmonary Trunk with Autologous Tissue Substitute, Open Approach */
"02RP08Z" = "1" /* Replacement of Pulmonary Trunk with Zooplastic Tissue, Open Approach */
"02RP0JZ" = "1" /* Replacement of Pulmonary Trunk with Synthetic Substitute, Open Approach */
"02RP0KZ" = "1" /* Replacement of Pulmonary Trunk with Nonautologous Tissue Substitute, Open Approach */
"02RP47Z" = "1" /* Replacement of Pulmonary Trunk with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RP48Z" = "1" /* Replacement of Pulmonary Trunk with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RP4JZ" = "1" /* Replacement of Pulmonary Trunk with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RP4KZ" = "1" /* Replacement of Pulmonary Trunk with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RQ07Z" = "1" /* Replacement of Right Pulmonary Artery with Autologous Tissue Substitute, Open Approach */
"02RQ08Z" = "1" /* Replacement of Right Pulmonary Artery with Zooplastic Tissue, Open Approach */
"02RQ0JZ" = "1" /* Replacement of Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"02RQ0KZ" = "1" /* Replacement of Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"02RQ47Z" = "1" /* Replacement of Right Pulmonary Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RQ48Z" = "1" /* Replacement of Right Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RQ4JZ" = "1" /* Replacement of Right Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RQ4KZ" = "1" /* Replacement of Right Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RR07Z" = "1" /* Replacement of Left Pulmonary Artery with Autologous Tissue Substitute, Open Approach */
"02RR08Z" = "1" /* Replacement of Left Pulmonary Artery with Zooplastic Tissue, Open Approach */
"02RR0JZ" = "1" /* Replacement of Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"02RR0KZ" = "1" /* Replacement of Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"02RR47Z" = "1" /* Replacement of Left Pulmonary Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RR48Z" = "1" /* Replacement of Left Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RR4JZ" = "1" /* Replacement of Left Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RR4KZ" = "1" /* Replacement of Left Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RS07Z" = "1" /* Replacement of Right Pulmonary Vein with Autologous Tissue Substitute, Open Approach */
"02RS08Z" = "1" /* Replacement of Right Pulmonary Vein with Zooplastic Tissue, Open Approach */
"02RS0JZ" = "1" /* Replacement of Right Pulmonary Vein with Synthetic Substitute, Open Approach */
"02RS0KZ" = "1" /* Replacement of Right Pulmonary Vein with Nonautologous Tissue Substitute, Open Approach */
"02RS47Z" = "1" /* Replacement of Right Pulmonary Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RS48Z" = "1" /* Replacement of Right Pulmonary Vein with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RS4JZ" = "1" /* Replacement of Right Pulmonary Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RS4KZ" = "1" /* Replacement of Right Pulmonary Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RT07Z" = "1" /* Replacement of Left Pulmonary Vein with Autologous Tissue Substitute, Open Approach */
"02RT08Z" = "1" /* Replacement of Left Pulmonary Vein with Zooplastic Tissue, Open Approach */
"02RT0JZ" = "1" /* Replacement of Left Pulmonary Vein with Synthetic Substitute, Open Approach */
"02RT0KZ" = "1" /* Replacement of Left Pulmonary Vein with Nonautologous Tissue Substitute, Open Approach */
"02RT47Z" = "1" /* Replacement of Left Pulmonary Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RT48Z" = "1" /* Replacement of Left Pulmonary Vein with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RT4JZ" = "1" /* Replacement of Left Pulmonary Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RT4KZ" = "1" /* Replacement of Left Pulmonary Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RV07Z" = "1" /* Replacement of Superior Vena Cava with Autologous Tissue Substitute, Open Approach */
"02RV08Z" = "1" /* Replacement of Superior Vena Cava with Zooplastic Tissue, Open Approach */
"02RV0JZ" = "1" /* Replacement of Superior Vena Cava with Synthetic Substitute, Open Approach */
"02RV0KZ" = "1" /* Replacement of Superior Vena Cava with Nonautologous Tissue Substitute, Open Approach */
"02RV47Z" = "1" /* Replacement of Superior Vena Cava with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RV48Z" = "1" /* Replacement of Superior Vena Cava with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RV4JZ" = "1" /* Replacement of Superior Vena Cava with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RV4KZ" = "1" /* Replacement of Superior Vena Cava with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RW07Z" = "1" /* Replacement of Thoracic Aorta with Autologous Tissue Substitute, Open Approach */
"02RW08Z" = "1" /* Replacement of Thoracic Aorta with Zooplastic Tissue, Open Approach */
"02RW0JZ" = "1" /* Replacement of Thoracic Aorta with Synthetic Substitute, Open Approach */
"02RW0KZ" = "1" /* Replacement of Thoracic Aorta with Nonautologous Tissue Substitute, Open Approach */
"02RW47Z" = "1" /* Replacement of Thoracic Aorta with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RW48Z" = "1" /* Replacement of Thoracic Aorta with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RW4JZ" = "1" /* Replacement of Thoracic Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RW4KZ" = "1" /* Replacement of Thoracic Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RX07Z" = "1" /* Replacement of Thoracic Aorta, Ascending/Arch with Autologous Tissue Substitute, Open Approach */
"02RX08Z" = "1" /* Replacement of Thoracic Aorta, Ascending/Arch with Zooplastic Tissue, Open Approach */
"02RX0JZ" = "1" /* Replacement of Thoracic Aorta, Ascending/Arch with Synthetic Substitute, Open Approach */
"02RX0KZ" = "1" /* Replacement of Thoracic Aorta, Ascending/Arch with Nonautologous Tissue Substitute, Open Approach */
"02RX47Z" = "1" /* Replacement of Thoracic Aorta, Ascending/Arch with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RX48Z" = "1" /* Replacement of Thoracic Aorta, Ascending/Arch with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RX4JZ" = "1" /* Replacement of Thoracic Aorta, Ascending/Arch with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RX4KZ" = "1" /* Replacement of Thoracic Aorta, Ascending/Arch with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02SP0ZZ" = "1" /* Reposition Pulmonary Trunk, Open Approach */
"02SW0ZZ" = "1" /* Reposition Thoracic Aorta, Open Approach */
"02SX0ZZ" = "1" /* Reposition Thoracic Aorta, Ascending/Arch, Open Approach */
"02T50ZZ" = "1" /* Resection of Atrial Septum, Open Approach */
"02T54ZZ" = "1" /* Resection of Atrial Septum, Percutaneous Endoscopic Approach */
"02T80ZZ" = "1" /* Resection of Conduction Mechanism, Open Approach */
"02T84ZZ" = "1" /* Resection of Conduction Mechanism, Percutaneous Endoscopic Approach */
"02T90ZZ" = "1" /* Resection of Chordae Tendineae, Open Approach */
"02T94ZZ" = "1" /* Resection of Chordae Tendineae, Percutaneous Endoscopic Approach */
"02TD0ZZ" = "1" /* Resection of Papillary Muscle, Open Approach */
"02TD4ZZ" = "1" /* Resection of Papillary Muscle, Percutaneous Endoscopic Approach */
"02TH0ZZ" = "1" /* Resection of Pulmonary Valve, Open Approach */
"02TH4ZZ" = "1" /* Resection of Pulmonary Valve, Percutaneous Endoscopic Approach */
"02TM0ZZ" = "1" /* Resection of Ventricular Septum, Open Approach */
"02TM4ZZ" = "1" /* Resection of Ventricular Septum, Percutaneous Endoscopic Approach */
"02TN0ZZ" = "1" /* Resection of Pericardium, Open Approach */
"02TN3ZZ" = "1" /* Resection of Pericardium, Percutaneous Approach */
"02TN4ZZ" = "1" /* Resection of Pericardium, Percutaneous Endoscopic Approach */
"02U507Z" = "1" /* Supplement Atrial Septum with Autologous Tissue Substitute, Open Approach */
"02U508Z" = "1" /* Supplement Atrial Septum with Zooplastic Tissue, Open Approach */
"02U50JZ" = "1" /* Supplement Atrial Septum with Synthetic Substitute, Open Approach */
"02U50KZ" = "1" /* Supplement Atrial Septum with Nonautologous Tissue Substitute, Open Approach */
"02U547Z" = "1" /* Supplement Atrial Septum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02U548Z" = "1" /* Supplement Atrial Septum with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02U54JZ" = "1" /* Supplement Atrial Septum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02U54KZ" = "1" /* Supplement Atrial Septum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02U607Z" = "1" /* Supplement Right Atrium with Autologous Tissue Substitute, Open Approach */
"02U608Z" = "1" /* Supplement Right Atrium with Zooplastic Tissue, Open Approach */
"02U60JZ" = "1" /* Supplement Right Atrium with Synthetic Substitute, Open Approach */
"02U60KZ" = "1" /* Supplement Right Atrium with Nonautologous Tissue Substitute, Open Approach */
"02U647Z" = "1" /* Supplement Right Atrium with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02U648Z" = "1" /* Supplement Right Atrium with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02U64JZ" = "1" /* Supplement Right Atrium with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02U64KZ" = "1" /* Supplement Right Atrium with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02U707Z" = "1" /* Supplement Left Atrium with Autologous Tissue Substitute, Open Approach */
"02U708Z" = "1" /* Supplement Left Atrium with Zooplastic Tissue, Open Approach */
"02U70JZ" = "1" /* Supplement Left Atrium with Synthetic Substitute, Open Approach */
"02U70KZ" = "1" /* Supplement Left Atrium with Nonautologous Tissue Substitute, Open Approach */
"02U747Z" = "1" /* Supplement Left Atrium with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02U748Z" = "1" /* Supplement Left Atrium with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02U74KZ" = "1" /* Supplement Left Atrium with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02U907Z" = "1" /* Supplement Chordae Tendineae with Autologous Tissue Substitute, Open Approach */
"02U908Z" = "1" /* Supplement Chordae Tendineae with Zooplastic Tissue, Open Approach */
"02U90JZ" = "1" /* Supplement Chordae Tendineae with Synthetic Substitute, Open Approach */
"02U90KZ" = "1" /* Supplement Chordae Tendineae with Nonautologous Tissue Substitute, Open Approach */
"02U947Z" = "1" /* Supplement Chordae Tendineae with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02U948Z" = "1" /* Supplement Chordae Tendineae with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02U94JZ" = "1" /* Supplement Chordae Tendineae with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02U94KZ" = "1" /* Supplement Chordae Tendineae with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UA07Z" = "1" /* Supplement Heart with Autologous Tissue Substitute, Open Approach */
"02UA08Z" = "1" /* Supplement Heart with Zooplastic Tissue, Open Approach */
"02UA0JZ" = "1" /* Supplement Heart with Synthetic Substitute, Open Approach */
"02UA0KZ" = "1" /* Supplement Heart with Nonautologous Tissue Substitute, Open Approach */
"02UA47Z" = "1" /* Supplement Heart with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UA48Z" = "1" /* Supplement Heart with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UA4JZ" = "1" /* Supplement Heart with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UA4KZ" = "1" /* Supplement Heart with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UD07Z" = "1" /* Supplement Papillary Muscle with Autologous Tissue Substitute, Open Approach */
"02UD08Z" = "1" /* Supplement Papillary Muscle with Zooplastic Tissue, Open Approach */
"02UD0JZ" = "1" /* Supplement Papillary Muscle with Synthetic Substitute, Open Approach */
"02UD0KZ" = "1" /* Supplement Papillary Muscle with Nonautologous Tissue Substitute, Open Approach */
"02UD47Z" = "1" /* Supplement Papillary Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UD48Z" = "1" /* Supplement Papillary Muscle with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UD4JZ" = "1" /* Supplement Papillary Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UD4KZ" = "1" /* Supplement Papillary Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UF07J" = "1" /* Supplement Aortic Valve created from Truncal Valve with Autologous Tissue Substitute, Open Approach */
"02UF07Z" = "1" /* Supplement Aortic Valve with Autologous Tissue Substitute, Open Approach */
"02UF08J" = "1" /* Supplement Aortic Valve created from Truncal Valve with Zooplastic Tissue, Open Approach */
"02UF08Z" = "1" /* Supplement Aortic Valve with Zooplastic Tissue, Open Approach */
"02UF0JJ" = "1" /* Supplement Aortic Valve created from Truncal Valve with Synthetic Substitute, Open Approach */
"02UF0JZ" = "1" /* Supplement Aortic Valve with Synthetic Substitute, Open Approach */
"02UF0KJ" = "1" /* Supplement Aortic Valve created from Truncal Valve with Nonautologous Tissue Substitute, Open Approach */
"02UF0KZ" = "1" /* Supplement Aortic Valve with Nonautologous Tissue Substitute, Open Approach */
"02UF47J" = "1" /* Supplement Aortic Valve created from Truncal Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UF47Z" = "1" /* Supplement Aortic Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UF48J" = "1" /* Supplement Aortic Valve created from Truncal Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UF48Z" = "1" /* Supplement Aortic Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UF4JJ" = "1" /* Supplement Aortic Valve created from Truncal Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UF4JZ" = "1" /* Supplement Aortic Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UF4KJ" = "1" /* Supplement Aortic Valve created from Truncal Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UF4KZ" = "1" /* Supplement Aortic Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UG07E" = "1" /* Supplement Mitral Valve created from Left Atrioventricular Valve with Autologous Tissue Substitute, Open Approach */
"02UG07Z" = "1" /* Supplement Mitral Valve with Autologous Tissue Substitute, Open Approach */
"02UG08E" = "1" /* Supplement Mitral Valve created from Left Atrioventricular Valve with Zooplastic Tissue, Open Approach */
"02UG08Z" = "1" /* Supplement Mitral Valve with Zooplastic Tissue, Open Approach */
"02UG0JE" = "1" /* Supplement Mitral Valve created from Left Atrioventricular Valve with Synthetic Substitute, Open Approach */
"02UG0JZ" = "1" /* Supplement Mitral Valve with Synthetic Substitute, Open Approach */
"02UG0KE" = "1" /* Supplement Mitral Valve created from Left Atrioventricular Valve with Nonautologous Tissue Substitute, Open Approach */
"02UG0KZ" = "1" /* Supplement Mitral Valve with Nonautologous Tissue Substitute, Open Approach */
"02UG47E" = "1" /* Supplement Mitral Valve created from Left Atrioventricular Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UG47Z" = "1" /* Supplement Mitral Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UG48E" = "1" /* Supplement Mitral Valve created from Left Atrioventricular Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UG48Z" = "1" /* Supplement Mitral Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UG4JE" = "1" /* Supplement Mitral Valve created from Left Atrioventricular Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UG4JZ" = "1" /* Supplement Mitral Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UG4KE" = "1" /* Supplement Mitral Valve created from Left Atrioventricular Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UG4KZ" = "1" /* Supplement Mitral Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UH07Z" = "1" /* Supplement Pulmonary Valve with Autologous Tissue Substitute, Open Approach */
"02UH08Z" = "1" /* Supplement Pulmonary Valve with Zooplastic Tissue, Open Approach */
"02UH0JZ" = "1" /* Supplement Pulmonary Valve with Synthetic Substitute, Open Approach */
"02UH0KZ" = "1" /* Supplement Pulmonary Valve with Nonautologous Tissue Substitute, Open Approach */
"02UH47Z" = "1" /* Supplement Pulmonary Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UH48Z" = "1" /* Supplement Pulmonary Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UH4JZ" = "1" /* Supplement Pulmonary Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UH4KZ" = "1" /* Supplement Pulmonary Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UJ07G" = "1" /* Supplement Tricuspid Valve created from Right Atrioventricular Valve with Autologous Tissue Substitute, Open Approach */
"02UJ07Z" = "1" /* Supplement Tricuspid Valve with Autologous Tissue Substitute, Open Approach */
"02UJ08G" = "1" /* Supplement Tricuspid Valve created from Right Atrioventricular Valve with Zooplastic Tissue, Open Approach */
"02UJ08Z" = "1" /* Supplement Tricuspid Valve with Zooplastic Tissue, Open Approach */
"02UJ0JG" = "1" /* Supplement Tricuspid Valve created from Right Atrioventricular Valve with Synthetic Substitute, Open Approach */
"02UJ0JZ" = "1" /* Supplement Tricuspid Valve with Synthetic Substitute, Open Approach */
"02UJ0KG" = "1" /* Supplement Tricuspid Valve created from Right Atrioventricular Valve with Nonautologous Tissue Substitute, Open Approach */
"02UJ0KZ" = "1" /* Supplement Tricuspid Valve with Nonautologous Tissue Substitute, Open Approach */
"02UJ47G" = "1" /* Supplement Tricuspid Valve created from Right Atrioventricular Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UJ47Z" = "1" /* Supplement Tricuspid Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UJ48G" = "1" /* Supplement Tricuspid Valve created from Right Atrioventricular Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UJ48Z" = "1" /* Supplement Tricuspid Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UJ4JG" = "1" /* Supplement Tricuspid Valve created from Right Atrioventricular Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UJ4JZ" = "1" /* Supplement Tricuspid Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UJ4KG" = "1" /* Supplement Tricuspid Valve created from Right Atrioventricular Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UJ4KZ" = "1" /* Supplement Tricuspid Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UK07Z" = "1" /* Supplement Right Ventricle with Autologous Tissue Substitute, Open Approach */
"02UK08Z" = "1" /* Supplement Right Ventricle with Zooplastic Tissue, Open Approach */
"02UK0JZ" = "1" /* Supplement Right Ventricle with Synthetic Substitute, Open Approach */
"02UK0KZ" = "1" /* Supplement Right Ventricle with Nonautologous Tissue Substitute, Open Approach */
"02UK47Z" = "1" /* Supplement Right Ventricle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UK48Z" = "1" /* Supplement Right Ventricle with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UK4JZ" = "1" /* Supplement Right Ventricle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UK4KZ" = "1" /* Supplement Right Ventricle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UL07Z" = "1" /* Supplement Left Ventricle with Autologous Tissue Substitute, Open Approach */
"02UL08Z" = "1" /* Supplement Left Ventricle with Zooplastic Tissue, Open Approach */
"02UL0JZ" = "1" /* Supplement Left Ventricle with Synthetic Substitute, Open Approach */
"02UL0KZ" = "1" /* Supplement Left Ventricle with Nonautologous Tissue Substitute, Open Approach */
"02UL47Z" = "1" /* Supplement Left Ventricle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UL48Z" = "1" /* Supplement Left Ventricle with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UL4JZ" = "1" /* Supplement Left Ventricle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UL4KZ" = "1" /* Supplement Left Ventricle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UM07Z" = "1" /* Supplement Ventricular Septum with Autologous Tissue Substitute, Open Approach */
"02UM08Z" = "1" /* Supplement Ventricular Septum with Zooplastic Tissue, Open Approach */
"02UM0JZ" = "1" /* Supplement Ventricular Septum with Synthetic Substitute, Open Approach */
"02UM0KZ" = "1" /* Supplement Ventricular Septum with Nonautologous Tissue Substitute, Open Approach */
"02UM47Z" = "1" /* Supplement Ventricular Septum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UM48Z" = "1" /* Supplement Ventricular Septum with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UM4JZ" = "1" /* Supplement Ventricular Septum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UM4KZ" = "1" /* Supplement Ventricular Septum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UN07Z" = "1" /* Supplement Pericardium with Autologous Tissue Substitute, Open Approach */
"02UN08Z" = "1" /* Supplement Pericardium with Zooplastic Tissue, Open Approach */
"02UN0JZ" = "1" /* Supplement Pericardium with Synthetic Substitute, Open Approach */
"02UN0KZ" = "1" /* Supplement Pericardium with Nonautologous Tissue Substitute, Open Approach */
"02UN37Z" = "1" /* Supplement Pericardium with Autologous Tissue Substitute, Percutaneous Approach */
"02UN38Z" = "1" /* Supplement Pericardium with Zooplastic Tissue, Percutaneous Approach */
"02UN3JZ" = "1" /* Supplement Pericardium with Synthetic Substitute, Percutaneous Approach */
"02UN3KZ" = "1" /* Supplement Pericardium with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UN47Z" = "1" /* Supplement Pericardium with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UN48Z" = "1" /* Supplement Pericardium with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UN4JZ" = "1" /* Supplement Pericardium with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UN4KZ" = "1" /* Supplement Pericardium with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02VA0CZ" = "1" /* Restriction of Heart with Extraluminal Device, Open Approach */
"02VA0ZZ" = "1" /* Restriction of Heart, Open Approach */
"02VA3CZ" = "1" /* Restriction of Heart with Extraluminal Device, Percutaneous Approach */
"02VA4CZ" = "1" /* Restriction of Heart with Extraluminal Device, Percutaneous Endoscopic Approach */
"02VA4ZZ" = "1" /* Restriction of Heart, Percutaneous Endoscopic Approach */
"02VQ0CZ" = "1" /* Restriction of Right Pulmonary Artery with Extraluminal Device, Open Approach */
"02VQ3CZ" = "1" /* Restriction of Right Pulmonary Artery with Extraluminal Device, Percutaneous Approach */
"02VQ4CZ" = "1" /* Restriction of Right Pulmonary Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"02VR0CZ" = "1" /* Restriction of Left Pulmonary Artery with Extraluminal Device, Open Approach */
"02VR0ZT" = "1" /* Restriction of Ductus Arteriosus, Open Approach */
"02VR3CZ" = "1" /* Restriction of Left Pulmonary Artery with Extraluminal Device, Percutaneous Approach */
"02VR4CZ" = "1" /* Restriction of Left Pulmonary Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"02W50JZ" = "1" /* Revision of Synthetic Substitute in Atrial Septum, Open Approach */
"02W54JZ" = "1" /* Revision of Synthetic Substitute in Atrial Septum, Percutaneous Endoscopic Approach */
"02WA02Z" = "1" /* Revision of Monitoring Device in Heart, Open Approach */
"02WA03Z" = "1" /* Revision of Infusion Device in Heart, Open Approach */
"02WA07Z" = "1" /* Revision of Autologous Tissue Substitute in Heart, Open Approach */
"02WA08Z" = "1" /* Revision of Zooplastic Tissue in Heart, Open Approach */
"02WA0CZ" = "1" /* Revision of Extraluminal Device in Heart, Open Approach */
"02WA0DZ" = "1" /* Revision of Intraluminal Device in Heart, Open Approach */
"02WA0JZ" = "1" /* Revision of Synthetic Substitute in Heart, Open Approach */
"02WA0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Heart, Open Approach */
"02WA0NZ" = "1" /* Revision of Intracardiac Pacemaker in Heart, Open Approach */
"02WA0QZ" = "1" /* Revision of Implantable Heart Assist System in Heart, Open Approach */
"02WA0RZ" = "1" /* Revision of External Heart Assist System in Heart, Open Approach */
"02WA3CZ" = "1" /* Revision of Extraluminal Device in Heart, Percutaneous Approach */
"02WA3RZ" = "1" /* Revision of External Heart Assist System in Heart, Percutaneous Approach */
"02WA42Z" = "1" /* Revision of Monitoring Device in Heart, Percutaneous Endoscopic Approach */
"02WA43Z" = "1" /* Revision of Infusion Device in Heart, Percutaneous Endoscopic Approach */
"02WA47Z" = "1" /* Revision of Autologous Tissue Substitute in Heart, Percutaneous Endoscopic Approach */
"02WA48Z" = "1" /* Revision of Zooplastic Tissue in Heart, Percutaneous Endoscopic Approach */
"02WA4CZ" = "1" /* Revision of Extraluminal Device in Heart, Percutaneous Endoscopic Approach */
"02WA4DZ" = "1" /* Revision of Intraluminal Device in Heart, Percutaneous Endoscopic Approach */
"02WA4JZ" = "1" /* Revision of Synthetic Substitute in Heart, Percutaneous Endoscopic Approach */
"02WA4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Heart, Percutaneous Endoscopic Approach */
"02WA4NZ" = "1" /* Revision of Intracardiac Pacemaker in Heart, Percutaneous Endoscopic Approach */
"02WA4QZ" = "1" /* Revision of Implantable Heart Assist System in Heart, Percutaneous Endoscopic Approach */
"02WA4RZ" = "1" /* Revision of External Heart Assist System in Heart, Percutaneous Endoscopic Approach */
"02WF07Z" = "1" /* Revision of Autologous Tissue Substitute in Aortic Valve, Open Approach */
"02WF08Z" = "1" /* Revision of Zooplastic Tissue in Aortic Valve, Open Approach */
"02WF0JZ" = "1" /* Revision of Synthetic Substitute in Aortic Valve, Open Approach */
"02WF0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Aortic Valve, Open Approach */
"02WF47Z" = "1" /* Revision of Autologous Tissue Substitute in Aortic Valve, Percutaneous Endoscopic Approach */
"02WF48Z" = "1" /* Revision of Zooplastic Tissue in Aortic Valve, Percutaneous Endoscopic Approach */
"02WF4JZ" = "1" /* Revision of Synthetic Substitute in Aortic Valve, Percutaneous Endoscopic Approach */
"02WF4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Aortic Valve, Percutaneous Endoscopic Approach */
"02WG07Z" = "1" /* Revision of Autologous Tissue Substitute in Mitral Valve, Open Approach */
"02WG08Z" = "1" /* Revision of Zooplastic Tissue in Mitral Valve, Open Approach */
"02WG0JZ" = "1" /* Revision of Synthetic Substitute in Mitral Valve, Open Approach */
"02WG0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mitral Valve, Open Approach */
"02WG47Z" = "1" /* Revision of Autologous Tissue Substitute in Mitral Valve, Percutaneous Endoscopic Approach */
"02WG48Z" = "1" /* Revision of Zooplastic Tissue in Mitral Valve, Percutaneous Endoscopic Approach */
"02WG4JZ" = "1" /* Revision of Synthetic Substitute in Mitral Valve, Percutaneous Endoscopic Approach */
"02WG4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mitral Valve, Percutaneous Endoscopic Approach */
"02WH07Z" = "1" /* Revision of Autologous Tissue Substitute in Pulmonary Valve, Open Approach */
"02WH08Z" = "1" /* Revision of Zooplastic Tissue in Pulmonary Valve, Open Approach */
"02WH0JZ" = "1" /* Revision of Synthetic Substitute in Pulmonary Valve, Open Approach */
"02WH0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Pulmonary Valve, Open Approach */
"02WH47Z" = "1" /* Revision of Autologous Tissue Substitute in Pulmonary Valve, Percutaneous Endoscopic Approach */
"02WH48Z" = "1" /* Revision of Zooplastic Tissue in Pulmonary Valve, Percutaneous Endoscopic Approach */
"02WH4JZ" = "1" /* Revision of Synthetic Substitute in Pulmonary Valve, Percutaneous Endoscopic Approach */
"02WH4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Pulmonary Valve, Percutaneous Endoscopic Approach */
"02WJ07Z" = "1" /* Revision of Autologous Tissue Substitute in Tricuspid Valve, Open Approach */
"02WJ08Z" = "1" /* Revision of Zooplastic Tissue in Tricuspid Valve, Open Approach */
"02WJ0JZ" = "1" /* Revision of Synthetic Substitute in Tricuspid Valve, Open Approach */
"02WJ0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Tricuspid Valve, Open Approach */
"02WJ47Z" = "1" /* Revision of Autologous Tissue Substitute in Tricuspid Valve, Percutaneous Endoscopic Approach */
"02WJ48Z" = "1" /* Revision of Zooplastic Tissue in Tricuspid Valve, Percutaneous Endoscopic Approach */
"02WJ4JZ" = "1" /* Revision of Synthetic Substitute in Tricuspid Valve, Percutaneous Endoscopic Approach */
"02WJ4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Tricuspid Valve, Percutaneous Endoscopic Approach */
"02WM0JZ" = "1" /* Revision of Synthetic Substitute in Ventricular Septum, Open Approach */
"02WM4JZ" = "1" /* Revision of Synthetic Substitute in Ventricular Septum, Percutaneous Endoscopic Approach */
"02WY02Z" = "1" /* Revision of Monitoring Device in Great Vessel, Open Approach */
"02WY03Z" = "1" /* Revision of Infusion Device in Great Vessel, Open Approach */
"02WY07Z" = "1" /* Revision of Autologous Tissue Substitute in Great Vessel, Open Approach */
"02WY08Z" = "1" /* Revision of Zooplastic Tissue in Great Vessel, Open Approach */
"02WY0CZ" = "1" /* Revision of Extraluminal Device in Great Vessel, Open Approach */
"02WY0DZ" = "1" /* Revision of Intraluminal Device in Great Vessel, Open Approach */
"02WY0JZ" = "1" /* Revision of Synthetic Substitute in Great Vessel, Open Approach */
"02WY0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Great Vessel, Open Approach */
"02WY3CZ" = "1" /* Revision of Extraluminal Device in Great Vessel, Percutaneous Approach */
"02WY42Z" = "1" /* Revision of Monitoring Device in Great Vessel, Percutaneous Endoscopic Approach */
"02WY43Z" = "1" /* Revision of Infusion Device in Great Vessel, Percutaneous Endoscopic Approach */
"02WY47Z" = "1" /* Revision of Autologous Tissue Substitute in Great Vessel, Percutaneous Endoscopic Approach */
"02WY48Z" = "1" /* Revision of Zooplastic Tissue in Great Vessel, Percutaneous Endoscopic Approach */
"02WY4CZ" = "1" /* Revision of Extraluminal Device in Great Vessel, Percutaneous Endoscopic Approach */
"02WY4DZ" = "1" /* Revision of Intraluminal Device in Great Vessel, Percutaneous Endoscopic Approach */
"02WY4JZ" = "1" /* Revision of Synthetic Substitute in Great Vessel, Percutaneous Endoscopic Approach */
"02WY4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Great Vessel, Percutaneous Endoscopic Approach */
"02YA0Z0" = "1" /* Transplantation of Heart, Allogeneic, Open Approach */
"02YA0Z1" = "1" /* Transplantation of Heart, Syngeneic, Open Approach */
"02YA0Z2" = "1" /* Transplantation of Heart, Zooplastic, Open Approach */
"031309M" = "1" /* Bypass Right Subclavian Artery to Right Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"031309N" = "1" /* Bypass Right Subclavian Artery to Left Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"03130AM" = "1" /* Bypass Right Subclavian Artery to Right Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"03130AN" = "1" /* Bypass Right Subclavian Artery to Left Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"03130JM" = "1" /* Bypass Right Subclavian Artery to Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"03130JN" = "1" /* Bypass Right Subclavian Artery to Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"03130KM" = "1" /* Bypass Right Subclavian Artery to Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"03130KN" = "1" /* Bypass Right Subclavian Artery to Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"03130ZM" = "1" /* Bypass Right Subclavian Artery to Right Pulmonary Artery, Open Approach */
"03130ZN" = "1" /* Bypass Right Subclavian Artery to Left Pulmonary Artery, Open Approach */
"031409M" = "1" /* Bypass Left Subclavian Artery to Right Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"031409N" = "1" /* Bypass Left Subclavian Artery to Left Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"03140AM" = "1" /* Bypass Left Subclavian Artery to Right Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"03140AN" = "1" /* Bypass Left Subclavian Artery to Left Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"03140JM" = "1" /* Bypass Left Subclavian Artery to Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"03140JN" = "1" /* Bypass Left Subclavian Artery to Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"03140KM" = "1" /* Bypass Left Subclavian Artery to Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"03140KN" = "1" /* Bypass Left Subclavian Artery to Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"03140ZM" = "1" /* Bypass Left Subclavian Artery to Right Pulmonary Artery, Open Approach */
"03140ZN" = "1" /* Bypass Left Subclavian Artery to Left Pulmonary Artery, Open Approach */
"031H09J" = "1" /* Bypass Right Common Carotid Artery to Right Extracranial Artery with Autologous Venous Tissue, Open Approach */
"031H0AJ" = "1" /* Bypass Right Common Carotid Artery to Right Extracranial Artery with Autologous Arterial Tissue, Open Approach */
"031H0JJ" = "1" /* Bypass Right Common Carotid Artery to Right Extracranial Artery with Synthetic Substitute, Open Approach */
"031H0KJ" = "1" /* Bypass Right Common Carotid Artery to Right Extracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"031H0ZJ" = "1" /* Bypass Right Common Carotid Artery to Right Extracranial Artery, Open Approach */
"031J09K" = "1" /* Bypass Left Common Carotid Artery to Left Extracranial Artery with Autologous Venous Tissue, Open Approach */
"031J0AK" = "1" /* Bypass Left Common Carotid Artery to Left Extracranial Artery with Autologous Arterial Tissue, Open Approach */
"031J0JK" = "1" /* Bypass Left Common Carotid Artery to Left Extracranial Artery with Synthetic Substitute, Open Approach */
"031J0KK" = "1" /* Bypass Left Common Carotid Artery to Left Extracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"031J0ZK" = "1" /* Bypass Left Common Carotid Artery to Left Extracranial Artery, Open Approach */
"03500ZZ" = "1" /* Destruction of Right Internal Mammary Artery, Open Approach */
"03503ZZ" = "1" /* Destruction of Right Internal Mammary Artery, Percutaneous Approach */
"03504ZZ" = "1" /* Destruction of Right Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03510ZZ" = "1" /* Destruction of Left Internal Mammary Artery, Open Approach */
"03513ZZ" = "1" /* Destruction of Left Internal Mammary Artery, Percutaneous Approach */
"03514ZZ" = "1" /* Destruction of Left Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03520ZZ" = "1" /* Destruction of Innominate Artery, Open Approach */
"03524ZZ" = "1" /* Destruction of Innominate Artery, Percutaneous Endoscopic Approach */
"03530ZZ" = "1" /* Destruction of Right Subclavian Artery, Open Approach */
"03534ZZ" = "1" /* Destruction of Right Subclavian Artery, Percutaneous Endoscopic Approach */
"03540ZZ" = "1" /* Destruction of Left Subclavian Artery, Open Approach */
"03544ZZ" = "1" /* Destruction of Left Subclavian Artery, Percutaneous Endoscopic Approach */
"03B00ZZ" = "1" /* Excision of Right Internal Mammary Artery, Open Approach */
"03B03ZZ" = "1" /* Excision of Right Internal Mammary Artery, Percutaneous Approach */
"03B04ZZ" = "1" /* Excision of Right Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03B10ZZ" = "1" /* Excision of Left Internal Mammary Artery, Open Approach */
"03B13ZZ" = "1" /* Excision of Left Internal Mammary Artery, Percutaneous Approach */
"03B14ZZ" = "1" /* Excision of Left Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03B20ZZ" = "1" /* Excision of Innominate Artery, Open Approach */
"03B24ZZ" = "1" /* Excision of Innominate Artery, Percutaneous Endoscopic Approach */
"03B30ZZ" = "1" /* Excision of Right Subclavian Artery, Open Approach */
"03B34ZZ" = "1" /* Excision of Right Subclavian Artery, Percutaneous Endoscopic Approach */
"03B40ZZ" = "1" /* Excision of Left Subclavian Artery, Open Approach */
"03B44ZZ" = "1" /* Excision of Left Subclavian Artery, Percutaneous Endoscopic Approach */
"03C00Z6" = "1" /* Extirpation of Matter from Right Internal Mammary Artery, Bifurcation, Open Approach */
"03C00ZZ" = "1" /* Extirpation of Matter from Right Internal Mammary Artery, Open Approach */
"03C04Z6" = "1" /* Extirpation of Matter from Right Internal Mammary Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03C04ZZ" = "1" /* Extirpation of Matter from Right Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03C10Z6" = "1" /* Extirpation of Matter from Left Internal Mammary Artery, Bifurcation, Open Approach */
"03C10ZZ" = "1" /* Extirpation of Matter from Left Internal Mammary Artery, Open Approach */
"03C14Z6" = "1" /* Extirpation of Matter from Left Internal Mammary Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03C14ZZ" = "1" /* Extirpation of Matter from Left Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03C20Z6" = "1" /* Extirpation of Matter from Innominate Artery, Bifurcation, Open Approach */
"03C20ZZ" = "1" /* Extirpation of Matter from Innominate Artery, Open Approach */
"03C24Z6" = "1" /* Extirpation of Matter from Innominate Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03C24ZZ" = "1" /* Extirpation of Matter from Innominate Artery, Percutaneous Endoscopic Approach */
"03C30Z6" = "1" /* Extirpation of Matter from Right Subclavian Artery, Bifurcation, Open Approach */
"03C30ZZ" = "1" /* Extirpation of Matter from Right Subclavian Artery, Open Approach */
"03C34Z6" = "1" /* Extirpation of Matter from Right Subclavian Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03C34ZZ" = "1" /* Extirpation of Matter from Right Subclavian Artery, Percutaneous Endoscopic Approach */
"03C40Z6" = "1" /* Extirpation of Matter from Left Subclavian Artery, Bifurcation, Open Approach */
"03C40ZZ" = "1" /* Extirpation of Matter from Left Subclavian Artery, Open Approach */
"03C44Z6" = "1" /* Extirpation of Matter from Left Subclavian Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03C44ZZ" = "1" /* Extirpation of Matter from Left Subclavian Artery, Percutaneous Endoscopic Approach */
"03L00CZ" = "1" /* Occlusion of Right Internal Mammary Artery with Extraluminal Device, Open Approach */
"03L00DZ" = "1" /* Occlusion of Right Internal Mammary Artery with Intraluminal Device, Open Approach */
"03L00ZZ" = "1" /* Occlusion of Right Internal Mammary Artery, Open Approach */
"03L03CZ" = "1" /* Occlusion of Right Internal Mammary Artery with Extraluminal Device, Percutaneous Approach */
"03L04CZ" = "1" /* Occlusion of Right Internal Mammary Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L04DZ" = "1" /* Occlusion of Right Internal Mammary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L04ZZ" = "1" /* Occlusion of Right Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03L10CZ" = "1" /* Occlusion of Left Internal Mammary Artery with Extraluminal Device, Open Approach */
"03L10DZ" = "1" /* Occlusion of Left Internal Mammary Artery with Intraluminal Device, Open Approach */
"03L10ZZ" = "1" /* Occlusion of Left Internal Mammary Artery, Open Approach */
"03L13CZ" = "1" /* Occlusion of Left Internal Mammary Artery with Extraluminal Device, Percutaneous Approach */
"03L14CZ" = "1" /* Occlusion of Left Internal Mammary Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L14DZ" = "1" /* Occlusion of Left Internal Mammary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L14ZZ" = "1" /* Occlusion of Left Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03L20CZ" = "1" /* Occlusion of Innominate Artery with Extraluminal Device, Open Approach */
"03L20DZ" = "1" /* Occlusion of Innominate Artery with Intraluminal Device, Open Approach */
"03L20ZZ" = "1" /* Occlusion of Innominate Artery, Open Approach */
"03L23CZ" = "1" /* Occlusion of Innominate Artery with Extraluminal Device, Percutaneous Approach */
"03L24CZ" = "1" /* Occlusion of Innominate Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L24DZ" = "1" /* Occlusion of Innominate Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L24ZZ" = "1" /* Occlusion of Innominate Artery, Percutaneous Endoscopic Approach */
"03L30CZ" = "1" /* Occlusion of Right Subclavian Artery with Extraluminal Device, Open Approach */
"03L30DZ" = "1" /* Occlusion of Right Subclavian Artery with Intraluminal Device, Open Approach */
"03L30ZZ" = "1" /* Occlusion of Right Subclavian Artery, Open Approach */
"03L33CZ" = "1" /* Occlusion of Right Subclavian Artery with Extraluminal Device, Percutaneous Approach */
"03L34CZ" = "1" /* Occlusion of Right Subclavian Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L34DZ" = "1" /* Occlusion of Right Subclavian Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L34ZZ" = "1" /* Occlusion of Right Subclavian Artery, Percutaneous Endoscopic Approach */
"03L40CZ" = "1" /* Occlusion of Left Subclavian Artery with Extraluminal Device, Open Approach */
"03L40DZ" = "1" /* Occlusion of Left Subclavian Artery with Intraluminal Device, Open Approach */
"03L40ZZ" = "1" /* Occlusion of Left Subclavian Artery, Open Approach */
"03L43CZ" = "1" /* Occlusion of Left Subclavian Artery with Extraluminal Device, Percutaneous Approach */
"03L44CZ" = "1" /* Occlusion of Left Subclavian Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L44DZ" = "1" /* Occlusion of Left Subclavian Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L44ZZ" = "1" /* Occlusion of Left Subclavian Artery, Percutaneous Endoscopic Approach */
"03R007Z" = "1" /* Replacement of Right Internal Mammary Artery with Autologous Tissue Substitute, Open Approach */
"03R00JZ" = "1" /* Replacement of Right Internal Mammary Artery with Synthetic Substitute, Open Approach */
"03R00KZ" = "1" /* Replacement of Right Internal Mammary Artery with Nonautologous Tissue Substitute, Open Approach */
"03R047Z" = "1" /* Replacement of Right Internal Mammary Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R04JZ" = "1" /* Replacement of Right Internal Mammary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03R04KZ" = "1" /* Replacement of Right Internal Mammary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R107Z" = "1" /* Replacement of Left Internal Mammary Artery with Autologous Tissue Substitute, Open Approach */
"03R10JZ" = "1" /* Replacement of Left Internal Mammary Artery with Synthetic Substitute, Open Approach */
"03R10KZ" = "1" /* Replacement of Left Internal Mammary Artery with Nonautologous Tissue Substitute, Open Approach */
"03R147Z" = "1" /* Replacement of Left Internal Mammary Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R14JZ" = "1" /* Replacement of Left Internal Mammary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03R14KZ" = "1" /* Replacement of Left Internal Mammary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R207Z" = "1" /* Replacement of Innominate Artery with Autologous Tissue Substitute, Open Approach */
"03R20JZ" = "1" /* Replacement of Innominate Artery with Synthetic Substitute, Open Approach */
"03R20KZ" = "1" /* Replacement of Innominate Artery with Nonautologous Tissue Substitute, Open Approach */
"03R247Z" = "1" /* Replacement of Innominate Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R24JZ" = "1" /* Replacement of Innominate Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03R24KZ" = "1" /* Replacement of Innominate Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R307Z" = "1" /* Replacement of Right Subclavian Artery with Autologous Tissue Substitute, Open Approach */
"03R30JZ" = "1" /* Replacement of Right Subclavian Artery with Synthetic Substitute, Open Approach */
"03R30KZ" = "1" /* Replacement of Right Subclavian Artery with Nonautologous Tissue Substitute, Open Approach */
"03R347Z" = "1" /* Replacement of Right Subclavian Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R34JZ" = "1" /* Replacement of Right Subclavian Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03R34KZ" = "1" /* Replacement of Right Subclavian Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R407Z" = "1" /* Replacement of Left Subclavian Artery with Autologous Tissue Substitute, Open Approach */
"03R40JZ" = "1" /* Replacement of Left Subclavian Artery with Synthetic Substitute, Open Approach */
"03R40KZ" = "1" /* Replacement of Left Subclavian Artery with Nonautologous Tissue Substitute, Open Approach */
"03R447Z" = "1" /* Replacement of Left Subclavian Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R44JZ" = "1" /* Replacement of Left Subclavian Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03R44KZ" = "1" /* Replacement of Left Subclavian Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04500ZZ" = "1" /* Destruction of Abdominal Aorta, Open Approach */
"04504ZZ" = "1" /* Destruction of Abdominal Aorta, Percutaneous Endoscopic Approach */
"04B00ZZ" = "1" /* Excision of Abdominal Aorta, Open Approach */
"04B04ZZ" = "1" /* Excision of Abdominal Aorta, Percutaneous Endoscopic Approach */
"04C00Z6" = "1" /* Extirpation of Matter from Abdominal Aorta, Bifurcation, Open Approach */
"04C00ZZ" = "1" /* Extirpation of Matter from Abdominal Aorta, Open Approach */
"04C04Z6" = "1" /* Extirpation of Matter from Abdominal Aorta, Bifurcation, Percutaneous Endoscopic Approach */
"04C04ZZ" = "1" /* Extirpation of Matter from Abdominal Aorta, Percutaneous Endoscopic Approach */
"04L00CZ" = "1" /* Occlusion of Abdominal Aorta with Extraluminal Device, Open Approach */
"04L00DZ" = "1" /* Occlusion of Abdominal Aorta with Intraluminal Device, Open Approach */
"04L00ZZ" = "1" /* Occlusion of Abdominal Aorta, Open Approach */
"04L03CZ" = "1" /* Occlusion of Abdominal Aorta with Extraluminal Device, Percutaneous Approach */
"04L04CZ" = "1" /* Occlusion of Abdominal Aorta with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L04DZ" = "1" /* Occlusion of Abdominal Aorta with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L04ZZ" = "1" /* Occlusion of Abdominal Aorta, Percutaneous Endoscopic Approach */
"04R007Z" = "1" /* Replacement of Abdominal Aorta with Autologous Tissue Substitute, Open Approach */
"04R00JZ" = "1" /* Replacement of Abdominal Aorta with Synthetic Substitute, Open Approach */
"04R00KZ" = "1" /* Replacement of Abdominal Aorta with Nonautologous Tissue Substitute, Open Approach */
"04R047Z" = "1" /* Replacement of Abdominal Aorta with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R04JZ" = "1" /* Replacement of Abdominal Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04R04KZ" = "1" /* Replacement of Abdominal Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051007Y" = "1" /* Bypass Azygos Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051009Y" = "1" /* Bypass Azygos Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"05100AY" = "1" /* Bypass Azygos Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"05100JY" = "1" /* Bypass Azygos Vein to Upper Vein with Synthetic Substitute, Open Approach */
"05100KY" = "1" /* Bypass Azygos Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"05100ZY" = "1" /* Bypass Azygos Vein to Upper Vein, Open Approach */
"051047Y" = "1" /* Bypass Azygos Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051049Y" = "1" /* Bypass Azygos Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"05104AY" = "1" /* Bypass Azygos Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"05104JY" = "1" /* Bypass Azygos Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05104KY" = "1" /* Bypass Azygos Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05104ZY" = "1" /* Bypass Azygos Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051107Y" = "1" /* Bypass Hemiazygos Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051109Y" = "1" /* Bypass Hemiazygos Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"05110AY" = "1" /* Bypass Hemiazygos Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"05110JY" = "1" /* Bypass Hemiazygos Vein to Upper Vein with Synthetic Substitute, Open Approach */
"05110KY" = "1" /* Bypass Hemiazygos Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"05110ZY" = "1" /* Bypass Hemiazygos Vein to Upper Vein, Open Approach */
"051147Y" = "1" /* Bypass Hemiazygos Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051149Y" = "1" /* Bypass Hemiazygos Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"05114AY" = "1" /* Bypass Hemiazygos Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"05114JY" = "1" /* Bypass Hemiazygos Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05114KY" = "1" /* Bypass Hemiazygos Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05114ZY" = "1" /* Bypass Hemiazygos Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051307Y" = "1" /* Bypass Right Innominate Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051309Y" = "1" /* Bypass Right Innominate Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"05130AY" = "1" /* Bypass Right Innominate Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"05130JY" = "1" /* Bypass Right Innominate Vein to Upper Vein with Synthetic Substitute, Open Approach */
"05130KY" = "1" /* Bypass Right Innominate Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"05130ZY" = "1" /* Bypass Right Innominate Vein to Upper Vein, Open Approach */
"051347Y" = "1" /* Bypass Right Innominate Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051349Y" = "1" /* Bypass Right Innominate Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"05134AY" = "1" /* Bypass Right Innominate Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"05134JY" = "1" /* Bypass Right Innominate Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05134KY" = "1" /* Bypass Right Innominate Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05134ZY" = "1" /* Bypass Right Innominate Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051407Y" = "1" /* Bypass Left Innominate Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051409Y" = "1" /* Bypass Left Innominate Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"05140AY" = "1" /* Bypass Left Innominate Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"05140JY" = "1" /* Bypass Left Innominate Vein to Upper Vein with Synthetic Substitute, Open Approach */
"05140KY" = "1" /* Bypass Left Innominate Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"05140ZY" = "1" /* Bypass Left Innominate Vein to Upper Vein, Open Approach */
"051447Y" = "1" /* Bypass Left Innominate Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051449Y" = "1" /* Bypass Left Innominate Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"05144AY" = "1" /* Bypass Left Innominate Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"05144JY" = "1" /* Bypass Left Innominate Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05144KY" = "1" /* Bypass Left Innominate Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05144ZY" = "1" /* Bypass Left Innominate Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051507Y" = "1" /* Bypass Right Subclavian Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051509Y" = "1" /* Bypass Right Subclavian Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"05150AY" = "1" /* Bypass Right Subclavian Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"05150JY" = "1" /* Bypass Right Subclavian Vein to Upper Vein with Synthetic Substitute, Open Approach */
"05150KY" = "1" /* Bypass Right Subclavian Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"05150ZY" = "1" /* Bypass Right Subclavian Vein to Upper Vein, Open Approach */
"051547Y" = "1" /* Bypass Right Subclavian Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051549Y" = "1" /* Bypass Right Subclavian Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"05154AY" = "1" /* Bypass Right Subclavian Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"05154JY" = "1" /* Bypass Right Subclavian Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05154KY" = "1" /* Bypass Right Subclavian Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05154ZY" = "1" /* Bypass Right Subclavian Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051607Y" = "1" /* Bypass Left Subclavian Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051609Y" = "1" /* Bypass Left Subclavian Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"05160AY" = "1" /* Bypass Left Subclavian Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"05160JY" = "1" /* Bypass Left Subclavian Vein to Upper Vein with Synthetic Substitute, Open Approach */
"05160KY" = "1" /* Bypass Left Subclavian Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"05160ZY" = "1" /* Bypass Left Subclavian Vein to Upper Vein, Open Approach */
"051647Y" = "1" /* Bypass Left Subclavian Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051649Y" = "1" /* Bypass Left Subclavian Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"05164AY" = "1" /* Bypass Left Subclavian Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"05164JY" = "1" /* Bypass Left Subclavian Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05164KY" = "1" /* Bypass Left Subclavian Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05164ZY" = "1" /* Bypass Left Subclavian Vein to Upper Vein, Percutaneous Endoscopic Approach */
"05500ZZ" = "1" /* Destruction of Azygos Vein, Open Approach */
"05504ZZ" = "1" /* Destruction of Azygos Vein, Percutaneous Endoscopic Approach */
"05510ZZ" = "1" /* Destruction of Hemiazygos Vein, Open Approach */
"05514ZZ" = "1" /* Destruction of Hemiazygos Vein, Percutaneous Endoscopic Approach */
"05530ZZ" = "1" /* Destruction of Right Innominate Vein, Open Approach */
"05534ZZ" = "1" /* Destruction of Right Innominate Vein, Percutaneous Endoscopic Approach */
"05540ZZ" = "1" /* Destruction of Left Innominate Vein, Open Approach */
"05544ZZ" = "1" /* Destruction of Left Innominate Vein, Percutaneous Endoscopic Approach */
"05550ZZ" = "1" /* Destruction of Right Subclavian Vein, Open Approach */
"05554ZZ" = "1" /* Destruction of Right Subclavian Vein, Percutaneous Endoscopic Approach */
"05560ZZ" = "1" /* Destruction of Left Subclavian Vein, Open Approach */
"05564ZZ" = "1" /* Destruction of Left Subclavian Vein, Percutaneous Endoscopic Approach */
"05B00ZZ" = "1" /* Excision of Azygos Vein, Open Approach */
"05B04ZZ" = "1" /* Excision of Azygos Vein, Percutaneous Endoscopic Approach */
"05B10ZZ" = "1" /* Excision of Hemiazygos Vein, Open Approach */
"05B14ZZ" = "1" /* Excision of Hemiazygos Vein, Percutaneous Endoscopic Approach */
"05B30ZZ" = "1" /* Excision of Right Innominate Vein, Open Approach */
"05B34ZZ" = "1" /* Excision of Right Innominate Vein, Percutaneous Endoscopic Approach */
"05B40ZZ" = "1" /* Excision of Left Innominate Vein, Open Approach */
"05B44ZZ" = "1" /* Excision of Left Innominate Vein, Percutaneous Endoscopic Approach */
"05B50ZZ" = "1" /* Excision of Right Subclavian Vein, Open Approach */
"05B54ZZ" = "1" /* Excision of Right Subclavian Vein, Percutaneous Endoscopic Approach */
"05B60ZZ" = "1" /* Excision of Left Subclavian Vein, Open Approach */
"05B64ZZ" = "1" /* Excision of Left Subclavian Vein, Percutaneous Endoscopic Approach */
"05C00ZZ" = "1" /* Extirpation of Matter from Azygos Vein, Open Approach */
"05C04ZZ" = "1" /* Extirpation of Matter from Azygos Vein, Percutaneous Endoscopic Approach */
"05C10ZZ" = "1" /* Extirpation of Matter from Hemiazygos Vein, Open Approach */
"05C14ZZ" = "1" /* Extirpation of Matter from Hemiazygos Vein, Percutaneous Endoscopic Approach */
"05C30ZZ" = "1" /* Extirpation of Matter from Right Innominate Vein, Open Approach */
"05C34ZZ" = "1" /* Extirpation of Matter from Right Innominate Vein, Percutaneous Endoscopic Approach */
"05C40ZZ" = "1" /* Extirpation of Matter from Left Innominate Vein, Open Approach */
"05C44ZZ" = "1" /* Extirpation of Matter from Left Innominate Vein, Percutaneous Endoscopic Approach */
"05C50ZZ" = "1" /* Extirpation of Matter from Right Subclavian Vein, Open Approach */
"05C54ZZ" = "1" /* Extirpation of Matter from Right Subclavian Vein, Percutaneous Endoscopic Approach */
"05C60ZZ" = "1" /* Extirpation of Matter from Left Subclavian Vein, Open Approach */
"05C64ZZ" = "1" /* Extirpation of Matter from Left Subclavian Vein, Percutaneous Endoscopic Approach */
"05L00CZ" = "1" /* Occlusion of Azygos Vein with Extraluminal Device, Open Approach */
"05L00DZ" = "1" /* Occlusion of Azygos Vein with Intraluminal Device, Open Approach */
"05L00ZZ" = "1" /* Occlusion of Azygos Vein, Open Approach */
"05L03CZ" = "1" /* Occlusion of Azygos Vein with Extraluminal Device, Percutaneous Approach */
"05L04CZ" = "1" /* Occlusion of Azygos Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L04DZ" = "1" /* Occlusion of Azygos Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L04ZZ" = "1" /* Occlusion of Azygos Vein, Percutaneous Endoscopic Approach */
"05L10CZ" = "1" /* Occlusion of Hemiazygos Vein with Extraluminal Device, Open Approach */
"05L10DZ" = "1" /* Occlusion of Hemiazygos Vein with Intraluminal Device, Open Approach */
"05L10ZZ" = "1" /* Occlusion of Hemiazygos Vein, Open Approach */
"05L13CZ" = "1" /* Occlusion of Hemiazygos Vein with Extraluminal Device, Percutaneous Approach */
"05L14CZ" = "1" /* Occlusion of Hemiazygos Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L14DZ" = "1" /* Occlusion of Hemiazygos Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L14ZZ" = "1" /* Occlusion of Hemiazygos Vein, Percutaneous Endoscopic Approach */
"05L30CZ" = "1" /* Occlusion of Right Innominate Vein with Extraluminal Device, Open Approach */
"05L30DZ" = "1" /* Occlusion of Right Innominate Vein with Intraluminal Device, Open Approach */
"05L30ZZ" = "1" /* Occlusion of Right Innominate Vein, Open Approach */
"05L33CZ" = "1" /* Occlusion of Right Innominate Vein with Extraluminal Device, Percutaneous Approach */
"05L34CZ" = "1" /* Occlusion of Right Innominate Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L34DZ" = "1" /* Occlusion of Right Innominate Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L34ZZ" = "1" /* Occlusion of Right Innominate Vein, Percutaneous Endoscopic Approach */
"05L40CZ" = "1" /* Occlusion of Left Innominate Vein with Extraluminal Device, Open Approach */
"05L40DZ" = "1" /* Occlusion of Left Innominate Vein with Intraluminal Device, Open Approach */
"05L40ZZ" = "1" /* Occlusion of Left Innominate Vein, Open Approach */
"05L43CZ" = "1" /* Occlusion of Left Innominate Vein with Extraluminal Device, Percutaneous Approach */
"05L44CZ" = "1" /* Occlusion of Left Innominate Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L44DZ" = "1" /* Occlusion of Left Innominate Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L44ZZ" = "1" /* Occlusion of Left Innominate Vein, Percutaneous Endoscopic Approach */
"05L50CZ" = "1" /* Occlusion of Right Subclavian Vein with Extraluminal Device, Open Approach */
"05L50DZ" = "1" /* Occlusion of Right Subclavian Vein with Intraluminal Device, Open Approach */
"05L50ZZ" = "1" /* Occlusion of Right Subclavian Vein, Open Approach */
"05L53CZ" = "1" /* Occlusion of Right Subclavian Vein with Extraluminal Device, Percutaneous Approach */
"05L54CZ" = "1" /* Occlusion of Right Subclavian Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L54DZ" = "1" /* Occlusion of Right Subclavian Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L54ZZ" = "1" /* Occlusion of Right Subclavian Vein, Percutaneous Endoscopic Approach */
"05L60CZ" = "1" /* Occlusion of Left Subclavian Vein with Extraluminal Device, Open Approach */
"05L60DZ" = "1" /* Occlusion of Left Subclavian Vein with Intraluminal Device, Open Approach */
"05L60ZZ" = "1" /* Occlusion of Left Subclavian Vein, Open Approach */
"05L63CZ" = "1" /* Occlusion of Left Subclavian Vein with Extraluminal Device, Percutaneous Approach */
"05L64CZ" = "1" /* Occlusion of Left Subclavian Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L64DZ" = "1" /* Occlusion of Left Subclavian Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L64ZZ" = "1" /* Occlusion of Left Subclavian Vein, Percutaneous Endoscopic Approach */
"05R007Z" = "1" /* Replacement of Azygos Vein with Autologous Tissue Substitute, Open Approach */
"05R00JZ" = "1" /* Replacement of Azygos Vein with Synthetic Substitute, Open Approach */
"05R00KZ" = "1" /* Replacement of Azygos Vein with Nonautologous Tissue Substitute, Open Approach */
"05R047Z" = "1" /* Replacement of Azygos Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R04JZ" = "1" /* Replacement of Azygos Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05R04KZ" = "1" /* Replacement of Azygos Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R107Z" = "1" /* Replacement of Hemiazygos Vein with Autologous Tissue Substitute, Open Approach */
"05R10JZ" = "1" /* Replacement of Hemiazygos Vein with Synthetic Substitute, Open Approach */
"05R10KZ" = "1" /* Replacement of Hemiazygos Vein with Nonautologous Tissue Substitute, Open Approach */
"05R147Z" = "1" /* Replacement of Hemiazygos Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R14JZ" = "1" /* Replacement of Hemiazygos Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05R14KZ" = "1" /* Replacement of Hemiazygos Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R307Z" = "1" /* Replacement of Right Innominate Vein with Autologous Tissue Substitute, Open Approach */
"05R30JZ" = "1" /* Replacement of Right Innominate Vein with Synthetic Substitute, Open Approach */
"05R30KZ" = "1" /* Replacement of Right Innominate Vein with Nonautologous Tissue Substitute, Open Approach */
"05R347Z" = "1" /* Replacement of Right Innominate Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R34JZ" = "1" /* Replacement of Right Innominate Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05R34KZ" = "1" /* Replacement of Right Innominate Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R407Z" = "1" /* Replacement of Left Innominate Vein with Autologous Tissue Substitute, Open Approach */
"05R40JZ" = "1" /* Replacement of Left Innominate Vein with Synthetic Substitute, Open Approach */
"05R40KZ" = "1" /* Replacement of Left Innominate Vein with Nonautologous Tissue Substitute, Open Approach */
"05R447Z" = "1" /* Replacement of Left Innominate Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R44JZ" = "1" /* Replacement of Left Innominate Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05R44KZ" = "1" /* Replacement of Left Innominate Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R507Z" = "1" /* Replacement of Right Subclavian Vein with Autologous Tissue Substitute, Open Approach */
"05R50JZ" = "1" /* Replacement of Right Subclavian Vein with Synthetic Substitute, Open Approach */
"05R50KZ" = "1" /* Replacement of Right Subclavian Vein with Nonautologous Tissue Substitute, Open Approach */
"05R547Z" = "1" /* Replacement of Right Subclavian Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R54JZ" = "1" /* Replacement of Right Subclavian Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05R54KZ" = "1" /* Replacement of Right Subclavian Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R607Z" = "1" /* Replacement of Left Subclavian Vein with Autologous Tissue Substitute, Open Approach */
"05R60JZ" = "1" /* Replacement of Left Subclavian Vein with Synthetic Substitute, Open Approach */
"05R60KZ" = "1" /* Replacement of Left Subclavian Vein with Nonautologous Tissue Substitute, Open Approach */
"05R647Z" = "1" /* Replacement of Left Subclavian Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R64JZ" = "1" /* Replacement of Left Subclavian Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05R64KZ" = "1" /* Replacement of Left Subclavian Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PT10ZZ" = "1" /* Resection of Right Rib, Open Approach */
"0PT20ZZ" = "1" /* Resection of Left Rib, Open Approach */
"0W9D00Z" = "1" /* Drainage of Pericardial Cavity with Drainage Device, Open Approach */
"0W9D0ZX" = "1" /* Drainage of Pericardial Cavity, Open Approach, Diagnostic */
"0W9D0ZZ" = "1" /* Drainage of Pericardial Cavity, Open Approach */
"0W9D30Z" = "1" /* Drainage of Pericardial Cavity with Drainage Device, Percutaneous Approach */
"0W9D3ZX" = "1" /* Drainage of Pericardial Cavity, Percutaneous Approach, Diagnostic */
"0W9D3ZZ" = "1" /* Drainage of Pericardial Cavity, Percutaneous Approach */
"0W9D40Z" = "1" /* Drainage of Pericardial Cavity with Drainage Device, Percutaneous Endoscopic Approach */
"0W9D4ZX" = "1" /* Drainage of Pericardial Cavity, Percutaneous Endoscopic Approach, Diagnostic */
"0W9D4ZZ" = "1" /* Drainage of Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WCD0ZZ" = "1" /* Extirpation of Matter from Pericardial Cavity, Open Approach */
"0WCD3ZZ" = "1" /* Extirpation of Matter from Pericardial Cavity, Percutaneous Approach */
"0WCD4ZZ" = "1" /* Extirpation of Matter from Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WFD0ZZ" = "1" /* Fragmentation in Pericardial Cavity, Open Approach */
"0WFD3ZZ" = "1" /* Fragmentation in Pericardial Cavity, Percutaneous Approach */
"0WFD4ZZ" = "1" /* Fragmentation in Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WFDXZZ" = "1" /* Fragmentation in Pericardial Cavity, External Approach */
"0WHD03Z" = "1" /* Insertion of Infusion Device into Pericardial Cavity, Open Approach */
"0WHD0YZ" = "1" /* Insertion of Other Device into Pericardial Cavity, Open Approach */
"0WHD33Z" = "1" /* Insertion of Infusion Device into Pericardial Cavity, Percutaneous Approach */
"0WHD3YZ" = "1" /* Insertion of Other Device into Pericardial Cavity, Percutaneous Approach */
"0WHD43Z" = "1" /* Insertion of Infusion Device into Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WHD4YZ" = "1" /* Insertion of Other Device into Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WPD00Z" = "1" /* Removal of Drainage Device from Pericardial Cavity, Open Approach */
"0WPD01Z" = "1" /* Removal of Radioactive Element from Pericardial Cavity, Open Approach */
"0WPD03Z" = "1" /* Removal of Infusion Device from Pericardial Cavity, Open Approach */
"0WPD0YZ" = "1" /* Removal of Other Device from Pericardial Cavity, Open Approach */
"0WPD30Z" = "1" /* Removal of Drainage Device from Pericardial Cavity, Percutaneous Approach */
"0WPD31Z" = "1" /* Removal of Radioactive Element from Pericardial Cavity, Percutaneous Approach */
"0WPD33Z" = "1" /* Removal of Infusion Device from Pericardial Cavity, Percutaneous Approach */
"0WPD3YZ" = "1" /* Removal of Other Device from Pericardial Cavity, Percutaneous Approach */
"0WPD40Z" = "1" /* Removal of Drainage Device from Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WPD41Z" = "1" /* Removal of Radioactive Element from Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WPD43Z" = "1" /* Removal of Infusion Device from Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WPD4YZ" = "1" /* Removal of Other Device from Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WWD00Z" = "1" /* Revision of Drainage Device in Pericardial Cavity, Open Approach */
"0WWD01Z" = "1" /* Revision of Radioactive Element in Pericardial Cavity, Open Approach */
"0WWD03Z" = "1" /* Revision of Infusion Device in Pericardial Cavity, Open Approach */
"0WWD0YZ" = "1" /* Revision of Other Device in Pericardial Cavity, Open Approach */
"0WWD30Z" = "1" /* Revision of Drainage Device in Pericardial Cavity, Percutaneous Approach */
"0WWD31Z" = "1" /* Revision of Radioactive Element in Pericardial Cavity, Percutaneous Approach */
"0WWD33Z" = "1" /* Revision of Infusion Device in Pericardial Cavity, Percutaneous Approach */
"0WWD3YZ" = "1" /* Revision of Other Device in Pericardial Cavity, Percutaneous Approach */
"0WWD40Z" = "1" /* Revision of Drainage Device in Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WWD41Z" = "1" /* Revision of Radioactive Element in Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WWD43Z" = "1" /* Revision of Infusion Device in Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WWD4YZ" = "1" /* Revision of Other Device in Pericardial Cavity, Percutaneous Endoscopic Approach */
"X2RF032" = "1" /* Replacement of Aortic Valve using Zooplastic Tissue, Rapid Deployment Technique, Open Approach, New Technology Group 2 */
"X2RF432" = "1" /* Replacement of Aortic Valve using Zooplastic Tissue, Rapid Deployment Technique, Percutaneous Endoscopic Approach, New Technology Group 2 */
Other = "0"
;

/* Procedure codeset HEMOTH2P last updated 161229 for ICD10 v70rev0 */
Value $HEMOTH2P
"009000Z" = "1" /* Drainage of Brain with Drainage Device, Open Approach */
"00900ZZ" = "1" /* Drainage of Brain, Open Approach */
"009030Z" = "1" /* Drainage of Brain with Drainage Device, Percutaneous Approach */
"00903ZZ" = "1" /* Drainage of Brain, Percutaneous Approach */
"009040Z" = "1" /* Drainage of Brain with Drainage Device, Percutaneous Endoscopic Approach */
"00904ZZ" = "1" /* Drainage of Brain, Percutaneous Endoscopic Approach */
"009100Z" = "1" /* Drainage of Cerebral Meninges with Drainage Device, Open Approach */
"00910ZZ" = "1" /* Drainage of Cerebral Meninges, Open Approach */
"009200Z" = "1" /* Drainage of Dura Mater with Drainage Device, Open Approach */
"00920ZZ" = "1" /* Drainage of Dura Mater, Open Approach */
"009300Z" = "1" /* Drainage of Epidural Space with Drainage Device, Open Approach */
"00930ZZ" = "1" /* Drainage of Epidural Space, Open Approach */
"009330Z" = "1" /* Drainage of Epidural Space with Drainage Device, Percutaneous Approach */
"00933ZZ" = "1" /* Drainage of Epidural Space, Percutaneous Approach */
"009340Z" = "1" /* Drainage of Epidural Space with Drainage Device, Percutaneous Endoscopic Approach */
"00934ZZ" = "1" /* Drainage of Epidural Space, Percutaneous Endoscopic Approach */
"009400Z" = "1" /* Drainage of Subdural Space with Drainage Device, Open Approach */
"00940ZZ" = "1" /* Drainage of Subdural Space, Open Approach */
"009500Z" = "1" /* Drainage of Subarachnoid Space with Drainage Device, Open Approach */
"00950ZZ" = "1" /* Drainage of Subarachnoid Space, Open Approach */
"00960ZZ" = "1" /* Drainage of Cerebral Ventricle, Open Approach */
"009700Z" = "1" /* Drainage of Cerebral Hemisphere with Drainage Device, Open Approach */
"00970ZZ" = "1" /* Drainage of Cerebral Hemisphere, Open Approach */
"009730Z" = "1" /* Drainage of Cerebral Hemisphere with Drainage Device, Percutaneous Approach */
"00973ZZ" = "1" /* Drainage of Cerebral Hemisphere, Percutaneous Approach */
"009740Z" = "1" /* Drainage of Cerebral Hemisphere with Drainage Device, Percutaneous Endoscopic Approach */
"00974ZZ" = "1" /* Drainage of Cerebral Hemisphere, Percutaneous Endoscopic Approach */
"009B00Z" = "1" /* Drainage of Pons with Drainage Device, Open Approach */
"009B0ZZ" = "1" /* Drainage of Pons, Open Approach */
"009B30Z" = "1" /* Drainage of Pons with Drainage Device, Percutaneous Approach */
"009B3ZZ" = "1" /* Drainage of Pons, Percutaneous Approach */
"009B40Z" = "1" /* Drainage of Pons with Drainage Device, Percutaneous Endoscopic Approach */
"009B4ZZ" = "1" /* Drainage of Pons, Percutaneous Endoscopic Approach */
"009C00Z" = "1" /* Drainage of Cerebellum with Drainage Device, Open Approach */
"009C0ZZ" = "1" /* Drainage of Cerebellum, Open Approach */
"009C30Z" = "1" /* Drainage of Cerebellum with Drainage Device, Percutaneous Approach */
"009C3ZZ" = "1" /* Drainage of Cerebellum, Percutaneous Approach */
"009C40Z" = "1" /* Drainage of Cerebellum with Drainage Device, Percutaneous Endoscopic Approach */
"009C4ZZ" = "1" /* Drainage of Cerebellum, Percutaneous Endoscopic Approach */
"009D00Z" = "1" /* Drainage of Medulla Oblongata with Drainage Device, Open Approach */
"009D0ZZ" = "1" /* Drainage of Medulla Oblongata, Open Approach */
"009D30Z" = "1" /* Drainage of Medulla Oblongata with Drainage Device, Percutaneous Approach */
"009D3ZZ" = "1" /* Drainage of Medulla Oblongata, Percutaneous Approach */
"009D40Z" = "1" /* Drainage of Medulla Oblongata with Drainage Device, Percutaneous Endoscopic Approach */
"009D4ZZ" = "1" /* Drainage of Medulla Oblongata, Percutaneous Endoscopic Approach */
"009T00Z" = "1" /* Drainage of Spinal Meninges with Drainage Device, Open Approach */
"009T0ZZ" = "1" /* Drainage of Spinal Meninges, Open Approach */
"009T30Z" = "1" /* Drainage of Spinal Meninges with Drainage Device, Percutaneous Approach */
"009T3ZZ" = "1" /* Drainage of Spinal Meninges, Percutaneous Approach */
"009T40Z" = "1" /* Drainage of Spinal Meninges with Drainage Device, Percutaneous Endoscopic Approach */
"009T4ZZ" = "1" /* Drainage of Spinal Meninges, Percutaneous Endoscopic Approach */
"009U00Z" = "1" /* Drainage of Spinal Canal with Drainage Device, Open Approach */
"009U0ZZ" = "1" /* Drainage of Spinal Canal, Open Approach */
"009W00Z" = "1" /* Drainage of Cervical Spinal Cord with Drainage Device, Open Approach */
"009W0ZZ" = "1" /* Drainage of Cervical Spinal Cord, Open Approach */
"009W30Z" = "1" /* Drainage of Cervical Spinal Cord with Drainage Device, Percutaneous Approach */
"009W3ZZ" = "1" /* Drainage of Cervical Spinal Cord, Percutaneous Approach */
"009W40Z" = "1" /* Drainage of Cervical Spinal Cord with Drainage Device, Percutaneous Endoscopic Approach */
"009W4ZZ" = "1" /* Drainage of Cervical Spinal Cord, Percutaneous Endoscopic Approach */
"009X00Z" = "1" /* Drainage of Thoracic Spinal Cord with Drainage Device, Open Approach */
"009X0ZZ" = "1" /* Drainage of Thoracic Spinal Cord, Open Approach */
"009X30Z" = "1" /* Drainage of Thoracic Spinal Cord with Drainage Device, Percutaneous Approach */
"009X3ZZ" = "1" /* Drainage of Thoracic Spinal Cord, Percutaneous Approach */
"009X40Z" = "1" /* Drainage of Thoracic Spinal Cord with Drainage Device, Percutaneous Endoscopic Approach */
"009X4ZZ" = "1" /* Drainage of Thoracic Spinal Cord, Percutaneous Endoscopic Approach */
"009Y00Z" = "1" /* Drainage of Lumbar Spinal Cord with Drainage Device, Open Approach */
"009Y0ZZ" = "1" /* Drainage of Lumbar Spinal Cord, Open Approach */
"009Y30Z" = "1" /* Drainage of Lumbar Spinal Cord with Drainage Device, Percutaneous Approach */
"009Y3ZZ" = "1" /* Drainage of Lumbar Spinal Cord, Percutaneous Approach */
"009Y40Z" = "1" /* Drainage of Lumbar Spinal Cord with Drainage Device, Percutaneous Endoscopic Approach */
"009Y4ZZ" = "1" /* Drainage of Lumbar Spinal Cord, Percutaneous Endoscopic Approach */
"00C00ZZ" = "1" /* Extirpation of Matter from Brain, Open Approach */
"00C03ZZ" = "1" /* Extirpation of Matter from Brain, Percutaneous Approach */
"00C04ZZ" = "1" /* Extirpation of Matter from Brain, Percutaneous Endoscopic Approach */
"00C10ZZ" = "1" /* Extirpation of Matter from Cerebral Meninges, Open Approach */
"00C13ZZ" = "1" /* Extirpation of Matter from Cerebral Meninges, Percutaneous Approach */
"00C14ZZ" = "1" /* Extirpation of Matter from Cerebral Meninges, Percutaneous Endoscopic Approach */
"00C20ZZ" = "1" /* Extirpation of Matter from Dura Mater, Open Approach */
"00C23ZZ" = "1" /* Extirpation of Matter from Dura Mater, Percutaneous Approach */
"00C24ZZ" = "1" /* Extirpation of Matter from Dura Mater, Percutaneous Endoscopic Approach */
"00C30ZZ" = "1" /* Extirpation of Matter from Epidural Space, Open Approach */
"00C33ZZ" = "1" /* Extirpation of Matter from Epidural Space, Percutaneous Approach */
"00C34ZZ" = "1" /* Extirpation of Matter from Epidural Space, Percutaneous Endoscopic Approach */
"00C40ZZ" = "1" /* Extirpation of Matter from Subdural Space, Open Approach */
"00C43ZZ" = "1" /* Extirpation of Matter from Subdural Space, Percutaneous Approach */
"00C44ZZ" = "1" /* Extirpation of Matter from Subdural Space, Percutaneous Endoscopic Approach */
"00C50ZZ" = "1" /* Extirpation of Matter from Subarachnoid Space, Open Approach */
"00C53ZZ" = "1" /* Extirpation of Matter from Subarachnoid Space, Percutaneous Approach */
"00C54ZZ" = "1" /* Extirpation of Matter from Subarachnoid Space, Percutaneous Endoscopic Approach */
"00C60ZZ" = "1" /* Extirpation of Matter from Cerebral Ventricle, Open Approach */
"00C63ZZ" = "1" /* Extirpation of Matter from Cerebral Ventricle, Percutaneous Approach */
"00C64ZZ" = "1" /* Extirpation of Matter from Cerebral Ventricle, Percutaneous Endoscopic Approach */
"00C70ZZ" = "1" /* Extirpation of Matter from Cerebral Hemisphere, Open Approach */
"00C73ZZ" = "1" /* Extirpation of Matter from Cerebral Hemisphere, Percutaneous Approach */
"00C74ZZ" = "1" /* Extirpation of Matter from Cerebral Hemisphere, Percutaneous Endoscopic Approach */
"00CB0ZZ" = "1" /* Extirpation of Matter from Pons, Open Approach */
"00CB3ZZ" = "1" /* Extirpation of Matter from Pons, Percutaneous Approach */
"00CB4ZZ" = "1" /* Extirpation of Matter from Pons, Percutaneous Endoscopic Approach */
"00CC0ZZ" = "1" /* Extirpation of Matter from Cerebellum, Open Approach */
"00CC3ZZ" = "1" /* Extirpation of Matter from Cerebellum, Percutaneous Approach */
"00CC4ZZ" = "1" /* Extirpation of Matter from Cerebellum, Percutaneous Endoscopic Approach */
"00CD0ZZ" = "1" /* Extirpation of Matter from Medulla Oblongata, Open Approach */
"00CD3ZZ" = "1" /* Extirpation of Matter from Medulla Oblongata, Percutaneous Approach */
"00CD4ZZ" = "1" /* Extirpation of Matter from Medulla Oblongata, Percutaneous Endoscopic Approach */
"00NW0ZZ" = "1" /* Release Cervical Spinal Cord, Open Approach */
"00NW3ZZ" = "1" /* Release Cervical Spinal Cord, Percutaneous Approach */
"00NW4ZZ" = "1" /* Release Cervical Spinal Cord, Percutaneous Endoscopic Approach */
"00NX0ZZ" = "1" /* Release Thoracic Spinal Cord, Open Approach */
"00NX3ZZ" = "1" /* Release Thoracic Spinal Cord, Percutaneous Approach */
"00NX4ZZ" = "1" /* Release Thoracic Spinal Cord, Percutaneous Endoscopic Approach */
"00NY0ZZ" = "1" /* Release Lumbar Spinal Cord, Open Approach */
"00NY3ZZ" = "1" /* Release Lumbar Spinal Cord, Percutaneous Approach */
"00NY4ZZ" = "1" /* Release Lumbar Spinal Cord, Percutaneous Endoscopic Approach */
"00W000Z" = "1" /* Revision of Drainage Device in Brain, Open Approach */
"00W030Z" = "1" /* Revision of Drainage Device in Brain, Percutaneous Approach */
"00W040Z" = "1" /* Revision of Drainage Device in Brain, Percutaneous Endoscopic Approach */
"00W600Z" = "1" /* Revision of Drainage Device in Cerebral Ventricle, Open Approach */
"00W630Z" = "1" /* Revision of Drainage Device in Cerebral Ventricle, Percutaneous Approach */
"00W640Z" = "1" /* Revision of Drainage Device in Cerebral Ventricle, Percutaneous Endoscopic Approach */
"01N50ZZ" = "1" /* Release Median Nerve, Open Approach */
"01N53ZZ" = "1" /* Release Median Nerve, Percutaneous Approach */
"01N54ZZ" = "1" /* Release Median Nerve, Percutaneous Endoscopic Approach */
"01NG0ZZ" = "1" /* Release Tibial Nerve, Open Approach */
"01NG3ZZ" = "1" /* Release Tibial Nerve, Percutaneous Approach */
"01NG4ZZ" = "1" /* Release Tibial Nerve, Percutaneous Endoscopic Approach */
"02540ZZ" = "1" /* Destruction of Coronary Vein, Open Approach */
"02543ZZ" = "1" /* Destruction of Coronary Vein, Percutaneous Approach */
"02544ZZ" = "1" /* Destruction of Coronary Vein, Percutaneous Endoscopic Approach */
"02B40ZZ" = "1" /* Excision of Coronary Vein, Open Approach */
"02B43ZZ" = "1" /* Excision of Coronary Vein, Percutaneous Approach */
"02B44ZZ" = "1" /* Excision of Coronary Vein, Percutaneous Endoscopic Approach */
"02LS0CZ" = "1" /* Occlusion of Right Pulmonary Vein with Extraluminal Device, Open Approach */
"02LS0DZ" = "1" /* Occlusion of Right Pulmonary Vein with Intraluminal Device, Open Approach */
"02LS0ZZ" = "1" /* Occlusion of Right Pulmonary Vein, Open Approach */
"02LS3CZ" = "1" /* Occlusion of Right Pulmonary Vein with Extraluminal Device, Percutaneous Approach */
"02LS3DZ" = "1" /* Occlusion of Right Pulmonary Vein with Intraluminal Device, Percutaneous Approach */
"02LS3ZZ" = "1" /* Occlusion of Right Pulmonary Vein, Percutaneous Approach */
"02LS4CZ" = "1" /* Occlusion of Right Pulmonary Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"02LS4DZ" = "1" /* Occlusion of Right Pulmonary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"02LS4ZZ" = "1" /* Occlusion of Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"02LT0CZ" = "1" /* Occlusion of Left Pulmonary Vein with Extraluminal Device, Open Approach */
"02LT0DZ" = "1" /* Occlusion of Left Pulmonary Vein with Intraluminal Device, Open Approach */
"02LT0ZZ" = "1" /* Occlusion of Left Pulmonary Vein, Open Approach */
"02LT3CZ" = "1" /* Occlusion of Left Pulmonary Vein with Extraluminal Device, Percutaneous Approach */
"02LT3DZ" = "1" /* Occlusion of Left Pulmonary Vein with Intraluminal Device, Percutaneous Approach */
"02LT3ZZ" = "1" /* Occlusion of Left Pulmonary Vein, Percutaneous Approach */
"02LT4CZ" = "1" /* Occlusion of Left Pulmonary Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"02LT4DZ" = "1" /* Occlusion of Left Pulmonary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"02LT4ZZ" = "1" /* Occlusion of Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"02LV0CZ" = "1" /* Occlusion of Superior Vena Cava with Extraluminal Device, Open Approach */
"02LV0DZ" = "1" /* Occlusion of Superior Vena Cava with Intraluminal Device, Open Approach */
"02LV0ZZ" = "1" /* Occlusion of Superior Vena Cava, Open Approach */
"02LV3CZ" = "1" /* Occlusion of Superior Vena Cava with Extraluminal Device, Percutaneous Approach */
"02LV3DZ" = "1" /* Occlusion of Superior Vena Cava with Intraluminal Device, Percutaneous Approach */
"02LV3ZZ" = "1" /* Occlusion of Superior Vena Cava, Percutaneous Approach */
"02LV4CZ" = "1" /* Occlusion of Superior Vena Cava with Extraluminal Device, Percutaneous Endoscopic Approach */
"02LV4DZ" = "1" /* Occlusion of Superior Vena Cava with Intraluminal Device, Percutaneous Endoscopic Approach */
"02LV4ZZ" = "1" /* Occlusion of Superior Vena Cava, Percutaneous Endoscopic Approach */
"02Q00ZZ" = "1" /* Repair Coronary Artery, One Artery, Open Approach */
"02Q03ZZ" = "1" /* Repair Coronary Artery, One Artery, Percutaneous Approach */
"02Q04ZZ" = "1" /* Repair Coronary Artery, One Artery, Percutaneous Endoscopic Approach */
"02Q10ZZ" = "1" /* Repair Coronary Artery, Two Arteries, Open Approach */
"02Q13ZZ" = "1" /* Repair Coronary Artery, Two Arteries, Percutaneous Approach */
"02Q14ZZ" = "1" /* Repair Coronary Artery, Two Arteries, Percutaneous Endoscopic Approach */
"02Q20ZZ" = "1" /* Repair Coronary Artery, Three Arteries, Open Approach */
"02Q23ZZ" = "1" /* Repair Coronary Artery, Three Arteries, Percutaneous Approach */
"02Q24ZZ" = "1" /* Repair Coronary Artery, Three Arteries, Percutaneous Endoscopic Approach */
"02Q30ZZ" = "1" /* Repair Coronary Artery, Four or More Arteries, Open Approach */
"02Q33ZZ" = "1" /* Repair Coronary Artery, Four or More Arteries, Percutaneous Approach */
"02Q34ZZ" = "1" /* Repair Coronary Artery, Four or More Arteries, Percutaneous Endoscopic Approach */
"02Q40ZZ" = "1" /* Repair Coronary Vein, Open Approach */
"02Q43ZZ" = "1" /* Repair Coronary Vein, Percutaneous Approach */
"02Q44ZZ" = "1" /* Repair Coronary Vein, Percutaneous Endoscopic Approach */
"02QA0ZZ" = "1" /* Repair Heart, Open Approach */
"02QA3ZZ" = "1" /* Repair Heart, Percutaneous Approach */
"02QA4ZZ" = "1" /* Repair Heart, Percutaneous Endoscopic Approach */
"02QB0ZZ" = "1" /* Repair Right Heart, Open Approach */
"02QC0ZZ" = "1" /* Repair Left Heart, Open Approach */
"02QP0ZZ" = "1" /* Repair Pulmonary Trunk, Open Approach */
"02QP3ZZ" = "1" /* Repair Pulmonary Trunk, Percutaneous Approach */
"02QP4ZZ" = "1" /* Repair Pulmonary Trunk, Percutaneous Endoscopic Approach */
"02QQ0ZZ" = "1" /* Repair Right Pulmonary Artery, Open Approach */
"02QQ3ZZ" = "1" /* Repair Right Pulmonary Artery, Percutaneous Approach */
"02QQ4ZZ" = "1" /* Repair Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"02QR0ZZ" = "1" /* Repair Left Pulmonary Artery, Open Approach */
"02QR3ZZ" = "1" /* Repair Left Pulmonary Artery, Percutaneous Approach */
"02QR4ZZ" = "1" /* Repair Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"02QS0ZZ" = "1" /* Repair Right Pulmonary Vein, Open Approach */
"02QS3ZZ" = "1" /* Repair Right Pulmonary Vein, Percutaneous Approach */
"02QS4ZZ" = "1" /* Repair Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"02QT0ZZ" = "1" /* Repair Left Pulmonary Vein, Open Approach */
"02QT3ZZ" = "1" /* Repair Left Pulmonary Vein, Percutaneous Approach */
"02QT4ZZ" = "1" /* Repair Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"02QV0ZZ" = "1" /* Repair Superior Vena Cava, Open Approach */
"02QV3ZZ" = "1" /* Repair Superior Vena Cava, Percutaneous Approach */
"02QV4ZZ" = "1" /* Repair Superior Vena Cava, Percutaneous Endoscopic Approach */
"02QW0ZZ" = "1" /* Repair Thoracic Aorta, Descending, Open Approach */
"02QW3ZZ" = "1" /* Repair Thoracic Aorta, Descending, Percutaneous Approach */
"02QW4ZZ" = "1" /* Repair Thoracic Aorta, Descending, Percutaneous Endoscopic Approach */
"02QX0ZZ" = "1" /* Repair Thoracic Aorta, Ascending/Arch, Open Approach */
"02QX3ZZ" = "1" /* Repair Thoracic Aorta, Ascending/Arch, Percutaneous Approach */
"02QX4ZZ" = "1" /* Repair Thoracic Aorta, Ascending/Arch, Percutaneous Endoscopic Approach */
"02U70JZ" = "1" /* Supplement Left Atrium with Synthetic Substitute, Open Approach */
"02WA08Z" = "1" /* Revision of Zooplastic Tissue in Heart, Open Approach */
"02WA0DZ" = "1" /* Revision of Intraluminal Device in Heart, Open Approach */
"02WA0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Heart, Open Approach */
"02WA38Z" = "1" /* Revision of Zooplastic Tissue in Heart, Percutaneous Approach */
"02WA3DZ" = "1" /* Revision of Intraluminal Device in Heart, Percutaneous Approach */
"02WA3JZ" = "1" /* Revision of Synthetic Substitute in Heart, Percutaneous Approach */
"02WA3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Heart, Percutaneous Approach */
"02WA48Z" = "1" /* Revision of Zooplastic Tissue in Heart, Percutaneous Endoscopic Approach */
"02WA4DZ" = "1" /* Revision of Intraluminal Device in Heart, Percutaneous Endoscopic Approach */
"02WA4JZ" = "1" /* Revision of Synthetic Substitute in Heart, Percutaneous Endoscopic Approach */
"02WA4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Heart, Percutaneous Endoscopic Approach */
"02WY08Z" = "1" /* Revision of Zooplastic Tissue in Great Vessel, Open Approach */
"02WY0DZ" = "1" /* Revision of Intraluminal Device in Great Vessel, Open Approach */
"02WY0JZ" = "1" /* Revision of Synthetic Substitute in Great Vessel, Open Approach */
"02WY0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Great Vessel, Open Approach */
"02WY38Z" = "1" /* Revision of Zooplastic Tissue in Great Vessel, Percutaneous Approach */
"02WY3DZ" = "1" /* Revision of Intraluminal Device in Great Vessel, Percutaneous Approach */
"02WY3JZ" = "1" /* Revision of Synthetic Substitute in Great Vessel, Percutaneous Approach */
"02WY3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Great Vessel, Percutaneous Approach */
"02WY48Z" = "1" /* Revision of Zooplastic Tissue in Great Vessel, Percutaneous Endoscopic Approach */
"02WY4DZ" = "1" /* Revision of Intraluminal Device in Great Vessel, Percutaneous Endoscopic Approach */
"02WY4JZ" = "1" /* Revision of Synthetic Substitute in Great Vessel, Percutaneous Endoscopic Approach */
"02WY4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Great Vessel, Percutaneous Endoscopic Approach */
"03L00CZ" = "1" /* Occlusion of Right Internal Mammary Artery with Extraluminal Device, Open Approach */
"03L00DZ" = "1" /* Occlusion of Right Internal Mammary Artery with Intraluminal Device, Open Approach */
"03L00ZZ" = "1" /* Occlusion of Right Internal Mammary Artery, Open Approach */
"03L03CZ" = "1" /* Occlusion of Right Internal Mammary Artery with Extraluminal Device, Percutaneous Approach */
"03L03DZ" = "1" /* Occlusion of Right Internal Mammary Artery with Intraluminal Device, Percutaneous Approach */
"03L03ZZ" = "1" /* Occlusion of Right Internal Mammary Artery, Percutaneous Approach */
"03L04CZ" = "1" /* Occlusion of Right Internal Mammary Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L04DZ" = "1" /* Occlusion of Right Internal Mammary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L04ZZ" = "1" /* Occlusion of Right Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03L10CZ" = "1" /* Occlusion of Left Internal Mammary Artery with Extraluminal Device, Open Approach */
"03L10DZ" = "1" /* Occlusion of Left Internal Mammary Artery with Intraluminal Device, Open Approach */
"03L10ZZ" = "1" /* Occlusion of Left Internal Mammary Artery, Open Approach */
"03L13CZ" = "1" /* Occlusion of Left Internal Mammary Artery with Extraluminal Device, Percutaneous Approach */
"03L13DZ" = "1" /* Occlusion of Left Internal Mammary Artery with Intraluminal Device, Percutaneous Approach */
"03L13ZZ" = "1" /* Occlusion of Left Internal Mammary Artery, Percutaneous Approach */
"03L14CZ" = "1" /* Occlusion of Left Internal Mammary Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L14DZ" = "1" /* Occlusion of Left Internal Mammary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L14ZZ" = "1" /* Occlusion of Left Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03L20CZ" = "1" /* Occlusion of Innominate Artery with Extraluminal Device, Open Approach */
"03L20DZ" = "1" /* Occlusion of Innominate Artery with Intraluminal Device, Open Approach */
"03L20ZZ" = "1" /* Occlusion of Innominate Artery, Open Approach */
"03L23CZ" = "1" /* Occlusion of Innominate Artery with Extraluminal Device, Percutaneous Approach */
"03L23DZ" = "1" /* Occlusion of Innominate Artery with Intraluminal Device, Percutaneous Approach */
"03L23ZZ" = "1" /* Occlusion of Innominate Artery, Percutaneous Approach */
"03L24CZ" = "1" /* Occlusion of Innominate Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L24DZ" = "1" /* Occlusion of Innominate Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L24ZZ" = "1" /* Occlusion of Innominate Artery, Percutaneous Endoscopic Approach */
"03L30CZ" = "1" /* Occlusion of Right Subclavian Artery with Extraluminal Device, Open Approach */
"03L30DZ" = "1" /* Occlusion of Right Subclavian Artery with Intraluminal Device, Open Approach */
"03L30ZZ" = "1" /* Occlusion of Right Subclavian Artery, Open Approach */
"03L33CZ" = "1" /* Occlusion of Right Subclavian Artery with Extraluminal Device, Percutaneous Approach */
"03L33DZ" = "1" /* Occlusion of Right Subclavian Artery with Intraluminal Device, Percutaneous Approach */
"03L33ZZ" = "1" /* Occlusion of Right Subclavian Artery, Percutaneous Approach */
"03L34CZ" = "1" /* Occlusion of Right Subclavian Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L34DZ" = "1" /* Occlusion of Right Subclavian Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L34ZZ" = "1" /* Occlusion of Right Subclavian Artery, Percutaneous Endoscopic Approach */
"03L40CZ" = "1" /* Occlusion of Left Subclavian Artery with Extraluminal Device, Open Approach */
"03L40DZ" = "1" /* Occlusion of Left Subclavian Artery with Intraluminal Device, Open Approach */
"03L40ZZ" = "1" /* Occlusion of Left Subclavian Artery, Open Approach */
"03L43CZ" = "1" /* Occlusion of Left Subclavian Artery with Extraluminal Device, Percutaneous Approach */
"03L43DZ" = "1" /* Occlusion of Left Subclavian Artery with Intraluminal Device, Percutaneous Approach */
"03L43ZZ" = "1" /* Occlusion of Left Subclavian Artery, Percutaneous Approach */
"03L44CZ" = "1" /* Occlusion of Left Subclavian Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L44DZ" = "1" /* Occlusion of Left Subclavian Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L44ZZ" = "1" /* Occlusion of Left Subclavian Artery, Percutaneous Endoscopic Approach */
"03L50CZ" = "1" /* Occlusion of Right Axillary Artery with Extraluminal Device, Open Approach */
"03L50DZ" = "1" /* Occlusion of Right Axillary Artery with Intraluminal Device, Open Approach */
"03L50ZZ" = "1" /* Occlusion of Right Axillary Artery, Open Approach */
"03L53CZ" = "1" /* Occlusion of Right Axillary Artery with Extraluminal Device, Percutaneous Approach */
"03L53DZ" = "1" /* Occlusion of Right Axillary Artery with Intraluminal Device, Percutaneous Approach */
"03L53ZZ" = "1" /* Occlusion of Right Axillary Artery, Percutaneous Approach */
"03L54CZ" = "1" /* Occlusion of Right Axillary Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L54DZ" = "1" /* Occlusion of Right Axillary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L54ZZ" = "1" /* Occlusion of Right Axillary Artery, Percutaneous Endoscopic Approach */
"03L60CZ" = "1" /* Occlusion of Left Axillary Artery with Extraluminal Device, Open Approach */
"03L60DZ" = "1" /* Occlusion of Left Axillary Artery with Intraluminal Device, Open Approach */
"03L60ZZ" = "1" /* Occlusion of Left Axillary Artery, Open Approach */
"03L63CZ" = "1" /* Occlusion of Left Axillary Artery with Extraluminal Device, Percutaneous Approach */
"03L63DZ" = "1" /* Occlusion of Left Axillary Artery with Intraluminal Device, Percutaneous Approach */
"03L63ZZ" = "1" /* Occlusion of Left Axillary Artery, Percutaneous Approach */
"03L64CZ" = "1" /* Occlusion of Left Axillary Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L64DZ" = "1" /* Occlusion of Left Axillary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L64ZZ" = "1" /* Occlusion of Left Axillary Artery, Percutaneous Endoscopic Approach */
"03L70CZ" = "1" /* Occlusion of Right Brachial Artery with Extraluminal Device, Open Approach */
"03L70DZ" = "1" /* Occlusion of Right Brachial Artery with Intraluminal Device, Open Approach */
"03L70ZZ" = "1" /* Occlusion of Right Brachial Artery, Open Approach */
"03L73CZ" = "1" /* Occlusion of Right Brachial Artery with Extraluminal Device, Percutaneous Approach */
"03L73DZ" = "1" /* Occlusion of Right Brachial Artery with Intraluminal Device, Percutaneous Approach */
"03L73ZZ" = "1" /* Occlusion of Right Brachial Artery, Percutaneous Approach */
"03L74CZ" = "1" /* Occlusion of Right Brachial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L74DZ" = "1" /* Occlusion of Right Brachial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L74ZZ" = "1" /* Occlusion of Right Brachial Artery, Percutaneous Endoscopic Approach */
"03L80CZ" = "1" /* Occlusion of Left Brachial Artery with Extraluminal Device, Open Approach */
"03L80DZ" = "1" /* Occlusion of Left Brachial Artery with Intraluminal Device, Open Approach */
"03L80ZZ" = "1" /* Occlusion of Left Brachial Artery, Open Approach */
"03L83CZ" = "1" /* Occlusion of Left Brachial Artery with Extraluminal Device, Percutaneous Approach */
"03L83DZ" = "1" /* Occlusion of Left Brachial Artery with Intraluminal Device, Percutaneous Approach */
"03L83ZZ" = "1" /* Occlusion of Left Brachial Artery, Percutaneous Approach */
"03L84CZ" = "1" /* Occlusion of Left Brachial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L84DZ" = "1" /* Occlusion of Left Brachial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L84ZZ" = "1" /* Occlusion of Left Brachial Artery, Percutaneous Endoscopic Approach */
"03L90CZ" = "1" /* Occlusion of Right Ulnar Artery with Extraluminal Device, Open Approach */
"03L90DZ" = "1" /* Occlusion of Right Ulnar Artery with Intraluminal Device, Open Approach */
"03L90ZZ" = "1" /* Occlusion of Right Ulnar Artery, Open Approach */
"03L93CZ" = "1" /* Occlusion of Right Ulnar Artery with Extraluminal Device, Percutaneous Approach */
"03L93DZ" = "1" /* Occlusion of Right Ulnar Artery with Intraluminal Device, Percutaneous Approach */
"03L93ZZ" = "1" /* Occlusion of Right Ulnar Artery, Percutaneous Approach */
"03L94CZ" = "1" /* Occlusion of Right Ulnar Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L94DZ" = "1" /* Occlusion of Right Ulnar Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L94ZZ" = "1" /* Occlusion of Right Ulnar Artery, Percutaneous Endoscopic Approach */
"03LA0CZ" = "1" /* Occlusion of Left Ulnar Artery with Extraluminal Device, Open Approach */
"03LA0DZ" = "1" /* Occlusion of Left Ulnar Artery with Intraluminal Device, Open Approach */
"03LA0ZZ" = "1" /* Occlusion of Left Ulnar Artery, Open Approach */
"03LA3CZ" = "1" /* Occlusion of Left Ulnar Artery with Extraluminal Device, Percutaneous Approach */
"03LA3DZ" = "1" /* Occlusion of Left Ulnar Artery with Intraluminal Device, Percutaneous Approach */
"03LA3ZZ" = "1" /* Occlusion of Left Ulnar Artery, Percutaneous Approach */
"03LA4CZ" = "1" /* Occlusion of Left Ulnar Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LA4DZ" = "1" /* Occlusion of Left Ulnar Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LA4ZZ" = "1" /* Occlusion of Left Ulnar Artery, Percutaneous Endoscopic Approach */
"03LB0CZ" = "1" /* Occlusion of Right Radial Artery with Extraluminal Device, Open Approach */
"03LB0DZ" = "1" /* Occlusion of Right Radial Artery with Intraluminal Device, Open Approach */
"03LB0ZZ" = "1" /* Occlusion of Right Radial Artery, Open Approach */
"03LB3CZ" = "1" /* Occlusion of Right Radial Artery with Extraluminal Device, Percutaneous Approach */
"03LB3DZ" = "1" /* Occlusion of Right Radial Artery with Intraluminal Device, Percutaneous Approach */
"03LB3ZZ" = "1" /* Occlusion of Right Radial Artery, Percutaneous Approach */
"03LB4CZ" = "1" /* Occlusion of Right Radial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LB4DZ" = "1" /* Occlusion of Right Radial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LB4ZZ" = "1" /* Occlusion of Right Radial Artery, Percutaneous Endoscopic Approach */
"03LC0CZ" = "1" /* Occlusion of Left Radial Artery with Extraluminal Device, Open Approach */
"03LC0DZ" = "1" /* Occlusion of Left Radial Artery with Intraluminal Device, Open Approach */
"03LC0ZZ" = "1" /* Occlusion of Left Radial Artery, Open Approach */
"03LC3CZ" = "1" /* Occlusion of Left Radial Artery with Extraluminal Device, Percutaneous Approach */
"03LC3DZ" = "1" /* Occlusion of Left Radial Artery with Intraluminal Device, Percutaneous Approach */
"03LC3ZZ" = "1" /* Occlusion of Left Radial Artery, Percutaneous Approach */
"03LC4CZ" = "1" /* Occlusion of Left Radial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LC4DZ" = "1" /* Occlusion of Left Radial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LC4ZZ" = "1" /* Occlusion of Left Radial Artery, Percutaneous Endoscopic Approach */
"03LD0CZ" = "1" /* Occlusion of Right Hand Artery with Extraluminal Device, Open Approach */
"03LD0DZ" = "1" /* Occlusion of Right Hand Artery with Intraluminal Device, Open Approach */
"03LD0ZZ" = "1" /* Occlusion of Right Hand Artery, Open Approach */
"03LD3CZ" = "1" /* Occlusion of Right Hand Artery with Extraluminal Device, Percutaneous Approach */
"03LD3DZ" = "1" /* Occlusion of Right Hand Artery with Intraluminal Device, Percutaneous Approach */
"03LD3ZZ" = "1" /* Occlusion of Right Hand Artery, Percutaneous Approach */
"03LD4CZ" = "1" /* Occlusion of Right Hand Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LD4DZ" = "1" /* Occlusion of Right Hand Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LD4ZZ" = "1" /* Occlusion of Right Hand Artery, Percutaneous Endoscopic Approach */
"03LF0CZ" = "1" /* Occlusion of Left Hand Artery with Extraluminal Device, Open Approach */
"03LF0DZ" = "1" /* Occlusion of Left Hand Artery with Intraluminal Device, Open Approach */
"03LF0ZZ" = "1" /* Occlusion of Left Hand Artery, Open Approach */
"03LF3CZ" = "1" /* Occlusion of Left Hand Artery with Extraluminal Device, Percutaneous Approach */
"03LF3DZ" = "1" /* Occlusion of Left Hand Artery with Intraluminal Device, Percutaneous Approach */
"03LF3ZZ" = "1" /* Occlusion of Left Hand Artery, Percutaneous Approach */
"03LF4CZ" = "1" /* Occlusion of Left Hand Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LF4DZ" = "1" /* Occlusion of Left Hand Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LF4ZZ" = "1" /* Occlusion of Left Hand Artery, Percutaneous Endoscopic Approach */
"03LG0BZ" = "1" /* Occlusion of Intracranial Artery with Bioactive Intraluminal Device, Open Approach */
"03LG0CZ" = "1" /* Occlusion of Intracranial Artery with Extraluminal Device, Open Approach */
"03LG0DZ" = "1" /* Occlusion of Intracranial Artery with Intraluminal Device, Open Approach */
"03LG0ZZ" = "1" /* Occlusion of Intracranial Artery, Open Approach */
"03LG3BZ" = "1" /* Occlusion of Intracranial Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03LG3CZ" = "1" /* Occlusion of Intracranial Artery with Extraluminal Device, Percutaneous Approach */
"03LG3DZ" = "1" /* Occlusion of Intracranial Artery with Intraluminal Device, Percutaneous Approach */
"03LG3ZZ" = "1" /* Occlusion of Intracranial Artery, Percutaneous Approach */
"03LG4BZ" = "1" /* Occlusion of Intracranial Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03LG4CZ" = "1" /* Occlusion of Intracranial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LG4DZ" = "1" /* Occlusion of Intracranial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LG4ZZ" = "1" /* Occlusion of Intracranial Artery, Percutaneous Endoscopic Approach */
"03LH0BZ" = "1" /* Occlusion of Right Common Carotid Artery with Bioactive Intraluminal Device, Open Approach */
"03LH0CZ" = "1" /* Occlusion of Right Common Carotid Artery with Extraluminal Device, Open Approach */
"03LH0DZ" = "1" /* Occlusion of Right Common Carotid Artery with Intraluminal Device, Open Approach */
"03LH0ZZ" = "1" /* Occlusion of Right Common Carotid Artery, Open Approach */
"03LH3BZ" = "1" /* Occlusion of Right Common Carotid Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03LH3CZ" = "1" /* Occlusion of Right Common Carotid Artery with Extraluminal Device, Percutaneous Approach */
"03LH3DZ" = "1" /* Occlusion of Right Common Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03LH3ZZ" = "1" /* Occlusion of Right Common Carotid Artery, Percutaneous Approach */
"03LH4BZ" = "1" /* Occlusion of Right Common Carotid Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03LH4CZ" = "1" /* Occlusion of Right Common Carotid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LH4DZ" = "1" /* Occlusion of Right Common Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LH4ZZ" = "1" /* Occlusion of Right Common Carotid Artery, Percutaneous Endoscopic Approach */
"03LJ0BZ" = "1" /* Occlusion of Left Common Carotid Artery with Bioactive Intraluminal Device, Open Approach */
"03LJ0CZ" = "1" /* Occlusion of Left Common Carotid Artery with Extraluminal Device, Open Approach */
"03LJ0DZ" = "1" /* Occlusion of Left Common Carotid Artery with Intraluminal Device, Open Approach */
"03LJ0ZZ" = "1" /* Occlusion of Left Common Carotid Artery, Open Approach */
"03LJ3BZ" = "1" /* Occlusion of Left Common Carotid Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03LJ3CZ" = "1" /* Occlusion of Left Common Carotid Artery with Extraluminal Device, Percutaneous Approach */
"03LJ3DZ" = "1" /* Occlusion of Left Common Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03LJ3ZZ" = "1" /* Occlusion of Left Common Carotid Artery, Percutaneous Approach */
"03LJ4BZ" = "1" /* Occlusion of Left Common Carotid Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03LJ4CZ" = "1" /* Occlusion of Left Common Carotid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LJ4DZ" = "1" /* Occlusion of Left Common Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LJ4ZZ" = "1" /* Occlusion of Left Common Carotid Artery, Percutaneous Endoscopic Approach */
"03LK0BZ" = "1" /* Occlusion of Right Internal Carotid Artery with Bioactive Intraluminal Device, Open Approach */
"03LK0CZ" = "1" /* Occlusion of Right Internal Carotid Artery with Extraluminal Device, Open Approach */
"03LK0DZ" = "1" /* Occlusion of Right Internal Carotid Artery with Intraluminal Device, Open Approach */
"03LK0ZZ" = "1" /* Occlusion of Right Internal Carotid Artery, Open Approach */
"03LK3BZ" = "1" /* Occlusion of Right Internal Carotid Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03LK3CZ" = "1" /* Occlusion of Right Internal Carotid Artery with Extraluminal Device, Percutaneous Approach */
"03LK3DZ" = "1" /* Occlusion of Right Internal Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03LK3ZZ" = "1" /* Occlusion of Right Internal Carotid Artery, Percutaneous Approach */
"03LK4BZ" = "1" /* Occlusion of Right Internal Carotid Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03LK4CZ" = "1" /* Occlusion of Right Internal Carotid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LK4DZ" = "1" /* Occlusion of Right Internal Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LK4ZZ" = "1" /* Occlusion of Right Internal Carotid Artery, Percutaneous Endoscopic Approach */
"03LL0BZ" = "1" /* Occlusion of Left Internal Carotid Artery with Bioactive Intraluminal Device, Open Approach */
"03LL0CZ" = "1" /* Occlusion of Left Internal Carotid Artery with Extraluminal Device, Open Approach */
"03LL0DZ" = "1" /* Occlusion of Left Internal Carotid Artery with Intraluminal Device, Open Approach */
"03LL0ZZ" = "1" /* Occlusion of Left Internal Carotid Artery, Open Approach */
"03LL3BZ" = "1" /* Occlusion of Left Internal Carotid Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03LL3CZ" = "1" /* Occlusion of Left Internal Carotid Artery with Extraluminal Device, Percutaneous Approach */
"03LL3DZ" = "1" /* Occlusion of Left Internal Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03LL3ZZ" = "1" /* Occlusion of Left Internal Carotid Artery, Percutaneous Approach */
"03LL4BZ" = "1" /* Occlusion of Left Internal Carotid Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03LL4CZ" = "1" /* Occlusion of Left Internal Carotid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LL4DZ" = "1" /* Occlusion of Left Internal Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LL4ZZ" = "1" /* Occlusion of Left Internal Carotid Artery, Percutaneous Endoscopic Approach */
"03LM0BZ" = "1" /* Occlusion of Right External Carotid Artery with Bioactive Intraluminal Device, Open Approach */
"03LM0CZ" = "1" /* Occlusion of Right External Carotid Artery with Extraluminal Device, Open Approach */
"03LM0DZ" = "1" /* Occlusion of Right External Carotid Artery with Intraluminal Device, Open Approach */
"03LM0ZZ" = "1" /* Occlusion of Right External Carotid Artery, Open Approach */
"03LM3BZ" = "1" /* Occlusion of Right External Carotid Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03LM3CZ" = "1" /* Occlusion of Right External Carotid Artery with Extraluminal Device, Percutaneous Approach */
"03LM3DZ" = "1" /* Occlusion of Right External Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03LM3ZZ" = "1" /* Occlusion of Right External Carotid Artery, Percutaneous Approach */
"03LM4BZ" = "1" /* Occlusion of Right External Carotid Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03LM4CZ" = "1" /* Occlusion of Right External Carotid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LM4DZ" = "1" /* Occlusion of Right External Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LM4ZZ" = "1" /* Occlusion of Right External Carotid Artery, Percutaneous Endoscopic Approach */
"03LN0BZ" = "1" /* Occlusion of Left External Carotid Artery with Bioactive Intraluminal Device, Open Approach */
"03LN0CZ" = "1" /* Occlusion of Left External Carotid Artery with Extraluminal Device, Open Approach */
"03LN0DZ" = "1" /* Occlusion of Left External Carotid Artery with Intraluminal Device, Open Approach */
"03LN0ZZ" = "1" /* Occlusion of Left External Carotid Artery, Open Approach */
"03LN3BZ" = "1" /* Occlusion of Left External Carotid Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03LN3CZ" = "1" /* Occlusion of Left External Carotid Artery with Extraluminal Device, Percutaneous Approach */
"03LN3DZ" = "1" /* Occlusion of Left External Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03LN3ZZ" = "1" /* Occlusion of Left External Carotid Artery, Percutaneous Approach */
"03LN4BZ" = "1" /* Occlusion of Left External Carotid Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03LN4CZ" = "1" /* Occlusion of Left External Carotid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LN4DZ" = "1" /* Occlusion of Left External Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LN4ZZ" = "1" /* Occlusion of Left External Carotid Artery, Percutaneous Endoscopic Approach */
"03LP0BZ" = "1" /* Occlusion of Right Vertebral Artery with Bioactive Intraluminal Device, Open Approach */
"03LP0CZ" = "1" /* Occlusion of Right Vertebral Artery with Extraluminal Device, Open Approach */
"03LP0DZ" = "1" /* Occlusion of Right Vertebral Artery with Intraluminal Device, Open Approach */
"03LP0ZZ" = "1" /* Occlusion of Right Vertebral Artery, Open Approach */
"03LP3BZ" = "1" /* Occlusion of Right Vertebral Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03LP3CZ" = "1" /* Occlusion of Right Vertebral Artery with Extraluminal Device, Percutaneous Approach */
"03LP3DZ" = "1" /* Occlusion of Right Vertebral Artery with Intraluminal Device, Percutaneous Approach */
"03LP3ZZ" = "1" /* Occlusion of Right Vertebral Artery, Percutaneous Approach */
"03LP4BZ" = "1" /* Occlusion of Right Vertebral Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03LP4CZ" = "1" /* Occlusion of Right Vertebral Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LP4DZ" = "1" /* Occlusion of Right Vertebral Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LP4ZZ" = "1" /* Occlusion of Right Vertebral Artery, Percutaneous Endoscopic Approach */
"03LQ0BZ" = "1" /* Occlusion of Left Vertebral Artery with Bioactive Intraluminal Device, Open Approach */
"03LQ0CZ" = "1" /* Occlusion of Left Vertebral Artery with Extraluminal Device, Open Approach */
"03LQ0DZ" = "1" /* Occlusion of Left Vertebral Artery with Intraluminal Device, Open Approach */
"03LQ0ZZ" = "1" /* Occlusion of Left Vertebral Artery, Open Approach */
"03LQ3BZ" = "1" /* Occlusion of Left Vertebral Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03LQ3CZ" = "1" /* Occlusion of Left Vertebral Artery with Extraluminal Device, Percutaneous Approach */
"03LQ3DZ" = "1" /* Occlusion of Left Vertebral Artery with Intraluminal Device, Percutaneous Approach */
"03LQ3ZZ" = "1" /* Occlusion of Left Vertebral Artery, Percutaneous Approach */
"03LQ4BZ" = "1" /* Occlusion of Left Vertebral Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03LQ4CZ" = "1" /* Occlusion of Left Vertebral Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LQ4DZ" = "1" /* Occlusion of Left Vertebral Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LQ4ZZ" = "1" /* Occlusion of Left Vertebral Artery, Percutaneous Endoscopic Approach */
"03LR0CZ" = "1" /* Occlusion of Face Artery with Extraluminal Device, Open Approach */
"03LR0DZ" = "1" /* Occlusion of Face Artery with Intraluminal Device, Open Approach */
"03LR0ZZ" = "1" /* Occlusion of Face Artery, Open Approach */
"03LR3CZ" = "1" /* Occlusion of Face Artery with Extraluminal Device, Percutaneous Approach */
"03LR3DZ" = "1" /* Occlusion of Face Artery with Intraluminal Device, Percutaneous Approach */
"03LR3ZZ" = "1" /* Occlusion of Face Artery, Percutaneous Approach */
"03LR4CZ" = "1" /* Occlusion of Face Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LR4DZ" = "1" /* Occlusion of Face Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LR4ZZ" = "1" /* Occlusion of Face Artery, Percutaneous Endoscopic Approach */
"03LS0CZ" = "1" /* Occlusion of Right Temporal Artery with Extraluminal Device, Open Approach */
"03LS0DZ" = "1" /* Occlusion of Right Temporal Artery with Intraluminal Device, Open Approach */
"03LS0ZZ" = "1" /* Occlusion of Right Temporal Artery, Open Approach */
"03LS3CZ" = "1" /* Occlusion of Right Temporal Artery with Extraluminal Device, Percutaneous Approach */
"03LS3DZ" = "1" /* Occlusion of Right Temporal Artery with Intraluminal Device, Percutaneous Approach */
"03LS3ZZ" = "1" /* Occlusion of Right Temporal Artery, Percutaneous Approach */
"03LS4CZ" = "1" /* Occlusion of Right Temporal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LS4DZ" = "1" /* Occlusion of Right Temporal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LS4ZZ" = "1" /* Occlusion of Right Temporal Artery, Percutaneous Endoscopic Approach */
"03LT0CZ" = "1" /* Occlusion of Left Temporal Artery with Extraluminal Device, Open Approach */
"03LT0DZ" = "1" /* Occlusion of Left Temporal Artery with Intraluminal Device, Open Approach */
"03LT0ZZ" = "1" /* Occlusion of Left Temporal Artery, Open Approach */
"03LT3CZ" = "1" /* Occlusion of Left Temporal Artery with Extraluminal Device, Percutaneous Approach */
"03LT3DZ" = "1" /* Occlusion of Left Temporal Artery with Intraluminal Device, Percutaneous Approach */
"03LT3ZZ" = "1" /* Occlusion of Left Temporal Artery, Percutaneous Approach */
"03LT4CZ" = "1" /* Occlusion of Left Temporal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LT4DZ" = "1" /* Occlusion of Left Temporal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LT4ZZ" = "1" /* Occlusion of Left Temporal Artery, Percutaneous Endoscopic Approach */
"03LU0CZ" = "1" /* Occlusion of Right Thyroid Artery with Extraluminal Device, Open Approach */
"03LU0DZ" = "1" /* Occlusion of Right Thyroid Artery with Intraluminal Device, Open Approach */
"03LU0ZZ" = "1" /* Occlusion of Right Thyroid Artery, Open Approach */
"03LU3CZ" = "1" /* Occlusion of Right Thyroid Artery with Extraluminal Device, Percutaneous Approach */
"03LU3DZ" = "1" /* Occlusion of Right Thyroid Artery with Intraluminal Device, Percutaneous Approach */
"03LU3ZZ" = "1" /* Occlusion of Right Thyroid Artery, Percutaneous Approach */
"03LU4CZ" = "1" /* Occlusion of Right Thyroid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LU4DZ" = "1" /* Occlusion of Right Thyroid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LU4ZZ" = "1" /* Occlusion of Right Thyroid Artery, Percutaneous Endoscopic Approach */
"03LV0CZ" = "1" /* Occlusion of Left Thyroid Artery with Extraluminal Device, Open Approach */
"03LV0DZ" = "1" /* Occlusion of Left Thyroid Artery with Intraluminal Device, Open Approach */
"03LV0ZZ" = "1" /* Occlusion of Left Thyroid Artery, Open Approach */
"03LV3CZ" = "1" /* Occlusion of Left Thyroid Artery with Extraluminal Device, Percutaneous Approach */
"03LV3DZ" = "1" /* Occlusion of Left Thyroid Artery with Intraluminal Device, Percutaneous Approach */
"03LV3ZZ" = "1" /* Occlusion of Left Thyroid Artery, Percutaneous Approach */
"03LV4CZ" = "1" /* Occlusion of Left Thyroid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LV4DZ" = "1" /* Occlusion of Left Thyroid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LV4ZZ" = "1" /* Occlusion of Left Thyroid Artery, Percutaneous Endoscopic Approach */
"03LY0CZ" = "1" /* Occlusion of Upper Artery with Extraluminal Device, Open Approach */
"03LY0DZ" = "1" /* Occlusion of Upper Artery with Intraluminal Device, Open Approach */
"03LY0ZZ" = "1" /* Occlusion of Upper Artery, Open Approach */
"03LY3CZ" = "1" /* Occlusion of Upper Artery with Extraluminal Device, Percutaneous Approach */
"03LY3DZ" = "1" /* Occlusion of Upper Artery with Intraluminal Device, Percutaneous Approach */
"03LY3ZZ" = "1" /* Occlusion of Upper Artery, Percutaneous Approach */
"03LY4CZ" = "1" /* Occlusion of Upper Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LY4DZ" = "1" /* Occlusion of Upper Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LY4ZZ" = "1" /* Occlusion of Upper Artery, Percutaneous Endoscopic Approach */
"03Q00ZZ" = "1" /* Repair Right Internal Mammary Artery, Open Approach */
"03Q03ZZ" = "1" /* Repair Right Internal Mammary Artery, Percutaneous Approach */
"03Q04ZZ" = "1" /* Repair Right Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03Q10ZZ" = "1" /* Repair Left Internal Mammary Artery, Open Approach */
"03Q13ZZ" = "1" /* Repair Left Internal Mammary Artery, Percutaneous Approach */
"03Q14ZZ" = "1" /* Repair Left Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03Q20ZZ" = "1" /* Repair Innominate Artery, Open Approach */
"03Q23ZZ" = "1" /* Repair Innominate Artery, Percutaneous Approach */
"03Q24ZZ" = "1" /* Repair Innominate Artery, Percutaneous Endoscopic Approach */
"03Q30ZZ" = "1" /* Repair Right Subclavian Artery, Open Approach */
"03Q33ZZ" = "1" /* Repair Right Subclavian Artery, Percutaneous Approach */
"03Q34ZZ" = "1" /* Repair Right Subclavian Artery, Percutaneous Endoscopic Approach */
"03Q40ZZ" = "1" /* Repair Left Subclavian Artery, Open Approach */
"03Q43ZZ" = "1" /* Repair Left Subclavian Artery, Percutaneous Approach */
"03Q44ZZ" = "1" /* Repair Left Subclavian Artery, Percutaneous Endoscopic Approach */
"03Q50ZZ" = "1" /* Repair Right Axillary Artery, Open Approach */
"03Q53ZZ" = "1" /* Repair Right Axillary Artery, Percutaneous Approach */
"03Q54ZZ" = "1" /* Repair Right Axillary Artery, Percutaneous Endoscopic Approach */
"03Q60ZZ" = "1" /* Repair Left Axillary Artery, Open Approach */
"03Q63ZZ" = "1" /* Repair Left Axillary Artery, Percutaneous Approach */
"03Q64ZZ" = "1" /* Repair Left Axillary Artery, Percutaneous Endoscopic Approach */
"03Q70ZZ" = "1" /* Repair Right Brachial Artery, Open Approach */
"03Q73ZZ" = "1" /* Repair Right Brachial Artery, Percutaneous Approach */
"03Q74ZZ" = "1" /* Repair Right Brachial Artery, Percutaneous Endoscopic Approach */
"03Q80ZZ" = "1" /* Repair Left Brachial Artery, Open Approach */
"03Q83ZZ" = "1" /* Repair Left Brachial Artery, Percutaneous Approach */
"03Q84ZZ" = "1" /* Repair Left Brachial Artery, Percutaneous Endoscopic Approach */
"03Q90ZZ" = "1" /* Repair Right Ulnar Artery, Open Approach */
"03Q93ZZ" = "1" /* Repair Right Ulnar Artery, Percutaneous Approach */
"03Q94ZZ" = "1" /* Repair Right Ulnar Artery, Percutaneous Endoscopic Approach */
"03QA0ZZ" = "1" /* Repair Left Ulnar Artery, Open Approach */
"03QA3ZZ" = "1" /* Repair Left Ulnar Artery, Percutaneous Approach */
"03QA4ZZ" = "1" /* Repair Left Ulnar Artery, Percutaneous Endoscopic Approach */
"03QB0ZZ" = "1" /* Repair Right Radial Artery, Open Approach */
"03QB3ZZ" = "1" /* Repair Right Radial Artery, Percutaneous Approach */
"03QB4ZZ" = "1" /* Repair Right Radial Artery, Percutaneous Endoscopic Approach */
"03QC0ZZ" = "1" /* Repair Left Radial Artery, Open Approach */
"03QC3ZZ" = "1" /* Repair Left Radial Artery, Percutaneous Approach */
"03QC4ZZ" = "1" /* Repair Left Radial Artery, Percutaneous Endoscopic Approach */
"03QD0ZZ" = "1" /* Repair Right Hand Artery, Open Approach */
"03QD3ZZ" = "1" /* Repair Right Hand Artery, Percutaneous Approach */
"03QD4ZZ" = "1" /* Repair Right Hand Artery, Percutaneous Endoscopic Approach */
"03QF0ZZ" = "1" /* Repair Left Hand Artery, Open Approach */
"03QF3ZZ" = "1" /* Repair Left Hand Artery, Percutaneous Approach */
"03QF4ZZ" = "1" /* Repair Left Hand Artery, Percutaneous Endoscopic Approach */
"03QG0ZZ" = "1" /* Repair Intracranial Artery, Open Approach */
"03QG3ZZ" = "1" /* Repair Intracranial Artery, Percutaneous Approach */
"03QG4ZZ" = "1" /* Repair Intracranial Artery, Percutaneous Endoscopic Approach */
"03QH0ZZ" = "1" /* Repair Right Common Carotid Artery, Open Approach */
"03QH3ZZ" = "1" /* Repair Right Common Carotid Artery, Percutaneous Approach */
"03QH4ZZ" = "1" /* Repair Right Common Carotid Artery, Percutaneous Endoscopic Approach */
"03QJ0ZZ" = "1" /* Repair Left Common Carotid Artery, Open Approach */
"03QJ3ZZ" = "1" /* Repair Left Common Carotid Artery, Percutaneous Approach */
"03QJ4ZZ" = "1" /* Repair Left Common Carotid Artery, Percutaneous Endoscopic Approach */
"03QK0ZZ" = "1" /* Repair Right Internal Carotid Artery, Open Approach */
"03QK3ZZ" = "1" /* Repair Right Internal Carotid Artery, Percutaneous Approach */
"03QK4ZZ" = "1" /* Repair Right Internal Carotid Artery, Percutaneous Endoscopic Approach */
"03QL0ZZ" = "1" /* Repair Left Internal Carotid Artery, Open Approach */
"03QL3ZZ" = "1" /* Repair Left Internal Carotid Artery, Percutaneous Approach */
"03QL4ZZ" = "1" /* Repair Left Internal Carotid Artery, Percutaneous Endoscopic Approach */
"03QM0ZZ" = "1" /* Repair Right External Carotid Artery, Open Approach */
"03QM3ZZ" = "1" /* Repair Right External Carotid Artery, Percutaneous Approach */
"03QM4ZZ" = "1" /* Repair Right External Carotid Artery, Percutaneous Endoscopic Approach */
"03QN0ZZ" = "1" /* Repair Left External Carotid Artery, Open Approach */
"03QN3ZZ" = "1" /* Repair Left External Carotid Artery, Percutaneous Approach */
"03QN4ZZ" = "1" /* Repair Left External Carotid Artery, Percutaneous Endoscopic Approach */
"03QP0ZZ" = "1" /* Repair Right Vertebral Artery, Open Approach */
"03QP3ZZ" = "1" /* Repair Right Vertebral Artery, Percutaneous Approach */
"03QP4ZZ" = "1" /* Repair Right Vertebral Artery, Percutaneous Endoscopic Approach */
"03QQ0ZZ" = "1" /* Repair Left Vertebral Artery, Open Approach */
"03QQ3ZZ" = "1" /* Repair Left Vertebral Artery, Percutaneous Approach */
"03QQ4ZZ" = "1" /* Repair Left Vertebral Artery, Percutaneous Endoscopic Approach */
"03QR0ZZ" = "1" /* Repair Face Artery, Open Approach */
"03QR3ZZ" = "1" /* Repair Face Artery, Percutaneous Approach */
"03QR4ZZ" = "1" /* Repair Face Artery, Percutaneous Endoscopic Approach */
"03QS0ZZ" = "1" /* Repair Right Temporal Artery, Open Approach */
"03QS3ZZ" = "1" /* Repair Right Temporal Artery, Percutaneous Approach */
"03QS4ZZ" = "1" /* Repair Right Temporal Artery, Percutaneous Endoscopic Approach */
"03QT0ZZ" = "1" /* Repair Left Temporal Artery, Open Approach */
"03QT3ZZ" = "1" /* Repair Left Temporal Artery, Percutaneous Approach */
"03QT4ZZ" = "1" /* Repair Left Temporal Artery, Percutaneous Endoscopic Approach */
"03QU0ZZ" = "1" /* Repair Right Thyroid Artery, Open Approach */
"03QU3ZZ" = "1" /* Repair Right Thyroid Artery, Percutaneous Approach */
"03QU4ZZ" = "1" /* Repair Right Thyroid Artery, Percutaneous Endoscopic Approach */
"03QV0ZZ" = "1" /* Repair Left Thyroid Artery, Open Approach */
"03QV3ZZ" = "1" /* Repair Left Thyroid Artery, Percutaneous Approach */
"03QV4ZZ" = "1" /* Repair Left Thyroid Artery, Percutaneous Endoscopic Approach */
"03QY0ZZ" = "1" /* Repair Upper Artery, Open Approach */
"03QY3ZZ" = "1" /* Repair Upper Artery, Percutaneous Approach */
"03QY4ZZ" = "1" /* Repair Upper Artery, Percutaneous Endoscopic Approach */
"03VG0DZ" = "1" /* Restriction of Intracranial Artery with Intraluminal Device, Open Approach */
"03VG3DZ" = "1" /* Restriction of Intracranial Artery with Intraluminal Device, Percutaneous Approach */
"03VG4DZ" = "1" /* Restriction of Intracranial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VH0DZ" = "1" /* Restriction of Right Common Carotid Artery with Intraluminal Device, Open Approach */
"03VH3DZ" = "1" /* Restriction of Right Common Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03VH4DZ" = "1" /* Restriction of Right Common Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VJ0DZ" = "1" /* Restriction of Left Common Carotid Artery with Intraluminal Device, Open Approach */
"03VJ3DZ" = "1" /* Restriction of Left Common Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03VJ4DZ" = "1" /* Restriction of Left Common Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VK0DZ" = "1" /* Restriction of Right Internal Carotid Artery with Intraluminal Device, Open Approach */
"03VK3DZ" = "1" /* Restriction of Right Internal Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03VK4DZ" = "1" /* Restriction of Right Internal Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VL0DZ" = "1" /* Restriction of Left Internal Carotid Artery with Intraluminal Device, Open Approach */
"03VL3DZ" = "1" /* Restriction of Left Internal Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03VL4DZ" = "1" /* Restriction of Left Internal Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VM0DZ" = "1" /* Restriction of Right External Carotid Artery with Intraluminal Device, Open Approach */
"03VM3DZ" = "1" /* Restriction of Right External Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03VM4DZ" = "1" /* Restriction of Right External Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VN0DZ" = "1" /* Restriction of Left External Carotid Artery with Intraluminal Device, Open Approach */
"03VN3DZ" = "1" /* Restriction of Left External Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03VN4DZ" = "1" /* Restriction of Left External Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VP0DZ" = "1" /* Restriction of Right Vertebral Artery with Intraluminal Device, Open Approach */
"03VP3DZ" = "1" /* Restriction of Right Vertebral Artery with Intraluminal Device, Percutaneous Approach */
"03VP4DZ" = "1" /* Restriction of Right Vertebral Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VQ0DZ" = "1" /* Restriction of Left Vertebral Artery with Intraluminal Device, Open Approach */
"03VQ3DZ" = "1" /* Restriction of Left Vertebral Artery with Intraluminal Device, Percutaneous Approach */
"03VQ4DZ" = "1" /* Restriction of Left Vertebral Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VR0DZ" = "1" /* Restriction of Face Artery with Intraluminal Device, Open Approach */
"03VR3DZ" = "1" /* Restriction of Face Artery with Intraluminal Device, Percutaneous Approach */
"03VR4DZ" = "1" /* Restriction of Face Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VS0DZ" = "1" /* Restriction of Right Temporal Artery with Intraluminal Device, Open Approach */
"03VS3DZ" = "1" /* Restriction of Right Temporal Artery with Intraluminal Device, Percutaneous Approach */
"03VS4DZ" = "1" /* Restriction of Right Temporal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VT0DZ" = "1" /* Restriction of Left Temporal Artery with Intraluminal Device, Open Approach */
"03VT3DZ" = "1" /* Restriction of Left Temporal Artery with Intraluminal Device, Percutaneous Approach */
"03VT4DZ" = "1" /* Restriction of Left Temporal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VU0DZ" = "1" /* Restriction of Right Thyroid Artery with Intraluminal Device, Open Approach */
"03VU3DZ" = "1" /* Restriction of Right Thyroid Artery with Intraluminal Device, Percutaneous Approach */
"03VU4DZ" = "1" /* Restriction of Right Thyroid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VV0DZ" = "1" /* Restriction of Left Thyroid Artery with Intraluminal Device, Open Approach */
"03VV3DZ" = "1" /* Restriction of Left Thyroid Artery with Intraluminal Device, Percutaneous Approach */
"03VV4DZ" = "1" /* Restriction of Left Thyroid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03WY0DZ" = "1" /* Revision of Intraluminal Device in Upper Artery, Open Approach */
"03WY0JZ" = "1" /* Revision of Synthetic Substitute in Upper Artery, Open Approach */
"03WY0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Artery, Open Approach */
"03WY3DZ" = "1" /* Revision of Intraluminal Device in Upper Artery, Percutaneous Approach */
"03WY3JZ" = "1" /* Revision of Synthetic Substitute in Upper Artery, Percutaneous Approach */
"03WY3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Artery, Percutaneous Approach */
"03WY4DZ" = "1" /* Revision of Intraluminal Device in Upper Artery, Percutaneous Endoscopic Approach */
"03WY4JZ" = "1" /* Revision of Synthetic Substitute in Upper Artery, Percutaneous Endoscopic Approach */
"03WY4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Artery, Percutaneous Endoscopic Approach */
"04L00CZ" = "1" /* Occlusion of Abdominal Aorta with Extraluminal Device, Open Approach */
"04L00DZ" = "1" /* Occlusion of Abdominal Aorta with Intraluminal Device, Open Approach */
"04L00ZZ" = "1" /* Occlusion of Abdominal Aorta, Open Approach */
"04L03CZ" = "1" /* Occlusion of Abdominal Aorta with Extraluminal Device, Percutaneous Approach */
"04L03DZ" = "1" /* Occlusion of Abdominal Aorta with Intraluminal Device, Percutaneous Approach */
"04L03ZZ" = "1" /* Occlusion of Abdominal Aorta, Percutaneous Approach */
"04L04CZ" = "1" /* Occlusion of Abdominal Aorta with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L04DZ" = "1" /* Occlusion of Abdominal Aorta with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L04ZZ" = "1" /* Occlusion of Abdominal Aorta, Percutaneous Endoscopic Approach */
"04L10CZ" = "1" /* Occlusion of Celiac Artery with Extraluminal Device, Open Approach */
"04L10DZ" = "1" /* Occlusion of Celiac Artery with Intraluminal Device, Open Approach */
"04L10ZZ" = "1" /* Occlusion of Celiac Artery, Open Approach */
"04L13CZ" = "1" /* Occlusion of Celiac Artery with Extraluminal Device, Percutaneous Approach */
"04L13DZ" = "1" /* Occlusion of Celiac Artery with Intraluminal Device, Percutaneous Approach */
"04L13ZZ" = "1" /* Occlusion of Celiac Artery, Percutaneous Approach */
"04L14CZ" = "1" /* Occlusion of Celiac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L14DZ" = "1" /* Occlusion of Celiac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L14ZZ" = "1" /* Occlusion of Celiac Artery, Percutaneous Endoscopic Approach */
"04L20CZ" = "1" /* Occlusion of Gastric Artery with Extraluminal Device, Open Approach */
"04L20DZ" = "1" /* Occlusion of Gastric Artery with Intraluminal Device, Open Approach */
"04L20ZZ" = "1" /* Occlusion of Gastric Artery, Open Approach */
"04L23CZ" = "1" /* Occlusion of Gastric Artery with Extraluminal Device, Percutaneous Approach */
"04L23DZ" = "1" /* Occlusion of Gastric Artery with Intraluminal Device, Percutaneous Approach */
"04L23ZZ" = "1" /* Occlusion of Gastric Artery, Percutaneous Approach */
"04L24CZ" = "1" /* Occlusion of Gastric Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L24DZ" = "1" /* Occlusion of Gastric Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L24ZZ" = "1" /* Occlusion of Gastric Artery, Percutaneous Endoscopic Approach */
"04L30CZ" = "1" /* Occlusion of Hepatic Artery with Extraluminal Device, Open Approach */
"04L30DZ" = "1" /* Occlusion of Hepatic Artery with Intraluminal Device, Open Approach */
"04L30ZZ" = "1" /* Occlusion of Hepatic Artery, Open Approach */
"04L33CZ" = "1" /* Occlusion of Hepatic Artery with Extraluminal Device, Percutaneous Approach */
"04L33DZ" = "1" /* Occlusion of Hepatic Artery with Intraluminal Device, Percutaneous Approach */
"04L33ZZ" = "1" /* Occlusion of Hepatic Artery, Percutaneous Approach */
"04L34CZ" = "1" /* Occlusion of Hepatic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L34DZ" = "1" /* Occlusion of Hepatic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L34ZZ" = "1" /* Occlusion of Hepatic Artery, Percutaneous Endoscopic Approach */
"04L40CZ" = "1" /* Occlusion of Splenic Artery with Extraluminal Device, Open Approach */
"04L40DZ" = "1" /* Occlusion of Splenic Artery with Intraluminal Device, Open Approach */
"04L40ZZ" = "1" /* Occlusion of Splenic Artery, Open Approach */
"04L43CZ" = "1" /* Occlusion of Splenic Artery with Extraluminal Device, Percutaneous Approach */
"04L43DZ" = "1" /* Occlusion of Splenic Artery with Intraluminal Device, Percutaneous Approach */
"04L43ZZ" = "1" /* Occlusion of Splenic Artery, Percutaneous Approach */
"04L44CZ" = "1" /* Occlusion of Splenic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L44DZ" = "1" /* Occlusion of Splenic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L44ZZ" = "1" /* Occlusion of Splenic Artery, Percutaneous Endoscopic Approach */
"04L50CZ" = "1" /* Occlusion of Superior Mesenteric Artery with Extraluminal Device, Open Approach */
"04L50DZ" = "1" /* Occlusion of Superior Mesenteric Artery with Intraluminal Device, Open Approach */
"04L50ZZ" = "1" /* Occlusion of Superior Mesenteric Artery, Open Approach */
"04L53CZ" = "1" /* Occlusion of Superior Mesenteric Artery with Extraluminal Device, Percutaneous Approach */
"04L53DZ" = "1" /* Occlusion of Superior Mesenteric Artery with Intraluminal Device, Percutaneous Approach */
"04L53ZZ" = "1" /* Occlusion of Superior Mesenteric Artery, Percutaneous Approach */
"04L54CZ" = "1" /* Occlusion of Superior Mesenteric Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L54DZ" = "1" /* Occlusion of Superior Mesenteric Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L54ZZ" = "1" /* Occlusion of Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04L60CZ" = "1" /* Occlusion of Right Colic Artery with Extraluminal Device, Open Approach */
"04L60DZ" = "1" /* Occlusion of Right Colic Artery with Intraluminal Device, Open Approach */
"04L60ZZ" = "1" /* Occlusion of Right Colic Artery, Open Approach */
"04L63CZ" = "1" /* Occlusion of Right Colic Artery with Extraluminal Device, Percutaneous Approach */
"04L63DZ" = "1" /* Occlusion of Right Colic Artery with Intraluminal Device, Percutaneous Approach */
"04L63ZZ" = "1" /* Occlusion of Right Colic Artery, Percutaneous Approach */
"04L64CZ" = "1" /* Occlusion of Right Colic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L64DZ" = "1" /* Occlusion of Right Colic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L64ZZ" = "1" /* Occlusion of Right Colic Artery, Percutaneous Endoscopic Approach */
"04L70CZ" = "1" /* Occlusion of Left Colic Artery with Extraluminal Device, Open Approach */
"04L70DZ" = "1" /* Occlusion of Left Colic Artery with Intraluminal Device, Open Approach */
"04L70ZZ" = "1" /* Occlusion of Left Colic Artery, Open Approach */
"04L73CZ" = "1" /* Occlusion of Left Colic Artery with Extraluminal Device, Percutaneous Approach */
"04L73DZ" = "1" /* Occlusion of Left Colic Artery with Intraluminal Device, Percutaneous Approach */
"04L73ZZ" = "1" /* Occlusion of Left Colic Artery, Percutaneous Approach */
"04L74CZ" = "1" /* Occlusion of Left Colic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L74DZ" = "1" /* Occlusion of Left Colic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L74ZZ" = "1" /* Occlusion of Left Colic Artery, Percutaneous Endoscopic Approach */
"04L80CZ" = "1" /* Occlusion of Middle Colic Artery with Extraluminal Device, Open Approach */
"04L80DZ" = "1" /* Occlusion of Middle Colic Artery with Intraluminal Device, Open Approach */
"04L80ZZ" = "1" /* Occlusion of Middle Colic Artery, Open Approach */
"04L83CZ" = "1" /* Occlusion of Middle Colic Artery with Extraluminal Device, Percutaneous Approach */
"04L83DZ" = "1" /* Occlusion of Middle Colic Artery with Intraluminal Device, Percutaneous Approach */
"04L83ZZ" = "1" /* Occlusion of Middle Colic Artery, Percutaneous Approach */
"04L84CZ" = "1" /* Occlusion of Middle Colic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L84DZ" = "1" /* Occlusion of Middle Colic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L84ZZ" = "1" /* Occlusion of Middle Colic Artery, Percutaneous Endoscopic Approach */
"04L90CZ" = "1" /* Occlusion of Right Renal Artery with Extraluminal Device, Open Approach */
"04L90DZ" = "1" /* Occlusion of Right Renal Artery with Intraluminal Device, Open Approach */
"04L90ZZ" = "1" /* Occlusion of Right Renal Artery, Open Approach */
"04L93CZ" = "1" /* Occlusion of Right Renal Artery with Extraluminal Device, Percutaneous Approach */
"04L93DZ" = "1" /* Occlusion of Right Renal Artery with Intraluminal Device, Percutaneous Approach */
"04L93ZZ" = "1" /* Occlusion of Right Renal Artery, Percutaneous Approach */
"04L94CZ" = "1" /* Occlusion of Right Renal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L94DZ" = "1" /* Occlusion of Right Renal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L94ZZ" = "1" /* Occlusion of Right Renal Artery, Percutaneous Endoscopic Approach */
"04LA0CZ" = "1" /* Occlusion of Left Renal Artery with Extraluminal Device, Open Approach */
"04LA0DZ" = "1" /* Occlusion of Left Renal Artery with Intraluminal Device, Open Approach */
"04LA0ZZ" = "1" /* Occlusion of Left Renal Artery, Open Approach */
"04LA3CZ" = "1" /* Occlusion of Left Renal Artery with Extraluminal Device, Percutaneous Approach */
"04LA3DZ" = "1" /* Occlusion of Left Renal Artery with Intraluminal Device, Percutaneous Approach */
"04LA3ZZ" = "1" /* Occlusion of Left Renal Artery, Percutaneous Approach */
"04LA4CZ" = "1" /* Occlusion of Left Renal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LA4DZ" = "1" /* Occlusion of Left Renal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LA4ZZ" = "1" /* Occlusion of Left Renal Artery, Percutaneous Endoscopic Approach */
"04LB0CZ" = "1" /* Occlusion of Inferior Mesenteric Artery with Extraluminal Device, Open Approach */
"04LB0DZ" = "1" /* Occlusion of Inferior Mesenteric Artery with Intraluminal Device, Open Approach */
"04LB0ZZ" = "1" /* Occlusion of Inferior Mesenteric Artery, Open Approach */
"04LB3CZ" = "1" /* Occlusion of Inferior Mesenteric Artery with Extraluminal Device, Percutaneous Approach */
"04LB3DZ" = "1" /* Occlusion of Inferior Mesenteric Artery with Intraluminal Device, Percutaneous Approach */
"04LB3ZZ" = "1" /* Occlusion of Inferior Mesenteric Artery, Percutaneous Approach */
"04LB4CZ" = "1" /* Occlusion of Inferior Mesenteric Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LB4DZ" = "1" /* Occlusion of Inferior Mesenteric Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LB4ZZ" = "1" /* Occlusion of Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04LC0CZ" = "1" /* Occlusion of Right Common Iliac Artery with Extraluminal Device, Open Approach */
"04LC0DZ" = "1" /* Occlusion of Right Common Iliac Artery with Intraluminal Device, Open Approach */
"04LC0ZZ" = "1" /* Occlusion of Right Common Iliac Artery, Open Approach */
"04LC3CZ" = "1" /* Occlusion of Right Common Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04LC3DZ" = "1" /* Occlusion of Right Common Iliac Artery with Intraluminal Device, Percutaneous Approach */
"04LC3ZZ" = "1" /* Occlusion of Right Common Iliac Artery, Percutaneous Approach */
"04LC4CZ" = "1" /* Occlusion of Right Common Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LC4DZ" = "1" /* Occlusion of Right Common Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LC4ZZ" = "1" /* Occlusion of Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"04LD0CZ" = "1" /* Occlusion of Left Common Iliac Artery with Extraluminal Device, Open Approach */
"04LD0DZ" = "1" /* Occlusion of Left Common Iliac Artery with Intraluminal Device, Open Approach */
"04LD0ZZ" = "1" /* Occlusion of Left Common Iliac Artery, Open Approach */
"04LD3CZ" = "1" /* Occlusion of Left Common Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04LD3DZ" = "1" /* Occlusion of Left Common Iliac Artery with Intraluminal Device, Percutaneous Approach */
"04LD3ZZ" = "1" /* Occlusion of Left Common Iliac Artery, Percutaneous Approach */
"04LD4CZ" = "1" /* Occlusion of Left Common Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LD4DZ" = "1" /* Occlusion of Left Common Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LD4ZZ" = "1" /* Occlusion of Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"04LE0CT" = "1" /* Occlusion of Right Uterine Artery with Extraluminal Device, Open Approach */
"04LE0CZ" = "1" /* Occlusion of Right Internal Iliac Artery with Extraluminal Device, Open Approach */
"04LE0DT" = "1" /* Occlusion of Right Uterine Artery with Intraluminal Device, Open Approach */
"04LE0DZ" = "1" /* Occlusion of Right Internal Iliac Artery with Intraluminal Device, Open Approach */
"04LE0ZT" = "1" /* Occlusion of Right Uterine Artery, Open Approach */
"04LE0ZZ" = "1" /* Occlusion of Right Internal Iliac Artery, Open Approach */
"04LE3CT" = "1" /* Occlusion of Right Uterine Artery with Extraluminal Device, Percutaneous Approach */
"04LE3CZ" = "1" /* Occlusion of Right Internal Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04LE3DT" = "1" /* Occlusion of Right Uterine Artery with Intraluminal Device, Percutaneous Approach */
"04LE3DZ" = "1" /* Occlusion of Right Internal Iliac Artery with Intraluminal Device, Percutaneous Approach */
"04LE3ZT" = "1" /* Occlusion of Right Uterine Artery, Percutaneous Approach */
"04LE3ZZ" = "1" /* Occlusion of Right Internal Iliac Artery, Percutaneous Approach */
"04LE4CT" = "1" /* Occlusion of Right Uterine Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LE4CZ" = "1" /* Occlusion of Right Internal Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LE4DT" = "1" /* Occlusion of Right Uterine Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LE4DZ" = "1" /* Occlusion of Right Internal Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LE4ZT" = "1" /* Occlusion of Right Uterine Artery, Percutaneous Endoscopic Approach */
"04LE4ZZ" = "1" /* Occlusion of Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04LF0CU" = "1" /* Occlusion of Left Uterine Artery with Extraluminal Device, Open Approach */
"04LF0CZ" = "1" /* Occlusion of Left Internal Iliac Artery with Extraluminal Device, Open Approach */
"04LF0DU" = "1" /* Occlusion of Left Uterine Artery with Intraluminal Device, Open Approach */
"04LF0DZ" = "1" /* Occlusion of Left Internal Iliac Artery with Intraluminal Device, Open Approach */
"04LF0ZU" = "1" /* Occlusion of Left Uterine Artery, Open Approach */
"04LF0ZZ" = "1" /* Occlusion of Left Internal Iliac Artery, Open Approach */
"04LF3CU" = "1" /* Occlusion of Left Uterine Artery with Extraluminal Device, Percutaneous Approach */
"04LF3CZ" = "1" /* Occlusion of Left Internal Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04LF3DU" = "1" /* Occlusion of Left Uterine Artery with Intraluminal Device, Percutaneous Approach */
"04LF3DZ" = "1" /* Occlusion of Left Internal Iliac Artery with Intraluminal Device, Percutaneous Approach */
"04LF3ZU" = "1" /* Occlusion of Left Uterine Artery, Percutaneous Approach */
"04LF3ZZ" = "1" /* Occlusion of Left Internal Iliac Artery, Percutaneous Approach */
"04LF4CU" = "1" /* Occlusion of Left Uterine Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LF4CZ" = "1" /* Occlusion of Left Internal Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LF4DU" = "1" /* Occlusion of Left Uterine Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LF4DZ" = "1" /* Occlusion of Left Internal Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LF4ZU" = "1" /* Occlusion of Left Uterine Artery, Percutaneous Endoscopic Approach */
"04LF4ZZ" = "1" /* Occlusion of Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04LH0CZ" = "1" /* Occlusion of Right External Iliac Artery with Extraluminal Device, Open Approach */
"04LH0DZ" = "1" /* Occlusion of Right External Iliac Artery with Intraluminal Device, Open Approach */
"04LH0ZZ" = "1" /* Occlusion of Right External Iliac Artery, Open Approach */
"04LH3CZ" = "1" /* Occlusion of Right External Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04LH3DZ" = "1" /* Occlusion of Right External Iliac Artery with Intraluminal Device, Percutaneous Approach */
"04LH3ZZ" = "1" /* Occlusion of Right External Iliac Artery, Percutaneous Approach */
"04LH4CZ" = "1" /* Occlusion of Right External Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LH4DZ" = "1" /* Occlusion of Right External Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LH4ZZ" = "1" /* Occlusion of Right External Iliac Artery, Percutaneous Endoscopic Approach */
"04LJ0CZ" = "1" /* Occlusion of Left External Iliac Artery with Extraluminal Device, Open Approach */
"04LJ0DZ" = "1" /* Occlusion of Left External Iliac Artery with Intraluminal Device, Open Approach */
"04LJ0ZZ" = "1" /* Occlusion of Left External Iliac Artery, Open Approach */
"04LJ3CZ" = "1" /* Occlusion of Left External Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04LJ3DZ" = "1" /* Occlusion of Left External Iliac Artery with Intraluminal Device, Percutaneous Approach */
"04LJ3ZZ" = "1" /* Occlusion of Left External Iliac Artery, Percutaneous Approach */
"04LJ4CZ" = "1" /* Occlusion of Left External Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LJ4DZ" = "1" /* Occlusion of Left External Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LJ4ZZ" = "1" /* Occlusion of Left External Iliac Artery, Percutaneous Endoscopic Approach */
"04LK0CZ" = "1" /* Occlusion of Right Femoral Artery with Extraluminal Device, Open Approach */
"04LK0DZ" = "1" /* Occlusion of Right Femoral Artery with Intraluminal Device, Open Approach */
"04LK0ZZ" = "1" /* Occlusion of Right Femoral Artery, Open Approach */
"04LK3CZ" = "1" /* Occlusion of Right Femoral Artery with Extraluminal Device, Percutaneous Approach */
"04LK3DZ" = "1" /* Occlusion of Right Femoral Artery with Intraluminal Device, Percutaneous Approach */
"04LK3ZZ" = "1" /* Occlusion of Right Femoral Artery, Percutaneous Approach */
"04LK4CZ" = "1" /* Occlusion of Right Femoral Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LK4DZ" = "1" /* Occlusion of Right Femoral Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LK4ZZ" = "1" /* Occlusion of Right Femoral Artery, Percutaneous Endoscopic Approach */
"04LL0CZ" = "1" /* Occlusion of Left Femoral Artery with Extraluminal Device, Open Approach */
"04LL0DZ" = "1" /* Occlusion of Left Femoral Artery with Intraluminal Device, Open Approach */
"04LL0ZZ" = "1" /* Occlusion of Left Femoral Artery, Open Approach */
"04LL3CZ" = "1" /* Occlusion of Left Femoral Artery with Extraluminal Device, Percutaneous Approach */
"04LL3DZ" = "1" /* Occlusion of Left Femoral Artery with Intraluminal Device, Percutaneous Approach */
"04LL3ZZ" = "1" /* Occlusion of Left Femoral Artery, Percutaneous Approach */
"04LL4CZ" = "1" /* Occlusion of Left Femoral Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LL4DZ" = "1" /* Occlusion of Left Femoral Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LL4ZZ" = "1" /* Occlusion of Left Femoral Artery, Percutaneous Endoscopic Approach */
"04LM0CZ" = "1" /* Occlusion of Right Popliteal Artery with Extraluminal Device, Open Approach */
"04LM0DZ" = "1" /* Occlusion of Right Popliteal Artery with Intraluminal Device, Open Approach */
"04LM0ZZ" = "1" /* Occlusion of Right Popliteal Artery, Open Approach */
"04LM3CZ" = "1" /* Occlusion of Right Popliteal Artery with Extraluminal Device, Percutaneous Approach */
"04LM3DZ" = "1" /* Occlusion of Right Popliteal Artery with Intraluminal Device, Percutaneous Approach */
"04LM3ZZ" = "1" /* Occlusion of Right Popliteal Artery, Percutaneous Approach */
"04LM4CZ" = "1" /* Occlusion of Right Popliteal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LM4DZ" = "1" /* Occlusion of Right Popliteal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LM4ZZ" = "1" /* Occlusion of Right Popliteal Artery, Percutaneous Endoscopic Approach */
"04LN0CZ" = "1" /* Occlusion of Left Popliteal Artery with Extraluminal Device, Open Approach */
"04LN0DZ" = "1" /* Occlusion of Left Popliteal Artery with Intraluminal Device, Open Approach */
"04LN0ZZ" = "1" /* Occlusion of Left Popliteal Artery, Open Approach */
"04LN3CZ" = "1" /* Occlusion of Left Popliteal Artery with Extraluminal Device, Percutaneous Approach */
"04LN3DZ" = "1" /* Occlusion of Left Popliteal Artery with Intraluminal Device, Percutaneous Approach */
"04LN3ZZ" = "1" /* Occlusion of Left Popliteal Artery, Percutaneous Approach */
"04LN4CZ" = "1" /* Occlusion of Left Popliteal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LN4DZ" = "1" /* Occlusion of Left Popliteal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LN4ZZ" = "1" /* Occlusion of Left Popliteal Artery, Percutaneous Endoscopic Approach */
"04LP0CZ" = "1" /* Occlusion of Right Anterior Tibial Artery with Extraluminal Device, Open Approach */
"04LP0DZ" = "1" /* Occlusion of Right Anterior Tibial Artery with Intraluminal Device, Open Approach */
"04LP0ZZ" = "1" /* Occlusion of Right Anterior Tibial Artery, Open Approach */
"04LP3CZ" = "1" /* Occlusion of Right Anterior Tibial Artery with Extraluminal Device, Percutaneous Approach */
"04LP3DZ" = "1" /* Occlusion of Right Anterior Tibial Artery with Intraluminal Device, Percutaneous Approach */
"04LP3ZZ" = "1" /* Occlusion of Right Anterior Tibial Artery, Percutaneous Approach */
"04LP4CZ" = "1" /* Occlusion of Right Anterior Tibial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LP4DZ" = "1" /* Occlusion of Right Anterior Tibial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LP4ZZ" = "1" /* Occlusion of Right Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"04LQ0CZ" = "1" /* Occlusion of Left Anterior Tibial Artery with Extraluminal Device, Open Approach */
"04LQ0DZ" = "1" /* Occlusion of Left Anterior Tibial Artery with Intraluminal Device, Open Approach */
"04LQ0ZZ" = "1" /* Occlusion of Left Anterior Tibial Artery, Open Approach */
"04LQ3CZ" = "1" /* Occlusion of Left Anterior Tibial Artery with Extraluminal Device, Percutaneous Approach */
"04LQ3DZ" = "1" /* Occlusion of Left Anterior Tibial Artery with Intraluminal Device, Percutaneous Approach */
"04LQ3ZZ" = "1" /* Occlusion of Left Anterior Tibial Artery, Percutaneous Approach */
"04LQ4CZ" = "1" /* Occlusion of Left Anterior Tibial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LQ4DZ" = "1" /* Occlusion of Left Anterior Tibial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LQ4ZZ" = "1" /* Occlusion of Left Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"04LR0CZ" = "1" /* Occlusion of Right Posterior Tibial Artery with Extraluminal Device, Open Approach */
"04LR0DZ" = "1" /* Occlusion of Right Posterior Tibial Artery with Intraluminal Device, Open Approach */
"04LR0ZZ" = "1" /* Occlusion of Right Posterior Tibial Artery, Open Approach */
"04LR3CZ" = "1" /* Occlusion of Right Posterior Tibial Artery with Extraluminal Device, Percutaneous Approach */
"04LR3DZ" = "1" /* Occlusion of Right Posterior Tibial Artery with Intraluminal Device, Percutaneous Approach */
"04LR3ZZ" = "1" /* Occlusion of Right Posterior Tibial Artery, Percutaneous Approach */
"04LR4CZ" = "1" /* Occlusion of Right Posterior Tibial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LR4DZ" = "1" /* Occlusion of Right Posterior Tibial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LR4ZZ" = "1" /* Occlusion of Right Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"04LS0CZ" = "1" /* Occlusion of Left Posterior Tibial Artery with Extraluminal Device, Open Approach */
"04LS0DZ" = "1" /* Occlusion of Left Posterior Tibial Artery with Intraluminal Device, Open Approach */
"04LS0ZZ" = "1" /* Occlusion of Left Posterior Tibial Artery, Open Approach */
"04LS3CZ" = "1" /* Occlusion of Left Posterior Tibial Artery with Extraluminal Device, Percutaneous Approach */
"04LS3DZ" = "1" /* Occlusion of Left Posterior Tibial Artery with Intraluminal Device, Percutaneous Approach */
"04LS3ZZ" = "1" /* Occlusion of Left Posterior Tibial Artery, Percutaneous Approach */
"04LS4CZ" = "1" /* Occlusion of Left Posterior Tibial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LS4DZ" = "1" /* Occlusion of Left Posterior Tibial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LS4ZZ" = "1" /* Occlusion of Left Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"04LT0CZ" = "1" /* Occlusion of Right Peroneal Artery with Extraluminal Device, Open Approach */
"04LT0DZ" = "1" /* Occlusion of Right Peroneal Artery with Intraluminal Device, Open Approach */
"04LT0ZZ" = "1" /* Occlusion of Right Peroneal Artery, Open Approach */
"04LT3CZ" = "1" /* Occlusion of Right Peroneal Artery with Extraluminal Device, Percutaneous Approach */
"04LT3DZ" = "1" /* Occlusion of Right Peroneal Artery with Intraluminal Device, Percutaneous Approach */
"04LT3ZZ" = "1" /* Occlusion of Right Peroneal Artery, Percutaneous Approach */
"04LT4CZ" = "1" /* Occlusion of Right Peroneal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LT4DZ" = "1" /* Occlusion of Right Peroneal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LT4ZZ" = "1" /* Occlusion of Right Peroneal Artery, Percutaneous Endoscopic Approach */
"04LU0CZ" = "1" /* Occlusion of Left Peroneal Artery with Extraluminal Device, Open Approach */
"04LU0DZ" = "1" /* Occlusion of Left Peroneal Artery with Intraluminal Device, Open Approach */
"04LU0ZZ" = "1" /* Occlusion of Left Peroneal Artery, Open Approach */
"04LU3CZ" = "1" /* Occlusion of Left Peroneal Artery with Extraluminal Device, Percutaneous Approach */
"04LU3DZ" = "1" /* Occlusion of Left Peroneal Artery with Intraluminal Device, Percutaneous Approach */
"04LU3ZZ" = "1" /* Occlusion of Left Peroneal Artery, Percutaneous Approach */
"04LU4CZ" = "1" /* Occlusion of Left Peroneal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LU4DZ" = "1" /* Occlusion of Left Peroneal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LU4ZZ" = "1" /* Occlusion of Left Peroneal Artery, Percutaneous Endoscopic Approach */
"04LV0CZ" = "1" /* Occlusion of Right Foot Artery with Extraluminal Device, Open Approach */
"04LV0DZ" = "1" /* Occlusion of Right Foot Artery with Intraluminal Device, Open Approach */
"04LV0ZZ" = "1" /* Occlusion of Right Foot Artery, Open Approach */
"04LV3CZ" = "1" /* Occlusion of Right Foot Artery with Extraluminal Device, Percutaneous Approach */
"04LV3DZ" = "1" /* Occlusion of Right Foot Artery with Intraluminal Device, Percutaneous Approach */
"04LV3ZZ" = "1" /* Occlusion of Right Foot Artery, Percutaneous Approach */
"04LV4CZ" = "1" /* Occlusion of Right Foot Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LV4DZ" = "1" /* Occlusion of Right Foot Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LV4ZZ" = "1" /* Occlusion of Right Foot Artery, Percutaneous Endoscopic Approach */
"04LW0CZ" = "1" /* Occlusion of Left Foot Artery with Extraluminal Device, Open Approach */
"04LW0DZ" = "1" /* Occlusion of Left Foot Artery with Intraluminal Device, Open Approach */
"04LW0ZZ" = "1" /* Occlusion of Left Foot Artery, Open Approach */
"04LW3CZ" = "1" /* Occlusion of Left Foot Artery with Extraluminal Device, Percutaneous Approach */
"04LW3DZ" = "1" /* Occlusion of Left Foot Artery with Intraluminal Device, Percutaneous Approach */
"04LW3ZZ" = "1" /* Occlusion of Left Foot Artery, Percutaneous Approach */
"04LW4CZ" = "1" /* Occlusion of Left Foot Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LW4DZ" = "1" /* Occlusion of Left Foot Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LW4ZZ" = "1" /* Occlusion of Left Foot Artery, Percutaneous Endoscopic Approach */
"04LY0CZ" = "1" /* Occlusion of Lower Artery with Extraluminal Device, Open Approach */
"04LY0DZ" = "1" /* Occlusion of Lower Artery with Intraluminal Device, Open Approach */
"04LY0ZZ" = "1" /* Occlusion of Lower Artery, Open Approach */
"04LY3CZ" = "1" /* Occlusion of Lower Artery with Extraluminal Device, Percutaneous Approach */
"04LY3DZ" = "1" /* Occlusion of Lower Artery with Intraluminal Device, Percutaneous Approach */
"04LY3ZZ" = "1" /* Occlusion of Lower Artery, Percutaneous Approach */
"04LY4CZ" = "1" /* Occlusion of Lower Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LY4DZ" = "1" /* Occlusion of Lower Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LY4ZZ" = "1" /* Occlusion of Lower Artery, Percutaneous Endoscopic Approach */
"04Q00ZZ" = "1" /* Repair Abdominal Aorta, Open Approach */
"04Q03ZZ" = "1" /* Repair Abdominal Aorta, Percutaneous Approach */
"04Q04ZZ" = "1" /* Repair Abdominal Aorta, Percutaneous Endoscopic Approach */
"04Q10ZZ" = "1" /* Repair Celiac Artery, Open Approach */
"04Q13ZZ" = "1" /* Repair Celiac Artery, Percutaneous Approach */
"04Q14ZZ" = "1" /* Repair Celiac Artery, Percutaneous Endoscopic Approach */
"04Q20ZZ" = "1" /* Repair Gastric Artery, Open Approach */
"04Q23ZZ" = "1" /* Repair Gastric Artery, Percutaneous Approach */
"04Q24ZZ" = "1" /* Repair Gastric Artery, Percutaneous Endoscopic Approach */
"04Q30ZZ" = "1" /* Repair Hepatic Artery, Open Approach */
"04Q33ZZ" = "1" /* Repair Hepatic Artery, Percutaneous Approach */
"04Q34ZZ" = "1" /* Repair Hepatic Artery, Percutaneous Endoscopic Approach */
"04Q40ZZ" = "1" /* Repair Splenic Artery, Open Approach */
"04Q43ZZ" = "1" /* Repair Splenic Artery, Percutaneous Approach */
"04Q44ZZ" = "1" /* Repair Splenic Artery, Percutaneous Endoscopic Approach */
"04Q50ZZ" = "1" /* Repair Superior Mesenteric Artery, Open Approach */
"04Q53ZZ" = "1" /* Repair Superior Mesenteric Artery, Percutaneous Approach */
"04Q54ZZ" = "1" /* Repair Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04Q60ZZ" = "1" /* Repair Right Colic Artery, Open Approach */
"04Q63ZZ" = "1" /* Repair Right Colic Artery, Percutaneous Approach */
"04Q64ZZ" = "1" /* Repair Right Colic Artery, Percutaneous Endoscopic Approach */
"04Q70ZZ" = "1" /* Repair Left Colic Artery, Open Approach */
"04Q73ZZ" = "1" /* Repair Left Colic Artery, Percutaneous Approach */
"04Q74ZZ" = "1" /* Repair Left Colic Artery, Percutaneous Endoscopic Approach */
"04Q80ZZ" = "1" /* Repair Middle Colic Artery, Open Approach */
"04Q83ZZ" = "1" /* Repair Middle Colic Artery, Percutaneous Approach */
"04Q84ZZ" = "1" /* Repair Middle Colic Artery, Percutaneous Endoscopic Approach */
"04Q90ZZ" = "1" /* Repair Right Renal Artery, Open Approach */
"04Q93ZZ" = "1" /* Repair Right Renal Artery, Percutaneous Approach */
"04Q94ZZ" = "1" /* Repair Right Renal Artery, Percutaneous Endoscopic Approach */
"04QA0ZZ" = "1" /* Repair Left Renal Artery, Open Approach */
"04QA3ZZ" = "1" /* Repair Left Renal Artery, Percutaneous Approach */
"04QA4ZZ" = "1" /* Repair Left Renal Artery, Percutaneous Endoscopic Approach */
"04QB0ZZ" = "1" /* Repair Inferior Mesenteric Artery, Open Approach */
"04QB3ZZ" = "1" /* Repair Inferior Mesenteric Artery, Percutaneous Approach */
"04QB4ZZ" = "1" /* Repair Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04QC0ZZ" = "1" /* Repair Right Common Iliac Artery, Open Approach */
"04QC3ZZ" = "1" /* Repair Right Common Iliac Artery, Percutaneous Approach */
"04QC4ZZ" = "1" /* Repair Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"04QD0ZZ" = "1" /* Repair Left Common Iliac Artery, Open Approach */
"04QD3ZZ" = "1" /* Repair Left Common Iliac Artery, Percutaneous Approach */
"04QD4ZZ" = "1" /* Repair Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"04QE0ZZ" = "1" /* Repair Right Internal Iliac Artery, Open Approach */
"04QE3ZZ" = "1" /* Repair Right Internal Iliac Artery, Percutaneous Approach */
"04QE4ZZ" = "1" /* Repair Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04QF0ZZ" = "1" /* Repair Left Internal Iliac Artery, Open Approach */
"04QF3ZZ" = "1" /* Repair Left Internal Iliac Artery, Percutaneous Approach */
"04QF4ZZ" = "1" /* Repair Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04QH0ZZ" = "1" /* Repair Right External Iliac Artery, Open Approach */
"04QH3ZZ" = "1" /* Repair Right External Iliac Artery, Percutaneous Approach */
"04QH4ZZ" = "1" /* Repair Right External Iliac Artery, Percutaneous Endoscopic Approach */
"04QJ0ZZ" = "1" /* Repair Left External Iliac Artery, Open Approach */
"04QJ3ZZ" = "1" /* Repair Left External Iliac Artery, Percutaneous Approach */
"04QJ4ZZ" = "1" /* Repair Left External Iliac Artery, Percutaneous Endoscopic Approach */
"04QK0ZZ" = "1" /* Repair Right Femoral Artery, Open Approach */
"04QK3ZZ" = "1" /* Repair Right Femoral Artery, Percutaneous Approach */
"04QK4ZZ" = "1" /* Repair Right Femoral Artery, Percutaneous Endoscopic Approach */
"04QL0ZZ" = "1" /* Repair Left Femoral Artery, Open Approach */
"04QL3ZZ" = "1" /* Repair Left Femoral Artery, Percutaneous Approach */
"04QL4ZZ" = "1" /* Repair Left Femoral Artery, Percutaneous Endoscopic Approach */
"04QM0ZZ" = "1" /* Repair Right Popliteal Artery, Open Approach */
"04QM3ZZ" = "1" /* Repair Right Popliteal Artery, Percutaneous Approach */
"04QM4ZZ" = "1" /* Repair Right Popliteal Artery, Percutaneous Endoscopic Approach */
"04QN0ZZ" = "1" /* Repair Left Popliteal Artery, Open Approach */
"04QN3ZZ" = "1" /* Repair Left Popliteal Artery, Percutaneous Approach */
"04QN4ZZ" = "1" /* Repair Left Popliteal Artery, Percutaneous Endoscopic Approach */
"04QP0ZZ" = "1" /* Repair Right Anterior Tibial Artery, Open Approach */
"04QP3ZZ" = "1" /* Repair Right Anterior Tibial Artery, Percutaneous Approach */
"04QP4ZZ" = "1" /* Repair Right Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"04QQ0ZZ" = "1" /* Repair Left Anterior Tibial Artery, Open Approach */
"04QQ3ZZ" = "1" /* Repair Left Anterior Tibial Artery, Percutaneous Approach */
"04QQ4ZZ" = "1" /* Repair Left Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"04QR0ZZ" = "1" /* Repair Right Posterior Tibial Artery, Open Approach */
"04QR3ZZ" = "1" /* Repair Right Posterior Tibial Artery, Percutaneous Approach */
"04QR4ZZ" = "1" /* Repair Right Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"04QS0ZZ" = "1" /* Repair Left Posterior Tibial Artery, Open Approach */
"04QS3ZZ" = "1" /* Repair Left Posterior Tibial Artery, Percutaneous Approach */
"04QS4ZZ" = "1" /* Repair Left Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"04QT0ZZ" = "1" /* Repair Right Peroneal Artery, Open Approach */
"04QT3ZZ" = "1" /* Repair Right Peroneal Artery, Percutaneous Approach */
"04QT4ZZ" = "1" /* Repair Right Peroneal Artery, Percutaneous Endoscopic Approach */
"04QU0ZZ" = "1" /* Repair Left Peroneal Artery, Open Approach */
"04QU3ZZ" = "1" /* Repair Left Peroneal Artery, Percutaneous Approach */
"04QU4ZZ" = "1" /* Repair Left Peroneal Artery, Percutaneous Endoscopic Approach */
"04QV0ZZ" = "1" /* Repair Right Foot Artery, Open Approach */
"04QV3ZZ" = "1" /* Repair Right Foot Artery, Percutaneous Approach */
"04QV4ZZ" = "1" /* Repair Right Foot Artery, Percutaneous Endoscopic Approach */
"04QW0ZZ" = "1" /* Repair Left Foot Artery, Open Approach */
"04QW3ZZ" = "1" /* Repair Left Foot Artery, Percutaneous Approach */
"04QW4ZZ" = "1" /* Repair Left Foot Artery, Percutaneous Endoscopic Approach */
"04QY0ZZ" = "1" /* Repair Lower Artery, Open Approach */
"04QY3ZZ" = "1" /* Repair Lower Artery, Percutaneous Approach */
"04QY4ZZ" = "1" /* Repair Lower Artery, Percutaneous Endoscopic Approach */
"04WY0DZ" = "1" /* Revision of Intraluminal Device in Lower Artery, Open Approach */
"04WY0JZ" = "1" /* Revision of Synthetic Substitute in Lower Artery, Open Approach */
"04WY0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Artery, Open Approach */
"04WY3DZ" = "1" /* Revision of Intraluminal Device in Lower Artery, Percutaneous Approach */
"04WY3JZ" = "1" /* Revision of Synthetic Substitute in Lower Artery, Percutaneous Approach */
"04WY3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Artery, Percutaneous Approach */
"04WY4DZ" = "1" /* Revision of Intraluminal Device in Lower Artery, Percutaneous Endoscopic Approach */
"04WY4JZ" = "1" /* Revision of Synthetic Substitute in Lower Artery, Percutaneous Endoscopic Approach */
"04WY4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Artery, Percutaneous Endoscopic Approach */
"05L00CZ" = "1" /* Occlusion of Azygos Vein with Extraluminal Device, Open Approach */
"05L00DZ" = "1" /* Occlusion of Azygos Vein with Intraluminal Device, Open Approach */
"05L00ZZ" = "1" /* Occlusion of Azygos Vein, Open Approach */
"05L03CZ" = "1" /* Occlusion of Azygos Vein with Extraluminal Device, Percutaneous Approach */
"05L03DZ" = "1" /* Occlusion of Azygos Vein with Intraluminal Device, Percutaneous Approach */
"05L03ZZ" = "1" /* Occlusion of Azygos Vein, Percutaneous Approach */
"05L04CZ" = "1" /* Occlusion of Azygos Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L04DZ" = "1" /* Occlusion of Azygos Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L04ZZ" = "1" /* Occlusion of Azygos Vein, Percutaneous Endoscopic Approach */
"05L10CZ" = "1" /* Occlusion of Hemiazygos Vein with Extraluminal Device, Open Approach */
"05L10DZ" = "1" /* Occlusion of Hemiazygos Vein with Intraluminal Device, Open Approach */
"05L10ZZ" = "1" /* Occlusion of Hemiazygos Vein, Open Approach */
"05L13CZ" = "1" /* Occlusion of Hemiazygos Vein with Extraluminal Device, Percutaneous Approach */
"05L13DZ" = "1" /* Occlusion of Hemiazygos Vein with Intraluminal Device, Percutaneous Approach */
"05L13ZZ" = "1" /* Occlusion of Hemiazygos Vein, Percutaneous Approach */
"05L14CZ" = "1" /* Occlusion of Hemiazygos Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L14DZ" = "1" /* Occlusion of Hemiazygos Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L14ZZ" = "1" /* Occlusion of Hemiazygos Vein, Percutaneous Endoscopic Approach */
"05L30CZ" = "1" /* Occlusion of Right Innominate Vein with Extraluminal Device, Open Approach */
"05L30DZ" = "1" /* Occlusion of Right Innominate Vein with Intraluminal Device, Open Approach */
"05L30ZZ" = "1" /* Occlusion of Right Innominate Vein, Open Approach */
"05L33CZ" = "1" /* Occlusion of Right Innominate Vein with Extraluminal Device, Percutaneous Approach */
"05L33DZ" = "1" /* Occlusion of Right Innominate Vein with Intraluminal Device, Percutaneous Approach */
"05L33ZZ" = "1" /* Occlusion of Right Innominate Vein, Percutaneous Approach */
"05L34CZ" = "1" /* Occlusion of Right Innominate Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L34DZ" = "1" /* Occlusion of Right Innominate Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L34ZZ" = "1" /* Occlusion of Right Innominate Vein, Percutaneous Endoscopic Approach */
"05L40CZ" = "1" /* Occlusion of Left Innominate Vein with Extraluminal Device, Open Approach */
"05L40DZ" = "1" /* Occlusion of Left Innominate Vein with Intraluminal Device, Open Approach */
"05L40ZZ" = "1" /* Occlusion of Left Innominate Vein, Open Approach */
"05L43CZ" = "1" /* Occlusion of Left Innominate Vein with Extraluminal Device, Percutaneous Approach */
"05L43DZ" = "1" /* Occlusion of Left Innominate Vein with Intraluminal Device, Percutaneous Approach */
"05L43ZZ" = "1" /* Occlusion of Left Innominate Vein, Percutaneous Approach */
"05L44CZ" = "1" /* Occlusion of Left Innominate Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L44DZ" = "1" /* Occlusion of Left Innominate Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L44ZZ" = "1" /* Occlusion of Left Innominate Vein, Percutaneous Endoscopic Approach */
"05L50CZ" = "1" /* Occlusion of Right Subclavian Vein with Extraluminal Device, Open Approach */
"05L50DZ" = "1" /* Occlusion of Right Subclavian Vein with Intraluminal Device, Open Approach */
"05L50ZZ" = "1" /* Occlusion of Right Subclavian Vein, Open Approach */
"05L53CZ" = "1" /* Occlusion of Right Subclavian Vein with Extraluminal Device, Percutaneous Approach */
"05L53DZ" = "1" /* Occlusion of Right Subclavian Vein with Intraluminal Device, Percutaneous Approach */
"05L53ZZ" = "1" /* Occlusion of Right Subclavian Vein, Percutaneous Approach */
"05L54CZ" = "1" /* Occlusion of Right Subclavian Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L54DZ" = "1" /* Occlusion of Right Subclavian Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L54ZZ" = "1" /* Occlusion of Right Subclavian Vein, Percutaneous Endoscopic Approach */
"05L60CZ" = "1" /* Occlusion of Left Subclavian Vein with Extraluminal Device, Open Approach */
"05L60DZ" = "1" /* Occlusion of Left Subclavian Vein with Intraluminal Device, Open Approach */
"05L60ZZ" = "1" /* Occlusion of Left Subclavian Vein, Open Approach */
"05L63CZ" = "1" /* Occlusion of Left Subclavian Vein with Extraluminal Device, Percutaneous Approach */
"05L63DZ" = "1" /* Occlusion of Left Subclavian Vein with Intraluminal Device, Percutaneous Approach */
"05L63ZZ" = "1" /* Occlusion of Left Subclavian Vein, Percutaneous Approach */
"05L64CZ" = "1" /* Occlusion of Left Subclavian Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L64DZ" = "1" /* Occlusion of Left Subclavian Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L64ZZ" = "1" /* Occlusion of Left Subclavian Vein, Percutaneous Endoscopic Approach */
"05L70CZ" = "1" /* Occlusion of Right Axillary Vein with Extraluminal Device, Open Approach */
"05L70DZ" = "1" /* Occlusion of Right Axillary Vein with Intraluminal Device, Open Approach */
"05L70ZZ" = "1" /* Occlusion of Right Axillary Vein, Open Approach */
"05L73CZ" = "1" /* Occlusion of Right Axillary Vein with Extraluminal Device, Percutaneous Approach */
"05L73DZ" = "1" /* Occlusion of Right Axillary Vein with Intraluminal Device, Percutaneous Approach */
"05L73ZZ" = "1" /* Occlusion of Right Axillary Vein, Percutaneous Approach */
"05L74CZ" = "1" /* Occlusion of Right Axillary Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L74DZ" = "1" /* Occlusion of Right Axillary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L74ZZ" = "1" /* Occlusion of Right Axillary Vein, Percutaneous Endoscopic Approach */
"05L80CZ" = "1" /* Occlusion of Left Axillary Vein with Extraluminal Device, Open Approach */
"05L80DZ" = "1" /* Occlusion of Left Axillary Vein with Intraluminal Device, Open Approach */
"05L80ZZ" = "1" /* Occlusion of Left Axillary Vein, Open Approach */
"05L83CZ" = "1" /* Occlusion of Left Axillary Vein with Extraluminal Device, Percutaneous Approach */
"05L83DZ" = "1" /* Occlusion of Left Axillary Vein with Intraluminal Device, Percutaneous Approach */
"05L83ZZ" = "1" /* Occlusion of Left Axillary Vein, Percutaneous Approach */
"05L84CZ" = "1" /* Occlusion of Left Axillary Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L84DZ" = "1" /* Occlusion of Left Axillary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L84ZZ" = "1" /* Occlusion of Left Axillary Vein, Percutaneous Endoscopic Approach */
"05L90CZ" = "1" /* Occlusion of Right Brachial Vein with Extraluminal Device, Open Approach */
"05L90DZ" = "1" /* Occlusion of Right Brachial Vein with Intraluminal Device, Open Approach */
"05L90ZZ" = "1" /* Occlusion of Right Brachial Vein, Open Approach */
"05L93CZ" = "1" /* Occlusion of Right Brachial Vein with Extraluminal Device, Percutaneous Approach */
"05L93DZ" = "1" /* Occlusion of Right Brachial Vein with Intraluminal Device, Percutaneous Approach */
"05L93ZZ" = "1" /* Occlusion of Right Brachial Vein, Percutaneous Approach */
"05L94CZ" = "1" /* Occlusion of Right Brachial Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L94DZ" = "1" /* Occlusion of Right Brachial Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L94ZZ" = "1" /* Occlusion of Right Brachial Vein, Percutaneous Endoscopic Approach */
"05LA0CZ" = "1" /* Occlusion of Left Brachial Vein with Extraluminal Device, Open Approach */
"05LA0DZ" = "1" /* Occlusion of Left Brachial Vein with Intraluminal Device, Open Approach */
"05LA0ZZ" = "1" /* Occlusion of Left Brachial Vein, Open Approach */
"05LA3CZ" = "1" /* Occlusion of Left Brachial Vein with Extraluminal Device, Percutaneous Approach */
"05LA3DZ" = "1" /* Occlusion of Left Brachial Vein with Intraluminal Device, Percutaneous Approach */
"05LA3ZZ" = "1" /* Occlusion of Left Brachial Vein, Percutaneous Approach */
"05LA4CZ" = "1" /* Occlusion of Left Brachial Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LA4DZ" = "1" /* Occlusion of Left Brachial Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LA4ZZ" = "1" /* Occlusion of Left Brachial Vein, Percutaneous Endoscopic Approach */
"05LB0CZ" = "1" /* Occlusion of Right Basilic Vein with Extraluminal Device, Open Approach */
"05LB0DZ" = "1" /* Occlusion of Right Basilic Vein with Intraluminal Device, Open Approach */
"05LB0ZZ" = "1" /* Occlusion of Right Basilic Vein, Open Approach */
"05LB3CZ" = "1" /* Occlusion of Right Basilic Vein with Extraluminal Device, Percutaneous Approach */
"05LB3DZ" = "1" /* Occlusion of Right Basilic Vein with Intraluminal Device, Percutaneous Approach */
"05LB3ZZ" = "1" /* Occlusion of Right Basilic Vein, Percutaneous Approach */
"05LB4CZ" = "1" /* Occlusion of Right Basilic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LB4DZ" = "1" /* Occlusion of Right Basilic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LB4ZZ" = "1" /* Occlusion of Right Basilic Vein, Percutaneous Endoscopic Approach */
"05LC0CZ" = "1" /* Occlusion of Left Basilic Vein with Extraluminal Device, Open Approach */
"05LC0DZ" = "1" /* Occlusion of Left Basilic Vein with Intraluminal Device, Open Approach */
"05LC0ZZ" = "1" /* Occlusion of Left Basilic Vein, Open Approach */
"05LC3CZ" = "1" /* Occlusion of Left Basilic Vein with Extraluminal Device, Percutaneous Approach */
"05LC3DZ" = "1" /* Occlusion of Left Basilic Vein with Intraluminal Device, Percutaneous Approach */
"05LC3ZZ" = "1" /* Occlusion of Left Basilic Vein, Percutaneous Approach */
"05LC4CZ" = "1" /* Occlusion of Left Basilic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LC4DZ" = "1" /* Occlusion of Left Basilic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LC4ZZ" = "1" /* Occlusion of Left Basilic Vein, Percutaneous Endoscopic Approach */
"05LD0CZ" = "1" /* Occlusion of Right Cephalic Vein with Extraluminal Device, Open Approach */
"05LD0DZ" = "1" /* Occlusion of Right Cephalic Vein with Intraluminal Device, Open Approach */
"05LD0ZZ" = "1" /* Occlusion of Right Cephalic Vein, Open Approach */
"05LD3CZ" = "1" /* Occlusion of Right Cephalic Vein with Extraluminal Device, Percutaneous Approach */
"05LD3DZ" = "1" /* Occlusion of Right Cephalic Vein with Intraluminal Device, Percutaneous Approach */
"05LD3ZZ" = "1" /* Occlusion of Right Cephalic Vein, Percutaneous Approach */
"05LD4CZ" = "1" /* Occlusion of Right Cephalic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LD4DZ" = "1" /* Occlusion of Right Cephalic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LD4ZZ" = "1" /* Occlusion of Right Cephalic Vein, Percutaneous Endoscopic Approach */
"05LF0CZ" = "1" /* Occlusion of Left Cephalic Vein with Extraluminal Device, Open Approach */
"05LF0DZ" = "1" /* Occlusion of Left Cephalic Vein with Intraluminal Device, Open Approach */
"05LF0ZZ" = "1" /* Occlusion of Left Cephalic Vein, Open Approach */
"05LF3CZ" = "1" /* Occlusion of Left Cephalic Vein with Extraluminal Device, Percutaneous Approach */
"05LF3DZ" = "1" /* Occlusion of Left Cephalic Vein with Intraluminal Device, Percutaneous Approach */
"05LF3ZZ" = "1" /* Occlusion of Left Cephalic Vein, Percutaneous Approach */
"05LF4CZ" = "1" /* Occlusion of Left Cephalic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LF4DZ" = "1" /* Occlusion of Left Cephalic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LF4ZZ" = "1" /* Occlusion of Left Cephalic Vein, Percutaneous Endoscopic Approach */
"05LG0CZ" = "1" /* Occlusion of Right Hand Vein with Extraluminal Device, Open Approach */
"05LG0DZ" = "1" /* Occlusion of Right Hand Vein with Intraluminal Device, Open Approach */
"05LG0ZZ" = "1" /* Occlusion of Right Hand Vein, Open Approach */
"05LG3CZ" = "1" /* Occlusion of Right Hand Vein with Extraluminal Device, Percutaneous Approach */
"05LG3DZ" = "1" /* Occlusion of Right Hand Vein with Intraluminal Device, Percutaneous Approach */
"05LG3ZZ" = "1" /* Occlusion of Right Hand Vein, Percutaneous Approach */
"05LG4CZ" = "1" /* Occlusion of Right Hand Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LG4DZ" = "1" /* Occlusion of Right Hand Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LG4ZZ" = "1" /* Occlusion of Right Hand Vein, Percutaneous Endoscopic Approach */
"05LH0CZ" = "1" /* Occlusion of Left Hand Vein with Extraluminal Device, Open Approach */
"05LH0DZ" = "1" /* Occlusion of Left Hand Vein with Intraluminal Device, Open Approach */
"05LH0ZZ" = "1" /* Occlusion of Left Hand Vein, Open Approach */
"05LH3CZ" = "1" /* Occlusion of Left Hand Vein with Extraluminal Device, Percutaneous Approach */
"05LH3DZ" = "1" /* Occlusion of Left Hand Vein with Intraluminal Device, Percutaneous Approach */
"05LH3ZZ" = "1" /* Occlusion of Left Hand Vein, Percutaneous Approach */
"05LH4CZ" = "1" /* Occlusion of Left Hand Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LH4DZ" = "1" /* Occlusion of Left Hand Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LH4ZZ" = "1" /* Occlusion of Left Hand Vein, Percutaneous Endoscopic Approach */
"05LL0CZ" = "1" /* Occlusion of Intracranial Vein with Extraluminal Device, Open Approach */
"05LL0DZ" = "1" /* Occlusion of Intracranial Vein with Intraluminal Device, Open Approach */
"05LL0ZZ" = "1" /* Occlusion of Intracranial Vein, Open Approach */
"05LL3CZ" = "1" /* Occlusion of Intracranial Vein with Extraluminal Device, Percutaneous Approach */
"05LL3DZ" = "1" /* Occlusion of Intracranial Vein with Intraluminal Device, Percutaneous Approach */
"05LL3ZZ" = "1" /* Occlusion of Intracranial Vein, Percutaneous Approach */
"05LL4CZ" = "1" /* Occlusion of Intracranial Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LL4DZ" = "1" /* Occlusion of Intracranial Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LL4ZZ" = "1" /* Occlusion of Intracranial Vein, Percutaneous Endoscopic Approach */
"05LM0CZ" = "1" /* Occlusion of Right Internal Jugular Vein with Extraluminal Device, Open Approach */
"05LM0DZ" = "1" /* Occlusion of Right Internal Jugular Vein with Intraluminal Device, Open Approach */
"05LM0ZZ" = "1" /* Occlusion of Right Internal Jugular Vein, Open Approach */
"05LM3CZ" = "1" /* Occlusion of Right Internal Jugular Vein with Extraluminal Device, Percutaneous Approach */
"05LM3DZ" = "1" /* Occlusion of Right Internal Jugular Vein with Intraluminal Device, Percutaneous Approach */
"05LM3ZZ" = "1" /* Occlusion of Right Internal Jugular Vein, Percutaneous Approach */
"05LM4CZ" = "1" /* Occlusion of Right Internal Jugular Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LM4DZ" = "1" /* Occlusion of Right Internal Jugular Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LM4ZZ" = "1" /* Occlusion of Right Internal Jugular Vein, Percutaneous Endoscopic Approach */
"05LN0CZ" = "1" /* Occlusion of Left Internal Jugular Vein with Extraluminal Device, Open Approach */
"05LN0DZ" = "1" /* Occlusion of Left Internal Jugular Vein with Intraluminal Device, Open Approach */
"05LN0ZZ" = "1" /* Occlusion of Left Internal Jugular Vein, Open Approach */
"05LN3CZ" = "1" /* Occlusion of Left Internal Jugular Vein with Extraluminal Device, Percutaneous Approach */
"05LN3DZ" = "1" /* Occlusion of Left Internal Jugular Vein with Intraluminal Device, Percutaneous Approach */
"05LN3ZZ" = "1" /* Occlusion of Left Internal Jugular Vein, Percutaneous Approach */
"05LN4CZ" = "1" /* Occlusion of Left Internal Jugular Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LN4DZ" = "1" /* Occlusion of Left Internal Jugular Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LN4ZZ" = "1" /* Occlusion of Left Internal Jugular Vein, Percutaneous Endoscopic Approach */
"05LP0CZ" = "1" /* Occlusion of Right External Jugular Vein with Extraluminal Device, Open Approach */
"05LP0DZ" = "1" /* Occlusion of Right External Jugular Vein with Intraluminal Device, Open Approach */
"05LP0ZZ" = "1" /* Occlusion of Right External Jugular Vein, Open Approach */
"05LP3CZ" = "1" /* Occlusion of Right External Jugular Vein with Extraluminal Device, Percutaneous Approach */
"05LP3DZ" = "1" /* Occlusion of Right External Jugular Vein with Intraluminal Device, Percutaneous Approach */
"05LP3ZZ" = "1" /* Occlusion of Right External Jugular Vein, Percutaneous Approach */
"05LP4CZ" = "1" /* Occlusion of Right External Jugular Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LP4DZ" = "1" /* Occlusion of Right External Jugular Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LP4ZZ" = "1" /* Occlusion of Right External Jugular Vein, Percutaneous Endoscopic Approach */
"05LQ0CZ" = "1" /* Occlusion of Left External Jugular Vein with Extraluminal Device, Open Approach */
"05LQ0DZ" = "1" /* Occlusion of Left External Jugular Vein with Intraluminal Device, Open Approach */
"05LQ0ZZ" = "1" /* Occlusion of Left External Jugular Vein, Open Approach */
"05LQ3CZ" = "1" /* Occlusion of Left External Jugular Vein with Extraluminal Device, Percutaneous Approach */
"05LQ3DZ" = "1" /* Occlusion of Left External Jugular Vein with Intraluminal Device, Percutaneous Approach */
"05LQ3ZZ" = "1" /* Occlusion of Left External Jugular Vein, Percutaneous Approach */
"05LQ4CZ" = "1" /* Occlusion of Left External Jugular Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LQ4DZ" = "1" /* Occlusion of Left External Jugular Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LQ4ZZ" = "1" /* Occlusion of Left External Jugular Vein, Percutaneous Endoscopic Approach */
"05LR0CZ" = "1" /* Occlusion of Right Vertebral Vein with Extraluminal Device, Open Approach */
"05LR0DZ" = "1" /* Occlusion of Right Vertebral Vein with Intraluminal Device, Open Approach */
"05LR0ZZ" = "1" /* Occlusion of Right Vertebral Vein, Open Approach */
"05LR3CZ" = "1" /* Occlusion of Right Vertebral Vein with Extraluminal Device, Percutaneous Approach */
"05LR3DZ" = "1" /* Occlusion of Right Vertebral Vein with Intraluminal Device, Percutaneous Approach */
"05LR3ZZ" = "1" /* Occlusion of Right Vertebral Vein, Percutaneous Approach */
"05LR4CZ" = "1" /* Occlusion of Right Vertebral Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LR4DZ" = "1" /* Occlusion of Right Vertebral Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LR4ZZ" = "1" /* Occlusion of Right Vertebral Vein, Percutaneous Endoscopic Approach */
"05LS0CZ" = "1" /* Occlusion of Left Vertebral Vein with Extraluminal Device, Open Approach */
"05LS0DZ" = "1" /* Occlusion of Left Vertebral Vein with Intraluminal Device, Open Approach */
"05LS0ZZ" = "1" /* Occlusion of Left Vertebral Vein, Open Approach */
"05LS3CZ" = "1" /* Occlusion of Left Vertebral Vein with Extraluminal Device, Percutaneous Approach */
"05LS3DZ" = "1" /* Occlusion of Left Vertebral Vein with Intraluminal Device, Percutaneous Approach */
"05LS3ZZ" = "1" /* Occlusion of Left Vertebral Vein, Percutaneous Approach */
"05LS4CZ" = "1" /* Occlusion of Left Vertebral Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LS4DZ" = "1" /* Occlusion of Left Vertebral Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LS4ZZ" = "1" /* Occlusion of Left Vertebral Vein, Percutaneous Endoscopic Approach */
"05LT0CZ" = "1" /* Occlusion of Right Face Vein with Extraluminal Device, Open Approach */
"05LT0DZ" = "1" /* Occlusion of Right Face Vein with Intraluminal Device, Open Approach */
"05LT0ZZ" = "1" /* Occlusion of Right Face Vein, Open Approach */
"05LT3CZ" = "1" /* Occlusion of Right Face Vein with Extraluminal Device, Percutaneous Approach */
"05LT3DZ" = "1" /* Occlusion of Right Face Vein with Intraluminal Device, Percutaneous Approach */
"05LT3ZZ" = "1" /* Occlusion of Right Face Vein, Percutaneous Approach */
"05LT4CZ" = "1" /* Occlusion of Right Face Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LT4DZ" = "1" /* Occlusion of Right Face Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LT4ZZ" = "1" /* Occlusion of Right Face Vein, Percutaneous Endoscopic Approach */
"05LV0CZ" = "1" /* Occlusion of Left Face Vein with Extraluminal Device, Open Approach */
"05LV0DZ" = "1" /* Occlusion of Left Face Vein with Intraluminal Device, Open Approach */
"05LV0ZZ" = "1" /* Occlusion of Left Face Vein, Open Approach */
"05LV3CZ" = "1" /* Occlusion of Left Face Vein with Extraluminal Device, Percutaneous Approach */
"05LV3DZ" = "1" /* Occlusion of Left Face Vein with Intraluminal Device, Percutaneous Approach */
"05LV3ZZ" = "1" /* Occlusion of Left Face Vein, Percutaneous Approach */
"05LV4CZ" = "1" /* Occlusion of Left Face Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LV4DZ" = "1" /* Occlusion of Left Face Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LV4ZZ" = "1" /* Occlusion of Left Face Vein, Percutaneous Endoscopic Approach */
"05LY0CZ" = "1" /* Occlusion of Upper Vein with Extraluminal Device, Open Approach */
"05LY0DZ" = "1" /* Occlusion of Upper Vein with Intraluminal Device, Open Approach */
"05LY0ZZ" = "1" /* Occlusion of Upper Vein, Open Approach */
"05LY3CZ" = "1" /* Occlusion of Upper Vein with Extraluminal Device, Percutaneous Approach */
"05LY3DZ" = "1" /* Occlusion of Upper Vein with Intraluminal Device, Percutaneous Approach */
"05LY3ZZ" = "1" /* Occlusion of Upper Vein, Percutaneous Approach */
"05LY4CZ" = "1" /* Occlusion of Upper Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LY4DZ" = "1" /* Occlusion of Upper Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LY4ZZ" = "1" /* Occlusion of Upper Vein, Percutaneous Endoscopic Approach */
"05Q00ZZ" = "1" /* Repair Azygos Vein, Open Approach */
"05Q03ZZ" = "1" /* Repair Azygos Vein, Percutaneous Approach */
"05Q04ZZ" = "1" /* Repair Azygos Vein, Percutaneous Endoscopic Approach */
"05Q10ZZ" = "1" /* Repair Hemiazygos Vein, Open Approach */
"05Q13ZZ" = "1" /* Repair Hemiazygos Vein, Percutaneous Approach */
"05Q14ZZ" = "1" /* Repair Hemiazygos Vein, Percutaneous Endoscopic Approach */
"05Q30ZZ" = "1" /* Repair Right Innominate Vein, Open Approach */
"05Q33ZZ" = "1" /* Repair Right Innominate Vein, Percutaneous Approach */
"05Q34ZZ" = "1" /* Repair Right Innominate Vein, Percutaneous Endoscopic Approach */
"05Q40ZZ" = "1" /* Repair Left Innominate Vein, Open Approach */
"05Q43ZZ" = "1" /* Repair Left Innominate Vein, Percutaneous Approach */
"05Q44ZZ" = "1" /* Repair Left Innominate Vein, Percutaneous Endoscopic Approach */
"05Q50ZZ" = "1" /* Repair Right Subclavian Vein, Open Approach */
"05Q53ZZ" = "1" /* Repair Right Subclavian Vein, Percutaneous Approach */
"05Q54ZZ" = "1" /* Repair Right Subclavian Vein, Percutaneous Endoscopic Approach */
"05Q60ZZ" = "1" /* Repair Left Subclavian Vein, Open Approach */
"05Q63ZZ" = "1" /* Repair Left Subclavian Vein, Percutaneous Approach */
"05Q64ZZ" = "1" /* Repair Left Subclavian Vein, Percutaneous Endoscopic Approach */
"05Q70ZZ" = "1" /* Repair Right Axillary Vein, Open Approach */
"05Q73ZZ" = "1" /* Repair Right Axillary Vein, Percutaneous Approach */
"05Q74ZZ" = "1" /* Repair Right Axillary Vein, Percutaneous Endoscopic Approach */
"05Q80ZZ" = "1" /* Repair Left Axillary Vein, Open Approach */
"05Q83ZZ" = "1" /* Repair Left Axillary Vein, Percutaneous Approach */
"05Q84ZZ" = "1" /* Repair Left Axillary Vein, Percutaneous Endoscopic Approach */
"05Q90ZZ" = "1" /* Repair Right Brachial Vein, Open Approach */
"05Q93ZZ" = "1" /* Repair Right Brachial Vein, Percutaneous Approach */
"05Q94ZZ" = "1" /* Repair Right Brachial Vein, Percutaneous Endoscopic Approach */
"05QA0ZZ" = "1" /* Repair Left Brachial Vein, Open Approach */
"05QA3ZZ" = "1" /* Repair Left Brachial Vein, Percutaneous Approach */
"05QA4ZZ" = "1" /* Repair Left Brachial Vein, Percutaneous Endoscopic Approach */
"05QB0ZZ" = "1" /* Repair Right Basilic Vein, Open Approach */
"05QB3ZZ" = "1" /* Repair Right Basilic Vein, Percutaneous Approach */
"05QB4ZZ" = "1" /* Repair Right Basilic Vein, Percutaneous Endoscopic Approach */
"05QC0ZZ" = "1" /* Repair Left Basilic Vein, Open Approach */
"05QC3ZZ" = "1" /* Repair Left Basilic Vein, Percutaneous Approach */
"05QC4ZZ" = "1" /* Repair Left Basilic Vein, Percutaneous Endoscopic Approach */
"05QD0ZZ" = "1" /* Repair Right Cephalic Vein, Open Approach */
"05QD3ZZ" = "1" /* Repair Right Cephalic Vein, Percutaneous Approach */
"05QD4ZZ" = "1" /* Repair Right Cephalic Vein, Percutaneous Endoscopic Approach */
"05QF0ZZ" = "1" /* Repair Left Cephalic Vein, Open Approach */
"05QF3ZZ" = "1" /* Repair Left Cephalic Vein, Percutaneous Approach */
"05QF4ZZ" = "1" /* Repair Left Cephalic Vein, Percutaneous Endoscopic Approach */
"05QG0ZZ" = "1" /* Repair Right Hand Vein, Open Approach */
"05QG3ZZ" = "1" /* Repair Right Hand Vein, Percutaneous Approach */
"05QG4ZZ" = "1" /* Repair Right Hand Vein, Percutaneous Endoscopic Approach */
"05QH0ZZ" = "1" /* Repair Left Hand Vein, Open Approach */
"05QH3ZZ" = "1" /* Repair Left Hand Vein, Percutaneous Approach */
"05QH4ZZ" = "1" /* Repair Left Hand Vein, Percutaneous Endoscopic Approach */
"05QL0ZZ" = "1" /* Repair Intracranial Vein, Open Approach */
"05QL3ZZ" = "1" /* Repair Intracranial Vein, Percutaneous Approach */
"05QL4ZZ" = "1" /* Repair Intracranial Vein, Percutaneous Endoscopic Approach */
"05QM0ZZ" = "1" /* Repair Right Internal Jugular Vein, Open Approach */
"05QM3ZZ" = "1" /* Repair Right Internal Jugular Vein, Percutaneous Approach */
"05QM4ZZ" = "1" /* Repair Right Internal Jugular Vein, Percutaneous Endoscopic Approach */
"05QN0ZZ" = "1" /* Repair Left Internal Jugular Vein, Open Approach */
"05QN3ZZ" = "1" /* Repair Left Internal Jugular Vein, Percutaneous Approach */
"05QN4ZZ" = "1" /* Repair Left Internal Jugular Vein, Percutaneous Endoscopic Approach */
"05QP0ZZ" = "1" /* Repair Right External Jugular Vein, Open Approach */
"05QP3ZZ" = "1" /* Repair Right External Jugular Vein, Percutaneous Approach */
"05QP4ZZ" = "1" /* Repair Right External Jugular Vein, Percutaneous Endoscopic Approach */
"05QQ0ZZ" = "1" /* Repair Left External Jugular Vein, Open Approach */
"05QQ3ZZ" = "1" /* Repair Left External Jugular Vein, Percutaneous Approach */
"05QQ4ZZ" = "1" /* Repair Left External Jugular Vein, Percutaneous Endoscopic Approach */
"05QR0ZZ" = "1" /* Repair Right Vertebral Vein, Open Approach */
"05QR3ZZ" = "1" /* Repair Right Vertebral Vein, Percutaneous Approach */
"05QR4ZZ" = "1" /* Repair Right Vertebral Vein, Percutaneous Endoscopic Approach */
"05QS0ZZ" = "1" /* Repair Left Vertebral Vein, Open Approach */
"05QS3ZZ" = "1" /* Repair Left Vertebral Vein, Percutaneous Approach */
"05QS4ZZ" = "1" /* Repair Left Vertebral Vein, Percutaneous Endoscopic Approach */
"05QT0ZZ" = "1" /* Repair Right Face Vein, Open Approach */
"05QT3ZZ" = "1" /* Repair Right Face Vein, Percutaneous Approach */
"05QT4ZZ" = "1" /* Repair Right Face Vein, Percutaneous Endoscopic Approach */
"05QV0ZZ" = "1" /* Repair Left Face Vein, Open Approach */
"05QV3ZZ" = "1" /* Repair Left Face Vein, Percutaneous Approach */
"05QV4ZZ" = "1" /* Repair Left Face Vein, Percutaneous Endoscopic Approach */
"05QY0ZZ" = "1" /* Repair Upper Vein, Open Approach */
"05QY3ZZ" = "1" /* Repair Upper Vein, Percutaneous Approach */
"05QY4ZZ" = "1" /* Repair Upper Vein, Percutaneous Endoscopic Approach */
"05WY0DZ" = "1" /* Revision of Intraluminal Device in Upper Vein, Open Approach */
"05WY0JZ" = "1" /* Revision of Synthetic Substitute in Upper Vein, Open Approach */
"05WY0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Vein, Open Approach */
"05WY3DZ" = "1" /* Revision of Intraluminal Device in Upper Vein, Percutaneous Approach */
"05WY3JZ" = "1" /* Revision of Synthetic Substitute in Upper Vein, Percutaneous Approach */
"05WY3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Vein, Percutaneous Approach */
"05WY4DZ" = "1" /* Revision of Intraluminal Device in Upper Vein, Percutaneous Endoscopic Approach */
"05WY4JZ" = "1" /* Revision of Synthetic Substitute in Upper Vein, Percutaneous Endoscopic Approach */
"05WY4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Vein, Percutaneous Endoscopic Approach */
"06L00CZ" = "1" /* Occlusion of Inferior Vena Cava with Extraluminal Device, Open Approach */
"06L00DZ" = "1" /* Occlusion of Inferior Vena Cava with Intraluminal Device, Open Approach */
"06L00ZZ" = "1" /* Occlusion of Inferior Vena Cava, Open Approach */
"06L03CZ" = "1" /* Occlusion of Inferior Vena Cava with Extraluminal Device, Percutaneous Approach */
"06L03DZ" = "1" /* Occlusion of Inferior Vena Cava with Intraluminal Device, Percutaneous Approach */
"06L03ZZ" = "1" /* Occlusion of Inferior Vena Cava, Percutaneous Approach */
"06L04CZ" = "1" /* Occlusion of Inferior Vena Cava with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L04DZ" = "1" /* Occlusion of Inferior Vena Cava with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L04ZZ" = "1" /* Occlusion of Inferior Vena Cava, Percutaneous Endoscopic Approach */
"06L10CZ" = "1" /* Occlusion of Splenic Vein with Extraluminal Device, Open Approach */
"06L10DZ" = "1" /* Occlusion of Splenic Vein with Intraluminal Device, Open Approach */
"06L10ZZ" = "1" /* Occlusion of Splenic Vein, Open Approach */
"06L13CZ" = "1" /* Occlusion of Splenic Vein with Extraluminal Device, Percutaneous Approach */
"06L13DZ" = "1" /* Occlusion of Splenic Vein with Intraluminal Device, Percutaneous Approach */
"06L13ZZ" = "1" /* Occlusion of Splenic Vein, Percutaneous Approach */
"06L14CZ" = "1" /* Occlusion of Splenic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L14DZ" = "1" /* Occlusion of Splenic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L14ZZ" = "1" /* Occlusion of Splenic Vein, Percutaneous Endoscopic Approach */
"06L20CZ" = "1" /* Occlusion of Gastric Vein with Extraluminal Device, Open Approach */
"06L20DZ" = "1" /* Occlusion of Gastric Vein with Intraluminal Device, Open Approach */
"06L20ZZ" = "1" /* Occlusion of Gastric Vein, Open Approach */
"06L23CZ" = "1" /* Occlusion of Gastric Vein with Extraluminal Device, Percutaneous Approach */
"06L23DZ" = "1" /* Occlusion of Gastric Vein with Intraluminal Device, Percutaneous Approach */
"06L23ZZ" = "1" /* Occlusion of Gastric Vein, Percutaneous Approach */
"06L24CZ" = "1" /* Occlusion of Gastric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L24DZ" = "1" /* Occlusion of Gastric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L24ZZ" = "1" /* Occlusion of Gastric Vein, Percutaneous Endoscopic Approach */
"06L30CZ" = "1" /* Occlusion of Esophageal Vein with Extraluminal Device, Open Approach */
"06L30DZ" = "1" /* Occlusion of Esophageal Vein with Intraluminal Device, Open Approach */
"06L30ZZ" = "1" /* Occlusion of Esophageal Vein, Open Approach */
"06L33CZ" = "1" /* Occlusion of Esophageal Vein with Extraluminal Device, Percutaneous Approach */
"06L33DZ" = "1" /* Occlusion of Esophageal Vein with Intraluminal Device, Percutaneous Approach */
"06L33ZZ" = "1" /* Occlusion of Esophageal Vein, Percutaneous Approach */
"06L34CZ" = "1" /* Occlusion of Esophageal Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L34DZ" = "1" /* Occlusion of Esophageal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L34ZZ" = "1" /* Occlusion of Esophageal Vein, Percutaneous Endoscopic Approach */
"06L40CZ" = "1" /* Occlusion of Hepatic Vein with Extraluminal Device, Open Approach */
"06L40DZ" = "1" /* Occlusion of Hepatic Vein with Intraluminal Device, Open Approach */
"06L40ZZ" = "1" /* Occlusion of Hepatic Vein, Open Approach */
"06L43CZ" = "1" /* Occlusion of Hepatic Vein with Extraluminal Device, Percutaneous Approach */
"06L43DZ" = "1" /* Occlusion of Hepatic Vein with Intraluminal Device, Percutaneous Approach */
"06L43ZZ" = "1" /* Occlusion of Hepatic Vein, Percutaneous Approach */
"06L44CZ" = "1" /* Occlusion of Hepatic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L44DZ" = "1" /* Occlusion of Hepatic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L44ZZ" = "1" /* Occlusion of Hepatic Vein, Percutaneous Endoscopic Approach */
"06L50CZ" = "1" /* Occlusion of Superior Mesenteric Vein with Extraluminal Device, Open Approach */
"06L50DZ" = "1" /* Occlusion of Superior Mesenteric Vein with Intraluminal Device, Open Approach */
"06L50ZZ" = "1" /* Occlusion of Superior Mesenteric Vein, Open Approach */
"06L53CZ" = "1" /* Occlusion of Superior Mesenteric Vein with Extraluminal Device, Percutaneous Approach */
"06L53DZ" = "1" /* Occlusion of Superior Mesenteric Vein with Intraluminal Device, Percutaneous Approach */
"06L53ZZ" = "1" /* Occlusion of Superior Mesenteric Vein, Percutaneous Approach */
"06L54CZ" = "1" /* Occlusion of Superior Mesenteric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L54DZ" = "1" /* Occlusion of Superior Mesenteric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L54ZZ" = "1" /* Occlusion of Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06L60CZ" = "1" /* Occlusion of Inferior Mesenteric Vein with Extraluminal Device, Open Approach */
"06L60DZ" = "1" /* Occlusion of Inferior Mesenteric Vein with Intraluminal Device, Open Approach */
"06L60ZZ" = "1" /* Occlusion of Inferior Mesenteric Vein, Open Approach */
"06L63CZ" = "1" /* Occlusion of Inferior Mesenteric Vein with Extraluminal Device, Percutaneous Approach */
"06L63DZ" = "1" /* Occlusion of Inferior Mesenteric Vein with Intraluminal Device, Percutaneous Approach */
"06L63ZZ" = "1" /* Occlusion of Inferior Mesenteric Vein, Percutaneous Approach */
"06L64CZ" = "1" /* Occlusion of Inferior Mesenteric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L64DZ" = "1" /* Occlusion of Inferior Mesenteric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L64ZZ" = "1" /* Occlusion of Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06L70CZ" = "1" /* Occlusion of Colic Vein with Extraluminal Device, Open Approach */
"06L70DZ" = "1" /* Occlusion of Colic Vein with Intraluminal Device, Open Approach */
"06L70ZZ" = "1" /* Occlusion of Colic Vein, Open Approach */
"06L73CZ" = "1" /* Occlusion of Colic Vein with Extraluminal Device, Percutaneous Approach */
"06L73DZ" = "1" /* Occlusion of Colic Vein with Intraluminal Device, Percutaneous Approach */
"06L73ZZ" = "1" /* Occlusion of Colic Vein, Percutaneous Approach */
"06L74CZ" = "1" /* Occlusion of Colic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L74DZ" = "1" /* Occlusion of Colic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L74ZZ" = "1" /* Occlusion of Colic Vein, Percutaneous Endoscopic Approach */
"06L80CZ" = "1" /* Occlusion of Portal Vein with Extraluminal Device, Open Approach */
"06L80DZ" = "1" /* Occlusion of Portal Vein with Intraluminal Device, Open Approach */
"06L80ZZ" = "1" /* Occlusion of Portal Vein, Open Approach */
"06L83CZ" = "1" /* Occlusion of Portal Vein with Extraluminal Device, Percutaneous Approach */
"06L83DZ" = "1" /* Occlusion of Portal Vein with Intraluminal Device, Percutaneous Approach */
"06L83ZZ" = "1" /* Occlusion of Portal Vein, Percutaneous Approach */
"06L84CZ" = "1" /* Occlusion of Portal Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L84DZ" = "1" /* Occlusion of Portal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L84ZZ" = "1" /* Occlusion of Portal Vein, Percutaneous Endoscopic Approach */
"06L90CZ" = "1" /* Occlusion of Right Renal Vein with Extraluminal Device, Open Approach */
"06L90DZ" = "1" /* Occlusion of Right Renal Vein with Intraluminal Device, Open Approach */
"06L90ZZ" = "1" /* Occlusion of Right Renal Vein, Open Approach */
"06L93CZ" = "1" /* Occlusion of Right Renal Vein with Extraluminal Device, Percutaneous Approach */
"06L93DZ" = "1" /* Occlusion of Right Renal Vein with Intraluminal Device, Percutaneous Approach */
"06L93ZZ" = "1" /* Occlusion of Right Renal Vein, Percutaneous Approach */
"06L94CZ" = "1" /* Occlusion of Right Renal Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L94DZ" = "1" /* Occlusion of Right Renal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L94ZZ" = "1" /* Occlusion of Right Renal Vein, Percutaneous Endoscopic Approach */
"06LB0CZ" = "1" /* Occlusion of Left Renal Vein with Extraluminal Device, Open Approach */
"06LB0DZ" = "1" /* Occlusion of Left Renal Vein with Intraluminal Device, Open Approach */
"06LB0ZZ" = "1" /* Occlusion of Left Renal Vein, Open Approach */
"06LB3CZ" = "1" /* Occlusion of Left Renal Vein with Extraluminal Device, Percutaneous Approach */
"06LB3DZ" = "1" /* Occlusion of Left Renal Vein with Intraluminal Device, Percutaneous Approach */
"06LB3ZZ" = "1" /* Occlusion of Left Renal Vein, Percutaneous Approach */
"06LB4CZ" = "1" /* Occlusion of Left Renal Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LB4DZ" = "1" /* Occlusion of Left Renal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LB4ZZ" = "1" /* Occlusion of Left Renal Vein, Percutaneous Endoscopic Approach */
"06LC0CZ" = "1" /* Occlusion of Right Common Iliac Vein with Extraluminal Device, Open Approach */
"06LC0DZ" = "1" /* Occlusion of Right Common Iliac Vein with Intraluminal Device, Open Approach */
"06LC0ZZ" = "1" /* Occlusion of Right Common Iliac Vein, Open Approach */
"06LC3CZ" = "1" /* Occlusion of Right Common Iliac Vein with Extraluminal Device, Percutaneous Approach */
"06LC3DZ" = "1" /* Occlusion of Right Common Iliac Vein with Intraluminal Device, Percutaneous Approach */
"06LC3ZZ" = "1" /* Occlusion of Right Common Iliac Vein, Percutaneous Approach */
"06LC4CZ" = "1" /* Occlusion of Right Common Iliac Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LC4DZ" = "1" /* Occlusion of Right Common Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LC4ZZ" = "1" /* Occlusion of Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"06LD0CZ" = "1" /* Occlusion of Left Common Iliac Vein with Extraluminal Device, Open Approach */
"06LD0DZ" = "1" /* Occlusion of Left Common Iliac Vein with Intraluminal Device, Open Approach */
"06LD0ZZ" = "1" /* Occlusion of Left Common Iliac Vein, Open Approach */
"06LD3CZ" = "1" /* Occlusion of Left Common Iliac Vein with Extraluminal Device, Percutaneous Approach */
"06LD3DZ" = "1" /* Occlusion of Left Common Iliac Vein with Intraluminal Device, Percutaneous Approach */
"06LD3ZZ" = "1" /* Occlusion of Left Common Iliac Vein, Percutaneous Approach */
"06LD4CZ" = "1" /* Occlusion of Left Common Iliac Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LD4DZ" = "1" /* Occlusion of Left Common Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LD4ZZ" = "1" /* Occlusion of Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"06LF0CZ" = "1" /* Occlusion of Right External Iliac Vein with Extraluminal Device, Open Approach */
"06LF0DZ" = "1" /* Occlusion of Right External Iliac Vein with Intraluminal Device, Open Approach */
"06LF0ZZ" = "1" /* Occlusion of Right External Iliac Vein, Open Approach */
"06LF3CZ" = "1" /* Occlusion of Right External Iliac Vein with Extraluminal Device, Percutaneous Approach */
"06LF3DZ" = "1" /* Occlusion of Right External Iliac Vein with Intraluminal Device, Percutaneous Approach */
"06LF3ZZ" = "1" /* Occlusion of Right External Iliac Vein, Percutaneous Approach */
"06LF4CZ" = "1" /* Occlusion of Right External Iliac Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LF4DZ" = "1" /* Occlusion of Right External Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LF4ZZ" = "1" /* Occlusion of Right External Iliac Vein, Percutaneous Endoscopic Approach */
"06LG0CZ" = "1" /* Occlusion of Left External Iliac Vein with Extraluminal Device, Open Approach */
"06LG0DZ" = "1" /* Occlusion of Left External Iliac Vein with Intraluminal Device, Open Approach */
"06LG0ZZ" = "1" /* Occlusion of Left External Iliac Vein, Open Approach */
"06LG3CZ" = "1" /* Occlusion of Left External Iliac Vein with Extraluminal Device, Percutaneous Approach */
"06LG3DZ" = "1" /* Occlusion of Left External Iliac Vein with Intraluminal Device, Percutaneous Approach */
"06LG3ZZ" = "1" /* Occlusion of Left External Iliac Vein, Percutaneous Approach */
"06LG4CZ" = "1" /* Occlusion of Left External Iliac Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LG4DZ" = "1" /* Occlusion of Left External Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LG4ZZ" = "1" /* Occlusion of Left External Iliac Vein, Percutaneous Endoscopic Approach */
"06LH0CZ" = "1" /* Occlusion of Right Hypogastric Vein with Extraluminal Device, Open Approach */
"06LH0DZ" = "1" /* Occlusion of Right Hypogastric Vein with Intraluminal Device, Open Approach */
"06LH0ZZ" = "1" /* Occlusion of Right Hypogastric Vein, Open Approach */
"06LH3CZ" = "1" /* Occlusion of Right Hypogastric Vein with Extraluminal Device, Percutaneous Approach */
"06LH3DZ" = "1" /* Occlusion of Right Hypogastric Vein with Intraluminal Device, Percutaneous Approach */
"06LH3ZZ" = "1" /* Occlusion of Right Hypogastric Vein, Percutaneous Approach */
"06LH4CZ" = "1" /* Occlusion of Right Hypogastric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LH4DZ" = "1" /* Occlusion of Right Hypogastric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LH4ZZ" = "1" /* Occlusion of Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"06LJ0CZ" = "1" /* Occlusion of Left Hypogastric Vein with Extraluminal Device, Open Approach */
"06LJ0DZ" = "1" /* Occlusion of Left Hypogastric Vein with Intraluminal Device, Open Approach */
"06LJ0ZZ" = "1" /* Occlusion of Left Hypogastric Vein, Open Approach */
"06LJ3CZ" = "1" /* Occlusion of Left Hypogastric Vein with Extraluminal Device, Percutaneous Approach */
"06LJ3DZ" = "1" /* Occlusion of Left Hypogastric Vein with Intraluminal Device, Percutaneous Approach */
"06LJ3ZZ" = "1" /* Occlusion of Left Hypogastric Vein, Percutaneous Approach */
"06LJ4CZ" = "1" /* Occlusion of Left Hypogastric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LJ4DZ" = "1" /* Occlusion of Left Hypogastric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LJ4ZZ" = "1" /* Occlusion of Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"06LM0CZ" = "1" /* Occlusion of Right Femoral Vein with Extraluminal Device, Open Approach */
"06LM0DZ" = "1" /* Occlusion of Right Femoral Vein with Intraluminal Device, Open Approach */
"06LM0ZZ" = "1" /* Occlusion of Right Femoral Vein, Open Approach */
"06LM3CZ" = "1" /* Occlusion of Right Femoral Vein with Extraluminal Device, Percutaneous Approach */
"06LM3DZ" = "1" /* Occlusion of Right Femoral Vein with Intraluminal Device, Percutaneous Approach */
"06LM3ZZ" = "1" /* Occlusion of Right Femoral Vein, Percutaneous Approach */
"06LM4CZ" = "1" /* Occlusion of Right Femoral Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LM4DZ" = "1" /* Occlusion of Right Femoral Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LM4ZZ" = "1" /* Occlusion of Right Femoral Vein, Percutaneous Endoscopic Approach */
"06LN0CZ" = "1" /* Occlusion of Left Femoral Vein with Extraluminal Device, Open Approach */
"06LN0DZ" = "1" /* Occlusion of Left Femoral Vein with Intraluminal Device, Open Approach */
"06LN0ZZ" = "1" /* Occlusion of Left Femoral Vein, Open Approach */
"06LN3CZ" = "1" /* Occlusion of Left Femoral Vein with Extraluminal Device, Percutaneous Approach */
"06LN3DZ" = "1" /* Occlusion of Left Femoral Vein with Intraluminal Device, Percutaneous Approach */
"06LN3ZZ" = "1" /* Occlusion of Left Femoral Vein, Percutaneous Approach */
"06LN4CZ" = "1" /* Occlusion of Left Femoral Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LN4DZ" = "1" /* Occlusion of Left Femoral Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LN4ZZ" = "1" /* Occlusion of Left Femoral Vein, Percutaneous Endoscopic Approach */
"06LP0CZ" = "1" /* Occlusion of Right Greater Saphenous Vein with Extraluminal Device, Open Approach */
"06LP0DZ" = "1" /* Occlusion of Right Greater Saphenous Vein with Intraluminal Device, Open Approach */
"06LP0ZZ" = "1" /* Occlusion of Right Greater Saphenous Vein, Open Approach */
"06LP3CZ" = "1" /* Occlusion of Right Greater Saphenous Vein with Extraluminal Device, Percutaneous Approach */
"06LP3DZ" = "1" /* Occlusion of Right Greater Saphenous Vein with Intraluminal Device, Percutaneous Approach */
"06LP3ZZ" = "1" /* Occlusion of Right Greater Saphenous Vein, Percutaneous Approach */
"06LP4CZ" = "1" /* Occlusion of Right Greater Saphenous Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LP4DZ" = "1" /* Occlusion of Right Greater Saphenous Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LP4ZZ" = "1" /* Occlusion of Right Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"06LQ0CZ" = "1" /* Occlusion of Left Greater Saphenous Vein with Extraluminal Device, Open Approach */
"06LQ0DZ" = "1" /* Occlusion of Left Greater Saphenous Vein with Intraluminal Device, Open Approach */
"06LQ0ZZ" = "1" /* Occlusion of Left Greater Saphenous Vein, Open Approach */
"06LQ3CZ" = "1" /* Occlusion of Left Greater Saphenous Vein with Extraluminal Device, Percutaneous Approach */
"06LQ3DZ" = "1" /* Occlusion of Left Greater Saphenous Vein with Intraluminal Device, Percutaneous Approach */
"06LQ3ZZ" = "1" /* Occlusion of Left Greater Saphenous Vein, Percutaneous Approach */
"06LQ4CZ" = "1" /* Occlusion of Left Greater Saphenous Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LQ4DZ" = "1" /* Occlusion of Left Greater Saphenous Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LQ4ZZ" = "1" /* Occlusion of Left Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"06LR0CZ" = "1" /* Occlusion of Right Lesser Saphenous Vein with Extraluminal Device, Open Approach */
"06LR0DZ" = "1" /* Occlusion of Right Lesser Saphenous Vein with Intraluminal Device, Open Approach */
"06LR0ZZ" = "1" /* Occlusion of Right Lesser Saphenous Vein, Open Approach */
"06LR3CZ" = "1" /* Occlusion of Right Lesser Saphenous Vein with Extraluminal Device, Percutaneous Approach */
"06LR3DZ" = "1" /* Occlusion of Right Lesser Saphenous Vein with Intraluminal Device, Percutaneous Approach */
"06LR3ZZ" = "1" /* Occlusion of Right Lesser Saphenous Vein, Percutaneous Approach */
"06LR4CZ" = "1" /* Occlusion of Right Lesser Saphenous Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LR4DZ" = "1" /* Occlusion of Right Lesser Saphenous Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LR4ZZ" = "1" /* Occlusion of Right Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"06LS0CZ" = "1" /* Occlusion of Left Lesser Saphenous Vein with Extraluminal Device, Open Approach */
"06LS0DZ" = "1" /* Occlusion of Left Lesser Saphenous Vein with Intraluminal Device, Open Approach */
"06LS0ZZ" = "1" /* Occlusion of Left Lesser Saphenous Vein, Open Approach */
"06LS3CZ" = "1" /* Occlusion of Left Lesser Saphenous Vein with Extraluminal Device, Percutaneous Approach */
"06LS3DZ" = "1" /* Occlusion of Left Lesser Saphenous Vein with Intraluminal Device, Percutaneous Approach */
"06LS3ZZ" = "1" /* Occlusion of Left Lesser Saphenous Vein, Percutaneous Approach */
"06LS4CZ" = "1" /* Occlusion of Left Lesser Saphenous Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LS4DZ" = "1" /* Occlusion of Left Lesser Saphenous Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LS4ZZ" = "1" /* Occlusion of Left Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"06LT0CZ" = "1" /* Occlusion of Right Foot Vein with Extraluminal Device, Open Approach */
"06LT0DZ" = "1" /* Occlusion of Right Foot Vein with Intraluminal Device, Open Approach */
"06LT0ZZ" = "1" /* Occlusion of Right Foot Vein, Open Approach */
"06LT3CZ" = "1" /* Occlusion of Right Foot Vein with Extraluminal Device, Percutaneous Approach */
"06LT3DZ" = "1" /* Occlusion of Right Foot Vein with Intraluminal Device, Percutaneous Approach */
"06LT3ZZ" = "1" /* Occlusion of Right Foot Vein, Percutaneous Approach */
"06LT4CZ" = "1" /* Occlusion of Right Foot Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LT4DZ" = "1" /* Occlusion of Right Foot Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LT4ZZ" = "1" /* Occlusion of Right Foot Vein, Percutaneous Endoscopic Approach */
"06LV0CZ" = "1" /* Occlusion of Left Foot Vein with Extraluminal Device, Open Approach */
"06LV0DZ" = "1" /* Occlusion of Left Foot Vein with Intraluminal Device, Open Approach */
"06LV0ZZ" = "1" /* Occlusion of Left Foot Vein, Open Approach */
"06LV3CZ" = "1" /* Occlusion of Left Foot Vein with Extraluminal Device, Percutaneous Approach */
"06LV3DZ" = "1" /* Occlusion of Left Foot Vein with Intraluminal Device, Percutaneous Approach */
"06LV3ZZ" = "1" /* Occlusion of Left Foot Vein, Percutaneous Approach */
"06LV4CZ" = "1" /* Occlusion of Left Foot Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LV4DZ" = "1" /* Occlusion of Left Foot Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LV4ZZ" = "1" /* Occlusion of Left Foot Vein, Percutaneous Endoscopic Approach */
"06LY0CC" = "1" /* Occlusion of Hemorrhoidal Plexus with Extraluminal Device, Open Approach */
"06LY0CZ" = "1" /* Occlusion of Lower Vein with Extraluminal Device, Open Approach */
"06LY0DC" = "1" /* Occlusion of Hemorrhoidal Plexus with Intraluminal Device, Open Approach */
"06LY0DZ" = "1" /* Occlusion of Lower Vein with Intraluminal Device, Open Approach */
"06LY0ZC" = "1" /* Occlusion of Hemorrhoidal Plexus, Open Approach */
"06LY0ZZ" = "1" /* Occlusion of Lower Vein, Open Approach */
"06LY3CC" = "1" /* Occlusion of Hemorrhoidal Plexus with Extraluminal Device, Percutaneous Approach */
"06LY3CZ" = "1" /* Occlusion of Lower Vein with Extraluminal Device, Percutaneous Approach */
"06LY3DC" = "1" /* Occlusion of Hemorrhoidal Plexus with Intraluminal Device, Percutaneous Approach */
"06LY3DZ" = "1" /* Occlusion of Lower Vein with Intraluminal Device, Percutaneous Approach */
"06LY3ZC" = "1" /* Occlusion of Hemorrhoidal Plexus, Percutaneous Approach */
"06LY3ZZ" = "1" /* Occlusion of Lower Vein, Percutaneous Approach */
"06LY4CC" = "1" /* Occlusion of Hemorrhoidal Plexus with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LY4CZ" = "1" /* Occlusion of Lower Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LY4DC" = "1" /* Occlusion of Hemorrhoidal Plexus with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LY4DZ" = "1" /* Occlusion of Lower Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LY4ZC" = "1" /* Occlusion of Hemorrhoidal Plexus, Percutaneous Endoscopic Approach */
"06LY4ZZ" = "1" /* Occlusion of Lower Vein, Percutaneous Endoscopic Approach */
"06Q00ZZ" = "1" /* Repair Inferior Vena Cava, Open Approach */
"06Q03ZZ" = "1" /* Repair Inferior Vena Cava, Percutaneous Approach */
"06Q04ZZ" = "1" /* Repair Inferior Vena Cava, Percutaneous Endoscopic Approach */
"06Q10ZZ" = "1" /* Repair Splenic Vein, Open Approach */
"06Q13ZZ" = "1" /* Repair Splenic Vein, Percutaneous Approach */
"06Q14ZZ" = "1" /* Repair Splenic Vein, Percutaneous Endoscopic Approach */
"06Q20ZZ" = "1" /* Repair Gastric Vein, Open Approach */
"06Q23ZZ" = "1" /* Repair Gastric Vein, Percutaneous Approach */
"06Q24ZZ" = "1" /* Repair Gastric Vein, Percutaneous Endoscopic Approach */
"06Q30ZZ" = "1" /* Repair Esophageal Vein, Open Approach */
"06Q33ZZ" = "1" /* Repair Esophageal Vein, Percutaneous Approach */
"06Q34ZZ" = "1" /* Repair Esophageal Vein, Percutaneous Endoscopic Approach */
"06Q40ZZ" = "1" /* Repair Hepatic Vein, Open Approach */
"06Q43ZZ" = "1" /* Repair Hepatic Vein, Percutaneous Approach */
"06Q44ZZ" = "1" /* Repair Hepatic Vein, Percutaneous Endoscopic Approach */
"06Q50ZZ" = "1" /* Repair Superior Mesenteric Vein, Open Approach */
"06Q53ZZ" = "1" /* Repair Superior Mesenteric Vein, Percutaneous Approach */
"06Q54ZZ" = "1" /* Repair Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06Q60ZZ" = "1" /* Repair Inferior Mesenteric Vein, Open Approach */
"06Q63ZZ" = "1" /* Repair Inferior Mesenteric Vein, Percutaneous Approach */
"06Q64ZZ" = "1" /* Repair Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06Q70ZZ" = "1" /* Repair Colic Vein, Open Approach */
"06Q73ZZ" = "1" /* Repair Colic Vein, Percutaneous Approach */
"06Q74ZZ" = "1" /* Repair Colic Vein, Percutaneous Endoscopic Approach */
"06Q80ZZ" = "1" /* Repair Portal Vein, Open Approach */
"06Q83ZZ" = "1" /* Repair Portal Vein, Percutaneous Approach */
"06Q84ZZ" = "1" /* Repair Portal Vein, Percutaneous Endoscopic Approach */
"06Q90ZZ" = "1" /* Repair Right Renal Vein, Open Approach */
"06Q93ZZ" = "1" /* Repair Right Renal Vein, Percutaneous Approach */
"06Q94ZZ" = "1" /* Repair Right Renal Vein, Percutaneous Endoscopic Approach */
"06QB0ZZ" = "1" /* Repair Left Renal Vein, Open Approach */
"06QB3ZZ" = "1" /* Repair Left Renal Vein, Percutaneous Approach */
"06QB4ZZ" = "1" /* Repair Left Renal Vein, Percutaneous Endoscopic Approach */
"06QC0ZZ" = "1" /* Repair Right Common Iliac Vein, Open Approach */
"06QC3ZZ" = "1" /* Repair Right Common Iliac Vein, Percutaneous Approach */
"06QC4ZZ" = "1" /* Repair Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"06QD0ZZ" = "1" /* Repair Left Common Iliac Vein, Open Approach */
"06QD3ZZ" = "1" /* Repair Left Common Iliac Vein, Percutaneous Approach */
"06QD4ZZ" = "1" /* Repair Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"06QF0ZZ" = "1" /* Repair Right External Iliac Vein, Open Approach */
"06QF3ZZ" = "1" /* Repair Right External Iliac Vein, Percutaneous Approach */
"06QF4ZZ" = "1" /* Repair Right External Iliac Vein, Percutaneous Endoscopic Approach */
"06QG0ZZ" = "1" /* Repair Left External Iliac Vein, Open Approach */
"06QG3ZZ" = "1" /* Repair Left External Iliac Vein, Percutaneous Approach */
"06QG4ZZ" = "1" /* Repair Left External Iliac Vein, Percutaneous Endoscopic Approach */
"06QH0ZZ" = "1" /* Repair Right Hypogastric Vein, Open Approach */
"06QH3ZZ" = "1" /* Repair Right Hypogastric Vein, Percutaneous Approach */
"06QH4ZZ" = "1" /* Repair Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"06QJ0ZZ" = "1" /* Repair Left Hypogastric Vein, Open Approach */
"06QJ3ZZ" = "1" /* Repair Left Hypogastric Vein, Percutaneous Approach */
"06QJ4ZZ" = "1" /* Repair Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"06QM0ZZ" = "1" /* Repair Right Femoral Vein, Open Approach */
"06QM3ZZ" = "1" /* Repair Right Femoral Vein, Percutaneous Approach */
"06QM4ZZ" = "1" /* Repair Right Femoral Vein, Percutaneous Endoscopic Approach */
"06QN0ZZ" = "1" /* Repair Left Femoral Vein, Open Approach */
"06QN3ZZ" = "1" /* Repair Left Femoral Vein, Percutaneous Approach */
"06QN4ZZ" = "1" /* Repair Left Femoral Vein, Percutaneous Endoscopic Approach */
"06QP0ZZ" = "1" /* Repair Right Greater Saphenous Vein, Open Approach */
"06QP3ZZ" = "1" /* Repair Right Greater Saphenous Vein, Percutaneous Approach */
"06QP4ZZ" = "1" /* Repair Right Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"06QQ0ZZ" = "1" /* Repair Left Greater Saphenous Vein, Open Approach */
"06QQ3ZZ" = "1" /* Repair Left Greater Saphenous Vein, Percutaneous Approach */
"06QQ4ZZ" = "1" /* Repair Left Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"06QR0ZZ" = "1" /* Repair Right Lesser Saphenous Vein, Open Approach */
"06QR3ZZ" = "1" /* Repair Right Lesser Saphenous Vein, Percutaneous Approach */
"06QR4ZZ" = "1" /* Repair Right Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"06QS0ZZ" = "1" /* Repair Left Lesser Saphenous Vein, Open Approach */
"06QS3ZZ" = "1" /* Repair Left Lesser Saphenous Vein, Percutaneous Approach */
"06QS4ZZ" = "1" /* Repair Left Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"06QT0ZZ" = "1" /* Repair Right Foot Vein, Open Approach */
"06QT3ZZ" = "1" /* Repair Right Foot Vein, Percutaneous Approach */
"06QT4ZZ" = "1" /* Repair Right Foot Vein, Percutaneous Endoscopic Approach */
"06QV0ZZ" = "1" /* Repair Left Foot Vein, Open Approach */
"06QV3ZZ" = "1" /* Repair Left Foot Vein, Percutaneous Approach */
"06QV4ZZ" = "1" /* Repair Left Foot Vein, Percutaneous Endoscopic Approach */
"06QY0ZZ" = "1" /* Repair Lower Vein, Open Approach */
"06QY3ZZ" = "1" /* Repair Lower Vein, Percutaneous Approach */
"06QY4ZZ" = "1" /* Repair Lower Vein, Percutaneous Endoscopic Approach */
"06WY0DZ" = "1" /* Revision of Intraluminal Device in Lower Vein, Open Approach */
"06WY0JZ" = "1" /* Revision of Synthetic Substitute in Lower Vein, Open Approach */
"06WY0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Vein, Open Approach */
"06WY3DZ" = "1" /* Revision of Intraluminal Device in Lower Vein, Percutaneous Approach */
"06WY3JZ" = "1" /* Revision of Synthetic Substitute in Lower Vein, Percutaneous Approach */
"06WY3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Vein, Percutaneous Approach */
"06WY4DZ" = "1" /* Revision of Intraluminal Device in Lower Vein, Percutaneous Endoscopic Approach */
"06WY4JZ" = "1" /* Revision of Synthetic Substitute in Lower Vein, Percutaneous Endoscopic Approach */
"06WY4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Vein, Percutaneous Endoscopic Approach */
"079M00Z" = "1" /* Drainage of Thymus with Drainage Device, Open Approach */
"079M0ZZ" = "1" /* Drainage of Thymus, Open Approach */
"079M30Z" = "1" /* Drainage of Thymus with Drainage Device, Percutaneous Approach */
"079M3ZZ" = "1" /* Drainage of Thymus, Percutaneous Approach */
"079M40Z" = "1" /* Drainage of Thymus with Drainage Device, Percutaneous Endoscopic Approach */
"079M4ZZ" = "1" /* Drainage of Thymus, Percutaneous Endoscopic Approach */
"079P00Z" = "1" /* Drainage of Spleen with Drainage Device, Open Approach */
"079P0ZZ" = "1" /* Drainage of Spleen, Open Approach */
"07CM0ZZ" = "1" /* Extirpation of Matter from Thymus, Open Approach */
"07CM3ZZ" = "1" /* Extirpation of Matter from Thymus, Percutaneous Approach */
"07CP0ZZ" = "1" /* Extirpation of Matter from Spleen, Open Approach */
"07WM00Z" = "1" /* Revision of Drainage Device in Thymus, Open Approach */
"07WM30Z" = "1" /* Revision of Drainage Device in Thymus, Percutaneous Approach */
"07WM40Z" = "1" /* Revision of Drainage Device in Thymus, Percutaneous Endoscopic Approach */
"07WP00Z" = "1" /* Revision of Drainage Device in Spleen, Open Approach */
"07WP30Z" = "1" /* Revision of Drainage Device in Spleen, Percutaneous Approach */
"07WP40Z" = "1" /* Revision of Drainage Device in Spleen, Percutaneous Endoscopic Approach */
"085G3ZZ" = "1" /* Destruction of Right Retinal Vessel, Percutaneous Approach */
"085H3ZZ" = "1" /* Destruction of Left Retinal Vessel, Percutaneous Approach */
"0896X0Z" = "1" /* Drainage of Right Sclera with Drainage Device, External Approach */
"0896XZZ" = "1" /* Drainage of Right Sclera, External Approach */
"0897X0Z" = "1" /* Drainage of Left Sclera with Drainage Device, External Approach */
"0897XZZ" = "1" /* Drainage of Left Sclera, External Approach */
"089A00Z" = "1" /* Drainage of Right Choroid with Drainage Device, Open Approach */
"089A0ZZ" = "1" /* Drainage of Right Choroid, Open Approach */
"089A30Z" = "1" /* Drainage of Right Choroid with Drainage Device, Percutaneous Approach */
"089A3ZZ" = "1" /* Drainage of Right Choroid, Percutaneous Approach */
"089B00Z" = "1" /* Drainage of Left Choroid with Drainage Device, Open Approach */
"089B0ZZ" = "1" /* Drainage of Left Choroid, Open Approach */
"089B30Z" = "1" /* Drainage of Left Choroid with Drainage Device, Percutaneous Approach */
"089B3ZZ" = "1" /* Drainage of Left Choroid, Percutaneous Approach */
"089E30Z" = "1" /* Drainage of Right Retina with Drainage Device, Percutaneous Approach */
"089E3ZZ" = "1" /* Drainage of Right Retina, Percutaneous Approach */
"089F30Z" = "1" /* Drainage of Left Retina with Drainage Device, Percutaneous Approach */
"089F3ZZ" = "1" /* Drainage of Left Retina, Percutaneous Approach */
"089G30Z" = "1" /* Drainage of Right Retinal Vessel with Drainage Device, Percutaneous Approach */
"089G3ZZ" = "1" /* Drainage of Right Retinal Vessel, Percutaneous Approach */
"089H30Z" = "1" /* Drainage of Left Retinal Vessel with Drainage Device, Percutaneous Approach */
"089H3ZZ" = "1" /* Drainage of Left Retinal Vessel, Percutaneous Approach */
"089N00Z" = "1" /* Drainage of Right Upper Eyelid with Drainage Device, Open Approach */
"089N0ZZ" = "1" /* Drainage of Right Upper Eyelid, Open Approach */
"089N30Z" = "1" /* Drainage of Right Upper Eyelid with Drainage Device, Percutaneous Approach */
"089N3ZZ" = "1" /* Drainage of Right Upper Eyelid, Percutaneous Approach */
"089NX0Z" = "1" /* Drainage of Right Upper Eyelid with Drainage Device, External Approach */
"089NXZZ" = "1" /* Drainage of Right Upper Eyelid, External Approach */
"089P00Z" = "1" /* Drainage of Left Upper Eyelid with Drainage Device, Open Approach */
"089P0ZZ" = "1" /* Drainage of Left Upper Eyelid, Open Approach */
"089P30Z" = "1" /* Drainage of Left Upper Eyelid with Drainage Device, Percutaneous Approach */
"089P3ZZ" = "1" /* Drainage of Left Upper Eyelid, Percutaneous Approach */
"089PX0Z" = "1" /* Drainage of Left Upper Eyelid with Drainage Device, External Approach */
"089PXZZ" = "1" /* Drainage of Left Upper Eyelid, External Approach */
"089Q00Z" = "1" /* Drainage of Right Lower Eyelid with Drainage Device, Open Approach */
"089Q0ZZ" = "1" /* Drainage of Right Lower Eyelid, Open Approach */
"089Q30Z" = "1" /* Drainage of Right Lower Eyelid with Drainage Device, Percutaneous Approach */
"089Q3ZZ" = "1" /* Drainage of Right Lower Eyelid, Percutaneous Approach */
"089QX0Z" = "1" /* Drainage of Right Lower Eyelid with Drainage Device, External Approach */
"089QXZZ" = "1" /* Drainage of Right Lower Eyelid, External Approach */
"089R00Z" = "1" /* Drainage of Left Lower Eyelid with Drainage Device, Open Approach */
"089R0ZZ" = "1" /* Drainage of Left Lower Eyelid, Open Approach */
"089R30Z" = "1" /* Drainage of Left Lower Eyelid with Drainage Device, Percutaneous Approach */
"089R3ZZ" = "1" /* Drainage of Left Lower Eyelid, Percutaneous Approach */
"089RX0Z" = "1" /* Drainage of Left Lower Eyelid with Drainage Device, External Approach */
"089RXZZ" = "1" /* Drainage of Left Lower Eyelid, External Approach */
"08CN0ZZ" = "1" /* Extirpation of Matter from Right Upper Eyelid, Open Approach */
"08CN3ZZ" = "1" /* Extirpation of Matter from Right Upper Eyelid, Percutaneous Approach */
"08CP0ZZ" = "1" /* Extirpation of Matter from Left Upper Eyelid, Open Approach */
"08CP3ZZ" = "1" /* Extirpation of Matter from Left Upper Eyelid, Percutaneous Approach */
"08CQ0ZZ" = "1" /* Extirpation of Matter from Right Lower Eyelid, Open Approach */
"08CQ3ZZ" = "1" /* Extirpation of Matter from Right Lower Eyelid, Percutaneous Approach */
"08CR0ZZ" = "1" /* Extirpation of Matter from Left Lower Eyelid, Open Approach */
"08CR3ZZ" = "1" /* Extirpation of Matter from Left Lower Eyelid, Percutaneous Approach */
"095D0ZZ" = "1" /* Destruction of Right Inner Ear, Open Approach */
"095E0ZZ" = "1" /* Destruction of Left Inner Ear, Open Approach */
"095K0ZZ" = "1" /* Destruction of Nose, Open Approach */
"095K3ZZ" = "1" /* Destruction of Nose, Percutaneous Approach */
"095K4ZZ" = "1" /* Destruction of Nose, Percutaneous Endoscopic Approach */
"099300Z" = "1" /* Drainage of Right External Auditory Canal with Drainage Device, Open Approach */
"09930ZZ" = "1" /* Drainage of Right External Auditory Canal, Open Approach */
"099330Z" = "1" /* Drainage of Right External Auditory Canal with Drainage Device, Percutaneous Approach */
"09933ZZ" = "1" /* Drainage of Right External Auditory Canal, Percutaneous Approach */
"099340Z" = "1" /* Drainage of Right External Auditory Canal with Drainage Device, Percutaneous Endoscopic Approach */
"09934ZZ" = "1" /* Drainage of Right External Auditory Canal, Percutaneous Endoscopic Approach */
"099370Z" = "1" /* Drainage of Right External Auditory Canal with Drainage Device, Via Natural or Artificial Opening */
"09937ZZ" = "1" /* Drainage of Right External Auditory Canal, Via Natural or Artificial Opening */
"099380Z" = "1" /* Drainage of Right External Auditory Canal with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"09938ZZ" = "1" /* Drainage of Right External Auditory Canal, Via Natural or Artificial Opening Endoscopic */
"0993X0Z" = "1" /* Drainage of Right External Auditory Canal with Drainage Device, External Approach */
"0993XZZ" = "1" /* Drainage of Right External Auditory Canal, External Approach */
"099400Z" = "1" /* Drainage of Left External Auditory Canal with Drainage Device, Open Approach */
"09940ZZ" = "1" /* Drainage of Left External Auditory Canal, Open Approach */
"099430Z" = "1" /* Drainage of Left External Auditory Canal with Drainage Device, Percutaneous Approach */
"09943ZZ" = "1" /* Drainage of Left External Auditory Canal, Percutaneous Approach */
"099440Z" = "1" /* Drainage of Left External Auditory Canal with Drainage Device, Percutaneous Endoscopic Approach */
"09944ZZ" = "1" /* Drainage of Left External Auditory Canal, Percutaneous Endoscopic Approach */
"099470Z" = "1" /* Drainage of Left External Auditory Canal with Drainage Device, Via Natural or Artificial Opening */
"09947ZZ" = "1" /* Drainage of Left External Auditory Canal, Via Natural or Artificial Opening */
"099480Z" = "1" /* Drainage of Left External Auditory Canal with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"09948ZZ" = "1" /* Drainage of Left External Auditory Canal, Via Natural or Artificial Opening Endoscopic */
"0994X0Z" = "1" /* Drainage of Left External Auditory Canal with Drainage Device, External Approach */
"0994XZZ" = "1" /* Drainage of Left External Auditory Canal, External Approach */
"099500Z" = "1" /* Drainage of Right Middle Ear with Drainage Device, Open Approach */
"09950ZZ" = "1" /* Drainage of Right Middle Ear, Open Approach */
"099600Z" = "1" /* Drainage of Left Middle Ear with Drainage Device, Open Approach */
"09960ZZ" = "1" /* Drainage of Left Middle Ear, Open Approach */
"099700Z" = "1" /* Drainage of Right Tympanic Membrane with Drainage Device, Open Approach */
"09970ZZ" = "1" /* Drainage of Right Tympanic Membrane, Open Approach */
"099730Z" = "1" /* Drainage of Right Tympanic Membrane with Drainage Device, Percutaneous Approach */
"09973ZZ" = "1" /* Drainage of Right Tympanic Membrane, Percutaneous Approach */
"099740Z" = "1" /* Drainage of Right Tympanic Membrane with Drainage Device, Percutaneous Endoscopic Approach */
"09974ZZ" = "1" /* Drainage of Right Tympanic Membrane, Percutaneous Endoscopic Approach */
"099770Z" = "1" /* Drainage of Right Tympanic Membrane with Drainage Device, Via Natural or Artificial Opening */
"09977ZZ" = "1" /* Drainage of Right Tympanic Membrane, Via Natural or Artificial Opening */
"099780Z" = "1" /* Drainage of Right Tympanic Membrane with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"09978ZZ" = "1" /* Drainage of Right Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"099800Z" = "1" /* Drainage of Left Tympanic Membrane with Drainage Device, Open Approach */
"09980ZZ" = "1" /* Drainage of Left Tympanic Membrane, Open Approach */
"099830Z" = "1" /* Drainage of Left Tympanic Membrane with Drainage Device, Percutaneous Approach */
"09983ZZ" = "1" /* Drainage of Left Tympanic Membrane, Percutaneous Approach */
"099840Z" = "1" /* Drainage of Left Tympanic Membrane with Drainage Device, Percutaneous Endoscopic Approach */
"09984ZZ" = "1" /* Drainage of Left Tympanic Membrane, Percutaneous Endoscopic Approach */
"099870Z" = "1" /* Drainage of Left Tympanic Membrane with Drainage Device, Via Natural or Artificial Opening */
"09987ZZ" = "1" /* Drainage of Left Tympanic Membrane, Via Natural or Artificial Opening */
"099880Z" = "1" /* Drainage of Left Tympanic Membrane with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"09988ZZ" = "1" /* Drainage of Left Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"099B00Z" = "1" /* Drainage of Right Mastoid Sinus with Drainage Device, Open Approach */
"099B0ZZ" = "1" /* Drainage of Right Mastoid Sinus, Open Approach */
"099B30Z" = "1" /* Drainage of Right Mastoid Sinus with Drainage Device, Percutaneous Approach */
"099B3ZZ" = "1" /* Drainage of Right Mastoid Sinus, Percutaneous Approach */
"099B40Z" = "1" /* Drainage of Right Mastoid Sinus with Drainage Device, Percutaneous Endoscopic Approach */
"099B4ZZ" = "1" /* Drainage of Right Mastoid Sinus, Percutaneous Endoscopic Approach */
"099C00Z" = "1" /* Drainage of Left Mastoid Sinus with Drainage Device, Open Approach */
"099C0ZZ" = "1" /* Drainage of Left Mastoid Sinus, Open Approach */
"099C30Z" = "1" /* Drainage of Left Mastoid Sinus with Drainage Device, Percutaneous Approach */
"099C3ZZ" = "1" /* Drainage of Left Mastoid Sinus, Percutaneous Approach */
"099C40Z" = "1" /* Drainage of Left Mastoid Sinus with Drainage Device, Percutaneous Endoscopic Approach */
"099C4ZZ" = "1" /* Drainage of Left Mastoid Sinus, Percutaneous Endoscopic Approach */
"099D00Z" = "1" /* Drainage of Right Inner Ear with Drainage Device, Open Approach */
"099D0ZZ" = "1" /* Drainage of Right Inner Ear, Open Approach */
"099E00Z" = "1" /* Drainage of Left Inner Ear with Drainage Device, Open Approach */
"099E0ZZ" = "1" /* Drainage of Left Inner Ear, Open Approach */
"099K00Z" = "1" /* Drainage of Nose with Drainage Device, Open Approach */
"099K0ZZ" = "1" /* Drainage of Nose, Open Approach */
"099K30Z" = "1" /* Drainage of Nose with Drainage Device, Percutaneous Approach */
"099K3ZZ" = "1" /* Drainage of Nose, Percutaneous Approach */
"099K40Z" = "1" /* Drainage of Nose with Drainage Device, Percutaneous Endoscopic Approach */
"099K4ZZ" = "1" /* Drainage of Nose, Percutaneous Endoscopic Approach */
"099KX0Z" = "1" /* Drainage of Nose with Drainage Device, External Approach */
"099KXZZ" = "1" /* Drainage of Nose, External Approach */
"099L00Z" = "1" /* Drainage of Nasal Turbinate with Drainage Device, Open Approach */
"099L0ZZ" = "1" /* Drainage of Nasal Turbinate, Open Approach */
"099L30Z" = "1" /* Drainage of Nasal Turbinate with Drainage Device, Percutaneous Approach */
"099L3ZZ" = "1" /* Drainage of Nasal Turbinate, Percutaneous Approach */
"099L40Z" = "1" /* Drainage of Nasal Turbinate with Drainage Device, Percutaneous Endoscopic Approach */
"099L4ZZ" = "1" /* Drainage of Nasal Turbinate, Percutaneous Endoscopic Approach */
"099L70Z" = "1" /* Drainage of Nasal Turbinate with Drainage Device, Via Natural or Artificial Opening */
"099L7ZZ" = "1" /* Drainage of Nasal Turbinate, Via Natural or Artificial Opening */
"099L80Z" = "1" /* Drainage of Nasal Turbinate with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"099L8ZZ" = "1" /* Drainage of Nasal Turbinate, Via Natural or Artificial Opening Endoscopic */
"099M00Z" = "1" /* Drainage of Nasal Septum with Drainage Device, Open Approach */
"099M0ZZ" = "1" /* Drainage of Nasal Septum, Open Approach */
"099M30Z" = "1" /* Drainage of Nasal Septum with Drainage Device, Percutaneous Approach */
"099M3ZZ" = "1" /* Drainage of Nasal Septum, Percutaneous Approach */
"099M40Z" = "1" /* Drainage of Nasal Septum with Drainage Device, Percutaneous Endoscopic Approach */
"099M4ZZ" = "1" /* Drainage of Nasal Septum, Percutaneous Endoscopic Approach */
"099Q00Z" = "1" /* Drainage of Right Maxillary Sinus with Drainage Device, Open Approach */
"099Q0ZZ" = "1" /* Drainage of Right Maxillary Sinus, Open Approach */
"099R00Z" = "1" /* Drainage of Left Maxillary Sinus with Drainage Device, Open Approach */
"099R0ZZ" = "1" /* Drainage of Left Maxillary Sinus, Open Approach */
"099S00Z" = "1" /* Drainage of Right Frontal Sinus with Drainage Device, Open Approach */
"099S0ZZ" = "1" /* Drainage of Right Frontal Sinus, Open Approach */
"099T00Z" = "1" /* Drainage of Left Frontal Sinus with Drainage Device, Open Approach */
"099T0ZZ" = "1" /* Drainage of Left Frontal Sinus, Open Approach */
"099U00Z" = "1" /* Drainage of Right Ethmoid Sinus with Drainage Device, Open Approach */
"099U0ZZ" = "1" /* Drainage of Right Ethmoid Sinus, Open Approach */
"099V00Z" = "1" /* Drainage of Left Ethmoid Sinus with Drainage Device, Open Approach */
"099V0ZZ" = "1" /* Drainage of Left Ethmoid Sinus, Open Approach */
"099W00Z" = "1" /* Drainage of Right Sphenoid Sinus with Drainage Device, Open Approach */
"099W0ZZ" = "1" /* Drainage of Right Sphenoid Sinus, Open Approach */
"099X00Z" = "1" /* Drainage of Left Sphenoid Sinus with Drainage Device, Open Approach */
"099X0ZZ" = "1" /* Drainage of Left Sphenoid Sinus, Open Approach */
"09C30ZZ" = "1" /* Extirpation of Matter from Right External Auditory Canal, Open Approach */
"09C33ZZ" = "1" /* Extirpation of Matter from Right External Auditory Canal, Percutaneous Approach */
"09C34ZZ" = "1" /* Extirpation of Matter from Right External Auditory Canal, Percutaneous Endoscopic Approach */
"09C40ZZ" = "1" /* Extirpation of Matter from Left External Auditory Canal, Open Approach */
"09C43ZZ" = "1" /* Extirpation of Matter from Left External Auditory Canal, Percutaneous Approach */
"09C44ZZ" = "1" /* Extirpation of Matter from Left External Auditory Canal, Percutaneous Endoscopic Approach */
"09C50ZZ" = "1" /* Extirpation of Matter from Right Middle Ear, Open Approach */
"09C60ZZ" = "1" /* Extirpation of Matter from Left Middle Ear, Open Approach */
"09C70ZZ" = "1" /* Extirpation of Matter from Right Tympanic Membrane, Open Approach */
"09C73ZZ" = "1" /* Extirpation of Matter from Right Tympanic Membrane, Percutaneous Approach */
"09C74ZZ" = "1" /* Extirpation of Matter from Right Tympanic Membrane, Percutaneous Endoscopic Approach */
"09C77ZZ" = "1" /* Extirpation of Matter from Right Tympanic Membrane, Via Natural or Artificial Opening */
"09C78ZZ" = "1" /* Extirpation of Matter from Right Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"09C80ZZ" = "1" /* Extirpation of Matter from Left Tympanic Membrane, Open Approach */
"09C83ZZ" = "1" /* Extirpation of Matter from Left Tympanic Membrane, Percutaneous Approach */
"09C84ZZ" = "1" /* Extirpation of Matter from Left Tympanic Membrane, Percutaneous Endoscopic Approach */
"09C87ZZ" = "1" /* Extirpation of Matter from Left Tympanic Membrane, Via Natural or Artificial Opening */
"09C88ZZ" = "1" /* Extirpation of Matter from Left Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"09CB0ZZ" = "1" /* Extirpation of Matter from Right Mastoid Sinus, Open Approach */
"09CB3ZZ" = "1" /* Extirpation of Matter from Right Mastoid Sinus, Percutaneous Approach */
"09CB4ZZ" = "1" /* Extirpation of Matter from Right Mastoid Sinus, Percutaneous Endoscopic Approach */
"09CC0ZZ" = "1" /* Extirpation of Matter from Left Mastoid Sinus, Open Approach */
"09CC3ZZ" = "1" /* Extirpation of Matter from Left Mastoid Sinus, Percutaneous Approach */
"09CC4ZZ" = "1" /* Extirpation of Matter from Left Mastoid Sinus, Percutaneous Endoscopic Approach */
"09CD0ZZ" = "1" /* Extirpation of Matter from Right Inner Ear, Open Approach */
"09CE0ZZ" = "1" /* Extirpation of Matter from Left Inner Ear, Open Approach */
"09CK0ZZ" = "1" /* Extirpation of Matter from Nose, Open Approach */
"09CK3ZZ" = "1" /* Extirpation of Matter from Nose, Percutaneous Approach */
"09CK4ZZ" = "1" /* Extirpation of Matter from Nose, Percutaneous Endoscopic Approach */
"09CL0ZZ" = "1" /* Extirpation of Matter from Nasal Turbinate, Open Approach */
"09CL3ZZ" = "1" /* Extirpation of Matter from Nasal Turbinate, Percutaneous Approach */
"09CL4ZZ" = "1" /* Extirpation of Matter from Nasal Turbinate, Percutaneous Endoscopic Approach */
"09CL7ZZ" = "1" /* Extirpation of Matter from Nasal Turbinate, Via Natural or Artificial Opening */
"09CL8ZZ" = "1" /* Extirpation of Matter from Nasal Turbinate, Via Natural or Artificial Opening Endoscopic */
"09CM0ZZ" = "1" /* Extirpation of Matter from Nasal Septum, Open Approach */
"09CM3ZZ" = "1" /* Extirpation of Matter from Nasal Septum, Percutaneous Approach */
"09CM4ZZ" = "1" /* Extirpation of Matter from Nasal Septum, Percutaneous Endoscopic Approach */
"09CQ0ZZ" = "1" /* Extirpation of Matter from Right Maxillary Sinus, Open Approach */
"09CQ3ZZ" = "1" /* Extirpation of Matter from Right Maxillary Sinus, Percutaneous Approach */
"09CQ4ZZ" = "1" /* Extirpation of Matter from Right Maxillary Sinus, Percutaneous Endoscopic Approach */
"09CR0ZZ" = "1" /* Extirpation of Matter from Left Maxillary Sinus, Open Approach */
"09CR3ZZ" = "1" /* Extirpation of Matter from Left Maxillary Sinus, Percutaneous Approach */
"09CR4ZZ" = "1" /* Extirpation of Matter from Left Maxillary Sinus, Percutaneous Endoscopic Approach */
"09CS0ZZ" = "1" /* Extirpation of Matter from Right Frontal Sinus, Open Approach */
"09CS3ZZ" = "1" /* Extirpation of Matter from Right Frontal Sinus, Percutaneous Approach */
"09CS4ZZ" = "1" /* Extirpation of Matter from Right Frontal Sinus, Percutaneous Endoscopic Approach */
"09CT0ZZ" = "1" /* Extirpation of Matter from Left Frontal Sinus, Open Approach */
"09CT3ZZ" = "1" /* Extirpation of Matter from Left Frontal Sinus, Percutaneous Approach */
"09CT4ZZ" = "1" /* Extirpation of Matter from Left Frontal Sinus, Percutaneous Endoscopic Approach */
"09CU0ZZ" = "1" /* Extirpation of Matter from Right Ethmoid Sinus, Open Approach */
"09CU3ZZ" = "1" /* Extirpation of Matter from Right Ethmoid Sinus, Percutaneous Approach */
"09CU4ZZ" = "1" /* Extirpation of Matter from Right Ethmoid Sinus, Percutaneous Endoscopic Approach */
"09CV0ZZ" = "1" /* Extirpation of Matter from Left Ethmoid Sinus, Open Approach */
"09CV3ZZ" = "1" /* Extirpation of Matter from Left Ethmoid Sinus, Percutaneous Approach */
"09CV4ZZ" = "1" /* Extirpation of Matter from Left Ethmoid Sinus, Percutaneous Endoscopic Approach */
"09CW0ZZ" = "1" /* Extirpation of Matter from Right Sphenoid Sinus, Open Approach */
"09CW3ZZ" = "1" /* Extirpation of Matter from Right Sphenoid Sinus, Percutaneous Approach */
"09CW4ZZ" = "1" /* Extirpation of Matter from Right Sphenoid Sinus, Percutaneous Endoscopic Approach */
"09CX0ZZ" = "1" /* Extirpation of Matter from Left Sphenoid Sinus, Open Approach */
"09CX3ZZ" = "1" /* Extirpation of Matter from Left Sphenoid Sinus, Percutaneous Approach */
"09CX4ZZ" = "1" /* Extirpation of Matter from Left Sphenoid Sinus, Percutaneous Endoscopic Approach */
"09WK00Z" = "1" /* Revision of Drainage Device in Nose, Open Approach */
"09WK30Z" = "1" /* Revision of Drainage Device in Nose, Percutaneous Approach */
"09WK40Z" = "1" /* Revision of Drainage Device in Nose, Percutaneous Endoscopic Approach */
"09WK70Z" = "1" /* Revision of Drainage Device in Nose, Via Natural or Artificial Opening */
"09WK80Z" = "1" /* Revision of Drainage Device in Nose, Via Natural or Artificial Opening Endoscopic */
"0B9C00Z" = "1" /* Drainage of Right Upper Lung Lobe with Drainage Device, Open Approach */
"0B9C0ZZ" = "1" /* Drainage of Right Upper Lung Lobe, Open Approach */
"0B9D00Z" = "1" /* Drainage of Right Middle Lung Lobe with Drainage Device, Open Approach */
"0B9D0ZZ" = "1" /* Drainage of Right Middle Lung Lobe, Open Approach */
"0B9F00Z" = "1" /* Drainage of Right Lower Lung Lobe with Drainage Device, Open Approach */
"0B9F0ZZ" = "1" /* Drainage of Right Lower Lung Lobe, Open Approach */
"0B9G00Z" = "1" /* Drainage of Left Upper Lung Lobe with Drainage Device, Open Approach */
"0B9G0ZZ" = "1" /* Drainage of Left Upper Lung Lobe, Open Approach */
"0B9H00Z" = "1" /* Drainage of Lung Lingula with Drainage Device, Open Approach */
"0B9H0ZZ" = "1" /* Drainage of Lung Lingula, Open Approach */
"0B9J00Z" = "1" /* Drainage of Left Lower Lung Lobe with Drainage Device, Open Approach */
"0B9J0ZZ" = "1" /* Drainage of Left Lower Lung Lobe, Open Approach */
"0B9K00Z" = "1" /* Drainage of Right Lung with Drainage Device, Open Approach */
"0B9K0ZZ" = "1" /* Drainage of Right Lung, Open Approach */
"0B9L00Z" = "1" /* Drainage of Left Lung with Drainage Device, Open Approach */
"0B9L0ZZ" = "1" /* Drainage of Left Lung, Open Approach */
"0B9M00Z" = "1" /* Drainage of Bilateral Lungs with Drainage Device, Open Approach */
"0B9M0ZZ" = "1" /* Drainage of Bilateral Lungs, Open Approach */
"0B9N00Z" = "1" /* Drainage of Right Pleura with Drainage Device, Open Approach */
"0B9N0ZZ" = "1" /* Drainage of Right Pleura, Open Approach */
"0B9N30Z" = "1" /* Drainage of Right Pleura with Drainage Device, Percutaneous Approach */
"0B9P00Z" = "1" /* Drainage of Left Pleura with Drainage Device, Open Approach */
"0B9P0ZZ" = "1" /* Drainage of Left Pleura, Open Approach */
"0B9P30Z" = "1" /* Drainage of Left Pleura with Drainage Device, Percutaneous Approach */
"0BCC0ZZ" = "1" /* Extirpation of Matter from Right Upper Lung Lobe, Open Approach */
"0BCC3ZZ" = "1" /* Extirpation of Matter from Right Upper Lung Lobe, Percutaneous Approach */
"0BCC4ZZ" = "1" /* Extirpation of Matter from Right Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BCD0ZZ" = "1" /* Extirpation of Matter from Right Middle Lung Lobe, Open Approach */
"0BCD3ZZ" = "1" /* Extirpation of Matter from Right Middle Lung Lobe, Percutaneous Approach */
"0BCD4ZZ" = "1" /* Extirpation of Matter from Right Middle Lung Lobe, Percutaneous Endoscopic Approach */
"0BCF0ZZ" = "1" /* Extirpation of Matter from Right Lower Lung Lobe, Open Approach */
"0BCF3ZZ" = "1" /* Extirpation of Matter from Right Lower Lung Lobe, Percutaneous Approach */
"0BCF4ZZ" = "1" /* Extirpation of Matter from Right Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BCG0ZZ" = "1" /* Extirpation of Matter from Left Upper Lung Lobe, Open Approach */
"0BCG3ZZ" = "1" /* Extirpation of Matter from Left Upper Lung Lobe, Percutaneous Approach */
"0BCG4ZZ" = "1" /* Extirpation of Matter from Left Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BCH0ZZ" = "1" /* Extirpation of Matter from Lung Lingula, Open Approach */
"0BCH3ZZ" = "1" /* Extirpation of Matter from Lung Lingula, Percutaneous Approach */
"0BCH4ZZ" = "1" /* Extirpation of Matter from Lung Lingula, Percutaneous Endoscopic Approach */
"0BCJ0ZZ" = "1" /* Extirpation of Matter from Left Lower Lung Lobe, Open Approach */
"0BCJ3ZZ" = "1" /* Extirpation of Matter from Left Lower Lung Lobe, Percutaneous Approach */
"0BCJ4ZZ" = "1" /* Extirpation of Matter from Left Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BCK0ZZ" = "1" /* Extirpation of Matter from Right Lung, Open Approach */
"0BCK3ZZ" = "1" /* Extirpation of Matter from Right Lung, Percutaneous Approach */
"0BCK4ZZ" = "1" /* Extirpation of Matter from Right Lung, Percutaneous Endoscopic Approach */
"0BCL0ZZ" = "1" /* Extirpation of Matter from Left Lung, Open Approach */
"0BCL3ZZ" = "1" /* Extirpation of Matter from Left Lung, Percutaneous Approach */
"0BCL4ZZ" = "1" /* Extirpation of Matter from Left Lung, Percutaneous Endoscopic Approach */
"0BCM0ZZ" = "1" /* Extirpation of Matter from Bilateral Lungs, Open Approach */
"0BCM3ZZ" = "1" /* Extirpation of Matter from Bilateral Lungs, Percutaneous Approach */
"0BCM4ZZ" = "1" /* Extirpation of Matter from Bilateral Lungs, Percutaneous Endoscopic Approach */
"0BCN0ZZ" = "1" /* Extirpation of Matter from Right Pleura, Open Approach */
"0BCN3ZZ" = "1" /* Extirpation of Matter from Right Pleura, Percutaneous Approach */
"0BCN4ZZ" = "1" /* Extirpation of Matter from Right Pleura, Percutaneous Endoscopic Approach */
"0BCP0ZZ" = "1" /* Extirpation of Matter from Left Pleura, Open Approach */
"0BCP3ZZ" = "1" /* Extirpation of Matter from Left Pleura, Percutaneous Approach */
"0BCP4ZZ" = "1" /* Extirpation of Matter from Left Pleura, Percutaneous Endoscopic Approach */
"0BW17FZ" = "1" /* Revision of Tracheostomy Device in Trachea, Via Natural or Artificial Opening */
"0BW18FZ" = "1" /* Revision of Tracheostomy Device in Trachea, Via Natural or Artificial Opening Endoscopic */
"0BWK00Z" = "1" /* Revision of Drainage Device in Right Lung, Open Approach */
"0BWK30Z" = "1" /* Revision of Drainage Device in Right Lung, Percutaneous Approach */
"0BWK40Z" = "1" /* Revision of Drainage Device in Right Lung, Percutaneous Endoscopic Approach */
"0BWL00Z" = "1" /* Revision of Drainage Device in Left Lung, Open Approach */
"0BWL30Z" = "1" /* Revision of Drainage Device in Left Lung, Percutaneous Approach */
"0BWL40Z" = "1" /* Revision of Drainage Device in Left Lung, Percutaneous Endoscopic Approach */
"0BWQ00Z" = "1" /* Revision of Drainage Device in Pleura, Open Approach */
"0BWQ30Z" = "1" /* Revision of Drainage Device in Pleura, Percutaneous Approach */
"0BWQ40Z" = "1" /* Revision of Drainage Device in Pleura, Percutaneous Endoscopic Approach */
"0C9000Z" = "1" /* Drainage of Upper Lip with Drainage Device, Open Approach */
"0C900ZZ" = "1" /* Drainage of Upper Lip, Open Approach */
"0C9030Z" = "1" /* Drainage of Upper Lip with Drainage Device, Percutaneous Approach */
"0C903ZZ" = "1" /* Drainage of Upper Lip, Percutaneous Approach */
"0C90X0Z" = "1" /* Drainage of Upper Lip with Drainage Device, External Approach */
"0C90XZZ" = "1" /* Drainage of Upper Lip, External Approach */
"0C9100Z" = "1" /* Drainage of Lower Lip with Drainage Device, Open Approach */
"0C910ZZ" = "1" /* Drainage of Lower Lip, Open Approach */
"0C9130Z" = "1" /* Drainage of Lower Lip with Drainage Device, Percutaneous Approach */
"0C913ZZ" = "1" /* Drainage of Lower Lip, Percutaneous Approach */
"0C91X0Z" = "1" /* Drainage of Lower Lip with Drainage Device, External Approach */
"0C91XZZ" = "1" /* Drainage of Lower Lip, External Approach */
"0C9400Z" = "1" /* Drainage of Buccal Mucosa with Drainage Device, Open Approach */
"0C940ZZ" = "1" /* Drainage of Buccal Mucosa, Open Approach */
"0C9430Z" = "1" /* Drainage of Buccal Mucosa with Drainage Device, Percutaneous Approach */
"0C943ZZ" = "1" /* Drainage of Buccal Mucosa, Percutaneous Approach */
"0C94X0Z" = "1" /* Drainage of Buccal Mucosa with Drainage Device, External Approach */
"0C94XZZ" = "1" /* Drainage of Buccal Mucosa, External Approach */
"0C9P00Z" = "1" /* Drainage of Tonsils with Drainage Device, Open Approach */
"0C9P0ZZ" = "1" /* Drainage of Tonsils, Open Approach */
"0C9P30Z" = "1" /* Drainage of Tonsils with Drainage Device, Percutaneous Approach */
"0C9P3ZZ" = "1" /* Drainage of Tonsils, Percutaneous Approach */
"0C9PX0Z" = "1" /* Drainage of Tonsils with Drainage Device, External Approach */
"0C9PXZZ" = "1" /* Drainage of Tonsils, External Approach */
"0C9R00Z" = "1" /* Drainage of Epiglottis with Drainage Device, Open Approach */
"0C9R0ZZ" = "1" /* Drainage of Epiglottis, Open Approach */
"0C9R30Z" = "1" /* Drainage of Epiglottis with Drainage Device, Percutaneous Approach */
"0C9R3ZZ" = "1" /* Drainage of Epiglottis, Percutaneous Approach */
"0C9R40Z" = "1" /* Drainage of Epiglottis with Drainage Device, Percutaneous Endoscopic Approach */
"0C9R4ZZ" = "1" /* Drainage of Epiglottis, Percutaneous Endoscopic Approach */
"0C9R70Z" = "1" /* Drainage of Epiglottis with Drainage Device, Via Natural or Artificial Opening */
"0C9R7ZZ" = "1" /* Drainage of Epiglottis, Via Natural or Artificial Opening */
"0C9R80Z" = "1" /* Drainage of Epiglottis with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0C9R8ZZ" = "1" /* Drainage of Epiglottis, Via Natural or Artificial Opening Endoscopic */
"0C9S00Z" = "1" /* Drainage of Larynx with Drainage Device, Open Approach */
"0C9S0ZZ" = "1" /* Drainage of Larynx, Open Approach */
"0C9S30Z" = "1" /* Drainage of Larynx with Drainage Device, Percutaneous Approach */
"0C9S3ZZ" = "1" /* Drainage of Larynx, Percutaneous Approach */
"0C9S40Z" = "1" /* Drainage of Larynx with Drainage Device, Percutaneous Endoscopic Approach */
"0C9S4ZZ" = "1" /* Drainage of Larynx, Percutaneous Endoscopic Approach */
"0C9S70Z" = "1" /* Drainage of Larynx with Drainage Device, Via Natural or Artificial Opening */
"0C9S7ZZ" = "1" /* Drainage of Larynx, Via Natural or Artificial Opening */
"0C9S80Z" = "1" /* Drainage of Larynx with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0C9S8ZZ" = "1" /* Drainage of Larynx, Via Natural or Artificial Opening Endoscopic */
"0C9T00Z" = "1" /* Drainage of Right Vocal Cord with Drainage Device, Open Approach */
"0C9T0ZZ" = "1" /* Drainage of Right Vocal Cord, Open Approach */
"0C9T30Z" = "1" /* Drainage of Right Vocal Cord with Drainage Device, Percutaneous Approach */
"0C9T3ZZ" = "1" /* Drainage of Right Vocal Cord, Percutaneous Approach */
"0C9T40Z" = "1" /* Drainage of Right Vocal Cord with Drainage Device, Percutaneous Endoscopic Approach */
"0C9T4ZZ" = "1" /* Drainage of Right Vocal Cord, Percutaneous Endoscopic Approach */
"0C9T70Z" = "1" /* Drainage of Right Vocal Cord with Drainage Device, Via Natural or Artificial Opening */
"0C9T7ZZ" = "1" /* Drainage of Right Vocal Cord, Via Natural or Artificial Opening */
"0C9T80Z" = "1" /* Drainage of Right Vocal Cord with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0C9T8ZZ" = "1" /* Drainage of Right Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0C9V00Z" = "1" /* Drainage of Left Vocal Cord with Drainage Device, Open Approach */
"0C9V0ZZ" = "1" /* Drainage of Left Vocal Cord, Open Approach */
"0C9V30Z" = "1" /* Drainage of Left Vocal Cord with Drainage Device, Percutaneous Approach */
"0C9V3ZZ" = "1" /* Drainage of Left Vocal Cord, Percutaneous Approach */
"0C9V40Z" = "1" /* Drainage of Left Vocal Cord with Drainage Device, Percutaneous Endoscopic Approach */
"0C9V4ZZ" = "1" /* Drainage of Left Vocal Cord, Percutaneous Endoscopic Approach */
"0C9V70Z" = "1" /* Drainage of Left Vocal Cord with Drainage Device, Via Natural or Artificial Opening */
"0C9V7ZZ" = "1" /* Drainage of Left Vocal Cord, Via Natural or Artificial Opening */
"0C9V80Z" = "1" /* Drainage of Left Vocal Cord with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0C9V8ZZ" = "1" /* Drainage of Left Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CC80ZZ" = "1" /* Extirpation of Matter from Right Parotid Gland, Open Approach */
"0CC83ZZ" = "1" /* Extirpation of Matter from Right Parotid Gland, Percutaneous Approach */
"0CC90ZZ" = "1" /* Extirpation of Matter from Left Parotid Gland, Open Approach */
"0CC93ZZ" = "1" /* Extirpation of Matter from Left Parotid Gland, Percutaneous Approach */
"0CCB0ZZ" = "1" /* Extirpation of Matter from Right Parotid Duct, Open Approach */
"0CCB3ZZ" = "1" /* Extirpation of Matter from Right Parotid Duct, Percutaneous Approach */
"0CCC0ZZ" = "1" /* Extirpation of Matter from Left Parotid Duct, Open Approach */
"0CCC3ZZ" = "1" /* Extirpation of Matter from Left Parotid Duct, Percutaneous Approach */
"0CCD0ZZ" = "1" /* Extirpation of Matter from Right Sublingual Gland, Open Approach */
"0CCD3ZZ" = "1" /* Extirpation of Matter from Right Sublingual Gland, Percutaneous Approach */
"0CCF0ZZ" = "1" /* Extirpation of Matter from Left Sublingual Gland, Open Approach */
"0CCF3ZZ" = "1" /* Extirpation of Matter from Left Sublingual Gland, Percutaneous Approach */
"0CCG0ZZ" = "1" /* Extirpation of Matter from Right Submaxillary Gland, Open Approach */
"0CCG3ZZ" = "1" /* Extirpation of Matter from Right Submaxillary Gland, Percutaneous Approach */
"0CCH0ZZ" = "1" /* Extirpation of Matter from Left Submaxillary Gland, Open Approach */
"0CCH3ZZ" = "1" /* Extirpation of Matter from Left Submaxillary Gland, Percutaneous Approach */
"0CCJ0ZZ" = "1" /* Extirpation of Matter from Minor Salivary Gland, Open Approach */
"0CCJ3ZZ" = "1" /* Extirpation of Matter from Minor Salivary Gland, Percutaneous Approach */
"0CCR0ZZ" = "1" /* Extirpation of Matter from Epiglottis, Open Approach */
"0CCR3ZZ" = "1" /* Extirpation of Matter from Epiglottis, Percutaneous Approach */
"0CCR4ZZ" = "1" /* Extirpation of Matter from Epiglottis, Percutaneous Endoscopic Approach */
"0CCR7ZZ" = "1" /* Extirpation of Matter from Epiglottis, Via Natural or Artificial Opening */
"0CCR8ZZ" = "1" /* Extirpation of Matter from Epiglottis, Via Natural or Artificial Opening Endoscopic */
"0CCS0ZZ" = "1" /* Extirpation of Matter from Larynx, Open Approach */
"0CCS3ZZ" = "1" /* Extirpation of Matter from Larynx, Percutaneous Approach */
"0CCS4ZZ" = "1" /* Extirpation of Matter from Larynx, Percutaneous Endoscopic Approach */
"0CCT0ZZ" = "1" /* Extirpation of Matter from Right Vocal Cord, Open Approach */
"0CCT3ZZ" = "1" /* Extirpation of Matter from Right Vocal Cord, Percutaneous Approach */
"0CCT4ZZ" = "1" /* Extirpation of Matter from Right Vocal Cord, Percutaneous Endoscopic Approach */
"0CCT7ZZ" = "1" /* Extirpation of Matter from Right Vocal Cord, Via Natural or Artificial Opening */
"0CCT8ZZ" = "1" /* Extirpation of Matter from Right Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CCV0ZZ" = "1" /* Extirpation of Matter from Left Vocal Cord, Open Approach */
"0CCV3ZZ" = "1" /* Extirpation of Matter from Left Vocal Cord, Percutaneous Approach */
"0CCV4ZZ" = "1" /* Extirpation of Matter from Left Vocal Cord, Percutaneous Endoscopic Approach */
"0CCV7ZZ" = "1" /* Extirpation of Matter from Left Vocal Cord, Via Natural or Artificial Opening */
"0CCV8ZZ" = "1" /* Extirpation of Matter from Left Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CWS00Z" = "1" /* Revision of Drainage Device in Larynx, Open Approach */
"0CWS30Z" = "1" /* Revision of Drainage Device in Larynx, Percutaneous Approach */
"0CWS70Z" = "1" /* Revision of Drainage Device in Larynx, Via Natural or Artificial Opening */
"0CWS80Z" = "1" /* Revision of Drainage Device in Larynx, Via Natural or Artificial Opening Endoscopic */
"0D510ZZ" = "1" /* Destruction of Upper Esophagus, Open Approach */
"0D513ZZ" = "1" /* Destruction of Upper Esophagus, Percutaneous Approach */
"0D514ZZ" = "1" /* Destruction of Upper Esophagus, Percutaneous Endoscopic Approach */
"0D517ZZ" = "1" /* Destruction of Upper Esophagus, Via Natural or Artificial Opening */
"0D518ZZ" = "1" /* Destruction of Upper Esophagus, Via Natural or Artificial Opening Endoscopic */
"0D520ZZ" = "1" /* Destruction of Middle Esophagus, Open Approach */
"0D523ZZ" = "1" /* Destruction of Middle Esophagus, Percutaneous Approach */
"0D524ZZ" = "1" /* Destruction of Middle Esophagus, Percutaneous Endoscopic Approach */
"0D527ZZ" = "1" /* Destruction of Middle Esophagus, Via Natural or Artificial Opening */
"0D528ZZ" = "1" /* Destruction of Middle Esophagus, Via Natural or Artificial Opening Endoscopic */
"0D530ZZ" = "1" /* Destruction of Lower Esophagus, Open Approach */
"0D533ZZ" = "1" /* Destruction of Lower Esophagus, Percutaneous Approach */
"0D534ZZ" = "1" /* Destruction of Lower Esophagus, Percutaneous Endoscopic Approach */
"0D537ZZ" = "1" /* Destruction of Lower Esophagus, Via Natural or Artificial Opening */
"0D538ZZ" = "1" /* Destruction of Lower Esophagus, Via Natural or Artificial Opening Endoscopic */
"0D540ZZ" = "1" /* Destruction of Esophagogastric Junction, Open Approach */
"0D543ZZ" = "1" /* Destruction of Esophagogastric Junction, Percutaneous Approach */
"0D544ZZ" = "1" /* Destruction of Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0D547ZZ" = "1" /* Destruction of Esophagogastric Junction, Via Natural or Artificial Opening */
"0D548ZZ" = "1" /* Destruction of Esophagogastric Junction, Via Natural or Artificial Opening Endoscopic */
"0D550ZZ" = "1" /* Destruction of Esophagus, Open Approach */
"0D553ZZ" = "1" /* Destruction of Esophagus, Percutaneous Approach */
"0D554ZZ" = "1" /* Destruction of Esophagus, Percutaneous Endoscopic Approach */
"0D557ZZ" = "1" /* Destruction of Esophagus, Via Natural or Artificial Opening */
"0D558ZZ" = "1" /* Destruction of Esophagus, Via Natural or Artificial Opening Endoscopic */
"0D564ZZ" = "1" /* Destruction of Stomach, Percutaneous Endoscopic Approach */
"0D568ZZ" = "1" /* Destruction of Stomach, Via Natural or Artificial Opening Endoscopic */
"0D574ZZ" = "1" /* Destruction of Stomach, Pylorus, Percutaneous Endoscopic Approach */
"0D578ZZ" = "1" /* Destruction of Stomach, Pylorus, Via Natural or Artificial Opening Endoscopic */
"0D5E0ZZ" = "1" /* Destruction of Large Intestine, Open Approach */
"0D5E3ZZ" = "1" /* Destruction of Large Intestine, Percutaneous Approach */
"0D5E4ZZ" = "1" /* Destruction of Large Intestine, Percutaneous Endoscopic Approach */
"0D5E7ZZ" = "1" /* Destruction of Large Intestine, Via Natural or Artificial Opening */
"0D5E8ZZ" = "1" /* Destruction of Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0D5F0ZZ" = "1" /* Destruction of Right Large Intestine, Open Approach */
"0D5F3ZZ" = "1" /* Destruction of Right Large Intestine, Percutaneous Approach */
"0D5F4ZZ" = "1" /* Destruction of Right Large Intestine, Percutaneous Endoscopic Approach */
"0D5F7ZZ" = "1" /* Destruction of Right Large Intestine, Via Natural or Artificial Opening */
"0D5F8ZZ" = "1" /* Destruction of Right Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0D5G0ZZ" = "1" /* Destruction of Left Large Intestine, Open Approach */
"0D5G3ZZ" = "1" /* Destruction of Left Large Intestine, Percutaneous Approach */
"0D5G4ZZ" = "1" /* Destruction of Left Large Intestine, Percutaneous Endoscopic Approach */
"0D5G7ZZ" = "1" /* Destruction of Left Large Intestine, Via Natural or Artificial Opening */
"0D5G8ZZ" = "1" /* Destruction of Left Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0D5H0ZZ" = "1" /* Destruction of Cecum, Open Approach */
"0D5H3ZZ" = "1" /* Destruction of Cecum, Percutaneous Approach */
"0D5H4ZZ" = "1" /* Destruction of Cecum, Percutaneous Endoscopic Approach */
"0D5H7ZZ" = "1" /* Destruction of Cecum, Via Natural or Artificial Opening */
"0D5H8ZZ" = "1" /* Destruction of Cecum, Via Natural or Artificial Opening Endoscopic */
"0D5K0ZZ" = "1" /* Destruction of Ascending Colon, Open Approach */
"0D5K3ZZ" = "1" /* Destruction of Ascending Colon, Percutaneous Approach */
"0D5K4ZZ" = "1" /* Destruction of Ascending Colon, Percutaneous Endoscopic Approach */
"0D5K7ZZ" = "1" /* Destruction of Ascending Colon, Via Natural or Artificial Opening */
"0D5K8ZZ" = "1" /* Destruction of Ascending Colon, Via Natural or Artificial Opening Endoscopic */
"0D5L0ZZ" = "1" /* Destruction of Transverse Colon, Open Approach */
"0D5L3ZZ" = "1" /* Destruction of Transverse Colon, Percutaneous Approach */
"0D5L4ZZ" = "1" /* Destruction of Transverse Colon, Percutaneous Endoscopic Approach */
"0D5L7ZZ" = "1" /* Destruction of Transverse Colon, Via Natural or Artificial Opening */
"0D5L8ZZ" = "1" /* Destruction of Transverse Colon, Via Natural or Artificial Opening Endoscopic */
"0D5M0ZZ" = "1" /* Destruction of Descending Colon, Open Approach */
"0D5M3ZZ" = "1" /* Destruction of Descending Colon, Percutaneous Approach */
"0D5M4ZZ" = "1" /* Destruction of Descending Colon, Percutaneous Endoscopic Approach */
"0D5M7ZZ" = "1" /* Destruction of Descending Colon, Via Natural or Artificial Opening */
"0D5M8ZZ" = "1" /* Destruction of Descending Colon, Via Natural or Artificial Opening Endoscopic */
"0D5N0ZZ" = "1" /* Destruction of Sigmoid Colon, Open Approach */
"0D5N3ZZ" = "1" /* Destruction of Sigmoid Colon, Percutaneous Approach */
"0D5N4ZZ" = "1" /* Destruction of Sigmoid Colon, Percutaneous Endoscopic Approach */
"0D5N7ZZ" = "1" /* Destruction of Sigmoid Colon, Via Natural or Artificial Opening */
"0D5N8ZZ" = "1" /* Destruction of Sigmoid Colon, Via Natural or Artificial Opening Endoscopic */
"0D9S00Z" = "1" /* Drainage of Greater Omentum with Drainage Device, Open Approach */
"0D9S0ZZ" = "1" /* Drainage of Greater Omentum, Open Approach */
"0D9T00Z" = "1" /* Drainage of Lesser Omentum with Drainage Device, Open Approach */
"0D9T0ZZ" = "1" /* Drainage of Lesser Omentum, Open Approach */
"0D9V00Z" = "1" /* Drainage of Mesentery with Drainage Device, Open Approach */
"0D9V0ZZ" = "1" /* Drainage of Mesentery, Open Approach */
"0D9W00Z" = "1" /* Drainage of Peritoneum with Drainage Device, Open Approach */
"0D9W0ZZ" = "1" /* Drainage of Peritoneum, Open Approach */
"0DB10ZZ" = "1" /* Excision of Upper Esophagus, Open Approach */
"0DB13ZZ" = "1" /* Excision of Upper Esophagus, Percutaneous Approach */
"0DB14ZZ" = "1" /* Excision of Upper Esophagus, Percutaneous Endoscopic Approach */
"0DB17ZZ" = "1" /* Excision of Upper Esophagus, Via Natural or Artificial Opening */
"0DB18ZZ" = "1" /* Excision of Upper Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DB20ZZ" = "1" /* Excision of Middle Esophagus, Open Approach */
"0DB23ZZ" = "1" /* Excision of Middle Esophagus, Percutaneous Approach */
"0DB24ZZ" = "1" /* Excision of Middle Esophagus, Percutaneous Endoscopic Approach */
"0DB27ZZ" = "1" /* Excision of Middle Esophagus, Via Natural or Artificial Opening */
"0DB28ZZ" = "1" /* Excision of Middle Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DB30ZZ" = "1" /* Excision of Lower Esophagus, Open Approach */
"0DB33ZZ" = "1" /* Excision of Lower Esophagus, Percutaneous Approach */
"0DB34ZZ" = "1" /* Excision of Lower Esophagus, Percutaneous Endoscopic Approach */
"0DB37ZZ" = "1" /* Excision of Lower Esophagus, Via Natural or Artificial Opening */
"0DB38ZZ" = "1" /* Excision of Lower Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DB40ZZ" = "1" /* Excision of Esophagogastric Junction, Open Approach */
"0DB43ZZ" = "1" /* Excision of Esophagogastric Junction, Percutaneous Approach */
"0DB47ZZ" = "1" /* Excision of Esophagogastric Junction, Via Natural or Artificial Opening */
"0DB48ZZ" = "1" /* Excision of Esophagogastric Junction, Via Natural or Artificial Opening Endoscopic */
"0DB50ZZ" = "1" /* Excision of Esophagus, Open Approach */
"0DB53ZZ" = "1" /* Excision of Esophagus, Percutaneous Approach */
"0DB54ZZ" = "1" /* Excision of Esophagus, Percutaneous Endoscopic Approach */
"0DB57ZZ" = "1" /* Excision of Esophagus, Via Natural or Artificial Opening */
"0DB58ZZ" = "1" /* Excision of Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DB64ZZ" = "1" /* Excision of Stomach, Percutaneous Endoscopic Approach */
"0DB68ZZ" = "1" /* Excision of Stomach, Via Natural or Artificial Opening Endoscopic */
"0DB74ZZ" = "1" /* Excision of Stomach, Pylorus, Percutaneous Endoscopic Approach */
"0DB78ZZ" = "1" /* Excision of Stomach, Pylorus, Via Natural or Artificial Opening Endoscopic */
"0DQ60ZZ" = "1" /* Repair Stomach, Open Approach */
"0DQ63ZZ" = "1" /* Repair Stomach, Percutaneous Approach */
"0DQ64ZZ" = "1" /* Repair Stomach, Percutaneous Endoscopic Approach */
"0DQ67ZZ" = "1" /* Repair Stomach, Via Natural or Artificial Opening */
"0DQ68ZZ" = "1" /* Repair Stomach, Via Natural or Artificial Opening Endoscopic */
"0DQ90ZZ" = "1" /* Repair Duodenum, Open Approach */
"0DQ93ZZ" = "1" /* Repair Duodenum, Percutaneous Approach */
"0DQ94ZZ" = "1" /* Repair Duodenum, Percutaneous Endoscopic Approach */
"0DQ97ZZ" = "1" /* Repair Duodenum, Via Natural or Artificial Opening */
"0DQ98ZZ" = "1" /* Repair Duodenum, Via Natural or Artificial Opening Endoscopic */
"0F9000Z" = "1" /* Drainage of Liver with Drainage Device, Open Approach */
"0F900ZZ" = "1" /* Drainage of Liver, Open Approach */
"0F9100Z" = "1" /* Drainage of Right Lobe Liver with Drainage Device, Open Approach */
"0F910ZZ" = "1" /* Drainage of Right Lobe Liver, Open Approach */
"0F9200Z" = "1" /* Drainage of Left Lobe Liver with Drainage Device, Open Approach */
"0F920ZZ" = "1" /* Drainage of Left Lobe Liver, Open Approach */
"0FC00ZZ" = "1" /* Extirpation of Matter from Liver, Open Approach */
"0FC03ZZ" = "1" /* Extirpation of Matter from Liver, Percutaneous Approach */
"0FC04ZZ" = "1" /* Extirpation of Matter from Liver, Percutaneous Endoscopic Approach */
"0FC10ZZ" = "1" /* Extirpation of Matter from Right Lobe Liver, Open Approach */
"0FC13ZZ" = "1" /* Extirpation of Matter from Right Lobe Liver, Percutaneous Approach */
"0FC14ZZ" = "1" /* Extirpation of Matter from Right Lobe Liver, Percutaneous Endoscopic Approach */
"0FC20ZZ" = "1" /* Extirpation of Matter from Left Lobe Liver, Open Approach */
"0FC23ZZ" = "1" /* Extirpation of Matter from Left Lobe Liver, Percutaneous Approach */
"0FC24ZZ" = "1" /* Extirpation of Matter from Left Lobe Liver, Percutaneous Endoscopic Approach */
"0FCG0ZZ" = "1" /* Extirpation of Matter from Pancreas, Open Approach */
"0FCG3ZZ" = "1" /* Extirpation of Matter from Pancreas, Percutaneous Approach */
"0FCG4ZZ" = "1" /* Extirpation of Matter from Pancreas, Percutaneous Endoscopic Approach */
"0FW000Z" = "1" /* Revision of Drainage Device in Liver, Open Approach */
"0FW030Z" = "1" /* Revision of Drainage Device in Liver, Percutaneous Approach */
"0FW040Z" = "1" /* Revision of Drainage Device in Liver, Percutaneous Endoscopic Approach */
"0G9200Z" = "1" /* Drainage of Left Adrenal Gland with Drainage Device, Open Approach */
"0G920ZZ" = "1" /* Drainage of Left Adrenal Gland, Open Approach */
"0G9230Z" = "1" /* Drainage of Left Adrenal Gland with Drainage Device, Percutaneous Approach */
"0G923ZZ" = "1" /* Drainage of Left Adrenal Gland, Percutaneous Approach */
"0G9240Z" = "1" /* Drainage of Left Adrenal Gland with Drainage Device, Percutaneous Endoscopic Approach */
"0G924ZZ" = "1" /* Drainage of Left Adrenal Gland, Percutaneous Endoscopic Approach */
"0G9300Z" = "1" /* Drainage of Right Adrenal Gland with Drainage Device, Open Approach */
"0G930ZZ" = "1" /* Drainage of Right Adrenal Gland, Open Approach */
"0G9330Z" = "1" /* Drainage of Right Adrenal Gland with Drainage Device, Percutaneous Approach */
"0G933ZZ" = "1" /* Drainage of Right Adrenal Gland, Percutaneous Approach */
"0G9340Z" = "1" /* Drainage of Right Adrenal Gland with Drainage Device, Percutaneous Endoscopic Approach */
"0G934ZZ" = "1" /* Drainage of Right Adrenal Gland, Percutaneous Endoscopic Approach */
"0G9400Z" = "1" /* Drainage of Bilateral Adrenal Glands with Drainage Device, Open Approach */
"0G940ZZ" = "1" /* Drainage of Bilateral Adrenal Glands, Open Approach */
"0G9430Z" = "1" /* Drainage of Bilateral Adrenal Glands with Drainage Device, Percutaneous Approach */
"0G943ZZ" = "1" /* Drainage of Bilateral Adrenal Glands, Percutaneous Approach */
"0G9440Z" = "1" /* Drainage of Bilateral Adrenal Glands with Drainage Device, Percutaneous Endoscopic Approach */
"0G944ZZ" = "1" /* Drainage of Bilateral Adrenal Glands, Percutaneous Endoscopic Approach */
"0G9G00Z" = "1" /* Drainage of Left Thyroid Gland Lobe with Drainage Device, Open Approach */
"0G9G0ZZ" = "1" /* Drainage of Left Thyroid Gland Lobe, Open Approach */
"0G9H00Z" = "1" /* Drainage of Right Thyroid Gland Lobe with Drainage Device, Open Approach */
"0G9H0ZZ" = "1" /* Drainage of Right Thyroid Gland Lobe, Open Approach */
"0G9K00Z" = "1" /* Drainage of Thyroid Gland with Drainage Device, Open Approach */
"0G9K0ZZ" = "1" /* Drainage of Thyroid Gland, Open Approach */
"0GC20ZZ" = "1" /* Extirpation of Matter from Left Adrenal Gland, Open Approach */
"0GC23ZZ" = "1" /* Extirpation of Matter from Left Adrenal Gland, Percutaneous Approach */
"0GC24ZZ" = "1" /* Extirpation of Matter from Left Adrenal Gland, Percutaneous Endoscopic Approach */
"0GC30ZZ" = "1" /* Extirpation of Matter from Right Adrenal Gland, Open Approach */
"0GC33ZZ" = "1" /* Extirpation of Matter from Right Adrenal Gland, Percutaneous Approach */
"0GC34ZZ" = "1" /* Extirpation of Matter from Right Adrenal Gland, Percutaneous Endoscopic Approach */
"0GC40ZZ" = "1" /* Extirpation of Matter from Bilateral Adrenal Glands, Open Approach */
"0GC43ZZ" = "1" /* Extirpation of Matter from Bilateral Adrenal Glands, Percutaneous Approach */
"0GC44ZZ" = "1" /* Extirpation of Matter from Bilateral Adrenal Glands, Percutaneous Endoscopic Approach */
"0GCG0ZZ" = "1" /* Extirpation of Matter from Left Thyroid Gland Lobe, Open Approach */
"0GCG3ZZ" = "1" /* Extirpation of Matter from Left Thyroid Gland Lobe, Percutaneous Approach */
"0GCG4ZZ" = "1" /* Extirpation of Matter from Left Thyroid Gland Lobe, Percutaneous Endoscopic Approach */
"0GCH0ZZ" = "1" /* Extirpation of Matter from Right Thyroid Gland Lobe, Open Approach */
"0GCH3ZZ" = "1" /* Extirpation of Matter from Right Thyroid Gland Lobe, Percutaneous Approach */
"0GCH4ZZ" = "1" /* Extirpation of Matter from Right Thyroid Gland Lobe, Percutaneous Endoscopic Approach */
"0GCK0ZZ" = "1" /* Extirpation of Matter from Thyroid Gland, Open Approach */
"0GCK3ZZ" = "1" /* Extirpation of Matter from Thyroid Gland, Percutaneous Approach */
"0GCK4ZZ" = "1" /* Extirpation of Matter from Thyroid Gland, Percutaneous Endoscopic Approach */
"0GW500Z" = "1" /* Revision of Drainage Device in Adrenal Gland, Open Approach */
"0GW530Z" = "1" /* Revision of Drainage Device in Adrenal Gland, Percutaneous Approach */
"0GW540Z" = "1" /* Revision of Drainage Device in Adrenal Gland, Percutaneous Endoscopic Approach */
"0GWK00Z" = "1" /* Revision of Drainage Device in Thyroid Gland, Open Approach */
"0GWK30Z" = "1" /* Revision of Drainage Device in Thyroid Gland, Percutaneous Approach */
"0GWK40Z" = "1" /* Revision of Drainage Device in Thyroid Gland, Percutaneous Endoscopic Approach */
"0H91X0Z" = "1" /* Drainage of Face Skin with Drainage Device, External Approach */
"0H91XZZ" = "1" /* Drainage of Face Skin, External Approach */
"0H98X0Z" = "1" /* Drainage of Buttock Skin with Drainage Device, External Approach */
"0H98XZZ" = "1" /* Drainage of Buttock Skin, External Approach */
"0H9T00Z" = "1" /* Drainage of Right Breast with Drainage Device, Open Approach */
"0H9T0ZZ" = "1" /* Drainage of Right Breast, Open Approach */
"0H9TX0Z" = "1" /* Drainage of Right Breast with Drainage Device, External Approach */
"0H9TXZZ" = "1" /* Drainage of Right Breast, External Approach */
"0H9U00Z" = "1" /* Drainage of Left Breast with Drainage Device, Open Approach */
"0H9U0ZZ" = "1" /* Drainage of Left Breast, Open Approach */
"0H9UX0Z" = "1" /* Drainage of Left Breast with Drainage Device, External Approach */
"0H9UXZZ" = "1" /* Drainage of Left Breast, External Approach */
"0H9V00Z" = "1" /* Drainage of Bilateral Breast with Drainage Device, Open Approach */
"0H9V0ZZ" = "1" /* Drainage of Bilateral Breast, Open Approach */
"0H9VX0Z" = "1" /* Drainage of Bilateral Breast with Drainage Device, External Approach */
"0H9VXZZ" = "1" /* Drainage of Bilateral Breast, External Approach */
"0H9W00Z" = "1" /* Drainage of Right Nipple with Drainage Device, Open Approach */
"0H9W0ZZ" = "1" /* Drainage of Right Nipple, Open Approach */
"0H9WX0Z" = "1" /* Drainage of Right Nipple with Drainage Device, External Approach */
"0H9WXZZ" = "1" /* Drainage of Right Nipple, External Approach */
"0H9X00Z" = "1" /* Drainage of Left Nipple with Drainage Device, Open Approach */
"0H9X0ZZ" = "1" /* Drainage of Left Nipple, Open Approach */
"0H9XX0Z" = "1" /* Drainage of Left Nipple with Drainage Device, External Approach */
"0H9XXZZ" = "1" /* Drainage of Left Nipple, External Approach */
"0HCT0ZZ" = "1" /* Extirpation of Matter from Right Breast, Open Approach */
"0HCT3ZZ" = "1" /* Extirpation of Matter from Right Breast, Percutaneous Approach */
"0HCT7ZZ" = "1" /* Extirpation of Matter from Right Breast, Via Natural or Artificial Opening */
"0HCT8ZZ" = "1" /* Extirpation of Matter from Right Breast, Via Natural or Artificial Opening Endoscopic */
"0HCTXZZ" = "1" /* Extirpation of Matter from Right Breast, External Approach */
"0HCU0ZZ" = "1" /* Extirpation of Matter from Left Breast, Open Approach */
"0HCU3ZZ" = "1" /* Extirpation of Matter from Left Breast, Percutaneous Approach */
"0HCU7ZZ" = "1" /* Extirpation of Matter from Left Breast, Via Natural or Artificial Opening */
"0HCU8ZZ" = "1" /* Extirpation of Matter from Left Breast, Via Natural or Artificial Opening Endoscopic */
"0HCUXZZ" = "1" /* Extirpation of Matter from Left Breast, External Approach */
"0HCV0ZZ" = "1" /* Extirpation of Matter from Bilateral Breast, Open Approach */
"0HCV3ZZ" = "1" /* Extirpation of Matter from Bilateral Breast, Percutaneous Approach */
"0HCV7ZZ" = "1" /* Extirpation of Matter from Bilateral Breast, Via Natural or Artificial Opening */
"0HCV8ZZ" = "1" /* Extirpation of Matter from Bilateral Breast, Via Natural or Artificial Opening Endoscopic */
"0HCVXZZ" = "1" /* Extirpation of Matter from Bilateral Breast, External Approach */
"0HCW0ZZ" = "1" /* Extirpation of Matter from Right Nipple, Open Approach */
"0HCW3ZZ" = "1" /* Extirpation of Matter from Right Nipple, Percutaneous Approach */
"0HCW7ZZ" = "1" /* Extirpation of Matter from Right Nipple, Via Natural or Artificial Opening */
"0HCW8ZZ" = "1" /* Extirpation of Matter from Right Nipple, Via Natural or Artificial Opening Endoscopic */
"0HCWXZZ" = "1" /* Extirpation of Matter from Right Nipple, External Approach */
"0HCX0ZZ" = "1" /* Extirpation of Matter from Left Nipple, Open Approach */
"0HCX3ZZ" = "1" /* Extirpation of Matter from Left Nipple, Percutaneous Approach */
"0HCX7ZZ" = "1" /* Extirpation of Matter from Left Nipple, Via Natural or Artificial Opening */
"0HCX8ZZ" = "1" /* Extirpation of Matter from Left Nipple, Via Natural or Artificial Opening Endoscopic */
"0HCXXZZ" = "1" /* Extirpation of Matter from Left Nipple, External Approach */
"0HWT00Z" = "1" /* Revision of Drainage Device in Right Breast, Open Approach */
"0HWT30Z" = "1" /* Revision of Drainage Device in Right Breast, Percutaneous Approach */
"0HWT70Z" = "1" /* Revision of Drainage Device in Right Breast, Via Natural or Artificial Opening */
"0HWT80Z" = "1" /* Revision of Drainage Device in Right Breast, Via Natural or Artificial Opening Endoscopic */
"0HWU00Z" = "1" /* Revision of Drainage Device in Left Breast, Open Approach */
"0HWU30Z" = "1" /* Revision of Drainage Device in Left Breast, Percutaneous Approach */
"0HWU70Z" = "1" /* Revision of Drainage Device in Left Breast, Via Natural or Artificial Opening */
"0HWU80Z" = "1" /* Revision of Drainage Device in Left Breast, Via Natural or Artificial Opening Endoscopic */
"0J900ZZ" = "1" /* Drainage of Scalp Subcutaneous Tissue and Fascia, Open Approach */
"0J9100Z" = "1" /* Drainage of Face Subcutaneous Tissue and Fascia with Drainage Device, Open Approach */
"0J910ZZ" = "1" /* Drainage of Face Subcutaneous Tissue and Fascia, Open Approach */
"0J9130Z" = "1" /* Drainage of Face Subcutaneous Tissue and Fascia with Drainage Device, Percutaneous Approach */
"0J940ZZ" = "1" /* Drainage of Anterior Neck Subcutaneous Tissue and Fascia, Open Approach */
"0J950ZZ" = "1" /* Drainage of Posterior Neck Subcutaneous Tissue and Fascia, Open Approach */
"0J960ZZ" = "1" /* Drainage of Chest Subcutaneous Tissue and Fascia, Open Approach */
"0J970ZZ" = "1" /* Drainage of Back Subcutaneous Tissue and Fascia, Open Approach */
"0J980ZZ" = "1" /* Drainage of Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0J990ZZ" = "1" /* Drainage of Buttock Subcutaneous Tissue and Fascia, Open Approach */
"0J9B0ZZ" = "1" /* Drainage of Perineum Subcutaneous Tissue and Fascia, Open Approach */
"0J9C0ZZ" = "1" /* Drainage of Pelvic Region Subcutaneous Tissue and Fascia, Open Approach */
"0J9D0ZZ" = "1" /* Drainage of Right Upper Arm Subcutaneous Tissue and Fascia, Open Approach */
"0J9F0ZZ" = "1" /* Drainage of Left Upper Arm Subcutaneous Tissue and Fascia, Open Approach */
"0J9G0ZZ" = "1" /* Drainage of Right Lower Arm Subcutaneous Tissue and Fascia, Open Approach */
"0J9H0ZZ" = "1" /* Drainage of Left Lower Arm Subcutaneous Tissue and Fascia, Open Approach */
"0J9J00Z" = "1" /* Drainage of Right Hand Subcutaneous Tissue and Fascia with Drainage Device, Open Approach */
"0J9J0ZZ" = "1" /* Drainage of Right Hand Subcutaneous Tissue and Fascia, Open Approach */
"0J9J30Z" = "1" /* Drainage of Right Hand Subcutaneous Tissue and Fascia with Drainage Device, Percutaneous Approach */
"0J9J3ZZ" = "1" /* Drainage of Right Hand Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J9K00Z" = "1" /* Drainage of Left Hand Subcutaneous Tissue and Fascia with Drainage Device, Open Approach */
"0J9K0ZZ" = "1" /* Drainage of Left Hand Subcutaneous Tissue and Fascia, Open Approach */
"0J9K30Z" = "1" /* Drainage of Left Hand Subcutaneous Tissue and Fascia with Drainage Device, Percutaneous Approach */
"0J9K3ZZ" = "1" /* Drainage of Left Hand Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J9L0ZZ" = "1" /* Drainage of Right Upper Leg Subcutaneous Tissue and Fascia, Open Approach */
"0J9M0ZZ" = "1" /* Drainage of Left Upper Leg Subcutaneous Tissue and Fascia, Open Approach */
"0J9N0ZZ" = "1" /* Drainage of Right Lower Leg Subcutaneous Tissue and Fascia, Open Approach */
"0J9P0ZZ" = "1" /* Drainage of Left Lower Leg Subcutaneous Tissue and Fascia, Open Approach */
"0J9Q0ZZ" = "1" /* Drainage of Right Foot Subcutaneous Tissue and Fascia, Open Approach */
"0J9R0ZZ" = "1" /* Drainage of Left Foot Subcutaneous Tissue and Fascia, Open Approach */
"0JC00ZZ" = "1" /* Extirpation of Matter from Scalp Subcutaneous Tissue and Fascia, Open Approach */
"0JC03ZZ" = "1" /* Extirpation of Matter from Scalp Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JC10ZZ" = "1" /* Extirpation of Matter from Face Subcutaneous Tissue and Fascia, Open Approach */
"0JC13ZZ" = "1" /* Extirpation of Matter from Face Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JC40ZZ" = "1" /* Extirpation of Matter from Anterior Neck Subcutaneous Tissue and Fascia, Open Approach */
"0JC43ZZ" = "1" /* Extirpation of Matter from Anterior Neck Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JC50ZZ" = "1" /* Extirpation of Matter from Posterior Neck Subcutaneous Tissue and Fascia, Open Approach */
"0JC53ZZ" = "1" /* Extirpation of Matter from Posterior Neck Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JC60ZZ" = "1" /* Extirpation of Matter from Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JC63ZZ" = "1" /* Extirpation of Matter from Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JC70ZZ" = "1" /* Extirpation of Matter from Back Subcutaneous Tissue and Fascia, Open Approach */
"0JC73ZZ" = "1" /* Extirpation of Matter from Back Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JC80ZZ" = "1" /* Extirpation of Matter from Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JC83ZZ" = "1" /* Extirpation of Matter from Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JC90ZZ" = "1" /* Extirpation of Matter from Buttock Subcutaneous Tissue and Fascia, Open Approach */
"0JC93ZZ" = "1" /* Extirpation of Matter from Buttock Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JCB0ZZ" = "1" /* Extirpation of Matter from Perineum Subcutaneous Tissue and Fascia, Open Approach */
"0JCB3ZZ" = "1" /* Extirpation of Matter from Perineum Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JCC0ZZ" = "1" /* Extirpation of Matter from Pelvic Region Subcutaneous Tissue and Fascia, Open Approach */
"0JCC3ZZ" = "1" /* Extirpation of Matter from Pelvic Region Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JCD0ZZ" = "1" /* Extirpation of Matter from Right Upper Arm Subcutaneous Tissue and Fascia, Open Approach */
"0JCD3ZZ" = "1" /* Extirpation of Matter from Right Upper Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JCF0ZZ" = "1" /* Extirpation of Matter from Left Upper Arm Subcutaneous Tissue and Fascia, Open Approach */
"0JCF3ZZ" = "1" /* Extirpation of Matter from Left Upper Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JCG0ZZ" = "1" /* Extirpation of Matter from Right Lower Arm Subcutaneous Tissue and Fascia, Open Approach */
"0JCG3ZZ" = "1" /* Extirpation of Matter from Right Lower Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JCH0ZZ" = "1" /* Extirpation of Matter from Left Lower Arm Subcutaneous Tissue and Fascia, Open Approach */
"0JCH3ZZ" = "1" /* Extirpation of Matter from Left Lower Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JCJ0ZZ" = "1" /* Extirpation of Matter from Right Hand Subcutaneous Tissue and Fascia, Open Approach */
"0JCJ3ZZ" = "1" /* Extirpation of Matter from Right Hand Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JCK0ZZ" = "1" /* Extirpation of Matter from Left Hand Subcutaneous Tissue and Fascia, Open Approach */
"0JCK3ZZ" = "1" /* Extirpation of Matter from Left Hand Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JCL0ZZ" = "1" /* Extirpation of Matter from Right Upper Leg Subcutaneous Tissue and Fascia, Open Approach */
"0JCL3ZZ" = "1" /* Extirpation of Matter from Right Upper Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JCM0ZZ" = "1" /* Extirpation of Matter from Left Upper Leg Subcutaneous Tissue and Fascia, Open Approach */
"0JCM3ZZ" = "1" /* Extirpation of Matter from Left Upper Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JCN0ZZ" = "1" /* Extirpation of Matter from Right Lower Leg Subcutaneous Tissue and Fascia, Open Approach */
"0JCN3ZZ" = "1" /* Extirpation of Matter from Right Lower Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JCP0ZZ" = "1" /* Extirpation of Matter from Left Lower Leg Subcutaneous Tissue and Fascia, Open Approach */
"0JCP3ZZ" = "1" /* Extirpation of Matter from Left Lower Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JCQ0ZZ" = "1" /* Extirpation of Matter from Right Foot Subcutaneous Tissue and Fascia, Open Approach */
"0JCQ3ZZ" = "1" /* Extirpation of Matter from Right Foot Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JCR0ZZ" = "1" /* Extirpation of Matter from Left Foot Subcutaneous Tissue and Fascia, Open Approach */
"0JCR3ZZ" = "1" /* Extirpation of Matter from Left Foot Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JWS00Z" = "1" /* Revision of Drainage Device in Head and Neck Subcutaneous Tissue and Fascia, Open Approach */
"0JWS30Z" = "1" /* Revision of Drainage Device in Head and Neck Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JWT00Z" = "1" /* Revision of Drainage Device in Trunk Subcutaneous Tissue and Fascia, Open Approach */
"0JWT0XZ" = "1" /* Revision of Vascular Access Device in Trunk Subcutaneous Tissue and Fascia, Open Approach */
"0JWT30Z" = "1" /* Revision of Drainage Device in Trunk Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JWT3XZ" = "1" /* Revision of Vascular Access Device in Trunk Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JWV00Z" = "1" /* Revision of Drainage Device in Upper Extremity Subcutaneous Tissue and Fascia, Open Approach */
"0JWV0XZ" = "1" /* Revision of Vascular Access Device in Upper Extremity Subcutaneous Tissue and Fascia, Open Approach */
"0JWV30Z" = "1" /* Revision of Drainage Device in Upper Extremity Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JWV3XZ" = "1" /* Revision of Vascular Access Device in Upper Extremity Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JWW00Z" = "1" /* Revision of Drainage Device in Lower Extremity Subcutaneous Tissue and Fascia, Open Approach */
"0JWW0XZ" = "1" /* Revision of Vascular Access Device in Lower Extremity Subcutaneous Tissue and Fascia, Open Approach */
"0JWW30Z" = "1" /* Revision of Drainage Device in Lower Extremity Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JWW3XZ" = "1" /* Revision of Vascular Access Device in Lower Extremity Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0K9000Z" = "1" /* Drainage of Head Muscle with Drainage Device, Open Approach */
"0K900ZZ" = "1" /* Drainage of Head Muscle, Open Approach */
"0K9030Z" = "1" /* Drainage of Head Muscle with Drainage Device, Percutaneous Approach */
"0K9040Z" = "1" /* Drainage of Head Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K904ZZ" = "1" /* Drainage of Head Muscle, Percutaneous Endoscopic Approach */
"0K9100Z" = "1" /* Drainage of Facial Muscle with Drainage Device, Open Approach */
"0K910ZZ" = "1" /* Drainage of Facial Muscle, Open Approach */
"0K9130Z" = "1" /* Drainage of Facial Muscle with Drainage Device, Percutaneous Approach */
"0K9140Z" = "1" /* Drainage of Facial Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K914ZZ" = "1" /* Drainage of Facial Muscle, Percutaneous Endoscopic Approach */
"0K9200Z" = "1" /* Drainage of Right Neck Muscle with Drainage Device, Open Approach */
"0K920ZZ" = "1" /* Drainage of Right Neck Muscle, Open Approach */
"0K9230Z" = "1" /* Drainage of Right Neck Muscle with Drainage Device, Percutaneous Approach */
"0K9240Z" = "1" /* Drainage of Right Neck Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K924ZZ" = "1" /* Drainage of Right Neck Muscle, Percutaneous Endoscopic Approach */
"0K9300Z" = "1" /* Drainage of Left Neck Muscle with Drainage Device, Open Approach */
"0K930ZZ" = "1" /* Drainage of Left Neck Muscle, Open Approach */
"0K9330Z" = "1" /* Drainage of Left Neck Muscle with Drainage Device, Percutaneous Approach */
"0K9340Z" = "1" /* Drainage of Left Neck Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K934ZZ" = "1" /* Drainage of Left Neck Muscle, Percutaneous Endoscopic Approach */
"0K9400Z" = "1" /* Drainage of Tongue, Palate, Pharynx Muscle with Drainage Device, Open Approach */
"0K940ZZ" = "1" /* Drainage of Tongue, Palate, Pharynx Muscle, Open Approach */
"0K9430Z" = "1" /* Drainage of Tongue, Palate, Pharynx Muscle with Drainage Device, Percutaneous Approach */
"0K9440Z" = "1" /* Drainage of Tongue, Palate, Pharynx Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K944ZZ" = "1" /* Drainage of Tongue, Palate, Pharynx Muscle, Percutaneous Endoscopic Approach */
"0K9500Z" = "1" /* Drainage of Right Shoulder Muscle with Drainage Device, Open Approach */
"0K950ZZ" = "1" /* Drainage of Right Shoulder Muscle, Open Approach */
"0K9530Z" = "1" /* Drainage of Right Shoulder Muscle with Drainage Device, Percutaneous Approach */
"0K9540Z" = "1" /* Drainage of Right Shoulder Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K954ZZ" = "1" /* Drainage of Right Shoulder Muscle, Percutaneous Endoscopic Approach */
"0K9600Z" = "1" /* Drainage of Left Shoulder Muscle with Drainage Device, Open Approach */
"0K960ZZ" = "1" /* Drainage of Left Shoulder Muscle, Open Approach */
"0K9630Z" = "1" /* Drainage of Left Shoulder Muscle with Drainage Device, Percutaneous Approach */
"0K9640Z" = "1" /* Drainage of Left Shoulder Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K964ZZ" = "1" /* Drainage of Left Shoulder Muscle, Percutaneous Endoscopic Approach */
"0K9700Z" = "1" /* Drainage of Right Upper Arm Muscle with Drainage Device, Open Approach */
"0K970ZZ" = "1" /* Drainage of Right Upper Arm Muscle, Open Approach */
"0K9730Z" = "1" /* Drainage of Right Upper Arm Muscle with Drainage Device, Percutaneous Approach */
"0K9740Z" = "1" /* Drainage of Right Upper Arm Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K974ZZ" = "1" /* Drainage of Right Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0K9800Z" = "1" /* Drainage of Left Upper Arm Muscle with Drainage Device, Open Approach */
"0K980ZZ" = "1" /* Drainage of Left Upper Arm Muscle, Open Approach */
"0K9830Z" = "1" /* Drainage of Left Upper Arm Muscle with Drainage Device, Percutaneous Approach */
"0K9840Z" = "1" /* Drainage of Left Upper Arm Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K984ZZ" = "1" /* Drainage of Left Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0K9900Z" = "1" /* Drainage of Right Lower Arm and Wrist Muscle with Drainage Device, Open Approach */
"0K990ZZ" = "1" /* Drainage of Right Lower Arm and Wrist Muscle, Open Approach */
"0K9930Z" = "1" /* Drainage of Right Lower Arm and Wrist Muscle with Drainage Device, Percutaneous Approach */
"0K9940Z" = "1" /* Drainage of Right Lower Arm and Wrist Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K994ZZ" = "1" /* Drainage of Right Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0K9B00Z" = "1" /* Drainage of Left Lower Arm and Wrist Muscle with Drainage Device, Open Approach */
"0K9B0ZZ" = "1" /* Drainage of Left Lower Arm and Wrist Muscle, Open Approach */
"0K9B30Z" = "1" /* Drainage of Left Lower Arm and Wrist Muscle with Drainage Device, Percutaneous Approach */
"0K9B40Z" = "1" /* Drainage of Left Lower Arm and Wrist Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9B4ZZ" = "1" /* Drainage of Left Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0K9C00Z" = "1" /* Drainage of Right Hand Muscle with Drainage Device, Open Approach */
"0K9C0ZZ" = "1" /* Drainage of Right Hand Muscle, Open Approach */
"0K9C30Z" = "1" /* Drainage of Right Hand Muscle with Drainage Device, Percutaneous Approach */
"0K9C40Z" = "1" /* Drainage of Right Hand Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9D00Z" = "1" /* Drainage of Left Hand Muscle with Drainage Device, Open Approach */
"0K9D0ZZ" = "1" /* Drainage of Left Hand Muscle, Open Approach */
"0K9D30Z" = "1" /* Drainage of Left Hand Muscle with Drainage Device, Percutaneous Approach */
"0K9D40Z" = "1" /* Drainage of Left Hand Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9F00Z" = "1" /* Drainage of Right Trunk Muscle with Drainage Device, Open Approach */
"0K9F0ZZ" = "1" /* Drainage of Right Trunk Muscle, Open Approach */
"0K9F30Z" = "1" /* Drainage of Right Trunk Muscle with Drainage Device, Percutaneous Approach */
"0K9F40Z" = "1" /* Drainage of Right Trunk Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9F4ZZ" = "1" /* Drainage of Right Trunk Muscle, Percutaneous Endoscopic Approach */
"0K9G00Z" = "1" /* Drainage of Left Trunk Muscle with Drainage Device, Open Approach */
"0K9G0ZZ" = "1" /* Drainage of Left Trunk Muscle, Open Approach */
"0K9G30Z" = "1" /* Drainage of Left Trunk Muscle with Drainage Device, Percutaneous Approach */
"0K9G40Z" = "1" /* Drainage of Left Trunk Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9G4ZZ" = "1" /* Drainage of Left Trunk Muscle, Percutaneous Endoscopic Approach */
"0K9H00Z" = "1" /* Drainage of Right Thorax Muscle with Drainage Device, Open Approach */
"0K9H0ZZ" = "1" /* Drainage of Right Thorax Muscle, Open Approach */
"0K9H30Z" = "1" /* Drainage of Right Thorax Muscle with Drainage Device, Percutaneous Approach */
"0K9H40Z" = "1" /* Drainage of Right Thorax Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9H4ZZ" = "1" /* Drainage of Right Thorax Muscle, Percutaneous Endoscopic Approach */
"0K9J00Z" = "1" /* Drainage of Left Thorax Muscle with Drainage Device, Open Approach */
"0K9J0ZZ" = "1" /* Drainage of Left Thorax Muscle, Open Approach */
"0K9J30Z" = "1" /* Drainage of Left Thorax Muscle with Drainage Device, Percutaneous Approach */
"0K9J40Z" = "1" /* Drainage of Left Thorax Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9J4ZZ" = "1" /* Drainage of Left Thorax Muscle, Percutaneous Endoscopic Approach */
"0K9K00Z" = "1" /* Drainage of Right Abdomen Muscle with Drainage Device, Open Approach */
"0K9K0ZZ" = "1" /* Drainage of Right Abdomen Muscle, Open Approach */
"0K9K30Z" = "1" /* Drainage of Right Abdomen Muscle with Drainage Device, Percutaneous Approach */
"0K9K40Z" = "1" /* Drainage of Right Abdomen Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9K4ZZ" = "1" /* Drainage of Right Abdomen Muscle, Percutaneous Endoscopic Approach */
"0K9L00Z" = "1" /* Drainage of Left Abdomen Muscle with Drainage Device, Open Approach */
"0K9L0ZZ" = "1" /* Drainage of Left Abdomen Muscle, Open Approach */
"0K9L30Z" = "1" /* Drainage of Left Abdomen Muscle with Drainage Device, Percutaneous Approach */
"0K9L40Z" = "1" /* Drainage of Left Abdomen Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9L4ZZ" = "1" /* Drainage of Left Abdomen Muscle, Percutaneous Endoscopic Approach */
"0K9M00Z" = "1" /* Drainage of Perineum Muscle with Drainage Device, Open Approach */
"0K9M0ZZ" = "1" /* Drainage of Perineum Muscle, Open Approach */
"0K9M30Z" = "1" /* Drainage of Perineum Muscle with Drainage Device, Percutaneous Approach */
"0K9M40Z" = "1" /* Drainage of Perineum Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9M4ZZ" = "1" /* Drainage of Perineum Muscle, Percutaneous Endoscopic Approach */
"0K9N00Z" = "1" /* Drainage of Right Hip Muscle with Drainage Device, Open Approach */
"0K9N0ZZ" = "1" /* Drainage of Right Hip Muscle, Open Approach */
"0K9N30Z" = "1" /* Drainage of Right Hip Muscle with Drainage Device, Percutaneous Approach */
"0K9N40Z" = "1" /* Drainage of Right Hip Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9N4ZZ" = "1" /* Drainage of Right Hip Muscle, Percutaneous Endoscopic Approach */
"0K9P00Z" = "1" /* Drainage of Left Hip Muscle with Drainage Device, Open Approach */
"0K9P0ZZ" = "1" /* Drainage of Left Hip Muscle, Open Approach */
"0K9P30Z" = "1" /* Drainage of Left Hip Muscle with Drainage Device, Percutaneous Approach */
"0K9P40Z" = "1" /* Drainage of Left Hip Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9P4ZZ" = "1" /* Drainage of Left Hip Muscle, Percutaneous Endoscopic Approach */
"0K9Q00Z" = "1" /* Drainage of Right Upper Leg Muscle with Drainage Device, Open Approach */
"0K9Q0ZZ" = "1" /* Drainage of Right Upper Leg Muscle, Open Approach */
"0K9Q30Z" = "1" /* Drainage of Right Upper Leg Muscle with Drainage Device, Percutaneous Approach */
"0K9Q40Z" = "1" /* Drainage of Right Upper Leg Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9Q4ZZ" = "1" /* Drainage of Right Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0K9R00Z" = "1" /* Drainage of Left Upper Leg Muscle with Drainage Device, Open Approach */
"0K9R0ZZ" = "1" /* Drainage of Left Upper Leg Muscle, Open Approach */
"0K9R30Z" = "1" /* Drainage of Left Upper Leg Muscle with Drainage Device, Percutaneous Approach */
"0K9R40Z" = "1" /* Drainage of Left Upper Leg Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9R4ZZ" = "1" /* Drainage of Left Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0K9S00Z" = "1" /* Drainage of Right Lower Leg Muscle with Drainage Device, Open Approach */
"0K9S0ZZ" = "1" /* Drainage of Right Lower Leg Muscle, Open Approach */
"0K9S30Z" = "1" /* Drainage of Right Lower Leg Muscle with Drainage Device, Percutaneous Approach */
"0K9S40Z" = "1" /* Drainage of Right Lower Leg Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9S4ZZ" = "1" /* Drainage of Right Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0K9T00Z" = "1" /* Drainage of Left Lower Leg Muscle with Drainage Device, Open Approach */
"0K9T0ZZ" = "1" /* Drainage of Left Lower Leg Muscle, Open Approach */
"0K9T30Z" = "1" /* Drainage of Left Lower Leg Muscle with Drainage Device, Percutaneous Approach */
"0K9T40Z" = "1" /* Drainage of Left Lower Leg Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9T4ZZ" = "1" /* Drainage of Left Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0K9V00Z" = "1" /* Drainage of Right Foot Muscle with Drainage Device, Open Approach */
"0K9V0ZZ" = "1" /* Drainage of Right Foot Muscle, Open Approach */
"0K9V30Z" = "1" /* Drainage of Right Foot Muscle with Drainage Device, Percutaneous Approach */
"0K9V40Z" = "1" /* Drainage of Right Foot Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9V4ZZ" = "1" /* Drainage of Right Foot Muscle, Percutaneous Endoscopic Approach */
"0K9W00Z" = "1" /* Drainage of Left Foot Muscle with Drainage Device, Open Approach */
"0K9W0ZZ" = "1" /* Drainage of Left Foot Muscle, Open Approach */
"0K9W30Z" = "1" /* Drainage of Left Foot Muscle with Drainage Device, Percutaneous Approach */
"0K9W40Z" = "1" /* Drainage of Left Foot Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9W4ZZ" = "1" /* Drainage of Left Foot Muscle, Percutaneous Endoscopic Approach */
"0KC00ZZ" = "1" /* Extirpation of Matter from Head Muscle, Open Approach */
"0KC03ZZ" = "1" /* Extirpation of Matter from Head Muscle, Percutaneous Approach */
"0KC04ZZ" = "1" /* Extirpation of Matter from Head Muscle, Percutaneous Endoscopic Approach */
"0KC10ZZ" = "1" /* Extirpation of Matter from Facial Muscle, Open Approach */
"0KC13ZZ" = "1" /* Extirpation of Matter from Facial Muscle, Percutaneous Approach */
"0KC14ZZ" = "1" /* Extirpation of Matter from Facial Muscle, Percutaneous Endoscopic Approach */
"0KC20ZZ" = "1" /* Extirpation of Matter from Right Neck Muscle, Open Approach */
"0KC23ZZ" = "1" /* Extirpation of Matter from Right Neck Muscle, Percutaneous Approach */
"0KC24ZZ" = "1" /* Extirpation of Matter from Right Neck Muscle, Percutaneous Endoscopic Approach */
"0KC30ZZ" = "1" /* Extirpation of Matter from Left Neck Muscle, Open Approach */
"0KC33ZZ" = "1" /* Extirpation of Matter from Left Neck Muscle, Percutaneous Approach */
"0KC34ZZ" = "1" /* Extirpation of Matter from Left Neck Muscle, Percutaneous Endoscopic Approach */
"0KC40ZZ" = "1" /* Extirpation of Matter from Tongue, Palate, Pharynx Muscle, Open Approach */
"0KC43ZZ" = "1" /* Extirpation of Matter from Tongue, Palate, Pharynx Muscle, Percutaneous Approach */
"0KC44ZZ" = "1" /* Extirpation of Matter from Tongue, Palate, Pharynx Muscle, Percutaneous Endoscopic Approach */
"0KC50ZZ" = "1" /* Extirpation of Matter from Right Shoulder Muscle, Open Approach */
"0KC53ZZ" = "1" /* Extirpation of Matter from Right Shoulder Muscle, Percutaneous Approach */
"0KC54ZZ" = "1" /* Extirpation of Matter from Right Shoulder Muscle, Percutaneous Endoscopic Approach */
"0KC60ZZ" = "1" /* Extirpation of Matter from Left Shoulder Muscle, Open Approach */
"0KC63ZZ" = "1" /* Extirpation of Matter from Left Shoulder Muscle, Percutaneous Approach */
"0KC64ZZ" = "1" /* Extirpation of Matter from Left Shoulder Muscle, Percutaneous Endoscopic Approach */
"0KC70ZZ" = "1" /* Extirpation of Matter from Right Upper Arm Muscle, Open Approach */
"0KC73ZZ" = "1" /* Extirpation of Matter from Right Upper Arm Muscle, Percutaneous Approach */
"0KC74ZZ" = "1" /* Extirpation of Matter from Right Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0KC80ZZ" = "1" /* Extirpation of Matter from Left Upper Arm Muscle, Open Approach */
"0KC83ZZ" = "1" /* Extirpation of Matter from Left Upper Arm Muscle, Percutaneous Approach */
"0KC84ZZ" = "1" /* Extirpation of Matter from Left Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0KC90ZZ" = "1" /* Extirpation of Matter from Right Lower Arm and Wrist Muscle, Open Approach */
"0KC93ZZ" = "1" /* Extirpation of Matter from Right Lower Arm and Wrist Muscle, Percutaneous Approach */
"0KC94ZZ" = "1" /* Extirpation of Matter from Right Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0KCB0ZZ" = "1" /* Extirpation of Matter from Left Lower Arm and Wrist Muscle, Open Approach */
"0KCB3ZZ" = "1" /* Extirpation of Matter from Left Lower Arm and Wrist Muscle, Percutaneous Approach */
"0KCB4ZZ" = "1" /* Extirpation of Matter from Left Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0KCC0ZZ" = "1" /* Extirpation of Matter from Right Hand Muscle, Open Approach */
"0KCC3ZZ" = "1" /* Extirpation of Matter from Right Hand Muscle, Percutaneous Approach */
"0KCC4ZZ" = "1" /* Extirpation of Matter from Right Hand Muscle, Percutaneous Endoscopic Approach */
"0KCD0ZZ" = "1" /* Extirpation of Matter from Left Hand Muscle, Open Approach */
"0KCD3ZZ" = "1" /* Extirpation of Matter from Left Hand Muscle, Percutaneous Approach */
"0KCD4ZZ" = "1" /* Extirpation of Matter from Left Hand Muscle, Percutaneous Endoscopic Approach */
"0KCF0ZZ" = "1" /* Extirpation of Matter from Right Trunk Muscle, Open Approach */
"0KCF3ZZ" = "1" /* Extirpation of Matter from Right Trunk Muscle, Percutaneous Approach */
"0KCF4ZZ" = "1" /* Extirpation of Matter from Right Trunk Muscle, Percutaneous Endoscopic Approach */
"0KCG0ZZ" = "1" /* Extirpation of Matter from Left Trunk Muscle, Open Approach */
"0KCG3ZZ" = "1" /* Extirpation of Matter from Left Trunk Muscle, Percutaneous Approach */
"0KCG4ZZ" = "1" /* Extirpation of Matter from Left Trunk Muscle, Percutaneous Endoscopic Approach */
"0KCH0ZZ" = "1" /* Extirpation of Matter from Right Thorax Muscle, Open Approach */
"0KCH3ZZ" = "1" /* Extirpation of Matter from Right Thorax Muscle, Percutaneous Approach */
"0KCH4ZZ" = "1" /* Extirpation of Matter from Right Thorax Muscle, Percutaneous Endoscopic Approach */
"0KCJ0ZZ" = "1" /* Extirpation of Matter from Left Thorax Muscle, Open Approach */
"0KCJ3ZZ" = "1" /* Extirpation of Matter from Left Thorax Muscle, Percutaneous Approach */
"0KCJ4ZZ" = "1" /* Extirpation of Matter from Left Thorax Muscle, Percutaneous Endoscopic Approach */
"0KCK0ZZ" = "1" /* Extirpation of Matter from Right Abdomen Muscle, Open Approach */
"0KCK3ZZ" = "1" /* Extirpation of Matter from Right Abdomen Muscle, Percutaneous Approach */
"0KCK4ZZ" = "1" /* Extirpation of Matter from Right Abdomen Muscle, Percutaneous Endoscopic Approach */
"0KCL0ZZ" = "1" /* Extirpation of Matter from Left Abdomen Muscle, Open Approach */
"0KCL3ZZ" = "1" /* Extirpation of Matter from Left Abdomen Muscle, Percutaneous Approach */
"0KCL4ZZ" = "1" /* Extirpation of Matter from Left Abdomen Muscle, Percutaneous Endoscopic Approach */
"0KCM0ZZ" = "1" /* Extirpation of Matter from Perineum Muscle, Open Approach */
"0KCM3ZZ" = "1" /* Extirpation of Matter from Perineum Muscle, Percutaneous Approach */
"0KCM4ZZ" = "1" /* Extirpation of Matter from Perineum Muscle, Percutaneous Endoscopic Approach */
"0KCN0ZZ" = "1" /* Extirpation of Matter from Right Hip Muscle, Open Approach */
"0KCN3ZZ" = "1" /* Extirpation of Matter from Right Hip Muscle, Percutaneous Approach */
"0KCN4ZZ" = "1" /* Extirpation of Matter from Right Hip Muscle, Percutaneous Endoscopic Approach */
"0KCP0ZZ" = "1" /* Extirpation of Matter from Left Hip Muscle, Open Approach */
"0KCP3ZZ" = "1" /* Extirpation of Matter from Left Hip Muscle, Percutaneous Approach */
"0KCP4ZZ" = "1" /* Extirpation of Matter from Left Hip Muscle, Percutaneous Endoscopic Approach */
"0KCQ0ZZ" = "1" /* Extirpation of Matter from Right Upper Leg Muscle, Open Approach */
"0KCQ3ZZ" = "1" /* Extirpation of Matter from Right Upper Leg Muscle, Percutaneous Approach */
"0KCQ4ZZ" = "1" /* Extirpation of Matter from Right Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0KCR0ZZ" = "1" /* Extirpation of Matter from Left Upper Leg Muscle, Open Approach */
"0KCR3ZZ" = "1" /* Extirpation of Matter from Left Upper Leg Muscle, Percutaneous Approach */
"0KCR4ZZ" = "1" /* Extirpation of Matter from Left Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0KCS0ZZ" = "1" /* Extirpation of Matter from Right Lower Leg Muscle, Open Approach */
"0KCS3ZZ" = "1" /* Extirpation of Matter from Right Lower Leg Muscle, Percutaneous Approach */
"0KCS4ZZ" = "1" /* Extirpation of Matter from Right Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0KCT0ZZ" = "1" /* Extirpation of Matter from Left Lower Leg Muscle, Open Approach */
"0KCT3ZZ" = "1" /* Extirpation of Matter from Left Lower Leg Muscle, Percutaneous Approach */
"0KCT4ZZ" = "1" /* Extirpation of Matter from Left Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0KCV0ZZ" = "1" /* Extirpation of Matter from Right Foot Muscle, Open Approach */
"0KCV3ZZ" = "1" /* Extirpation of Matter from Right Foot Muscle, Percutaneous Approach */
"0KCV4ZZ" = "1" /* Extirpation of Matter from Right Foot Muscle, Percutaneous Endoscopic Approach */
"0KCW0ZZ" = "1" /* Extirpation of Matter from Left Foot Muscle, Open Approach */
"0KCW3ZZ" = "1" /* Extirpation of Matter from Left Foot Muscle, Percutaneous Approach */
"0KCW4ZZ" = "1" /* Extirpation of Matter from Left Foot Muscle, Percutaneous Endoscopic Approach */
"0KWX00Z" = "1" /* Revision of Drainage Device in Upper Muscle, Open Approach */
"0KWX30Z" = "1" /* Revision of Drainage Device in Upper Muscle, Percutaneous Approach */
"0KWX40Z" = "1" /* Revision of Drainage Device in Upper Muscle, Percutaneous Endoscopic Approach */
"0KWY00Z" = "1" /* Revision of Drainage Device in Lower Muscle, Open Approach */
"0KWY30Z" = "1" /* Revision of Drainage Device in Lower Muscle, Percutaneous Approach */
"0KWY40Z" = "1" /* Revision of Drainage Device in Lower Muscle, Percutaneous Endoscopic Approach */
"0N9P00Z" = "1" /* Drainage of Right Orbit with Drainage Device, Open Approach */
"0N9P0ZZ" = "1" /* Drainage of Right Orbit, Open Approach */
"0N9P30Z" = "1" /* Drainage of Right Orbit with Drainage Device, Percutaneous Approach */
"0N9P40Z" = "1" /* Drainage of Right Orbit with Drainage Device, Percutaneous Endoscopic Approach */
"0N9P4ZZ" = "1" /* Drainage of Right Orbit, Percutaneous Endoscopic Approach */
"0N9Q00Z" = "1" /* Drainage of Left Orbit with Drainage Device, Open Approach */
"0N9Q0ZZ" = "1" /* Drainage of Left Orbit, Open Approach */
"0N9Q30Z" = "1" /* Drainage of Left Orbit with Drainage Device, Percutaneous Approach */
"0N9Q40Z" = "1" /* Drainage of Left Orbit with Drainage Device, Percutaneous Endoscopic Approach */
"0N9Q4ZZ" = "1" /* Drainage of Left Orbit, Percutaneous Endoscopic Approach */
"0R9000Z" = "1" /* Drainage of Occipital-cervical Joint with Drainage Device, Open Approach */
"0R900ZZ" = "1" /* Drainage of Occipital-cervical Joint, Open Approach */
"0R9100Z" = "1" /* Drainage of Cervical Vertebral Joint with Drainage Device, Open Approach */
"0R910ZZ" = "1" /* Drainage of Cervical Vertebral Joint, Open Approach */
"0R9400Z" = "1" /* Drainage of Cervicothoracic Vertebral Joint with Drainage Device, Open Approach */
"0R940ZZ" = "1" /* Drainage of Cervicothoracic Vertebral Joint, Open Approach */
"0R9600Z" = "1" /* Drainage of Thoracic Vertebral Joint with Drainage Device, Open Approach */
"0R960ZZ" = "1" /* Drainage of Thoracic Vertebral Joint, Open Approach */
"0R9A00Z" = "1" /* Drainage of Thoracolumbar Vertebral Joint with Drainage Device, Open Approach */
"0R9A0ZZ" = "1" /* Drainage of Thoracolumbar Vertebral Joint, Open Approach */
"0R9C00Z" = "1" /* Drainage of Right Temporomandibular Joint with Drainage Device, Open Approach */
"0R9C0ZZ" = "1" /* Drainage of Right Temporomandibular Joint, Open Approach */
"0R9D00Z" = "1" /* Drainage of Left Temporomandibular Joint with Drainage Device, Open Approach */
"0R9D0ZZ" = "1" /* Drainage of Left Temporomandibular Joint, Open Approach */
"0R9J00Z" = "1" /* Drainage of Right Shoulder Joint with Drainage Device, Open Approach */
"0R9J0ZZ" = "1" /* Drainage of Right Shoulder Joint, Open Approach */
"0R9K00Z" = "1" /* Drainage of Left Shoulder Joint with Drainage Device, Open Approach */
"0R9K0ZZ" = "1" /* Drainage of Left Shoulder Joint, Open Approach */
"0R9L00Z" = "1" /* Drainage of Right Elbow Joint with Drainage Device, Open Approach */
"0R9L0ZZ" = "1" /* Drainage of Right Elbow Joint, Open Approach */
"0R9M00Z" = "1" /* Drainage of Left Elbow Joint with Drainage Device, Open Approach */
"0R9M0ZZ" = "1" /* Drainage of Left Elbow Joint, Open Approach */
"0R9N00Z" = "1" /* Drainage of Right Wrist Joint with Drainage Device, Open Approach */
"0R9N0ZZ" = "1" /* Drainage of Right Wrist Joint, Open Approach */
"0R9P00Z" = "1" /* Drainage of Left Wrist Joint with Drainage Device, Open Approach */
"0R9P0ZZ" = "1" /* Drainage of Left Wrist Joint, Open Approach */
"0R9Q00Z" = "1" /* Drainage of Right Carpal Joint with Drainage Device, Open Approach */
"0R9Q0ZZ" = "1" /* Drainage of Right Carpal Joint, Open Approach */
"0R9R00Z" = "1" /* Drainage of Left Carpal Joint with Drainage Device, Open Approach */
"0R9R0ZZ" = "1" /* Drainage of Left Carpal Joint, Open Approach */
"0R9S00Z" = "1" /* Drainage of Right Metacarpocarpal Joint with Drainage Device, Open Approach */
"0R9S0ZZ" = "1" /* Drainage of Right Metacarpocarpal Joint, Open Approach */
"0R9T00Z" = "1" /* Drainage of Left Metacarpocarpal Joint with Drainage Device, Open Approach */
"0R9T0ZZ" = "1" /* Drainage of Left Metacarpocarpal Joint, Open Approach */
"0R9U00Z" = "1" /* Drainage of Right Metacarpophalangeal Joint with Drainage Device, Open Approach */
"0R9U0ZZ" = "1" /* Drainage of Right Metacarpophalangeal Joint, Open Approach */
"0R9V00Z" = "1" /* Drainage of Left Metacarpophalangeal Joint with Drainage Device, Open Approach */
"0R9V0ZZ" = "1" /* Drainage of Left Metacarpophalangeal Joint, Open Approach */
"0R9W00Z" = "1" /* Drainage of Right Finger Phalangeal Joint with Drainage Device, Open Approach */
"0R9W0ZZ" = "1" /* Drainage of Right Finger Phalangeal Joint, Open Approach */
"0R9X00Z" = "1" /* Drainage of Left Finger Phalangeal Joint with Drainage Device, Open Approach */
"0R9X0ZZ" = "1" /* Drainage of Left Finger Phalangeal Joint, Open Approach */
"0S9000Z" = "1" /* Drainage of Lumbar Vertebral Joint with Drainage Device, Open Approach */
"0S900ZZ" = "1" /* Drainage of Lumbar Vertebral Joint, Open Approach */
"0S9300Z" = "1" /* Drainage of Lumbosacral Joint with Drainage Device, Open Approach */
"0S930ZZ" = "1" /* Drainage of Lumbosacral Joint, Open Approach */
"0S9500Z" = "1" /* Drainage of Sacrococcygeal Joint with Drainage Device, Open Approach */
"0S950ZZ" = "1" /* Drainage of Sacrococcygeal Joint, Open Approach */
"0S9600Z" = "1" /* Drainage of Coccygeal Joint with Drainage Device, Open Approach */
"0S960ZZ" = "1" /* Drainage of Coccygeal Joint, Open Approach */
"0S9700Z" = "1" /* Drainage of Right Sacroiliac Joint with Drainage Device, Open Approach */
"0S970ZZ" = "1" /* Drainage of Right Sacroiliac Joint, Open Approach */
"0S9800Z" = "1" /* Drainage of Left Sacroiliac Joint with Drainage Device, Open Approach */
"0S980ZZ" = "1" /* Drainage of Left Sacroiliac Joint, Open Approach */
"0S9900Z" = "1" /* Drainage of Right Hip Joint with Drainage Device, Open Approach */
"0S990ZZ" = "1" /* Drainage of Right Hip Joint, Open Approach */
"0S9B00Z" = "1" /* Drainage of Left Hip Joint with Drainage Device, Open Approach */
"0S9B0ZZ" = "1" /* Drainage of Left Hip Joint, Open Approach */
"0S9C00Z" = "1" /* Drainage of Right Knee Joint with Drainage Device, Open Approach */
"0S9C0ZZ" = "1" /* Drainage of Right Knee Joint, Open Approach */
"0S9D00Z" = "1" /* Drainage of Left Knee Joint with Drainage Device, Open Approach */
"0S9D0ZZ" = "1" /* Drainage of Left Knee Joint, Open Approach */
"0S9F00Z" = "1" /* Drainage of Right Ankle Joint with Drainage Device, Open Approach */
"0S9F0ZZ" = "1" /* Drainage of Right Ankle Joint, Open Approach */
"0S9G00Z" = "1" /* Drainage of Left Ankle Joint with Drainage Device, Open Approach */
"0S9G0ZZ" = "1" /* Drainage of Left Ankle Joint, Open Approach */
"0S9K00Z" = "1" /* Drainage of Right Metatarsal-Tarsal Joint with Drainage Device, Open Approach */
"0S9K0ZZ" = "1" /* Drainage of Right Metatarsal-Tarsal Joint, Open Approach */
"0S9L00Z" = "1" /* Drainage of Left Metatarsal-Tarsal Joint with Drainage Device, Open Approach */
"0S9L0ZZ" = "1" /* Drainage of Left Metatarsal-Tarsal Joint, Open Approach */
"0S9M00Z" = "1" /* Drainage of Right Metatarsal-Phalangeal Joint with Drainage Device, Open Approach */
"0S9M0ZZ" = "1" /* Drainage of Right Metatarsal-Phalangeal Joint, Open Approach */
"0S9N00Z" = "1" /* Drainage of Left Metatarsal-Phalangeal Joint with Drainage Device, Open Approach */
"0S9N0ZZ" = "1" /* Drainage of Left Metatarsal-Phalangeal Joint, Open Approach */
"0S9P00Z" = "1" /* Drainage of Right Toe Phalangeal Joint with Drainage Device, Open Approach */
"0S9P0ZZ" = "1" /* Drainage of Right Toe Phalangeal Joint, Open Approach */
"0S9Q00Z" = "1" /* Drainage of Left Toe Phalangeal Joint with Drainage Device, Open Approach */
"0S9Q0ZZ" = "1" /* Drainage of Left Toe Phalangeal Joint, Open Approach */
"0T9000Z" = "1" /* Drainage of Right Kidney with Drainage Device, Open Approach */
"0T900ZZ" = "1" /* Drainage of Right Kidney, Open Approach */
"0T9030Z" = "1" /* Drainage of Right Kidney with Drainage Device, Percutaneous Approach */
"0T903ZZ" = "1" /* Drainage of Right Kidney, Percutaneous Approach */
"0T9040Z" = "1" /* Drainage of Right Kidney with Drainage Device, Percutaneous Endoscopic Approach */
"0T904ZZ" = "1" /* Drainage of Right Kidney, Percutaneous Endoscopic Approach */
"0T9100Z" = "1" /* Drainage of Left Kidney with Drainage Device, Open Approach */
"0T910ZZ" = "1" /* Drainage of Left Kidney, Open Approach */
"0T9130Z" = "1" /* Drainage of Left Kidney with Drainage Device, Percutaneous Approach */
"0T913ZZ" = "1" /* Drainage of Left Kidney, Percutaneous Approach */
"0T9140Z" = "1" /* Drainage of Left Kidney with Drainage Device, Percutaneous Endoscopic Approach */
"0T914ZZ" = "1" /* Drainage of Left Kidney, Percutaneous Endoscopic Approach */
"0T9300Z" = "1" /* Drainage of Right Kidney Pelvis with Drainage Device, Open Approach */
"0T9330Z" = "1" /* Drainage of Right Kidney Pelvis with Drainage Device, Percutaneous Approach */
"0T9340Z" = "1" /* Drainage of Right Kidney Pelvis with Drainage Device, Percutaneous Endoscopic Approach */
"0T9400Z" = "1" /* Drainage of Left Kidney Pelvis with Drainage Device, Open Approach */
"0T9430Z" = "1" /* Drainage of Left Kidney Pelvis with Drainage Device, Percutaneous Approach */
"0T9440Z" = "1" /* Drainage of Left Kidney Pelvis with Drainage Device, Percutaneous Endoscopic Approach */
"0T9B00Z" = "1" /* Drainage of Bladder with Drainage Device, Open Approach */
"0T9C00Z" = "1" /* Drainage of Bladder Neck with Drainage Device, Open Approach */
"0TC00ZZ" = "1" /* Extirpation of Matter from Right Kidney, Open Approach */
"0TC07ZZ" = "1" /* Extirpation of Matter from Right Kidney, Via Natural or Artificial Opening */
"0TC08ZZ" = "1" /* Extirpation of Matter from Right Kidney, Via Natural or Artificial Opening Endoscopic */
"0TC10ZZ" = "1" /* Extirpation of Matter from Left Kidney, Open Approach */
"0TC17ZZ" = "1" /* Extirpation of Matter from Left Kidney, Via Natural or Artificial Opening */
"0TC18ZZ" = "1" /* Extirpation of Matter from Left Kidney, Via Natural or Artificial Opening Endoscopic */
"0TC30ZZ" = "1" /* Extirpation of Matter from Right Kidney Pelvis, Open Approach */
"0TC40ZZ" = "1" /* Extirpation of Matter from Left Kidney Pelvis, Open Approach */
"0TCB0ZZ" = "1" /* Extirpation of Matter from Bladder, Open Approach */
"0TCB3ZZ" = "1" /* Extirpation of Matter from Bladder, Percutaneous Approach */
"0TCB4ZZ" = "1" /* Extirpation of Matter from Bladder, Percutaneous Endoscopic Approach */
"0TCC0ZZ" = "1" /* Extirpation of Matter from Bladder Neck, Open Approach */
"0TCC3ZZ" = "1" /* Extirpation of Matter from Bladder Neck, Percutaneous Approach */
"0TCC4ZZ" = "1" /* Extirpation of Matter from Bladder Neck, Percutaneous Endoscopic Approach */
"0TW500Z" = "1" /* Revision of Drainage Device in Kidney, Open Approach */
"0TW530Z" = "1" /* Revision of Drainage Device in Kidney, Percutaneous Approach */
"0TW540Z" = "1" /* Revision of Drainage Device in Kidney, Percutaneous Endoscopic Approach */
"0TW570Z" = "1" /* Revision of Drainage Device in Kidney, Via Natural or Artificial Opening */
"0TW580Z" = "1" /* Revision of Drainage Device in Kidney, Via Natural or Artificial Opening Endoscopic */
"0TWB00Z" = "1" /* Revision of Drainage Device in Bladder, Open Approach */
"0TWB03Z" = "1" /* Revision of Infusion Device in Bladder, Open Approach */
"0TWB30Z" = "1" /* Revision of Drainage Device in Bladder, Percutaneous Approach */
"0TWB33Z" = "1" /* Revision of Infusion Device in Bladder, Percutaneous Approach */
"0TWB40Z" = "1" /* Revision of Drainage Device in Bladder, Percutaneous Endoscopic Approach */
"0TWB43Z" = "1" /* Revision of Infusion Device in Bladder, Percutaneous Endoscopic Approach */
"0TWB70Z" = "1" /* Revision of Drainage Device in Bladder, Via Natural or Artificial Opening */
"0TWB73Z" = "1" /* Revision of Infusion Device in Bladder, Via Natural or Artificial Opening */
"0TWB80Z" = "1" /* Revision of Drainage Device in Bladder, Via Natural or Artificial Opening Endoscopic */
"0TWB83Z" = "1" /* Revision of Infusion Device in Bladder, Via Natural or Artificial Opening Endoscopic */
"0U9000Z" = "1" /* Drainage of Right Ovary with Drainage Device, Open Approach */
"0U900ZZ" = "1" /* Drainage of Right Ovary, Open Approach */
"0U9040Z" = "1" /* Drainage of Right Ovary with Drainage Device, Percutaneous Endoscopic Approach */
"0U904ZZ" = "1" /* Drainage of Right Ovary, Percutaneous Endoscopic Approach */
"0U9100Z" = "1" /* Drainage of Left Ovary with Drainage Device, Open Approach */
"0U910ZZ" = "1" /* Drainage of Left Ovary, Open Approach */
"0U9140Z" = "1" /* Drainage of Left Ovary with Drainage Device, Percutaneous Endoscopic Approach */
"0U914ZZ" = "1" /* Drainage of Left Ovary, Percutaneous Endoscopic Approach */
"0U9200Z" = "1" /* Drainage of Bilateral Ovaries with Drainage Device, Open Approach */
"0U920ZZ" = "1" /* Drainage of Bilateral Ovaries, Open Approach */
"0U9240Z" = "1" /* Drainage of Bilateral Ovaries with Drainage Device, Percutaneous Endoscopic Approach */
"0U924ZZ" = "1" /* Drainage of Bilateral Ovaries, Percutaneous Endoscopic Approach */
"0U950ZZ" = "1" /* Drainage of Right Fallopian Tube, Open Approach */
"0U960ZZ" = "1" /* Drainage of Left Fallopian Tube, Open Approach */
"0U970ZZ" = "1" /* Drainage of Bilateral Fallopian Tubes, Open Approach */
"0U9900Z" = "1" /* Drainage of Uterus with Drainage Device, Open Approach */
"0U990ZZ" = "1" /* Drainage of Uterus, Open Approach */
"0U9930Z" = "1" /* Drainage of Uterus with Drainage Device, Percutaneous Approach */
"0U993ZZ" = "1" /* Drainage of Uterus, Percutaneous Approach */
"0U9940Z" = "1" /* Drainage of Uterus with Drainage Device, Percutaneous Endoscopic Approach */
"0U994ZZ" = "1" /* Drainage of Uterus, Percutaneous Endoscopic Approach */
"0U9970Z" = "1" /* Drainage of Uterus with Drainage Device, Via Natural or Artificial Opening */
"0U997ZZ" = "1" /* Drainage of Uterus, Via Natural or Artificial Opening */
"0U9980Z" = "1" /* Drainage of Uterus with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0U998ZZ" = "1" /* Drainage of Uterus, Via Natural or Artificial Opening Endoscopic */
"0U9C00Z" = "1" /* Drainage of Cervix with Drainage Device, Open Approach */
"0U9C0ZZ" = "1" /* Drainage of Cervix, Open Approach */
"0U9C30Z" = "1" /* Drainage of Cervix with Drainage Device, Percutaneous Approach */
"0U9C3ZZ" = "1" /* Drainage of Cervix, Percutaneous Approach */
"0U9C40Z" = "1" /* Drainage of Cervix with Drainage Device, Percutaneous Endoscopic Approach */
"0U9C4ZZ" = "1" /* Drainage of Cervix, Percutaneous Endoscopic Approach */
"0U9C70Z" = "1" /* Drainage of Cervix with Drainage Device, Via Natural or Artificial Opening */
"0U9C7ZZ" = "1" /* Drainage of Cervix, Via Natural or Artificial Opening */
"0U9C80Z" = "1" /* Drainage of Cervix with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0U9C8ZZ" = "1" /* Drainage of Cervix, Via Natural or Artificial Opening Endoscopic */
"0U9F00Z" = "1" /* Drainage of Cul-de-sac with Drainage Device, Open Approach */
"0U9F0ZZ" = "1" /* Drainage of Cul-de-sac, Open Approach */
"0U9F30Z" = "1" /* Drainage of Cul-de-sac with Drainage Device, Percutaneous Approach */
"0U9F3ZZ" = "1" /* Drainage of Cul-de-sac, Percutaneous Approach */
"0U9F40Z" = "1" /* Drainage of Cul-de-sac with Drainage Device, Percutaneous Endoscopic Approach */
"0U9F4ZZ" = "1" /* Drainage of Cul-de-sac, Percutaneous Endoscopic Approach */
"0U9F70Z" = "1" /* Drainage of Cul-de-sac with Drainage Device, Via Natural or Artificial Opening */
"0U9F7ZZ" = "1" /* Drainage of Cul-de-sac, Via Natural or Artificial Opening */
"0U9F80Z" = "1" /* Drainage of Cul-de-sac with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0U9F8ZZ" = "1" /* Drainage of Cul-de-sac, Via Natural or Artificial Opening Endoscopic */
"0UC00ZZ" = "1" /* Extirpation of Matter from Right Ovary, Open Approach */
"0UC03ZZ" = "1" /* Extirpation of Matter from Right Ovary, Percutaneous Approach */
"0UC04ZZ" = "1" /* Extirpation of Matter from Right Ovary, Percutaneous Endoscopic Approach */
"0UC10ZZ" = "1" /* Extirpation of Matter from Left Ovary, Open Approach */
"0UC13ZZ" = "1" /* Extirpation of Matter from Left Ovary, Percutaneous Approach */
"0UC14ZZ" = "1" /* Extirpation of Matter from Left Ovary, Percutaneous Endoscopic Approach */
"0UC20ZZ" = "1" /* Extirpation of Matter from Bilateral Ovaries, Open Approach */
"0UC23ZZ" = "1" /* Extirpation of Matter from Bilateral Ovaries, Percutaneous Approach */
"0UC24ZZ" = "1" /* Extirpation of Matter from Bilateral Ovaries, Percutaneous Endoscopic Approach */
"0UC50ZZ" = "1" /* Extirpation of Matter from Right Fallopian Tube, Open Approach */
"0UC53ZZ" = "1" /* Extirpation of Matter from Right Fallopian Tube, Percutaneous Approach */
"0UC54ZZ" = "1" /* Extirpation of Matter from Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0UC57ZZ" = "1" /* Extirpation of Matter from Right Fallopian Tube, Via Natural or Artificial Opening */
"0UC58ZZ" = "1" /* Extirpation of Matter from Right Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UC60ZZ" = "1" /* Extirpation of Matter from Left Fallopian Tube, Open Approach */
"0UC63ZZ" = "1" /* Extirpation of Matter from Left Fallopian Tube, Percutaneous Approach */
"0UC64ZZ" = "1" /* Extirpation of Matter from Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0UC67ZZ" = "1" /* Extirpation of Matter from Left Fallopian Tube, Via Natural or Artificial Opening */
"0UC68ZZ" = "1" /* Extirpation of Matter from Left Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UC70ZZ" = "1" /* Extirpation of Matter from Bilateral Fallopian Tubes, Open Approach */
"0UC73ZZ" = "1" /* Extirpation of Matter from Bilateral Fallopian Tubes, Percutaneous Approach */
"0UC74ZZ" = "1" /* Extirpation of Matter from Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0UC77ZZ" = "1" /* Extirpation of Matter from Bilateral Fallopian Tubes, Via Natural or Artificial Opening */
"0UC78ZZ" = "1" /* Extirpation of Matter from Bilateral Fallopian Tubes, Via Natural or Artificial Opening Endoscopic */
"0UC90ZZ" = "1" /* Extirpation of Matter from Uterus, Open Approach */
"0UC93ZZ" = "1" /* Extirpation of Matter from Uterus, Percutaneous Approach */
"0UC94ZZ" = "1" /* Extirpation of Matter from Uterus, Percutaneous Endoscopic Approach */
"0UCF0ZZ" = "1" /* Extirpation of Matter from Cul-de-sac, Open Approach */
"0UCF3ZZ" = "1" /* Extirpation of Matter from Cul-de-sac, Percutaneous Approach */
"0UCF4ZZ" = "1" /* Extirpation of Matter from Cul-de-sac, Percutaneous Endoscopic Approach */
"0UCF7ZZ" = "1" /* Extirpation of Matter from Cul-de-sac, Via Natural or Artificial Opening */
"0UCF8ZZ" = "1" /* Extirpation of Matter from Cul-de-sac, Via Natural or Artificial Opening Endoscopic */
"0UW300Z" = "1" /* Revision of Drainage Device in Ovary, Open Approach */
"0UW330Z" = "1" /* Revision of Drainage Device in Ovary, Percutaneous Approach */
"0UW340Z" = "1" /* Revision of Drainage Device in Ovary, Percutaneous Endoscopic Approach */
"0UW800Z" = "1" /* Revision of Drainage Device in Fallopian Tube, Open Approach */
"0UW830Z" = "1" /* Revision of Drainage Device in Fallopian Tube, Percutaneous Approach */
"0UW840Z" = "1" /* Revision of Drainage Device in Fallopian Tube, Percutaneous Endoscopic Approach */
"0UW870Z" = "1" /* Revision of Drainage Device in Fallopian Tube, Via Natural or Artificial Opening */
"0UW880Z" = "1" /* Revision of Drainage Device in Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UWD00Z" = "1" /* Revision of Drainage Device in Uterus and Cervix, Open Approach */
"0UWD30Z" = "1" /* Revision of Drainage Device in Uterus and Cervix, Percutaneous Approach */
"0UWD40Z" = "1" /* Revision of Drainage Device in Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UWD70Z" = "1" /* Revision of Drainage Device in Uterus and Cervix, Via Natural or Artificial Opening */
"0UWD80Z" = "1" /* Revision of Drainage Device in Uterus and Cervix, Via Natural or Artificial Opening Endoscopic */
"0UWH00Z" = "1" /* Revision of Drainage Device in Vagina and Cul-de-sac, Open Approach */
"0UWH30Z" = "1" /* Revision of Drainage Device in Vagina and Cul-de-sac, Percutaneous Approach */
"0UWH40Z" = "1" /* Revision of Drainage Device in Vagina and Cul-de-sac, Percutaneous Endoscopic Approach */
"0UWH70Z" = "1" /* Revision of Drainage Device in Vagina and Cul-de-sac, Via Natural or Artificial Opening */
"0UWH80Z" = "1" /* Revision of Drainage Device in Vagina and Cul-de-sac, Via Natural or Artificial Opening Endoscopic */
"0V9S00Z" = "1" /* Drainage of Penis with Drainage Device, Open Approach */
"0V9S0ZZ" = "1" /* Drainage of Penis, Open Approach */
"0V9S30Z" = "1" /* Drainage of Penis with Drainage Device, Percutaneous Approach */
"0V9S3ZZ" = "1" /* Drainage of Penis, Percutaneous Approach */
"0V9S40Z" = "1" /* Drainage of Penis with Drainage Device, Percutaneous Endoscopic Approach */
"0V9S4ZZ" = "1" /* Drainage of Penis, Percutaneous Endoscopic Approach */
"0V9SX0Z" = "1" /* Drainage of Penis with Drainage Device, External Approach */
"0V9SXZZ" = "1" /* Drainage of Penis, External Approach */
"0V9T00Z" = "1" /* Drainage of Prepuce with Drainage Device, Open Approach */
"0V9T0ZZ" = "1" /* Drainage of Prepuce, Open Approach */
"0V9T30Z" = "1" /* Drainage of Prepuce with Drainage Device, Percutaneous Approach */
"0V9T3ZZ" = "1" /* Drainage of Prepuce, Percutaneous Approach */
"0V9T40Z" = "1" /* Drainage of Prepuce with Drainage Device, Percutaneous Endoscopic Approach */
"0V9T4ZZ" = "1" /* Drainage of Prepuce, Percutaneous Endoscopic Approach */
"0V9TX0Z" = "1" /* Drainage of Prepuce with Drainage Device, External Approach */
"0V9TXZZ" = "1" /* Drainage of Prepuce, External Approach */
"0VBF0ZZ" = "1" /* Excision of Right Spermatic Cord, Open Approach */
"0VBF3ZZ" = "1" /* Excision of Right Spermatic Cord, Percutaneous Approach */
"0VBF4ZZ" = "1" /* Excision of Right Spermatic Cord, Percutaneous Endoscopic Approach */
"0VBG0ZZ" = "1" /* Excision of Left Spermatic Cord, Open Approach */
"0VBG3ZZ" = "1" /* Excision of Left Spermatic Cord, Percutaneous Approach */
"0VBG4ZZ" = "1" /* Excision of Left Spermatic Cord, Percutaneous Endoscopic Approach */
"0VBH0ZZ" = "1" /* Excision of Bilateral Spermatic Cords, Open Approach */
"0VBH3ZZ" = "1" /* Excision of Bilateral Spermatic Cords, Percutaneous Approach */
"0VBH4ZZ" = "1" /* Excision of Bilateral Spermatic Cords, Percutaneous Endoscopic Approach */
"0VC00ZZ" = "1" /* Extirpation of Matter from Prostate, Open Approach */
"0VC03ZZ" = "1" /* Extirpation of Matter from Prostate, Percutaneous Approach */
"0VC04ZZ" = "1" /* Extirpation of Matter from Prostate, Percutaneous Endoscopic Approach */
"0VC07ZZ" = "1" /* Extirpation of Matter from Prostate, Via Natural or Artificial Opening */
"0VC08ZZ" = "1" /* Extirpation of Matter from Prostate, Via Natural or Artificial Opening Endoscopic */
"0VC90ZZ" = "1" /* Extirpation of Matter from Right Testis, Open Approach */
"0VC93ZZ" = "1" /* Extirpation of Matter from Right Testis, Percutaneous Approach */
"0VC94ZZ" = "1" /* Extirpation of Matter from Right Testis, Percutaneous Endoscopic Approach */
"0VCB0ZZ" = "1" /* Extirpation of Matter from Left Testis, Open Approach */
"0VCB3ZZ" = "1" /* Extirpation of Matter from Left Testis, Percutaneous Approach */
"0VCB4ZZ" = "1" /* Extirpation of Matter from Left Testis, Percutaneous Endoscopic Approach */
"0VCC0ZZ" = "1" /* Extirpation of Matter from Bilateral Testes, Open Approach */
"0VCC3ZZ" = "1" /* Extirpation of Matter from Bilateral Testes, Percutaneous Approach */
"0VCC4ZZ" = "1" /* Extirpation of Matter from Bilateral Testes, Percutaneous Endoscopic Approach */
"0VCS0ZZ" = "1" /* Extirpation of Matter from Penis, Open Approach */
"0VCS3ZZ" = "1" /* Extirpation of Matter from Penis, Percutaneous Approach */
"0VCS4ZZ" = "1" /* Extirpation of Matter from Penis, Percutaneous Endoscopic Approach */
"0VWS00Z" = "1" /* Revision of Drainage Device in Penis, Open Approach */
"0VWS30Z" = "1" /* Revision of Drainage Device in Penis, Percutaneous Approach */
"0VWS40Z" = "1" /* Revision of Drainage Device in Penis, Percutaneous Endoscopic Approach */
"0VWS70Z" = "1" /* Revision of Drainage Device in Penis, Via Natural or Artificial Opening */
"0VWS80Z" = "1" /* Revision of Drainage Device in Penis, Via Natural or Artificial Opening Endoscopic */
"0W300ZZ" = "1" /* Control Bleeding in Head, Open Approach */
"0W303ZZ" = "1" /* Control Bleeding in Head, Percutaneous Approach */
"0W304ZZ" = "1" /* Control Bleeding in Head, Percutaneous Endoscopic Approach */
"0W310ZZ" = "1" /* Control Bleeding in Cranial Cavity, Open Approach */
"0W313ZZ" = "1" /* Control Bleeding in Cranial Cavity, Percutaneous Approach */
"0W314ZZ" = "1" /* Control Bleeding in Cranial Cavity, Percutaneous Endoscopic Approach */
"0W320ZZ" = "1" /* Control Bleeding in Face, Open Approach */
"0W323ZZ" = "1" /* Control Bleeding in Face, Percutaneous Approach */
"0W324ZZ" = "1" /* Control Bleeding in Face, Percutaneous Endoscopic Approach */
"0W330ZZ" = "1" /* Control Bleeding in Oral Cavity and Throat, Open Approach */
"0W333ZZ" = "1" /* Control Bleeding in Oral Cavity and Throat, Percutaneous Approach */
"0W334ZZ" = "1" /* Control Bleeding in Oral Cavity and Throat, Percutaneous Endoscopic Approach */
"0W337ZZ" = "1" /* Control Bleeding in Oral Cavity and Throat, Via Natural or Artificial Opening */
"0W338ZZ" = "1" /* Control Bleeding in Oral Cavity and Throat, Via Natural or Artificial Opening Endoscopic */
"0W33XZZ" = "1" /* Control Bleeding in Oral Cavity and Throat, External Approach */
"0W340ZZ" = "1" /* Control Bleeding in Upper Jaw, Open Approach */
"0W343ZZ" = "1" /* Control Bleeding in Upper Jaw, Percutaneous Approach */
"0W344ZZ" = "1" /* Control Bleeding in Upper Jaw, Percutaneous Endoscopic Approach */
"0W350ZZ" = "1" /* Control Bleeding in Lower Jaw, Open Approach */
"0W353ZZ" = "1" /* Control Bleeding in Lower Jaw, Percutaneous Approach */
"0W354ZZ" = "1" /* Control Bleeding in Lower Jaw, Percutaneous Endoscopic Approach */
"0W360ZZ" = "1" /* Control Bleeding in Neck, Open Approach */
"0W363ZZ" = "1" /* Control Bleeding in Neck, Percutaneous Approach */
"0W364ZZ" = "1" /* Control Bleeding in Neck, Percutaneous Endoscopic Approach */
"0W380ZZ" = "1" /* Control Bleeding in Chest Wall, Open Approach */
"0W383ZZ" = "1" /* Control Bleeding in Chest Wall, Percutaneous Approach */
"0W384ZZ" = "1" /* Control Bleeding in Chest Wall, Percutaneous Endoscopic Approach */
"0W390ZZ" = "1" /* Control Bleeding in Right Pleural Cavity, Open Approach */
"0W393ZZ" = "1" /* Control Bleeding in Right Pleural Cavity, Percutaneous Approach */
"0W394ZZ" = "1" /* Control Bleeding in Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0W3B0ZZ" = "1" /* Control Bleeding in Left Pleural Cavity, Open Approach */
"0W3B3ZZ" = "1" /* Control Bleeding in Left Pleural Cavity, Percutaneous Approach */
"0W3B4ZZ" = "1" /* Control Bleeding in Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0W3C0ZZ" = "1" /* Control Bleeding in Mediastinum, Open Approach */
"0W3C3ZZ" = "1" /* Control Bleeding in Mediastinum, Percutaneous Approach */
"0W3C4ZZ" = "1" /* Control Bleeding in Mediastinum, Percutaneous Endoscopic Approach */
"0W3D0ZZ" = "1" /* Control Bleeding in Pericardial Cavity, Open Approach */
"0W3D3ZZ" = "1" /* Control Bleeding in Pericardial Cavity, Percutaneous Approach */
"0W3D4ZZ" = "1" /* Control Bleeding in Pericardial Cavity, Percutaneous Endoscopic Approach */
"0W3F0ZZ" = "1" /* Control Bleeding in Abdominal Wall, Open Approach */
"0W3F3ZZ" = "1" /* Control Bleeding in Abdominal Wall, Percutaneous Approach */
"0W3F4ZZ" = "1" /* Control Bleeding in Abdominal Wall, Percutaneous Endoscopic Approach */
"0W3G0ZZ" = "1" /* Control Bleeding in Peritoneal Cavity, Open Approach */
"0W3G3ZZ" = "1" /* Control Bleeding in Peritoneal Cavity, Percutaneous Approach */
"0W3G4ZZ" = "1" /* Control Bleeding in Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0W3H0ZZ" = "1" /* Control Bleeding in Retroperitoneum, Open Approach */
"0W3H3ZZ" = "1" /* Control Bleeding in Retroperitoneum, Percutaneous Approach */
"0W3H4ZZ" = "1" /* Control Bleeding in Retroperitoneum, Percutaneous Endoscopic Approach */
"0W3J0ZZ" = "1" /* Control Bleeding in Pelvic Cavity, Open Approach */
"0W3J3ZZ" = "1" /* Control Bleeding in Pelvic Cavity, Percutaneous Approach */
"0W3J4ZZ" = "1" /* Control Bleeding in Pelvic Cavity, Percutaneous Endoscopic Approach */
"0W3K0ZZ" = "1" /* Control Bleeding in Upper Back, Open Approach */
"0W3K3ZZ" = "1" /* Control Bleeding in Upper Back, Percutaneous Approach */
"0W3K4ZZ" = "1" /* Control Bleeding in Upper Back, Percutaneous Endoscopic Approach */
"0W3L0ZZ" = "1" /* Control Bleeding in Lower Back, Open Approach */
"0W3L3ZZ" = "1" /* Control Bleeding in Lower Back, Percutaneous Approach */
"0W3L4ZZ" = "1" /* Control Bleeding in Lower Back, Percutaneous Endoscopic Approach */
"0W3M0ZZ" = "1" /* Control Bleeding in Male Perineum, Open Approach */
"0W3M3ZZ" = "1" /* Control Bleeding in Male Perineum, Percutaneous Approach */
"0W3M4ZZ" = "1" /* Control Bleeding in Male Perineum, Percutaneous Endoscopic Approach */
"0W3N0ZZ" = "1" /* Control Bleeding in Female Perineum, Open Approach */
"0W3N3ZZ" = "1" /* Control Bleeding in Female Perineum, Percutaneous Approach */
"0W3N4ZZ" = "1" /* Control Bleeding in Female Perineum, Percutaneous Endoscopic Approach */
"0W3P0ZZ" = "1" /* Control Bleeding in Gastrointestinal Tract, Open Approach */
"0W3P3ZZ" = "1" /* Control Bleeding in Gastrointestinal Tract, Percutaneous Approach */
"0W3P4ZZ" = "1" /* Control Bleeding in Gastrointestinal Tract, Percutaneous Endoscopic Approach */
"0W3P7ZZ" = "1" /* Control Bleeding in Gastrointestinal Tract, Via Natural or Artificial Opening */
"0W3P8ZZ" = "1" /* Control Bleeding in Gastrointestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0W3Q0ZZ" = "1" /* Control Bleeding in Respiratory Tract, Open Approach */
"0W3Q3ZZ" = "1" /* Control Bleeding in Respiratory Tract, Percutaneous Approach */
"0W3Q4ZZ" = "1" /* Control Bleeding in Respiratory Tract, Percutaneous Endoscopic Approach */
"0W3Q7ZZ" = "1" /* Control Bleeding in Respiratory Tract, Via Natural or Artificial Opening */
"0W3Q8ZZ" = "1" /* Control Bleeding in Respiratory Tract, Via Natural or Artificial Opening Endoscopic */
"0W3R0ZZ" = "1" /* Control Bleeding in Genitourinary Tract, Open Approach */
"0W3R3ZZ" = "1" /* Control Bleeding in Genitourinary Tract, Percutaneous Approach */
"0W3R4ZZ" = "1" /* Control Bleeding in Genitourinary Tract, Percutaneous Endoscopic Approach */
"0W3R7ZZ" = "1" /* Control Bleeding in Genitourinary Tract, Via Natural or Artificial Opening */
"0W3R8ZZ" = "1" /* Control Bleeding in Genitourinary Tract, Via Natural or Artificial Opening Endoscopic */
"0W9100Z" = "1" /* Drainage of Cranial Cavity with Drainage Device, Open Approach */
"0W910ZZ" = "1" /* Drainage of Cranial Cavity, Open Approach */
"0W9200Z" = "1" /* Drainage of Face with Drainage Device, Open Approach */
"0W920ZZ" = "1" /* Drainage of Face, Open Approach */
"0W9230Z" = "1" /* Drainage of Face with Drainage Device, Percutaneous Approach */
"0W923ZZ" = "1" /* Drainage of Face, Percutaneous Approach */
"0W9240Z" = "1" /* Drainage of Face with Drainage Device, Percutaneous Endoscopic Approach */
"0W924ZZ" = "1" /* Drainage of Face, Percutaneous Endoscopic Approach */
"0W9300Z" = "1" /* Drainage of Oral Cavity and Throat with Drainage Device, Open Approach */
"0W930ZZ" = "1" /* Drainage of Oral Cavity and Throat, Open Approach */
"0W9330Z" = "1" /* Drainage of Oral Cavity and Throat with Drainage Device, Percutaneous Approach */
"0W933ZZ" = "1" /* Drainage of Oral Cavity and Throat, Percutaneous Approach */
"0W9340Z" = "1" /* Drainage of Oral Cavity and Throat with Drainage Device, Percutaneous Endoscopic Approach */
"0W934ZZ" = "1" /* Drainage of Oral Cavity and Throat, Percutaneous Endoscopic Approach */
"0W9400Z" = "1" /* Drainage of Upper Jaw with Drainage Device, Open Approach */
"0W940ZZ" = "1" /* Drainage of Upper Jaw, Open Approach */
"0W9430Z" = "1" /* Drainage of Upper Jaw with Drainage Device, Percutaneous Approach */
"0W943ZZ" = "1" /* Drainage of Upper Jaw, Percutaneous Approach */
"0W9440Z" = "1" /* Drainage of Upper Jaw with Drainage Device, Percutaneous Endoscopic Approach */
"0W944ZZ" = "1" /* Drainage of Upper Jaw, Percutaneous Endoscopic Approach */
"0W9500Z" = "1" /* Drainage of Lower Jaw with Drainage Device, Open Approach */
"0W950ZZ" = "1" /* Drainage of Lower Jaw, Open Approach */
"0W9530Z" = "1" /* Drainage of Lower Jaw with Drainage Device, Percutaneous Approach */
"0W953ZZ" = "1" /* Drainage of Lower Jaw, Percutaneous Approach */
"0W9540Z" = "1" /* Drainage of Lower Jaw with Drainage Device, Percutaneous Endoscopic Approach */
"0W954ZZ" = "1" /* Drainage of Lower Jaw, Percutaneous Endoscopic Approach */
"0W9600Z" = "1" /* Drainage of Neck with Drainage Device, Open Approach */
"0W960ZZ" = "1" /* Drainage of Neck, Open Approach */
"0W9630Z" = "1" /* Drainage of Neck with Drainage Device, Percutaneous Approach */
"0W963ZZ" = "1" /* Drainage of Neck, Percutaneous Approach */
"0W9640Z" = "1" /* Drainage of Neck with Drainage Device, Percutaneous Endoscopic Approach */
"0W964ZZ" = "1" /* Drainage of Neck, Percutaneous Endoscopic Approach */
"0W9900Z" = "1" /* Drainage of Right Pleural Cavity with Drainage Device, Open Approach */
"0W990ZZ" = "1" /* Drainage of Right Pleural Cavity, Open Approach */
"0W994ZZ" = "1" /* Drainage of Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0W9B00Z" = "1" /* Drainage of Left Pleural Cavity with Drainage Device, Open Approach */
"0W9B0ZZ" = "1" /* Drainage of Left Pleural Cavity, Open Approach */
"0W9B4ZZ" = "1" /* Drainage of Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0W9C00Z" = "1" /* Drainage of Mediastinum with Drainage Device, Open Approach */
"0W9C0ZZ" = "1" /* Drainage of Mediastinum, Open Approach */
"0W9C30Z" = "1" /* Drainage of Mediastinum with Drainage Device, Percutaneous Approach */
"0W9C3ZZ" = "1" /* Drainage of Mediastinum, Percutaneous Approach */
"0W9C40Z" = "1" /* Drainage of Mediastinum with Drainage Device, Percutaneous Endoscopic Approach */
"0W9C4ZZ" = "1" /* Drainage of Mediastinum, Percutaneous Endoscopic Approach */
"0W9D30Z" = "1" /* Drainage of Pericardial Cavity with Drainage Device, Percutaneous Approach */
"0W9D3ZX" = "1" /* Drainage of Pericardial Cavity, Percutaneous Approach, Diagnostic */
"0W9D3ZZ" = "1" /* Drainage of Pericardial Cavity, Percutaneous Approach */
"0W9D40Z" = "1" /* Drainage of Pericardial Cavity with Drainage Device, Percutaneous Endoscopic Approach */
"0W9D4ZX" = "1" /* Drainage of Pericardial Cavity, Percutaneous Endoscopic Approach, Diagnostic */
"0W9D4ZZ" = "1" /* Drainage of Pericardial Cavity, Percutaneous Endoscopic Approach */
"0W9G00Z" = "1" /* Drainage of Peritoneal Cavity with Drainage Device, Open Approach */
"0W9G0ZZ" = "1" /* Drainage of Peritoneal Cavity, Open Approach */
"0W9J00Z" = "1" /* Drainage of Pelvic Cavity with Drainage Device, Open Approach */
"0W9J0ZZ" = "1" /* Drainage of Pelvic Cavity, Open Approach */
"0W9J40Z" = "1" /* Drainage of Pelvic Cavity with Drainage Device, Percutaneous Endoscopic Approach */
"0W9J4ZZ" = "1" /* Drainage of Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WC10ZZ" = "1" /* Extirpation of Matter from Cranial Cavity, Open Approach */
"0WC13ZZ" = "1" /* Extirpation of Matter from Cranial Cavity, Percutaneous Approach */
"0WC14ZZ" = "1" /* Extirpation of Matter from Cranial Cavity, Percutaneous Endoscopic Approach */
"0WC90ZZ" = "1" /* Extirpation of Matter from Right Pleural Cavity, Open Approach */
"0WC93ZZ" = "1" /* Extirpation of Matter from Right Pleural Cavity, Percutaneous Approach */
"0WC94ZZ" = "1" /* Extirpation of Matter from Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0WCB0ZZ" = "1" /* Extirpation of Matter from Left Pleural Cavity, Open Approach */
"0WCB3ZZ" = "1" /* Extirpation of Matter from Left Pleural Cavity, Percutaneous Approach */
"0WCB4ZZ" = "1" /* Extirpation of Matter from Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0WCC0ZZ" = "1" /* Extirpation of Matter from Mediastinum, Open Approach */
"0WCC3ZZ" = "1" /* Extirpation of Matter from Mediastinum, Percutaneous Approach */
"0WCC4ZZ" = "1" /* Extirpation of Matter from Mediastinum, Percutaneous Endoscopic Approach */
"0WCJ0ZZ" = "1" /* Extirpation of Matter from Pelvic Cavity, Open Approach */
"0WCP0ZZ" = "1" /* Extirpation of Matter from Gastrointestinal Tract, Open Approach */
"0WCQ0ZZ" = "1" /* Extirpation of Matter from Respiratory Tract, Open Approach */
"0WCQ3ZZ" = "1" /* Extirpation of Matter from Respiratory Tract, Percutaneous Approach */
"0WCQ4ZZ" = "1" /* Extirpation of Matter from Respiratory Tract, Percutaneous Endoscopic Approach */
"0WCR0ZZ" = "1" /* Extirpation of Matter from Genitourinary Tract, Open Approach */
"0WW000Z" = "1" /* Revision of Drainage Device in Head, Open Approach */
"0WW030Z" = "1" /* Revision of Drainage Device in Head, Percutaneous Approach */
"0WW040Z" = "1" /* Revision of Drainage Device in Head, Percutaneous Endoscopic Approach */
"0WW100Z" = "1" /* Revision of Drainage Device in Cranial Cavity, Open Approach */
"0WW130Z" = "1" /* Revision of Drainage Device in Cranial Cavity, Percutaneous Approach */
"0WW140Z" = "1" /* Revision of Drainage Device in Cranial Cavity, Percutaneous Endoscopic Approach */
"0WW200Z" = "1" /* Revision of Drainage Device in Face, Open Approach */
"0WW230Z" = "1" /* Revision of Drainage Device in Face, Percutaneous Approach */
"0WW240Z" = "1" /* Revision of Drainage Device in Face, Percutaneous Endoscopic Approach */
"0WW400Z" = "1" /* Revision of Drainage Device in Upper Jaw, Open Approach */
"0WW430Z" = "1" /* Revision of Drainage Device in Upper Jaw, Percutaneous Approach */
"0WW440Z" = "1" /* Revision of Drainage Device in Upper Jaw, Percutaneous Endoscopic Approach */
"0WW500Z" = "1" /* Revision of Drainage Device in Lower Jaw, Open Approach */
"0WW530Z" = "1" /* Revision of Drainage Device in Lower Jaw, Percutaneous Approach */
"0WW540Z" = "1" /* Revision of Drainage Device in Lower Jaw, Percutaneous Endoscopic Approach */
"0WW600Z" = "1" /* Revision of Drainage Device in Neck, Open Approach */
"0WW630Z" = "1" /* Revision of Drainage Device in Neck, Percutaneous Approach */
"0WW640Z" = "1" /* Revision of Drainage Device in Neck, Percutaneous Endoscopic Approach */
"0WW900Z" = "1" /* Revision of Drainage Device in Right Pleural Cavity, Open Approach */
"0WW930Z" = "1" /* Revision of Drainage Device in Right Pleural Cavity, Percutaneous Approach */
"0WW940Z" = "1" /* Revision of Drainage Device in Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0WWB00Z" = "1" /* Revision of Drainage Device in Left Pleural Cavity, Open Approach */
"0WWB30Z" = "1" /* Revision of Drainage Device in Left Pleural Cavity, Percutaneous Approach */
"0WWB40Z" = "1" /* Revision of Drainage Device in Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0WWC00Z" = "1" /* Revision of Drainage Device in Mediastinum, Open Approach */
"0WWC30Z" = "1" /* Revision of Drainage Device in Mediastinum, Percutaneous Approach */
"0WWC40Z" = "1" /* Revision of Drainage Device in Mediastinum, Percutaneous Endoscopic Approach */
"0WWG00Z" = "1" /* Revision of Drainage Device in Peritoneal Cavity, Open Approach */
"0WWG30Z" = "1" /* Revision of Drainage Device in Peritoneal Cavity, Percutaneous Approach */
"0WWG40Z" = "1" /* Revision of Drainage Device in Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WWH00Z" = "1" /* Revision of Drainage Device in Retroperitoneum, Open Approach */
"0WWH30Z" = "1" /* Revision of Drainage Device in Retroperitoneum, Percutaneous Approach */
"0WWH40Z" = "1" /* Revision of Drainage Device in Retroperitoneum, Percutaneous Endoscopic Approach */
"0WWJ00Z" = "1" /* Revision of Drainage Device in Pelvic Cavity, Open Approach */
"0WWJ30Z" = "1" /* Revision of Drainage Device in Pelvic Cavity, Percutaneous Approach */
"0WWJ40Z" = "1" /* Revision of Drainage Device in Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WWK00Z" = "1" /* Revision of Drainage Device in Upper Back, Open Approach */
"0WWK30Z" = "1" /* Revision of Drainage Device in Upper Back, Percutaneous Approach */
"0WWK40Z" = "1" /* Revision of Drainage Device in Upper Back, Percutaneous Endoscopic Approach */
"0WWL00Z" = "1" /* Revision of Drainage Device in Lower Back, Open Approach */
"0WWL30Z" = "1" /* Revision of Drainage Device in Lower Back, Percutaneous Approach */
"0WWL40Z" = "1" /* Revision of Drainage Device in Lower Back, Percutaneous Endoscopic Approach */
"0WWM00Z" = "1" /* Revision of Drainage Device in Male Perineum, Open Approach */
"0WWM30Z" = "1" /* Revision of Drainage Device in Male Perineum, Percutaneous Approach */
"0WWM40Z" = "1" /* Revision of Drainage Device in Male Perineum, Percutaneous Endoscopic Approach */
"0X320ZZ" = "1" /* Control Bleeding in Right Shoulder Region, Open Approach */
"0X323ZZ" = "1" /* Control Bleeding in Right Shoulder Region, Percutaneous Approach */
"0X324ZZ" = "1" /* Control Bleeding in Right Shoulder Region, Percutaneous Endoscopic Approach */
"0X330ZZ" = "1" /* Control Bleeding in Left Shoulder Region, Open Approach */
"0X333ZZ" = "1" /* Control Bleeding in Left Shoulder Region, Percutaneous Approach */
"0X334ZZ" = "1" /* Control Bleeding in Left Shoulder Region, Percutaneous Endoscopic Approach */
"0X340ZZ" = "1" /* Control Bleeding in Right Axilla, Open Approach */
"0X343ZZ" = "1" /* Control Bleeding in Right Axilla, Percutaneous Approach */
"0X344ZZ" = "1" /* Control Bleeding in Right Axilla, Percutaneous Endoscopic Approach */
"0X350ZZ" = "1" /* Control Bleeding in Left Axilla, Open Approach */
"0X353ZZ" = "1" /* Control Bleeding in Left Axilla, Percutaneous Approach */
"0X354ZZ" = "1" /* Control Bleeding in Left Axilla, Percutaneous Endoscopic Approach */
"0X360ZZ" = "1" /* Control Bleeding in Right Upper Extremity, Open Approach */
"0X363ZZ" = "1" /* Control Bleeding in Right Upper Extremity, Percutaneous Approach */
"0X364ZZ" = "1" /* Control Bleeding in Right Upper Extremity, Percutaneous Endoscopic Approach */
"0X370ZZ" = "1" /* Control Bleeding in Left Upper Extremity, Open Approach */
"0X373ZZ" = "1" /* Control Bleeding in Left Upper Extremity, Percutaneous Approach */
"0X374ZZ" = "1" /* Control Bleeding in Left Upper Extremity, Percutaneous Endoscopic Approach */
"0X380ZZ" = "1" /* Control Bleeding in Right Upper Arm, Open Approach */
"0X383ZZ" = "1" /* Control Bleeding in Right Upper Arm, Percutaneous Approach */
"0X384ZZ" = "1" /* Control Bleeding in Right Upper Arm, Percutaneous Endoscopic Approach */
"0X390ZZ" = "1" /* Control Bleeding in Left Upper Arm, Open Approach */
"0X393ZZ" = "1" /* Control Bleeding in Left Upper Arm, Percutaneous Approach */
"0X394ZZ" = "1" /* Control Bleeding in Left Upper Arm, Percutaneous Endoscopic Approach */
"0X3B0ZZ" = "1" /* Control Bleeding in Right Elbow Region, Open Approach */
"0X3B3ZZ" = "1" /* Control Bleeding in Right Elbow Region, Percutaneous Approach */
"0X3B4ZZ" = "1" /* Control Bleeding in Right Elbow Region, Percutaneous Endoscopic Approach */
"0X3C0ZZ" = "1" /* Control Bleeding in Left Elbow Region, Open Approach */
"0X3C3ZZ" = "1" /* Control Bleeding in Left Elbow Region, Percutaneous Approach */
"0X3C4ZZ" = "1" /* Control Bleeding in Left Elbow Region, Percutaneous Endoscopic Approach */
"0X3D0ZZ" = "1" /* Control Bleeding in Right Lower Arm, Open Approach */
"0X3D3ZZ" = "1" /* Control Bleeding in Right Lower Arm, Percutaneous Approach */
"0X3D4ZZ" = "1" /* Control Bleeding in Right Lower Arm, Percutaneous Endoscopic Approach */
"0X3F0ZZ" = "1" /* Control Bleeding in Left Lower Arm, Open Approach */
"0X3F3ZZ" = "1" /* Control Bleeding in Left Lower Arm, Percutaneous Approach */
"0X3F4ZZ" = "1" /* Control Bleeding in Left Lower Arm, Percutaneous Endoscopic Approach */
"0X3G0ZZ" = "1" /* Control Bleeding in Right Wrist Region, Open Approach */
"0X3G3ZZ" = "1" /* Control Bleeding in Right Wrist Region, Percutaneous Approach */
"0X3G4ZZ" = "1" /* Control Bleeding in Right Wrist Region, Percutaneous Endoscopic Approach */
"0X3H0ZZ" = "1" /* Control Bleeding in Left Wrist Region, Open Approach */
"0X3H3ZZ" = "1" /* Control Bleeding in Left Wrist Region, Percutaneous Approach */
"0X3H4ZZ" = "1" /* Control Bleeding in Left Wrist Region, Percutaneous Endoscopic Approach */
"0X3J0ZZ" = "1" /* Control Bleeding in Right Hand, Open Approach */
"0X3J3ZZ" = "1" /* Control Bleeding in Right Hand, Percutaneous Approach */
"0X3J4ZZ" = "1" /* Control Bleeding in Right Hand, Percutaneous Endoscopic Approach */
"0X3K0ZZ" = "1" /* Control Bleeding in Left Hand, Open Approach */
"0X3K3ZZ" = "1" /* Control Bleeding in Left Hand, Percutaneous Approach */
"0X3K4ZZ" = "1" /* Control Bleeding in Left Hand, Percutaneous Endoscopic Approach */
"0X9J00Z" = "1" /* Drainage of Right Hand with Drainage Device, Open Approach */
"0X9J0ZZ" = "1" /* Drainage of Right Hand, Open Approach */
"0X9J30Z" = "1" /* Drainage of Right Hand with Drainage Device, Percutaneous Approach */
"0X9J3ZZ" = "1" /* Drainage of Right Hand, Percutaneous Approach */
"0X9J40Z" = "1" /* Drainage of Right Hand with Drainage Device, Percutaneous Endoscopic Approach */
"0X9J4ZZ" = "1" /* Drainage of Right Hand, Percutaneous Endoscopic Approach */
"0X9K00Z" = "1" /* Drainage of Left Hand with Drainage Device, Open Approach */
"0X9K0ZZ" = "1" /* Drainage of Left Hand, Open Approach */
"0X9K30Z" = "1" /* Drainage of Left Hand with Drainage Device, Percutaneous Approach */
"0X9K3ZZ" = "1" /* Drainage of Left Hand, Percutaneous Approach */
"0X9K40Z" = "1" /* Drainage of Left Hand with Drainage Device, Percutaneous Endoscopic Approach */
"0X9K4ZZ" = "1" /* Drainage of Left Hand, Percutaneous Endoscopic Approach */
"0XW600Z" = "1" /* Revision of Drainage Device in Right Upper Extremity, Open Approach */
"0XW630Z" = "1" /* Revision of Drainage Device in Right Upper Extremity, Percutaneous Approach */
"0XW640Z" = "1" /* Revision of Drainage Device in Right Upper Extremity, Percutaneous Endoscopic Approach */
"0XW700Z" = "1" /* Revision of Drainage Device in Left Upper Extremity, Open Approach */
"0XW730Z" = "1" /* Revision of Drainage Device in Left Upper Extremity, Percutaneous Approach */
"0XW740Z" = "1" /* Revision of Drainage Device in Left Upper Extremity, Percutaneous Endoscopic Approach */
"0Y300ZZ" = "1" /* Control Bleeding in Right Buttock, Open Approach */
"0Y303ZZ" = "1" /* Control Bleeding in Right Buttock, Percutaneous Approach */
"0Y304ZZ" = "1" /* Control Bleeding in Right Buttock, Percutaneous Endoscopic Approach */
"0Y310ZZ" = "1" /* Control Bleeding in Left Buttock, Open Approach */
"0Y313ZZ" = "1" /* Control Bleeding in Left Buttock, Percutaneous Approach */
"0Y314ZZ" = "1" /* Control Bleeding in Left Buttock, Percutaneous Endoscopic Approach */
"0Y350ZZ" = "1" /* Control Bleeding in Right Inguinal Region, Open Approach */
"0Y353ZZ" = "1" /* Control Bleeding in Right Inguinal Region, Percutaneous Approach */
"0Y354ZZ" = "1" /* Control Bleeding in Right Inguinal Region, Percutaneous Endoscopic Approach */
"0Y360ZZ" = "1" /* Control Bleeding in Left Inguinal Region, Open Approach */
"0Y363ZZ" = "1" /* Control Bleeding in Left Inguinal Region, Percutaneous Approach */
"0Y364ZZ" = "1" /* Control Bleeding in Left Inguinal Region, Percutaneous Endoscopic Approach */
"0Y370ZZ" = "1" /* Control Bleeding in Right Femoral Region, Open Approach */
"0Y373ZZ" = "1" /* Control Bleeding in Right Femoral Region, Percutaneous Approach */
"0Y374ZZ" = "1" /* Control Bleeding in Right Femoral Region, Percutaneous Endoscopic Approach */
"0Y380ZZ" = "1" /* Control Bleeding in Left Femoral Region, Open Approach */
"0Y383ZZ" = "1" /* Control Bleeding in Left Femoral Region, Percutaneous Approach */
"0Y384ZZ" = "1" /* Control Bleeding in Left Femoral Region, Percutaneous Endoscopic Approach */
"0Y390ZZ" = "1" /* Control Bleeding in Right Lower Extremity, Open Approach */
"0Y393ZZ" = "1" /* Control Bleeding in Right Lower Extremity, Percutaneous Approach */
"0Y394ZZ" = "1" /* Control Bleeding in Right Lower Extremity, Percutaneous Endoscopic Approach */
"0Y3B0ZZ" = "1" /* Control Bleeding in Left Lower Extremity, Open Approach */
"0Y3B3ZZ" = "1" /* Control Bleeding in Left Lower Extremity, Percutaneous Approach */
"0Y3B4ZZ" = "1" /* Control Bleeding in Left Lower Extremity, Percutaneous Endoscopic Approach */
"0Y3C0ZZ" = "1" /* Control Bleeding in Right Upper Leg, Open Approach */
"0Y3C3ZZ" = "1" /* Control Bleeding in Right Upper Leg, Percutaneous Approach */
"0Y3C4ZZ" = "1" /* Control Bleeding in Right Upper Leg, Percutaneous Endoscopic Approach */
"0Y3D0ZZ" = "1" /* Control Bleeding in Left Upper Leg, Open Approach */
"0Y3D3ZZ" = "1" /* Control Bleeding in Left Upper Leg, Percutaneous Approach */
"0Y3D4ZZ" = "1" /* Control Bleeding in Left Upper Leg, Percutaneous Endoscopic Approach */
"0Y3F0ZZ" = "1" /* Control Bleeding in Right Knee Region, Open Approach */
"0Y3F3ZZ" = "1" /* Control Bleeding in Right Knee Region, Percutaneous Approach */
"0Y3F4ZZ" = "1" /* Control Bleeding in Right Knee Region, Percutaneous Endoscopic Approach */
"0Y3G0ZZ" = "1" /* Control Bleeding in Left Knee Region, Open Approach */
"0Y3G3ZZ" = "1" /* Control Bleeding in Left Knee Region, Percutaneous Approach */
"0Y3G4ZZ" = "1" /* Control Bleeding in Left Knee Region, Percutaneous Endoscopic Approach */
"0Y3H0ZZ" = "1" /* Control Bleeding in Right Lower Leg, Open Approach */
"0Y3H3ZZ" = "1" /* Control Bleeding in Right Lower Leg, Percutaneous Approach */
"0Y3H4ZZ" = "1" /* Control Bleeding in Right Lower Leg, Percutaneous Endoscopic Approach */
"0Y3J0ZZ" = "1" /* Control Bleeding in Left Lower Leg, Open Approach */
"0Y3J3ZZ" = "1" /* Control Bleeding in Left Lower Leg, Percutaneous Approach */
"0Y3J4ZZ" = "1" /* Control Bleeding in Left Lower Leg, Percutaneous Endoscopic Approach */
"0Y3K0ZZ" = "1" /* Control Bleeding in Right Ankle Region, Open Approach */
"0Y3K3ZZ" = "1" /* Control Bleeding in Right Ankle Region, Percutaneous Approach */
"0Y3K4ZZ" = "1" /* Control Bleeding in Right Ankle Region, Percutaneous Endoscopic Approach */
"0Y3L0ZZ" = "1" /* Control Bleeding in Left Ankle Region, Open Approach */
"0Y3L3ZZ" = "1" /* Control Bleeding in Left Ankle Region, Percutaneous Approach */
"0Y3L4ZZ" = "1" /* Control Bleeding in Left Ankle Region, Percutaneous Endoscopic Approach */
"0Y3M0ZZ" = "1" /* Control Bleeding in Right Foot, Open Approach */
"0Y3M3ZZ" = "1" /* Control Bleeding in Right Foot, Percutaneous Approach */
"0Y3M4ZZ" = "1" /* Control Bleeding in Right Foot, Percutaneous Endoscopic Approach */
"0Y3N0ZZ" = "1" /* Control Bleeding in Left Foot, Open Approach */
"0Y3N3ZZ" = "1" /* Control Bleeding in Left Foot, Percutaneous Approach */
"0Y3N4ZZ" = "1" /* Control Bleeding in Left Foot, Percutaneous Endoscopic Approach */
"0YW900Z" = "1" /* Revision of Drainage Device in Right Lower Extremity, Open Approach */
"0YW930Z" = "1" /* Revision of Drainage Device in Right Lower Extremity, Percutaneous Approach */
"0YW940Z" = "1" /* Revision of Drainage Device in Right Lower Extremity, Percutaneous Endoscopic Approach */
"0YWB00Z" = "1" /* Revision of Drainage Device in Left Lower Extremity, Open Approach */
"0YWB30Z" = "1" /* Revision of Drainage Device in Left Lower Extremity, Percutaneous Approach */
"0YWB40Z" = "1" /* Revision of Drainage Device in Left Lower Extremity, Percutaneous Endoscopic Approach */
"2Y41X5Z" = "1" /* Packing of Nasal Region using Packing Material */
"3E050TZ" = "1" /* Introduction of Destructive Agent into Peripheral Artery, Open Approach */
"3E053TZ" = "1" /* Introduction of Destructive Agent into Peripheral Artery, Percutaneous Approach */
"3E060TZ" = "1" /* Introduction of Destructive Agent into Central Artery, Open Approach */
"3E063TZ" = "1" /* Introduction of Destructive Agent into Central Artery, Percutaneous Approach */
"3E093TZ" = "1" /* Introduction of Destructive Agent into Nose, Percutaneous Approach */
"3E097TZ" = "1" /* Introduction of Destructive Agent into Nose, Via Natural or Artificial Opening */
"3E09XTZ" = "1" /* Introduction of Destructive Agent into Nose, External Approach */
"3E0D3TZ" = "1" /* Introduction of Destructive Agent into Mouth and Pharynx, Percutaneous Approach */
"3E0D7TZ" = "1" /* Introduction of Destructive Agent into Mouth and Pharynx, Via Natural or Artificial Opening */
"3E0DXTZ" = "1" /* Introduction of Destructive Agent into Mouth and Pharynx, External Approach */
"3E0G3TZ" = "1" /* Introduction of Destructive Agent into Upper GI, Percutaneous Approach */
"3E0G7TZ" = "1" /* Introduction of Destructive Agent into Upper GI, Via Natural or Artificial Opening */
"3E0G8TZ" = "1" /* Introduction of Destructive Agent into Upper GI, Via Natural or Artificial Opening Endoscopic */
"3E0H3TZ" = "1" /* Introduction of Destructive Agent into Lower GI, Percutaneous Approach */
"3E0H7TZ" = "1" /* Introduction of Destructive Agent into Lower GI, Via Natural or Artificial Opening */
"3E0H8TZ" = "1" /* Introduction of Destructive Agent into Lower GI, Via Natural or Artificial Opening Endoscopic */
"3E0K3TZ" = "1" /* Introduction of Destructive Agent into Genitourinary Tract, Percutaneous Approach */
"3E0K7TZ" = "1" /* Introduction of Destructive Agent into Genitourinary Tract, Via Natural or Artificial Opening */
"3E0K8TZ" = "1" /* Introduction of Destructive Agent into Genitourinary Tract, Via Natural or Artificial Opening Endoscopic */
"3E0N7TZ" = "1" /* Introduction of Destructive Agent into Male Reproductive, Via Natural or Artificial Opening */
"3E0N8TZ" = "1" /* Introduction of Destructive Agent into Male Reproductive, Via Natural or Artificial Opening Endoscopic */
Other = "0"
;

/* Procedure codeset NUCRANP last updated 170108 for ICD10 v70rev0 */
Value $NUCRANP
"008P0ZZ" = "1" /* Division of Glossopharyngeal Nerve, Open Approach */
"008P3ZZ" = "1" /* Division of Glossopharyngeal Nerve, Percutaneous Approach */
"008P4ZZ" = "1" /* Division of Glossopharyngeal Nerve, Percutaneous Endoscopic Approach */
"008Q0ZZ" = "1" /* Division of Vagus Nerve, Open Approach */
"008Q3ZZ" = "1" /* Division of Vagus Nerve, Percutaneous Approach */
"008Q4ZZ" = "1" /* Division of Vagus Nerve, Percutaneous Endoscopic Approach */
"07T10ZZ" = "1" /* Resection of Right Neck Lymphatic, Open Approach */
"07T14ZZ" = "1" /* Resection of Right Neck Lymphatic, Percutaneous Endoscopic Approach */
"07T20ZZ" = "1" /* Resection of Left Neck Lymphatic, Open Approach */
"07T24ZZ" = "1" /* Resection of Left Neck Lymphatic, Percutaneous Endoscopic Approach */
"095N0ZZ" = "1" /* Destruction of Nasopharynx, Open Approach */
"095N3ZZ" = "1" /* Destruction of Nasopharynx, Percutaneous Approach */
"095N4ZZ" = "1" /* Destruction of Nasopharynx, Percutaneous Endoscopic Approach */
"095P0ZZ" = "1" /* Destruction of Accessory Sinus, Open Approach */
"095Q0ZZ" = "1" /* Destruction of Right Maxillary Sinus, Open Approach */
"095R0ZZ" = "1" /* Destruction of Left Maxillary Sinus, Open Approach */
"095S0ZZ" = "1" /* Destruction of Right Frontal Sinus, Open Approach */
"095T0ZZ" = "1" /* Destruction of Left Frontal Sinus, Open Approach */
"095U0ZZ" = "1" /* Destruction of Right Ethmoid Sinus, Open Approach */
"095V0ZZ" = "1" /* Destruction of Left Ethmoid Sinus, Open Approach */
"095W0ZZ" = "1" /* Destruction of Right Sphenoid Sinus, Open Approach */
"095X0ZZ" = "1" /* Destruction of Left Sphenoid Sinus, Open Approach */
"099N00Z" = "1" /* Drainage of Nasopharynx with Drainage Device, Open Approach */
"099N0ZZ" = "1" /* Drainage of Nasopharynx, Open Approach */
"099N30Z" = "1" /* Drainage of Nasopharynx with Drainage Device, Percutaneous Approach */
"099N40Z" = "1" /* Drainage of Nasopharynx with Drainage Device, Percutaneous Endoscopic Approach */
"099N70Z" = "1" /* Drainage of Nasopharynx with Drainage Device, Via Natural or Artificial Opening */
"099N80Z" = "1" /* Drainage of Nasopharynx with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"099P00Z" = "1" /* Drainage of Accessory Sinus with Drainage Device, Open Approach */
"099P0ZZ" = "1" /* Drainage of Accessory Sinus, Open Approach */
"099Q00Z" = "1" /* Drainage of Right Maxillary Sinus with Drainage Device, Open Approach */
"099Q0ZZ" = "1" /* Drainage of Right Maxillary Sinus, Open Approach */
"099R00Z" = "1" /* Drainage of Left Maxillary Sinus with Drainage Device, Open Approach */
"099R0ZZ" = "1" /* Drainage of Left Maxillary Sinus, Open Approach */
"099S00Z" = "1" /* Drainage of Right Frontal Sinus with Drainage Device, Open Approach */
"099S0ZZ" = "1" /* Drainage of Right Frontal Sinus, Open Approach */
"099T00Z" = "1" /* Drainage of Left Frontal Sinus with Drainage Device, Open Approach */
"099T0ZZ" = "1" /* Drainage of Left Frontal Sinus, Open Approach */
"099U00Z" = "1" /* Drainage of Right Ethmoid Sinus with Drainage Device, Open Approach */
"099U0ZZ" = "1" /* Drainage of Right Ethmoid Sinus, Open Approach */
"099V00Z" = "1" /* Drainage of Left Ethmoid Sinus with Drainage Device, Open Approach */
"099V0ZZ" = "1" /* Drainage of Left Ethmoid Sinus, Open Approach */
"099W00Z" = "1" /* Drainage of Right Sphenoid Sinus with Drainage Device, Open Approach */
"099W0ZZ" = "1" /* Drainage of Right Sphenoid Sinus, Open Approach */
"099X00Z" = "1" /* Drainage of Left Sphenoid Sinus with Drainage Device, Open Approach */
"099X0ZZ" = "1" /* Drainage of Left Sphenoid Sinus, Open Approach */
"09BN0ZZ" = "1" /* Excision of Nasopharynx, Open Approach */
"09BP0ZZ" = "1" /* Excision of Accessory Sinus, Open Approach */
"09BQ0ZZ" = "1" /* Excision of Right Maxillary Sinus, Open Approach */
"09BR0ZZ" = "1" /* Excision of Left Maxillary Sinus, Open Approach */
"09BS0ZZ" = "1" /* Excision of Right Frontal Sinus, Open Approach */
"09BT0ZZ" = "1" /* Excision of Left Frontal Sinus, Open Approach */
"09BU0ZZ" = "1" /* Excision of Right Ethmoid Sinus, Open Approach */
"09BV0ZZ" = "1" /* Excision of Left Ethmoid Sinus, Open Approach */
"09BW0ZZ" = "1" /* Excision of Right Sphenoid Sinus, Open Approach */
"09BX0ZZ" = "1" /* Excision of Left Sphenoid Sinus, Open Approach */
"09CN0ZZ" = "1" /* Extirpation of Matter from Nasopharynx, Open Approach */
"09CN3ZZ" = "1" /* Extirpation of Matter from Nasopharynx, Percutaneous Approach */
"09CN7ZZ" = "1" /* Extirpation of Matter from Nasopharynx, Via Natural or Artificial Opening */
"09CN8ZZ" = "1" /* Extirpation of Matter from Nasopharynx, Via Natural or Artificial Opening Endoscopic */
"09CP0ZZ" = "1" /* Extirpation of Matter from Accessory Sinus, Open Approach */
"09CQ0ZZ" = "1" /* Extirpation of Matter from Right Maxillary Sinus, Open Approach */
"09CR0ZZ" = "1" /* Extirpation of Matter from Left Maxillary Sinus, Open Approach */
"09CS0ZZ" = "1" /* Extirpation of Matter from Right Frontal Sinus, Open Approach */
"09CT0ZZ" = "1" /* Extirpation of Matter from Left Frontal Sinus, Open Approach */
"09CU0ZZ" = "1" /* Extirpation of Matter from Right Ethmoid Sinus, Open Approach */
"09CV0ZZ" = "1" /* Extirpation of Matter from Left Ethmoid Sinus, Open Approach */
"09CW0ZZ" = "1" /* Extirpation of Matter from Right Sphenoid Sinus, Open Approach */
"09CX0ZZ" = "1" /* Extirpation of Matter from Left Sphenoid Sinus, Open Approach */
"09DP0ZZ" = "1" /* Extraction of Accessory Sinus, Open Approach */
"09DQ0ZZ" = "1" /* Extraction of Right Maxillary Sinus, Open Approach */
"09DR0ZZ" = "1" /* Extraction of Left Maxillary Sinus, Open Approach */
"09DS0ZZ" = "1" /* Extraction of Right Frontal Sinus, Open Approach */
"09DT0ZZ" = "1" /* Extraction of Left Frontal Sinus, Open Approach */
"09DU0ZZ" = "1" /* Extraction of Right Ethmoid Sinus, Open Approach */
"09DV0ZZ" = "1" /* Extraction of Left Ethmoid Sinus, Open Approach */
"09DW0ZZ" = "1" /* Extraction of Right Sphenoid Sinus, Open Approach */
"09DX0ZZ" = "1" /* Extraction of Left Sphenoid Sinus, Open Approach */
"09NN0ZZ" = "1" /* Release Nasopharynx, Open Approach */
"09NN3ZZ" = "1" /* Release Nasopharynx, Percutaneous Approach */
"09NN4ZZ" = "1" /* Release Nasopharynx, Percutaneous Endoscopic Approach */
"09NN7ZZ" = "1" /* Release Nasopharynx, Via Natural or Artificial Opening */
"09NN8ZZ" = "1" /* Release Nasopharynx, Via Natural or Artificial Opening Endoscopic */
"09NP0ZZ" = "1" /* Release Accessory Sinus, Open Approach */
"09NQ0ZZ" = "1" /* Release Right Maxillary Sinus, Open Approach */
"09NR0ZZ" = "1" /* Release Left Maxillary Sinus, Open Approach */
"09NS0ZZ" = "1" /* Release Right Frontal Sinus, Open Approach */
"09NT0ZZ" = "1" /* Release Left Frontal Sinus, Open Approach */
"09NU0ZZ" = "1" /* Release Right Ethmoid Sinus, Open Approach */
"09NV0ZZ" = "1" /* Release Left Ethmoid Sinus, Open Approach */
"09NW0ZZ" = "1" /* Release Right Sphenoid Sinus, Open Approach */
"09NX0ZZ" = "1" /* Release Left Sphenoid Sinus, Open Approach */
"09QN0ZZ" = "1" /* Repair Nasopharynx, Open Approach */
"09QN3ZZ" = "1" /* Repair Nasopharynx, Percutaneous Approach */
"09QN7ZZ" = "1" /* Repair Nasopharynx, Via Natural or Artificial Opening */
"09QN8ZZ" = "1" /* Repair Nasopharynx, Via Natural or Artificial Opening Endoscopic */
"09QP0ZZ" = "1" /* Repair Accessory Sinus, Open Approach */
"09QQ0ZZ" = "1" /* Repair Right Maxillary Sinus, Open Approach */
"09QR0ZZ" = "1" /* Repair Left Maxillary Sinus, Open Approach */
"09QS0ZZ" = "1" /* Repair Right Frontal Sinus, Open Approach */
"09QT0ZZ" = "1" /* Repair Left Frontal Sinus, Open Approach */
"09QU0ZZ" = "1" /* Repair Right Ethmoid Sinus, Open Approach */
"09QV0ZZ" = "1" /* Repair Left Ethmoid Sinus, Open Approach */
"09QW0ZZ" = "1" /* Repair Right Sphenoid Sinus, Open Approach */
"09QX0ZZ" = "1" /* Repair Left Sphenoid Sinus, Open Approach */
"09RN07Z" = "1" /* Replacement of Nasopharynx with Autologous Tissue Substitute, Open Approach */
"09RN0JZ" = "1" /* Replacement of Nasopharynx with Synthetic Substitute, Open Approach */
"09RN0KZ" = "1" /* Replacement of Nasopharynx with Nonautologous Tissue Substitute, Open Approach */
"09RN77Z" = "1" /* Replacement of Nasopharynx with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"09RN7JZ" = "1" /* Replacement of Nasopharynx with Synthetic Substitute, Via Natural or Artificial Opening */
"09RN7KZ" = "1" /* Replacement of Nasopharynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"09RN87Z" = "1" /* Replacement of Nasopharynx with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"09RN8JZ" = "1" /* Replacement of Nasopharynx with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"09RN8KZ" = "1" /* Replacement of Nasopharynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"09TN0ZZ" = "1" /* Resection of Nasopharynx, Open Approach */
"09TN4ZZ" = "1" /* Resection of Nasopharynx, Percutaneous Endoscopic Approach */
"09TN7ZZ" = "1" /* Resection of Nasopharynx, Via Natural or Artificial Opening */
"09TN8ZZ" = "1" /* Resection of Nasopharynx, Via Natural or Artificial Opening Endoscopic */
"09TP0ZZ" = "1" /* Resection of Accessory Sinus, Open Approach */
"09TQ0ZZ" = "1" /* Resection of Right Maxillary Sinus, Open Approach */
"09TR0ZZ" = "1" /* Resection of Left Maxillary Sinus, Open Approach */
"09TS0ZZ" = "1" /* Resection of Right Frontal Sinus, Open Approach */
"09TT0ZZ" = "1" /* Resection of Left Frontal Sinus, Open Approach */
"09TU0ZZ" = "1" /* Resection of Right Ethmoid Sinus, Open Approach */
"09TV0ZZ" = "1" /* Resection of Left Ethmoid Sinus, Open Approach */
"09TW0ZZ" = "1" /* Resection of Right Sphenoid Sinus, Open Approach */
"09TX0ZZ" = "1" /* Resection of Left Sphenoid Sinus, Open Approach */
"09UN07Z" = "1" /* Supplement Nasopharynx with Autologous Tissue Substitute, Open Approach */
"09UN0JZ" = "1" /* Supplement Nasopharynx with Synthetic Substitute, Open Approach */
"09UN0KZ" = "1" /* Supplement Nasopharynx with Nonautologous Tissue Substitute, Open Approach */
"09UN77Z" = "1" /* Supplement Nasopharynx with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"09UN7JZ" = "1" /* Supplement Nasopharynx with Synthetic Substitute, Via Natural or Artificial Opening */
"09UN7KZ" = "1" /* Supplement Nasopharynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"09UN87Z" = "1" /* Supplement Nasopharynx with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"09UN8JZ" = "1" /* Supplement Nasopharynx with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"09UN8KZ" = "1" /* Supplement Nasopharynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0B110D6" = "1" /* Bypass Trachea to Esophagus with Intraluminal Device, Open Approach */
"0B110F4" = "1" /* Bypass Trachea to Cutaneous with Tracheostomy Device, Open Approach */
"0B110Z4" = "1" /* Bypass Trachea to Cutaneous, Open Approach */
"0B113F4" = "1" /* Bypass Trachea to Cutaneous with Tracheostomy Device, Percutaneous Approach */
"0B113Z4" = "1" /* Bypass Trachea to Cutaneous, Percutaneous Approach */
"0B114F4" = "1" /* Bypass Trachea to Cutaneous with Tracheostomy Device, Percutaneous Endoscopic Approach */
"0B114Z4" = "1" /* Bypass Trachea to Cutaneous, Percutaneous Endoscopic Approach */
"0B510ZZ" = "1" /* Destruction of Trachea, Open Approach */
"0B513ZZ" = "1" /* Destruction of Trachea, Percutaneous Approach */
"0B514ZZ" = "1" /* Destruction of Trachea, Percutaneous Endoscopic Approach */
"0B517ZZ" = "1" /* Destruction of Trachea, Via Natural or Artificial Opening */
"0B518ZZ" = "1" /* Destruction of Trachea, Via Natural or Artificial Opening Endoscopic */
"0B520ZZ" = "1" /* Destruction of Carina, Open Approach */
"0B523ZZ" = "1" /* Destruction of Carina, Percutaneous Approach */
"0B524ZZ" = "1" /* Destruction of Carina, Percutaneous Endoscopic Approach */
"0B527ZZ" = "1" /* Destruction of Carina, Via Natural or Artificial Opening */
"0B528ZZ" = "1" /* Destruction of Carina, Via Natural or Artificial Opening Endoscopic */
"0B710DZ" = "1" /* Dilation of Trachea with Intraluminal Device, Open Approach */
"0B710ZZ" = "1" /* Dilation of Trachea, Open Approach */
"0B713DZ" = "1" /* Dilation of Trachea with Intraluminal Device, Percutaneous Approach */
"0B713ZZ" = "1" /* Dilation of Trachea, Percutaneous Approach */
"0B714DZ" = "1" /* Dilation of Trachea with Intraluminal Device, Percutaneous Endoscopic Approach */
"0B714ZZ" = "1" /* Dilation of Trachea, Percutaneous Endoscopic Approach */
"0B717DZ" = "1" /* Dilation of Trachea with Intraluminal Device, Via Natural or Artificial Opening */
"0B717ZZ" = "1" /* Dilation of Trachea, Via Natural or Artificial Opening */
"0B718DZ" = "1" /* Dilation of Trachea with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0B718ZZ" = "1" /* Dilation of Trachea, Via Natural or Artificial Opening Endoscopic */
"0B720DZ" = "1" /* Dilation of Carina with Intraluminal Device, Open Approach */
"0B720ZZ" = "1" /* Dilation of Carina, Open Approach */
"0B723DZ" = "1" /* Dilation of Carina with Intraluminal Device, Percutaneous Approach */
"0B723ZZ" = "1" /* Dilation of Carina, Percutaneous Approach */
"0B724DZ" = "1" /* Dilation of Carina with Intraluminal Device, Percutaneous Endoscopic Approach */
"0B724ZZ" = "1" /* Dilation of Carina, Percutaneous Endoscopic Approach */
"0B727DZ" = "1" /* Dilation of Carina with Intraluminal Device, Via Natural or Artificial Opening */
"0B727ZZ" = "1" /* Dilation of Carina, Via Natural or Artificial Opening */
"0B728DZ" = "1" /* Dilation of Carina with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0B728ZZ" = "1" /* Dilation of Carina, Via Natural or Artificial Opening Endoscopic */
"0B9100Z" = "1" /* Drainage of Trachea with Drainage Device, Open Approach */
"0B910ZZ" = "1" /* Drainage of Trachea, Open Approach */
"0B9130Z" = "1" /* Drainage of Trachea with Drainage Device, Percutaneous Approach */
"0B913ZZ" = "1" /* Drainage of Trachea, Percutaneous Approach */
"0B9140Z" = "1" /* Drainage of Trachea with Drainage Device, Percutaneous Endoscopic Approach */
"0B914ZZ" = "1" /* Drainage of Trachea, Percutaneous Endoscopic Approach */
"0B9170Z" = "1" /* Drainage of Trachea with Drainage Device, Via Natural or Artificial Opening */
"0B917ZZ" = "1" /* Drainage of Trachea, Via Natural or Artificial Opening */
"0B9180Z" = "1" /* Drainage of Trachea with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B918ZZ" = "1" /* Drainage of Trachea, Via Natural or Artificial Opening Endoscopic */
"0B9200Z" = "1" /* Drainage of Carina with Drainage Device, Open Approach */
"0B920ZZ" = "1" /* Drainage of Carina, Open Approach */
"0B9230Z" = "1" /* Drainage of Carina with Drainage Device, Percutaneous Approach */
"0B923ZZ" = "1" /* Drainage of Carina, Percutaneous Approach */
"0B9240Z" = "1" /* Drainage of Carina with Drainage Device, Percutaneous Endoscopic Approach */
"0B924ZZ" = "1" /* Drainage of Carina, Percutaneous Endoscopic Approach */
"0B9270Z" = "1" /* Drainage of Carina with Drainage Device, Via Natural or Artificial Opening */
"0B927ZZ" = "1" /* Drainage of Carina, Via Natural or Artificial Opening */
"0B9280Z" = "1" /* Drainage of Carina with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B928ZZ" = "1" /* Drainage of Carina, Via Natural or Artificial Opening Endoscopic */
"0BB10ZZ" = "1" /* Excision of Trachea, Open Approach */
"0BB13ZZ" = "1" /* Excision of Trachea, Percutaneous Approach */
"0BB14ZZ" = "1" /* Excision of Trachea, Percutaneous Endoscopic Approach */
"0BB17ZZ" = "1" /* Excision of Trachea, Via Natural or Artificial Opening */
"0BB18ZZ" = "1" /* Excision of Trachea, Via Natural or Artificial Opening Endoscopic */
"0BB20ZZ" = "1" /* Excision of Carina, Open Approach */
"0BB23ZZ" = "1" /* Excision of Carina, Percutaneous Approach */
"0BB24ZZ" = "1" /* Excision of Carina, Percutaneous Endoscopic Approach */
"0BB27ZZ" = "1" /* Excision of Carina, Via Natural or Artificial Opening */
"0BB28ZZ" = "1" /* Excision of Carina, Via Natural or Artificial Opening Endoscopic */
"0BC10ZZ" = "1" /* Extirpation of Matter from Trachea, Open Approach */
"0BC13ZZ" = "1" /* Extirpation of Matter from Trachea, Percutaneous Approach */
"0BC14ZZ" = "1" /* Extirpation of Matter from Trachea, Percutaneous Endoscopic Approach */
"0BC20ZZ" = "1" /* Extirpation of Matter from Carina, Open Approach */
"0BC23ZZ" = "1" /* Extirpation of Matter from Carina, Percutaneous Approach */
"0BC24ZZ" = "1" /* Extirpation of Matter from Carina, Percutaneous Endoscopic Approach */
"0BF10ZZ" = "1" /* Fragmentation in Trachea, Open Approach */
"0BF13ZZ" = "1" /* Fragmentation in Trachea, Percutaneous Approach */
"0BF14ZZ" = "1" /* Fragmentation in Trachea, Percutaneous Endoscopic Approach */
"0BF17ZZ" = "1" /* Fragmentation in Trachea, Via Natural or Artificial Opening */
"0BF18ZZ" = "1" /* Fragmentation in Trachea, Via Natural or Artificial Opening Endoscopic */
"0BF20ZZ" = "1" /* Fragmentation in Carina, Open Approach */
"0BF23ZZ" = "1" /* Fragmentation in Carina, Percutaneous Approach */
"0BF24ZZ" = "1" /* Fragmentation in Carina, Percutaneous Endoscopic Approach */
"0BF27ZZ" = "1" /* Fragmentation in Carina, Via Natural or Artificial Opening */
"0BF28ZZ" = "1" /* Fragmentation in Carina, Via Natural or Artificial Opening Endoscopic */
"0BH102Z" = "1" /* Insertion of Monitoring Device into Trachea, Open Approach */
"0BH10DZ" = "1" /* Insertion of Intraluminal Device into Trachea, Open Approach */
"0BH13DZ" = "1" /* Insertion of Intraluminal Device into Trachea, Percutaneous Approach */
"0BH14DZ" = "1" /* Insertion of Intraluminal Device into Trachea, Percutaneous Endoscopic Approach */
"0BH172Z" = "1" /* Insertion of Monitoring Device into Trachea, Via Natural or Artificial Opening */
"0BH17DZ" = "1" /* Insertion of Intraluminal Device into Trachea, Via Natural or Artificial Opening */
"0BH182Z" = "1" /* Insertion of Monitoring Device into Trachea, Via Natural or Artificial Opening Endoscopic */
"0BH18DZ" = "1" /* Insertion of Intraluminal Device into Trachea, Via Natural or Artificial Opening Endoscopic */
"0BL10CZ" = "1" /* Occlusion of Trachea with Extraluminal Device, Open Approach */
"0BL10DZ" = "1" /* Occlusion of Trachea with Intraluminal Device, Open Approach */
"0BL10ZZ" = "1" /* Occlusion of Trachea, Open Approach */
"0BL13CZ" = "1" /* Occlusion of Trachea with Extraluminal Device, Percutaneous Approach */
"0BL13DZ" = "1" /* Occlusion of Trachea with Intraluminal Device, Percutaneous Approach */
"0BL13ZZ" = "1" /* Occlusion of Trachea, Percutaneous Approach */
"0BL14CZ" = "1" /* Occlusion of Trachea with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BL14DZ" = "1" /* Occlusion of Trachea with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BL14ZZ" = "1" /* Occlusion of Trachea, Percutaneous Endoscopic Approach */
"0BL17DZ" = "1" /* Occlusion of Trachea with Intraluminal Device, Via Natural or Artificial Opening */
"0BL17ZZ" = "1" /* Occlusion of Trachea, Via Natural or Artificial Opening */
"0BL18DZ" = "1" /* Occlusion of Trachea with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BL18ZZ" = "1" /* Occlusion of Trachea, Via Natural or Artificial Opening Endoscopic */
"0BL20CZ" = "1" /* Occlusion of Carina with Extraluminal Device, Open Approach */
"0BL20DZ" = "1" /* Occlusion of Carina with Intraluminal Device, Open Approach */
"0BL20ZZ" = "1" /* Occlusion of Carina, Open Approach */
"0BL23CZ" = "1" /* Occlusion of Carina with Extraluminal Device, Percutaneous Approach */
"0BL23DZ" = "1" /* Occlusion of Carina with Intraluminal Device, Percutaneous Approach */
"0BL23ZZ" = "1" /* Occlusion of Carina, Percutaneous Approach */
"0BL24CZ" = "1" /* Occlusion of Carina with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BL24DZ" = "1" /* Occlusion of Carina with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BL24ZZ" = "1" /* Occlusion of Carina, Percutaneous Endoscopic Approach */
"0BL27DZ" = "1" /* Occlusion of Carina with Intraluminal Device, Via Natural or Artificial Opening */
"0BL27ZZ" = "1" /* Occlusion of Carina, Via Natural or Artificial Opening */
"0BL28DZ" = "1" /* Occlusion of Carina with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BL28ZZ" = "1" /* Occlusion of Carina, Via Natural or Artificial Opening Endoscopic */
"0BM10ZZ" = "1" /* Reattachment of Trachea, Open Approach */
"0BM20ZZ" = "1" /* Reattachment of Carina, Open Approach */
"0BN10ZZ" = "1" /* Release Trachea, Open Approach */
"0BN13ZZ" = "1" /* Release Trachea, Percutaneous Approach */
"0BN14ZZ" = "1" /* Release Trachea, Percutaneous Endoscopic Approach */
"0BN17ZZ" = "1" /* Release Trachea, Via Natural or Artificial Opening */
"0BN18ZZ" = "1" /* Release Trachea, Via Natural or Artificial Opening Endoscopic */
"0BN20ZZ" = "1" /* Release Carina, Open Approach */
"0BN23ZZ" = "1" /* Release Carina, Percutaneous Approach */
"0BN24ZZ" = "1" /* Release Carina, Percutaneous Endoscopic Approach */
"0BN27ZZ" = "1" /* Release Carina, Via Natural or Artificial Opening */
"0BN28ZZ" = "1" /* Release Carina, Via Natural or Artificial Opening Endoscopic */
"0BP003Z" = "1" /* Removal of Infusion Device from Tracheobronchial Tree, Open Approach */
"0BP007Z" = "1" /* Removal of Autologous Tissue Substitute from Tracheobronchial Tree, Open Approach */
"0BP033Z" = "1" /* Removal of Infusion Device from Tracheobronchial Tree, Percutaneous Approach */
"0BP037Z" = "1" /* Removal of Autologous Tissue Substitute from Tracheobronchial Tree, Percutaneous Approach */
"0BP043Z" = "1" /* Removal of Infusion Device from Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BP047Z" = "1" /* Removal of Autologous Tissue Substitute from Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BP073Z" = "1" /* Removal of Infusion Device from Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BP077Z" = "1" /* Removal of Autologous Tissue Substitute from Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BP07CZ" = "1" /* Removal of Extraluminal Device from Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BP07JZ" = "1" /* Removal of Synthetic Substitute from Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BP07KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BP083Z" = "1" /* Removal of Infusion Device from Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BP087Z" = "1" /* Removal of Autologous Tissue Substitute from Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BP08CZ" = "1" /* Removal of Extraluminal Device from Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BP08JZ" = "1" /* Removal of Synthetic Substitute from Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BP08KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BP100Z" = "1" /* Removal of Drainage Device from Trachea, Open Approach */
"0BP102Z" = "1" /* Removal of Monitoring Device from Trachea, Open Approach */
"0BP107Z" = "1" /* Removal of Autologous Tissue Substitute from Trachea, Open Approach */
"0BP10CZ" = "1" /* Removal of Extraluminal Device from Trachea, Open Approach */
"0BP10DZ" = "1" /* Removal of Intraluminal Device from Trachea, Open Approach */
"0BP10FZ" = "1" /* Removal of Tracheostomy Device from Trachea, Open Approach */
"0BP10JZ" = "1" /* Removal of Synthetic Substitute from Trachea, Open Approach */
"0BP10KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Trachea, Open Approach */
"0BP130Z" = "1" /* Removal of Drainage Device from Trachea, Percutaneous Approach */
"0BP132Z" = "1" /* Removal of Monitoring Device from Trachea, Percutaneous Approach */
"0BP137Z" = "1" /* Removal of Autologous Tissue Substitute from Trachea, Percutaneous Approach */
"0BP13CZ" = "1" /* Removal of Extraluminal Device from Trachea, Percutaneous Approach */
"0BP13DZ" = "1" /* Removal of Intraluminal Device from Trachea, Percutaneous Approach */
"0BP13FZ" = "1" /* Removal of Tracheostomy Device from Trachea, Percutaneous Approach */
"0BP13JZ" = "1" /* Removal of Synthetic Substitute from Trachea, Percutaneous Approach */
"0BP13KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Trachea, Percutaneous Approach */
"0BP140Z" = "1" /* Removal of Drainage Device from Trachea, Percutaneous Endoscopic Approach */
"0BP142Z" = "1" /* Removal of Monitoring Device from Trachea, Percutaneous Endoscopic Approach */
"0BP147Z" = "1" /* Removal of Autologous Tissue Substitute from Trachea, Percutaneous Endoscopic Approach */
"0BP14CZ" = "1" /* Removal of Extraluminal Device from Trachea, Percutaneous Endoscopic Approach */
"0BP14DZ" = "1" /* Removal of Intraluminal Device from Trachea, Percutaneous Endoscopic Approach */
"0BP14FZ" = "1" /* Removal of Tracheostomy Device from Trachea, Percutaneous Endoscopic Approach */
"0BP14JZ" = "1" /* Removal of Synthetic Substitute from Trachea, Percutaneous Endoscopic Approach */
"0BP14KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Trachea, Percutaneous Endoscopic Approach */
"0BP170Z" = "1" /* Removal of Drainage Device from Trachea, Via Natural or Artificial Opening */
"0BP172Z" = "1" /* Removal of Monitoring Device from Trachea, Via Natural or Artificial Opening */
"0BP177Z" = "1" /* Removal of Autologous Tissue Substitute from Trachea, Via Natural or Artificial Opening */
"0BP17CZ" = "1" /* Removal of Extraluminal Device from Trachea, Via Natural or Artificial Opening */
"0BP17DZ" = "1" /* Removal of Intraluminal Device from Trachea, Via Natural or Artificial Opening */
"0BP17FZ" = "1" /* Removal of Tracheostomy Device from Trachea, Via Natural or Artificial Opening */
"0BP17JZ" = "1" /* Removal of Synthetic Substitute from Trachea, Via Natural or Artificial Opening */
"0BP17KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Trachea, Via Natural or Artificial Opening */
"0BP180Z" = "1" /* Removal of Drainage Device from Trachea, Via Natural or Artificial Opening Endoscopic */
"0BP182Z" = "1" /* Removal of Monitoring Device from Trachea, Via Natural or Artificial Opening Endoscopic */
"0BP187Z" = "1" /* Removal of Autologous Tissue Substitute from Trachea, Via Natural or Artificial Opening Endoscopic */
"0BP18CZ" = "1" /* Removal of Extraluminal Device from Trachea, Via Natural or Artificial Opening Endoscopic */
"0BP18DZ" = "1" /* Removal of Intraluminal Device from Trachea, Via Natural or Artificial Opening Endoscopic */
"0BP18FZ" = "1" /* Removal of Tracheostomy Device from Trachea, Via Natural or Artificial Opening Endoscopic */
"0BP18JZ" = "1" /* Removal of Synthetic Substitute from Trachea, Via Natural or Artificial Opening Endoscopic */
"0BP18KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Trachea, Via Natural or Artificial Opening Endoscopic */
"0BQ10ZZ" = "1" /* Repair Trachea, Open Approach */
"0BQ13ZZ" = "1" /* Repair Trachea, Percutaneous Approach */
"0BQ14ZZ" = "1" /* Repair Trachea, Percutaneous Endoscopic Approach */
"0BQ17ZZ" = "1" /* Repair Trachea, Via Natural or Artificial Opening */
"0BQ18ZZ" = "1" /* Repair Trachea, Via Natural or Artificial Opening Endoscopic */
"0BQ20ZZ" = "1" /* Repair Carina, Open Approach */
"0BQ23ZZ" = "1" /* Repair Carina, Percutaneous Approach */
"0BQ24ZZ" = "1" /* Repair Carina, Percutaneous Endoscopic Approach */
"0BQ27ZZ" = "1" /* Repair Carina, Via Natural or Artificial Opening */
"0BQ28ZZ" = "1" /* Repair Carina, Via Natural or Artificial Opening Endoscopic */
"0BS10ZZ" = "1" /* Reposition Trachea, Open Approach */
"0BS20ZZ" = "1" /* Reposition Carina, Open Approach */
"0BT10ZZ" = "1" /* Resection of Trachea, Open Approach */
"0BT14ZZ" = "1" /* Resection of Trachea, Percutaneous Endoscopic Approach */
"0BT20ZZ" = "1" /* Resection of Carina, Open Approach */
"0BT24ZZ" = "1" /* Resection of Carina, Percutaneous Endoscopic Approach */
"0BU107Z" = "1" /* Supplement Trachea with Autologous Tissue Substitute, Open Approach */
"0BU10JZ" = "1" /* Supplement Trachea with Synthetic Substitute, Open Approach */
"0BU10KZ" = "1" /* Supplement Trachea with Nonautologous Tissue Substitute, Open Approach */
"0BU147Z" = "1" /* Supplement Trachea with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU14JZ" = "1" /* Supplement Trachea with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BU14KZ" = "1" /* Supplement Trachea with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU207Z" = "1" /* Supplement Carina with Autologous Tissue Substitute, Open Approach */
"0BU20JZ" = "1" /* Supplement Carina with Synthetic Substitute, Open Approach */
"0BU20KZ" = "1" /* Supplement Carina with Nonautologous Tissue Substitute, Open Approach */
"0BU247Z" = "1" /* Supplement Carina with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU24JZ" = "1" /* Supplement Carina with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BU24KZ" = "1" /* Supplement Carina with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BV10CZ" = "1" /* Restriction of Trachea with Extraluminal Device, Open Approach */
"0BV10DZ" = "1" /* Restriction of Trachea with Intraluminal Device, Open Approach */
"0BV10ZZ" = "1" /* Restriction of Trachea, Open Approach */
"0BV13CZ" = "1" /* Restriction of Trachea with Extraluminal Device, Percutaneous Approach */
"0BV13DZ" = "1" /* Restriction of Trachea with Intraluminal Device, Percutaneous Approach */
"0BV13ZZ" = "1" /* Restriction of Trachea, Percutaneous Approach */
"0BV14CZ" = "1" /* Restriction of Trachea with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BV14DZ" = "1" /* Restriction of Trachea with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BV14ZZ" = "1" /* Restriction of Trachea, Percutaneous Endoscopic Approach */
"0BV17DZ" = "1" /* Restriction of Trachea with Intraluminal Device, Via Natural or Artificial Opening */
"0BV17ZZ" = "1" /* Restriction of Trachea, Via Natural or Artificial Opening */
"0BV18DZ" = "1" /* Restriction of Trachea with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BV18ZZ" = "1" /* Restriction of Trachea, Via Natural or Artificial Opening Endoscopic */
"0BV20CZ" = "1" /* Restriction of Carina with Extraluminal Device, Open Approach */
"0BV20DZ" = "1" /* Restriction of Carina with Intraluminal Device, Open Approach */
"0BV20ZZ" = "1" /* Restriction of Carina, Open Approach */
"0BV23CZ" = "1" /* Restriction of Carina with Extraluminal Device, Percutaneous Approach */
"0BV23DZ" = "1" /* Restriction of Carina with Intraluminal Device, Percutaneous Approach */
"0BV23ZZ" = "1" /* Restriction of Carina, Percutaneous Approach */
"0BV24CZ" = "1" /* Restriction of Carina with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BV24DZ" = "1" /* Restriction of Carina with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BV24ZZ" = "1" /* Restriction of Carina, Percutaneous Endoscopic Approach */
"0BV27DZ" = "1" /* Restriction of Carina with Intraluminal Device, Via Natural or Artificial Opening */
"0BV27ZZ" = "1" /* Restriction of Carina, Via Natural or Artificial Opening */
"0BV28DZ" = "1" /* Restriction of Carina with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BV28ZZ" = "1" /* Restriction of Carina, Via Natural or Artificial Opening Endoscopic */
"0BW003Z" = "1" /* Revision of Infusion Device in Tracheobronchial Tree, Open Approach */
"0BW007Z" = "1" /* Revision of Autologous Tissue Substitute in Tracheobronchial Tree, Open Approach */
"0BW033Z" = "1" /* Revision of Infusion Device in Tracheobronchial Tree, Percutaneous Approach */
"0BW037Z" = "1" /* Revision of Autologous Tissue Substitute in Tracheobronchial Tree, Percutaneous Approach */
"0BW043Z" = "1" /* Revision of Infusion Device in Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BW047Z" = "1" /* Revision of Autologous Tissue Substitute in Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BW073Z" = "1" /* Revision of Infusion Device in Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BW077Z" = "1" /* Revision of Autologous Tissue Substitute in Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BW07CZ" = "1" /* Revision of Extraluminal Device in Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BW07JZ" = "1" /* Revision of Synthetic Substitute in Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BW07KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BW083Z" = "1" /* Revision of Infusion Device in Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BW087Z" = "1" /* Revision of Autologous Tissue Substitute in Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BW08CZ" = "1" /* Revision of Extraluminal Device in Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BW08JZ" = "1" /* Revision of Synthetic Substitute in Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BW08KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BW100Z" = "1" /* Revision of Drainage Device in Trachea, Open Approach */
"0BW102Z" = "1" /* Revision of Monitoring Device in Trachea, Open Approach */
"0BW107Z" = "1" /* Revision of Autologous Tissue Substitute in Trachea, Open Approach */
"0BW10CZ" = "1" /* Revision of Extraluminal Device in Trachea, Open Approach */
"0BW10DZ" = "1" /* Revision of Intraluminal Device in Trachea, Open Approach */
"0BW10JZ" = "1" /* Revision of Synthetic Substitute in Trachea, Open Approach */
"0BW10KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Trachea, Open Approach */
"0BW130Z" = "1" /* Revision of Drainage Device in Trachea, Percutaneous Approach */
"0BW132Z" = "1" /* Revision of Monitoring Device in Trachea, Percutaneous Approach */
"0BW137Z" = "1" /* Revision of Autologous Tissue Substitute in Trachea, Percutaneous Approach */
"0BW13CZ" = "1" /* Revision of Extraluminal Device in Trachea, Percutaneous Approach */
"0BW13DZ" = "1" /* Revision of Intraluminal Device in Trachea, Percutaneous Approach */
"0BW13JZ" = "1" /* Revision of Synthetic Substitute in Trachea, Percutaneous Approach */
"0BW13KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Trachea, Percutaneous Approach */
"0BW140Z" = "1" /* Revision of Drainage Device in Trachea, Percutaneous Endoscopic Approach */
"0BW142Z" = "1" /* Revision of Monitoring Device in Trachea, Percutaneous Endoscopic Approach */
"0BW147Z" = "1" /* Revision of Autologous Tissue Substitute in Trachea, Percutaneous Endoscopic Approach */
"0BW14CZ" = "1" /* Revision of Extraluminal Device in Trachea, Percutaneous Endoscopic Approach */
"0BW14DZ" = "1" /* Revision of Intraluminal Device in Trachea, Percutaneous Endoscopic Approach */
"0BW14JZ" = "1" /* Revision of Synthetic Substitute in Trachea, Percutaneous Endoscopic Approach */
"0BW14KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Trachea, Percutaneous Endoscopic Approach */
"0BW170Z" = "1" /* Revision of Drainage Device in Trachea, Via Natural or Artificial Opening */
"0BW172Z" = "1" /* Revision of Monitoring Device in Trachea, Via Natural or Artificial Opening */
"0BW177Z" = "1" /* Revision of Autologous Tissue Substitute in Trachea, Via Natural or Artificial Opening */
"0BW17CZ" = "1" /* Revision of Extraluminal Device in Trachea, Via Natural or Artificial Opening */
"0BW17DZ" = "1" /* Revision of Intraluminal Device in Trachea, Via Natural or Artificial Opening */
"0BW17FZ" = "1" /* Revision of Tracheostomy Device in Trachea, Via Natural or Artificial Opening */
"0BW17JZ" = "1" /* Revision of Synthetic Substitute in Trachea, Via Natural or Artificial Opening */
"0BW17KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Trachea, Via Natural or Artificial Opening */
"0BW180Z" = "1" /* Revision of Drainage Device in Trachea, Via Natural or Artificial Opening Endoscopic */
"0BW182Z" = "1" /* Revision of Monitoring Device in Trachea, Via Natural or Artificial Opening Endoscopic */
"0BW187Z" = "1" /* Revision of Autologous Tissue Substitute in Trachea, Via Natural or Artificial Opening Endoscopic */
"0BW18CZ" = "1" /* Revision of Extraluminal Device in Trachea, Via Natural or Artificial Opening Endoscopic */
"0BW18DZ" = "1" /* Revision of Intraluminal Device in Trachea, Via Natural or Artificial Opening Endoscopic */
"0BW18FZ" = "1" /* Revision of Tracheostomy Device in Trachea, Via Natural or Artificial Opening Endoscopic */
"0BW18JZ" = "1" /* Revision of Synthetic Substitute in Trachea, Via Natural or Artificial Opening Endoscopic */
"0BW18KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Trachea, Via Natural or Artificial Opening Endoscopic */
"0C520ZZ" = "1" /* Destruction of Hard Palate, Open Approach */
"0C523ZZ" = "1" /* Destruction of Hard Palate, Percutaneous Approach */
"0C52XZZ" = "1" /* Destruction of Hard Palate, External Approach */
"0C530ZZ" = "1" /* Destruction of Soft Palate, Open Approach */
"0C533ZZ" = "1" /* Destruction of Soft Palate, Percutaneous Approach */
"0C53XZZ" = "1" /* Destruction of Soft Palate, External Approach */
"0C540ZZ" = "1" /* Destruction of Buccal Mucosa, Open Approach */
"0C570ZZ" = "1" /* Destruction of Tongue, Open Approach */
"0C573ZZ" = "1" /* Destruction of Tongue, Percutaneous Approach */
"0C57XZZ" = "1" /* Destruction of Tongue, External Approach */
"0C5M0ZZ" = "1" /* Destruction of Pharynx, Open Approach */
"0C5M3ZZ" = "1" /* Destruction of Pharynx, Percutaneous Approach */
"0C5M4ZZ" = "1" /* Destruction of Pharynx, Percutaneous Endoscopic Approach */
"0C5M7ZZ" = "1" /* Destruction of Pharynx, Via Natural or Artificial Opening */
"0C5M8ZZ" = "1" /* Destruction of Pharynx, Via Natural or Artificial Opening Endoscopic */
"0C5R0ZZ" = "1" /* Destruction of Epiglottis, Open Approach */
"0C5R3ZZ" = "1" /* Destruction of Epiglottis, Percutaneous Approach */
"0C5R4ZZ" = "1" /* Destruction of Epiglottis, Percutaneous Endoscopic Approach */
"0C5R7ZZ" = "1" /* Destruction of Epiglottis, Via Natural or Artificial Opening */
"0C5R8ZZ" = "1" /* Destruction of Epiglottis, Via Natural or Artificial Opening Endoscopic */
"0C5S0ZZ" = "1" /* Destruction of Larynx, Open Approach */
"0C5S3ZZ" = "1" /* Destruction of Larynx, Percutaneous Approach */
"0C5S4ZZ" = "1" /* Destruction of Larynx, Percutaneous Endoscopic Approach */
"0C5S7ZZ" = "1" /* Destruction of Larynx, Via Natural or Artificial Opening */
"0C5S8ZZ" = "1" /* Destruction of Larynx, Via Natural or Artificial Opening Endoscopic */
"0C5T0ZZ" = "1" /* Destruction of Right Vocal Cord, Open Approach */
"0C5T3ZZ" = "1" /* Destruction of Right Vocal Cord, Percutaneous Approach */
"0C5T4ZZ" = "1" /* Destruction of Right Vocal Cord, Percutaneous Endoscopic Approach */
"0C5T7ZZ" = "1" /* Destruction of Right Vocal Cord, Via Natural or Artificial Opening */
"0C5T8ZZ" = "1" /* Destruction of Right Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0C5V0ZZ" = "1" /* Destruction of Left Vocal Cord, Open Approach */
"0C5V3ZZ" = "1" /* Destruction of Left Vocal Cord, Percutaneous Approach */
"0C5V4ZZ" = "1" /* Destruction of Left Vocal Cord, Percutaneous Endoscopic Approach */
"0C5V7ZZ" = "1" /* Destruction of Left Vocal Cord, Via Natural or Artificial Opening */
"0C5V8ZZ" = "1" /* Destruction of Left Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0C7M7DZ" = "1" /* Dilation of Pharynx with Intraluminal Device, Via Natural or Artificial Opening */
"0C7M7ZZ" = "1" /* Dilation of Pharynx, Via Natural or Artificial Opening */
"0C7M8DZ" = "1" /* Dilation of Pharynx with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0C7M8ZZ" = "1" /* Dilation of Pharynx, Via Natural or Artificial Opening Endoscopic */
"0C7S0DZ" = "1" /* Dilation of Larynx with Intraluminal Device, Open Approach */
"0C7S0ZZ" = "1" /* Dilation of Larynx, Open Approach */
"0C7S3DZ" = "1" /* Dilation of Larynx with Intraluminal Device, Percutaneous Approach */
"0C7S3ZZ" = "1" /* Dilation of Larynx, Percutaneous Approach */
"0C7S4DZ" = "1" /* Dilation of Larynx with Intraluminal Device, Percutaneous Endoscopic Approach */
"0C7S4ZZ" = "1" /* Dilation of Larynx, Percutaneous Endoscopic Approach */
"0C7S7DZ" = "1" /* Dilation of Larynx with Intraluminal Device, Via Natural or Artificial Opening */
"0C7S7ZZ" = "1" /* Dilation of Larynx, Via Natural or Artificial Opening */
"0C7S8DZ" = "1" /* Dilation of Larynx with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0C7S8ZZ" = "1" /* Dilation of Larynx, Via Natural or Artificial Opening Endoscopic */
"0C9200Z" = "1" /* Drainage of Hard Palate with Drainage Device, Open Approach */
"0C920ZZ" = "1" /* Drainage of Hard Palate, Open Approach */
"0C9300Z" = "1" /* Drainage of Soft Palate with Drainage Device, Open Approach */
"0C930ZZ" = "1" /* Drainage of Soft Palate, Open Approach */
"0C9330Z" = "1" /* Drainage of Soft Palate with Drainage Device, Percutaneous Approach */
"0C933ZZ" = "1" /* Drainage of Soft Palate, Percutaneous Approach */
"0C93X0Z" = "1" /* Drainage of Soft Palate with Drainage Device, External Approach */
"0C93XZZ" = "1" /* Drainage of Soft Palate, External Approach */
"0C9400Z" = "1" /* Drainage of Buccal Mucosa with Drainage Device, Open Approach */
"0C940ZZ" = "1" /* Drainage of Buccal Mucosa, Open Approach */
"0C9700Z" = "1" /* Drainage of Tongue with Drainage Device, Open Approach */
"0C970ZZ" = "1" /* Drainage of Tongue, Open Approach */
"0C9730Z" = "1" /* Drainage of Tongue with Drainage Device, Percutaneous Approach */
"0C973ZZ" = "1" /* Drainage of Tongue, Percutaneous Approach */
"0C97X0Z" = "1" /* Drainage of Tongue with Drainage Device, External Approach */
"0C97XZZ" = "1" /* Drainage of Tongue, External Approach */
"0C9M00Z" = "1" /* Drainage of Pharynx with Drainage Device, Open Approach */
"0C9M0ZZ" = "1" /* Drainage of Pharynx, Open Approach */
"0C9M30Z" = "1" /* Drainage of Pharynx with Drainage Device, Percutaneous Approach */
"0C9M3ZZ" = "1" /* Drainage of Pharynx, Percutaneous Approach */
"0C9M40Z" = "1" /* Drainage of Pharynx with Drainage Device, Percutaneous Endoscopic Approach */
"0C9M4ZZ" = "1" /* Drainage of Pharynx, Percutaneous Endoscopic Approach */
"0C9M70Z" = "1" /* Drainage of Pharynx with Drainage Device, Via Natural or Artificial Opening */
"0C9M7ZZ" = "1" /* Drainage of Pharynx, Via Natural or Artificial Opening */
"0C9M80Z" = "1" /* Drainage of Pharynx with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0C9M8ZZ" = "1" /* Drainage of Pharynx, Via Natural or Artificial Opening Endoscopic */
"0C9R00Z" = "1" /* Drainage of Epiglottis with Drainage Device, Open Approach */
"0C9R0ZZ" = "1" /* Drainage of Epiglottis, Open Approach */
"0C9R30Z" = "1" /* Drainage of Epiglottis with Drainage Device, Percutaneous Approach */
"0C9R3ZZ" = "1" /* Drainage of Epiglottis, Percutaneous Approach */
"0C9R40Z" = "1" /* Drainage of Epiglottis with Drainage Device, Percutaneous Endoscopic Approach */
"0C9R4ZZ" = "1" /* Drainage of Epiglottis, Percutaneous Endoscopic Approach */
"0C9R70Z" = "1" /* Drainage of Epiglottis with Drainage Device, Via Natural or Artificial Opening */
"0C9R7ZZ" = "1" /* Drainage of Epiglottis, Via Natural or Artificial Opening */
"0C9R80Z" = "1" /* Drainage of Epiglottis with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0C9R8ZZ" = "1" /* Drainage of Epiglottis, Via Natural or Artificial Opening Endoscopic */
"0C9S00Z" = "1" /* Drainage of Larynx with Drainage Device, Open Approach */
"0C9S0ZZ" = "1" /* Drainage of Larynx, Open Approach */
"0C9S30Z" = "1" /* Drainage of Larynx with Drainage Device, Percutaneous Approach */
"0C9S3ZZ" = "1" /* Drainage of Larynx, Percutaneous Approach */
"0C9S40Z" = "1" /* Drainage of Larynx with Drainage Device, Percutaneous Endoscopic Approach */
"0C9S4ZZ" = "1" /* Drainage of Larynx, Percutaneous Endoscopic Approach */
"0C9S70Z" = "1" /* Drainage of Larynx with Drainage Device, Via Natural or Artificial Opening */
"0C9S7ZZ" = "1" /* Drainage of Larynx, Via Natural or Artificial Opening */
"0C9S80Z" = "1" /* Drainage of Larynx with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0C9S8ZZ" = "1" /* Drainage of Larynx, Via Natural or Artificial Opening Endoscopic */
"0C9T00Z" = "1" /* Drainage of Right Vocal Cord with Drainage Device, Open Approach */
"0C9T0ZZ" = "1" /* Drainage of Right Vocal Cord, Open Approach */
"0C9T30Z" = "1" /* Drainage of Right Vocal Cord with Drainage Device, Percutaneous Approach */
"0C9T3ZZ" = "1" /* Drainage of Right Vocal Cord, Percutaneous Approach */
"0C9T40Z" = "1" /* Drainage of Right Vocal Cord with Drainage Device, Percutaneous Endoscopic Approach */
"0C9T4ZZ" = "1" /* Drainage of Right Vocal Cord, Percutaneous Endoscopic Approach */
"0C9T70Z" = "1" /* Drainage of Right Vocal Cord with Drainage Device, Via Natural or Artificial Opening */
"0C9T7ZZ" = "1" /* Drainage of Right Vocal Cord, Via Natural or Artificial Opening */
"0C9T80Z" = "1" /* Drainage of Right Vocal Cord with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0C9T8ZZ" = "1" /* Drainage of Right Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0C9V00Z" = "1" /* Drainage of Left Vocal Cord with Drainage Device, Open Approach */
"0C9V0ZZ" = "1" /* Drainage of Left Vocal Cord, Open Approach */
"0C9V30Z" = "1" /* Drainage of Left Vocal Cord with Drainage Device, Percutaneous Approach */
"0C9V3ZZ" = "1" /* Drainage of Left Vocal Cord, Percutaneous Approach */
"0C9V40Z" = "1" /* Drainage of Left Vocal Cord with Drainage Device, Percutaneous Endoscopic Approach */
"0C9V4ZZ" = "1" /* Drainage of Left Vocal Cord, Percutaneous Endoscopic Approach */
"0C9V70Z" = "1" /* Drainage of Left Vocal Cord with Drainage Device, Via Natural or Artificial Opening */
"0C9V7ZZ" = "1" /* Drainage of Left Vocal Cord, Via Natural or Artificial Opening */
"0C9V80Z" = "1" /* Drainage of Left Vocal Cord with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0C9V8ZZ" = "1" /* Drainage of Left Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CB20ZZ" = "1" /* Excision of Hard Palate, Open Approach */
"0CB23ZZ" = "1" /* Excision of Hard Palate, Percutaneous Approach */
"0CB30ZZ" = "1" /* Excision of Soft Palate, Open Approach */
"0CB33ZZ" = "1" /* Excision of Soft Palate, Percutaneous Approach */
"0CB3XZZ" = "1" /* Excision of Soft Palate, External Approach */
"0CB40ZZ" = "1" /* Excision of Buccal Mucosa, Open Approach */
"0CB70ZZ" = "1" /* Excision of Tongue, Open Approach */
"0CB73ZZ" = "1" /* Excision of Tongue, Percutaneous Approach */
"0CBM0ZZ" = "1" /* Excision of Pharynx, Open Approach */
"0CBM3ZZ" = "1" /* Excision of Pharynx, Percutaneous Approach */
"0CBM4ZZ" = "1" /* Excision of Pharynx, Percutaneous Endoscopic Approach */
"0CBM7ZZ" = "1" /* Excision of Pharynx, Via Natural or Artificial Opening */
"0CBM8ZZ" = "1" /* Excision of Pharynx, Via Natural or Artificial Opening Endoscopic */
"0CBR0ZZ" = "1" /* Excision of Epiglottis, Open Approach */
"0CBR3ZZ" = "1" /* Excision of Epiglottis, Percutaneous Approach */
"0CBR4ZZ" = "1" /* Excision of Epiglottis, Percutaneous Endoscopic Approach */
"0CBR7ZZ" = "1" /* Excision of Epiglottis, Via Natural or Artificial Opening */
"0CBR8ZZ" = "1" /* Excision of Epiglottis, Via Natural or Artificial Opening Endoscopic */
"0CBS0ZZ" = "1" /* Excision of Larynx, Open Approach */
"0CBS3ZZ" = "1" /* Excision of Larynx, Percutaneous Approach */
"0CBS4ZZ" = "1" /* Excision of Larynx, Percutaneous Endoscopic Approach */
"0CBS7ZZ" = "1" /* Excision of Larynx, Via Natural or Artificial Opening */
"0CBS8ZZ" = "1" /* Excision of Larynx, Via Natural or Artificial Opening Endoscopic */
"0CBT0ZZ" = "1" /* Excision of Right Vocal Cord, Open Approach */
"0CBT3ZZ" = "1" /* Excision of Right Vocal Cord, Percutaneous Approach */
"0CBT4ZZ" = "1" /* Excision of Right Vocal Cord, Percutaneous Endoscopic Approach */
"0CBT7ZZ" = "1" /* Excision of Right Vocal Cord, Via Natural or Artificial Opening */
"0CBT8ZZ" = "1" /* Excision of Right Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CBV0ZZ" = "1" /* Excision of Left Vocal Cord, Open Approach */
"0CBV3ZZ" = "1" /* Excision of Left Vocal Cord, Percutaneous Approach */
"0CBV4ZZ" = "1" /* Excision of Left Vocal Cord, Percutaneous Endoscopic Approach */
"0CBV7ZZ" = "1" /* Excision of Left Vocal Cord, Via Natural or Artificial Opening */
"0CBV8ZZ" = "1" /* Excision of Left Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CC20ZZ" = "1" /* Extirpation of Matter from Hard Palate, Open Approach */
"0CC23ZZ" = "1" /* Extirpation of Matter from Hard Palate, Percutaneous Approach */
"0CC30ZZ" = "1" /* Extirpation of Matter from Soft Palate, Open Approach */
"0CC33ZZ" = "1" /* Extirpation of Matter from Soft Palate, Percutaneous Approach */
"0CC40ZZ" = "1" /* Extirpation of Matter from Buccal Mucosa, Open Approach */
"0CC70ZZ" = "1" /* Extirpation of Matter from Tongue, Open Approach */
"0CC73ZZ" = "1" /* Extirpation of Matter from Tongue, Percutaneous Approach */
"0CCM0ZZ" = "1" /* Extirpation of Matter from Pharynx, Open Approach */
"0CCM3ZZ" = "1" /* Extirpation of Matter from Pharynx, Percutaneous Approach */
"0CCM4ZZ" = "1" /* Extirpation of Matter from Pharynx, Percutaneous Endoscopic Approach */
"0CCR0ZZ" = "1" /* Extirpation of Matter from Epiglottis, Open Approach */
"0CCR3ZZ" = "1" /* Extirpation of Matter from Epiglottis, Percutaneous Approach */
"0CCR4ZZ" = "1" /* Extirpation of Matter from Epiglottis, Percutaneous Endoscopic Approach */
"0CCR7ZZ" = "1" /* Extirpation of Matter from Epiglottis, Via Natural or Artificial Opening */
"0CCR8ZZ" = "1" /* Extirpation of Matter from Epiglottis, Via Natural or Artificial Opening Endoscopic */
"0CCS0ZZ" = "1" /* Extirpation of Matter from Larynx, Open Approach */
"0CCS3ZZ" = "1" /* Extirpation of Matter from Larynx, Percutaneous Approach */
"0CCS4ZZ" = "1" /* Extirpation of Matter from Larynx, Percutaneous Endoscopic Approach */
"0CCT0ZZ" = "1" /* Extirpation of Matter from Right Vocal Cord, Open Approach */
"0CCT3ZZ" = "1" /* Extirpation of Matter from Right Vocal Cord, Percutaneous Approach */
"0CCT4ZZ" = "1" /* Extirpation of Matter from Right Vocal Cord, Percutaneous Endoscopic Approach */
"0CCT7ZZ" = "1" /* Extirpation of Matter from Right Vocal Cord, Via Natural or Artificial Opening */
"0CCT8ZZ" = "1" /* Extirpation of Matter from Right Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CCV0ZZ" = "1" /* Extirpation of Matter from Left Vocal Cord, Open Approach */
"0CCV3ZZ" = "1" /* Extirpation of Matter from Left Vocal Cord, Percutaneous Approach */
"0CCV4ZZ" = "1" /* Extirpation of Matter from Left Vocal Cord, Percutaneous Endoscopic Approach */
"0CCV7ZZ" = "1" /* Extirpation of Matter from Left Vocal Cord, Via Natural or Artificial Opening */
"0CCV8ZZ" = "1" /* Extirpation of Matter from Left Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CDT0ZZ" = "1" /* Extraction of Right Vocal Cord, Open Approach */
"0CDT3ZZ" = "1" /* Extraction of Right Vocal Cord, Percutaneous Approach */
"0CDT4ZZ" = "1" /* Extraction of Right Vocal Cord, Percutaneous Endoscopic Approach */
"0CDT7ZZ" = "1" /* Extraction of Right Vocal Cord, Via Natural or Artificial Opening */
"0CDT8ZZ" = "1" /* Extraction of Right Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CDV0ZZ" = "1" /* Extraction of Left Vocal Cord, Open Approach */
"0CDV3ZZ" = "1" /* Extraction of Left Vocal Cord, Percutaneous Approach */
"0CDV4ZZ" = "1" /* Extraction of Left Vocal Cord, Percutaneous Endoscopic Approach */
"0CDV7ZZ" = "1" /* Extraction of Left Vocal Cord, Via Natural or Artificial Opening */
"0CDV8ZZ" = "1" /* Extraction of Left Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CM30ZZ" = "1" /* Reattachment of Soft Palate, Open Approach */
"0CM70ZZ" = "1" /* Reattachment of Tongue, Open Approach */
"0CMN0ZZ" = "1" /* Reattachment of Uvula, Open Approach */
"0CN20ZZ" = "1" /* Release Hard Palate, Open Approach */
"0CN23ZZ" = "1" /* Release Hard Palate, Percutaneous Approach */
"0CN2XZZ" = "1" /* Release Hard Palate, External Approach */
"0CN30ZZ" = "1" /* Release Soft Palate, Open Approach */
"0CN33ZZ" = "1" /* Release Soft Palate, Percutaneous Approach */
"0CN3XZZ" = "1" /* Release Soft Palate, External Approach */
"0CN40ZZ" = "1" /* Release Buccal Mucosa, Open Approach */
"0CNM0ZZ" = "1" /* Release Pharynx, Open Approach */
"0CNM3ZZ" = "1" /* Release Pharynx, Percutaneous Approach */
"0CNM4ZZ" = "1" /* Release Pharynx, Percutaneous Endoscopic Approach */
"0CNM7ZZ" = "1" /* Release Pharynx, Via Natural or Artificial Opening */
"0CNM8ZZ" = "1" /* Release Pharynx, Via Natural or Artificial Opening Endoscopic */
"0CNR0ZZ" = "1" /* Release Epiglottis, Open Approach */
"0CNR3ZZ" = "1" /* Release Epiglottis, Percutaneous Approach */
"0CNR4ZZ" = "1" /* Release Epiglottis, Percutaneous Endoscopic Approach */
"0CNR7ZZ" = "1" /* Release Epiglottis, Via Natural or Artificial Opening */
"0CNR8ZZ" = "1" /* Release Epiglottis, Via Natural or Artificial Opening Endoscopic */
"0CNS0ZZ" = "1" /* Release Larynx, Open Approach */
"0CNS3ZZ" = "1" /* Release Larynx, Percutaneous Approach */
"0CNS4ZZ" = "1" /* Release Larynx, Percutaneous Endoscopic Approach */
"0CNS7ZZ" = "1" /* Release Larynx, Via Natural or Artificial Opening */
"0CNS8ZZ" = "1" /* Release Larynx, Via Natural or Artificial Opening Endoscopic */
"0CNT0ZZ" = "1" /* Release Right Vocal Cord, Open Approach */
"0CNT3ZZ" = "1" /* Release Right Vocal Cord, Percutaneous Approach */
"0CNT4ZZ" = "1" /* Release Right Vocal Cord, Percutaneous Endoscopic Approach */
"0CNT7ZZ" = "1" /* Release Right Vocal Cord, Via Natural or Artificial Opening */
"0CNT8ZZ" = "1" /* Release Right Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CNV0ZZ" = "1" /* Release Left Vocal Cord, Open Approach */
"0CNV3ZZ" = "1" /* Release Left Vocal Cord, Percutaneous Approach */
"0CNV4ZZ" = "1" /* Release Left Vocal Cord, Percutaneous Endoscopic Approach */
"0CNV7ZZ" = "1" /* Release Left Vocal Cord, Via Natural or Artificial Opening */
"0CNV8ZZ" = "1" /* Release Left Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CPS00Z" = "1" /* Removal of Drainage Device from Larynx, Open Approach */
"0CPS07Z" = "1" /* Removal of Autologous Tissue Substitute from Larynx, Open Approach */
"0CPS0DZ" = "1" /* Removal of Intraluminal Device from Larynx, Open Approach */
"0CPS0JZ" = "1" /* Removal of Synthetic Substitute from Larynx, Open Approach */
"0CPS0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Larynx, Open Approach */
"0CPS30Z" = "1" /* Removal of Drainage Device from Larynx, Percutaneous Approach */
"0CPS37Z" = "1" /* Removal of Autologous Tissue Substitute from Larynx, Percutaneous Approach */
"0CPS3DZ" = "1" /* Removal of Intraluminal Device from Larynx, Percutaneous Approach */
"0CPS3JZ" = "1" /* Removal of Synthetic Substitute from Larynx, Percutaneous Approach */
"0CPS3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Larynx, Percutaneous Approach */
"0CPS70Z" = "1" /* Removal of Drainage Device from Larynx, Via Natural or Artificial Opening */
"0CPS77Z" = "1" /* Removal of Autologous Tissue Substitute from Larynx, Via Natural or Artificial Opening */
"0CPS7DZ" = "1" /* Removal of Intraluminal Device from Larynx, Via Natural or Artificial Opening */
"0CPS7JZ" = "1" /* Removal of Synthetic Substitute from Larynx, Via Natural or Artificial Opening */
"0CPS7KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Larynx, Via Natural or Artificial Opening */
"0CPS80Z" = "1" /* Removal of Drainage Device from Larynx, Via Natural or Artificial Opening Endoscopic */
"0CPS87Z" = "1" /* Removal of Autologous Tissue Substitute from Larynx, Via Natural or Artificial Opening Endoscopic */
"0CPS8DZ" = "1" /* Removal of Intraluminal Device from Larynx, Via Natural or Artificial Opening Endoscopic */
"0CPS8JZ" = "1" /* Removal of Synthetic Substitute from Larynx, Via Natural or Artificial Opening Endoscopic */
"0CPS8KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Larynx, Via Natural or Artificial Opening Endoscopic */
"0CQ20ZZ" = "1" /* Repair Hard Palate, Open Approach */
"0CQ23ZZ" = "1" /* Repair Hard Palate, Percutaneous Approach */
"0CQ30ZZ" = "1" /* Repair Soft Palate, Open Approach */
"0CQ33ZZ" = "1" /* Repair Soft Palate, Percutaneous Approach */
"0CQ3XZZ" = "1" /* Repair Soft Palate, External Approach */
"0CQ40ZZ" = "1" /* Repair Buccal Mucosa, Open Approach */
"0CQ70ZZ" = "1" /* Repair Tongue, Open Approach */
"0CQ73ZZ" = "1" /* Repair Tongue, Percutaneous Approach */
"0CQM0ZZ" = "1" /* Repair Pharynx, Open Approach */
"0CQM3ZZ" = "1" /* Repair Pharynx, Percutaneous Approach */
"0CQM4ZZ" = "1" /* Repair Pharynx, Percutaneous Endoscopic Approach */
"0CQM7ZZ" = "1" /* Repair Pharynx, Via Natural or Artificial Opening */
"0CQM8ZZ" = "1" /* Repair Pharynx, Via Natural or Artificial Opening Endoscopic */
"0CQR0ZZ" = "1" /* Repair Epiglottis, Open Approach */
"0CQR3ZZ" = "1" /* Repair Epiglottis, Percutaneous Approach */
"0CQR4ZZ" = "1" /* Repair Epiglottis, Percutaneous Endoscopic Approach */
"0CQR7ZZ" = "1" /* Repair Epiglottis, Via Natural or Artificial Opening */
"0CQR8ZZ" = "1" /* Repair Epiglottis, Via Natural or Artificial Opening Endoscopic */
"0CQS0ZZ" = "1" /* Repair Larynx, Open Approach */
"0CQS3ZZ" = "1" /* Repair Larynx, Percutaneous Approach */
"0CQS4ZZ" = "1" /* Repair Larynx, Percutaneous Endoscopic Approach */
"0CQS7ZZ" = "1" /* Repair Larynx, Via Natural or Artificial Opening */
"0CQS8ZZ" = "1" /* Repair Larynx, Via Natural or Artificial Opening Endoscopic */
"0CQT0ZZ" = "1" /* Repair Right Vocal Cord, Open Approach */
"0CQT3ZZ" = "1" /* Repair Right Vocal Cord, Percutaneous Approach */
"0CQT4ZZ" = "1" /* Repair Right Vocal Cord, Percutaneous Endoscopic Approach */
"0CQT7ZZ" = "1" /* Repair Right Vocal Cord, Via Natural or Artificial Opening */
"0CQT8ZZ" = "1" /* Repair Right Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CQV0ZZ" = "1" /* Repair Left Vocal Cord, Open Approach */
"0CQV3ZZ" = "1" /* Repair Left Vocal Cord, Percutaneous Approach */
"0CQV4ZZ" = "1" /* Repair Left Vocal Cord, Percutaneous Endoscopic Approach */
"0CQV7ZZ" = "1" /* Repair Left Vocal Cord, Via Natural or Artificial Opening */
"0CQV8ZZ" = "1" /* Repair Left Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CR007Z" = "1" /* Replacement of Upper Lip with Autologous Tissue Substitute, Open Approach */
"0CR107Z" = "1" /* Replacement of Lower Lip with Autologous Tissue Substitute, Open Approach */
"0CR207Z" = "1" /* Replacement of Hard Palate with Autologous Tissue Substitute, Open Approach */
"0CR20JZ" = "1" /* Replacement of Hard Palate with Synthetic Substitute, Open Approach */
"0CR20KZ" = "1" /* Replacement of Hard Palate with Nonautologous Tissue Substitute, Open Approach */
"0CR237Z" = "1" /* Replacement of Hard Palate with Autologous Tissue Substitute, Percutaneous Approach */
"0CR23JZ" = "1" /* Replacement of Hard Palate with Synthetic Substitute, Percutaneous Approach */
"0CR23KZ" = "1" /* Replacement of Hard Palate with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CR2X7Z" = "1" /* Replacement of Hard Palate with Autologous Tissue Substitute, External Approach */
"0CR2XJZ" = "1" /* Replacement of Hard Palate with Synthetic Substitute, External Approach */
"0CR2XKZ" = "1" /* Replacement of Hard Palate with Nonautologous Tissue Substitute, External Approach */
"0CR307Z" = "1" /* Replacement of Soft Palate with Autologous Tissue Substitute, Open Approach */
"0CR30JZ" = "1" /* Replacement of Soft Palate with Synthetic Substitute, Open Approach */
"0CR30KZ" = "1" /* Replacement of Soft Palate with Nonautologous Tissue Substitute, Open Approach */
"0CR337Z" = "1" /* Replacement of Soft Palate with Autologous Tissue Substitute, Percutaneous Approach */
"0CR33JZ" = "1" /* Replacement of Soft Palate with Synthetic Substitute, Percutaneous Approach */
"0CR33KZ" = "1" /* Replacement of Soft Palate with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CR3X7Z" = "1" /* Replacement of Soft Palate with Autologous Tissue Substitute, External Approach */
"0CR3XJZ" = "1" /* Replacement of Soft Palate with Synthetic Substitute, External Approach */
"0CR3XKZ" = "1" /* Replacement of Soft Palate with Nonautologous Tissue Substitute, External Approach */
"0CR407Z" = "1" /* Replacement of Buccal Mucosa with Autologous Tissue Substitute, Open Approach */
"0CR40JZ" = "1" /* Replacement of Buccal Mucosa with Synthetic Substitute, Open Approach */
"0CR40KZ" = "1" /* Replacement of Buccal Mucosa with Nonautologous Tissue Substitute, Open Approach */
"0CR4X7Z" = "1" /* Replacement of Buccal Mucosa with Autologous Tissue Substitute, External Approach */
"0CR4XJZ" = "1" /* Replacement of Buccal Mucosa with Synthetic Substitute, External Approach */
"0CR4XKZ" = "1" /* Replacement of Buccal Mucosa with Nonautologous Tissue Substitute, External Approach */
"0CR707Z" = "1" /* Replacement of Tongue with Autologous Tissue Substitute, Open Approach */
"0CR70JZ" = "1" /* Replacement of Tongue with Synthetic Substitute, Open Approach */
"0CR70KZ" = "1" /* Replacement of Tongue with Nonautologous Tissue Substitute, Open Approach */
"0CR737Z" = "1" /* Replacement of Tongue with Autologous Tissue Substitute, Percutaneous Approach */
"0CR73JZ" = "1" /* Replacement of Tongue with Synthetic Substitute, Percutaneous Approach */
"0CR73KZ" = "1" /* Replacement of Tongue with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CR7X7Z" = "1" /* Replacement of Tongue with Autologous Tissue Substitute, External Approach */
"0CR7XJZ" = "1" /* Replacement of Tongue with Synthetic Substitute, External Approach */
"0CR7XKZ" = "1" /* Replacement of Tongue with Nonautologous Tissue Substitute, External Approach */
"0CRM07Z" = "1" /* Replacement of Pharynx with Autologous Tissue Substitute, Open Approach */
"0CRM0JZ" = "1" /* Replacement of Pharynx with Synthetic Substitute, Open Approach */
"0CRM0KZ" = "1" /* Replacement of Pharynx with Nonautologous Tissue Substitute, Open Approach */
"0CRM77Z" = "1" /* Replacement of Pharynx with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0CRM7JZ" = "1" /* Replacement of Pharynx with Synthetic Substitute, Via Natural or Artificial Opening */
"0CRM7KZ" = "1" /* Replacement of Pharynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0CRM87Z" = "1" /* Replacement of Pharynx with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRM8JZ" = "1" /* Replacement of Pharynx with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRM8KZ" = "1" /* Replacement of Pharynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRN07Z" = "1" /* Replacement of Uvula with Autologous Tissue Substitute, Open Approach */
"0CRN0JZ" = "1" /* Replacement of Uvula with Synthetic Substitute, Open Approach */
"0CRN0KZ" = "1" /* Replacement of Uvula with Nonautologous Tissue Substitute, Open Approach */
"0CRN37Z" = "1" /* Replacement of Uvula with Autologous Tissue Substitute, Percutaneous Approach */
"0CRN3JZ" = "1" /* Replacement of Uvula with Synthetic Substitute, Percutaneous Approach */
"0CRN3KZ" = "1" /* Replacement of Uvula with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CRNX7Z" = "1" /* Replacement of Uvula with Autologous Tissue Substitute, External Approach */
"0CRNXJZ" = "1" /* Replacement of Uvula with Synthetic Substitute, External Approach */
"0CRNXKZ" = "1" /* Replacement of Uvula with Nonautologous Tissue Substitute, External Approach */
"0CRR07Z" = "1" /* Replacement of Epiglottis with Autologous Tissue Substitute, Open Approach */
"0CRR0JZ" = "1" /* Replacement of Epiglottis with Synthetic Substitute, Open Approach */
"0CRR0KZ" = "1" /* Replacement of Epiglottis with Nonautologous Tissue Substitute, Open Approach */
"0CRR77Z" = "1" /* Replacement of Epiglottis with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0CRR7JZ" = "1" /* Replacement of Epiglottis with Synthetic Substitute, Via Natural or Artificial Opening */
"0CRR7KZ" = "1" /* Replacement of Epiglottis with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0CRR87Z" = "1" /* Replacement of Epiglottis with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRR8JZ" = "1" /* Replacement of Epiglottis with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRR8KZ" = "1" /* Replacement of Epiglottis with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRS07Z" = "1" /* Replacement of Larynx with Autologous Tissue Substitute, Open Approach */
"0CRS0JZ" = "1" /* Replacement of Larynx with Synthetic Substitute, Open Approach */
"0CRS0KZ" = "1" /* Replacement of Larynx with Nonautologous Tissue Substitute, Open Approach */
"0CRS77Z" = "1" /* Replacement of Larynx with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0CRS7JZ" = "1" /* Replacement of Larynx with Synthetic Substitute, Via Natural or Artificial Opening */
"0CRS7KZ" = "1" /* Replacement of Larynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0CRS87Z" = "1" /* Replacement of Larynx with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRS8JZ" = "1" /* Replacement of Larynx with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRS8KZ" = "1" /* Replacement of Larynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRT07Z" = "1" /* Replacement of Right Vocal Cord with Autologous Tissue Substitute, Open Approach */
"0CRT0JZ" = "1" /* Replacement of Right Vocal Cord with Synthetic Substitute, Open Approach */
"0CRT0KZ" = "1" /* Replacement of Right Vocal Cord with Nonautologous Tissue Substitute, Open Approach */
"0CRT77Z" = "1" /* Replacement of Right Vocal Cord with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0CRT7JZ" = "1" /* Replacement of Right Vocal Cord with Synthetic Substitute, Via Natural or Artificial Opening */
"0CRT7KZ" = "1" /* Replacement of Right Vocal Cord with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0CRT87Z" = "1" /* Replacement of Right Vocal Cord with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRT8JZ" = "1" /* Replacement of Right Vocal Cord with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRT8KZ" = "1" /* Replacement of Right Vocal Cord with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRV07Z" = "1" /* Replacement of Left Vocal Cord with Autologous Tissue Substitute, Open Approach */
"0CRV0JZ" = "1" /* Replacement of Left Vocal Cord with Synthetic Substitute, Open Approach */
"0CRV0KZ" = "1" /* Replacement of Left Vocal Cord with Nonautologous Tissue Substitute, Open Approach */
"0CRV77Z" = "1" /* Replacement of Left Vocal Cord with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0CRV7JZ" = "1" /* Replacement of Left Vocal Cord with Synthetic Substitute, Via Natural or Artificial Opening */
"0CRV7KZ" = "1" /* Replacement of Left Vocal Cord with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0CRV87Z" = "1" /* Replacement of Left Vocal Cord with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRV8JZ" = "1" /* Replacement of Left Vocal Cord with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRV8KZ" = "1" /* Replacement of Left Vocal Cord with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CS20ZZ" = "1" /* Reposition Hard Palate, Open Approach */
"0CS2XZZ" = "1" /* Reposition Hard Palate, External Approach */
"0CS30ZZ" = "1" /* Reposition Soft Palate, Open Approach */
"0CS3XZZ" = "1" /* Reposition Soft Palate, External Approach */
"0CS70ZZ" = "1" /* Reposition Tongue, Open Approach */
"0CS7XZZ" = "1" /* Reposition Tongue, External Approach */
"0CSR0ZZ" = "1" /* Reposition Epiglottis, Open Approach */
"0CSR7ZZ" = "1" /* Reposition Epiglottis, Via Natural or Artificial Opening */
"0CSR8ZZ" = "1" /* Reposition Epiglottis, Via Natural or Artificial Opening Endoscopic */
"0CST0ZZ" = "1" /* Reposition Right Vocal Cord, Open Approach */
"0CST7ZZ" = "1" /* Reposition Right Vocal Cord, Via Natural or Artificial Opening */
"0CST8ZZ" = "1" /* Reposition Right Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CSV0ZZ" = "1" /* Reposition Left Vocal Cord, Open Approach */
"0CSV7ZZ" = "1" /* Reposition Left Vocal Cord, Via Natural or Artificial Opening */
"0CSV8ZZ" = "1" /* Reposition Left Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CT20ZZ" = "1" /* Resection of Hard Palate, Open Approach */
"0CT2XZZ" = "1" /* Resection of Hard Palate, External Approach */
"0CT30ZZ" = "1" /* Resection of Soft Palate, Open Approach */
"0CT3XZZ" = "1" /* Resection of Soft Palate, External Approach */
"0CT70ZZ" = "1" /* Resection of Tongue, Open Approach */
"0CT7XZZ" = "1" /* Resection of Tongue, External Approach */
"0CTM0ZZ" = "1" /* Resection of Pharynx, Open Approach */
"0CTM4ZZ" = "1" /* Resection of Pharynx, Percutaneous Endoscopic Approach */
"0CTM7ZZ" = "1" /* Resection of Pharynx, Via Natural or Artificial Opening */
"0CTM8ZZ" = "1" /* Resection of Pharynx, Via Natural or Artificial Opening Endoscopic */
"0CTN0ZZ" = "1" /* Resection of Uvula, Open Approach */
"0CTNXZZ" = "1" /* Resection of Uvula, External Approach */
"0CTR0ZZ" = "1" /* Resection of Epiglottis, Open Approach */
"0CTR4ZZ" = "1" /* Resection of Epiglottis, Percutaneous Endoscopic Approach */
"0CTR7ZZ" = "1" /* Resection of Epiglottis, Via Natural or Artificial Opening */
"0CTR8ZZ" = "1" /* Resection of Epiglottis, Via Natural or Artificial Opening Endoscopic */
"0CTS0ZZ" = "1" /* Resection of Larynx, Open Approach */
"0CTS4ZZ" = "1" /* Resection of Larynx, Percutaneous Endoscopic Approach */
"0CTS7ZZ" = "1" /* Resection of Larynx, Via Natural or Artificial Opening */
"0CTS8ZZ" = "1" /* Resection of Larynx, Via Natural or Artificial Opening Endoscopic */
"0CTT0ZZ" = "1" /* Resection of Right Vocal Cord, Open Approach */
"0CTT4ZZ" = "1" /* Resection of Right Vocal Cord, Percutaneous Endoscopic Approach */
"0CTT7ZZ" = "1" /* Resection of Right Vocal Cord, Via Natural or Artificial Opening */
"0CTT8ZZ" = "1" /* Resection of Right Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CTV0ZZ" = "1" /* Resection of Left Vocal Cord, Open Approach */
"0CTV4ZZ" = "1" /* Resection of Left Vocal Cord, Percutaneous Endoscopic Approach */
"0CTV7ZZ" = "1" /* Resection of Left Vocal Cord, Via Natural or Artificial Opening */
"0CTV8ZZ" = "1" /* Resection of Left Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CU207Z" = "1" /* Supplement Hard Palate with Autologous Tissue Substitute, Open Approach */
"0CU20JZ" = "1" /* Supplement Hard Palate with Synthetic Substitute, Open Approach */
"0CU20KZ" = "1" /* Supplement Hard Palate with Nonautologous Tissue Substitute, Open Approach */
"0CU237Z" = "1" /* Supplement Hard Palate with Autologous Tissue Substitute, Percutaneous Approach */
"0CU23JZ" = "1" /* Supplement Hard Palate with Synthetic Substitute, Percutaneous Approach */
"0CU23KZ" = "1" /* Supplement Hard Palate with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CU2X7Z" = "1" /* Supplement Hard Palate with Autologous Tissue Substitute, External Approach */
"0CU2XJZ" = "1" /* Supplement Hard Palate with Synthetic Substitute, External Approach */
"0CU2XKZ" = "1" /* Supplement Hard Palate with Nonautologous Tissue Substitute, External Approach */
"0CU307Z" = "1" /* Supplement Soft Palate with Autologous Tissue Substitute, Open Approach */
"0CU30JZ" = "1" /* Supplement Soft Palate with Synthetic Substitute, Open Approach */
"0CU30KZ" = "1" /* Supplement Soft Palate with Nonautologous Tissue Substitute, Open Approach */
"0CU337Z" = "1" /* Supplement Soft Palate with Autologous Tissue Substitute, Percutaneous Approach */
"0CU33JZ" = "1" /* Supplement Soft Palate with Synthetic Substitute, Percutaneous Approach */
"0CU33KZ" = "1" /* Supplement Soft Palate with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CU3X7Z" = "1" /* Supplement Soft Palate with Autologous Tissue Substitute, External Approach */
"0CU3XJZ" = "1" /* Supplement Soft Palate with Synthetic Substitute, External Approach */
"0CU3XKZ" = "1" /* Supplement Soft Palate with Nonautologous Tissue Substitute, External Approach */
"0CU407Z" = "1" /* Supplement Buccal Mucosa with Autologous Tissue Substitute, Open Approach */
"0CU40JZ" = "1" /* Supplement Buccal Mucosa with Synthetic Substitute, Open Approach */
"0CU40KZ" = "1" /* Supplement Buccal Mucosa with Nonautologous Tissue Substitute, Open Approach */
"0CU4X7Z" = "1" /* Supplement Buccal Mucosa with Autologous Tissue Substitute, External Approach */
"0CU4XJZ" = "1" /* Supplement Buccal Mucosa with Synthetic Substitute, External Approach */
"0CU4XKZ" = "1" /* Supplement Buccal Mucosa with Nonautologous Tissue Substitute, External Approach */
"0CU707Z" = "1" /* Supplement Tongue with Autologous Tissue Substitute, Open Approach */
"0CU70JZ" = "1" /* Supplement Tongue with Synthetic Substitute, Open Approach */
"0CU70KZ" = "1" /* Supplement Tongue with Nonautologous Tissue Substitute, Open Approach */
"0CU737Z" = "1" /* Supplement Tongue with Autologous Tissue Substitute, Percutaneous Approach */
"0CU73JZ" = "1" /* Supplement Tongue with Synthetic Substitute, Percutaneous Approach */
"0CU73KZ" = "1" /* Supplement Tongue with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CU7X7Z" = "1" /* Supplement Tongue with Autologous Tissue Substitute, External Approach */
"0CU7XJZ" = "1" /* Supplement Tongue with Synthetic Substitute, External Approach */
"0CU7XKZ" = "1" /* Supplement Tongue with Nonautologous Tissue Substitute, External Approach */
"0CUM07Z" = "1" /* Supplement Pharynx with Autologous Tissue Substitute, Open Approach */
"0CUM0JZ" = "1" /* Supplement Pharynx with Synthetic Substitute, Open Approach */
"0CUM0KZ" = "1" /* Supplement Pharynx with Nonautologous Tissue Substitute, Open Approach */
"0CUM77Z" = "1" /* Supplement Pharynx with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0CUM7JZ" = "1" /* Supplement Pharynx with Synthetic Substitute, Via Natural or Artificial Opening */
"0CUM7KZ" = "1" /* Supplement Pharynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0CUM87Z" = "1" /* Supplement Pharynx with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUM8JZ" = "1" /* Supplement Pharynx with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUM8KZ" = "1" /* Supplement Pharynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUN07Z" = "1" /* Supplement Uvula with Autologous Tissue Substitute, Open Approach */
"0CUN0JZ" = "1" /* Supplement Uvula with Synthetic Substitute, Open Approach */
"0CUN0KZ" = "1" /* Supplement Uvula with Nonautologous Tissue Substitute, Open Approach */
"0CUN37Z" = "1" /* Supplement Uvula with Autologous Tissue Substitute, Percutaneous Approach */
"0CUN3JZ" = "1" /* Supplement Uvula with Synthetic Substitute, Percutaneous Approach */
"0CUN3KZ" = "1" /* Supplement Uvula with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CUNX7Z" = "1" /* Supplement Uvula with Autologous Tissue Substitute, External Approach */
"0CUNXJZ" = "1" /* Supplement Uvula with Synthetic Substitute, External Approach */
"0CUNXKZ" = "1" /* Supplement Uvula with Nonautologous Tissue Substitute, External Approach */
"0CUR07Z" = "1" /* Supplement Epiglottis with Autologous Tissue Substitute, Open Approach */
"0CUR0JZ" = "1" /* Supplement Epiglottis with Synthetic Substitute, Open Approach */
"0CUR0KZ" = "1" /* Supplement Epiglottis with Nonautologous Tissue Substitute, Open Approach */
"0CUR77Z" = "1" /* Supplement Epiglottis with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0CUR7JZ" = "1" /* Supplement Epiglottis with Synthetic Substitute, Via Natural or Artificial Opening */
"0CUR7KZ" = "1" /* Supplement Epiglottis with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0CUR87Z" = "1" /* Supplement Epiglottis with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUR8JZ" = "1" /* Supplement Epiglottis with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUR8KZ" = "1" /* Supplement Epiglottis with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUS07Z" = "1" /* Supplement Larynx with Autologous Tissue Substitute, Open Approach */
"0CUS0JZ" = "1" /* Supplement Larynx with Synthetic Substitute, Open Approach */
"0CUS0KZ" = "1" /* Supplement Larynx with Nonautologous Tissue Substitute, Open Approach */
"0CUS77Z" = "1" /* Supplement Larynx with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0CUS7JZ" = "1" /* Supplement Larynx with Synthetic Substitute, Via Natural or Artificial Opening */
"0CUS7KZ" = "1" /* Supplement Larynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0CUS87Z" = "1" /* Supplement Larynx with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUS8JZ" = "1" /* Supplement Larynx with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUS8KZ" = "1" /* Supplement Larynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUT07Z" = "1" /* Supplement Right Vocal Cord with Autologous Tissue Substitute, Open Approach */
"0CUT0JZ" = "1" /* Supplement Right Vocal Cord with Synthetic Substitute, Open Approach */
"0CUT0KZ" = "1" /* Supplement Right Vocal Cord with Nonautologous Tissue Substitute, Open Approach */
"0CUT77Z" = "1" /* Supplement Right Vocal Cord with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0CUT7JZ" = "1" /* Supplement Right Vocal Cord with Synthetic Substitute, Via Natural or Artificial Opening */
"0CUT7KZ" = "1" /* Supplement Right Vocal Cord with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0CUT87Z" = "1" /* Supplement Right Vocal Cord with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUT8JZ" = "1" /* Supplement Right Vocal Cord with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUT8KZ" = "1" /* Supplement Right Vocal Cord with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUV07Z" = "1" /* Supplement Left Vocal Cord with Autologous Tissue Substitute, Open Approach */
"0CUV0JZ" = "1" /* Supplement Left Vocal Cord with Synthetic Substitute, Open Approach */
"0CUV0KZ" = "1" /* Supplement Left Vocal Cord with Nonautologous Tissue Substitute, Open Approach */
"0CUV77Z" = "1" /* Supplement Left Vocal Cord with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0CUV7JZ" = "1" /* Supplement Left Vocal Cord with Synthetic Substitute, Via Natural or Artificial Opening */
"0CUV7KZ" = "1" /* Supplement Left Vocal Cord with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0CUV87Z" = "1" /* Supplement Left Vocal Cord with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUV8JZ" = "1" /* Supplement Left Vocal Cord with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUV8KZ" = "1" /* Supplement Left Vocal Cord with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CWS00Z" = "1" /* Revision of Drainage Device in Larynx, Open Approach */
"0CWS07Z" = "1" /* Revision of Autologous Tissue Substitute in Larynx, Open Approach */
"0CWS0DZ" = "1" /* Revision of Intraluminal Device in Larynx, Open Approach */
"0CWS0JZ" = "1" /* Revision of Synthetic Substitute in Larynx, Open Approach */
"0CWS0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Larynx, Open Approach */
"0CWS30Z" = "1" /* Revision of Drainage Device in Larynx, Percutaneous Approach */
"0CWS37Z" = "1" /* Revision of Autologous Tissue Substitute in Larynx, Percutaneous Approach */
"0CWS3DZ" = "1" /* Revision of Intraluminal Device in Larynx, Percutaneous Approach */
"0CWS3JZ" = "1" /* Revision of Synthetic Substitute in Larynx, Percutaneous Approach */
"0CWS3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Larynx, Percutaneous Approach */
"0CWS70Z" = "1" /* Revision of Drainage Device in Larynx, Via Natural or Artificial Opening */
"0CWS77Z" = "1" /* Revision of Autologous Tissue Substitute in Larynx, Via Natural or Artificial Opening */
"0CWS7DZ" = "1" /* Revision of Intraluminal Device in Larynx, Via Natural or Artificial Opening */
"0CWS7JZ" = "1" /* Revision of Synthetic Substitute in Larynx, Via Natural or Artificial Opening */
"0CWS7KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Larynx, Via Natural or Artificial Opening */
"0CWS80Z" = "1" /* Revision of Drainage Device in Larynx, Via Natural or Artificial Opening Endoscopic */
"0CWS87Z" = "1" /* Revision of Autologous Tissue Substitute in Larynx, Via Natural or Artificial Opening Endoscopic */
"0CWS8DZ" = "1" /* Revision of Intraluminal Device in Larynx, Via Natural or Artificial Opening Endoscopic */
"0CWS8JZ" = "1" /* Revision of Synthetic Substitute in Larynx, Via Natural or Artificial Opening Endoscopic */
"0CWS8KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Larynx, Via Natural or Artificial Opening Endoscopic */
"0CWY00Z" = "1" /* Revision of Drainage Device in Mouth and Throat, Open Approach */
"0CWY01Z" = "1" /* Revision of Radioactive Element in Mouth and Throat, Open Approach */
"0CWY0DZ" = "1" /* Revision of Intraluminal Device in Mouth and Throat, Open Approach */
"0CWY0JZ" = "1" /* Revision of Synthetic Substitute in Mouth and Throat, Open Approach */
"0CWY0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mouth and Throat, Open Approach */
"0CWY30Z" = "1" /* Revision of Drainage Device in Mouth and Throat, Percutaneous Approach */
"0CWY31Z" = "1" /* Revision of Radioactive Element in Mouth and Throat, Percutaneous Approach */
"0CWY37Z" = "1" /* Revision of Autologous Tissue Substitute in Mouth and Throat, Percutaneous Approach */
"0CWY3DZ" = "1" /* Revision of Intraluminal Device in Mouth and Throat, Percutaneous Approach */
"0CWY3JZ" = "1" /* Revision of Synthetic Substitute in Mouth and Throat, Percutaneous Approach */
"0CWY3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mouth and Throat, Percutaneous Approach */
"0CWY70Z" = "1" /* Revision of Drainage Device in Mouth and Throat, Via Natural or Artificial Opening */
"0CWY71Z" = "1" /* Revision of Radioactive Element in Mouth and Throat, Via Natural or Artificial Opening */
"0CWY77Z" = "1" /* Revision of Autologous Tissue Substitute in Mouth and Throat, Via Natural or Artificial Opening */
"0CWY7DZ" = "1" /* Revision of Intraluminal Device in Mouth and Throat, Via Natural or Artificial Opening */
"0CWY7JZ" = "1" /* Revision of Synthetic Substitute in Mouth and Throat, Via Natural or Artificial Opening */
"0CWY7KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mouth and Throat, Via Natural or Artificial Opening */
"0CWY80Z" = "1" /* Revision of Drainage Device in Mouth and Throat, Via Natural or Artificial Opening Endoscopic */
"0CWY81Z" = "1" /* Revision of Radioactive Element in Mouth and Throat, Via Natural or Artificial Opening Endoscopic */
"0CWY87Z" = "1" /* Revision of Autologous Tissue Substitute in Mouth and Throat, Via Natural or Artificial Opening Endoscopic */
"0CWY8DZ" = "1" /* Revision of Intraluminal Device in Mouth and Throat, Via Natural or Artificial Opening Endoscopic */
"0CWY8JZ" = "1" /* Revision of Synthetic Substitute in Mouth and Throat, Via Natural or Artificial Opening Endoscopic */
"0CWY8KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mouth and Throat, Via Natural or Artificial Opening Endoscopic */
"0CX30ZZ" = "1" /* Transfer Soft Palate, Open Approach */
"0CX3XZZ" = "1" /* Transfer Soft Palate, External Approach */
"0CX40ZZ" = "1" /* Transfer Buccal Mucosa, Open Approach */
"0CX4XZZ" = "1" /* Transfer Buccal Mucosa, External Approach */
"0CX70ZZ" = "1" /* Transfer Tongue, Open Approach */
"0CX7XZZ" = "1" /* Transfer Tongue, External Approach */
"0DQ50ZZ" = "1" /* Repair Esophagus, Open Approach */
"0DQ53ZZ" = "1" /* Repair Esophagus, Percutaneous Approach */
"0DQ54ZZ" = "1" /* Repair Esophagus, Percutaneous Endoscopic Approach */
"0DQ57ZZ" = "1" /* Repair Esophagus, Via Natural or Artificial Opening */
"0DQ58ZZ" = "1" /* Repair Esophagus, Via Natural or Artificial Opening Endoscopic */
"0J9100Z" = "1" /* Drainage of Face Subcutaneous Tissue and Fascia with Drainage Device, Open Approach */
"0J910ZZ" = "1" /* Drainage of Face Subcutaneous Tissue and Fascia, Open Approach */
"0JB40ZZ" = "1" /* Excision of Anterior Neck Subcutaneous Tissue and Fascia, Open Approach */
"0K840ZZ" = "1" /* Division of Tongue, Palate, Pharynx Muscle, Open Approach */
"0K843ZZ" = "1" /* Division of Tongue, Palate, Pharynx Muscle, Percutaneous Approach */
"0K844ZZ" = "1" /* Division of Tongue, Palate, Pharynx Muscle, Percutaneous Endoscopic Approach */
"0NBC0ZZ" = "1" /* Excision of Right Sphenoid Bone, Open Approach */
"0NBD0ZZ" = "1" /* Excision of Left Sphenoid Bone, Open Approach */
"0NBF0ZZ" = "1" /* Excision of Right Ethmoid Bone, Open Approach */
"0NBG0ZZ" = "1" /* Excision of Left Ethmoid Bone, Open Approach */
"0NBK0ZZ" = "1" /* Excision of Right Palatine Bone, Open Approach */
"0NBL0ZZ" = "1" /* Excision of Left Palatine Bone, Open Approach */
"0NBT0ZZ" = "1" /* Excision of Right Mandible, Open Approach */
"0NBV0ZZ" = "1" /* Excision of Left Mandible, Open Approach */
"0NBX0ZZ" = "1" /* Excision of Hyoid Bone, Open Approach */
"0NBX3ZZ" = "1" /* Excision of Hyoid Bone, Percutaneous Approach */
"0NBX4ZZ" = "1" /* Excision of Hyoid Bone, Percutaneous Endoscopic Approach */
"0NNC0ZZ" = "1" /* Release Right Sphenoid Bone, Open Approach */
"0NND0ZZ" = "1" /* Release Left Sphenoid Bone, Open Approach */
"0NNF0ZZ" = "1" /* Release Right Ethmoid Bone, Open Approach */
"0NNG0ZZ" = "1" /* Release Left Ethmoid Bone, Open Approach */
"0NNK0ZZ" = "1" /* Release Right Palatine Bone, Open Approach */
"0NNL0ZZ" = "1" /* Release Left Palatine Bone, Open Approach */
"0NNX0ZZ" = "1" /* Release Hyoid Bone, Open Approach */
"0NNX3ZZ" = "1" /* Release Hyoid Bone, Percutaneous Approach */
"0NNX4ZZ" = "1" /* Release Hyoid Bone, Percutaneous Endoscopic Approach */
"0NQC0ZZ" = "1" /* Repair Right Sphenoid Bone, Open Approach */
"0NQD0ZZ" = "1" /* Repair Left Sphenoid Bone, Open Approach */
"0NQF0ZZ" = "1" /* Repair Right Ethmoid Bone, Open Approach */
"0NQG0ZZ" = "1" /* Repair Left Ethmoid Bone, Open Approach */
"0NQK0ZZ" = "1" /* Repair Right Palatine Bone, Open Approach */
"0NQL0ZZ" = "1" /* Repair Left Palatine Bone, Open Approach */
"0NQX0ZZ" = "1" /* Repair Hyoid Bone, Open Approach */
"0NQX3ZZ" = "1" /* Repair Hyoid Bone, Percutaneous Approach */
"0NQX4ZZ" = "1" /* Repair Hyoid Bone, Percutaneous Endoscopic Approach */
"0NQXXZZ" = "1" /* Repair Hyoid Bone, External Approach */
"0NRC07Z" = "1" /* Replacement of Right Sphenoid Bone with Autologous Tissue Substitute, Open Approach */
"0NRC0JZ" = "1" /* Replacement of Right Sphenoid Bone with Synthetic Substitute, Open Approach */
"0NRC0KZ" = "1" /* Replacement of Right Sphenoid Bone with Nonautologous Tissue Substitute, Open Approach */
"0NRD07Z" = "1" /* Replacement of Left Sphenoid Bone with Autologous Tissue Substitute, Open Approach */
"0NRD0JZ" = "1" /* Replacement of Left Sphenoid Bone with Synthetic Substitute, Open Approach */
"0NRD0KZ" = "1" /* Replacement of Left Sphenoid Bone with Nonautologous Tissue Substitute, Open Approach */
"0NRF07Z" = "1" /* Replacement of Right Ethmoid Bone with Autologous Tissue Substitute, Open Approach */
"0NRF0JZ" = "1" /* Replacement of Right Ethmoid Bone with Synthetic Substitute, Open Approach */
"0NRF0KZ" = "1" /* Replacement of Right Ethmoid Bone with Nonautologous Tissue Substitute, Open Approach */
"0NRG07Z" = "1" /* Replacement of Left Ethmoid Bone with Autologous Tissue Substitute, Open Approach */
"0NRG0JZ" = "1" /* Replacement of Left Ethmoid Bone with Synthetic Substitute, Open Approach */
"0NRG0KZ" = "1" /* Replacement of Left Ethmoid Bone with Nonautologous Tissue Substitute, Open Approach */
"0NRK07Z" = "1" /* Replacement of Right Palatine Bone with Autologous Tissue Substitute, Open Approach */
"0NRK0JZ" = "1" /* Replacement of Right Palatine Bone with Synthetic Substitute, Open Approach */
"0NRK0KZ" = "1" /* Replacement of Right Palatine Bone with Nonautologous Tissue Substitute, Open Approach */
"0NRK37Z" = "1" /* Replacement of Right Palatine Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NRK3JZ" = "1" /* Replacement of Right Palatine Bone with Synthetic Substitute, Percutaneous Approach */
"0NRK3KZ" = "1" /* Replacement of Right Palatine Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NRK47Z" = "1" /* Replacement of Right Palatine Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRK4JZ" = "1" /* Replacement of Right Palatine Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NRK4KZ" = "1" /* Replacement of Right Palatine Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRL07Z" = "1" /* Replacement of Left Palatine Bone with Autologous Tissue Substitute, Open Approach */
"0NRL0JZ" = "1" /* Replacement of Left Palatine Bone with Synthetic Substitute, Open Approach */
"0NRL0KZ" = "1" /* Replacement of Left Palatine Bone with Nonautologous Tissue Substitute, Open Approach */
"0NRL37Z" = "1" /* Replacement of Left Palatine Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NRL3JZ" = "1" /* Replacement of Left Palatine Bone with Synthetic Substitute, Percutaneous Approach */
"0NRL3KZ" = "1" /* Replacement of Left Palatine Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NRL47Z" = "1" /* Replacement of Left Palatine Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRL4JZ" = "1" /* Replacement of Left Palatine Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NRL4KZ" = "1" /* Replacement of Left Palatine Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRT07Z" = "1" /* Replacement of Right Mandible with Autologous Tissue Substitute, Open Approach */
"0NRT0JZ" = "1" /* Replacement of Right Mandible with Synthetic Substitute, Open Approach */
"0NRT0KZ" = "1" /* Replacement of Right Mandible with Nonautologous Tissue Substitute, Open Approach */
"0NRT37Z" = "1" /* Replacement of Right Mandible with Autologous Tissue Substitute, Percutaneous Approach */
"0NRT3JZ" = "1" /* Replacement of Right Mandible with Synthetic Substitute, Percutaneous Approach */
"0NRT3KZ" = "1" /* Replacement of Right Mandible with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NRT47Z" = "1" /* Replacement of Right Mandible with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRT4JZ" = "1" /* Replacement of Right Mandible with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NRT4KZ" = "1" /* Replacement of Right Mandible with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRV07Z" = "1" /* Replacement of Left Mandible with Autologous Tissue Substitute, Open Approach */
"0NRV0JZ" = "1" /* Replacement of Left Mandible with Synthetic Substitute, Open Approach */
"0NRV0KZ" = "1" /* Replacement of Left Mandible with Nonautologous Tissue Substitute, Open Approach */
"0NRV37Z" = "1" /* Replacement of Left Mandible with Autologous Tissue Substitute, Percutaneous Approach */
"0NRV3JZ" = "1" /* Replacement of Left Mandible with Synthetic Substitute, Percutaneous Approach */
"0NRV3KZ" = "1" /* Replacement of Left Mandible with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NRV47Z" = "1" /* Replacement of Left Mandible with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRV4JZ" = "1" /* Replacement of Left Mandible with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NRV4KZ" = "1" /* Replacement of Left Mandible with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRX07Z" = "1" /* Replacement of Hyoid Bone with Autologous Tissue Substitute, Open Approach */
"0NRX0JZ" = "1" /* Replacement of Hyoid Bone with Synthetic Substitute, Open Approach */
"0NRX0KZ" = "1" /* Replacement of Hyoid Bone with Nonautologous Tissue Substitute, Open Approach */
"0NRX37Z" = "1" /* Replacement of Hyoid Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NRX3JZ" = "1" /* Replacement of Hyoid Bone with Synthetic Substitute, Percutaneous Approach */
"0NRX3KZ" = "1" /* Replacement of Hyoid Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NRX47Z" = "1" /* Replacement of Hyoid Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRX4JZ" = "1" /* Replacement of Hyoid Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NRX4KZ" = "1" /* Replacement of Hyoid Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NSC04Z" = "1" /* Reposition Right Sphenoid Bone with Internal Fixation Device, Open Approach */
"0NSC0ZZ" = "1" /* Reposition Right Sphenoid Bone, Open Approach */
"0NSD04Z" = "1" /* Reposition Left Sphenoid Bone with Internal Fixation Device, Open Approach */
"0NSD0ZZ" = "1" /* Reposition Left Sphenoid Bone, Open Approach */
"0NSF04Z" = "1" /* Reposition Right Ethmoid Bone with Internal Fixation Device, Open Approach */
"0NSF0ZZ" = "1" /* Reposition Right Ethmoid Bone, Open Approach */
"0NSG04Z" = "1" /* Reposition Left Ethmoid Bone with Internal Fixation Device, Open Approach */
"0NSG0ZZ" = "1" /* Reposition Left Ethmoid Bone, Open Approach */
"0NSK04Z" = "1" /* Reposition Right Palatine Bone with Internal Fixation Device, Open Approach */
"0NSK0ZZ" = "1" /* Reposition Right Palatine Bone, Open Approach */
"0NSL04Z" = "1" /* Reposition Left Palatine Bone with Internal Fixation Device, Open Approach */
"0NSL0ZZ" = "1" /* Reposition Left Palatine Bone, Open Approach */
"0NSX04Z" = "1" /* Reposition Hyoid Bone with Internal Fixation Device, Open Approach */
"0NSX0ZZ" = "1" /* Reposition Hyoid Bone, Open Approach */
"0NSX34Z" = "1" /* Reposition Hyoid Bone with Internal Fixation Device, Percutaneous Approach */
"0NSX3ZZ" = "1" /* Reposition Hyoid Bone, Percutaneous Approach */
"0NSX44Z" = "1" /* Reposition Hyoid Bone with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0NSX4ZZ" = "1" /* Reposition Hyoid Bone, Percutaneous Endoscopic Approach */
"0NSXXZZ" = "1" /* Reposition Hyoid Bone, External Approach */
"0NTC0ZZ" = "1" /* Resection of Right Sphenoid Bone, Open Approach */
"0NTD0ZZ" = "1" /* Resection of Left Sphenoid Bone, Open Approach */
"0NTF0ZZ" = "1" /* Resection of Right Ethmoid Bone, Open Approach */
"0NTG0ZZ" = "1" /* Resection of Left Ethmoid Bone, Open Approach */
"0NTK0ZZ" = "1" /* Resection of Right Palatine Bone, Open Approach */
"0NTL0ZZ" = "1" /* Resection of Left Palatine Bone, Open Approach */
"0NTT0ZZ" = "1" /* Resection of Right Mandible, Open Approach */
"0NTV0ZZ" = "1" /* Resection of Left Mandible, Open Approach */
"0NTX0ZZ" = "1" /* Resection of Hyoid Bone, Open Approach */
"0NUC07Z" = "1" /* Supplement Right Sphenoid Bone with Autologous Tissue Substitute, Open Approach */
"0NUC0JZ" = "1" /* Supplement Right Sphenoid Bone with Synthetic Substitute, Open Approach */
"0NUC0KZ" = "1" /* Supplement Right Sphenoid Bone with Nonautologous Tissue Substitute, Open Approach */
"0NUD07Z" = "1" /* Supplement Left Sphenoid Bone with Autologous Tissue Substitute, Open Approach */
"0NUD0JZ" = "1" /* Supplement Left Sphenoid Bone with Synthetic Substitute, Open Approach */
"0NUD0KZ" = "1" /* Supplement Left Sphenoid Bone with Nonautologous Tissue Substitute, Open Approach */
"0NUF07Z" = "1" /* Supplement Right Ethmoid Bone with Autologous Tissue Substitute, Open Approach */
"0NUF0JZ" = "1" /* Supplement Right Ethmoid Bone with Synthetic Substitute, Open Approach */
"0NUF0KZ" = "1" /* Supplement Right Ethmoid Bone with Nonautologous Tissue Substitute, Open Approach */
"0NUG07Z" = "1" /* Supplement Left Ethmoid Bone with Autologous Tissue Substitute, Open Approach */
"0NUG0JZ" = "1" /* Supplement Left Ethmoid Bone with Synthetic Substitute, Open Approach */
"0NUG0KZ" = "1" /* Supplement Left Ethmoid Bone with Nonautologous Tissue Substitute, Open Approach */
"0NUK07Z" = "1" /* Supplement Right Palatine Bone with Autologous Tissue Substitute, Open Approach */
"0NUK0JZ" = "1" /* Supplement Right Palatine Bone with Synthetic Substitute, Open Approach */
"0NUK0KZ" = "1" /* Supplement Right Palatine Bone with Nonautologous Tissue Substitute, Open Approach */
"0NUL07Z" = "1" /* Supplement Left Palatine Bone with Autologous Tissue Substitute, Open Approach */
"0NUL0JZ" = "1" /* Supplement Left Palatine Bone with Synthetic Substitute, Open Approach */
"0NUL0KZ" = "1" /* Supplement Left Palatine Bone with Nonautologous Tissue Substitute, Open Approach */
"0NUT07Z" = "1" /* Supplement Right Mandible with Autologous Tissue Substitute, Open Approach */
"0NUT0JZ" = "1" /* Supplement Right Mandible with Synthetic Substitute, Open Approach */
"0NUT0KZ" = "1" /* Supplement Right Mandible with Nonautologous Tissue Substitute, Open Approach */
"0NUT37Z" = "1" /* Supplement Right Mandible with Autologous Tissue Substitute, Percutaneous Approach */
"0NUT3JZ" = "1" /* Supplement Right Mandible with Synthetic Substitute, Percutaneous Approach */
"0NUT3KZ" = "1" /* Supplement Right Mandible with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NUT47Z" = "1" /* Supplement Right Mandible with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUT4JZ" = "1" /* Supplement Right Mandible with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NUT4KZ" = "1" /* Supplement Right Mandible with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUV07Z" = "1" /* Supplement Left Mandible with Autologous Tissue Substitute, Open Approach */
"0NUV0JZ" = "1" /* Supplement Left Mandible with Synthetic Substitute, Open Approach */
"0NUV0KZ" = "1" /* Supplement Left Mandible with Nonautologous Tissue Substitute, Open Approach */
"0NUV37Z" = "1" /* Supplement Left Mandible with Autologous Tissue Substitute, Percutaneous Approach */
"0NUV3JZ" = "1" /* Supplement Left Mandible with Synthetic Substitute, Percutaneous Approach */
"0NUV3KZ" = "1" /* Supplement Left Mandible with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NUV47Z" = "1" /* Supplement Left Mandible with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUV4JZ" = "1" /* Supplement Left Mandible with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NUV4KZ" = "1" /* Supplement Left Mandible with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUX07Z" = "1" /* Supplement Hyoid Bone with Autologous Tissue Substitute, Open Approach */
"0NUX0JZ" = "1" /* Supplement Hyoid Bone with Synthetic Substitute, Open Approach */
"0NUX0KZ" = "1" /* Supplement Hyoid Bone with Nonautologous Tissue Substitute, Open Approach */
"0NUX37Z" = "1" /* Supplement Hyoid Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NUX3JZ" = "1" /* Supplement Hyoid Bone with Synthetic Substitute, Percutaneous Approach */
"0NUX3KZ" = "1" /* Supplement Hyoid Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NUX47Z" = "1" /* Supplement Hyoid Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUX4JZ" = "1" /* Supplement Hyoid Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NUX4KZ" = "1" /* Supplement Hyoid Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGC04Z" = "1" /* Fusion of Right Temporomandibular Joint with Internal Fixation Device, Open Approach */
"0RGC07Z" = "1" /* Fusion of Right Temporomandibular Joint with Autologous Tissue Substitute, Open Approach */
"0RGC0JZ" = "1" /* Fusion of Right Temporomandibular Joint with Synthetic Substitute, Open Approach */
"0RGC0KZ" = "1" /* Fusion of Right Temporomandibular Joint with Nonautologous Tissue Substitute, Open Approach */
"0RGC0ZZ" = "1" /* Fusion of Right Temporomandibular Joint, Open Approach */
"0RGC34Z" = "1" /* Fusion of Right Temporomandibular Joint with Internal Fixation Device, Percutaneous Approach */
"0RGC37Z" = "1" /* Fusion of Right Temporomandibular Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RGC3JZ" = "1" /* Fusion of Right Temporomandibular Joint with Synthetic Substitute, Percutaneous Approach */
"0RGC3KZ" = "1" /* Fusion of Right Temporomandibular Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RGC3ZZ" = "1" /* Fusion of Right Temporomandibular Joint, Percutaneous Approach */
"0RGC44Z" = "1" /* Fusion of Right Temporomandibular Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RGC47Z" = "1" /* Fusion of Right Temporomandibular Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGC4JZ" = "1" /* Fusion of Right Temporomandibular Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RGC4KZ" = "1" /* Fusion of Right Temporomandibular Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGC4ZZ" = "1" /* Fusion of Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RGD04Z" = "1" /* Fusion of Left Temporomandibular Joint with Internal Fixation Device, Open Approach */
"0RGD07Z" = "1" /* Fusion of Left Temporomandibular Joint with Autologous Tissue Substitute, Open Approach */
"0RGD0JZ" = "1" /* Fusion of Left Temporomandibular Joint with Synthetic Substitute, Open Approach */
"0RGD0KZ" = "1" /* Fusion of Left Temporomandibular Joint with Nonautologous Tissue Substitute, Open Approach */
"0RGD0ZZ" = "1" /* Fusion of Left Temporomandibular Joint, Open Approach */
"0RGD34Z" = "1" /* Fusion of Left Temporomandibular Joint with Internal Fixation Device, Percutaneous Approach */
"0RGD37Z" = "1" /* Fusion of Left Temporomandibular Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RGD3JZ" = "1" /* Fusion of Left Temporomandibular Joint with Synthetic Substitute, Percutaneous Approach */
"0RGD3KZ" = "1" /* Fusion of Left Temporomandibular Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RGD3ZZ" = "1" /* Fusion of Left Temporomandibular Joint, Percutaneous Approach */
"0RGD44Z" = "1" /* Fusion of Left Temporomandibular Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RGD47Z" = "1" /* Fusion of Left Temporomandibular Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGD4JZ" = "1" /* Fusion of Left Temporomandibular Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RGD4KZ" = "1" /* Fusion of Left Temporomandibular Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGD4ZZ" = "1" /* Fusion of Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RNC0ZZ" = "1" /* Release Right Temporomandibular Joint, Open Approach */
"0RNC3ZZ" = "1" /* Release Right Temporomandibular Joint, Percutaneous Approach */
"0RNC4ZZ" = "1" /* Release Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RND0ZZ" = "1" /* Release Left Temporomandibular Joint, Open Approach */
"0RND3ZZ" = "1" /* Release Left Temporomandibular Joint, Percutaneous Approach */
"0RND4ZZ" = "1" /* Release Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RPC04Z" = "1" /* Removal of Internal Fixation Device from Right Temporomandibular Joint, Open Approach */
"0RPC34Z" = "1" /* Removal of Internal Fixation Device from Right Temporomandibular Joint, Percutaneous Approach */
"0RPC44Z" = "1" /* Removal of Internal Fixation Device from Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RPD04Z" = "1" /* Removal of Internal Fixation Device from Left Temporomandibular Joint, Open Approach */
"0RPD34Z" = "1" /* Removal of Internal Fixation Device from Left Temporomandibular Joint, Percutaneous Approach */
"0RPD44Z" = "1" /* Removal of Internal Fixation Device from Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RSC04Z" = "1" /* Reposition Right Temporomandibular Joint with Internal Fixation Device, Open Approach */
"0RSC0ZZ" = "1" /* Reposition Right Temporomandibular Joint, Open Approach */
"0RSC34Z" = "1" /* Reposition Right Temporomandibular Joint with Internal Fixation Device, Percutaneous Approach */
"0RSC3ZZ" = "1" /* Reposition Right Temporomandibular Joint, Percutaneous Approach */
"0RSC44Z" = "1" /* Reposition Right Temporomandibular Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RSC4ZZ" = "1" /* Reposition Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RSD04Z" = "1" /* Reposition Left Temporomandibular Joint with Internal Fixation Device, Open Approach */
"0RSD0ZZ" = "1" /* Reposition Left Temporomandibular Joint, Open Approach */
"0RSD34Z" = "1" /* Reposition Left Temporomandibular Joint with Internal Fixation Device, Percutaneous Approach */
"0RSD3ZZ" = "1" /* Reposition Left Temporomandibular Joint, Percutaneous Approach */
"0RSD44Z" = "1" /* Reposition Left Temporomandibular Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RSD4ZZ" = "1" /* Reposition Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RTC0ZZ" = "1" /* Resection of Right Temporomandibular Joint, Open Approach */
"0RTD0ZZ" = "1" /* Resection of Left Temporomandibular Joint, Open Approach */
"0W9200Z" = "1" /* Drainage of Face with Drainage Device, Open Approach */
"0W920ZZ" = "1" /* Drainage of Face, Open Approach */
"0W9300Z" = "1" /* Drainage of Oral Cavity and Throat with Drainage Device, Open Approach */
"0W930ZZ" = "1" /* Drainage of Oral Cavity and Throat, Open Approach */
"0W9330Z" = "1" /* Drainage of Oral Cavity and Throat with Drainage Device, Percutaneous Approach */
"0W933ZZ" = "1" /* Drainage of Oral Cavity and Throat, Percutaneous Approach */
"0W9340Z" = "1" /* Drainage of Oral Cavity and Throat with Drainage Device, Percutaneous Endoscopic Approach */
"0W934ZZ" = "1" /* Drainage of Oral Cavity and Throat, Percutaneous Endoscopic Approach */
"0W9400Z" = "1" /* Drainage of Upper Jaw with Drainage Device, Open Approach */
"0W940ZZ" = "1" /* Drainage of Upper Jaw, Open Approach */
"0W9500Z" = "1" /* Drainage of Lower Jaw with Drainage Device, Open Approach */
"0W950ZZ" = "1" /* Drainage of Lower Jaw, Open Approach */
"0WC30ZZ" = "1" /* Extirpation of Matter from Oral Cavity and Throat, Open Approach */
"0WC33ZZ" = "1" /* Extirpation of Matter from Oral Cavity and Throat, Percutaneous Approach */
"0WC34ZZ" = "1" /* Extirpation of Matter from Oral Cavity and Throat, Percutaneous Endoscopic Approach */
"0WF30ZZ" = "1" /* Fragmentation in Oral Cavity and Throat, Open Approach */
"0WF33ZZ" = "1" /* Fragmentation in Oral Cavity and Throat, Percutaneous Approach */
"0WF34ZZ" = "1" /* Fragmentation in Oral Cavity and Throat, Percutaneous Endoscopic Approach */
"0WH303Z" = "1" /* Insertion of Infusion Device into Oral Cavity and Throat, Open Approach */
"0WH30YZ" = "1" /* Insertion of Other Device into Oral Cavity and Throat, Open Approach */
Other = "0"
;

/* Procedure codeset ORPROC last updated 170108 for ICD10 v70rev0 */
Value $ORPROC
"0016070" = "1" /* Bypass Cerebral Ventricle to Nasopharynx with Autologous Tissue Substitute, Open Approach */
"0016071" = "1" /* Bypass Cerebral Ventricle to Mastoid Sinus with Autologous Tissue Substitute, Open Approach */
"0016072" = "1" /* Bypass Cerebral Ventricle to Atrium with Autologous Tissue Substitute, Open Approach */
"0016073" = "1" /* Bypass Cerebral Ventricle to Blood Vessel with Autologous Tissue Substitute, Open Approach */
"0016074" = "1" /* Bypass Cerebral Ventricle to Pleural Cavity with Autologous Tissue Substitute, Open Approach */
"0016075" = "1" /* Bypass Cerebral Ventricle to Intestine with Autologous Tissue Substitute, Open Approach */
"0016076" = "1" /* Bypass Cerebral Ventricle to Peritoneal Cavity with Autologous Tissue Substitute, Open Approach */
"0016077" = "1" /* Bypass Cerebral Ventricle to Urinary Tract with Autologous Tissue Substitute, Open Approach */
"0016078" = "1" /* Bypass Cerebral Ventricle to Bone Marrow with Autologous Tissue Substitute, Open Approach */
"001607B" = "1" /* Bypass Cerebral Ventricle to Cerebral Cisterns with Autologous Tissue Substitute, Open Approach */
"00160J0" = "1" /* Bypass Cerebral Ventricle to Nasopharynx with Synthetic Substitute, Open Approach */
"00160J1" = "1" /* Bypass Cerebral Ventricle to Mastoid Sinus with Synthetic Substitute, Open Approach */
"00160J2" = "1" /* Bypass Cerebral Ventricle to Atrium with Synthetic Substitute, Open Approach */
"00160J3" = "1" /* Bypass Cerebral Ventricle to Blood Vessel with Synthetic Substitute, Open Approach */
"00160J4" = "1" /* Bypass Cerebral Ventricle to Pleural Cavity with Synthetic Substitute, Open Approach */
"00160J5" = "1" /* Bypass Cerebral Ventricle to Intestine with Synthetic Substitute, Open Approach */
"00160J6" = "1" /* Bypass Cerebral Ventricle to Peritoneal Cavity with Synthetic Substitute, Open Approach */
"00160J7" = "1" /* Bypass Cerebral Ventricle to Urinary Tract with Synthetic Substitute, Open Approach */
"00160J8" = "1" /* Bypass Cerebral Ventricle to Bone Marrow with Synthetic Substitute, Open Approach */
"00160JB" = "1" /* Bypass Cerebral Ventricle to Cerebral Cisterns with Synthetic Substitute, Open Approach */
"00160K0" = "1" /* Bypass Cerebral Ventricle to Nasopharynx with Nonautologous Tissue Substitute, Open Approach */
"00160K1" = "1" /* Bypass Cerebral Ventricle to Mastoid Sinus with Nonautologous Tissue Substitute, Open Approach */
"00160K2" = "1" /* Bypass Cerebral Ventricle to Atrium with Nonautologous Tissue Substitute, Open Approach */
"00160K3" = "1" /* Bypass Cerebral Ventricle to Blood Vessel with Nonautologous Tissue Substitute, Open Approach */
"00160K4" = "1" /* Bypass Cerebral Ventricle to Pleural Cavity with Nonautologous Tissue Substitute, Open Approach */
"00160K5" = "1" /* Bypass Cerebral Ventricle to Intestine with Nonautologous Tissue Substitute, Open Approach */
"00160K6" = "1" /* Bypass Cerebral Ventricle to Peritoneal Cavity with Nonautologous Tissue Substitute, Open Approach */
"00160K7" = "1" /* Bypass Cerebral Ventricle to Urinary Tract with Nonautologous Tissue Substitute, Open Approach */
"00160K8" = "1" /* Bypass Cerebral Ventricle to Bone Marrow with Nonautologous Tissue Substitute, Open Approach */
"00160KB" = "1" /* Bypass Cerebral Ventricle to Cerebral Cisterns with Nonautologous Tissue Substitute, Open Approach */
"0016370" = "1" /* Bypass Cerebral Ventricle to Nasopharynx with Autologous Tissue Substitute, Percutaneous Approach */
"0016371" = "1" /* Bypass Cerebral Ventricle to Mastoid Sinus with Autologous Tissue Substitute, Percutaneous Approach */
"0016372" = "1" /* Bypass Cerebral Ventricle to Atrium with Autologous Tissue Substitute, Percutaneous Approach */
"0016373" = "1" /* Bypass Cerebral Ventricle to Blood Vessel with Autologous Tissue Substitute, Percutaneous Approach */
"0016374" = "1" /* Bypass Cerebral Ventricle to Pleural Cavity with Autologous Tissue Substitute, Percutaneous Approach */
"0016375" = "1" /* Bypass Cerebral Ventricle to Intestine with Autologous Tissue Substitute, Percutaneous Approach */
"0016376" = "1" /* Bypass Cerebral Ventricle to Peritoneal Cavity with Autologous Tissue Substitute, Percutaneous Approach */
"0016377" = "1" /* Bypass Cerebral Ventricle to Urinary Tract with Autologous Tissue Substitute, Percutaneous Approach */
"0016378" = "1" /* Bypass Cerebral Ventricle to Bone Marrow with Autologous Tissue Substitute, Percutaneous Approach */
"001637B" = "1" /* Bypass Cerebral Ventricle to Cerebral Cisterns with Autologous Tissue Substitute, Percutaneous Approach */
"00163J0" = "1" /* Bypass Cerebral Ventricle to Nasopharynx with Synthetic Substitute, Percutaneous Approach */
"00163J1" = "1" /* Bypass Cerebral Ventricle to Mastoid Sinus with Synthetic Substitute, Percutaneous Approach */
"00163J2" = "1" /* Bypass Cerebral Ventricle to Atrium with Synthetic Substitute, Percutaneous Approach */
"00163J3" = "1" /* Bypass Cerebral Ventricle to Blood Vessel with Synthetic Substitute, Percutaneous Approach */
"00163J4" = "1" /* Bypass Cerebral Ventricle to Pleural Cavity with Synthetic Substitute, Percutaneous Approach */
"00163J5" = "1" /* Bypass Cerebral Ventricle to Intestine with Synthetic Substitute, Percutaneous Approach */
"00163J6" = "1" /* Bypass Cerebral Ventricle to Peritoneal Cavity with Synthetic Substitute, Percutaneous Approach */
"00163J7" = "1" /* Bypass Cerebral Ventricle to Urinary Tract with Synthetic Substitute, Percutaneous Approach */
"00163J8" = "1" /* Bypass Cerebral Ventricle to Bone Marrow with Synthetic Substitute, Percutaneous Approach */
"00163JB" = "1" /* Bypass Cerebral Ventricle to Cerebral Cisterns with Synthetic Substitute, Percutaneous Approach */
"00163K0" = "1" /* Bypass Cerebral Ventricle to Nasopharynx with Nonautologous Tissue Substitute, Percutaneous Approach */
"00163K1" = "1" /* Bypass Cerebral Ventricle to Mastoid Sinus with Nonautologous Tissue Substitute, Percutaneous Approach */
"00163K2" = "1" /* Bypass Cerebral Ventricle to Atrium with Nonautologous Tissue Substitute, Percutaneous Approach */
"00163K3" = "1" /* Bypass Cerebral Ventricle to Blood Vessel with Nonautologous Tissue Substitute, Percutaneous Approach */
"00163K4" = "1" /* Bypass Cerebral Ventricle to Pleural Cavity with Nonautologous Tissue Substitute, Percutaneous Approach */
"00163K5" = "1" /* Bypass Cerebral Ventricle to Intestine with Nonautologous Tissue Substitute, Percutaneous Approach */
"00163K6" = "1" /* Bypass Cerebral Ventricle to Peritoneal Cavity with Nonautologous Tissue Substitute, Percutaneous Approach */
"00163K7" = "1" /* Bypass Cerebral Ventricle to Urinary Tract with Nonautologous Tissue Substitute, Percutaneous Approach */
"00163K8" = "1" /* Bypass Cerebral Ventricle to Bone Marrow with Nonautologous Tissue Substitute, Percutaneous Approach */
"00163KB" = "1" /* Bypass Cerebral Ventricle to Cerebral Cisterns with Nonautologous Tissue Substitute, Percutaneous Approach */
"001U074" = "1" /* Bypass Spinal Canal to Pleural Cavity with Autologous Tissue Substitute, Open Approach */
"001U076" = "1" /* Bypass Spinal Canal to Peritoneal Cavity with Autologous Tissue Substitute, Open Approach */
"001U077" = "1" /* Bypass Spinal Canal to Urinary Tract with Autologous Tissue Substitute, Open Approach */
"001U079" = "1" /* Bypass Spinal Canal to Fallopian Tube with Autologous Tissue Substitute, Open Approach */
"001U0J4" = "1" /* Bypass Spinal Canal to Pleural Cavity with Synthetic Substitute, Open Approach */
"001U0J6" = "1" /* Bypass Spinal Canal to Peritoneal Cavity with Synthetic Substitute, Open Approach */
"001U0J7" = "1" /* Bypass Spinal Canal to Urinary Tract with Synthetic Substitute, Open Approach */
"001U0J9" = "1" /* Bypass Spinal Canal to Fallopian Tube with Synthetic Substitute, Open Approach */
"001U0K4" = "1" /* Bypass Spinal Canal to Pleural Cavity with Nonautologous Tissue Substitute, Open Approach */
"001U0K6" = "1" /* Bypass Spinal Canal to Peritoneal Cavity with Nonautologous Tissue Substitute, Open Approach */
"001U0K7" = "1" /* Bypass Spinal Canal to Urinary Tract with Nonautologous Tissue Substitute, Open Approach */
"001U0K9" = "1" /* Bypass Spinal Canal to Fallopian Tube with Nonautologous Tissue Substitute, Open Approach */
"001U374" = "1" /* Bypass Spinal Canal to Pleural Cavity with Autologous Tissue Substitute, Percutaneous Approach */
"001U376" = "1" /* Bypass Spinal Canal to Peritoneal Cavity with Autologous Tissue Substitute, Percutaneous Approach */
"001U377" = "1" /* Bypass Spinal Canal to Urinary Tract with Autologous Tissue Substitute, Percutaneous Approach */
"001U379" = "1" /* Bypass Spinal Canal to Fallopian Tube with Autologous Tissue Substitute, Percutaneous Approach */
"001U3J4" = "1" /* Bypass Spinal Canal to Pleural Cavity with Synthetic Substitute, Percutaneous Approach */
"001U3J6" = "1" /* Bypass Spinal Canal to Peritoneal Cavity with Synthetic Substitute, Percutaneous Approach */
"001U3J7" = "1" /* Bypass Spinal Canal to Urinary Tract with Synthetic Substitute, Percutaneous Approach */
"001U3J9" = "1" /* Bypass Spinal Canal to Fallopian Tube with Synthetic Substitute, Percutaneous Approach */
"001U3K4" = "1" /* Bypass Spinal Canal to Pleural Cavity with Nonautologous Tissue Substitute, Percutaneous Approach */
"001U3K6" = "1" /* Bypass Spinal Canal to Peritoneal Cavity with Nonautologous Tissue Substitute, Percutaneous Approach */
"001U3K7" = "1" /* Bypass Spinal Canal to Urinary Tract with Nonautologous Tissue Substitute, Percutaneous Approach */
"001U3K9" = "1" /* Bypass Spinal Canal to Fallopian Tube with Nonautologous Tissue Substitute, Percutaneous Approach */
"00500ZZ" = "1" /* Destruction of Brain, Open Approach */
"00503ZZ" = "1" /* Destruction of Brain, Percutaneous Approach */
"00504ZZ" = "1" /* Destruction of Brain, Percutaneous Endoscopic Approach */
"00510ZZ" = "1" /* Destruction of Cerebral Meninges, Open Approach */
"00513ZZ" = "1" /* Destruction of Cerebral Meninges, Percutaneous Approach */
"00514ZZ" = "1" /* Destruction of Cerebral Meninges, Percutaneous Endoscopic Approach */
"00520ZZ" = "1" /* Destruction of Dura Mater, Open Approach */
"00523ZZ" = "1" /* Destruction of Dura Mater, Percutaneous Approach */
"00524ZZ" = "1" /* Destruction of Dura Mater, Percutaneous Endoscopic Approach */
"00560ZZ" = "1" /* Destruction of Cerebral Ventricle, Open Approach */
"00563ZZ" = "1" /* Destruction of Cerebral Ventricle, Percutaneous Approach */
"00564ZZ" = "1" /* Destruction of Cerebral Ventricle, Percutaneous Endoscopic Approach */
"00570ZZ" = "1" /* Destruction of Cerebral Hemisphere, Open Approach */
"00573ZZ" = "1" /* Destruction of Cerebral Hemisphere, Percutaneous Approach */
"00574ZZ" = "1" /* Destruction of Cerebral Hemisphere, Percutaneous Endoscopic Approach */
"00580ZZ" = "1" /* Destruction of Basal Ganglia, Open Approach */
"00583ZZ" = "1" /* Destruction of Basal Ganglia, Percutaneous Approach */
"00584ZZ" = "1" /* Destruction of Basal Ganglia, Percutaneous Endoscopic Approach */
"00590ZZ" = "1" /* Destruction of Thalamus, Open Approach */
"00593ZZ" = "1" /* Destruction of Thalamus, Percutaneous Approach */
"00594ZZ" = "1" /* Destruction of Thalamus, Percutaneous Endoscopic Approach */
"005A0ZZ" = "1" /* Destruction of Hypothalamus, Open Approach */
"005A3ZZ" = "1" /* Destruction of Hypothalamus, Percutaneous Approach */
"005A4ZZ" = "1" /* Destruction of Hypothalamus, Percutaneous Endoscopic Approach */
"005B0ZZ" = "1" /* Destruction of Pons, Open Approach */
"005B3ZZ" = "1" /* Destruction of Pons, Percutaneous Approach */
"005B4ZZ" = "1" /* Destruction of Pons, Percutaneous Endoscopic Approach */
"005C0ZZ" = "1" /* Destruction of Cerebellum, Open Approach */
"005C3ZZ" = "1" /* Destruction of Cerebellum, Percutaneous Approach */
"005C4ZZ" = "1" /* Destruction of Cerebellum, Percutaneous Endoscopic Approach */
"005D0ZZ" = "1" /* Destruction of Medulla Oblongata, Open Approach */
"005D3ZZ" = "1" /* Destruction of Medulla Oblongata, Percutaneous Approach */
"005D4ZZ" = "1" /* Destruction of Medulla Oblongata, Percutaneous Endoscopic Approach */
"005T0ZZ" = "1" /* Destruction of Spinal Meninges, Open Approach */
"005T3ZZ" = "1" /* Destruction of Spinal Meninges, Percutaneous Approach */
"005T4ZZ" = "1" /* Destruction of Spinal Meninges, Percutaneous Endoscopic Approach */
"005W0ZZ" = "1" /* Destruction of Cervical Spinal Cord, Open Approach */
"005W3ZZ" = "1" /* Destruction of Cervical Spinal Cord, Percutaneous Approach */
"005W4ZZ" = "1" /* Destruction of Cervical Spinal Cord, Percutaneous Endoscopic Approach */
"005X0ZZ" = "1" /* Destruction of Thoracic Spinal Cord, Open Approach */
"005X3ZZ" = "1" /* Destruction of Thoracic Spinal Cord, Percutaneous Approach */
"005X4ZZ" = "1" /* Destruction of Thoracic Spinal Cord, Percutaneous Endoscopic Approach */
"005Y0ZZ" = "1" /* Destruction of Lumbar Spinal Cord, Open Approach */
"005Y3ZZ" = "1" /* Destruction of Lumbar Spinal Cord, Percutaneous Approach */
"005Y4ZZ" = "1" /* Destruction of Lumbar Spinal Cord, Percutaneous Endoscopic Approach */
"00800ZZ" = "1" /* Division of Brain, Open Approach */
"00803ZZ" = "1" /* Division of Brain, Percutaneous Approach */
"00804ZZ" = "1" /* Division of Brain, Percutaneous Endoscopic Approach */
"00870ZZ" = "1" /* Division of Cerebral Hemisphere, Open Approach */
"00873ZZ" = "1" /* Division of Cerebral Hemisphere, Percutaneous Approach */
"00874ZZ" = "1" /* Division of Cerebral Hemisphere, Percutaneous Endoscopic Approach */
"00880ZZ" = "1" /* Division of Basal Ganglia, Open Approach */
"00883ZZ" = "1" /* Division of Basal Ganglia, Percutaneous Approach */
"00884ZZ" = "1" /* Division of Basal Ganglia, Percutaneous Endoscopic Approach */
"008F0ZZ" = "1" /* Division of Olfactory Nerve, Open Approach */
"008F3ZZ" = "1" /* Division of Olfactory Nerve, Percutaneous Approach */
"008F4ZZ" = "1" /* Division of Olfactory Nerve, Percutaneous Endoscopic Approach */
"008G0ZZ" = "1" /* Division of Optic Nerve, Open Approach */
"008G3ZZ" = "1" /* Division of Optic Nerve, Percutaneous Approach */
"008G4ZZ" = "1" /* Division of Optic Nerve, Percutaneous Endoscopic Approach */
"008H0ZZ" = "1" /* Division of Oculomotor Nerve, Open Approach */
"008H3ZZ" = "1" /* Division of Oculomotor Nerve, Percutaneous Approach */
"008H4ZZ" = "1" /* Division of Oculomotor Nerve, Percutaneous Endoscopic Approach */
"008J0ZZ" = "1" /* Division of Trochlear Nerve, Open Approach */
"008J3ZZ" = "1" /* Division of Trochlear Nerve, Percutaneous Approach */
"008J4ZZ" = "1" /* Division of Trochlear Nerve, Percutaneous Endoscopic Approach */
"008K0ZZ" = "1" /* Division of Trigeminal Nerve, Open Approach */
"008K3ZZ" = "1" /* Division of Trigeminal Nerve, Percutaneous Approach */
"008K4ZZ" = "1" /* Division of Trigeminal Nerve, Percutaneous Endoscopic Approach */
"008L0ZZ" = "1" /* Division of Abducens Nerve, Open Approach */
"008L3ZZ" = "1" /* Division of Abducens Nerve, Percutaneous Approach */
"008L4ZZ" = "1" /* Division of Abducens Nerve, Percutaneous Endoscopic Approach */
"008M0ZZ" = "1" /* Division of Facial Nerve, Open Approach */
"008M3ZZ" = "1" /* Division of Facial Nerve, Percutaneous Approach */
"008M4ZZ" = "1" /* Division of Facial Nerve, Percutaneous Endoscopic Approach */
"008N0ZZ" = "1" /* Division of Acoustic Nerve, Open Approach */
"008N3ZZ" = "1" /* Division of Acoustic Nerve, Percutaneous Approach */
"008N4ZZ" = "1" /* Division of Acoustic Nerve, Percutaneous Endoscopic Approach */
"008P0ZZ" = "1" /* Division of Glossopharyngeal Nerve, Open Approach */
"008P3ZZ" = "1" /* Division of Glossopharyngeal Nerve, Percutaneous Approach */
"008P4ZZ" = "1" /* Division of Glossopharyngeal Nerve, Percutaneous Endoscopic Approach */
"008Q0ZZ" = "1" /* Division of Vagus Nerve, Open Approach */
"008Q3ZZ" = "1" /* Division of Vagus Nerve, Percutaneous Approach */
"008Q4ZZ" = "1" /* Division of Vagus Nerve, Percutaneous Endoscopic Approach */
"008R0ZZ" = "1" /* Division of Accessory Nerve, Open Approach */
"008R3ZZ" = "1" /* Division of Accessory Nerve, Percutaneous Approach */
"008R4ZZ" = "1" /* Division of Accessory Nerve, Percutaneous Endoscopic Approach */
"008S0ZZ" = "1" /* Division of Hypoglossal Nerve, Open Approach */
"008S3ZZ" = "1" /* Division of Hypoglossal Nerve, Percutaneous Approach */
"008S4ZZ" = "1" /* Division of Hypoglossal Nerve, Percutaneous Endoscopic Approach */
"008W0ZZ" = "1" /* Division of Cervical Spinal Cord, Open Approach */
"008W3ZZ" = "1" /* Division of Cervical Spinal Cord, Percutaneous Approach */
"008W4ZZ" = "1" /* Division of Cervical Spinal Cord, Percutaneous Endoscopic Approach */
"008X0ZZ" = "1" /* Division of Thoracic Spinal Cord, Open Approach */
"008X3ZZ" = "1" /* Division of Thoracic Spinal Cord, Percutaneous Approach */
"008X4ZZ" = "1" /* Division of Thoracic Spinal Cord, Percutaneous Endoscopic Approach */
"008Y0ZZ" = "1" /* Division of Lumbar Spinal Cord, Open Approach */
"008Y3ZZ" = "1" /* Division of Lumbar Spinal Cord, Percutaneous Approach */
"008Y4ZZ" = "1" /* Division of Lumbar Spinal Cord, Percutaneous Endoscopic Approach */
"009000Z" = "1" /* Drainage of Brain with Drainage Device, Open Approach */
"00900ZX" = "1" /* Drainage of Brain, Open Approach, Diagnostic */
"00900ZZ" = "1" /* Drainage of Brain, Open Approach */
"009030Z" = "1" /* Drainage of Brain with Drainage Device, Percutaneous Approach */
"00903ZZ" = "1" /* Drainage of Brain, Percutaneous Approach */
"009040Z" = "1" /* Drainage of Brain with Drainage Device, Percutaneous Endoscopic Approach */
"00904ZZ" = "1" /* Drainage of Brain, Percutaneous Endoscopic Approach */
"009100Z" = "1" /* Drainage of Cerebral Meninges with Drainage Device, Open Approach */
"00910ZX" = "1" /* Drainage of Cerebral Meninges, Open Approach, Diagnostic */
"00910ZZ" = "1" /* Drainage of Cerebral Meninges, Open Approach */
"009140Z" = "1" /* Drainage of cerebral meninges with drainage device, percutaneous endoscopic approach. */
"00914ZZ" = "1" /* Drainage of cerebral meninges with drainage device, percutaneous endoscopic approach. */
"009200Z" = "1" /* Drainage of Dura Mater with Drainage Device, Open Approach */
"00920ZX" = "1" /* Drainage of Dura Mater, Open Approach, Diagnostic */
"00920ZZ" = "1" /* Drainage of Dura Mater, Open Approach */
"009240Z" = "1" /* Drainage of dura mater with drainage device, percutaneous endoscopic approach. */
"00924ZZ" = "1" /* Drainage of dura mater, percutaneous endoscopic approach. */
"009300Z" = "1" /* Drainage of Epidural Space with Drainage Device, Open Approach */
"00930ZX" = "1" /* Drainage of Epidural Space, Open Approach, Diagnostic */
"00930ZZ" = "1" /* Drainage of Epidural Space, Open Approach */
"009340Z" = "1" /* Drainage of Epidural Space with Drainage Device, Percutaneous Endoscopic Approach */
"00934ZZ" = "1" /* Drainage of Epidural Space, Percutaneous Endoscopic Approach */
"009400Z" = "1" /* Drainage of Subdural Space with Drainage Device, Open Approach */
"00940ZX" = "1" /* Drainage of Subdural Space, Open Approach, Diagnostic */
"00940ZZ" = "1" /* Drainage of Subdural Space, Open Approach */
"009440Z" = "1" /* Drainage of subdural space with drainage device, percutaneous endoscopic approach. */
"00944ZZ" = "1" /* Drainage of subdural space, percutaneous endoscopic approach. */
"009500Z" = "1" /* Drainage of Subarachnoid Space with Drainage Device, Open Approach */
"00950ZX" = "1" /* Drainage of Subarachnoid Space, Open Approach, Diagnostic */
"00950ZZ" = "1" /* Drainage of Subarachnoid Space, Open Approach */
"009540Z" = "1" /* Drainage of subarachnoid space with drainage device, percutaneous endoscopic approach. */
"009600Z" = "1" /* Drainage of Cerebral Ventricle with Drainage Device, Open Approach */
"00960ZX" = "1" /* Drainage of Cerebral Ventricle, Open Approach, Diagnostic */
"00960ZZ" = "1" /* Drainage of Cerebral Ventricle, Open Approach */
"009630Z" = "1" /* Drainage of Cerebral Ventricle with Drainage Device, Percutaneous Approach */
"00963ZZ" = "1" /* Drainage of cerebral ventricle, percutaneous approach. */
"009640Z" = "1" /* Drainage of Cerebral Ventricle with Drainage Device, Percutaneous Endoscopic Approach */
"00964ZZ" = "1" /* Drainage of cerebral ventricle, percutaneous endoscopic approach. */
"009700Z" = "1" /* Drainage of Cerebral Hemisphere with Drainage Device, Open Approach */
"00970ZX" = "1" /* Drainage of Cerebral Hemisphere, Open Approach, Diagnostic */
"00970ZZ" = "1" /* Drainage of Cerebral Hemisphere, Open Approach */
"009730Z" = "1" /* Drainage of Cerebral Hemisphere with Drainage Device, Percutaneous Approach */
"00973ZZ" = "1" /* Drainage of Cerebral Hemisphere, Percutaneous Approach */
"009740Z" = "1" /* Drainage of Cerebral Hemisphere with Drainage Device, Percutaneous Endoscopic Approach */
"00974ZZ" = "1" /* Drainage of Cerebral Hemisphere, Percutaneous Endoscopic Approach */
"009800Z" = "1" /* Drainage of Basal Ganglia with Drainage Device, Open Approach */
"00980ZX" = "1" /* Drainage of Basal Ganglia, Open Approach, Diagnostic */
"00980ZZ" = "1" /* Drainage of Basal Ganglia, Open Approach */
"009830Z" = "1" /* Drainage of Basal Ganglia with Drainage Device, Percutaneous Approach */
"00983ZZ" = "1" /* Drainage of Basal Ganglia, Percutaneous Approach */
"009840Z" = "1" /* Drainage of Basal Ganglia with Drainage Device, Percutaneous Endoscopic Approach */
"00984ZZ" = "1" /* Drainage of Basal Ganglia, Percutaneous Endoscopic Approach */
"009900Z" = "1" /* Drainage of Thalamus with Drainage Device, Open Approach */
"00990ZX" = "1" /* Drainage of Thalamus, Open Approach, Diagnostic */
"00990ZZ" = "1" /* Drainage of Thalamus, Open Approach */
"009930Z" = "1" /* Drainage of Thalamus with Drainage Device, Percutaneous Approach */
"00993ZZ" = "1" /* Drainage of Thalamus, Percutaneous Approach */
"009940Z" = "1" /* Drainage of Thalamus with Drainage Device, Percutaneous Endoscopic Approach */
"00994ZZ" = "1" /* Drainage of Thalamus, Percutaneous Endoscopic Approach */
"009A00Z" = "1" /* Drainage of Hypothalamus with Drainage Device, Open Approach */
"009A0ZX" = "1" /* Drainage of Hypothalamus, Open Approach, Diagnostic */
"009A0ZZ" = "1" /* Drainage of Hypothalamus, Open Approach */
"009A30Z" = "1" /* Drainage of Hypothalamus with Drainage Device, Percutaneous Approach */
"009A3ZZ" = "1" /* Drainage of Hypothalamus, Percutaneous Approach */
"009A40Z" = "1" /* Drainage of Hypothalamus with Drainage Device, Percutaneous Endoscopic Approach */
"009A4ZZ" = "1" /* Drainage of Hypothalamus, Percutaneous Endoscopic Approach */
"009B00Z" = "1" /* Drainage of Pons with Drainage Device, Open Approach */
"009B0ZX" = "1" /* Drainage of Pons, Open Approach, Diagnostic */
"009B0ZZ" = "1" /* Drainage of Pons, Open Approach */
"009B30Z" = "1" /* Drainage of Pons with Drainage Device, Percutaneous Approach */
"009B3ZZ" = "1" /* Drainage of Pons, Percutaneous Approach */
"009B40Z" = "1" /* Drainage of Pons with Drainage Device, Percutaneous Endoscopic Approach */
"009B4ZZ" = "1" /* Drainage of Pons, Percutaneous Endoscopic Approach */
"009C00Z" = "1" /* Drainage of Cerebellum with Drainage Device, Open Approach */
"009C0ZX" = "1" /* Drainage of Cerebellum, Open Approach, Diagnostic */
"009C0ZZ" = "1" /* Drainage of Cerebellum, Open Approach */
"009C30Z" = "1" /* Drainage of Cerebellum with Drainage Device, Percutaneous Approach */
"009C3ZZ" = "1" /* Drainage of Cerebellum, Percutaneous Approach */
"009C40Z" = "1" /* Drainage of Cerebellum with Drainage Device, Percutaneous Endoscopic Approach */
"009C4ZZ" = "1" /* Drainage of Cerebellum, Percutaneous Endoscopic Approach */
"009D00Z" = "1" /* Drainage of Medulla Oblongata with Drainage Device, Open Approach */
"009D0ZX" = "1" /* Drainage of Medulla Oblongata, Open Approach, Diagnostic */
"009D0ZZ" = "1" /* Drainage of Medulla Oblongata, Open Approach */
"009D30Z" = "1" /* Drainage of Medulla Oblongata with Drainage Device, Percutaneous Approach */
"009D3ZZ" = "1" /* Drainage of Medulla Oblongata, Percutaneous Approach */
"009D40Z" = "1" /* Drainage of Medulla Oblongata with Drainage Device, Percutaneous Endoscopic Approach */
"009D4ZZ" = "1" /* Drainage of Medulla Oblongata, Percutaneous Endoscopic Approach */
"009F00Z" = "1" /* Drainage of Olfactory Nerve with Drainage Device, Open Approach */
"009F0ZX" = "1" /* Drainage of Olfactory Nerve, Open Approach, Diagnostic */
"009F0ZZ" = "1" /* Drainage of Olfactory Nerve, Open Approach */
"009F30Z" = "1" /* Drainage of Olfactory Nerve with Drainage Device, Percutaneous Approach */
"009F3ZZ" = "1" /* Drainage of Olfactory Nerve, Percutaneous Approach */
"009F40Z" = "1" /* Drainage of Olfactory Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"009F4ZZ" = "1" /* Drainage of Olfactory Nerve, Percutaneous Endoscopic Approach */
"009G00Z" = "1" /* Drainage of Optic Nerve with Drainage Device, Open Approach */
"009G0ZX" = "1" /* Drainage of Optic Nerve, Open Approach, Diagnostic */
"009G0ZZ" = "1" /* Drainage of Optic Nerve, Open Approach */
"009G30Z" = "1" /* Drainage of Optic Nerve with Drainage Device, Percutaneous Approach */
"009G3ZZ" = "1" /* Drainage of Optic Nerve, Percutaneous Approach */
"009G40Z" = "1" /* Drainage of Optic Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"009G4ZZ" = "1" /* Drainage of Optic Nerve, Percutaneous Endoscopic Approach */
"009H00Z" = "1" /* Drainage of Oculomotor Nerve with Drainage Device, Open Approach */
"009H0ZX" = "1" /* Drainage of Oculomotor Nerve, Open Approach, Diagnostic */
"009H0ZZ" = "1" /* Drainage of Oculomotor Nerve, Open Approach */
"009H30Z" = "1" /* Drainage of Oculomotor Nerve with Drainage Device, Percutaneous Approach */
"009H3ZZ" = "1" /* Drainage of Oculomotor Nerve, Percutaneous Approach */
"009H40Z" = "1" /* Drainage of Oculomotor Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"009H4ZZ" = "1" /* Drainage of Oculomotor Nerve, Percutaneous Endoscopic Approach */
"009J00Z" = "1" /* Drainage of Trochlear Nerve with Drainage Device, Open Approach */
"009J0ZX" = "1" /* Drainage of Trochlear Nerve, Open Approach, Diagnostic */
"009J0ZZ" = "1" /* Drainage of Trochlear Nerve, Open Approach */
"009J30Z" = "1" /* Drainage of Trochlear Nerve with Drainage Device, Percutaneous Approach */
"009J3ZZ" = "1" /* Drainage of Trochlear Nerve, Percutaneous Approach */
"009J40Z" = "1" /* Drainage of Trochlear Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"009J4ZZ" = "1" /* Drainage of Trochlear Nerve, Percutaneous Endoscopic Approach */
"009K00Z" = "1" /* Drainage of Trigeminal Nerve with Drainage Device, Open Approach */
"009K0ZX" = "1" /* Drainage of Trigeminal Nerve, Open Approach, Diagnostic */
"009K0ZZ" = "1" /* Drainage of Trigeminal Nerve, Open Approach */
"009K30Z" = "1" /* Drainage of Trigeminal Nerve with Drainage Device, Percutaneous Approach */
"009K3ZZ" = "1" /* Drainage of Trigeminal Nerve, Percutaneous Approach */
"009K40Z" = "1" /* Drainage of Trigeminal Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"009K4ZZ" = "1" /* Drainage of Trigeminal Nerve, Percutaneous Endoscopic Approach */
"009L00Z" = "1" /* Drainage of Abducens Nerve with Drainage Device, Open Approach */
"009L0ZX" = "1" /* Drainage of Abducens Nerve, Open Approach, Diagnostic */
"009L0ZZ" = "1" /* Drainage of Abducens Nerve, Open Approach */
"009L30Z" = "1" /* Drainage of Abducens Nerve with Drainage Device, Percutaneous Approach */
"009L3ZZ" = "1" /* Drainage of Abducens Nerve, Percutaneous Approach */
"009L40Z" = "1" /* Drainage of Abducens Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"009L4ZZ" = "1" /* Drainage of Abducens Nerve, Percutaneous Endoscopic Approach */
"009M00Z" = "1" /* Drainage of Facial Nerve with Drainage Device, Open Approach */
"009M0ZX" = "1" /* Drainage of Facial Nerve, Open Approach, Diagnostic */
"009M0ZZ" = "1" /* Drainage of Facial Nerve, Open Approach */
"009M30Z" = "1" /* Drainage of Facial Nerve with Drainage Device, Percutaneous Approach */
"009M3ZZ" = "1" /* Drainage of Facial Nerve, Percutaneous Approach */
"009M40Z" = "1" /* Drainage of Facial Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"009M4ZZ" = "1" /* Drainage of Facial Nerve, Percutaneous Endoscopic Approach */
"009N00Z" = "1" /* Drainage of Acoustic Nerve with Drainage Device, Open Approach */
"009N0ZX" = "1" /* Drainage of Acoustic Nerve, Open Approach, Diagnostic */
"009N0ZZ" = "1" /* Drainage of Acoustic Nerve, Open Approach */
"009N30Z" = "1" /* Drainage of Acoustic Nerve with Drainage Device, Percutaneous Approach */
"009N3ZZ" = "1" /* Drainage of Acoustic Nerve, Percutaneous Approach */
"009N40Z" = "1" /* Drainage of Acoustic Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"009N4ZZ" = "1" /* Drainage of Acoustic Nerve, Percutaneous Endoscopic Approach */
"009P00Z" = "1" /* Drainage of Glossopharyngeal Nerve with Drainage Device, Open Approach */
"009P0ZX" = "1" /* Drainage of Glossopharyngeal Nerve, Open Approach, Diagnostic */
"009P0ZZ" = "1" /* Drainage of Glossopharyngeal Nerve, Open Approach */
"009P30Z" = "1" /* Drainage of Glossopharyngeal Nerve with Drainage Device, Percutaneous Approach */
"009P3ZZ" = "1" /* Drainage of Glossopharyngeal Nerve, Percutaneous Approach */
"009P40Z" = "1" /* Drainage of Glossopharyngeal Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"009P4ZZ" = "1" /* Drainage of Glossopharyngeal Nerve, Percutaneous Endoscopic Approach */
"009Q00Z" = "1" /* Drainage of Vagus Nerve with Drainage Device, Open Approach */
"009Q0ZX" = "1" /* Drainage of Vagus Nerve, Open Approach, Diagnostic */
"009Q0ZZ" = "1" /* Drainage of Vagus Nerve, Open Approach */
"009Q30Z" = "1" /* Drainage of Vagus Nerve with Drainage Device, Percutaneous Approach */
"009Q3ZZ" = "1" /* Drainage of Vagus Nerve, Percutaneous Approach */
"009Q40Z" = "1" /* Drainage of Vagus Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"009Q4ZZ" = "1" /* Drainage of Vagus Nerve, Percutaneous Endoscopic Approach */
"009R00Z" = "1" /* Drainage of Accessory Nerve with Drainage Device, Open Approach */
"009R0ZX" = "1" /* Drainage of Accessory Nerve, Open Approach, Diagnostic */
"009R0ZZ" = "1" /* Drainage of Accessory Nerve, Open Approach */
"009R30Z" = "1" /* Drainage of Accessory Nerve with Drainage Device, Percutaneous Approach */
"009R3ZZ" = "1" /* Drainage of Accessory Nerve, Percutaneous Approach */
"009R40Z" = "1" /* Drainage of Accessory Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"009R4ZZ" = "1" /* Drainage of Accessory Nerve, Percutaneous Endoscopic Approach */
"009S00Z" = "1" /* Drainage of Hypoglossal Nerve with Drainage Device, Open Approach */
"009S0ZX" = "1" /* Drainage of Hypoglossal Nerve, Open Approach, Diagnostic */
"009S0ZZ" = "1" /* Drainage of Hypoglossal Nerve, Open Approach */
"009S30Z" = "1" /* Drainage of Hypoglossal Nerve with Drainage Device, Percutaneous Approach */
"009S3ZZ" = "1" /* Drainage of Hypoglossal Nerve, Percutaneous Approach */
"009S40Z" = "1" /* Drainage of Hypoglossal Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"009S4ZZ" = "1" /* Drainage of Hypoglossal Nerve, Percutaneous Endoscopic Approach */
"009T00Z" = "1" /* Drainage of Spinal Meninges with Drainage Device, Open Approach */
"009T0ZX" = "1" /* Drainage of Spinal Meninges, Open Approach, Diagnostic */
"009T0ZZ" = "1" /* Drainage of Spinal Meninges, Open Approach */
"009T40Z" = "1" /* Drainage of Spinal Meninges with Drainage Device, Percutaneous Endoscopic Approach */
"009T4ZX" = "1" /* Drainage of Spinal Meninges, Percutaneous Endoscopic Approach, Diagnostic */
"009T4ZZ" = "1" /* Drainage of Spinal Meninges, Percutaneous Endoscopic Approach */
"009U00Z" = "1" /* Drainage of Spinal Canal with Drainage Device, Open Approach */
"009U0ZX" = "1" /* Drainage of Spinal Canal, Open Approach, Diagnostic */
"009U0ZZ" = "1" /* Drainage of Spinal Canal, Open Approach */
"009W00Z" = "1" /* Drainage of Cervical Spinal Cord with Drainage Device, Open Approach */
"009W0ZX" = "1" /* Drainage of Cervical Spinal Cord, Open Approach, Diagnostic */
"009W0ZZ" = "1" /* Drainage of Cervical Spinal Cord, Open Approach */
"009W40Z" = "1" /* Drainage of Cervical Spinal Cord with Drainage Device, Percutaneous Endoscopic Approach */
"009W4ZX" = "1" /* Drainage of Cervical Spinal Cord, Percutaneous Endoscopic Approach, Diagnostic */
"009W4ZZ" = "1" /* Drainage of Cervical Spinal Cord, Percutaneous Endoscopic Approach */
"009X00Z" = "1" /* Drainage of Thoracic Spinal Cord with Drainage Device, Open Approach */
"009X0ZX" = "1" /* Drainage of Thoracic Spinal Cord, Open Approach, Diagnostic */
"009X0ZZ" = "1" /* Drainage of Thoracic Spinal Cord, Open Approach */
"009X40Z" = "1" /* Drainage of Thoracic Spinal Cord with Drainage Device, Percutaneous Endoscopic Approach */
"009X4ZX" = "1" /* Drainage of Thoracic Spinal Cord, Percutaneous Endoscopic Approach, Diagnostic */
"009X4ZZ" = "1" /* Drainage of Thoracic Spinal Cord, Percutaneous Endoscopic Approach */
"009Y00Z" = "1" /* Drainage of Lumbar Spinal Cord with Drainage Device, Open Approach */
"009Y0ZX" = "1" /* Drainage of Lumbar Spinal Cord, Open Approach, Diagnostic */
"009Y0ZZ" = "1" /* Drainage of Lumbar Spinal Cord, Open Approach */
"009Y40Z" = "1" /* Drainage of Lumbar Spinal Cord with Drainage Device, Percutaneous Endoscopic Approach */
"009Y4ZX" = "1" /* Drainage of Lumbar Spinal Cord, Percutaneous Endoscopic Approach, Diagnostic */
"009Y4ZZ" = "1" /* Drainage of Lumbar Spinal Cord, Percutaneous Endoscopic Approach */
"00B00ZX" = "1" /* Excision of Brain, Open Approach, Diagnostic */
"00B00ZZ" = "1" /* Excision of Brain, Open Approach */
"00B03ZZ" = "1" /* Excision of Brain, Percutaneous Approach */
"00B04ZZ" = "1" /* Excision of Brain, Percutaneous Endoscopic Approach */
"00B10ZX" = "1" /* Excision of Cerebral Meninges, Open Approach, Diagnostic */
"00B10ZZ" = "1" /* Excision of Cerebral Meninges, Open Approach */
"00B13ZZ" = "1" /* Excision of Cerebral Meninges, Percutaneous Approach */
"00B14ZZ" = "1" /* Excision of Cerebral Meninges, Percutaneous Endoscopic Approach */
"00B20ZX" = "1" /* Excision of Dura Mater, Open Approach, Diagnostic */
"00B20ZZ" = "1" /* Excision of Dura Mater, Open Approach */
"00B23ZZ" = "1" /* Excision of Dura Mater, Percutaneous Approach */
"00B24ZZ" = "1" /* Excision of Dura Mater, Percutaneous Endoscopic Approach */
"00B60ZX" = "1" /* Excision of Cerebral Ventricle, Open Approach, Diagnostic */
"00B60ZZ" = "1" /* Excision of Cerebral Ventricle, Open Approach */
"00B63ZZ" = "1" /* Excision of Cerebral Ventricle, Percutaneous Approach */
"00B64ZZ" = "1" /* Excision of Cerebral Ventricle, Percutaneous Endoscopic Approach */
"00B70ZX" = "1" /* Excision of Cerebral Hemisphere, Open Approach, Diagnostic */
"00B70ZZ" = "1" /* Excision of Cerebral Hemisphere, Open Approach */
"00B73ZZ" = "1" /* Excision of Cerebral Hemisphere, Percutaneous Approach */
"00B74ZZ" = "1" /* Excision of Cerebral Hemisphere, Percutaneous Endoscopic Approach */
"00B80ZX" = "1" /* Excision of Basal Ganglia, Open Approach, Diagnostic */
"00B80ZZ" = "1" /* Excision of Basal Ganglia, Open Approach */
"00B83ZZ" = "1" /* Excision of Basal Ganglia, Percutaneous Approach */
"00B84ZZ" = "1" /* Excision of Basal Ganglia, Percutaneous Endoscopic Approach */
"00B90ZX" = "1" /* Excision of Thalamus, Open Approach, Diagnostic */
"00B90ZZ" = "1" /* Excision of Thalamus, Open Approach */
"00B93ZZ" = "1" /* Excision of Thalamus, Percutaneous Approach */
"00B94ZZ" = "1" /* Excision of Thalamus, Percutaneous Endoscopic Approach */
"00BA0ZX" = "1" /* Excision of Hypothalamus, Open Approach, Diagnostic */
"00BA0ZZ" = "1" /* Excision of Hypothalamus, Open Approach */
"00BA3ZZ" = "1" /* Excision of Hypothalamus, Percutaneous Approach */
"00BA4ZZ" = "1" /* Excision of Hypothalamus, Percutaneous Endoscopic Approach */
"00BB0ZX" = "1" /* Excision of Pons, Open Approach, Diagnostic */
"00BB0ZZ" = "1" /* Excision of Pons, Open Approach */
"00BB3ZZ" = "1" /* Excision of Pons, Percutaneous Approach */
"00BB4ZZ" = "1" /* Excision of Pons, Percutaneous Endoscopic Approach */
"00BC0ZX" = "1" /* Excision of Cerebellum, Open Approach, Diagnostic */
"00BC0ZZ" = "1" /* Excision of Cerebellum, Open Approach */
"00BC3ZZ" = "1" /* Excision of Cerebellum, Percutaneous Approach */
"00BC4ZZ" = "1" /* Excision of Cerebellum, Percutaneous Endoscopic Approach */
"00BD0ZX" = "1" /* Excision of Medulla Oblongata, Open Approach, Diagnostic */
"00BD0ZZ" = "1" /* Excision of Medulla Oblongata, Open Approach */
"00BD3ZZ" = "1" /* Excision of Medulla Oblongata, Percutaneous Approach */
"00BD4ZZ" = "1" /* Excision of Medulla Oblongata, Percutaneous Endoscopic Approach */
"00BF0ZX" = "1" /* Excision of Olfactory Nerve, Open Approach, Diagnostic */
"00BF0ZZ" = "1" /* Excision of Olfactory Nerve, Open Approach */
"00BF3ZZ" = "1" /* Excision of Olfactory Nerve, Percutaneous Approach */
"00BF4ZZ" = "1" /* Excision of Olfactory Nerve, Percutaneous Endoscopic Approach */
"00BG0ZX" = "1" /* Excision of Optic Nerve, Open Approach, Diagnostic */
"00BG0ZZ" = "1" /* Excision of Optic Nerve, Open Approach */
"00BG3ZZ" = "1" /* Excision of Optic Nerve, Percutaneous Approach */
"00BG4ZZ" = "1" /* Excision of Optic Nerve, Percutaneous Endoscopic Approach */
"00BH0ZX" = "1" /* Excision of Oculomotor Nerve, Open Approach, Diagnostic */
"00BH0ZZ" = "1" /* Excision of Oculomotor Nerve, Open Approach */
"00BH3ZZ" = "1" /* Excision of Oculomotor Nerve, Percutaneous Approach */
"00BH4ZZ" = "1" /* Excision of Oculomotor Nerve, Percutaneous Endoscopic Approach */
"00BJ0ZX" = "1" /* Excision of Trochlear Nerve, Open Approach, Diagnostic */
"00BJ0ZZ" = "1" /* Excision of Trochlear Nerve, Open Approach */
"00BJ3ZZ" = "1" /* Excision of Trochlear Nerve, Percutaneous Approach */
"00BJ4ZZ" = "1" /* Excision of Trochlear Nerve, Percutaneous Endoscopic Approach */
"00BK0ZX" = "1" /* Excision of Trigeminal Nerve, Open Approach, Diagnostic */
"00BK0ZZ" = "1" /* Excision of Trigeminal Nerve, Open Approach */
"00BK3ZZ" = "1" /* Excision of Trigeminal Nerve, Percutaneous Approach */
"00BK4ZZ" = "1" /* Excision of Trigeminal Nerve, Percutaneous Endoscopic Approach */
"00BL0ZX" = "1" /* Excision of Abducens Nerve, Open Approach, Diagnostic */
"00BL0ZZ" = "1" /* Excision of Abducens Nerve, Open Approach */
"00BL3ZZ" = "1" /* Excision of Abducens Nerve, Percutaneous Approach */
"00BL4ZZ" = "1" /* Excision of Abducens Nerve, Percutaneous Endoscopic Approach */
"00BM0ZX" = "1" /* Excision of Facial Nerve, Open Approach, Diagnostic */
"00BM0ZZ" = "1" /* Excision of Facial Nerve, Open Approach */
"00BM3ZZ" = "1" /* Excision of Facial Nerve, Percutaneous Approach */
"00BM4ZZ" = "1" /* Excision of Facial Nerve, Percutaneous Endoscopic Approach */
"00BN0ZX" = "1" /* Excision of Acoustic Nerve, Open Approach, Diagnostic */
"00BN0ZZ" = "1" /* Excision of Acoustic Nerve, Open Approach */
"00BN3ZZ" = "1" /* Excision of Acoustic Nerve, Percutaneous Approach */
"00BN4ZZ" = "1" /* Excision of Acoustic Nerve, Percutaneous Endoscopic Approach */
"00BP0ZX" = "1" /* Excision of Glossopharyngeal Nerve, Open Approach, Diagnostic */
"00BP0ZZ" = "1" /* Excision of Glossopharyngeal Nerve, Open Approach */
"00BP3ZZ" = "1" /* Excision of Glossopharyngeal Nerve, Percutaneous Approach */
"00BP4ZZ" = "1" /* Excision of Glossopharyngeal Nerve, Percutaneous Endoscopic Approach */
"00BQ0ZX" = "1" /* Excision of Vagus Nerve, Open Approach, Diagnostic */
"00BQ0ZZ" = "1" /* Excision of Vagus Nerve, Open Approach */
"00BQ3ZZ" = "1" /* Excision of Vagus Nerve, Percutaneous Approach */
"00BQ4ZZ" = "1" /* Excision of Vagus Nerve, Percutaneous Endoscopic Approach */
"00BR0ZX" = "1" /* Excision of Accessory Nerve, Open Approach, Diagnostic */
"00BR0ZZ" = "1" /* Excision of Accessory Nerve, Open Approach */
"00BR3ZZ" = "1" /* Excision of Accessory Nerve, Percutaneous Approach */
"00BR4ZZ" = "1" /* Excision of Accessory Nerve, Percutaneous Endoscopic Approach */
"00BS0ZX" = "1" /* Excision of Hypoglossal Nerve, Open Approach, Diagnostic */
"00BS0ZZ" = "1" /* Excision of Hypoglossal Nerve, Open Approach */
"00BS3ZZ" = "1" /* Excision of Hypoglossal Nerve, Percutaneous Approach */
"00BS4ZZ" = "1" /* Excision of Hypoglossal Nerve, Percutaneous Endoscopic Approach */
"00BT0ZX" = "1" /* Excision of Spinal Meninges, Open Approach, Diagnostic */
"00BT0ZZ" = "1" /* Excision of Spinal Meninges, Open Approach */
"00BT3ZX" = "1" /* Excision of Spinal Meninges, Percutaneous Approach, Diagnostic */
"00BT3ZZ" = "1" /* Excision of Spinal Meninges, Percutaneous Approach */
"00BT4ZX" = "1" /* Excision of Spinal Meninges, Percutaneous Endoscopic Approach, Diagnostic */
"00BT4ZZ" = "1" /* Excision of Spinal Meninges, Percutaneous Endoscopic Approach */
"00BW0ZX" = "1" /* Excision of Cervical Spinal Cord, Open Approach, Diagnostic */
"00BW0ZZ" = "1" /* Excision of Cervical Spinal Cord, Open Approach */
"00BW3ZX" = "1" /* Excision of Cervical Spinal Cord, Percutaneous Approach, Diagnostic */
"00BW3ZZ" = "1" /* Excision of Cervical Spinal Cord, Percutaneous Approach */
"00BW4ZX" = "1" /* Excision of Cervical Spinal Cord, Percutaneous Endoscopic Approach, Diagnostic */
"00BW4ZZ" = "1" /* Excision of Cervical Spinal Cord, Percutaneous Endoscopic Approach */
"00BX0ZX" = "1" /* Excision of Thoracic Spinal Cord, Open Approach, Diagnostic */
"00BX0ZZ" = "1" /* Excision of Thoracic Spinal Cord, Open Approach */
"00BX3ZX" = "1" /* Excision of Thoracic Spinal Cord, Percutaneous Approach, Diagnostic */
"00BX3ZZ" = "1" /* Excision of Thoracic Spinal Cord, Percutaneous Approach */
"00BX4ZX" = "1" /* Excision of Thoracic Spinal Cord, Percutaneous Endoscopic Approach, Diagnostic */
"00BX4ZZ" = "1" /* Excision of Thoracic Spinal Cord, Percutaneous Endoscopic Approach */
"00BY0ZX" = "1" /* Excision of Lumbar Spinal Cord, Open Approach, Diagnostic */
"00BY0ZZ" = "1" /* Excision of Lumbar Spinal Cord, Open Approach */
"00BY3ZX" = "1" /* Excision of Lumbar Spinal Cord, Percutaneous Approach, Diagnostic */
"00BY3ZZ" = "1" /* Excision of Lumbar Spinal Cord, Percutaneous Approach */
"00BY4ZX" = "1" /* Excision of Lumbar Spinal Cord, Percutaneous Endoscopic Approach, Diagnostic */
"00BY4ZZ" = "1" /* Excision of Lumbar Spinal Cord, Percutaneous Endoscopic Approach */
"00C00ZZ" = "1" /* Extirpation of Matter from Brain, Open Approach */
"00C03ZZ" = "1" /* Extirpation of Matter from Brain, Percutaneous Approach */
"00C04ZZ" = "1" /* Extirpation of Matter from Brain, Percutaneous Endoscopic Approach */
"00C10ZZ" = "1" /* Extirpation of Matter from Cerebral Meninges, Open Approach */
"00C13ZZ" = "1" /* Extirpation of Matter from Cerebral Meninges, Percutaneous Approach */
"00C14ZZ" = "1" /* Extirpation of Matter from Cerebral Meninges, Percutaneous Endoscopic Approach */
"00C20ZZ" = "1" /* Extirpation of Matter from Dura Mater, Open Approach */
"00C23ZZ" = "1" /* Extirpation of Matter from Dura Mater, Percutaneous Approach */
"00C24ZZ" = "1" /* Extirpation of Matter from Dura Mater, Percutaneous Endoscopic Approach */
"00C30ZZ" = "1" /* Extirpation of Matter from Epidural Space, Open Approach */
"00C33ZZ" = "1" /* Extirpation of Matter from Epidural Space, Percutaneous Approach */
"00C34ZZ" = "1" /* Extirpation of Matter from Epidural Space, Percutaneous Endoscopic Approach */
"00C40ZZ" = "1" /* Extirpation of Matter from Subdural Space, Open Approach */
"00C43ZZ" = "1" /* Extirpation of Matter from Subdural Space, Percutaneous Approach */
"00C44ZZ" = "1" /* Extirpation of Matter from Subdural Space, Percutaneous Endoscopic Approach */
"00C50ZZ" = "1" /* Extirpation of Matter from Subarachnoid Space, Open Approach */
"00C53ZZ" = "1" /* Extirpation of Matter from Subarachnoid Space, Percutaneous Approach */
"00C54ZZ" = "1" /* Extirpation of Matter from Subarachnoid Space, Percutaneous Endoscopic Approach */
"00C60ZZ" = "1" /* Extirpation of Matter from Cerebral Ventricle, Open Approach */
"00C63ZZ" = "1" /* Extirpation of Matter from Cerebral Ventricle, Percutaneous Approach */
"00C64ZZ" = "1" /* Extirpation of Matter from Cerebral Ventricle, Percutaneous Endoscopic Approach */
"00C70ZZ" = "1" /* Extirpation of Matter from Cerebral Hemisphere, Open Approach */
"00C73ZZ" = "1" /* Extirpation of Matter from Cerebral Hemisphere, Percutaneous Approach */
"00C74ZZ" = "1" /* Extirpation of Matter from Cerebral Hemisphere, Percutaneous Endoscopic Approach */
"00C80ZZ" = "1" /* Extirpation of Matter from Basal Ganglia, Open Approach */
"00C83ZZ" = "1" /* Extirpation of Matter from Basal Ganglia, Percutaneous Approach */
"00C84ZZ" = "1" /* Extirpation of Matter from Basal Ganglia, Percutaneous Endoscopic Approach */
"00C90ZZ" = "1" /* Extirpation of Matter from Thalamus, Open Approach */
"00C93ZZ" = "1" /* Extirpation of Matter from Thalamus, Percutaneous Approach */
"00C94ZZ" = "1" /* Extirpation of Matter from Thalamus, Percutaneous Endoscopic Approach */
"00CA0ZZ" = "1" /* Extirpation of Matter from Hypothalamus, Open Approach */
"00CA3ZZ" = "1" /* Extirpation of Matter from Hypothalamus, Percutaneous Approach */
"00CA4ZZ" = "1" /* Extirpation of Matter from Hypothalamus, Percutaneous Endoscopic Approach */
"00CB0ZZ" = "1" /* Extirpation of Matter from Pons, Open Approach */
"00CB3ZZ" = "1" /* Extirpation of Matter from Pons, Percutaneous Approach */
"00CB4ZZ" = "1" /* Extirpation of Matter from Pons, Percutaneous Endoscopic Approach */
"00CC0ZZ" = "1" /* Extirpation of Matter from Cerebellum, Open Approach */
"00CC3ZZ" = "1" /* Extirpation of Matter from Cerebellum, Percutaneous Approach */
"00CC4ZZ" = "1" /* Extirpation of Matter from Cerebellum, Percutaneous Endoscopic Approach */
"00CD0ZZ" = "1" /* Extirpation of Matter from Medulla Oblongata, Open Approach */
"00CD3ZZ" = "1" /* Extirpation of Matter from Medulla Oblongata, Percutaneous Approach */
"00CD4ZZ" = "1" /* Extirpation of Matter from Medulla Oblongata, Percutaneous Endoscopic Approach */
"00CF0ZZ" = "1" /* Extirpation of Matter from Olfactory Nerve, Open Approach */
"00CF3ZZ" = "1" /* Extirpation of Matter from Olfactory Nerve, Percutaneous Approach */
"00CF4ZZ" = "1" /* Extirpation of Matter from Olfactory Nerve, Percutaneous Endoscopic Approach */
"00CG0ZZ" = "1" /* Extirpation of Matter from Optic Nerve, Open Approach */
"00CG3ZZ" = "1" /* Extirpation of Matter from Optic Nerve, Percutaneous Approach */
"00CG4ZZ" = "1" /* Extirpation of Matter from Optic Nerve, Percutaneous Endoscopic Approach */
"00CH0ZZ" = "1" /* Extirpation of Matter from Oculomotor Nerve, Open Approach */
"00CH3ZZ" = "1" /* Extirpation of Matter from Oculomotor Nerve, Percutaneous Approach */
"00CH4ZZ" = "1" /* Extirpation of Matter from Oculomotor Nerve, Percutaneous Endoscopic Approach */
"00CJ0ZZ" = "1" /* Extirpation of Matter from Trochlear Nerve, Open Approach */
"00CJ3ZZ" = "1" /* Extirpation of Matter from Trochlear Nerve, Percutaneous Approach */
"00CJ4ZZ" = "1" /* Extirpation of Matter from Trochlear Nerve, Percutaneous Endoscopic Approach */
"00CK0ZZ" = "1" /* Extirpation of Matter from Trigeminal Nerve, Open Approach */
"00CK3ZZ" = "1" /* Extirpation of Matter from Trigeminal Nerve, Percutaneous Approach */
"00CK4ZZ" = "1" /* Extirpation of Matter from Trigeminal Nerve, Percutaneous Endoscopic Approach */
"00CL0ZZ" = "1" /* Extirpation of Matter from Abducens Nerve, Open Approach */
"00CL3ZZ" = "1" /* Extirpation of Matter from Abducens Nerve, Percutaneous Approach */
"00CL4ZZ" = "1" /* Extirpation of Matter from Abducens Nerve, Percutaneous Endoscopic Approach */
"00CM0ZZ" = "1" /* Extirpation of Matter from Facial Nerve, Open Approach */
"00CM3ZZ" = "1" /* Extirpation of Matter from Facial Nerve, Percutaneous Approach */
"00CM4ZZ" = "1" /* Extirpation of Matter from Facial Nerve, Percutaneous Endoscopic Approach */
"00CN0ZZ" = "1" /* Extirpation of Matter from Acoustic Nerve, Open Approach */
"00CN3ZZ" = "1" /* Extirpation of Matter from Acoustic Nerve, Percutaneous Approach */
"00CN4ZZ" = "1" /* Extirpation of Matter from Acoustic Nerve, Percutaneous Endoscopic Approach */
"00CP0ZZ" = "1" /* Extirpation of Matter from Glossopharyngeal Nerve, Open Approach */
"00CP3ZZ" = "1" /* Extirpation of Matter from Glossopharyngeal Nerve, Percutaneous Approach */
"00CP4ZZ" = "1" /* Extirpation of Matter from Glossopharyngeal Nerve, Percutaneous Endoscopic Approach */
"00CQ0ZZ" = "1" /* Extirpation of Matter from Vagus Nerve, Open Approach */
"00CQ3ZZ" = "1" /* Extirpation of Matter from Vagus Nerve, Percutaneous Approach */
"00CQ4ZZ" = "1" /* Extirpation of Matter from Vagus Nerve, Percutaneous Endoscopic Approach */
"00CR0ZZ" = "1" /* Extirpation of Matter from Accessory Nerve, Open Approach */
"00CR3ZZ" = "1" /* Extirpation of Matter from Accessory Nerve, Percutaneous Approach */
"00CR4ZZ" = "1" /* Extirpation of Matter from Accessory Nerve, Percutaneous Endoscopic Approach */
"00CS0ZZ" = "1" /* Extirpation of Matter from Hypoglossal Nerve, Open Approach */
"00CS3ZZ" = "1" /* Extirpation of Matter from Hypoglossal Nerve, Percutaneous Approach */
"00CS4ZZ" = "1" /* Extirpation of Matter from Hypoglossal Nerve, Percutaneous Endoscopic Approach */
"00CT0ZZ" = "1" /* Extirpation of Matter from Spinal Meninges, Open Approach */
"00CT3ZZ" = "1" /* Extirpation of Matter from Spinal Meninges, Percutaneous Approach */
"00CT4ZZ" = "1" /* Extirpation of Matter from Spinal Meninges, Percutaneous Endoscopic Approach */
"00CW0ZZ" = "1" /* Extirpation of Matter from Cervical Spinal Cord, Open Approach */
"00CW3ZZ" = "1" /* Extirpation of Matter from Cervical Spinal Cord, Percutaneous Approach */
"00CW4ZZ" = "1" /* Extirpation of Matter from Cervical Spinal Cord, Percutaneous Endoscopic Approach */
"00CX0ZZ" = "1" /* Extirpation of Matter from Thoracic Spinal Cord, Open Approach */
"00CX3ZZ" = "1" /* Extirpation of Matter from Thoracic Spinal Cord, Percutaneous Approach */
"00CX4ZZ" = "1" /* Extirpation of Matter from Thoracic Spinal Cord, Percutaneous Endoscopic Approach */
"00CY0ZZ" = "1" /* Extirpation of Matter from Lumbar Spinal Cord, Open Approach */
"00CY3ZZ" = "1" /* Extirpation of Matter from Lumbar Spinal Cord, Percutaneous Approach */
"00CY4ZZ" = "1" /* Extirpation of Matter from Lumbar Spinal Cord, Percutaneous Endoscopic Approach */
"00D10ZZ" = "1" /* Extraction of Cerebral Meninges, Open Approach */
"00D13ZZ" = "1" /* Extraction of Cerebral Meninges, Percutaneous Approach */
"00D14ZZ" = "1" /* Extraction of Cerebral Meninges, Percutaneous Endoscopic Approach */
"00D20ZZ" = "1" /* Extraction of Dura Mater, Open Approach */
"00D23ZZ" = "1" /* Extraction of Dura Mater, Percutaneous Approach */
"00D24ZZ" = "1" /* Extraction of Dura Mater, Percutaneous Endoscopic Approach */
"00DF0ZZ" = "1" /* Extraction of Olfactory Nerve, Open Approach */
"00DF3ZZ" = "1" /* Extraction of Olfactory Nerve, Percutaneous Approach */
"00DF4ZZ" = "1" /* Extraction of Olfactory Nerve, Percutaneous Endoscopic Approach */
"00DG0ZZ" = "1" /* Extraction of Optic Nerve, Open Approach */
"00DG3ZZ" = "1" /* Extraction of Optic Nerve, Percutaneous Approach */
"00DG4ZZ" = "1" /* Extraction of Optic Nerve, Percutaneous Endoscopic Approach */
"00DH0ZZ" = "1" /* Extraction of Oculomotor Nerve, Open Approach */
"00DH3ZZ" = "1" /* Extraction of Oculomotor Nerve, Percutaneous Approach */
"00DH4ZZ" = "1" /* Extraction of Oculomotor Nerve, Percutaneous Endoscopic Approach */
"00DJ0ZZ" = "1" /* Extraction of Trochlear Nerve, Open Approach */
"00DJ3ZZ" = "1" /* Extraction of Trochlear Nerve, Percutaneous Approach */
"00DJ4ZZ" = "1" /* Extraction of Trochlear Nerve, Percutaneous Endoscopic Approach */
"00DK0ZZ" = "1" /* Extraction of Trigeminal Nerve, Open Approach */
"00DK3ZZ" = "1" /* Extraction of Trigeminal Nerve, Percutaneous Approach */
"00DK4ZZ" = "1" /* Extraction of Trigeminal Nerve, Percutaneous Endoscopic Approach */
"00DL0ZZ" = "1" /* Extraction of Abducens Nerve, Open Approach */
"00DL3ZZ" = "1" /* Extraction of Abducens Nerve, Percutaneous Approach */
"00DL4ZZ" = "1" /* Extraction of Abducens Nerve, Percutaneous Endoscopic Approach */
"00DM0ZZ" = "1" /* Extraction of Facial Nerve, Open Approach */
"00DM3ZZ" = "1" /* Extraction of Facial Nerve, Percutaneous Approach */
"00DM4ZZ" = "1" /* Extraction of Facial Nerve, Percutaneous Endoscopic Approach */
"00DN0ZZ" = "1" /* Extraction of Acoustic Nerve, Open Approach */
"00DN3ZZ" = "1" /* Extraction of Acoustic Nerve, Percutaneous Approach */
"00DN4ZZ" = "1" /* Extraction of Acoustic Nerve, Percutaneous Endoscopic Approach */
"00DP0ZZ" = "1" /* Extraction of Glossopharyngeal Nerve, Open Approach */
"00DP3ZZ" = "1" /* Extraction of Glossopharyngeal Nerve, Percutaneous Approach */
"00DP4ZZ" = "1" /* Extraction of Glossopharyngeal Nerve, Percutaneous Endoscopic Approach */
"00DQ0ZZ" = "1" /* Extraction of Vagus Nerve, Open Approach */
"00DQ3ZZ" = "1" /* Extraction of Vagus Nerve, Percutaneous Approach */
"00DQ4ZZ" = "1" /* Extraction of Vagus Nerve, Percutaneous Endoscopic Approach */
"00DR0ZZ" = "1" /* Extraction of Accessory Nerve, Open Approach */
"00DR3ZZ" = "1" /* Extraction of Accessory Nerve, Percutaneous Approach */
"00DR4ZZ" = "1" /* Extraction of Accessory Nerve, Percutaneous Endoscopic Approach */
"00DS0ZZ" = "1" /* Extraction of Hypoglossal Nerve, Open Approach */
"00DS3ZZ" = "1" /* Extraction of Hypoglossal Nerve, Percutaneous Approach */
"00DS4ZZ" = "1" /* Extraction of Hypoglossal Nerve, Percutaneous Endoscopic Approach */
"00DT0ZZ" = "1" /* Extraction of Spinal Meninges, Open Approach */
"00DT3ZZ" = "1" /* Extraction of Spinal Meninges, Percutaneous Approach */
"00DT4ZZ" = "1" /* Extraction of Spinal Meninges, Percutaneous Endoscopic Approach */
"00F30ZZ" = "1" /* Fragmentation in Epidural Space, Open Approach */
"00F33ZZ" = "1" /* Fragmentation in Epidural Space, Percutaneous Approach */
"00F34ZZ" = "1" /* Fragmentation in Epidural Space, Percutaneous Endoscopic Approach */
"00F40ZZ" = "1" /* Fragmentation in Subdural Space, Open Approach */
"00F43ZZ" = "1" /* Fragmentation in Subdural Space, Percutaneous Approach */
"00F44ZZ" = "1" /* Fragmentation in Subdural Space, Percutaneous Endoscopic Approach */
"00F50ZZ" = "1" /* Fragmentation in Subarachnoid Space, Open Approach */
"00F53ZZ" = "1" /* Fragmentation in Subarachnoid Space, Percutaneous Approach */
"00F54ZZ" = "1" /* Fragmentation in Subarachnoid Space, Percutaneous Endoscopic Approach */
"00F60ZZ" = "1" /* Fragmentation in Cerebral Ventricle, Open Approach */
"00F63ZZ" = "1" /* Fragmentation in Cerebral Ventricle, Percutaneous Approach */
"00F64ZZ" = "1" /* Fragmentation in Cerebral Ventricle, Percutaneous Endoscopic Approach */
"00FU0ZZ" = "1" /* Fragmentation in Spinal Canal, Open Approach */
"00FU3ZZ" = "1" /* Fragmentation in Spinal Canal, Percutaneous Approach */
"00FU4ZZ" = "1" /* Fragmentation in Spinal Canal, Percutaneous Endoscopic Approach */
"00FUXZZ" = "1" /* Fragmentation in Spinal Canal, External Approach */
"00H002Z" = "1" /* Insertion of Monitoring Device into Brain, Open Approach */
"00H003Z" = "1" /* Insertion of Infusion Device into Brain, Open Approach */
"00H00MZ" = "1" /* Insertion of Neurostimulator Lead into Brain, Open Approach */
"00H033Z" = "1" /* Insertion of Infusion Device into Brain, Percutaneous Approach */
"00H03MZ" = "1" /* Insertion of Neurostimulator Lead into Brain, Percutaneous Approach */
"00H042Z" = "1" /* Insertion of Monitoring Device into Brain, Percutaneous Endoscopic Approach */
"00H043Z" = "1" /* Insertion of Infusion Device into Brain, Percutaneous Endoscopic Approach */
"00H04MZ" = "1" /* Insertion of Neurostimulator Lead into Brain, Percutaneous Endoscopic Approach */
"00H602Z" = "1" /* Insertion of Monitoring Device into Cerebral Ventricle, Open Approach */
"00H603Z" = "1" /* Insertion of Infusion Device into Cerebral Ventricle, Open Approach */
"00H60MZ" = "1" /* Insertion of Neurostimulator Lead into Cerebral Ventricle, Open Approach */
"00H633Z" = "1" /* Insertion of Infusion Device into Cerebral Ventricle, Percutaneous Approach */
"00H63MZ" = "1" /* Insertion of Neurostimulator Lead into Cerebral Ventricle, Percutaneous Approach */
"00H642Z" = "1" /* Insertion of Monitoring Device into Cerebral Ventricle, Percutaneous Endoscopic Approach */
"00H643Z" = "1" /* Insertion of Infusion Device into Cerebral Ventricle, Percutaneous Endoscopic Approach */
"00H64MZ" = "1" /* Insertion of Neurostimulator Lead into Cerebral Ventricle, Percutaneous Endoscopic Approach */
"00HE02Z" = "1" /* Insertion of Monitoring Device into Cranial Nerve, Open Approach */
"00HE03Z" = "1" /* Insertion of Infusion Device into Cranial Nerve, Open Approach */
"00HE0MZ" = "1" /* Insertion of Neurostimulator Lead into Cranial Nerve, Open Approach */
"00HE33Z" = "1" /* Insertion of Infusion Device into Cranial Nerve, Percutaneous Approach */
"00HE3MZ" = "1" /* Insertion of Neurostimulator Lead into Cranial Nerve, Percutaneous Approach */
"00HE42Z" = "1" /* Insertion of Monitoring Device into Cranial Nerve, Percutaneous Endoscopic Approach */
"00HE43Z" = "1" /* Insertion of Infusion Device into Cranial Nerve, Percutaneous Endoscopic Approach */
"00HE4MZ" = "1" /* Insertion of Neurostimulator Lead into Cranial Nerve, Percutaneous Endoscopic Approach */
"00HU02Z" = "1" /* Insertion of Monitoring Device into Spinal Canal, Open Approach */
"00HU0MZ" = "1" /* Insertion of Neurostimulator Lead into Spinal Canal, Open Approach */
"00HU3MZ" = "1" /* Insertion of Neurostimulator Lead into Spinal Canal, Percutaneous Approach */
"00HU42Z" = "1" /* Insertion of Monitoring Device into Spinal Canal, Percutaneous Endoscopic Approach */
"00HU4MZ" = "1" /* Insertion of Neurostimulator Lead into Spinal Canal, Percutaneous Endoscopic Approach */
"00HV02Z" = "1" /* Insertion of Monitoring Device into Spinal Cord, Open Approach */
"00HV0MZ" = "1" /* Insertion of Neurostimulator Lead into Spinal Cord, Open Approach */
"00HV3MZ" = "1" /* Insertion of Neurostimulator Lead into Spinal Cord, Percutaneous Approach */
"00HV42Z" = "1" /* Insertion of Monitoring Device into Spinal Cord, Percutaneous Endoscopic Approach */
"00HV4MZ" = "1" /* Insertion of Neurostimulator Lead into Spinal Cord, Percutaneous Endoscopic Approach */
"00J00ZZ" = "1" /* Inspection of Brain, Open Approach */
"00J04ZZ" = "1" /* Inspection of Brain, Percutaneous Endoscopic Approach */
"00JE0ZZ" = "1" /* Inspection of Cranial Nerve, Open Approach */
"00JE4ZZ" = "1" /* Inspection of Cranial Nerve, Percutaneous Endoscopic Approach */
"00JU0ZZ" = "1" /* Inspection of Spinal Canal, Open Approach */
"00JU4ZZ" = "1" /* Inspection of Spinal Canal, Percutaneous Endoscopic Approach */
"00JV0ZZ" = "1" /* Inspection of Spinal Cord, Open Approach */
"00JV4ZZ" = "1" /* Inspection of Spinal Cord, Percutaneous Endoscopic Approach */
"00K00ZZ" = "1" /* Map Brain, Open Approach */
"00K03ZZ" = "1" /* Map Brain, Percutaneous Approach */
"00K04ZZ" = "1" /* Map Brain, Percutaneous Endoscopic Approach */
"00K70ZZ" = "1" /* Map Cerebral Hemisphere, Open Approach */
"00K73ZZ" = "1" /* Map Cerebral Hemisphere, Percutaneous Approach */
"00K74ZZ" = "1" /* Map Cerebral Hemisphere, Percutaneous Endoscopic Approach */
"00K80ZZ" = "1" /* Map Basal Ganglia, Open Approach */
"00K83ZZ" = "1" /* Map Basal Ganglia, Percutaneous Approach */
"00K84ZZ" = "1" /* Map Basal Ganglia, Percutaneous Endoscopic Approach */
"00K90ZZ" = "1" /* Map Thalamus, Open Approach */
"00K93ZZ" = "1" /* Map Thalamus, Percutaneous Approach */
"00K94ZZ" = "1" /* Map Thalamus, Percutaneous Endoscopic Approach */
"00KA0ZZ" = "1" /* Map Hypothalamus, Open Approach */
"00KA3ZZ" = "1" /* Map Hypothalamus, Percutaneous Approach */
"00KA4ZZ" = "1" /* Map Hypothalamus, Percutaneous Endoscopic Approach */
"00KB0ZZ" = "1" /* Map Pons, Open Approach */
"00KB3ZZ" = "1" /* Map Pons, Percutaneous Approach */
"00KB4ZZ" = "1" /* Map Pons, Percutaneous Endoscopic Approach */
"00KC0ZZ" = "1" /* Map Cerebellum, Open Approach */
"00KC3ZZ" = "1" /* Map Cerebellum, Percutaneous Approach */
"00KC4ZZ" = "1" /* Map Cerebellum, Percutaneous Endoscopic Approach */
"00KD0ZZ" = "1" /* Map Medulla Oblongata, Open Approach */
"00KD3ZZ" = "1" /* Map Medulla Oblongata, Percutaneous Approach */
"00KD4ZZ" = "1" /* Map Medulla Oblongata, Percutaneous Endoscopic Approach */
"00N00ZZ" = "1" /* Release Brain, Open Approach */
"00N03ZZ" = "1" /* Release Brain, Percutaneous Approach */
"00N04ZZ" = "1" /* Release Brain, Percutaneous Endoscopic Approach */
"00N10ZZ" = "1" /* Release Cerebral Meninges, Open Approach */
"00N13ZZ" = "1" /* Release Cerebral Meninges, Percutaneous Approach */
"00N14ZZ" = "1" /* Release Cerebral Meninges, Percutaneous Endoscopic Approach */
"00N20ZZ" = "1" /* Release Dura Mater, Open Approach */
"00N23ZZ" = "1" /* Release Dura Mater, Percutaneous Approach */
"00N24ZZ" = "1" /* Release Dura Mater, Percutaneous Endoscopic Approach */
"00N60ZZ" = "1" /* Release Cerebral Ventricle, Open Approach */
"00N63ZZ" = "1" /* Release Cerebral Ventricle, Percutaneous Approach */
"00N64ZZ" = "1" /* Release Cerebral Ventricle, Percutaneous Endoscopic Approach */
"00N70ZZ" = "1" /* Release Cerebral Hemisphere, Open Approach */
"00N73ZZ" = "1" /* Release Cerebral Hemisphere, Percutaneous Approach */
"00N74ZZ" = "1" /* Release Cerebral Hemisphere, Percutaneous Endoscopic Approach */
"00N80ZZ" = "1" /* Release Basal Ganglia, Open Approach */
"00N83ZZ" = "1" /* Release Basal Ganglia, Percutaneous Approach */
"00N84ZZ" = "1" /* Release Basal Ganglia, Percutaneous Endoscopic Approach */
"00N90ZZ" = "1" /* Release Thalamus, Open Approach */
"00N93ZZ" = "1" /* Release Thalamus, Percutaneous Approach */
"00N94ZZ" = "1" /* Release Thalamus, Percutaneous Endoscopic Approach */
"00NA0ZZ" = "1" /* Release Hypothalamus, Open Approach */
"00NA3ZZ" = "1" /* Release Hypothalamus, Percutaneous Approach */
"00NA4ZZ" = "1" /* Release Hypothalamus, Percutaneous Endoscopic Approach */
"00NB0ZZ" = "1" /* Release Pons, Open Approach */
"00NB3ZZ" = "1" /* Release Pons, Percutaneous Approach */
"00NB4ZZ" = "1" /* Release Pons, Percutaneous Endoscopic Approach */
"00NC0ZZ" = "1" /* Release Cerebellum, Open Approach */
"00NC3ZZ" = "1" /* Release Cerebellum, Percutaneous Approach */
"00NC4ZZ" = "1" /* Release Cerebellum, Percutaneous Endoscopic Approach */
"00ND0ZZ" = "1" /* Release Medulla Oblongata, Open Approach */
"00ND3ZZ" = "1" /* Release Medulla Oblongata, Percutaneous Approach */
"00ND4ZZ" = "1" /* Release Medulla Oblongata, Percutaneous Endoscopic Approach */
"00NF0ZZ" = "1" /* Release Olfactory Nerve, Open Approach */
"00NF3ZZ" = "1" /* Release Olfactory Nerve, Percutaneous Approach */
"00NF4ZZ" = "1" /* Release Olfactory Nerve, Percutaneous Endoscopic Approach */
"00NG0ZZ" = "1" /* Release Optic Nerve, Open Approach */
"00NG3ZZ" = "1" /* Release Optic Nerve, Percutaneous Approach */
"00NG4ZZ" = "1" /* Release Optic Nerve, Percutaneous Endoscopic Approach */
"00NH0ZZ" = "1" /* Release Oculomotor Nerve, Open Approach */
"00NH3ZZ" = "1" /* Release Oculomotor Nerve, Percutaneous Approach */
"00NH4ZZ" = "1" /* Release Oculomotor Nerve, Percutaneous Endoscopic Approach */
"00NJ0ZZ" = "1" /* Release Trochlear Nerve, Open Approach */
"00NJ3ZZ" = "1" /* Release Trochlear Nerve, Percutaneous Approach */
"00NJ4ZZ" = "1" /* Release Trochlear Nerve, Percutaneous Endoscopic Approach */
"00NK0ZZ" = "1" /* Release Trigeminal Nerve, Open Approach */
"00NK3ZZ" = "1" /* Release Trigeminal Nerve, Percutaneous Approach */
"00NK4ZZ" = "1" /* Release Trigeminal Nerve, Percutaneous Endoscopic Approach */
"00NL0ZZ" = "1" /* Release Abducens Nerve, Open Approach */
"00NL3ZZ" = "1" /* Release Abducens Nerve, Percutaneous Approach */
"00NL4ZZ" = "1" /* Release Abducens Nerve, Percutaneous Endoscopic Approach */
"00NM0ZZ" = "1" /* Release Facial Nerve, Open Approach */
"00NM3ZZ" = "1" /* Release Facial Nerve, Percutaneous Approach */
"00NM4ZZ" = "1" /* Release Facial Nerve, Percutaneous Endoscopic Approach */
"00NN0ZZ" = "1" /* Release Acoustic Nerve, Open Approach */
"00NN3ZZ" = "1" /* Release Acoustic Nerve, Percutaneous Approach */
"00NN4ZZ" = "1" /* Release Acoustic Nerve, Percutaneous Endoscopic Approach */
"00NP0ZZ" = "1" /* Release Glossopharyngeal Nerve, Open Approach */
"00NP3ZZ" = "1" /* Release Glossopharyngeal Nerve, Percutaneous Approach */
"00NP4ZZ" = "1" /* Release Glossopharyngeal Nerve, Percutaneous Endoscopic Approach */
"00NQ0ZZ" = "1" /* Release Vagus Nerve, Open Approach */
"00NQ3ZZ" = "1" /* Release Vagus Nerve, Percutaneous Approach */
"00NQ4ZZ" = "1" /* Release Vagus Nerve, Percutaneous Endoscopic Approach */
"00NR0ZZ" = "1" /* Release Accessory Nerve, Open Approach */
"00NR3ZZ" = "1" /* Release Accessory Nerve, Percutaneous Approach */
"00NR4ZZ" = "1" /* Release Accessory Nerve, Percutaneous Endoscopic Approach */
"00NS0ZZ" = "1" /* Release Hypoglossal Nerve, Open Approach */
"00NS3ZZ" = "1" /* Release Hypoglossal Nerve, Percutaneous Approach */
"00NS4ZZ" = "1" /* Release Hypoglossal Nerve, Percutaneous Endoscopic Approach */
"00NT0ZZ" = "1" /* Release Spinal Meninges, Open Approach */
"00NT3ZZ" = "1" /* Release Spinal Meninges, Percutaneous Approach */
"00NT4ZZ" = "1" /* Release Spinal Meninges, Percutaneous Endoscopic Approach */
"00NW0ZZ" = "1" /* Release Cervical Spinal Cord, Open Approach */
"00NW3ZZ" = "1" /* Release Cervical Spinal Cord, Percutaneous Approach */
"00NW4ZZ" = "1" /* Release Cervical Spinal Cord, Percutaneous Endoscopic Approach */
"00NX0ZZ" = "1" /* Release Thoracic Spinal Cord, Open Approach */
"00NX3ZZ" = "1" /* Release Thoracic Spinal Cord, Percutaneous Approach */
"00NX4ZZ" = "1" /* Release Thoracic Spinal Cord, Percutaneous Endoscopic Approach */
"00NY0ZZ" = "1" /* Release Lumbar Spinal Cord, Open Approach */
"00NY3ZZ" = "1" /* Release Lumbar Spinal Cord, Percutaneous Approach */
"00NY4ZZ" = "1" /* Release Lumbar Spinal Cord, Percutaneous Endoscopic Approach */
"00P000Z" = "1" /* Removal of Drainage Device from Brain, Open Approach */
"00P002Z" = "1" /* Removal of Monitoring Device from Brain, Open Approach */
"00P003Z" = "1" /* Removal of Infusion Device from Brain, Open Approach */
"00P007Z" = "1" /* Removal of Autologous Tissue Substitute from Brain, Open Approach */
"00P00JZ" = "1" /* Removal of Synthetic Substitute from Brain, Open Approach */
"00P00KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Brain, Open Approach */
"00P00MZ" = "1" /* Removal of Neurostimulator Lead from Brain, Open Approach */
"00P037Z" = "1" /* Removal of Autologous Tissue Substitute from Brain, Percutaneous Approach */
"00P03JZ" = "1" /* Removal of Synthetic Substitute from Brain, Percutaneous Approach */
"00P03KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Brain, Percutaneous Approach */
"00P03MZ" = "1" /* Removal of Neurostimulator Lead from Brain, Percutaneous Approach */
"00P040Z" = "1" /* Removal of Drainage Device from Brain, Percutaneous Endoscopic Approach */
"00P042Z" = "1" /* Removal of Monitoring Device from Brain, Percutaneous Endoscopic Approach */
"00P043Z" = "1" /* Removal of Infusion Device from Brain, Percutaneous Endoscopic Approach */
"00P047Z" = "1" /* Removal of Autologous Tissue Substitute from Brain, Percutaneous Endoscopic Approach */
"00P04JZ" = "1" /* Removal of Synthetic Substitute from Brain, Percutaneous Endoscopic Approach */
"00P04KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Brain, Percutaneous Endoscopic Approach */
"00P04MZ" = "1" /* Removal of Neurostimulator Lead from Brain, Percutaneous Endoscopic Approach */
"00P600Z" = "1" /* Removal of Drainage Device from Cerebral Ventricle, Open Approach */
"00P602Z" = "1" /* Removal of Monitoring Device from Cerebral Ventricle, Open Approach */
"00P603Z" = "1" /* Removal of Infusion Device from Cerebral Ventricle, Open Approach */
"00P60JZ" = "1" /* Removal of Synthetic Substitute from Cerebral Ventricle, Open Approach */
"00P60MZ" = "1" /* Removal of Neurostimulator Lead from Cerebral Ventricle, Open Approach */
"00P63JZ" = "1" /* Removal of Synthetic Substitute from Cerebral Ventricle, Percutaneous Approach */
"00P63MZ" = "1" /* Removal of Neurostimulator Lead from Cerebral Ventricle, Percutaneous Approach */
"00P640Z" = "1" /* Removal of Drainage Device from Cerebral Ventricle, Percutaneous Endoscopic Approach */
"00P642Z" = "1" /* Removal of Monitoring Device from Cerebral Ventricle, Percutaneous Endoscopic Approach */
"00P643Z" = "1" /* Removal of Infusion Device from Cerebral Ventricle, Percutaneous Endoscopic Approach */
"00P64JZ" = "1" /* Removal of Synthetic Substitute from Cerebral Ventricle, Percutaneous Endoscopic Approach */
"00P64MZ" = "1" /* Removal of Neurostimulator Lead from Cerebral Ventricle, Percutaneous Endoscopic Approach */
"00PE00Z" = "1" /* Removal of Drainage Device from Cranial Nerve, Open Approach */
"00PE02Z" = "1" /* Removal of Monitoring Device from Cranial Nerve, Open Approach */
"00PE03Z" = "1" /* Removal of Infusion Device from Cranial Nerve, Open Approach */
"00PE07Z" = "1" /* Removal of Autologous Tissue Substitute from Cranial Nerve, Open Approach */
"00PE0MZ" = "1" /* Removal of Neurostimulator Lead from Cranial Nerve, Open Approach */
"00PE37Z" = "1" /* Removal of Autologous Tissue Substitute from Cranial Nerve, Percutaneous Approach */
"00PE3MZ" = "1" /* Removal of Neurostimulator Lead from Cranial Nerve, Percutaneous Approach */
"00PE40Z" = "1" /* Removal of Drainage Device from Cranial Nerve, Percutaneous Endoscopic Approach */
"00PE42Z" = "1" /* Removal of Monitoring Device from Cranial Nerve, Percutaneous Endoscopic Approach */
"00PE43Z" = "1" /* Removal of Infusion Device from Cranial Nerve, Percutaneous Endoscopic Approach */
"00PE47Z" = "1" /* Removal of Autologous Tissue Substitute from Cranial Nerve, Percutaneous Endoscopic Approach */
"00PE4MZ" = "1" /* Removal of Neurostimulator Lead from Cranial Nerve, Percutaneous Endoscopic Approach */
"00PU00Z" = "1" /* Removal of Drainage Device from Spinal Canal, Open Approach */
"00PU02Z" = "1" /* Removal of Monitoring Device from Spinal Canal, Open Approach */
"00PU03Z" = "1" /* Removal of Infusion Device from Spinal Canal, Open Approach */
"00PU0JZ" = "1" /* Removal of Synthetic Substitute from Spinal Canal, Open Approach */
"00PU0MZ" = "1" /* Removal of Neurostimulator Lead from Spinal Canal, Open Approach */
"00PU3JZ" = "1" /* Removal of Synthetic Substitute from Spinal Canal, Percutaneous Approach */
"00PU3MZ" = "1" /* Removal of Neurostimulator Lead from Spinal Canal, Percutaneous Approach */
"00PU40Z" = "1" /* Removal of Drainage Device from Spinal Canal, Percutaneous Endoscopic Approach */
"00PU42Z" = "1" /* Removal of Monitoring Device from Spinal Canal, Percutaneous Endoscopic Approach */
"00PU43Z" = "1" /* Removal of Infusion Device from Spinal Canal, Percutaneous Endoscopic Approach */
"00PU4JZ" = "1" /* Removal of Synthetic Substitute from Spinal Canal, Percutaneous Endoscopic Approach */
"00PU4MZ" = "1" /* Removal of Neurostimulator Lead from Spinal Canal, Percutaneous Endoscopic Approach */
"00PV00Z" = "1" /* Removal of Drainage Device from Spinal Cord, Open Approach */
"00PV02Z" = "1" /* Removal of Monitoring Device from Spinal Cord, Open Approach */
"00PV03Z" = "1" /* Removal of Infusion Device from Spinal Cord, Open Approach */
"00PV07Z" = "1" /* Removal of Autologous Tissue Substitute from Spinal Cord, Open Approach */
"00PV0JZ" = "1" /* Removal of Synthetic Substitute from Spinal Cord, Open Approach */
"00PV0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Spinal Cord, Open Approach */
"00PV0MZ" = "1" /* Removal of Neurostimulator Lead from Spinal Cord, Open Approach */
"00PV37Z" = "1" /* Removal of Autologous Tissue Substitute from Spinal Cord, Percutaneous Approach */
"00PV3JZ" = "1" /* Removal of Synthetic Substitute from Spinal Cord, Percutaneous Approach */
"00PV3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Spinal Cord, Percutaneous Approach */
"00PV3MZ" = "1" /* Removal of Neurostimulator Lead from Spinal Cord, Percutaneous Approach */
"00PV40Z" = "1" /* Removal of Drainage Device from Spinal Cord, Percutaneous Endoscopic Approach */
"00PV42Z" = "1" /* Removal of Monitoring Device from Spinal Cord, Percutaneous Endoscopic Approach */
"00PV43Z" = "1" /* Removal of Infusion Device from Spinal Cord, Percutaneous Endoscopic Approach */
"00PV47Z" = "1" /* Removal of Autologous Tissue Substitute from Spinal Cord, Percutaneous Endoscopic Approach */
"00PV4JZ" = "1" /* Removal of Synthetic Substitute from Spinal Cord, Percutaneous Endoscopic Approach */
"00PV4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Spinal Cord, Percutaneous Endoscopic Approach */
"00PV4MZ" = "1" /* Removal of Neurostimulator Lead from Spinal Cord, Percutaneous Endoscopic Approach */
"00Q00ZZ" = "1" /* Repair Brain, Open Approach */
"00Q03ZZ" = "1" /* Repair Brain, Percutaneous Approach */
"00Q04ZZ" = "1" /* Repair Brain, Percutaneous Endoscopic Approach */
"00Q10ZZ" = "1" /* Repair Cerebral Meninges, Open Approach */
"00Q13ZZ" = "1" /* Repair Cerebral Meninges, Percutaneous Approach */
"00Q14ZZ" = "1" /* Repair Cerebral Meninges, Percutaneous Endoscopic Approach */
"00Q20ZZ" = "1" /* Repair Dura Mater, Open Approach */
"00Q23ZZ" = "1" /* Repair Dura Mater, Percutaneous Approach */
"00Q24ZZ" = "1" /* Repair Dura Mater, Percutaneous Endoscopic Approach */
"00Q60ZZ" = "1" /* Repair Cerebral Ventricle, Open Approach */
"00Q63ZZ" = "1" /* Repair Cerebral Ventricle, Percutaneous Approach */
"00Q64ZZ" = "1" /* Repair Cerebral Ventricle, Percutaneous Endoscopic Approach */
"00Q70ZZ" = "1" /* Repair Cerebral Hemisphere, Open Approach */
"00Q73ZZ" = "1" /* Repair Cerebral Hemisphere, Percutaneous Approach */
"00Q74ZZ" = "1" /* Repair Cerebral Hemisphere, Percutaneous Endoscopic Approach */
"00Q80ZZ" = "1" /* Repair Basal Ganglia, Open Approach */
"00Q83ZZ" = "1" /* Repair Basal Ganglia, Percutaneous Approach */
"00Q84ZZ" = "1" /* Repair Basal Ganglia, Percutaneous Endoscopic Approach */
"00Q90ZZ" = "1" /* Repair Thalamus, Open Approach */
"00Q93ZZ" = "1" /* Repair Thalamus, Percutaneous Approach */
"00Q94ZZ" = "1" /* Repair Thalamus, Percutaneous Endoscopic Approach */
"00QA0ZZ" = "1" /* Repair Hypothalamus, Open Approach */
"00QA3ZZ" = "1" /* Repair Hypothalamus, Percutaneous Approach */
"00QA4ZZ" = "1" /* Repair Hypothalamus, Percutaneous Endoscopic Approach */
"00QB0ZZ" = "1" /* Repair Pons, Open Approach */
"00QB3ZZ" = "1" /* Repair Pons, Percutaneous Approach */
"00QB4ZZ" = "1" /* Repair Pons, Percutaneous Endoscopic Approach */
"00QC0ZZ" = "1" /* Repair Cerebellum, Open Approach */
"00QC3ZZ" = "1" /* Repair Cerebellum, Percutaneous Approach */
"00QC4ZZ" = "1" /* Repair Cerebellum, Percutaneous Endoscopic Approach */
"00QD0ZZ" = "1" /* Repair Medulla Oblongata, Open Approach */
"00QD3ZZ" = "1" /* Repair Medulla Oblongata, Percutaneous Approach */
"00QD4ZZ" = "1" /* Repair Medulla Oblongata, Percutaneous Endoscopic Approach */
"00QF0ZZ" = "1" /* Repair Olfactory Nerve, Open Approach */
"00QF3ZZ" = "1" /* Repair Olfactory Nerve, Percutaneous Approach */
"00QF4ZZ" = "1" /* Repair Olfactory Nerve, Percutaneous Endoscopic Approach */
"00QG0ZZ" = "1" /* Repair Optic Nerve, Open Approach */
"00QG3ZZ" = "1" /* Repair Optic Nerve, Percutaneous Approach */
"00QG4ZZ" = "1" /* Repair Optic Nerve, Percutaneous Endoscopic Approach */
"00QH0ZZ" = "1" /* Repair Oculomotor Nerve, Open Approach */
"00QH3ZZ" = "1" /* Repair Oculomotor Nerve, Percutaneous Approach */
"00QH4ZZ" = "1" /* Repair Oculomotor Nerve, Percutaneous Endoscopic Approach */
"00QJ0ZZ" = "1" /* Repair Trochlear Nerve, Open Approach */
"00QJ3ZZ" = "1" /* Repair Trochlear Nerve, Percutaneous Approach */
"00QJ4ZZ" = "1" /* Repair Trochlear Nerve, Percutaneous Endoscopic Approach */
"00QK0ZZ" = "1" /* Repair Trigeminal Nerve, Open Approach */
"00QK3ZZ" = "1" /* Repair Trigeminal Nerve, Percutaneous Approach */
"00QK4ZZ" = "1" /* Repair Trigeminal Nerve, Percutaneous Endoscopic Approach */
"00QL0ZZ" = "1" /* Repair Abducens Nerve, Open Approach */
"00QL3ZZ" = "1" /* Repair Abducens Nerve, Percutaneous Approach */
"00QL4ZZ" = "1" /* Repair Abducens Nerve, Percutaneous Endoscopic Approach */
"00QM0ZZ" = "1" /* Repair Facial Nerve, Open Approach */
"00QM3ZZ" = "1" /* Repair Facial Nerve, Percutaneous Approach */
"00QM4ZZ" = "1" /* Repair Facial Nerve, Percutaneous Endoscopic Approach */
"00QN0ZZ" = "1" /* Repair Acoustic Nerve, Open Approach */
"00QN3ZZ" = "1" /* Repair Acoustic Nerve, Percutaneous Approach */
"00QN4ZZ" = "1" /* Repair Acoustic Nerve, Percutaneous Endoscopic Approach */
"00QP0ZZ" = "1" /* Repair Glossopharyngeal Nerve, Open Approach */
"00QP3ZZ" = "1" /* Repair Glossopharyngeal Nerve, Percutaneous Approach */
"00QP4ZZ" = "1" /* Repair Glossopharyngeal Nerve, Percutaneous Endoscopic Approach */
"00QQ0ZZ" = "1" /* Repair Vagus Nerve, Open Approach */
"00QQ3ZZ" = "1" /* Repair Vagus Nerve, Percutaneous Approach */
"00QQ4ZZ" = "1" /* Repair Vagus Nerve, Percutaneous Endoscopic Approach */
"00QR0ZZ" = "1" /* Repair Accessory Nerve, Open Approach */
"00QR3ZZ" = "1" /* Repair Accessory Nerve, Percutaneous Approach */
"00QR4ZZ" = "1" /* Repair Accessory Nerve, Percutaneous Endoscopic Approach */
"00QS0ZZ" = "1" /* Repair Hypoglossal Nerve, Open Approach */
"00QS3ZZ" = "1" /* Repair Hypoglossal Nerve, Percutaneous Approach */
"00QS4ZZ" = "1" /* Repair Hypoglossal Nerve, Percutaneous Endoscopic Approach */
"00QT0ZZ" = "1" /* Repair Spinal Meninges, Open Approach */
"00QT3ZZ" = "1" /* Repair Spinal Meninges, Percutaneous Approach */
"00QT4ZZ" = "1" /* Repair Spinal Meninges, Percutaneous Endoscopic Approach */
"00QW0ZZ" = "1" /* Repair Cervical Spinal Cord, Open Approach */
"00QW3ZZ" = "1" /* Repair Cervical Spinal Cord, Percutaneous Approach */
"00QW4ZZ" = "1" /* Repair Cervical Spinal Cord, Percutaneous Endoscopic Approach */
"00QX0ZZ" = "1" /* Repair Thoracic Spinal Cord, Open Approach */
"00QX3ZZ" = "1" /* Repair Thoracic Spinal Cord, Percutaneous Approach */
"00QX4ZZ" = "1" /* Repair Thoracic Spinal Cord, Percutaneous Endoscopic Approach */
"00QY0ZZ" = "1" /* Repair Lumbar Spinal Cord, Open Approach */
"00QY3ZZ" = "1" /* Repair Lumbar Spinal Cord, Percutaneous Approach */
"00QY4ZZ" = "1" /* Repair Lumbar Spinal Cord, Percutaneous Endoscopic Approach */
"00SF0ZZ" = "1" /* Reposition Olfactory Nerve, Open Approach */
"00SF3ZZ" = "1" /* Reposition Olfactory Nerve, Percutaneous Approach */
"00SF4ZZ" = "1" /* Reposition Olfactory Nerve, Percutaneous Endoscopic Approach */
"00SG0ZZ" = "1" /* Reposition Optic Nerve, Open Approach */
"00SG3ZZ" = "1" /* Reposition Optic Nerve, Percutaneous Approach */
"00SG4ZZ" = "1" /* Reposition Optic Nerve, Percutaneous Endoscopic Approach */
"00SH0ZZ" = "1" /* Reposition Oculomotor Nerve, Open Approach */
"00SH3ZZ" = "1" /* Reposition Oculomotor Nerve, Percutaneous Approach */
"00SH4ZZ" = "1" /* Reposition Oculomotor Nerve, Percutaneous Endoscopic Approach */
"00SJ0ZZ" = "1" /* Reposition Trochlear Nerve, Open Approach */
"00SJ3ZZ" = "1" /* Reposition Trochlear Nerve, Percutaneous Approach */
"00SJ4ZZ" = "1" /* Reposition Trochlear Nerve, Percutaneous Endoscopic Approach */
"00SK0ZZ" = "1" /* Reposition Trigeminal Nerve, Open Approach */
"00SK3ZZ" = "1" /* Reposition Trigeminal Nerve, Percutaneous Approach */
"00SK4ZZ" = "1" /* Reposition Trigeminal Nerve, Percutaneous Endoscopic Approach */
"00SL0ZZ" = "1" /* Reposition Abducens Nerve, Open Approach */
"00SL3ZZ" = "1" /* Reposition Abducens Nerve, Percutaneous Approach */
"00SL4ZZ" = "1" /* Reposition Abducens Nerve, Percutaneous Endoscopic Approach */
"00SM0ZZ" = "1" /* Reposition Facial Nerve, Open Approach */
"00SM3ZZ" = "1" /* Reposition Facial Nerve, Percutaneous Approach */
"00SM4ZZ" = "1" /* Reposition Facial Nerve, Percutaneous Endoscopic Approach */
"00SN0ZZ" = "1" /* Reposition Acoustic Nerve, Open Approach */
"00SN3ZZ" = "1" /* Reposition Acoustic Nerve, Percutaneous Approach */
"00SN4ZZ" = "1" /* Reposition Acoustic Nerve, Percutaneous Endoscopic Approach */
"00SP0ZZ" = "1" /* Reposition Glossopharyngeal Nerve, Open Approach */
"00SP3ZZ" = "1" /* Reposition Glossopharyngeal Nerve, Percutaneous Approach */
"00SP4ZZ" = "1" /* Reposition Glossopharyngeal Nerve, Percutaneous Endoscopic Approach */
"00SQ0ZZ" = "1" /* Reposition Vagus Nerve, Open Approach */
"00SQ3ZZ" = "1" /* Reposition Vagus Nerve, Percutaneous Approach */
"00SQ4ZZ" = "1" /* Reposition Vagus Nerve, Percutaneous Endoscopic Approach */
"00SR0ZZ" = "1" /* Reposition Accessory Nerve, Open Approach */
"00SR3ZZ" = "1" /* Reposition Accessory Nerve, Percutaneous Approach */
"00SR4ZZ" = "1" /* Reposition Accessory Nerve, Percutaneous Endoscopic Approach */
"00SS0ZZ" = "1" /* Reposition Hypoglossal Nerve, Open Approach */
"00SS3ZZ" = "1" /* Reposition Hypoglossal Nerve, Percutaneous Approach */
"00SS4ZZ" = "1" /* Reposition Hypoglossal Nerve, Percutaneous Endoscopic Approach */
"00SW0ZZ" = "1" /* Reposition Cervical Spinal Cord, Open Approach */
"00SW3ZZ" = "1" /* Reposition Cervical Spinal Cord, Percutaneous Approach */
"00SW4ZZ" = "1" /* Reposition Cervical Spinal Cord, Percutaneous Endoscopic Approach */
"00SX0ZZ" = "1" /* Reposition Thoracic Spinal Cord, Open Approach */
"00SX3ZZ" = "1" /* Reposition Thoracic Spinal Cord, Percutaneous Approach */
"00SX4ZZ" = "1" /* Reposition Thoracic Spinal Cord, Percutaneous Endoscopic Approach */
"00SY0ZZ" = "1" /* Reposition Lumbar Spinal Cord, Open Approach */
"00SY3ZZ" = "1" /* Reposition Lumbar Spinal Cord, Percutaneous Approach */
"00SY4ZZ" = "1" /* Reposition Lumbar Spinal Cord, Percutaneous Endoscopic Approach */
"00T70ZZ" = "1" /* Resection of Cerebral Hemisphere, Open Approach */
"00T73ZZ" = "1" /* Resection of Cerebral Hemisphere, Percutaneous Approach */
"00T74ZZ" = "1" /* Resection of Cerebral Hemisphere, Percutaneous Endoscopic Approach */
"00U107Z" = "1" /* Supplement Cerebral Meninges with Autologous Tissue Substitute, Open Approach */
"00U10JZ" = "1" /* Supplement Cerebral Meninges with Synthetic Substitute, Open Approach */
"00U10KZ" = "1" /* Supplement Cerebral Meninges with Nonautologous Tissue Substitute, Open Approach */
"00U137Z" = "1" /* Supplement Cerebral Meninges with Autologous Tissue Substitute, Percutaneous Approach */
"00U13JZ" = "1" /* Supplement Cerebral Meninges with Synthetic Substitute, Percutaneous Approach */
"00U13KZ" = "1" /* Supplement Cerebral Meninges with Nonautologous Tissue Substitute, Percutaneous Approach */
"00U147Z" = "1" /* Supplement Cerebral Meninges with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"00U14JZ" = "1" /* Supplement Cerebral Meninges with Synthetic Substitute, Percutaneous Endoscopic Approach */
"00U14KZ" = "1" /* Supplement Cerebral Meninges with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"00U207Z" = "1" /* Supplement Dura Mater with Autologous Tissue Substitute, Open Approach */
"00U20JZ" = "1" /* Supplement Dura Mater with Synthetic Substitute, Open Approach */
"00U20KZ" = "1" /* Supplement Dura Mater with Nonautologous Tissue Substitute, Open Approach */
"00U237Z" = "1" /* Supplement Dura Mater with Autologous Tissue Substitute, Percutaneous Approach */
"00U23JZ" = "1" /* Supplement Dura Mater with Synthetic Substitute, Percutaneous Approach */
"00U23KZ" = "1" /* Supplement Dura Mater with Nonautologous Tissue Substitute, Percutaneous Approach */
"00U247Z" = "1" /* Supplement Dura Mater with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"00U24JZ" = "1" /* Supplement Dura Mater with Synthetic Substitute, Percutaneous Endoscopic Approach */
"00U24KZ" = "1" /* Supplement Dura Mater with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"00UF07Z" = "1" /* Supplement Olfactory Nerve with Autologous Tissue Substitute, Open Approach */
"00UF37Z" = "1" /* Supplement Olfactory Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"00UF47Z" = "1" /* Supplement Olfactory Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"00UG07Z" = "1" /* Supplement Optic Nerve with Autologous Tissue Substitute, Open Approach */
"00UG37Z" = "1" /* Supplement Optic Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"00UG47Z" = "1" /* Supplement Optic Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"00UH07Z" = "1" /* Supplement Oculomotor Nerve with Autologous Tissue Substitute, Open Approach */
"00UH37Z" = "1" /* Supplement Oculomotor Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"00UH47Z" = "1" /* Supplement Oculomotor Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"00UJ07Z" = "1" /* Supplement Trochlear Nerve with Autologous Tissue Substitute, Open Approach */
"00UJ37Z" = "1" /* Supplement Trochlear Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"00UJ47Z" = "1" /* Supplement Trochlear Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"00UK07Z" = "1" /* Supplement Trigeminal Nerve with Autologous Tissue Substitute, Open Approach */
"00UK37Z" = "1" /* Supplement Trigeminal Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"00UK47Z" = "1" /* Supplement Trigeminal Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"00UL07Z" = "1" /* Supplement Abducens Nerve with Autologous Tissue Substitute, Open Approach */
"00UL37Z" = "1" /* Supplement Abducens Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"00UL47Z" = "1" /* Supplement Abducens Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"00UM07Z" = "1" /* Supplement Facial Nerve with Autologous Tissue Substitute, Open Approach */
"00UM37Z" = "1" /* Supplement Facial Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"00UM47Z" = "1" /* Supplement Facial Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"00UN07Z" = "1" /* Supplement Acoustic Nerve with Autologous Tissue Substitute, Open Approach */
"00UN37Z" = "1" /* Supplement Acoustic Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"00UN47Z" = "1" /* Supplement Acoustic Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"00UP07Z" = "1" /* Supplement Glossopharyngeal Nerve with Autologous Tissue Substitute, Open Approach */
"00UP37Z" = "1" /* Supplement Glossopharyngeal Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"00UP47Z" = "1" /* Supplement Glossopharyngeal Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"00UQ07Z" = "1" /* Supplement Vagus Nerve with Autologous Tissue Substitute, Open Approach */
"00UQ37Z" = "1" /* Supplement Vagus Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"00UQ47Z" = "1" /* Supplement Vagus Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"00UR07Z" = "1" /* Supplement Accessory Nerve with Autologous Tissue Substitute, Open Approach */
"00UR37Z" = "1" /* Supplement Accessory Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"00UR47Z" = "1" /* Supplement Accessory Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"00US07Z" = "1" /* Supplement Hypoglossal Nerve with Autologous Tissue Substitute, Open Approach */
"00US37Z" = "1" /* Supplement Hypoglossal Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"00US47Z" = "1" /* Supplement Hypoglossal Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"00UT07Z" = "1" /* Supplement Spinal Meninges with Autologous Tissue Substitute, Open Approach */
"00UT0JZ" = "1" /* Supplement Spinal Meninges with Synthetic Substitute, Open Approach */
"00UT0KZ" = "1" /* Supplement Spinal Meninges with Nonautologous Tissue Substitute, Open Approach */
"00UT37Z" = "1" /* Supplement Spinal Meninges with Autologous Tissue Substitute, Percutaneous Approach */
"00UT3JZ" = "1" /* Supplement Spinal Meninges with Synthetic Substitute, Percutaneous Approach */
"00UT3KZ" = "1" /* Supplement Spinal Meninges with Nonautologous Tissue Substitute, Percutaneous Approach */
"00UT47Z" = "1" /* Supplement Spinal Meninges with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"00UT4JZ" = "1" /* Supplement Spinal Meninges with Synthetic Substitute, Percutaneous Endoscopic Approach */
"00UT4KZ" = "1" /* Supplement Spinal Meninges with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"00W000Z" = "1" /* Revision of Drainage Device in Brain, Open Approach */
"00W002Z" = "1" /* Revision of Monitoring Device in Brain, Open Approach */
"00W003Z" = "1" /* Revision of Infusion Device in Brain, Open Approach */
"00W007Z" = "1" /* Revision of Autologous Tissue Substitute in Brain, Open Approach */
"00W00JZ" = "1" /* Revision of Synthetic Substitute in Brain, Open Approach */
"00W00KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Brain, Open Approach */
"00W00MZ" = "1" /* Revision of Neurostimulator Lead in Brain, Open Approach */
"00W030Z" = "1" /* Revision of Drainage Device in Brain, Percutaneous Approach */
"00W032Z" = "1" /* Revision of Monitoring Device in Brain, Percutaneous Approach */
"00W033Z" = "1" /* Revision of Infusion Device in Brain, Percutaneous Approach */
"00W037Z" = "1" /* Revision of Autologous Tissue Substitute in Brain, Percutaneous Approach */
"00W03JZ" = "1" /* Revision of Synthetic Substitute in Brain, Percutaneous Approach */
"00W03KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Brain, Percutaneous Approach */
"00W03MZ" = "1" /* Revision of Neurostimulator Lead in Brain, Percutaneous Approach */
"00W040Z" = "1" /* Revision of Drainage Device in Brain, Percutaneous Endoscopic Approach */
"00W042Z" = "1" /* Revision of Monitoring Device in Brain, Percutaneous Endoscopic Approach */
"00W043Z" = "1" /* Revision of Infusion Device in Brain, Percutaneous Endoscopic Approach */
"00W047Z" = "1" /* Revision of Autologous Tissue Substitute in Brain, Percutaneous Endoscopic Approach */
"00W04JZ" = "1" /* Revision of Synthetic Substitute in Brain, Percutaneous Endoscopic Approach */
"00W04KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Brain, Percutaneous Endoscopic Approach */
"00W04MZ" = "1" /* Revision of Neurostimulator Lead in Brain, Percutaneous Endoscopic Approach */
"00W600Z" = "1" /* Revision of Drainage Device in Cerebral Ventricle, Open Approach */
"00W602Z" = "1" /* Revision of Monitoring Device in Cerebral Ventricle, Open Approach */
"00W603Z" = "1" /* Revision of Infusion Device in Cerebral Ventricle, Open Approach */
"00W60JZ" = "1" /* Revision of Synthetic Substitute in Cerebral Ventricle, Open Approach */
"00W60MZ" = "1" /* Revision of Neurostimulator Lead in Cerebral Ventricle, Open Approach */
"00W630Z" = "1" /* Revision of Drainage Device in Cerebral Ventricle, Percutaneous Approach */
"00W632Z" = "1" /* Revision of Monitoring Device in Cerebral Ventricle, Percutaneous Approach */
"00W633Z" = "1" /* Revision of Infusion Device in Cerebral Ventricle, Percutaneous Approach */
"00W63JZ" = "1" /* Revision of Synthetic Substitute in Cerebral Ventricle, Percutaneous Approach */
"00W63MZ" = "1" /* Revision of Neurostimulator Lead in Cerebral Ventricle, Percutaneous Approach */
"00W640Z" = "1" /* Revision of Drainage Device in Cerebral Ventricle, Percutaneous Endoscopic Approach */
"00W642Z" = "1" /* Revision of Monitoring Device in Cerebral Ventricle, Percutaneous Endoscopic Approach */
"00W643Z" = "1" /* Revision of Infusion Device in Cerebral Ventricle, Percutaneous Endoscopic Approach */
"00W64JZ" = "1" /* Revision of Synthetic Substitute in Cerebral Ventricle, Percutaneous Endoscopic Approach */
"00W64MZ" = "1" /* Revision of Neurostimulator Lead in Cerebral Ventricle, Percutaneous Endoscopic Approach */
"00WE00Z" = "1" /* Revision of Drainage Device in Cranial Nerve, Open Approach */
"00WE02Z" = "1" /* Revision of Monitoring Device in Cranial Nerve, Open Approach */
"00WE03Z" = "1" /* Revision of Infusion Device in Cranial Nerve, Open Approach */
"00WE07Z" = "1" /* Revision of Autologous Tissue Substitute in Cranial Nerve, Open Approach */
"00WE0MZ" = "1" /* Revision of Neurostimulator Lead in Cranial Nerve, Open Approach */
"00WE30Z" = "1" /* Revision of Drainage Device in Cranial Nerve, Percutaneous Approach */
"00WE32Z" = "1" /* Revision of Monitoring Device in Cranial Nerve, Percutaneous Approach */
"00WE33Z" = "1" /* Revision of Infusion Device in Cranial Nerve, Percutaneous Approach */
"00WE37Z" = "1" /* Revision of Autologous Tissue Substitute in Cranial Nerve, Percutaneous Approach */
"00WE3MZ" = "1" /* Revision of Neurostimulator Lead in Cranial Nerve, Percutaneous Approach */
"00WE40Z" = "1" /* Revision of Drainage Device in Cranial Nerve, Percutaneous Endoscopic Approach */
"00WE42Z" = "1" /* Revision of Monitoring Device in Cranial Nerve, Percutaneous Endoscopic Approach */
"00WE43Z" = "1" /* Revision of Infusion Device in Cranial Nerve, Percutaneous Endoscopic Approach */
"00WE47Z" = "1" /* Revision of Autologous Tissue Substitute in Cranial Nerve, Percutaneous Endoscopic Approach */
"00WE4MZ" = "1" /* Revision of Neurostimulator Lead in Cranial Nerve, Percutaneous Endoscopic Approach */
"00WU00Z" = "1" /* Revision of Drainage Device in Spinal Canal, Open Approach */
"00WU02Z" = "1" /* Revision of Monitoring Device in Spinal Canal, Open Approach */
"00WU03Z" = "1" /* Revision of Infusion Device in Spinal Canal, Open Approach */
"00WU0JZ" = "1" /* Revision of Synthetic Substitute in Spinal Canal, Open Approach */
"00WU0MZ" = "1" /* Revision of Neurostimulator Lead in Spinal Canal, Open Approach */
"00WU30Z" = "1" /* Revision of Drainage Device in Spinal Canal, Percutaneous Approach */
"00WU32Z" = "1" /* Revision of Monitoring Device in Spinal Canal, Percutaneous Approach */
"00WU33Z" = "1" /* Revision of Infusion Device in Spinal Canal, Percutaneous Approach */
"00WU3JZ" = "1" /* Revision of Synthetic Substitute in Spinal Canal, Percutaneous Approach */
"00WU3MZ" = "1" /* Revision of Neurostimulator Lead in Spinal Canal, Percutaneous Approach */
"00WU40Z" = "1" /* Revision of Drainage Device in Spinal Canal, Percutaneous Endoscopic Approach */
"00WU42Z" = "1" /* Revision of Monitoring Device in Spinal Canal, Percutaneous Endoscopic Approach */
"00WU43Z" = "1" /* Revision of Infusion Device in Spinal Canal, Percutaneous Endoscopic Approach */
"00WU4JZ" = "1" /* Revision of Synthetic Substitute in Spinal Canal, Percutaneous Endoscopic Approach */
"00WU4MZ" = "1" /* Revision of Neurostimulator Lead in Spinal Canal, Percutaneous Endoscopic Approach */
"00WV00Z" = "1" /* Revision of Drainage Device in Spinal Cord, Open Approach */
"00WV02Z" = "1" /* Revision of Monitoring Device in Spinal Cord, Open Approach */
"00WV03Z" = "1" /* Revision of Infusion Device in Spinal Cord, Open Approach */
"00WV07Z" = "1" /* Revision of Autologous Tissue Substitute in Spinal Cord, Open Approach */
"00WV0JZ" = "1" /* Revision of Synthetic Substitute in Spinal Cord, Open Approach */
"00WV0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Spinal Cord, Open Approach */
"00WV0MZ" = "1" /* Revision of Neurostimulator Lead in Spinal Cord, Open Approach */
"00WV30Z" = "1" /* Revision of Drainage Device in Spinal Cord, Percutaneous Approach */
"00WV32Z" = "1" /* Revision of Monitoring Device in Spinal Cord, Percutaneous Approach */
"00WV33Z" = "1" /* Revision of Infusion Device in Spinal Cord, Percutaneous Approach */
"00WV37Z" = "1" /* Revision of Autologous Tissue Substitute in Spinal Cord, Percutaneous Approach */
"00WV3JZ" = "1" /* Revision of Synthetic Substitute in Spinal Cord, Percutaneous Approach */
"00WV3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Spinal Cord, Percutaneous Approach */
"00WV3MZ" = "1" /* Revision of Neurostimulator Lead in Spinal Cord, Percutaneous Approach */
"00WV40Z" = "1" /* Revision of Drainage Device in Spinal Cord, Percutaneous Endoscopic Approach */
"00WV42Z" = "1" /* Revision of Monitoring Device in Spinal Cord, Percutaneous Endoscopic Approach */
"00WV43Z" = "1" /* Revision of Infusion Device in Spinal Cord, Percutaneous Endoscopic Approach */
"00WV47Z" = "1" /* Revision of Autologous Tissue Substitute in Spinal Cord, Percutaneous Endoscopic Approach */
"00WV4JZ" = "1" /* Revision of Synthetic Substitute in Spinal Cord, Percutaneous Endoscopic Approach */
"00WV4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Spinal Cord, Percutaneous Endoscopic Approach */
"00WV4MZ" = "1" /* Revision of Neurostimulator Lead in Spinal Cord, Percutaneous Endoscopic Approach */
"00XF0ZF" = "1" /* Transfer Olfactory Nerve to Olfactory Nerve, Open Approach */
"00XF0ZG" = "1" /* Transfer Olfactory Nerve to Optic Nerve, Open Approach */
"00XF0ZH" = "1" /* Transfer Olfactory Nerve to Oculomotor Nerve, Open Approach */
"00XF0ZJ" = "1" /* Transfer Olfactory Nerve to Trochlear Nerve, Open Approach */
"00XF0ZK" = "1" /* Transfer Olfactory Nerve to Trigeminal Nerve, Open Approach */
"00XF0ZL" = "1" /* Transfer Olfactory Nerve to Abducens Nerve, Open Approach */
"00XF0ZM" = "1" /* Transfer Olfactory Nerve to Facial Nerve, Open Approach */
"00XF0ZN" = "1" /* Transfer Olfactory Nerve to Acoustic Nerve, Open Approach */
"00XF0ZP" = "1" /* Transfer Olfactory Nerve to Glossopharyngeal Nerve, Open Approach */
"00XF0ZQ" = "1" /* Transfer Olfactory Nerve to Vagus Nerve, Open Approach */
"00XF0ZR" = "1" /* Transfer Olfactory Nerve to Accessory Nerve, Open Approach */
"00XF0ZS" = "1" /* Transfer Olfactory Nerve to Hypoglossal Nerve, Open Approach */
"00XF4ZF" = "1" /* Transfer Olfactory Nerve to Olfactory Nerve, Percutaneous Endoscopic Approach */
"00XF4ZG" = "1" /* Transfer Olfactory Nerve to Optic Nerve, Percutaneous Endoscopic Approach */
"00XF4ZH" = "1" /* Transfer Olfactory Nerve to Oculomotor Nerve, Percutaneous Endoscopic Approach */
"00XF4ZJ" = "1" /* Transfer Olfactory Nerve to Trochlear Nerve, Percutaneous Endoscopic Approach */
"00XF4ZK" = "1" /* Transfer Olfactory Nerve to Trigeminal Nerve, Percutaneous Endoscopic Approach */
"00XF4ZL" = "1" /* Transfer Olfactory Nerve to Abducens Nerve, Percutaneous Endoscopic Approach */
"00XF4ZM" = "1" /* Transfer Olfactory Nerve to Facial Nerve, Percutaneous Endoscopic Approach */
"00XF4ZN" = "1" /* Transfer Olfactory Nerve to Acoustic Nerve, Percutaneous Endoscopic Approach */
"00XF4ZP" = "1" /* Transfer Olfactory Nerve to Glossopharyngeal Nerve, Percutaneous Endoscopic Approach */
"00XF4ZQ" = "1" /* Transfer Olfactory Nerve to Vagus Nerve, Percutaneous Endoscopic Approach */
"00XF4ZR" = "1" /* Transfer Olfactory Nerve to Accessory Nerve, Percutaneous Endoscopic Approach */
"00XF4ZS" = "1" /* Transfer Olfactory Nerve to Hypoglossal Nerve, Percutaneous Endoscopic Approach */
"00XG0ZF" = "1" /* Transfer Optic Nerve to Olfactory Nerve, Open Approach */
"00XG0ZG" = "1" /* Transfer Optic Nerve to Optic Nerve, Open Approach */
"00XG0ZH" = "1" /* Transfer Optic Nerve to Oculomotor Nerve, Open Approach */
"00XG0ZJ" = "1" /* Transfer Optic Nerve to Trochlear Nerve, Open Approach */
"00XG0ZK" = "1" /* Transfer Optic Nerve to Trigeminal Nerve, Open Approach */
"00XG0ZL" = "1" /* Transfer Optic Nerve to Abducens Nerve, Open Approach */
"00XG0ZM" = "1" /* Transfer Optic Nerve to Facial Nerve, Open Approach */
"00XG0ZN" = "1" /* Transfer Optic Nerve to Acoustic Nerve, Open Approach */
"00XG0ZP" = "1" /* Transfer Optic Nerve to Glossopharyngeal Nerve, Open Approach */
"00XG0ZQ" = "1" /* Transfer Optic Nerve to Vagus Nerve, Open Approach */
"00XG0ZR" = "1" /* Transfer Optic Nerve to Accessory Nerve, Open Approach */
"00XG0ZS" = "1" /* Transfer Optic Nerve to Hypoglossal Nerve, Open Approach */
"00XG4ZF" = "1" /* Transfer Optic Nerve to Olfactory Nerve, Percutaneous Endoscopic Approach */
"00XG4ZG" = "1" /* Transfer Optic Nerve to Optic Nerve, Percutaneous Endoscopic Approach */
"00XG4ZH" = "1" /* Transfer Optic Nerve to Oculomotor Nerve, Percutaneous Endoscopic Approach */
"00XG4ZJ" = "1" /* Transfer Optic Nerve to Trochlear Nerve, Percutaneous Endoscopic Approach */
"00XG4ZK" = "1" /* Transfer Optic Nerve to Trigeminal Nerve, Percutaneous Endoscopic Approach */
"00XG4ZL" = "1" /* Transfer Optic Nerve to Abducens Nerve, Percutaneous Endoscopic Approach */
"00XG4ZM" = "1" /* Transfer Optic Nerve to Facial Nerve, Percutaneous Endoscopic Approach */
"00XG4ZN" = "1" /* Transfer Optic Nerve to Acoustic Nerve, Percutaneous Endoscopic Approach */
"00XG4ZP" = "1" /* Transfer Optic Nerve to Glossopharyngeal Nerve, Percutaneous Endoscopic Approach */
"00XG4ZQ" = "1" /* Transfer Optic Nerve to Vagus Nerve, Percutaneous Endoscopic Approach */
"00XG4ZR" = "1" /* Transfer Optic Nerve to Accessory Nerve, Percutaneous Endoscopic Approach */
"00XG4ZS" = "1" /* Transfer Optic Nerve to Hypoglossal Nerve, Percutaneous Endoscopic Approach */
"00XH0ZF" = "1" /* Transfer Oculomotor Nerve to Olfactory Nerve, Open Approach */
"00XH0ZG" = "1" /* Transfer Oculomotor Nerve to Optic Nerve, Open Approach */
"00XH0ZH" = "1" /* Transfer Oculomotor Nerve to Oculomotor Nerve, Open Approach */
"00XH0ZJ" = "1" /* Transfer Oculomotor Nerve to Trochlear Nerve, Open Approach */
"00XH0ZK" = "1" /* Transfer Oculomotor Nerve to Trigeminal Nerve, Open Approach */
"00XH0ZL" = "1" /* Transfer Oculomotor Nerve to Abducens Nerve, Open Approach */
"00XH0ZM" = "1" /* Transfer Oculomotor Nerve to Facial Nerve, Open Approach */
"00XH0ZN" = "1" /* Transfer Oculomotor Nerve to Acoustic Nerve, Open Approach */
"00XH0ZP" = "1" /* Transfer Oculomotor Nerve to Glossopharyngeal Nerve, Open Approach */
"00XH0ZQ" = "1" /* Transfer Oculomotor Nerve to Vagus Nerve, Open Approach */
"00XH0ZR" = "1" /* Transfer Oculomotor Nerve to Accessory Nerve, Open Approach */
"00XH0ZS" = "1" /* Transfer Oculomotor Nerve to Hypoglossal Nerve, Open Approach */
"00XH4ZF" = "1" /* Transfer Oculomotor Nerve to Olfactory Nerve, Percutaneous Endoscopic Approach */
"00XH4ZG" = "1" /* Transfer Oculomotor Nerve to Optic Nerve, Percutaneous Endoscopic Approach */
"00XH4ZH" = "1" /* Transfer Oculomotor Nerve to Oculomotor Nerve, Percutaneous Endoscopic Approach */
"00XH4ZJ" = "1" /* Transfer Oculomotor Nerve to Trochlear Nerve, Percutaneous Endoscopic Approach */
"00XH4ZK" = "1" /* Transfer Oculomotor Nerve to Trigeminal Nerve, Percutaneous Endoscopic Approach */
"00XH4ZL" = "1" /* Transfer Oculomotor Nerve to Abducens Nerve, Percutaneous Endoscopic Approach */
"00XH4ZM" = "1" /* Transfer Oculomotor Nerve to Facial Nerve, Percutaneous Endoscopic Approach */
"00XH4ZN" = "1" /* Transfer Oculomotor Nerve to Acoustic Nerve, Percutaneous Endoscopic Approach */
"00XH4ZP" = "1" /* Transfer Oculomotor Nerve to Glossopharyngeal Nerve, Percutaneous Endoscopic Approach */
"00XH4ZQ" = "1" /* Transfer Oculomotor Nerve to Vagus Nerve, Percutaneous Endoscopic Approach */
"00XH4ZR" = "1" /* Transfer Oculomotor Nerve to Accessory Nerve, Percutaneous Endoscopic Approach */
"00XH4ZS" = "1" /* Transfer Oculomotor Nerve to Hypoglossal Nerve, Percutaneous Endoscopic Approach */
"00XJ0ZF" = "1" /* Transfer Trochlear Nerve to Olfactory Nerve, Open Approach */
"00XJ0ZG" = "1" /* Transfer Trochlear Nerve to Optic Nerve, Open Approach */
"00XJ0ZH" = "1" /* Transfer Trochlear Nerve to Oculomotor Nerve, Open Approach */
"00XJ0ZJ" = "1" /* Transfer Trochlear Nerve to Trochlear Nerve, Open Approach */
"00XJ0ZK" = "1" /* Transfer Trochlear Nerve to Trigeminal Nerve, Open Approach */
"00XJ0ZL" = "1" /* Transfer Trochlear Nerve to Abducens Nerve, Open Approach */
"00XJ0ZM" = "1" /* Transfer Trochlear Nerve to Facial Nerve, Open Approach */
"00XJ0ZN" = "1" /* Transfer Trochlear Nerve to Acoustic Nerve, Open Approach */
"00XJ0ZP" = "1" /* Transfer Trochlear Nerve to Glossopharyngeal Nerve, Open Approach */
"00XJ0ZQ" = "1" /* Transfer Trochlear Nerve to Vagus Nerve, Open Approach */
"00XJ0ZR" = "1" /* Transfer Trochlear Nerve to Accessory Nerve, Open Approach */
"00XJ0ZS" = "1" /* Transfer Trochlear Nerve to Hypoglossal Nerve, Open Approach */
"00XJ4ZF" = "1" /* Transfer Trochlear Nerve to Olfactory Nerve, Percutaneous Endoscopic Approach */
"00XJ4ZG" = "1" /* Transfer Trochlear Nerve to Optic Nerve, Percutaneous Endoscopic Approach */
"00XJ4ZH" = "1" /* Transfer Trochlear Nerve to Oculomotor Nerve, Percutaneous Endoscopic Approach */
"00XJ4ZJ" = "1" /* Transfer Trochlear Nerve to Trochlear Nerve, Percutaneous Endoscopic Approach */
"00XJ4ZK" = "1" /* Transfer Trochlear Nerve to Trigeminal Nerve, Percutaneous Endoscopic Approach */
"00XJ4ZL" = "1" /* Transfer Trochlear Nerve to Abducens Nerve, Percutaneous Endoscopic Approach */
"00XJ4ZM" = "1" /* Transfer Trochlear Nerve to Facial Nerve, Percutaneous Endoscopic Approach */
"00XJ4ZN" = "1" /* Transfer Trochlear Nerve to Acoustic Nerve, Percutaneous Endoscopic Approach */
"00XJ4ZP" = "1" /* Transfer Trochlear Nerve to Glossopharyngeal Nerve, Percutaneous Endoscopic Approach */
"00XJ4ZQ" = "1" /* Transfer Trochlear Nerve to Vagus Nerve, Percutaneous Endoscopic Approach */
"00XJ4ZR" = "1" /* Transfer Trochlear Nerve to Accessory Nerve, Percutaneous Endoscopic Approach */
"00XJ4ZS" = "1" /* Transfer Trochlear Nerve to Hypoglossal Nerve, Percutaneous Endoscopic Approach */
"00XK0ZF" = "1" /* Transfer Trigeminal Nerve to Olfactory Nerve, Open Approach */
"00XK0ZG" = "1" /* Transfer Trigeminal Nerve to Optic Nerve, Open Approach */
"00XK0ZH" = "1" /* Transfer Trigeminal Nerve to Oculomotor Nerve, Open Approach */
"00XK0ZJ" = "1" /* Transfer Trigeminal Nerve to Trochlear Nerve, Open Approach */
"00XK0ZK" = "1" /* Transfer Trigeminal Nerve to Trigeminal Nerve, Open Approach */
"00XK0ZL" = "1" /* Transfer Trigeminal Nerve to Abducens Nerve, Open Approach */
"00XK0ZM" = "1" /* Transfer Trigeminal Nerve to Facial Nerve, Open Approach */
"00XK0ZN" = "1" /* Transfer Trigeminal Nerve to Acoustic Nerve, Open Approach */
"00XK0ZP" = "1" /* Transfer Trigeminal Nerve to Glossopharyngeal Nerve, Open Approach */
"00XK0ZQ" = "1" /* Transfer Trigeminal Nerve to Vagus Nerve, Open Approach */
"00XK0ZR" = "1" /* Transfer Trigeminal Nerve to Accessory Nerve, Open Approach */
"00XK0ZS" = "1" /* Transfer Trigeminal Nerve to Hypoglossal Nerve, Open Approach */
"00XK4ZF" = "1" /* Transfer Trigeminal Nerve to Olfactory Nerve, Percutaneous Endoscopic Approach */
"00XK4ZG" = "1" /* Transfer Trigeminal Nerve to Optic Nerve, Percutaneous Endoscopic Approach */
"00XK4ZH" = "1" /* Transfer Trigeminal Nerve to Oculomotor Nerve, Percutaneous Endoscopic Approach */
"00XK4ZJ" = "1" /* Transfer Trigeminal Nerve to Trochlear Nerve, Percutaneous Endoscopic Approach */
"00XK4ZK" = "1" /* Transfer Trigeminal Nerve to Trigeminal Nerve, Percutaneous Endoscopic Approach */
"00XK4ZL" = "1" /* Transfer Trigeminal Nerve to Abducens Nerve, Percutaneous Endoscopic Approach */
"00XK4ZM" = "1" /* Transfer Trigeminal Nerve to Facial Nerve, Percutaneous Endoscopic Approach */
"00XK4ZN" = "1" /* Transfer Trigeminal Nerve to Acoustic Nerve, Percutaneous Endoscopic Approach */
"00XK4ZP" = "1" /* Transfer Trigeminal Nerve to Glossopharyngeal Nerve, Percutaneous Endoscopic Approach */
"00XK4ZQ" = "1" /* Transfer Trigeminal Nerve to Vagus Nerve, Percutaneous Endoscopic Approach */
"00XK4ZR" = "1" /* Transfer Trigeminal Nerve to Accessory Nerve, Percutaneous Endoscopic Approach */
"00XK4ZS" = "1" /* Transfer Trigeminal Nerve to Hypoglossal Nerve, Percutaneous Endoscopic Approach */
"00XL0ZF" = "1" /* Transfer Abducens Nerve to Olfactory Nerve, Open Approach */
"00XL0ZG" = "1" /* Transfer Abducens Nerve to Optic Nerve, Open Approach */
"00XL0ZH" = "1" /* Transfer Abducens Nerve to Oculomotor Nerve, Open Approach */
"00XL0ZJ" = "1" /* Transfer Abducens Nerve to Trochlear Nerve, Open Approach */
"00XL0ZK" = "1" /* Transfer Abducens Nerve to Trigeminal Nerve, Open Approach */
"00XL0ZL" = "1" /* Transfer Abducens Nerve to Abducens Nerve, Open Approach */
"00XL0ZM" = "1" /* Transfer Abducens Nerve to Facial Nerve, Open Approach */
"00XL0ZN" = "1" /* Transfer Abducens Nerve to Acoustic Nerve, Open Approach */
"00XL0ZP" = "1" /* Transfer Abducens Nerve to Glossopharyngeal Nerve, Open Approach */
"00XL0ZQ" = "1" /* Transfer Abducens Nerve to Vagus Nerve, Open Approach */
"00XL0ZR" = "1" /* Transfer Abducens Nerve to Accessory Nerve, Open Approach */
"00XL0ZS" = "1" /* Transfer Abducens Nerve to Hypoglossal Nerve, Open Approach */
"00XL4ZF" = "1" /* Transfer Abducens Nerve to Olfactory Nerve, Percutaneous Endoscopic Approach */
"00XL4ZG" = "1" /* Transfer Abducens Nerve to Optic Nerve, Percutaneous Endoscopic Approach */
"00XL4ZH" = "1" /* Transfer Abducens Nerve to Oculomotor Nerve, Percutaneous Endoscopic Approach */
"00XL4ZJ" = "1" /* Transfer Abducens Nerve to Trochlear Nerve, Percutaneous Endoscopic Approach */
"00XL4ZK" = "1" /* Transfer Abducens Nerve to Trigeminal Nerve, Percutaneous Endoscopic Approach */
"00XL4ZL" = "1" /* Transfer Abducens Nerve to Abducens Nerve, Percutaneous Endoscopic Approach */
"00XL4ZM" = "1" /* Transfer Abducens Nerve to Facial Nerve, Percutaneous Endoscopic Approach */
"00XL4ZN" = "1" /* Transfer Abducens Nerve to Acoustic Nerve, Percutaneous Endoscopic Approach */
"00XL4ZP" = "1" /* Transfer Abducens Nerve to Glossopharyngeal Nerve, Percutaneous Endoscopic Approach */
"00XL4ZQ" = "1" /* Transfer Abducens Nerve to Vagus Nerve, Percutaneous Endoscopic Approach */
"00XL4ZR" = "1" /* Transfer Abducens Nerve to Accessory Nerve, Percutaneous Endoscopic Approach */
"00XL4ZS" = "1" /* Transfer Abducens Nerve to Hypoglossal Nerve, Percutaneous Endoscopic Approach */
"00XM0ZF" = "1" /* Transfer Facial Nerve to Olfactory Nerve, Open Approach */
"00XM0ZG" = "1" /* Transfer Facial Nerve to Optic Nerve, Open Approach */
"00XM0ZH" = "1" /* Transfer Facial Nerve to Oculomotor Nerve, Open Approach */
"00XM0ZJ" = "1" /* Transfer Facial Nerve to Trochlear Nerve, Open Approach */
"00XM0ZK" = "1" /* Transfer Facial Nerve to Trigeminal Nerve, Open Approach */
"00XM0ZL" = "1" /* Transfer Facial Nerve to Abducens Nerve, Open Approach */
"00XM0ZM" = "1" /* Transfer Facial Nerve to Facial Nerve, Open Approach */
"00XM0ZN" = "1" /* Transfer Facial Nerve to Acoustic Nerve, Open Approach */
"00XM0ZP" = "1" /* Transfer Facial Nerve to Glossopharyngeal Nerve, Open Approach */
"00XM0ZQ" = "1" /* Transfer Facial Nerve to Vagus Nerve, Open Approach */
"00XM0ZR" = "1" /* Transfer Facial Nerve to Accessory Nerve, Open Approach */
"00XM0ZS" = "1" /* Transfer Facial Nerve to Hypoglossal Nerve, Open Approach */
"00XM4ZF" = "1" /* Transfer Facial Nerve to Olfactory Nerve, Percutaneous Endoscopic Approach */
"00XM4ZG" = "1" /* Transfer Facial Nerve to Optic Nerve, Percutaneous Endoscopic Approach */
"00XM4ZH" = "1" /* Transfer Facial Nerve to Oculomotor Nerve, Percutaneous Endoscopic Approach */
"00XM4ZJ" = "1" /* Transfer Facial Nerve to Trochlear Nerve, Percutaneous Endoscopic Approach */
"00XM4ZK" = "1" /* Transfer Facial Nerve to Trigeminal Nerve, Percutaneous Endoscopic Approach */
"00XM4ZL" = "1" /* Transfer Facial Nerve to Abducens Nerve, Percutaneous Endoscopic Approach */
"00XM4ZM" = "1" /* Transfer Facial Nerve to Facial Nerve, Percutaneous Endoscopic Approach */
"00XM4ZN" = "1" /* Transfer Facial Nerve to Acoustic Nerve, Percutaneous Endoscopic Approach */
"00XM4ZP" = "1" /* Transfer Facial Nerve to Glossopharyngeal Nerve, Percutaneous Endoscopic Approach */
"00XM4ZQ" = "1" /* Transfer Facial Nerve to Vagus Nerve, Percutaneous Endoscopic Approach */
"00XM4ZR" = "1" /* Transfer Facial Nerve to Accessory Nerve, Percutaneous Endoscopic Approach */
"00XM4ZS" = "1" /* Transfer Facial Nerve to Hypoglossal Nerve, Percutaneous Endoscopic Approach */
"00XN0ZF" = "1" /* Transfer Acoustic Nerve to Olfactory Nerve, Open Approach */
"00XN0ZG" = "1" /* Transfer Acoustic Nerve to Optic Nerve, Open Approach */
"00XN0ZH" = "1" /* Transfer Acoustic Nerve to Oculomotor Nerve, Open Approach */
"00XN0ZJ" = "1" /* Transfer Acoustic Nerve to Trochlear Nerve, Open Approach */
"00XN0ZK" = "1" /* Transfer Acoustic Nerve to Trigeminal Nerve, Open Approach */
"00XN0ZL" = "1" /* Transfer Acoustic Nerve to Abducens Nerve, Open Approach */
"00XN0ZM" = "1" /* Transfer Acoustic Nerve to Facial Nerve, Open Approach */
"00XN0ZN" = "1" /* Transfer Acoustic Nerve to Acoustic Nerve, Open Approach */
"00XN0ZP" = "1" /* Transfer Acoustic Nerve to Glossopharyngeal Nerve, Open Approach */
"00XN0ZQ" = "1" /* Transfer Acoustic Nerve to Vagus Nerve, Open Approach */
"00XN0ZR" = "1" /* Transfer Acoustic Nerve to Accessory Nerve, Open Approach */
"00XN0ZS" = "1" /* Transfer Acoustic Nerve to Hypoglossal Nerve, Open Approach */
"00XN4ZF" = "1" /* Transfer Acoustic Nerve to Olfactory Nerve, Percutaneous Endoscopic Approach */
"00XN4ZG" = "1" /* Transfer Acoustic Nerve to Optic Nerve, Percutaneous Endoscopic Approach */
"00XN4ZH" = "1" /* Transfer Acoustic Nerve to Oculomotor Nerve, Percutaneous Endoscopic Approach */
"00XN4ZJ" = "1" /* Transfer Acoustic Nerve to Trochlear Nerve, Percutaneous Endoscopic Approach */
"00XN4ZK" = "1" /* Transfer Acoustic Nerve to Trigeminal Nerve, Percutaneous Endoscopic Approach */
"00XN4ZL" = "1" /* Transfer Acoustic Nerve to Abducens Nerve, Percutaneous Endoscopic Approach */
"00XN4ZM" = "1" /* Transfer Acoustic Nerve to Facial Nerve, Percutaneous Endoscopic Approach */
"00XN4ZN" = "1" /* Transfer Acoustic Nerve to Acoustic Nerve, Percutaneous Endoscopic Approach */
"00XN4ZP" = "1" /* Transfer Acoustic Nerve to Glossopharyngeal Nerve, Percutaneous Endoscopic Approach */
"00XN4ZQ" = "1" /* Transfer Acoustic Nerve to Vagus Nerve, Percutaneous Endoscopic Approach */
"00XN4ZR" = "1" /* Transfer Acoustic Nerve to Accessory Nerve, Percutaneous Endoscopic Approach */
"00XN4ZS" = "1" /* Transfer Acoustic Nerve to Hypoglossal Nerve, Percutaneous Endoscopic Approach */
"00XP0ZF" = "1" /* Transfer Glossopharyngeal Nerve to Olfactory Nerve, Open Approach */
"00XP0ZG" = "1" /* Transfer Glossopharyngeal Nerve to Optic Nerve, Open Approach */
"00XP0ZH" = "1" /* Transfer Glossopharyngeal Nerve to Oculomotor Nerve, Open Approach */
"00XP0ZJ" = "1" /* Transfer Glossopharyngeal Nerve to Trochlear Nerve, Open Approach */
"00XP0ZK" = "1" /* Transfer Glossopharyngeal Nerve to Trigeminal Nerve, Open Approach */
"00XP0ZL" = "1" /* Transfer Glossopharyngeal Nerve to Abducens Nerve, Open Approach */
"00XP0ZM" = "1" /* Transfer Glossopharyngeal Nerve to Facial Nerve, Open Approach */
"00XP0ZN" = "1" /* Transfer Glossopharyngeal Nerve to Acoustic Nerve, Open Approach */
"00XP0ZP" = "1" /* Transfer Glossopharyngeal Nerve to Glossopharyngeal Nerve, Open Approach */
"00XP0ZQ" = "1" /* Transfer Glossopharyngeal Nerve to Vagus Nerve, Open Approach */
"00XP0ZR" = "1" /* Transfer Glossopharyngeal Nerve to Accessory Nerve, Open Approach */
"00XP0ZS" = "1" /* Transfer Glossopharyngeal Nerve to Hypoglossal Nerve, Open Approach */
"00XP4ZF" = "1" /* Transfer Glossopharyngeal Nerve to Olfactory Nerve, Percutaneous Endoscopic Approach */
"00XP4ZG" = "1" /* Transfer Glossopharyngeal Nerve to Optic Nerve, Percutaneous Endoscopic Approach */
"00XP4ZH" = "1" /* Transfer Glossopharyngeal Nerve to Oculomotor Nerve, Percutaneous Endoscopic Approach */
"00XP4ZJ" = "1" /* Transfer Glossopharyngeal Nerve to Trochlear Nerve, Percutaneous Endoscopic Approach */
"00XP4ZK" = "1" /* Transfer Glossopharyngeal Nerve to Trigeminal Nerve, Percutaneous Endoscopic Approach */
"00XP4ZL" = "1" /* Transfer Glossopharyngeal Nerve to Abducens Nerve, Percutaneous Endoscopic Approach */
"00XP4ZM" = "1" /* Transfer Glossopharyngeal Nerve to Facial Nerve, Percutaneous Endoscopic Approach */
"00XP4ZN" = "1" /* Transfer Glossopharyngeal Nerve to Acoustic Nerve, Percutaneous Endoscopic Approach */
"00XP4ZP" = "1" /* Transfer Glossopharyngeal Nerve to Glossopharyngeal Nerve, Percutaneous Endoscopic Approach */
"00XP4ZQ" = "1" /* Transfer Glossopharyngeal Nerve to Vagus Nerve, Percutaneous Endoscopic Approach */
"00XP4ZR" = "1" /* Transfer Glossopharyngeal Nerve to Accessory Nerve, Percutaneous Endoscopic Approach */
"00XP4ZS" = "1" /* Transfer Glossopharyngeal Nerve to Hypoglossal Nerve, Percutaneous Endoscopic Approach */
"00XQ0ZF" = "1" /* Transfer Vagus Nerve to Olfactory Nerve, Open Approach */
"00XQ0ZG" = "1" /* Transfer Vagus Nerve to Optic Nerve, Open Approach */
"00XQ0ZH" = "1" /* Transfer Vagus Nerve to Oculomotor Nerve, Open Approach */
"00XQ0ZJ" = "1" /* Transfer Vagus Nerve to Trochlear Nerve, Open Approach */
"00XQ0ZK" = "1" /* Transfer Vagus Nerve to Trigeminal Nerve, Open Approach */
"00XQ0ZL" = "1" /* Transfer Vagus Nerve to Abducens Nerve, Open Approach */
"00XQ0ZM" = "1" /* Transfer Vagus Nerve to Facial Nerve, Open Approach */
"00XQ0ZN" = "1" /* Transfer Vagus Nerve to Acoustic Nerve, Open Approach */
"00XQ0ZP" = "1" /* Transfer Vagus Nerve to Glossopharyngeal Nerve, Open Approach */
"00XQ0ZQ" = "1" /* Transfer Vagus Nerve to Vagus Nerve, Open Approach */
"00XQ0ZR" = "1" /* Transfer Vagus Nerve to Accessory Nerve, Open Approach */
"00XQ0ZS" = "1" /* Transfer Vagus Nerve to Hypoglossal Nerve, Open Approach */
"00XQ4ZF" = "1" /* Transfer Vagus Nerve to Olfactory Nerve, Percutaneous Endoscopic Approach */
"00XQ4ZG" = "1" /* Transfer Vagus Nerve to Optic Nerve, Percutaneous Endoscopic Approach */
"00XQ4ZH" = "1" /* Transfer Vagus Nerve to Oculomotor Nerve, Percutaneous Endoscopic Approach */
"00XQ4ZJ" = "1" /* Transfer Vagus Nerve to Trochlear Nerve, Percutaneous Endoscopic Approach */
"00XQ4ZK" = "1" /* Transfer Vagus Nerve to Trigeminal Nerve, Percutaneous Endoscopic Approach */
"00XQ4ZL" = "1" /* Transfer Vagus Nerve to Abducens Nerve, Percutaneous Endoscopic Approach */
"00XQ4ZM" = "1" /* Transfer Vagus Nerve to Facial Nerve, Percutaneous Endoscopic Approach */
"00XQ4ZN" = "1" /* Transfer Vagus Nerve to Acoustic Nerve, Percutaneous Endoscopic Approach */
"00XQ4ZP" = "1" /* Transfer Vagus Nerve to Glossopharyngeal Nerve, Percutaneous Endoscopic Approach */
"00XQ4ZQ" = "1" /* Transfer Vagus Nerve to Vagus Nerve, Percutaneous Endoscopic Approach */
"00XQ4ZR" = "1" /* Transfer Vagus Nerve to Accessory Nerve, Percutaneous Endoscopic Approach */
"00XQ4ZS" = "1" /* Transfer Vagus Nerve to Hypoglossal Nerve, Percutaneous Endoscopic Approach */
"00XR0ZF" = "1" /* Transfer Accessory Nerve to Olfactory Nerve, Open Approach */
"00XR0ZG" = "1" /* Transfer Accessory Nerve to Optic Nerve, Open Approach */
"00XR0ZH" = "1" /* Transfer Accessory Nerve to Oculomotor Nerve, Open Approach */
"00XR0ZJ" = "1" /* Transfer Accessory Nerve to Trochlear Nerve, Open Approach */
"00XR0ZK" = "1" /* Transfer Accessory Nerve to Trigeminal Nerve, Open Approach */
"00XR0ZL" = "1" /* Transfer Accessory Nerve to Abducens Nerve, Open Approach */
"00XR0ZM" = "1" /* Transfer Accessory Nerve to Facial Nerve, Open Approach */
"00XR0ZN" = "1" /* Transfer Accessory Nerve to Acoustic Nerve, Open Approach */
"00XR0ZP" = "1" /* Transfer Accessory Nerve to Glossopharyngeal Nerve, Open Approach */
"00XR0ZQ" = "1" /* Transfer Accessory Nerve to Vagus Nerve, Open Approach */
"00XR0ZR" = "1" /* Transfer Accessory Nerve to Accessory Nerve, Open Approach */
"00XR0ZS" = "1" /* Transfer Accessory Nerve to Hypoglossal Nerve, Open Approach */
"00XR4ZF" = "1" /* Transfer Accessory Nerve to Olfactory Nerve, Percutaneous Endoscopic Approach */
"00XR4ZG" = "1" /* Transfer Accessory Nerve to Optic Nerve, Percutaneous Endoscopic Approach */
"00XR4ZH" = "1" /* Transfer Accessory Nerve to Oculomotor Nerve, Percutaneous Endoscopic Approach */
"00XR4ZJ" = "1" /* Transfer Accessory Nerve to Trochlear Nerve, Percutaneous Endoscopic Approach */
"00XR4ZK" = "1" /* Transfer Accessory Nerve to Trigeminal Nerve, Percutaneous Endoscopic Approach */
"00XR4ZL" = "1" /* Transfer Accessory Nerve to Abducens Nerve, Percutaneous Endoscopic Approach */
"00XR4ZM" = "1" /* Transfer Accessory Nerve to Facial Nerve, Percutaneous Endoscopic Approach */
"00XR4ZN" = "1" /* Transfer Accessory Nerve to Acoustic Nerve, Percutaneous Endoscopic Approach */
"00XR4ZP" = "1" /* Transfer Accessory Nerve to Glossopharyngeal Nerve, Percutaneous Endoscopic Approach */
"00XR4ZQ" = "1" /* Transfer Accessory Nerve to Vagus Nerve, Percutaneous Endoscopic Approach */
"00XR4ZR" = "1" /* Transfer Accessory Nerve to Accessory Nerve, Percutaneous Endoscopic Approach */
"00XR4ZS" = "1" /* Transfer Accessory Nerve to Hypoglossal Nerve, Percutaneous Endoscopic Approach */
"00XS0ZF" = "1" /* Transfer Hypoglossal Nerve to Olfactory Nerve, Open Approach */
"00XS0ZG" = "1" /* Transfer Hypoglossal Nerve to Optic Nerve, Open Approach */
"00XS0ZH" = "1" /* Transfer Hypoglossal Nerve to Oculomotor Nerve, Open Approach */
"00XS0ZJ" = "1" /* Transfer Hypoglossal Nerve to Trochlear Nerve, Open Approach */
"00XS0ZK" = "1" /* Transfer Hypoglossal Nerve to Trigeminal Nerve, Open Approach */
"00XS0ZL" = "1" /* Transfer Hypoglossal Nerve to Abducens Nerve, Open Approach */
"00XS0ZM" = "1" /* Transfer Hypoglossal Nerve to Facial Nerve, Open Approach */
"00XS0ZN" = "1" /* Transfer Hypoglossal Nerve to Acoustic Nerve, Open Approach */
"00XS0ZP" = "1" /* Transfer Hypoglossal Nerve to Glossopharyngeal Nerve, Open Approach */
"00XS0ZQ" = "1" /* Transfer Hypoglossal Nerve to Vagus Nerve, Open Approach */
"00XS0ZR" = "1" /* Transfer Hypoglossal Nerve to Accessory Nerve, Open Approach */
"00XS0ZS" = "1" /* Transfer Hypoglossal Nerve to Hypoglossal Nerve, Open Approach */
"00XS4ZF" = "1" /* Transfer Hypoglossal Nerve to Olfactory Nerve, Percutaneous Endoscopic Approach */
"00XS4ZG" = "1" /* Transfer Hypoglossal Nerve to Optic Nerve, Percutaneous Endoscopic Approach */
"00XS4ZH" = "1" /* Transfer Hypoglossal Nerve to Oculomotor Nerve, Percutaneous Endoscopic Approach */
"00XS4ZJ" = "1" /* Transfer Hypoglossal Nerve to Trochlear Nerve, Percutaneous Endoscopic Approach */
"00XS4ZK" = "1" /* Transfer Hypoglossal Nerve to Trigeminal Nerve, Percutaneous Endoscopic Approach */
"00XS4ZL" = "1" /* Transfer Hypoglossal Nerve to Abducens Nerve, Percutaneous Endoscopic Approach */
"00XS4ZM" = "1" /* Transfer Hypoglossal Nerve to Facial Nerve, Percutaneous Endoscopic Approach */
"00XS4ZN" = "1" /* Transfer Hypoglossal Nerve to Acoustic Nerve, Percutaneous Endoscopic Approach */
"00XS4ZP" = "1" /* Transfer Hypoglossal Nerve to Glossopharyngeal Nerve, Percutaneous Endoscopic Approach */
"00XS4ZQ" = "1" /* Transfer Hypoglossal Nerve to Vagus Nerve, Percutaneous Endoscopic Approach */
"00XS4ZR" = "1" /* Transfer Hypoglossal Nerve to Accessory Nerve, Percutaneous Endoscopic Approach */
"00XS4ZS" = "1" /* Transfer Hypoglossal Nerve to Hypoglossal Nerve, Percutaneous Endoscopic Approach */
"01510ZZ" = "1" /* Destruction of Cervical Nerve, Open Approach */
"01514ZZ" = "1" /* Destruction of Cervical Nerve, Percutaneous Endoscopic Approach */
"01580ZZ" = "1" /* Destruction of Thoracic Nerve, Open Approach */
"01584ZZ" = "1" /* Destruction of Thoracic Nerve, Percutaneous Endoscopic Approach */
"015B0ZZ" = "1" /* Destruction of Lumbar Nerve, Open Approach */
"015B4ZZ" = "1" /* Destruction of Lumbar Nerve, Percutaneous Endoscopic Approach */
"015K0ZZ" = "1" /* Destruction of Head and Neck Sympathetic Nerve, Open Approach */
"015K3ZZ" = "1" /* Destruction of Head and Neck Sympathetic Nerve, Percutaneous Approach */
"015K4ZZ" = "1" /* Destruction of Head and Neck Sympathetic Nerve, Percutaneous Endoscopic Approach */
"015L0ZZ" = "1" /* Destruction of Thoracic Sympathetic Nerve, Open Approach */
"015L3ZZ" = "1" /* Destruction of Thoracic Sympathetic Nerve, Percutaneous Approach */
"015L4ZZ" = "1" /* Destruction of Thoracic Sympathetic Nerve, Percutaneous Endoscopic Approach */
"015M0ZZ" = "1" /* Destruction of Abdominal Sympathetic Nerve, Open Approach */
"015M3ZZ" = "1" /* Destruction of Abdominal Sympathetic Nerve, Percutaneous Approach */
"015M4ZZ" = "1" /* Destruction of Abdominal Sympathetic Nerve, Percutaneous Endoscopic Approach */
"015N0ZZ" = "1" /* Destruction of Lumbar Sympathetic Nerve, Open Approach */
"015N3ZZ" = "1" /* Destruction of Lumbar Sympathetic Nerve, Percutaneous Approach */
"015N4ZZ" = "1" /* Destruction of Lumbar Sympathetic Nerve, Percutaneous Endoscopic Approach */
"015P0ZZ" = "1" /* Destruction of Sacral Sympathetic Nerve, Open Approach */
"015P3ZZ" = "1" /* Destruction of Sacral Sympathetic Nerve, Percutaneous Approach */
"015P4ZZ" = "1" /* Destruction of Sacral Sympathetic Nerve, Percutaneous Endoscopic Approach */
"015R0ZZ" = "1" /* Destruction of Sacral Nerve, Open Approach */
"015R4ZZ" = "1" /* Destruction of Sacral Nerve, Percutaneous Endoscopic Approach */
"01800ZZ" = "1" /* Division of Cervical Plexus, Open Approach */
"01803ZZ" = "1" /* Division of Cervical Plexus, Percutaneous Approach */
"01804ZZ" = "1" /* Division of Cervical Plexus, Percutaneous Endoscopic Approach */
"01810ZZ" = "1" /* Division of Cervical Nerve, Open Approach */
"01813ZZ" = "1" /* Division of Cervical Nerve, Percutaneous Approach */
"01814ZZ" = "1" /* Division of Cervical Nerve, Percutaneous Endoscopic Approach */
"01820ZZ" = "1" /* Division of Phrenic Nerve, Open Approach */
"01823ZZ" = "1" /* Division of Phrenic Nerve, Percutaneous Approach */
"01824ZZ" = "1" /* Division of Phrenic Nerve, Percutaneous Endoscopic Approach */
"01830ZZ" = "1" /* Division of Brachial Plexus, Open Approach */
"01833ZZ" = "1" /* Division of Brachial Plexus, Percutaneous Approach */
"01834ZZ" = "1" /* Division of Brachial Plexus, Percutaneous Endoscopic Approach */
"01840ZZ" = "1" /* Division of Ulnar Nerve, Open Approach */
"01843ZZ" = "1" /* Division of Ulnar Nerve, Percutaneous Approach */
"01844ZZ" = "1" /* Division of Ulnar Nerve, Percutaneous Endoscopic Approach */
"01850ZZ" = "1" /* Division of Median Nerve, Open Approach */
"01853ZZ" = "1" /* Division of Median Nerve, Percutaneous Approach */
"01854ZZ" = "1" /* Division of Median Nerve, Percutaneous Endoscopic Approach */
"01860ZZ" = "1" /* Division of Radial Nerve, Open Approach */
"01863ZZ" = "1" /* Division of Radial Nerve, Percutaneous Approach */
"01864ZZ" = "1" /* Division of Radial Nerve, Percutaneous Endoscopic Approach */
"01880ZZ" = "1" /* Division of Thoracic Nerve, Open Approach */
"01883ZZ" = "1" /* Division of Thoracic Nerve, Percutaneous Approach */
"01884ZZ" = "1" /* Division of Thoracic Nerve, Percutaneous Endoscopic Approach */
"01890ZZ" = "1" /* Division of Lumbar Plexus, Open Approach */
"01893ZZ" = "1" /* Division of Lumbar Plexus, Percutaneous Approach */
"01894ZZ" = "1" /* Division of Lumbar Plexus, Percutaneous Endoscopic Approach */
"018A0ZZ" = "1" /* Division of Lumbosacral Plexus, Open Approach */
"018A3ZZ" = "1" /* Division of Lumbosacral Plexus, Percutaneous Approach */
"018A4ZZ" = "1" /* Division of Lumbosacral Plexus, Percutaneous Endoscopic Approach */
"018B0ZZ" = "1" /* Division of Lumbar Nerve, Open Approach */
"018B3ZZ" = "1" /* Division of Lumbar Nerve, Percutaneous Approach */
"018B4ZZ" = "1" /* Division of Lumbar Nerve, Percutaneous Endoscopic Approach */
"018C0ZZ" = "1" /* Division of Pudendal Nerve, Open Approach */
"018C3ZZ" = "1" /* Division of Pudendal Nerve, Percutaneous Approach */
"018C4ZZ" = "1" /* Division of Pudendal Nerve, Percutaneous Endoscopic Approach */
"018D0ZZ" = "1" /* Division of Femoral Nerve, Open Approach */
"018D3ZZ" = "1" /* Division of Femoral Nerve, Percutaneous Approach */
"018D4ZZ" = "1" /* Division of Femoral Nerve, Percutaneous Endoscopic Approach */
"018F0ZZ" = "1" /* Division of Sciatic Nerve, Open Approach */
"018F3ZZ" = "1" /* Division of Sciatic Nerve, Percutaneous Approach */
"018F4ZZ" = "1" /* Division of Sciatic Nerve, Percutaneous Endoscopic Approach */
"018G0ZZ" = "1" /* Division of Tibial Nerve, Open Approach */
"018G3ZZ" = "1" /* Division of Tibial Nerve, Percutaneous Approach */
"018G4ZZ" = "1" /* Division of Tibial Nerve, Percutaneous Endoscopic Approach */
"018H0ZZ" = "1" /* Division of Peroneal Nerve, Open Approach */
"018H3ZZ" = "1" /* Division of Peroneal Nerve, Percutaneous Approach */
"018H4ZZ" = "1" /* Division of Peroneal Nerve, Percutaneous Endoscopic Approach */
"018K0ZZ" = "1" /* Division of Head and Neck Sympathetic Nerve, Open Approach */
"018K3ZZ" = "1" /* Division of Head and Neck Sympathetic Nerve, Percutaneous Approach */
"018K4ZZ" = "1" /* Division of Head and Neck Sympathetic Nerve, Percutaneous Endoscopic Approach */
"018L0ZZ" = "1" /* Division of Thoracic Sympathetic Nerve, Open Approach */
"018L3ZZ" = "1" /* Division of Thoracic Sympathetic Nerve, Percutaneous Approach */
"018L4ZZ" = "1" /* Division of Thoracic Sympathetic Nerve, Percutaneous Endoscopic Approach */
"018M0ZZ" = "1" /* Division of Abdominal Sympathetic Nerve, Open Approach */
"018M3ZZ" = "1" /* Division of Abdominal Sympathetic Nerve, Percutaneous Approach */
"018M4ZZ" = "1" /* Division of Abdominal Sympathetic Nerve, Percutaneous Endoscopic Approach */
"018N0ZZ" = "1" /* Division of Lumbar Sympathetic Nerve, Open Approach */
"018N3ZZ" = "1" /* Division of Lumbar Sympathetic Nerve, Percutaneous Approach */
"018N4ZZ" = "1" /* Division of Lumbar Sympathetic Nerve, Percutaneous Endoscopic Approach */
"018P0ZZ" = "1" /* Division of Sacral Sympathetic Nerve, Open Approach */
"018P3ZZ" = "1" /* Division of Sacral Sympathetic Nerve, Percutaneous Approach */
"018P4ZZ" = "1" /* Division of Sacral Sympathetic Nerve, Percutaneous Endoscopic Approach */
"018Q0ZZ" = "1" /* Division of Sacral Plexus, Open Approach */
"018Q3ZZ" = "1" /* Division of Sacral Plexus, Percutaneous Approach */
"018Q4ZZ" = "1" /* Division of Sacral Plexus, Percutaneous Endoscopic Approach */
"018R0ZZ" = "1" /* Division of Sacral Nerve, Open Approach */
"018R3ZZ" = "1" /* Division of Sacral Nerve, Percutaneous Approach */
"018R4ZZ" = "1" /* Division of Sacral Nerve, Percutaneous Endoscopic Approach */
"019000Z" = "1" /* Drainage of Cervical Plexus with Drainage Device, Open Approach */
"01900ZX" = "1" /* Drainage of Cervical Plexus, Open Approach, Diagnostic */
"01900ZZ" = "1" /* Drainage of Cervical Plexus, Open Approach */
"019040Z" = "1" /* Drainage of Cervical Plexus with Drainage Device, Percutaneous Endoscopic Approach */
"01904ZZ" = "1" /* Drainage of Cervical Plexus, Percutaneous Endoscopic Approach */
"019100Z" = "1" /* Drainage of Cervical Nerve with Drainage Device, Open Approach */
"01910ZX" = "1" /* Drainage of Cervical Nerve, Open Approach, Diagnostic */
"01910ZZ" = "1" /* Drainage of Cervical Nerve, Open Approach */
"019140Z" = "1" /* Drainage of Cervical Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"01914ZZ" = "1" /* Drainage of Cervical Nerve, Percutaneous Endoscopic Approach */
"019200Z" = "1" /* Drainage of Phrenic Nerve with Drainage Device, Open Approach */
"01920ZX" = "1" /* Drainage of Phrenic Nerve, Open Approach, Diagnostic */
"01920ZZ" = "1" /* Drainage of Phrenic Nerve, Open Approach */
"019240Z" = "1" /* Drainage of Phrenic Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"01924ZZ" = "1" /* Drainage of Phrenic Nerve, Percutaneous Endoscopic Approach */
"019300Z" = "1" /* Drainage of Brachial Plexus with Drainage Device, Open Approach */
"01930ZX" = "1" /* Drainage of Brachial Plexus, Open Approach, Diagnostic */
"01930ZZ" = "1" /* Drainage of Brachial Plexus, Open Approach */
"019340Z" = "1" /* Drainage of Brachial Plexus with Drainage Device, Percutaneous Endoscopic Approach */
"01934ZZ" = "1" /* Drainage of Brachial Plexus, Percutaneous Endoscopic Approach */
"019400Z" = "1" /* Drainage of Ulnar Nerve with Drainage Device, Open Approach */
"01940ZX" = "1" /* Drainage of Ulnar Nerve, Open Approach, Diagnostic */
"01940ZZ" = "1" /* Drainage of Ulnar Nerve, Open Approach */
"019440Z" = "1" /* Drainage of Ulnar Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"01944ZZ" = "1" /* Drainage of Ulnar Nerve, Percutaneous Endoscopic Approach */
"019500Z" = "1" /* Drainage of Median Nerve with Drainage Device, Open Approach */
"01950ZX" = "1" /* Drainage of Median Nerve, Open Approach, Diagnostic */
"01950ZZ" = "1" /* Drainage of Median Nerve, Open Approach */
"019540Z" = "1" /* Drainage of Median Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"01954ZZ" = "1" /* Drainage of Median Nerve, Percutaneous Endoscopic Approach */
"019600Z" = "1" /* Drainage of Radial Nerve with Drainage Device, Open Approach */
"01960ZX" = "1" /* Drainage of Radial Nerve, Open Approach, Diagnostic */
"01960ZZ" = "1" /* Drainage of Radial Nerve, Open Approach */
"019640Z" = "1" /* Drainage of Radial Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"01964ZZ" = "1" /* Drainage of Radial Nerve, Percutaneous Endoscopic Approach */
"019800Z" = "1" /* Drainage of Thoracic Nerve with Drainage Device, Open Approach */
"01980ZX" = "1" /* Drainage of Thoracic Nerve, Open Approach, Diagnostic */
"01980ZZ" = "1" /* Drainage of Thoracic Nerve, Open Approach */
"019840Z" = "1" /* Drainage of Thoracic Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"01984ZZ" = "1" /* Drainage of Thoracic Nerve, Percutaneous Endoscopic Approach */
"019900Z" = "1" /* Drainage of Lumbar Plexus with Drainage Device, Open Approach */
"01990ZX" = "1" /* Drainage of Lumbar Plexus, Open Approach, Diagnostic */
"01990ZZ" = "1" /* Drainage of Lumbar Plexus, Open Approach */
"019940Z" = "1" /* Drainage of Lumbar Plexus with Drainage Device, Percutaneous Endoscopic Approach */
"01994ZZ" = "1" /* Drainage of Lumbar Plexus, Percutaneous Endoscopic Approach */
"019A00Z" = "1" /* Drainage of Lumbosacral Plexus with Drainage Device, Open Approach */
"019A0ZX" = "1" /* Drainage of Lumbosacral Plexus, Open Approach, Diagnostic */
"019A0ZZ" = "1" /* Drainage of Lumbosacral Plexus, Open Approach */
"019A40Z" = "1" /* Drainage of Lumbosacral Plexus with Drainage Device, Percutaneous Endoscopic Approach */
"019A4ZZ" = "1" /* Drainage of Lumbosacral Plexus, Percutaneous Endoscopic Approach */
"019B00Z" = "1" /* Drainage of Lumbar Nerve with Drainage Device, Open Approach */
"019B0ZX" = "1" /* Drainage of Lumbar Nerve, Open Approach, Diagnostic */
"019B0ZZ" = "1" /* Drainage of Lumbar Nerve, Open Approach */
"019B40Z" = "1" /* Drainage of Lumbar Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"019B4ZZ" = "1" /* Drainage of Lumbar Nerve, Percutaneous Endoscopic Approach */
"019C00Z" = "1" /* Drainage of Pudendal Nerve with Drainage Device, Open Approach */
"019C0ZX" = "1" /* Drainage of Pudendal Nerve, Open Approach, Diagnostic */
"019C0ZZ" = "1" /* Drainage of Pudendal Nerve, Open Approach */
"019C40Z" = "1" /* Drainage of Pudendal Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"019C4ZZ" = "1" /* Drainage of Pudendal Nerve, Percutaneous Endoscopic Approach */
"019D00Z" = "1" /* Drainage of Femoral Nerve with Drainage Device, Open Approach */
"019D0ZX" = "1" /* Drainage of Femoral Nerve, Open Approach, Diagnostic */
"019D0ZZ" = "1" /* Drainage of Femoral Nerve, Open Approach */
"019D40Z" = "1" /* Drainage of Femoral Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"019D4ZZ" = "1" /* Drainage of Femoral Nerve, Percutaneous Endoscopic Approach */
"019F00Z" = "1" /* Drainage of Sciatic Nerve with Drainage Device, Open Approach */
"019F0ZX" = "1" /* Drainage of Sciatic Nerve, Open Approach, Diagnostic */
"019F0ZZ" = "1" /* Drainage of Sciatic Nerve, Open Approach */
"019F40Z" = "1" /* Drainage of Sciatic Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"019F4ZZ" = "1" /* Drainage of Sciatic Nerve, Percutaneous Endoscopic Approach */
"019G00Z" = "1" /* Drainage of Tibial Nerve with Drainage Device, Open Approach */
"019G0ZX" = "1" /* Drainage of Tibial Nerve, Open Approach, Diagnostic */
"019G0ZZ" = "1" /* Drainage of Tibial Nerve, Open Approach */
"019G40Z" = "1" /* Drainage of Tibial Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"019G4ZZ" = "1" /* Drainage of Tibial Nerve, Percutaneous Endoscopic Approach */
"019H00Z" = "1" /* Drainage of Peroneal Nerve with Drainage Device, Open Approach */
"019H0ZX" = "1" /* Drainage of Peroneal Nerve, Open Approach, Diagnostic */
"019H0ZZ" = "1" /* Drainage of Peroneal Nerve, Open Approach */
"019H40Z" = "1" /* Drainage of Peroneal Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"019H4ZZ" = "1" /* Drainage of Peroneal Nerve, Percutaneous Endoscopic Approach */
"019K00Z" = "1" /* Drainage of Head and Neck Sympathetic Nerve with Drainage Device, Open Approach */
"019K0ZX" = "1" /* Drainage of Head and Neck Sympathetic Nerve, Open Approach, Diagnostic */
"019K0ZZ" = "1" /* Drainage of Head and Neck Sympathetic Nerve, Open Approach */
"019K40Z" = "1" /* Drainage of Head and Neck Sympathetic Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"019K4ZX" = "1" /* Drainage of Head and Neck Sympathetic Nerve, Percutaneous Endoscopic Approach, Diagnostic */
"019K4ZZ" = "1" /* Drainage of Head and Neck Sympathetic Nerve, Percutaneous Endoscopic Approach */
"019L00Z" = "1" /* Drainage of Thoracic Sympathetic Nerve with Drainage Device, Open Approach */
"019L0ZX" = "1" /* Drainage of Thoracic Sympathetic Nerve, Open Approach, Diagnostic */
"019L0ZZ" = "1" /* Drainage of Thoracic Sympathetic Nerve, Open Approach */
"019L40Z" = "1" /* Drainage of Thoracic Sympathetic Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"019L4ZX" = "1" /* Drainage of Thoracic Sympathetic Nerve, Percutaneous Endoscopic Approach, Diagnostic */
"019L4ZZ" = "1" /* Drainage of Thoracic Sympathetic Nerve, Percutaneous Endoscopic Approach */
"019M00Z" = "1" /* Drainage of Abdominal Sympathetic Nerve with Drainage Device, Open Approach */
"019M0ZX" = "1" /* Drainage of Abdominal Sympathetic Nerve, Open Approach, Diagnostic */
"019M0ZZ" = "1" /* Drainage of Abdominal Sympathetic Nerve, Open Approach */
"019M40Z" = "1" /* Drainage of Abdominal Sympathetic Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"019M4ZX" = "1" /* Drainage of Abdominal Sympathetic Nerve, Percutaneous Endoscopic Approach, Diagnostic */
"019M4ZZ" = "1" /* Drainage of Abdominal Sympathetic Nerve, Percutaneous Endoscopic Approach */
"019N00Z" = "1" /* Drainage of Lumbar Sympathetic Nerve with Drainage Device, Open Approach */
"019N0ZX" = "1" /* Drainage of Lumbar Sympathetic Nerve, Open Approach, Diagnostic */
"019N0ZZ" = "1" /* Drainage of Lumbar Sympathetic Nerve, Open Approach */
"019N40Z" = "1" /* Drainage of Lumbar Sympathetic Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"019N4ZX" = "1" /* Drainage of Lumbar Sympathetic Nerve, Percutaneous Endoscopic Approach, Diagnostic */
"019N4ZZ" = "1" /* Drainage of Lumbar Sympathetic Nerve, Percutaneous Endoscopic Approach */
"019P00Z" = "1" /* Drainage of Sacral Sympathetic Nerve with Drainage Device, Open Approach */
"019P0ZX" = "1" /* Drainage of Sacral Sympathetic Nerve, Open Approach, Diagnostic */
"019P0ZZ" = "1" /* Drainage of Sacral Sympathetic Nerve, Open Approach */
"019P40Z" = "1" /* Drainage of Sacral Sympathetic Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"019P4ZX" = "1" /* Drainage of Sacral Sympathetic Nerve, Percutaneous Endoscopic Approach, Diagnostic */
"019P4ZZ" = "1" /* Drainage of Sacral Sympathetic Nerve, Percutaneous Endoscopic Approach */
"019Q00Z" = "1" /* Drainage of Sacral Plexus with Drainage Device, Open Approach */
"019Q0ZX" = "1" /* Drainage of Sacral Plexus, Open Approach, Diagnostic */
"019Q0ZZ" = "1" /* Drainage of Sacral Plexus, Open Approach */
"019Q40Z" = "1" /* Drainage of Sacral Plexus with Drainage Device, Percutaneous Endoscopic Approach */
"019Q4ZZ" = "1" /* Drainage of Sacral Plexus, Percutaneous Endoscopic Approach */
"019R00Z" = "1" /* Drainage of Sacral Nerve with Drainage Device, Open Approach */
"019R0ZX" = "1" /* Drainage of Sacral Nerve, Open Approach, Diagnostic */
"019R0ZZ" = "1" /* Drainage of Sacral Nerve, Open Approach */
"019R40Z" = "1" /* Drainage of Sacral Nerve with Drainage Device, Percutaneous Endoscopic Approach */
"019R4ZZ" = "1" /* Drainage of Sacral Nerve, Percutaneous Endoscopic Approach */
"01B00ZX" = "1" /* Excision of Cervical Plexus, Open Approach, Diagnostic */
"01B00ZZ" = "1" /* Excision of Cervical Plexus, Open Approach */
"01B03ZZ" = "1" /* Excision of Cervical Plexus, Percutaneous Approach */
"01B04ZZ" = "1" /* Excision of Cervical Plexus, Percutaneous Endoscopic Approach */
"01B10ZX" = "1" /* Excision of Cervical Nerve, Open Approach, Diagnostic */
"01B10ZZ" = "1" /* Excision of Cervical Nerve, Open Approach */
"01B13ZZ" = "1" /* Excision of Cervical Nerve, Percutaneous Approach */
"01B14ZZ" = "1" /* Excision of Cervical Nerve, Percutaneous Endoscopic Approach */
"01B20ZX" = "1" /* Excision of Phrenic Nerve, Open Approach, Diagnostic */
"01B20ZZ" = "1" /* Excision of Phrenic Nerve, Open Approach */
"01B23ZZ" = "1" /* Excision of Phrenic Nerve, Percutaneous Approach */
"01B24ZZ" = "1" /* Excision of Phrenic Nerve, Percutaneous Endoscopic Approach */
"01B30ZX" = "1" /* Excision of Brachial Plexus, Open Approach, Diagnostic */
"01B30ZZ" = "1" /* Excision of Brachial Plexus, Open Approach */
"01B33ZZ" = "1" /* Excision of Brachial Plexus, Percutaneous Approach */
"01B34ZZ" = "1" /* Excision of Brachial Plexus, Percutaneous Endoscopic Approach */
"01B40ZX" = "1" /* Excision of Ulnar Nerve, Open Approach, Diagnostic */
"01B40ZZ" = "1" /* Excision of Ulnar Nerve, Open Approach */
"01B43ZZ" = "1" /* Excision of Ulnar Nerve, Percutaneous Approach */
"01B44ZZ" = "1" /* Excision of Ulnar Nerve, Percutaneous Endoscopic Approach */
"01B50ZX" = "1" /* Excision of Median Nerve, Open Approach, Diagnostic */
"01B50ZZ" = "1" /* Excision of Median Nerve, Open Approach */
"01B53ZZ" = "1" /* Excision of Median Nerve, Percutaneous Approach */
"01B54ZZ" = "1" /* Excision of Median Nerve, Percutaneous Endoscopic Approach */
"01B60ZX" = "1" /* Excision of Radial Nerve, Open Approach, Diagnostic */
"01B60ZZ" = "1" /* Excision of Radial Nerve, Open Approach */
"01B63ZZ" = "1" /* Excision of Radial Nerve, Percutaneous Approach */
"01B64ZZ" = "1" /* Excision of Radial Nerve, Percutaneous Endoscopic Approach */
"01B80ZX" = "1" /* Excision of Thoracic Nerve, Open Approach, Diagnostic */
"01B80ZZ" = "1" /* Excision of Thoracic Nerve, Open Approach */
"01B83ZZ" = "1" /* Excision of Thoracic Nerve, Percutaneous Approach */
"01B84ZZ" = "1" /* Excision of Thoracic Nerve, Percutaneous Endoscopic Approach */
"01B90ZX" = "1" /* Excision of Lumbar Plexus, Open Approach, Diagnostic */
"01B90ZZ" = "1" /* Excision of Lumbar Plexus, Open Approach */
"01B93ZZ" = "1" /* Excision of Lumbar Plexus, Percutaneous Approach */
"01B94ZZ" = "1" /* Excision of Lumbar Plexus, Percutaneous Endoscopic Approach */
"01BA0ZX" = "1" /* Excision of Lumbosacral Plexus, Open Approach, Diagnostic */
"01BA0ZZ" = "1" /* Excision of Lumbosacral Plexus, Open Approach */
"01BA3ZZ" = "1" /* Excision of Lumbosacral Plexus, Percutaneous Approach */
"01BA4ZZ" = "1" /* Excision of Lumbosacral Plexus, Percutaneous Endoscopic Approach */
"01BB0ZX" = "1" /* Excision of Lumbar Nerve, Open Approach, Diagnostic */
"01BB0ZZ" = "1" /* Excision of Lumbar Nerve, Open Approach */
"01BB3ZZ" = "1" /* Excision of Lumbar Nerve, Percutaneous Approach */
"01BB4ZZ" = "1" /* Excision of Lumbar Nerve, Percutaneous Endoscopic Approach */
"01BC0ZX" = "1" /* Excision of Pudendal Nerve, Open Approach, Diagnostic */
"01BC0ZZ" = "1" /* Excision of Pudendal Nerve, Open Approach */
"01BC3ZZ" = "1" /* Excision of Pudendal Nerve, Percutaneous Approach */
"01BC4ZZ" = "1" /* Excision of Pudendal Nerve, Percutaneous Endoscopic Approach */
"01BD0ZX" = "1" /* Excision of Femoral Nerve, Open Approach, Diagnostic */
"01BD0ZZ" = "1" /* Excision of Femoral Nerve, Open Approach */
"01BD3ZZ" = "1" /* Excision of Femoral Nerve, Percutaneous Approach */
"01BD4ZZ" = "1" /* Excision of Femoral Nerve, Percutaneous Endoscopic Approach */
"01BF0ZX" = "1" /* Excision of Sciatic Nerve, Open Approach, Diagnostic */
"01BF0ZZ" = "1" /* Excision of Sciatic Nerve, Open Approach */
"01BF3ZZ" = "1" /* Excision of Sciatic Nerve, Percutaneous Approach */
"01BF4ZZ" = "1" /* Excision of Sciatic Nerve, Percutaneous Endoscopic Approach */
"01BG0ZX" = "1" /* Excision of Tibial Nerve, Open Approach, Diagnostic */
"01BG0ZZ" = "1" /* Excision of Tibial Nerve, Open Approach */
"01BG3ZZ" = "1" /* Excision of Tibial Nerve, Percutaneous Approach */
"01BG4ZZ" = "1" /* Excision of Tibial Nerve, Percutaneous Endoscopic Approach */
"01BH0ZX" = "1" /* Excision of Peroneal Nerve, Open Approach, Diagnostic */
"01BH0ZZ" = "1" /* Excision of Peroneal Nerve, Open Approach */
"01BH3ZZ" = "1" /* Excision of Peroneal Nerve, Percutaneous Approach */
"01BH4ZZ" = "1" /* Excision of Peroneal Nerve, Percutaneous Endoscopic Approach */
"01BK0ZX" = "1" /* Excision of Head and Neck Sympathetic Nerve, Open Approach, Diagnostic */
"01BK0ZZ" = "1" /* Excision of Head and Neck Sympathetic Nerve, Open Approach */
"01BK3ZX" = "1" /* Excision of Head and Neck Sympathetic Nerve, Percutaneous Approach, Diagnostic */
"01BK3ZZ" = "1" /* Excision of Head and Neck Sympathetic Nerve, Percutaneous Approach */
"01BK4ZX" = "1" /* Excision of Head and Neck Sympathetic Nerve, Percutaneous Endoscopic Approach, Diagnostic */
"01BK4ZZ" = "1" /* Excision of Head and Neck Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01BL0ZX" = "1" /* Excision of Thoracic Sympathetic Nerve, Open Approach, Diagnostic */
"01BL0ZZ" = "1" /* Excision of Thoracic Sympathetic Nerve, Open Approach */
"01BL3ZX" = "1" /* Excision of Thoracic Sympathetic Nerve, Percutaneous Approach, Diagnostic */
"01BL3ZZ" = "1" /* Excision of Thoracic Sympathetic Nerve, Percutaneous Approach */
"01BL4ZX" = "1" /* Excision of Thoracic Sympathetic Nerve, Percutaneous Endoscopic Approach, Diagnostic */
"01BL4ZZ" = "1" /* Excision of Thoracic Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01BM0ZX" = "1" /* Excision of Abdominal Sympathetic Nerve, Open Approach, Diagnostic */
"01BM0ZZ" = "1" /* Excision of Abdominal Sympathetic Nerve, Open Approach */
"01BM3ZX" = "1" /* Excision of Abdominal Sympathetic Nerve, Percutaneous Approach, Diagnostic */
"01BM3ZZ" = "1" /* Excision of Abdominal Sympathetic Nerve, Percutaneous Approach */
"01BM4ZX" = "1" /* Excision of Abdominal Sympathetic Nerve, Percutaneous Endoscopic Approach, Diagnostic */
"01BM4ZZ" = "1" /* Excision of Abdominal Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01BN0ZX" = "1" /* Excision of Lumbar Sympathetic Nerve, Open Approach, Diagnostic */
"01BN0ZZ" = "1" /* Excision of Lumbar Sympathetic Nerve, Open Approach */
"01BN3ZX" = "1" /* Excision of Lumbar Sympathetic Nerve, Percutaneous Approach, Diagnostic */
"01BN3ZZ" = "1" /* Excision of Lumbar Sympathetic Nerve, Percutaneous Approach */
"01BN4ZX" = "1" /* Excision of Lumbar Sympathetic Nerve, Percutaneous Endoscopic Approach, Diagnostic */
"01BN4ZZ" = "1" /* Excision of Lumbar Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01BP0ZX" = "1" /* Excision of Sacral Sympathetic Nerve, Open Approach, Diagnostic */
"01BP0ZZ" = "1" /* Excision of Sacral Sympathetic Nerve, Open Approach */
"01BP3ZX" = "1" /* Excision of Sacral Sympathetic Nerve, Percutaneous Approach, Diagnostic */
"01BP3ZZ" = "1" /* Excision of Sacral Sympathetic Nerve, Percutaneous Approach */
"01BP4ZX" = "1" /* Excision of Sacral Sympathetic Nerve, Percutaneous Endoscopic Approach, Diagnostic */
"01BP4ZZ" = "1" /* Excision of Sacral Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01BQ0ZX" = "1" /* Excision of Sacral Plexus, Open Approach, Diagnostic */
"01BQ0ZZ" = "1" /* Excision of Sacral Plexus, Open Approach */
"01BQ3ZZ" = "1" /* Excision of Sacral Plexus, Percutaneous Approach */
"01BQ4ZZ" = "1" /* Excision of Sacral Plexus, Percutaneous Endoscopic Approach */
"01BR0ZX" = "1" /* Excision of Sacral Nerve, Open Approach, Diagnostic */
"01BR0ZZ" = "1" /* Excision of Sacral Nerve, Open Approach */
"01BR3ZZ" = "1" /* Excision of Sacral Nerve, Percutaneous Approach */
"01BR4ZZ" = "1" /* Excision of Sacral Nerve, Percutaneous Endoscopic Approach */
"01C00ZZ" = "1" /* Extirpation of Matter from Cervical Plexus, Open Approach */
"01C03ZZ" = "1" /* Extirpation of Matter from Cervical Plexus, Percutaneous Approach */
"01C04ZZ" = "1" /* Extirpation of Matter from Cervical Plexus, Percutaneous Endoscopic Approach */
"01C10ZZ" = "1" /* Extirpation of Matter from Cervical Nerve, Open Approach */
"01C13ZZ" = "1" /* Extirpation of Matter from Cervical Nerve, Percutaneous Approach */
"01C14ZZ" = "1" /* Extirpation of Matter from Cervical Nerve, Percutaneous Endoscopic Approach */
"01C20ZZ" = "1" /* Extirpation of Matter from Phrenic Nerve, Open Approach */
"01C23ZZ" = "1" /* Extirpation of Matter from Phrenic Nerve, Percutaneous Approach */
"01C24ZZ" = "1" /* Extirpation of Matter from Phrenic Nerve, Percutaneous Endoscopic Approach */
"01C30ZZ" = "1" /* Extirpation of Matter from Brachial Plexus, Open Approach */
"01C33ZZ" = "1" /* Extirpation of Matter from Brachial Plexus, Percutaneous Approach */
"01C34ZZ" = "1" /* Extirpation of Matter from Brachial Plexus, Percutaneous Endoscopic Approach */
"01C40ZZ" = "1" /* Extirpation of Matter from Ulnar Nerve, Open Approach */
"01C43ZZ" = "1" /* Extirpation of Matter from Ulnar Nerve, Percutaneous Approach */
"01C44ZZ" = "1" /* Extirpation of Matter from Ulnar Nerve, Percutaneous Endoscopic Approach */
"01C50ZZ" = "1" /* Extirpation of Matter from Median Nerve, Open Approach */
"01C53ZZ" = "1" /* Extirpation of Matter from Median Nerve, Percutaneous Approach */
"01C54ZZ" = "1" /* Extirpation of Matter from Median Nerve, Percutaneous Endoscopic Approach */
"01C60ZZ" = "1" /* Extirpation of Matter from Radial Nerve, Open Approach */
"01C63ZZ" = "1" /* Extirpation of Matter from Radial Nerve, Percutaneous Approach */
"01C64ZZ" = "1" /* Extirpation of Matter from Radial Nerve, Percutaneous Endoscopic Approach */
"01C80ZZ" = "1" /* Extirpation of Matter from Thoracic Nerve, Open Approach */
"01C83ZZ" = "1" /* Extirpation of Matter from Thoracic Nerve, Percutaneous Approach */
"01C84ZZ" = "1" /* Extirpation of Matter from Thoracic Nerve, Percutaneous Endoscopic Approach */
"01C90ZZ" = "1" /* Extirpation of Matter from Lumbar Plexus, Open Approach */
"01C93ZZ" = "1" /* Extirpation of Matter from Lumbar Plexus, Percutaneous Approach */
"01C94ZZ" = "1" /* Extirpation of Matter from Lumbar Plexus, Percutaneous Endoscopic Approach */
"01CA0ZZ" = "1" /* Extirpation of Matter from Lumbosacral Plexus, Open Approach */
"01CA3ZZ" = "1" /* Extirpation of Matter from Lumbosacral Plexus, Percutaneous Approach */
"01CA4ZZ" = "1" /* Extirpation of Matter from Lumbosacral Plexus, Percutaneous Endoscopic Approach */
"01CB0ZZ" = "1" /* Extirpation of Matter from Lumbar Nerve, Open Approach */
"01CB3ZZ" = "1" /* Extirpation of Matter from Lumbar Nerve, Percutaneous Approach */
"01CB4ZZ" = "1" /* Extirpation of Matter from Lumbar Nerve, Percutaneous Endoscopic Approach */
"01CC0ZZ" = "1" /* Extirpation of Matter from Pudendal Nerve, Open Approach */
"01CC3ZZ" = "1" /* Extirpation of Matter from Pudendal Nerve, Percutaneous Approach */
"01CC4ZZ" = "1" /* Extirpation of Matter from Pudendal Nerve, Percutaneous Endoscopic Approach */
"01CD0ZZ" = "1" /* Extirpation of Matter from Femoral Nerve, Open Approach */
"01CD3ZZ" = "1" /* Extirpation of Matter from Femoral Nerve, Percutaneous Approach */
"01CD4ZZ" = "1" /* Extirpation of Matter from Femoral Nerve, Percutaneous Endoscopic Approach */
"01CF0ZZ" = "1" /* Extirpation of Matter from Sciatic Nerve, Open Approach */
"01CF3ZZ" = "1" /* Extirpation of Matter from Sciatic Nerve, Percutaneous Approach */
"01CF4ZZ" = "1" /* Extirpation of Matter from Sciatic Nerve, Percutaneous Endoscopic Approach */
"01CG0ZZ" = "1" /* Extirpation of Matter from Tibial Nerve, Open Approach */
"01CG3ZZ" = "1" /* Extirpation of Matter from Tibial Nerve, Percutaneous Approach */
"01CG4ZZ" = "1" /* Extirpation of Matter from Tibial Nerve, Percutaneous Endoscopic Approach */
"01CH0ZZ" = "1" /* Extirpation of Matter from Peroneal Nerve, Open Approach */
"01CH3ZZ" = "1" /* Extirpation of Matter from Peroneal Nerve, Percutaneous Approach */
"01CH4ZZ" = "1" /* Extirpation of Matter from Peroneal Nerve, Percutaneous Endoscopic Approach */
"01CK0ZZ" = "1" /* Extirpation of Matter from Head and Neck Sympathetic Nerve, Open Approach */
"01CK3ZZ" = "1" /* Extirpation of Matter from Head and Neck Sympathetic Nerve, Percutaneous Approach */
"01CK4ZZ" = "1" /* Extirpation of Matter from Head and Neck Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01CL0ZZ" = "1" /* Extirpation of Matter from Thoracic Sympathetic Nerve, Open Approach */
"01CL3ZZ" = "1" /* Extirpation of Matter from Thoracic Sympathetic Nerve, Percutaneous Approach */
"01CL4ZZ" = "1" /* Extirpation of Matter from Thoracic Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01CM0ZZ" = "1" /* Extirpation of Matter from Abdominal Sympathetic Nerve, Open Approach */
"01CM3ZZ" = "1" /* Extirpation of Matter from Abdominal Sympathetic Nerve, Percutaneous Approach */
"01CM4ZZ" = "1" /* Extirpation of Matter from Abdominal Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01CN0ZZ" = "1" /* Extirpation of Matter from Lumbar Sympathetic Nerve, Open Approach */
"01CN3ZZ" = "1" /* Extirpation of Matter from Lumbar Sympathetic Nerve, Percutaneous Approach */
"01CN4ZZ" = "1" /* Extirpation of Matter from Lumbar Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01CP0ZZ" = "1" /* Extirpation of Matter from Sacral Sympathetic Nerve, Open Approach */
"01CP3ZZ" = "1" /* Extirpation of Matter from Sacral Sympathetic Nerve, Percutaneous Approach */
"01CP4ZZ" = "1" /* Extirpation of Matter from Sacral Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01CQ0ZZ" = "1" /* Extirpation of Matter from Sacral Plexus, Open Approach */
"01CQ3ZZ" = "1" /* Extirpation of Matter from Sacral Plexus, Percutaneous Approach */
"01CQ4ZZ" = "1" /* Extirpation of Matter from Sacral Plexus, Percutaneous Endoscopic Approach */
"01CR0ZZ" = "1" /* Extirpation of Matter from Sacral Nerve, Open Approach */
"01CR3ZZ" = "1" /* Extirpation of Matter from Sacral Nerve, Percutaneous Approach */
"01CR4ZZ" = "1" /* Extirpation of Matter from Sacral Nerve, Percutaneous Endoscopic Approach */
"01D00ZZ" = "1" /* Extraction of Cervical Plexus, Open Approach */
"01D03ZZ" = "1" /* Extraction of Cervical Plexus, Percutaneous Approach */
"01D04ZZ" = "1" /* Extraction of Cervical Plexus, Percutaneous Endoscopic Approach */
"01D10ZZ" = "1" /* Extraction of Cervical Nerve, Open Approach */
"01D13ZZ" = "1" /* Extraction of Cervical Nerve, Percutaneous Approach */
"01D14ZZ" = "1" /* Extraction of Cervical Nerve, Percutaneous Endoscopic Approach */
"01D20ZZ" = "1" /* Extraction of Phrenic Nerve, Open Approach */
"01D23ZZ" = "1" /* Extraction of Phrenic Nerve, Percutaneous Approach */
"01D24ZZ" = "1" /* Extraction of Phrenic Nerve, Percutaneous Endoscopic Approach */
"01D30ZZ" = "1" /* Extraction of Brachial Plexus, Open Approach */
"01D33ZZ" = "1" /* Extraction of Brachial Plexus, Percutaneous Approach */
"01D34ZZ" = "1" /* Extraction of Brachial Plexus, Percutaneous Endoscopic Approach */
"01D40ZZ" = "1" /* Extraction of Ulnar Nerve, Open Approach */
"01D43ZZ" = "1" /* Extraction of Ulnar Nerve, Percutaneous Approach */
"01D44ZZ" = "1" /* Extraction of Ulnar Nerve, Percutaneous Endoscopic Approach */
"01D50ZZ" = "1" /* Extraction of Median Nerve, Open Approach */
"01D53ZZ" = "1" /* Extraction of Median Nerve, Percutaneous Approach */
"01D54ZZ" = "1" /* Extraction of Median Nerve, Percutaneous Endoscopic Approach */
"01D60ZZ" = "1" /* Extraction of Radial Nerve, Open Approach */
"01D63ZZ" = "1" /* Extraction of Radial Nerve, Percutaneous Approach */
"01D64ZZ" = "1" /* Extraction of Radial Nerve, Percutaneous Endoscopic Approach */
"01D80ZZ" = "1" /* Extraction of Thoracic Nerve, Open Approach */
"01D83ZZ" = "1" /* Extraction of Thoracic Nerve, Percutaneous Approach */
"01D84ZZ" = "1" /* Extraction of Thoracic Nerve, Percutaneous Endoscopic Approach */
"01D90ZZ" = "1" /* Extraction of Lumbar Plexus, Open Approach */
"01D93ZZ" = "1" /* Extraction of Lumbar Plexus, Percutaneous Approach */
"01D94ZZ" = "1" /* Extraction of Lumbar Plexus, Percutaneous Endoscopic Approach */
"01DA0ZZ" = "1" /* Extraction of Lumbosacral Plexus, Open Approach */
"01DA3ZZ" = "1" /* Extraction of Lumbosacral Plexus, Percutaneous Approach */
"01DA4ZZ" = "1" /* Extraction of Lumbosacral Plexus, Percutaneous Endoscopic Approach */
"01DB0ZZ" = "1" /* Extraction of Lumbar Nerve, Open Approach */
"01DB3ZZ" = "1" /* Extraction of Lumbar Nerve, Percutaneous Approach */
"01DB4ZZ" = "1" /* Extraction of Lumbar Nerve, Percutaneous Endoscopic Approach */
"01DC0ZZ" = "1" /* Extraction of Pudendal Nerve, Open Approach */
"01DC3ZZ" = "1" /* Extraction of Pudendal Nerve, Percutaneous Approach */
"01DC4ZZ" = "1" /* Extraction of Pudendal Nerve, Percutaneous Endoscopic Approach */
"01DD0ZZ" = "1" /* Extraction of Femoral Nerve, Open Approach */
"01DD3ZZ" = "1" /* Extraction of Femoral Nerve, Percutaneous Approach */
"01DD4ZZ" = "1" /* Extraction of Femoral Nerve, Percutaneous Endoscopic Approach */
"01DF0ZZ" = "1" /* Extraction of Sciatic Nerve, Open Approach */
"01DF3ZZ" = "1" /* Extraction of Sciatic Nerve, Percutaneous Approach */
"01DF4ZZ" = "1" /* Extraction of Sciatic Nerve, Percutaneous Endoscopic Approach */
"01DG0ZZ" = "1" /* Extraction of Tibial Nerve, Open Approach */
"01DG3ZZ" = "1" /* Extraction of Tibial Nerve, Percutaneous Approach */
"01DG4ZZ" = "1" /* Extraction of Tibial Nerve, Percutaneous Endoscopic Approach */
"01DH0ZZ" = "1" /* Extraction of Peroneal Nerve, Open Approach */
"01DH3ZZ" = "1" /* Extraction of Peroneal Nerve, Percutaneous Approach */
"01DH4ZZ" = "1" /* Extraction of Peroneal Nerve, Percutaneous Endoscopic Approach */
"01DK0ZZ" = "1" /* Extraction of Head and Neck Sympathetic Nerve, Open Approach */
"01DK3ZZ" = "1" /* Extraction of Head and Neck Sympathetic Nerve, Percutaneous Approach */
"01DK4ZZ" = "1" /* Extraction of Head and Neck Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01DL0ZZ" = "1" /* Extraction of Thoracic Sympathetic Nerve, Open Approach */
"01DL3ZZ" = "1" /* Extraction of Thoracic Sympathetic Nerve, Percutaneous Approach */
"01DL4ZZ" = "1" /* Extraction of Thoracic Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01DM0ZZ" = "1" /* Extraction of Abdominal Sympathetic Nerve, Open Approach */
"01DM3ZZ" = "1" /* Extraction of Abdominal Sympathetic Nerve, Percutaneous Approach */
"01DM4ZZ" = "1" /* Extraction of Abdominal Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01DN0ZZ" = "1" /* Extraction of Lumbar Sympathetic Nerve, Open Approach */
"01DN3ZZ" = "1" /* Extraction of Lumbar Sympathetic Nerve, Percutaneous Approach */
"01DN4ZZ" = "1" /* Extraction of Lumbar Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01DP0ZZ" = "1" /* Extraction of Sacral Sympathetic Nerve, Open Approach */
"01DP3ZZ" = "1" /* Extraction of Sacral Sympathetic Nerve, Percutaneous Approach */
"01DP4ZZ" = "1" /* Extraction of Sacral Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01DQ0ZZ" = "1" /* Extraction of Sacral Plexus, Open Approach */
"01DQ3ZZ" = "1" /* Extraction of Sacral Plexus, Percutaneous Approach */
"01DQ4ZZ" = "1" /* Extraction of Sacral Plexus, Percutaneous Endoscopic Approach */
"01DR0ZZ" = "1" /* Extraction of Sacral Nerve, Open Approach */
"01DR3ZZ" = "1" /* Extraction of Sacral Nerve, Percutaneous Approach */
"01DR4ZZ" = "1" /* Extraction of Sacral Nerve, Percutaneous Endoscopic Approach */
"01HY02Z" = "1" /* Insertion of Monitoring Device into Peripheral Nerve, Open Approach */
"01HY0MZ" = "1" /* Insertion of Neurostimulator Lead into Peripheral Nerve, Open Approach */
"01HY32Z" = "1" /* Insertion of Monitoring Device into Peripheral Nerve, Percutaneous Approach */
"01HY3MZ" = "1" /* Insertion of Neurostimulator Lead into Peripheral Nerve, Percutaneous Approach */
"01HY42Z" = "1" /* Insertion of Monitoring Device into Peripheral Nerve, Percutaneous Endoscopic Approach */
"01HY4MZ" = "1" /* Insertion of Neurostimulator Lead into Peripheral Nerve, Percutaneous Endoscopic Approach */
"01JY0ZZ" = "1" /* Inspection of Peripheral Nerve, Open Approach */
"01JY4ZZ" = "1" /* Inspection of Peripheral Nerve, Percutaneous Endoscopic Approach */
"01N00ZZ" = "1" /* Release Cervical Plexus, Open Approach */
"01N03ZZ" = "1" /* Release Cervical Plexus, Percutaneous Approach */
"01N04ZZ" = "1" /* Release Cervical Plexus, Percutaneous Endoscopic Approach */
"01N10ZZ" = "1" /* Release Cervical Nerve, Open Approach */
"01N13ZZ" = "1" /* Release Cervical Nerve, Percutaneous Approach */
"01N14ZZ" = "1" /* Release Cervical Nerve, Percutaneous Endoscopic Approach */
"01N20ZZ" = "1" /* Release Phrenic Nerve, Open Approach */
"01N23ZZ" = "1" /* Release Phrenic Nerve, Percutaneous Approach */
"01N24ZZ" = "1" /* Release Phrenic Nerve, Percutaneous Endoscopic Approach */
"01N30ZZ" = "1" /* Release Brachial Plexus, Open Approach */
"01N33ZZ" = "1" /* Release Brachial Plexus, Percutaneous Approach */
"01N34ZZ" = "1" /* Release Brachial Plexus, Percutaneous Endoscopic Approach */
"01N40ZZ" = "1" /* Release Ulnar Nerve, Open Approach */
"01N43ZZ" = "1" /* Release Ulnar Nerve, Percutaneous Approach */
"01N44ZZ" = "1" /* Release Ulnar Nerve, Percutaneous Endoscopic Approach */
"01N50ZZ" = "1" /* Release Median Nerve, Open Approach */
"01N53ZZ" = "1" /* Release Median Nerve, Percutaneous Approach */
"01N54ZZ" = "1" /* Release Median Nerve, Percutaneous Endoscopic Approach */
"01N60ZZ" = "1" /* Release Radial Nerve, Open Approach */
"01N63ZZ" = "1" /* Release Radial Nerve, Percutaneous Approach */
"01N64ZZ" = "1" /* Release Radial Nerve, Percutaneous Endoscopic Approach */
"01N80ZZ" = "1" /* Release Thoracic Nerve, Open Approach */
"01N83ZZ" = "1" /* Release Thoracic Nerve, Percutaneous Approach */
"01N84ZZ" = "1" /* Release Thoracic Nerve, Percutaneous Endoscopic Approach */
"01N90ZZ" = "1" /* Release Lumbar Plexus, Open Approach */
"01N93ZZ" = "1" /* Release Lumbar Plexus, Percutaneous Approach */
"01N94ZZ" = "1" /* Release Lumbar Plexus, Percutaneous Endoscopic Approach */
"01NA0ZZ" = "1" /* Release Lumbosacral Plexus, Open Approach */
"01NA3ZZ" = "1" /* Release Lumbosacral Plexus, Percutaneous Approach */
"01NA4ZZ" = "1" /* Release Lumbosacral Plexus, Percutaneous Endoscopic Approach */
"01NB0ZZ" = "1" /* Release Lumbar Nerve, Open Approach */
"01NB3ZZ" = "1" /* Release Lumbar Nerve, Percutaneous Approach */
"01NB4ZZ" = "1" /* Release Lumbar Nerve, Percutaneous Endoscopic Approach */
"01NC0ZZ" = "1" /* Release Pudendal Nerve, Open Approach */
"01NC3ZZ" = "1" /* Release Pudendal Nerve, Percutaneous Approach */
"01NC4ZZ" = "1" /* Release Pudendal Nerve, Percutaneous Endoscopic Approach */
"01ND0ZZ" = "1" /* Release Femoral Nerve, Open Approach */
"01ND3ZZ" = "1" /* Release Femoral Nerve, Percutaneous Approach */
"01ND4ZZ" = "1" /* Release Femoral Nerve, Percutaneous Endoscopic Approach */
"01NF0ZZ" = "1" /* Release Sciatic Nerve, Open Approach */
"01NF3ZZ" = "1" /* Release Sciatic Nerve, Percutaneous Approach */
"01NF4ZZ" = "1" /* Release Sciatic Nerve, Percutaneous Endoscopic Approach */
"01NG0ZZ" = "1" /* Release Tibial Nerve, Open Approach */
"01NG3ZZ" = "1" /* Release Tibial Nerve, Percutaneous Approach */
"01NG4ZZ" = "1" /* Release Tibial Nerve, Percutaneous Endoscopic Approach */
"01NH0ZZ" = "1" /* Release Peroneal Nerve, Open Approach */
"01NH3ZZ" = "1" /* Release Peroneal Nerve, Percutaneous Approach */
"01NH4ZZ" = "1" /* Release Peroneal Nerve, Percutaneous Endoscopic Approach */
"01NK0ZZ" = "1" /* Release Head and Neck Sympathetic Nerve, Open Approach */
"01NK3ZZ" = "1" /* Release Head and Neck Sympathetic Nerve, Percutaneous Approach */
"01NK4ZZ" = "1" /* Release Head and Neck Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01NL0ZZ" = "1" /* Release Thoracic Sympathetic Nerve, Open Approach */
"01NL3ZZ" = "1" /* Release Thoracic Sympathetic Nerve, Percutaneous Approach */
"01NL4ZZ" = "1" /* Release Thoracic Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01NM0ZZ" = "1" /* Release Abdominal Sympathetic Nerve, Open Approach */
"01NM3ZZ" = "1" /* Release Abdominal Sympathetic Nerve, Percutaneous Approach */
"01NM4ZZ" = "1" /* Release Abdominal Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01NN0ZZ" = "1" /* Release Lumbar Sympathetic Nerve, Open Approach */
"01NN3ZZ" = "1" /* Release Lumbar Sympathetic Nerve, Percutaneous Approach */
"01NN4ZZ" = "1" /* Release Lumbar Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01NP0ZZ" = "1" /* Release Sacral Sympathetic Nerve, Open Approach */
"01NP3ZZ" = "1" /* Release Sacral Sympathetic Nerve, Percutaneous Approach */
"01NP4ZZ" = "1" /* Release Sacral Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01NQ0ZZ" = "1" /* Release Sacral Plexus, Open Approach */
"01NQ3ZZ" = "1" /* Release Sacral Plexus, Percutaneous Approach */
"01NQ4ZZ" = "1" /* Release Sacral Plexus, Percutaneous Endoscopic Approach */
"01NR0ZZ" = "1" /* Release Sacral Nerve, Open Approach */
"01NR3ZZ" = "1" /* Release Sacral Nerve, Percutaneous Approach */
"01NR4ZZ" = "1" /* Release Sacral Nerve, Percutaneous Endoscopic Approach */
"01PY00Z" = "1" /* Removal of Drainage Device from Peripheral Nerve, Open Approach */
"01PY02Z" = "1" /* Removal of Monitoring Device from Peripheral Nerve, Open Approach */
"01PY07Z" = "1" /* Removal of Autologous Tissue Substitute from Peripheral Nerve, Open Approach */
"01PY0MZ" = "1" /* Removal of Neurostimulator Lead from Peripheral Nerve, Open Approach */
"01PY37Z" = "1" /* Removal of Autologous Tissue Substitute from Peripheral Nerve, Percutaneous Approach */
"01PY3MZ" = "1" /* Removal of Neurostimulator Lead from Peripheral Nerve, Percutaneous Approach */
"01PY40Z" = "1" /* Removal of Drainage Device from Peripheral Nerve, Percutaneous Endoscopic Approach */
"01PY42Z" = "1" /* Removal of Monitoring Device from Peripheral Nerve, Percutaneous Endoscopic Approach */
"01PY47Z" = "1" /* Removal of Autologous Tissue Substitute from Peripheral Nerve, Percutaneous Endoscopic Approach */
"01PY4MZ" = "1" /* Removal of Neurostimulator Lead from Peripheral Nerve, Percutaneous Endoscopic Approach */
"01Q00ZZ" = "1" /* Repair Cervical Plexus, Open Approach */
"01Q03ZZ" = "1" /* Repair Cervical Plexus, Percutaneous Approach */
"01Q04ZZ" = "1" /* Repair Cervical Plexus, Percutaneous Endoscopic Approach */
"01Q10ZZ" = "1" /* Repair Cervical Nerve, Open Approach */
"01Q13ZZ" = "1" /* Repair Cervical Nerve, Percutaneous Approach */
"01Q14ZZ" = "1" /* Repair Cervical Nerve, Percutaneous Endoscopic Approach */
"01Q20ZZ" = "1" /* Repair Phrenic Nerve, Open Approach */
"01Q23ZZ" = "1" /* Repair Phrenic Nerve, Percutaneous Approach */
"01Q24ZZ" = "1" /* Repair Phrenic Nerve, Percutaneous Endoscopic Approach */
"01Q30ZZ" = "1" /* Repair Brachial Plexus, Open Approach */
"01Q33ZZ" = "1" /* Repair Brachial Plexus, Percutaneous Approach */
"01Q34ZZ" = "1" /* Repair Brachial Plexus, Percutaneous Endoscopic Approach */
"01Q40ZZ" = "1" /* Repair Ulnar Nerve, Open Approach */
"01Q43ZZ" = "1" /* Repair Ulnar Nerve, Percutaneous Approach */
"01Q44ZZ" = "1" /* Repair Ulnar Nerve, Percutaneous Endoscopic Approach */
"01Q50ZZ" = "1" /* Repair Median Nerve, Open Approach */
"01Q53ZZ" = "1" /* Repair Median Nerve, Percutaneous Approach */
"01Q54ZZ" = "1" /* Repair Median Nerve, Percutaneous Endoscopic Approach */
"01Q60ZZ" = "1" /* Repair Radial Nerve, Open Approach */
"01Q63ZZ" = "1" /* Repair Radial Nerve, Percutaneous Approach */
"01Q64ZZ" = "1" /* Repair Radial Nerve, Percutaneous Endoscopic Approach */
"01Q80ZZ" = "1" /* Repair Thoracic Nerve, Open Approach */
"01Q83ZZ" = "1" /* Repair Thoracic Nerve, Percutaneous Approach */
"01Q84ZZ" = "1" /* Repair Thoracic Nerve, Percutaneous Endoscopic Approach */
"01Q90ZZ" = "1" /* Repair Lumbar Plexus, Open Approach */
"01Q93ZZ" = "1" /* Repair Lumbar Plexus, Percutaneous Approach */
"01Q94ZZ" = "1" /* Repair Lumbar Plexus, Percutaneous Endoscopic Approach */
"01QA0ZZ" = "1" /* Repair Lumbosacral Plexus, Open Approach */
"01QA3ZZ" = "1" /* Repair Lumbosacral Plexus, Percutaneous Approach */
"01QA4ZZ" = "1" /* Repair Lumbosacral Plexus, Percutaneous Endoscopic Approach */
"01QB0ZZ" = "1" /* Repair Lumbar Nerve, Open Approach */
"01QB3ZZ" = "1" /* Repair Lumbar Nerve, Percutaneous Approach */
"01QB4ZZ" = "1" /* Repair Lumbar Nerve, Percutaneous Endoscopic Approach */
"01QC0ZZ" = "1" /* Repair Pudendal Nerve, Open Approach */
"01QC3ZZ" = "1" /* Repair Pudendal Nerve, Percutaneous Approach */
"01QC4ZZ" = "1" /* Repair Pudendal Nerve, Percutaneous Endoscopic Approach */
"01QD0ZZ" = "1" /* Repair Femoral Nerve, Open Approach */
"01QD3ZZ" = "1" /* Repair Femoral Nerve, Percutaneous Approach */
"01QD4ZZ" = "1" /* Repair Femoral Nerve, Percutaneous Endoscopic Approach */
"01QF0ZZ" = "1" /* Repair Sciatic Nerve, Open Approach */
"01QF3ZZ" = "1" /* Repair Sciatic Nerve, Percutaneous Approach */
"01QF4ZZ" = "1" /* Repair Sciatic Nerve, Percutaneous Endoscopic Approach */
"01QG0ZZ" = "1" /* Repair Tibial Nerve, Open Approach */
"01QG3ZZ" = "1" /* Repair Tibial Nerve, Percutaneous Approach */
"01QG4ZZ" = "1" /* Repair Tibial Nerve, Percutaneous Endoscopic Approach */
"01QH0ZZ" = "1" /* Repair Peroneal Nerve, Open Approach */
"01QH3ZZ" = "1" /* Repair Peroneal Nerve, Percutaneous Approach */
"01QH4ZZ" = "1" /* Repair Peroneal Nerve, Percutaneous Endoscopic Approach */
"01QK0ZZ" = "1" /* Repair Head and Neck Sympathetic Nerve, Open Approach */
"01QK3ZZ" = "1" /* Repair Head and Neck Sympathetic Nerve, Percutaneous Approach */
"01QK4ZZ" = "1" /* Repair Head and Neck Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01QL0ZZ" = "1" /* Repair Thoracic Sympathetic Nerve, Open Approach */
"01QL3ZZ" = "1" /* Repair Thoracic Sympathetic Nerve, Percutaneous Approach */
"01QL4ZZ" = "1" /* Repair Thoracic Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01QM0ZZ" = "1" /* Repair Abdominal Sympathetic Nerve, Open Approach */
"01QM3ZZ" = "1" /* Repair Abdominal Sympathetic Nerve, Percutaneous Approach */
"01QM4ZZ" = "1" /* Repair Abdominal Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01QN0ZZ" = "1" /* Repair Lumbar Sympathetic Nerve, Open Approach */
"01QN3ZZ" = "1" /* Repair Lumbar Sympathetic Nerve, Percutaneous Approach */
"01QN4ZZ" = "1" /* Repair Lumbar Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01QP0ZZ" = "1" /* Repair Sacral Sympathetic Nerve, Open Approach */
"01QP3ZZ" = "1" /* Repair Sacral Sympathetic Nerve, Percutaneous Approach */
"01QP4ZZ" = "1" /* Repair Sacral Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01QQ0ZZ" = "1" /* Repair Sacral Plexus, Open Approach */
"01QQ3ZZ" = "1" /* Repair Sacral Plexus, Percutaneous Approach */
"01QQ4ZZ" = "1" /* Repair Sacral Plexus, Percutaneous Endoscopic Approach */
"01QR0ZZ" = "1" /* Repair Sacral Nerve, Open Approach */
"01QR3ZZ" = "1" /* Repair Sacral Nerve, Percutaneous Approach */
"01QR4ZZ" = "1" /* Repair Sacral Nerve, Percutaneous Endoscopic Approach */
"01S00ZZ" = "1" /* Reposition Cervical Plexus, Open Approach */
"01S03ZZ" = "1" /* Reposition Cervical Plexus, Percutaneous Approach */
"01S04ZZ" = "1" /* Reposition Cervical Plexus, Percutaneous Endoscopic Approach */
"01S10ZZ" = "1" /* Reposition Cervical Nerve, Open Approach */
"01S13ZZ" = "1" /* Reposition Cervical Nerve, Percutaneous Approach */
"01S14ZZ" = "1" /* Reposition Cervical Nerve, Percutaneous Endoscopic Approach */
"01S20ZZ" = "1" /* Reposition Phrenic Nerve, Open Approach */
"01S23ZZ" = "1" /* Reposition Phrenic Nerve, Percutaneous Approach */
"01S24ZZ" = "1" /* Reposition Phrenic Nerve, Percutaneous Endoscopic Approach */
"01S30ZZ" = "1" /* Reposition Brachial Plexus, Open Approach */
"01S33ZZ" = "1" /* Reposition Brachial Plexus, Percutaneous Approach */
"01S34ZZ" = "1" /* Reposition Brachial Plexus, Percutaneous Endoscopic Approach */
"01S40ZZ" = "1" /* Reposition Ulnar Nerve, Open Approach */
"01S43ZZ" = "1" /* Reposition Ulnar Nerve, Percutaneous Approach */
"01S44ZZ" = "1" /* Reposition Ulnar Nerve, Percutaneous Endoscopic Approach */
"01S50ZZ" = "1" /* Reposition Median Nerve, Open Approach */
"01S53ZZ" = "1" /* Reposition Median Nerve, Percutaneous Approach */
"01S54ZZ" = "1" /* Reposition Median Nerve, Percutaneous Endoscopic Approach */
"01S60ZZ" = "1" /* Reposition Radial Nerve, Open Approach */
"01S63ZZ" = "1" /* Reposition Radial Nerve, Percutaneous Approach */
"01S64ZZ" = "1" /* Reposition Radial Nerve, Percutaneous Endoscopic Approach */
"01S80ZZ" = "1" /* Reposition Thoracic Nerve, Open Approach */
"01S83ZZ" = "1" /* Reposition Thoracic Nerve, Percutaneous Approach */
"01S84ZZ" = "1" /* Reposition Thoracic Nerve, Percutaneous Endoscopic Approach */
"01S90ZZ" = "1" /* Reposition Lumbar Plexus, Open Approach */
"01S93ZZ" = "1" /* Reposition Lumbar Plexus, Percutaneous Approach */
"01S94ZZ" = "1" /* Reposition Lumbar Plexus, Percutaneous Endoscopic Approach */
"01SA0ZZ" = "1" /* Reposition Lumbosacral Plexus, Open Approach */
"01SA3ZZ" = "1" /* Reposition Lumbosacral Plexus, Percutaneous Approach */
"01SA4ZZ" = "1" /* Reposition Lumbosacral Plexus, Percutaneous Endoscopic Approach */
"01SB0ZZ" = "1" /* Reposition Lumbar Nerve, Open Approach */
"01SB3ZZ" = "1" /* Reposition Lumbar Nerve, Percutaneous Approach */
"01SB4ZZ" = "1" /* Reposition Lumbar Nerve, Percutaneous Endoscopic Approach */
"01SC0ZZ" = "1" /* Reposition Pudendal Nerve, Open Approach */
"01SC3ZZ" = "1" /* Reposition Pudendal Nerve, Percutaneous Approach */
"01SC4ZZ" = "1" /* Reposition Pudendal Nerve, Percutaneous Endoscopic Approach */
"01SD0ZZ" = "1" /* Reposition Femoral Nerve, Open Approach */
"01SD3ZZ" = "1" /* Reposition Femoral Nerve, Percutaneous Approach */
"01SD4ZZ" = "1" /* Reposition Femoral Nerve, Percutaneous Endoscopic Approach */
"01SF0ZZ" = "1" /* Reposition Sciatic Nerve, Open Approach */
"01SF3ZZ" = "1" /* Reposition Sciatic Nerve, Percutaneous Approach */
"01SF4ZZ" = "1" /* Reposition Sciatic Nerve, Percutaneous Endoscopic Approach */
"01SG0ZZ" = "1" /* Reposition Tibial Nerve, Open Approach */
"01SG3ZZ" = "1" /* Reposition Tibial Nerve, Percutaneous Approach */
"01SG4ZZ" = "1" /* Reposition Tibial Nerve, Percutaneous Endoscopic Approach */
"01SH0ZZ" = "1" /* Reposition Peroneal Nerve, Open Approach */
"01SH3ZZ" = "1" /* Reposition Peroneal Nerve, Percutaneous Approach */
"01SH4ZZ" = "1" /* Reposition Peroneal Nerve, Percutaneous Endoscopic Approach */
"01SQ0ZZ" = "1" /* Reposition Sacral Plexus, Open Approach */
"01SQ3ZZ" = "1" /* Reposition Sacral Plexus, Percutaneous Approach */
"01SQ4ZZ" = "1" /* Reposition Sacral Plexus, Percutaneous Endoscopic Approach */
"01SR0ZZ" = "1" /* Reposition Sacral Nerve, Open Approach */
"01SR3ZZ" = "1" /* Reposition Sacral Nerve, Percutaneous Approach */
"01SR4ZZ" = "1" /* Reposition Sacral Nerve, Percutaneous Endoscopic Approach */
"01U107Z" = "1" /* Supplement Cervical Nerve with Autologous Tissue Substitute, Open Approach */
"01U137Z" = "1" /* Supplement Cervical Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"01U147Z" = "1" /* Supplement Cervical Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"01U207Z" = "1" /* Supplement Phrenic Nerve with Autologous Tissue Substitute, Open Approach */
"01U237Z" = "1" /* Supplement Phrenic Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"01U247Z" = "1" /* Supplement Phrenic Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"01U407Z" = "1" /* Supplement Ulnar Nerve with Autologous Tissue Substitute, Open Approach */
"01U437Z" = "1" /* Supplement Ulnar Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"01U447Z" = "1" /* Supplement Ulnar Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"01U507Z" = "1" /* Supplement Median Nerve with Autologous Tissue Substitute, Open Approach */
"01U537Z" = "1" /* Supplement Median Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"01U547Z" = "1" /* Supplement Median Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"01U607Z" = "1" /* Supplement Radial Nerve with Autologous Tissue Substitute, Open Approach */
"01U637Z" = "1" /* Supplement Radial Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"01U647Z" = "1" /* Supplement Radial Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"01U807Z" = "1" /* Supplement Thoracic Nerve with Autologous Tissue Substitute, Open Approach */
"01U837Z" = "1" /* Supplement Thoracic Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"01U847Z" = "1" /* Supplement Thoracic Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"01UB07Z" = "1" /* Supplement Lumbar Nerve with Autologous Tissue Substitute, Open Approach */
"01UB37Z" = "1" /* Supplement Lumbar Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"01UB47Z" = "1" /* Supplement Lumbar Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"01UC07Z" = "1" /* Supplement Pudendal Nerve with Autologous Tissue Substitute, Open Approach */
"01UC37Z" = "1" /* Supplement Pudendal Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"01UC47Z" = "1" /* Supplement Pudendal Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"01UD07Z" = "1" /* Supplement Femoral Nerve with Autologous Tissue Substitute, Open Approach */
"01UD37Z" = "1" /* Supplement Femoral Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"01UD47Z" = "1" /* Supplement Femoral Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"01UF07Z" = "1" /* Supplement Sciatic Nerve with Autologous Tissue Substitute, Open Approach */
"01UF37Z" = "1" /* Supplement Sciatic Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"01UF47Z" = "1" /* Supplement Sciatic Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"01UG07Z" = "1" /* Supplement Tibial Nerve with Autologous Tissue Substitute, Open Approach */
"01UG37Z" = "1" /* Supplement Tibial Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"01UG47Z" = "1" /* Supplement Tibial Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"01UH07Z" = "1" /* Supplement Peroneal Nerve with Autologous Tissue Substitute, Open Approach */
"01UH37Z" = "1" /* Supplement Peroneal Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"01UH47Z" = "1" /* Supplement Peroneal Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"01UR07Z" = "1" /* Supplement Sacral Nerve with Autologous Tissue Substitute, Open Approach */
"01UR37Z" = "1" /* Supplement Sacral Nerve with Autologous Tissue Substitute, Percutaneous Approach */
"01UR47Z" = "1" /* Supplement Sacral Nerve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"01WY00Z" = "1" /* Revision of Drainage Device in Peripheral Nerve, Open Approach */
"01WY02Z" = "1" /* Revision of Monitoring Device in Peripheral Nerve, Open Approach */
"01WY07Z" = "1" /* Revision of Autologous Tissue Substitute in Peripheral Nerve, Open Approach */
"01WY0MZ" = "1" /* Revision of Neurostimulator Lead in Peripheral Nerve, Open Approach */
"01WY30Z" = "1" /* Revision of Drainage Device in Peripheral Nerve, Percutaneous Approach */
"01WY32Z" = "1" /* Revision of Monitoring Device in Peripheral Nerve, Percutaneous Approach */
"01WY37Z" = "1" /* Revision of Autologous Tissue Substitute in Peripheral Nerve, Percutaneous Approach */
"01WY3MZ" = "1" /* Revision of Neurostimulator Lead in Peripheral Nerve, Percutaneous Approach */
"01WY40Z" = "1" /* Revision of Drainage Device in Peripheral Nerve, Percutaneous Endoscopic Approach */
"01WY42Z" = "1" /* Revision of Monitoring Device in Peripheral Nerve, Percutaneous Endoscopic Approach */
"01WY47Z" = "1" /* Revision of Autologous Tissue Substitute in Peripheral Nerve, Percutaneous Endoscopic Approach */
"01WY4MZ" = "1" /* Revision of Neurostimulator Lead in Peripheral Nerve, Percutaneous Endoscopic Approach */
"01X10Z1" = "1" /* Transfer Cervical Nerve to Cervical Nerve, Open Approach */
"01X10Z2" = "1" /* Transfer Cervical Nerve to Phrenic Nerve, Open Approach */
"01X14Z1" = "1" /* Transfer Cervical Nerve to Cervical Nerve, Percutaneous Endoscopic Approach */
"01X14Z2" = "1" /* Transfer Cervical Nerve to Phrenic Nerve, Percutaneous Endoscopic Approach */
"01X20Z1" = "1" /* Transfer Phrenic Nerve to Cervical Nerve, Open Approach */
"01X20Z2" = "1" /* Transfer Phrenic Nerve to Phrenic Nerve, Open Approach */
"01X24Z1" = "1" /* Transfer Phrenic Nerve to Cervical Nerve, Percutaneous Endoscopic Approach */
"01X24Z2" = "1" /* Transfer Phrenic Nerve to Phrenic Nerve, Percutaneous Endoscopic Approach */
"01X40Z4" = "1" /* Transfer Ulnar Nerve to Ulnar Nerve, Open Approach */
"01X40Z5" = "1" /* Transfer Ulnar Nerve to Median Nerve, Open Approach */
"01X40Z6" = "1" /* Transfer Ulnar Nerve to Radial Nerve, Open Approach */
"01X44Z4" = "1" /* Transfer Ulnar Nerve to Ulnar Nerve, Percutaneous Endoscopic Approach */
"01X44Z5" = "1" /* Transfer Ulnar Nerve to Median Nerve, Percutaneous Endoscopic Approach */
"01X44Z6" = "1" /* Transfer Ulnar Nerve to Radial Nerve, Percutaneous Endoscopic Approach */
"01X50Z4" = "1" /* Transfer Median Nerve to Ulnar Nerve, Open Approach */
"01X50Z5" = "1" /* Transfer Median Nerve to Median Nerve, Open Approach */
"01X50Z6" = "1" /* Transfer Median Nerve to Radial Nerve, Open Approach */
"01X54Z4" = "1" /* Transfer Median Nerve to Ulnar Nerve, Percutaneous Endoscopic Approach */
"01X54Z5" = "1" /* Transfer Median Nerve to Median Nerve, Percutaneous Endoscopic Approach */
"01X54Z6" = "1" /* Transfer Median Nerve to Radial Nerve, Percutaneous Endoscopic Approach */
"01X60Z4" = "1" /* Transfer Radial Nerve to Ulnar Nerve, Open Approach */
"01X60Z5" = "1" /* Transfer Radial Nerve to Median Nerve, Open Approach */
"01X60Z6" = "1" /* Transfer Radial Nerve to Radial Nerve, Open Approach */
"01X64Z4" = "1" /* Transfer Radial Nerve to Ulnar Nerve, Percutaneous Endoscopic Approach */
"01X64Z5" = "1" /* Transfer Radial Nerve to Median Nerve, Percutaneous Endoscopic Approach */
"01X64Z6" = "1" /* Transfer Radial Nerve to Radial Nerve, Percutaneous Endoscopic Approach */
"01X80Z8" = "1" /* Transfer Thoracic Nerve to Thoracic Nerve, Open Approach */
"01X84Z8" = "1" /* Transfer Thoracic Nerve to Thoracic Nerve, Percutaneous Endoscopic Approach */
"01XB0ZB" = "1" /* Transfer Lumbar Nerve to Lumbar Nerve, Open Approach */
"01XB0ZC" = "1" /* Transfer Lumbar Nerve to Perineal Nerve, Open Approach */
"01XB4ZB" = "1" /* Transfer Lumbar Nerve to Lumbar Nerve, Percutaneous Endoscopic Approach */
"01XB4ZC" = "1" /* Transfer Lumbar Nerve to Perineal Nerve, Percutaneous Endoscopic Approach */
"01XC0ZB" = "1" /* Transfer Pudendal Nerve to Lumbar Nerve, Open Approach */
"01XC0ZC" = "1" /* Transfer Pudendal Nerve to Perineal Nerve, Open Approach */
"01XC4ZB" = "1" /* Transfer Pudendal Nerve to Lumbar Nerve, Percutaneous Endoscopic Approach */
"01XC4ZC" = "1" /* Transfer Pudendal Nerve to Perineal Nerve, Percutaneous Endoscopic Approach */
"01XD0ZD" = "1" /* Transfer Femoral Nerve to Femoral Nerve, Open Approach */
"01XD0ZF" = "1" /* Transfer Femoral Nerve to Sciatic Nerve, Open Approach */
"01XD0ZG" = "1" /* Transfer Femoral Nerve to Tibial Nerve, Open Approach */
"01XD0ZH" = "1" /* Transfer Femoral Nerve to Peroneal Nerve, Open Approach */
"01XD4ZD" = "1" /* Transfer Femoral Nerve to Femoral Nerve, Percutaneous Endoscopic Approach */
"01XD4ZF" = "1" /* Transfer Femoral Nerve to Sciatic Nerve, Percutaneous Endoscopic Approach */
"01XD4ZG" = "1" /* Transfer Femoral Nerve to Tibial Nerve, Percutaneous Endoscopic Approach */
"01XD4ZH" = "1" /* Transfer Femoral Nerve to Peroneal Nerve, Percutaneous Endoscopic Approach */
"01XF0ZD" = "1" /* Transfer Sciatic Nerve to Femoral Nerve, Open Approach */
"01XF0ZF" = "1" /* Transfer Sciatic Nerve to Sciatic Nerve, Open Approach */
"01XF0ZG" = "1" /* Transfer Sciatic Nerve to Tibial Nerve, Open Approach */
"01XF0ZH" = "1" /* Transfer Sciatic Nerve to Peroneal Nerve, Open Approach */
"01XF4ZD" = "1" /* Transfer Sciatic Nerve to Femoral Nerve, Percutaneous Endoscopic Approach */
"01XF4ZF" = "1" /* Transfer Sciatic Nerve to Sciatic Nerve, Percutaneous Endoscopic Approach */
"01XF4ZG" = "1" /* Transfer Sciatic Nerve to Tibial Nerve, Percutaneous Endoscopic Approach */
"01XF4ZH" = "1" /* Transfer Sciatic Nerve to Peroneal Nerve, Percutaneous Endoscopic Approach */
"01XG0ZD" = "1" /* Transfer Tibial Nerve to Femoral Nerve, Open Approach */
"01XG0ZF" = "1" /* Transfer Tibial Nerve to Sciatic Nerve, Open Approach */
"01XG0ZG" = "1" /* Transfer Tibial Nerve to Tibial Nerve, Open Approach */
"01XG0ZH" = "1" /* Transfer Tibial Nerve to Peroneal Nerve, Open Approach */
"01XG4ZD" = "1" /* Transfer Tibial Nerve to Femoral Nerve, Percutaneous Endoscopic Approach */
"01XG4ZF" = "1" /* Transfer Tibial Nerve to Sciatic Nerve, Percutaneous Endoscopic Approach */
"01XG4ZG" = "1" /* Transfer Tibial Nerve to Tibial Nerve, Percutaneous Endoscopic Approach */
"01XG4ZH" = "1" /* Transfer Tibial Nerve to Peroneal Nerve, Percutaneous Endoscopic Approach */
"01XH0ZD" = "1" /* Transfer Peroneal Nerve to Femoral Nerve, Open Approach */
"01XH0ZF" = "1" /* Transfer Peroneal Nerve to Sciatic Nerve, Open Approach */
"01XH0ZG" = "1" /* Transfer Peroneal Nerve to Tibial Nerve, Open Approach */
"01XH0ZH" = "1" /* Transfer Peroneal Nerve to Peroneal Nerve, Open Approach */
"01XH4ZD" = "1" /* Transfer Peroneal Nerve to Femoral Nerve, Percutaneous Endoscopic Approach */
"01XH4ZF" = "1" /* Transfer Peroneal Nerve to Sciatic Nerve, Percutaneous Endoscopic Approach */
"01XH4ZG" = "1" /* Transfer Peroneal Nerve to Tibial Nerve, Percutaneous Endoscopic Approach */
"01XH4ZH" = "1" /* Transfer Peroneal Nerve to Peroneal Nerve, Percutaneous Endoscopic Approach */
"0210083" = "1" /* Bypass Coronary Artery, One Artery from Coronary Artery with Zooplastic Tissue, Open Approach */
"0210088" = "1" /* Bypass Coronary Artery, One Artery from Right Internal Mammary with Zooplastic Tissue, Open Approach */
"0210089" = "1" /* Bypass Coronary Artery, One Artery from Left Internal Mammary with Zooplastic Tissue, Open Approach */
"021008C" = "1" /* Bypass Coronary Artery, One Artery from Thoracic Artery with Zooplastic Tissue, Open Approach */
"021008F" = "1" /* Bypass Coronary Artery, One Artery from Abdominal Artery with Zooplastic Tissue, Open Approach */
"021008W" = "1" /* Bypass Coronary Artery, One Artery from Aorta with Zooplastic Tissue, Open Approach */
"0210093" = "1" /* Bypass Coronary Artery, One Artery from Coronary Artery with Autologous Venous Tissue, Open Approach */
"0210098" = "1" /* Bypass Coronary Artery, One Artery from Right Internal Mammary with Autologous Venous Tissue, Open Approach */
"0210099" = "1" /* Bypass Coronary Artery, One Artery from Left Internal Mammary with Autologous Venous Tissue, Open Approach */
"021009C" = "1" /* Bypass Coronary Artery, One Artery from Thoracic Artery with Autologous Venous Tissue, Open Approach */
"021009F" = "1" /* Bypass Coronary Artery, One Artery from Abdominal Artery with Autologous Venous Tissue, Open Approach */
"021009W" = "1" /* Bypass Coronary Artery, One Artery from Aorta with Autologous Venous Tissue, Open Approach */
"02100A3" = "1" /* Bypass Coronary Artery, One Artery from Coronary Artery with Autologous Arterial Tissue, Open Approach */
"02100A8" = "1" /* Bypass Coronary Artery, One Artery from Right Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02100A9" = "1" /* Bypass Coronary Artery, One Artery from Left Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02100AC" = "1" /* Bypass Coronary Artery, One Artery from Thoracic Artery with Autologous Arterial Tissue, Open Approach */
"02100AF" = "1" /* Bypass Coronary Artery, One Artery from Abdominal Artery with Autologous Arterial Tissue, Open Approach */
"02100AW" = "1" /* Bypass Coronary Artery, One Artery from Aorta with Autologous Arterial Tissue, Open Approach */
"02100J3" = "1" /* Bypass Coronary Artery, One Artery from Coronary Artery with Synthetic Substitute, Open Approach */
"02100J8" = "1" /* Bypass Coronary Artery, One Artery from Right Internal Mammary with Synthetic Substitute, Open Approach */
"02100J9" = "1" /* Bypass Coronary Artery, One Artery from Left Internal Mammary with Synthetic Substitute, Open Approach */
"02100JC" = "1" /* Bypass Coronary Artery, One Artery from Thoracic Artery with Synthetic Substitute, Open Approach */
"02100JF" = "1" /* Bypass Coronary Artery, One Artery from Abdominal Artery with Synthetic Substitute, Open Approach */
"02100JW" = "1" /* Bypass Coronary Artery, One Artery from Aorta with Synthetic Substitute, Open Approach */
"02100K3" = "1" /* Bypass Coronary Artery, One Artery from Coronary Artery with Nonautologous Tissue Substitute, Open Approach */
"02100K8" = "1" /* Bypass Coronary Artery, One Artery from Right Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02100K9" = "1" /* Bypass Coronary Artery, One Artery from Left Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02100KC" = "1" /* Bypass Coronary Artery, One Artery from Thoracic Artery with Nonautologous Tissue Substitute, Open Approach */
"02100KF" = "1" /* Bypass Coronary Artery, One Artery from Abdominal Artery with Nonautologous Tissue Substitute, Open Approach */
"02100KW" = "1" /* Bypass Coronary Artery, One Artery from Aorta with Nonautologous Tissue Substitute, Open Approach */
"02100Z3" = "1" /* Bypass Coronary Artery, One Artery from Coronary Artery, Open Approach */
"02100Z8" = "1" /* Bypass Coronary Artery, One Artery from Right Internal Mammary, Open Approach */
"02100Z9" = "1" /* Bypass Coronary Artery, One Artery from Left Internal Mammary, Open Approach */
"02100ZC" = "1" /* Bypass Coronary Artery, One Artery from Thoracic Artery, Open Approach */
"02100ZF" = "1" /* Bypass Coronary Artery, One Artery from Abdominal Artery, Open Approach */
"0210483" = "1" /* Bypass Coronary Artery, One Artery from Coronary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0210488" = "1" /* Bypass Coronary Artery, One Artery from Right Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0210489" = "1" /* Bypass Coronary Artery, One Artery from Left Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021048C" = "1" /* Bypass Coronary Artery, One Artery from Thoracic Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021048F" = "1" /* Bypass Coronary Artery, One Artery from Abdominal Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021048W" = "1" /* Bypass Coronary Artery, One Artery from Aorta with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0210493" = "1" /* Bypass Coronary Artery, One Artery from Coronary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0210498" = "1" /* Bypass Coronary Artery, One Artery from Right Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0210499" = "1" /* Bypass Coronary Artery, One Artery from Left Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021049C" = "1" /* Bypass Coronary Artery, One Artery from Thoracic Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021049F" = "1" /* Bypass Coronary Artery, One Artery from Abdominal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021049W" = "1" /* Bypass Coronary Artery, One Artery from Aorta with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"02104A3" = "1" /* Bypass Coronary Artery, One Artery from Coronary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104A8" = "1" /* Bypass Coronary Artery, One Artery from Right Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104A9" = "1" /* Bypass Coronary Artery, One Artery from Left Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104AC" = "1" /* Bypass Coronary Artery, One Artery from Thoracic Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104AF" = "1" /* Bypass Coronary Artery, One Artery from Abdominal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104AW" = "1" /* Bypass Coronary Artery, One Artery from Aorta with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104J3" = "1" /* Bypass Coronary Artery, One Artery from Coronary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104J8" = "1" /* Bypass Coronary Artery, One Artery from Right Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104J9" = "1" /* Bypass Coronary Artery, One Artery from Left Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104JC" = "1" /* Bypass Coronary Artery, One Artery from Thoracic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104JF" = "1" /* Bypass Coronary Artery, One Artery from Abdominal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104JW" = "1" /* Bypass Coronary Artery, One Artery from Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104K3" = "1" /* Bypass Coronary Artery, One Artery from Coronary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104K8" = "1" /* Bypass Coronary Artery, One Artery from Right Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104K9" = "1" /* Bypass Coronary Artery, One Artery from Left Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104KC" = "1" /* Bypass Coronary Artery, One Artery from Thoracic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104KF" = "1" /* Bypass Coronary Artery, One Artery from Abdominal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104KW" = "1" /* Bypass Coronary Artery, One Artery from Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104Z3" = "1" /* Bypass Coronary Artery, One Artery from Coronary Artery, Percutaneous Endoscopic Approach */
"02104Z8" = "1" /* Bypass Coronary Artery, One Artery from Right Internal Mammary, Percutaneous Endoscopic Approach */
"02104Z9" = "1" /* Bypass Coronary Artery, One Artery from Left Internal Mammary, Percutaneous Endoscopic Approach */
"02104ZC" = "1" /* Bypass Coronary Artery, One Artery from Thoracic Artery, Percutaneous Endoscopic Approach */
"02104ZF" = "1" /* Bypass Coronary Artery, One Artery from Abdominal Artery, Percutaneous Endoscopic Approach */
"0211083" = "1" /* Bypass Coronary Artery, Two Arteries from Coronary Artery with Zooplastic Tissue, Open Approach */
"0211088" = "1" /* Bypass Coronary Artery, Two Arteries from Right Internal Mammary with Zooplastic Tissue, Open Approach */
"0211089" = "1" /* Bypass Coronary Artery, Two Arteries from Left Internal Mammary with Zooplastic Tissue, Open Approach */
"021108C" = "1" /* Bypass Coronary Artery, Two Arteries from Thoracic Artery with Zooplastic Tissue, Open Approach */
"021108F" = "1" /* Bypass Coronary Artery, Two Arteries from Abdominal Artery with Zooplastic Tissue, Open Approach */
"021108W" = "1" /* Bypass Coronary Artery, Two Arteries from Aorta with Zooplastic Tissue, Open Approach */
"0211093" = "1" /* Bypass Coronary Artery, Two Arteries from Coronary Artery with Autologous Venous Tissue, Open Approach */
"0211098" = "1" /* Bypass Coronary Artery, Two Arteries from Right Internal Mammary with Autologous Venous Tissue, Open Approach */
"0211099" = "1" /* Bypass Coronary Artery, Two Arteries from Left Internal Mammary with Autologous Venous Tissue, Open Approach */
"021109C" = "1" /* Bypass Coronary Artery, Two Arteries from Thoracic Artery with Autologous Venous Tissue, Open Approach */
"021109F" = "1" /* Bypass Coronary Artery, Two Arteries from Abdominal Artery with Autologous Venous Tissue, Open Approach */
"021109W" = "1" /* Bypass Coronary Artery, Two Arteries from Aorta with Autologous Venous Tissue, Open Approach */
"02110A3" = "1" /* Bypass Coronary Artery, Two Arteries from Coronary Artery with Autologous Arterial Tissue, Open Approach */
"02110A8" = "1" /* Bypass Coronary Artery, Two Arteries from Right Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02110A9" = "1" /* Bypass Coronary Artery, Two Arteries from Left Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02110AC" = "1" /* Bypass Coronary Artery, Two Arteries from Thoracic Artery with Autologous Arterial Tissue, Open Approach */
"02110AF" = "1" /* Bypass Coronary Artery, Two Arteries from Abdominal Artery with Autologous Arterial Tissue, Open Approach */
"02110AW" = "1" /* Bypass Coronary Artery, Two Arteries from Aorta with Autologous Arterial Tissue, Open Approach */
"02110J3" = "1" /* Bypass Coronary Artery, Two Arteries from Coronary Artery with Synthetic Substitute, Open Approach */
"02110J8" = "1" /* Bypass Coronary Artery, Two Arteries from Right Internal Mammary with Synthetic Substitute, Open Approach */
"02110J9" = "1" /* Bypass Coronary Artery, Two Arteries from Left Internal Mammary with Synthetic Substitute, Open Approach */
"02110JC" = "1" /* Bypass Coronary Artery, Two Arteries from Thoracic Artery with Synthetic Substitute, Open Approach */
"02110JF" = "1" /* Bypass Coronary Artery, Two Arteries from Abdominal Artery with Synthetic Substitute, Open Approach */
"02110JW" = "1" /* Bypass Coronary Artery, Two Arteries from Aorta with Synthetic Substitute, Open Approach */
"02110K3" = "1" /* Bypass Coronary Artery, Two Arteries from Coronary Artery with Nonautologous Tissue Substitute, Open Approach */
"02110K8" = "1" /* Bypass Coronary Artery, Two Arteries from Right Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02110K9" = "1" /* Bypass Coronary Artery, Two Arteries from Left Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02110KC" = "1" /* Bypass Coronary Artery, Two Arteries from Thoracic Artery with Nonautologous Tissue Substitute, Open Approach */
"02110KF" = "1" /* Bypass Coronary Artery, Two Arteries from Abdominal Artery with Nonautologous Tissue Substitute, Open Approach */
"02110KW" = "1" /* Bypass Coronary Artery, Two Arteries from Aorta with Nonautologous Tissue Substitute, Open Approach */
"02110Z3" = "1" /* Bypass Coronary Artery, Two Arteries from Coronary Artery, Open Approach */
"02110Z8" = "1" /* Bypass Coronary Artery, Two Arteries from Right Internal Mammary, Open Approach */
"02110Z9" = "1" /* Bypass Coronary Artery, Two Arteries from Left Internal Mammary, Open Approach */
"02110ZC" = "1" /* Bypass Coronary Artery, Two Arteries from Thoracic Artery, Open Approach */
"02110ZF" = "1" /* Bypass Coronary Artery, Two Arteries from Abdominal Artery, Open Approach */
"0211483" = "1" /* Bypass Coronary Artery, Two Arteries from Coronary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0211488" = "1" /* Bypass Coronary Artery, Two Arteries from Right Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0211489" = "1" /* Bypass Coronary Artery, Two Arteries from Left Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021148C" = "1" /* Bypass Coronary Artery, Two Arteries from Thoracic Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021148F" = "1" /* Bypass Coronary Artery, Two Arteries from Abdominal Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021148W" = "1" /* Bypass Coronary Artery, Two Arteries from Aorta with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0211493" = "1" /* Bypass Coronary Artery, Two Arteries from Coronary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0211498" = "1" /* Bypass Coronary Artery, Two Arteries from Right Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0211499" = "1" /* Bypass Coronary Artery, Two Arteries from Left Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021149C" = "1" /* Bypass Coronary Artery, Two Arteries from Thoracic Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021149F" = "1" /* Bypass Coronary Artery, Two Arteries from Abdominal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021149W" = "1" /* Bypass Coronary Artery, Two Arteries from Aorta with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"02114A3" = "1" /* Bypass Coronary Artery, Two Arteries from Coronary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114A8" = "1" /* Bypass Coronary Artery, Two Arteries from Right Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114A9" = "1" /* Bypass Coronary Artery, Two Arteries from Left Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114AC" = "1" /* Bypass Coronary Artery, Two Arteries from Thoracic Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114AF" = "1" /* Bypass Coronary Artery, Two Arteries from Abdominal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114AW" = "1" /* Bypass Coronary Artery, Two Arteries from Aorta with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114J3" = "1" /* Bypass Coronary Artery, Two Arteries from Coronary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114J8" = "1" /* Bypass Coronary Artery, Two Arteries from Right Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114J9" = "1" /* Bypass Coronary Artery, Two Arteries from Left Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114JC" = "1" /* Bypass Coronary Artery, Two Arteries from Thoracic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114JF" = "1" /* Bypass Coronary Artery, Two Arteries from Abdominal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114JW" = "1" /* Bypass Coronary Artery, Two Arteries from Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114K3" = "1" /* Bypass Coronary Artery, Two Arteries from Coronary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114K8" = "1" /* Bypass Coronary Artery, Two Arteries from Right Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114K9" = "1" /* Bypass Coronary Artery, Two Arteries from Left Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114KC" = "1" /* Bypass Coronary Artery, Two Arteries from Thoracic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114KF" = "1" /* Bypass Coronary Artery, Two Arteries from Abdominal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114KW" = "1" /* Bypass Coronary Artery, Two Arteries from Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114Z3" = "1" /* Bypass Coronary Artery, Two Arteries from Coronary Artery, Percutaneous Endoscopic Approach */
"02114Z8" = "1" /* Bypass Coronary Artery, Two Arteries from Right Internal Mammary, Percutaneous Endoscopic Approach */
"02114Z9" = "1" /* Bypass Coronary Artery, Two Arteries from Left Internal Mammary, Percutaneous Endoscopic Approach */
"02114ZC" = "1" /* Bypass Coronary Artery, Two Arteries from Thoracic Artery, Percutaneous Endoscopic Approach */
"02114ZF" = "1" /* Bypass Coronary Artery, Two Arteries from Abdominal Artery, Percutaneous Endoscopic Approach */
"0212083" = "1" /* Bypass Coronary Artery, Three Arteries from Coronary Artery with Zooplastic Tissue, Open Approach */
"0212088" = "1" /* Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Zooplastic Tissue, Open Approach */
"0212089" = "1" /* Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Zooplastic Tissue, Open Approach */
"021208C" = "1" /* Bypass Coronary Artery, Three Arteries from Thoracic Artery with Zooplastic Tissue, Open Approach */
"021208F" = "1" /* Bypass Coronary Artery, Three Arteries from Abdominal Artery with Zooplastic Tissue, Open Approach */
"021208W" = "1" /* Bypass Coronary Artery, Three Arteries from Aorta with Zooplastic Tissue, Open Approach */
"0212093" = "1" /* Bypass Coronary Artery, Three Arteries from Coronary Artery with Autologous Venous Tissue, Open Approach */
"0212098" = "1" /* Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Autologous Venous Tissue, Open Approach */
"0212099" = "1" /* Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Autologous Venous Tissue, Open Approach */
"021209C" = "1" /* Bypass Coronary Artery, Three Arteries from Thoracic Artery with Autologous Venous Tissue, Open Approach */
"021209F" = "1" /* Bypass Coronary Artery, Three Arteries from Abdominal Artery with Autologous Venous Tissue, Open Approach */
"021209W" = "1" /* Bypass Coronary Artery, Three Arteries from Aorta with Autologous Venous Tissue, Open Approach */
"02120A3" = "1" /* Bypass Coronary Artery, Three Arteries from Coronary Artery with Autologous Arterial Tissue, Open Approach */
"02120A8" = "1" /* Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02120A9" = "1" /* Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02120AC" = "1" /* Bypass Coronary Artery, Three Arteries from Thoracic Artery with Autologous Arterial Tissue, Open Approach */
"02120AF" = "1" /* Bypass Coronary Artery, Three Arteries from Abdominal Artery with Autologous Arterial Tissue, Open Approach */
"02120AW" = "1" /* Bypass Coronary Artery, Three Arteries from Aorta with Autologous Arterial Tissue, Open Approach */
"02120J3" = "1" /* Bypass Coronary Artery, Three Arteries from Coronary Artery with Synthetic Substitute, Open Approach */
"02120J8" = "1" /* Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Synthetic Substitute, Open Approach */
"02120J9" = "1" /* Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Synthetic Substitute, Open Approach */
"02120JC" = "1" /* Bypass Coronary Artery, Three Arteries from Thoracic Artery with Synthetic Substitute, Open Approach */
"02120JF" = "1" /* Bypass Coronary Artery, Three Arteries from Abdominal Artery with Synthetic Substitute, Open Approach */
"02120JW" = "1" /* Bypass Coronary Artery, Three Arteries from Aorta with Synthetic Substitute, Open Approach */
"02120K3" = "1" /* Bypass Coronary Artery, Three Arteries from Coronary Artery with Nonautologous Tissue Substitute, Open Approach */
"02120K8" = "1" /* Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02120K9" = "1" /* Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02120KC" = "1" /* Bypass Coronary Artery, Three Arteries from Thoracic Artery with Nonautologous Tissue Substitute, Open Approach */
"02120KF" = "1" /* Bypass Coronary Artery, Three Arteries from Abdominal Artery with Nonautologous Tissue Substitute, Open Approach */
"02120KW" = "1" /* Bypass Coronary Artery, Three Arteries from Aorta with Nonautologous Tissue Substitute, Open Approach */
"02120Z3" = "1" /* Bypass Coronary Artery, Three Arteries from Coronary Artery, Open Approach */
"02120Z8" = "1" /* Bypass Coronary Artery, Three Arteries from Right Internal Mammary, Open Approach */
"02120Z9" = "1" /* Bypass Coronary Artery, Three Arteries from Left Internal Mammary, Open Approach */
"02120ZC" = "1" /* Bypass Coronary Artery, Three Arteries from Thoracic Artery, Open Approach */
"02120ZF" = "1" /* Bypass Coronary Artery, Three Arteries from Abdominal Artery, Open Approach */
"0212483" = "1" /* Bypass Coronary Artery, Three Arteries from Coronary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0212488" = "1" /* Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0212489" = "1" /* Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021248C" = "1" /* Bypass Coronary Artery, Three Arteries from Thoracic Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021248F" = "1" /* Bypass Coronary Artery, Three Arteries from Abdominal Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021248W" = "1" /* Bypass Coronary Artery, Three Arteries from Aorta with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0212493" = "1" /* Bypass Coronary Artery, Three Arteries from Coronary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0212498" = "1" /* Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0212499" = "1" /* Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021249C" = "1" /* Bypass Coronary Artery, Three Arteries from Thoracic Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021249F" = "1" /* Bypass Coronary Artery, Three Arteries from Abdominal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021249W" = "1" /* Bypass Coronary Artery, Three Arteries from Aorta with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"02124A3" = "1" /* Bypass Coronary Artery, Three Arteries from Coronary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124A8" = "1" /* Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124A9" = "1" /* Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124AC" = "1" /* Bypass Coronary Artery, Three Arteries from Thoracic Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124AF" = "1" /* Bypass Coronary Artery, Three Arteries from Abdominal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124AW" = "1" /* Bypass Coronary Artery, Three Arteries from Aorta with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124J3" = "1" /* Bypass Coronary Artery, Three Arteries from Coronary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124J8" = "1" /* Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124J9" = "1" /* Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124JC" = "1" /* Bypass Coronary Artery, Three Arteries from Thoracic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124JF" = "1" /* Bypass Coronary Artery, Three Arteries from Abdominal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124JW" = "1" /* Bypass Coronary Artery, Three Arteries from Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124K3" = "1" /* Bypass Coronary Artery, Three Arteries from Coronary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124K8" = "1" /* Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124K9" = "1" /* Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124KC" = "1" /* Bypass Coronary Artery, Three Arteries from Thoracic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124KF" = "1" /* Bypass Coronary Artery, Three Arteries from Abdominal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124KW" = "1" /* Bypass Coronary Artery, Three Arteries from Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124Z3" = "1" /* Bypass Coronary Artery, Three Arteries from Coronary Artery, Percutaneous Endoscopic Approach */
"02124Z8" = "1" /* Bypass Coronary Artery, Three Arteries from Right Internal Mammary, Percutaneous Endoscopic Approach */
"02124Z9" = "1" /* Bypass Coronary Artery, Three Arteries from Left Internal Mammary, Percutaneous Endoscopic Approach */
"02124ZC" = "1" /* Bypass Coronary Artery, Three Arteries from Thoracic Artery, Percutaneous Endoscopic Approach */
"02124ZF" = "1" /* Bypass Coronary Artery, Three Arteries from Abdominal Artery, Percutaneous Endoscopic Approach */
"0213083" = "1" /* Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Zooplastic Tissue, Open Approach */
"0213088" = "1" /* Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Zooplastic Tissue, Open Approach */
"0213089" = "1" /* Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Zooplastic Tissue, Open Approach */
"021308C" = "1" /* Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Zooplastic Tissue, Open Approach */
"021308F" = "1" /* Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Zooplastic Tissue, Open Approach */
"021308W" = "1" /* Bypass Coronary Artery, Four or More Arteries from Aorta with Zooplastic Tissue, Open Approach */
"0213093" = "1" /* Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Autologous Venous Tissue, Open Approach */
"0213098" = "1" /* Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Autologous Venous Tissue, Open Approach */
"0213099" = "1" /* Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Autologous Venous Tissue, Open Approach */
"021309C" = "1" /* Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Autologous Venous Tissue, Open Approach */
"021309F" = "1" /* Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Autologous Venous Tissue, Open Approach */
"021309W" = "1" /* Bypass Coronary Artery, Four or More Arteries from Aorta with Autologous Venous Tissue, Open Approach */
"02130A3" = "1" /* Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Autologous Arterial Tissue, Open Approach */
"02130A8" = "1" /* Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02130A9" = "1" /* Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02130AC" = "1" /* Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Autologous Arterial Tissue, Open Approach */
"02130AF" = "1" /* Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Autologous Arterial Tissue, Open Approach */
"02130AW" = "1" /* Bypass Coronary Artery, Four or More Arteries from Aorta with Autologous Arterial Tissue, Open Approach */
"02130J3" = "1" /* Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Synthetic Substitute, Open Approach */
"02130J8" = "1" /* Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Synthetic Substitute, Open Approach */
"02130J9" = "1" /* Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Synthetic Substitute, Open Approach */
"02130JC" = "1" /* Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Synthetic Substitute, Open Approach */
"02130JF" = "1" /* Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Synthetic Substitute, Open Approach */
"02130JW" = "1" /* Bypass Coronary Artery, Four or More Arteries from Aorta with Synthetic Substitute, Open Approach */
"02130K3" = "1" /* Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Nonautologous Tissue Substitute, Open Approach */
"02130K8" = "1" /* Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02130K9" = "1" /* Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02130KC" = "1" /* Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Nonautologous Tissue Substitute, Open Approach */
"02130KF" = "1" /* Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Nonautologous Tissue Substitute, Open Approach */
"02130KW" = "1" /* Bypass Coronary Artery, Four or More Arteries from Aorta with Nonautologous Tissue Substitute, Open Approach */
"02130Z3" = "1" /* Bypass Coronary Artery, Four or More Arteries from Coronary Artery, Open Approach */
"02130Z8" = "1" /* Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary, Open Approach */
"02130Z9" = "1" /* Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary, Open Approach */
"02130ZC" = "1" /* Bypass Coronary Artery, Four or More Arteries from Thoracic Artery, Open Approach */
"02130ZF" = "1" /* Bypass Coronary Artery, Four or More Arteries from Abdominal Artery, Open Approach */
"0213483" = "1" /* Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0213488" = "1" /* Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0213489" = "1" /* Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021348C" = "1" /* Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021348F" = "1" /* Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021348W" = "1" /* Bypass Coronary Artery, Four or More Arteries from Aorta with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0213493" = "1" /* Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0213498" = "1" /* Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0213499" = "1" /* Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021349C" = "1" /* Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021349F" = "1" /* Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021349W" = "1" /* Bypass Coronary Artery, Four or More Arteries from Aorta with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"02134A3" = "1" /* Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134A8" = "1" /* Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134A9" = "1" /* Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134AC" = "1" /* Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134AF" = "1" /* Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134AW" = "1" /* Bypass Coronary Artery, Four or More Arteries from Aorta with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134J3" = "1" /* Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134J8" = "1" /* Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134J9" = "1" /* Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134JC" = "1" /* Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134JF" = "1" /* Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134JW" = "1" /* Bypass Coronary Artery, Four or More Arteries from Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134K3" = "1" /* Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134K8" = "1" /* Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134K9" = "1" /* Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134KC" = "1" /* Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134KF" = "1" /* Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134KW" = "1" /* Bypass Coronary Artery, Four or More Arteries from Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134Z3" = "1" /* Bypass Coronary Artery, Four or More Arteries from Coronary Artery, Percutaneous Endoscopic Approach */
"02134Z8" = "1" /* Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary, Percutaneous Endoscopic Approach */
"02134Z9" = "1" /* Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary, Percutaneous Endoscopic Approach */
"02134ZC" = "1" /* Bypass Coronary Artery, Four or More Arteries from Thoracic Artery, Percutaneous Endoscopic Approach */
"02134ZF" = "1" /* Bypass Coronary Artery, Four or More Arteries from Abdominal Artery, Percutaneous Endoscopic Approach */
"021608P" = "1" /* Bypass Right Atrium to Pulmonary Trunk with Zooplastic Tissue, Open Approach */
"021608Q" = "1" /* Bypass Right Atrium to Right Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021608R" = "1" /* Bypass Right Atrium to Left Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021609P" = "1" /* Bypass Right Atrium to Pulmonary Trunk with Autologous Venous Tissue, Open Approach */
"021609Q" = "1" /* Bypass Right Atrium to Right Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021609R" = "1" /* Bypass Right Atrium to Left Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"02160AP" = "1" /* Bypass Right Atrium to Pulmonary Trunk with Autologous Arterial Tissue, Open Approach */
"02160AQ" = "1" /* Bypass Right Atrium to Right Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"02160AR" = "1" /* Bypass Right Atrium to Left Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"02160JP" = "1" /* Bypass Right Atrium to Pulmonary Trunk with Synthetic Substitute, Open Approach */
"02160JQ" = "1" /* Bypass Right Atrium to Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"02160JR" = "1" /* Bypass Right Atrium to Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"02160KP" = "1" /* Bypass Right Atrium to Pulmonary Trunk with Nonautologous Tissue Substitute, Open Approach */
"02160KQ" = "1" /* Bypass Right Atrium to Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"02160KR" = "1" /* Bypass Right Atrium to Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"02160Z7" = "1" /* Bypass Right Atrium to Left Atrium, Open Approach */
"02160ZP" = "1" /* Bypass Right Atrium to Pulmonary Trunk, Open Approach */
"02160ZQ" = "1" /* Bypass Right Atrium to Right Pulmonary Artery, Open Approach */
"02160ZR" = "1" /* Bypass Right Atrium to Left Pulmonary Artery, Open Approach */
"021648P" = "1" /* Bypass Right Atrium to Pulmonary Trunk with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021648Q" = "1" /* Bypass Right Atrium to Right Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021648R" = "1" /* Bypass Right Atrium to Left Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021649P" = "1" /* Bypass Right Atrium to Pulmonary Trunk with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021649Q" = "1" /* Bypass Right Atrium to Right Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021649R" = "1" /* Bypass Right Atrium to Left Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"02164AP" = "1" /* Bypass Right Atrium to Pulmonary Trunk with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02164AQ" = "1" /* Bypass Right Atrium to Right Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02164AR" = "1" /* Bypass Right Atrium to Left Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02164JP" = "1" /* Bypass Right Atrium to Pulmonary Trunk with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02164JQ" = "1" /* Bypass Right Atrium to Right Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02164JR" = "1" /* Bypass Right Atrium to Left Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02164KP" = "1" /* Bypass Right Atrium to Pulmonary Trunk with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02164KQ" = "1" /* Bypass Right Atrium to Right Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02164KR" = "1" /* Bypass Right Atrium to Left Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02164Z7" = "1" /* Bypass Right Atrium to Left Atrium, Percutaneous Endoscopic Approach */
"02164ZP" = "1" /* Bypass Right Atrium to Pulmonary Trunk, Percutaneous Endoscopic Approach */
"02164ZQ" = "1" /* Bypass Right Atrium to Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"02164ZR" = "1" /* Bypass Right Atrium to Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"021708P" = "1" /* Bypass Left Atrium to Pulmonary Trunk with Zooplastic Tissue, Open Approach */
"021708Q" = "1" /* Bypass Left Atrium to Right Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021708R" = "1" /* Bypass Left Atrium to Left Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021708S" = "1" /* Bypass Left Atrium to Right Pulmonary Vein with Zooplastic Tissue, Open Approach */
"021708T" = "1" /* Bypass Left Atrium to Left Pulmonary Vein with Zooplastic Tissue, Open Approach */
"021708U" = "1" /* Bypass Left Atrium to Pulmonary Vein Confluence with Zooplastic Tissue, Open Approach */
"021709P" = "1" /* Bypass Left Atrium to Pulmonary Trunk with Autologous Venous Tissue, Open Approach */
"021709Q" = "1" /* Bypass Left Atrium to Right Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021709R" = "1" /* Bypass Left Atrium to Left Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021709S" = "1" /* Bypass Left Atrium to Right Pulmonary Vein with Autologous Venous Tissue, Open Approach */
"021709T" = "1" /* Bypass Left Atrium to Left Pulmonary Vein with Autologous Venous Tissue, Open Approach */
"021709U" = "1" /* Bypass Left Atrium to Pulmonary Vein Confluence with Autologous Venous Tissue, Open Approach */
"02170AP" = "1" /* Bypass Left Atrium to Pulmonary Trunk with Autologous Arterial Tissue, Open Approach */
"02170AQ" = "1" /* Bypass Left Atrium to Right Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"02170AR" = "1" /* Bypass Left Atrium to Left Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"02170AS" = "1" /* Bypass Left Atrium to Right Pulmonary Vein with Autologous Arterial Tissue, Open Approach */
"02170AT" = "1" /* Bypass Left Atrium to Left Pulmonary Vein with Autologous Arterial Tissue, Open Approach */
"02170AU" = "1" /* Bypass Left Atrium to Pulmonary Vein Confluence with Autologous Arterial Tissue, Open Approach */
"02170JP" = "1" /* Bypass Left Atrium to Pulmonary Trunk with Synthetic Substitute, Open Approach */
"02170JQ" = "1" /* Bypass Left Atrium to Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"02170JR" = "1" /* Bypass Left Atrium to Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"02170JS" = "1" /* Bypass Left Atrium to Right Pulmonary Vein with Synthetic Substitute, Open Approach */
"02170JT" = "1" /* Bypass Left Atrium to Left Pulmonary Vein with Synthetic Substitute, Open Approach */
"02170JU" = "1" /* Bypass Left Atrium to Pulmonary Vein Confluence with Synthetic Substitute, Open Approach */
"02170KP" = "1" /* Bypass Left Atrium to Pulmonary Trunk with Nonautologous Tissue Substitute, Open Approach */
"02170KQ" = "1" /* Bypass Left Atrium to Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"02170KR" = "1" /* Bypass Left Atrium to Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"02170KS" = "1" /* Bypass Left Atrium to Right Pulmonary Vein with Nonautologous Tissue Substitute, Open Approach */
"02170KT" = "1" /* Bypass Left Atrium to Left Pulmonary Vein with Nonautologous Tissue Substitute, Open Approach */
"02170KU" = "1" /* Bypass Left Atrium to Pulmonary Vein Confluence with Nonautologous Tissue Substitute, Open Approach */
"02170ZP" = "1" /* Bypass Left Atrium to Pulmonary Trunk, Open Approach */
"02170ZQ" = "1" /* Bypass Left Atrium to Right Pulmonary Artery, Open Approach */
"02170ZR" = "1" /* Bypass Left Atrium to Left Pulmonary Artery, Open Approach */
"02170ZS" = "1" /* Bypass Left Atrium to Right Pulmonary Vein, Open Approach */
"02170ZT" = "1" /* Bypass Left Atrium to Left Pulmonary Vein, Open Approach */
"02170ZU" = "1" /* Bypass Left Atrium to Pulmonary Vein Confluence, Open Approach */
"021748P" = "1" /* Bypass Left Atrium to Pulmonary Trunk with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021748Q" = "1" /* Bypass Left Atrium to Right Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021748R" = "1" /* Bypass Left Atrium to Left Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021748S" = "1" /* Bypass Left Atrium to Right Pulmonary Vein with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021748T" = "1" /* Bypass Left Atrium to Left Pulmonary Vein with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021748U" = "1" /* Bypass Left Atrium to Pulmonary Vein Confluence with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021749P" = "1" /* Bypass Left Atrium to Pulmonary Trunk with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021749Q" = "1" /* Bypass Left Atrium to Right Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021749R" = "1" /* Bypass Left Atrium to Left Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021749S" = "1" /* Bypass Left Atrium to Right Pulmonary Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021749T" = "1" /* Bypass Left Atrium to Left Pulmonary Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021749U" = "1" /* Bypass Left Atrium to Pulmonary Vein Confluence with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"02174AP" = "1" /* Bypass Left Atrium to Pulmonary Trunk with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02174AQ" = "1" /* Bypass Left Atrium to Right Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02174AR" = "1" /* Bypass Left Atrium to Left Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02174AS" = "1" /* Bypass Left Atrium to Right Pulmonary Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02174AT" = "1" /* Bypass Left Atrium to Left Pulmonary Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02174AU" = "1" /* Bypass Left Atrium to Pulmonary Vein Confluence with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02174JP" = "1" /* Bypass Left Atrium to Pulmonary Trunk with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02174JQ" = "1" /* Bypass Left Atrium to Right Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02174JR" = "1" /* Bypass Left Atrium to Left Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02174JS" = "1" /* Bypass Left Atrium to Right Pulmonary Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02174JT" = "1" /* Bypass Left Atrium to Left Pulmonary Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02174JU" = "1" /* Bypass Left Atrium to Pulmonary Vein Confluence with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02174KP" = "1" /* Bypass Left Atrium to Pulmonary Trunk with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02174KQ" = "1" /* Bypass Left Atrium to Right Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02174KR" = "1" /* Bypass Left Atrium to Left Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02174KS" = "1" /* Bypass Left Atrium to Right Pulmonary Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02174KT" = "1" /* Bypass Left Atrium to Left Pulmonary Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02174KU" = "1" /* Bypass Left Atrium to Pulmonary Vein Confluence with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02174ZP" = "1" /* Bypass Left Atrium to Pulmonary Trunk, Percutaneous Endoscopic Approach */
"02174ZQ" = "1" /* Bypass Left Atrium to Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"02174ZR" = "1" /* Bypass Left Atrium to Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"02174ZS" = "1" /* Bypass Left Atrium to Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"02174ZT" = "1" /* Bypass Left Atrium to Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"02174ZU" = "1" /* Bypass Left Atrium to Pulmonary Vein Confluence, Percutaneous Endoscopic Approach */
"021K08P" = "1" /* Bypass Right Ventricle to Pulmonary Trunk with Zooplastic Tissue, Open Approach */
"021K08Q" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021K08R" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021K09P" = "1" /* Bypass Right Ventricle to Pulmonary Trunk with Autologous Venous Tissue, Open Approach */
"021K09Q" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021K09R" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021K0AP" = "1" /* Bypass Right Ventricle to Pulmonary Trunk with Autologous Arterial Tissue, Open Approach */
"021K0AQ" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021K0AR" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021K0JP" = "1" /* Bypass Right Ventricle to Pulmonary Trunk with Synthetic Substitute, Open Approach */
"021K0JQ" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"021K0JR" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"021K0KP" = "1" /* Bypass Right Ventricle to Pulmonary Trunk with Nonautologous Tissue Substitute, Open Approach */
"021K0KQ" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021K0KR" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021K0Z5" = "1" /* Bypass Right Ventricle to Coronary Circulation, Open Approach */
"021K0Z8" = "1" /* Bypass Right Ventricle to Right Internal Mammary, Open Approach */
"021K0Z9" = "1" /* Bypass Right Ventricle to Left Internal Mammary, Open Approach */
"021K0ZC" = "1" /* Bypass Right Ventricle to Thoracic Artery, Open Approach */
"021K0ZF" = "1" /* Bypass Right Ventricle to Abdominal Artery, Open Approach */
"021K0ZP" = "1" /* Bypass Right Ventricle to Pulmonary Trunk, Open Approach */
"021K0ZQ" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery, Open Approach */
"021K0ZR" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery, Open Approach */
"021K0ZW" = "1" /* Bypass Right Ventricle to Aorta, Open Approach */
"021K48P" = "1" /* Bypass Right Ventricle to Pulmonary Trunk with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021K48Q" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021K48R" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021K49P" = "1" /* Bypass Right Ventricle to Pulmonary Trunk with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021K49Q" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021K49R" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021K4AP" = "1" /* Bypass Right Ventricle to Pulmonary Trunk with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021K4AQ" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021K4AR" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021K4JP" = "1" /* Bypass Right Ventricle to Pulmonary Trunk with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021K4JQ" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021K4JR" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021K4KP" = "1" /* Bypass Right Ventricle to Pulmonary Trunk with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021K4KQ" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021K4KR" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021K4Z5" = "1" /* Bypass Right Ventricle to Coronary Circulation, Percutaneous Endoscopic Approach */
"021K4Z8" = "1" /* Bypass Right Ventricle to Right Internal Mammary, Percutaneous Endoscopic Approach */
"021K4Z9" = "1" /* Bypass Right Ventricle to Left Internal Mammary, Percutaneous Endoscopic Approach */
"021K4ZC" = "1" /* Bypass Right Ventricle to Thoracic Artery, Percutaneous Endoscopic Approach */
"021K4ZF" = "1" /* Bypass Right Ventricle to Abdominal Artery, Percutaneous Endoscopic Approach */
"021K4ZP" = "1" /* Bypass Right Ventricle to Pulmonary Trunk, Percutaneous Endoscopic Approach */
"021K4ZQ" = "1" /* Bypass Right Ventricle to Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"021K4ZR" = "1" /* Bypass Right Ventricle to Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"021K4ZW" = "1" /* Bypass Right Ventricle to Aorta, Percutaneous Endoscopic Approach */
"021L08P" = "1" /* Bypass Left Ventricle to Pulmonary Trunk with Zooplastic Tissue, Open Approach */
"021L08Q" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021L08R" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021L09P" = "1" /* Bypass Left Ventricle to Pulmonary Trunk with Autologous Venous Tissue, Open Approach */
"021L09Q" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021L09R" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021L0AP" = "1" /* Bypass Left Ventricle to Pulmonary Trunk with Autologous Arterial Tissue, Open Approach */
"021L0AQ" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021L0AR" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021L0JP" = "1" /* Bypass Left Ventricle to Pulmonary Trunk with Synthetic Substitute, Open Approach */
"021L0JQ" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"021L0JR" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"021L0KP" = "1" /* Bypass Left Ventricle to Pulmonary Trunk with Nonautologous Tissue Substitute, Open Approach */
"021L0KQ" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021L0KR" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021L0Z5" = "1" /* Bypass Left Ventricle to Coronary Circulation, Open Approach */
"021L0Z8" = "1" /* Bypass Left Ventricle to Right Internal Mammary, Open Approach */
"021L0Z9" = "1" /* Bypass Left Ventricle to Left Internal Mammary, Open Approach */
"021L0ZC" = "1" /* Bypass Left Ventricle to Thoracic Artery, Open Approach */
"021L0ZF" = "1" /* Bypass Left Ventricle to Abdominal Artery, Open Approach */
"021L0ZP" = "1" /* Bypass Left Ventricle to Pulmonary Trunk, Open Approach */
"021L0ZQ" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery, Open Approach */
"021L0ZR" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery, Open Approach */
"021L0ZW" = "1" /* Bypass Left Ventricle to Aorta, Open Approach */
"021L48P" = "1" /* Bypass Left Ventricle to Pulmonary Trunk with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021L48Q" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021L48R" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021L49P" = "1" /* Bypass Left Ventricle to Pulmonary Trunk with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021L49Q" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021L49R" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021L4AP" = "1" /* Bypass Left Ventricle to Pulmonary Trunk with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021L4AQ" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021L4AR" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021L4JP" = "1" /* Bypass Left Ventricle to Pulmonary Trunk with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021L4JQ" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021L4JR" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021L4KP" = "1" /* Bypass Left Ventricle to Pulmonary Trunk with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021L4KQ" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021L4KR" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021L4Z5" = "1" /* Bypass Left Ventricle to Coronary Circulation, Percutaneous Endoscopic Approach */
"021L4Z8" = "1" /* Bypass Left Ventricle to Right Internal Mammary, Percutaneous Endoscopic Approach */
"021L4Z9" = "1" /* Bypass Left Ventricle to Left Internal Mammary, Percutaneous Endoscopic Approach */
"021L4ZC" = "1" /* Bypass Left Ventricle to Thoracic Artery, Percutaneous Endoscopic Approach */
"021L4ZF" = "1" /* Bypass Left Ventricle to Abdominal Artery, Percutaneous Endoscopic Approach */
"021L4ZP" = "1" /* Bypass Left Ventricle to Pulmonary Trunk, Percutaneous Endoscopic Approach */
"021L4ZQ" = "1" /* Bypass Left Ventricle to Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"021L4ZR" = "1" /* Bypass Left Ventricle to Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"021L4ZW" = "1" /* Bypass Left Ventricle to Aorta, Percutaneous Endoscopic Approach */
"021P08A" = "1" /* Bypass Pulmonary Trunk from Innominate Artery with Zooplastic Tissue, Open Approach */
"021P08B" = "1" /* Bypass Pulmonary Trunk from Subclavian with Zooplastic Tissue, Open Approach */
"021P08D" = "1" /* Bypass Pulmonary Trunk from Carotid with Zooplastic Tissue, Open Approach */
"021P09A" = "1" /* Bypass Pulmonary Trunk from Innominate Artery with Autologous Venous Tissue, Open Approach */
"021P09B" = "1" /* Bypass Pulmonary Trunk from Subclavian with Autologous Venous Tissue, Open Approach */
"021P09D" = "1" /* Bypass Pulmonary Trunk from Carotid with Autologous Venous Tissue, Open Approach */
"021P0AA" = "1" /* Bypass Pulmonary Trunk from Innominate Artery with Autologous Arterial Tissue, Open Approach */
"021P0AB" = "1" /* Bypass Pulmonary Trunk from Subclavian with Autologous Arterial Tissue, Open Approach */
"021P0AD" = "1" /* Bypass Pulmonary Trunk from Carotid with Autologous Arterial Tissue, Open Approach */
"021P0JA" = "1" /* Bypass Pulmonary Trunk from Innominate Artery with Synthetic Substitute, Open Approach */
"021P0JB" = "1" /* Bypass Pulmonary Trunk from Subclavian with Synthetic Substitute, Open Approach */
"021P0JD" = "1" /* Bypass Pulmonary Trunk from Carotid with Synthetic Substitute, Open Approach */
"021P0KA" = "1" /* Bypass Pulmonary Trunk from Innominate Artery with Nonautologous Tissue Substitute, Open Approach */
"021P0KB" = "1" /* Bypass Pulmonary Trunk from Subclavian with Nonautologous Tissue Substitute, Open Approach */
"021P0KD" = "1" /* Bypass Pulmonary Trunk from Carotid with Nonautologous Tissue Substitute, Open Approach */
"021P0ZA" = "1" /* Bypass Pulmonary Trunk from Innominate Artery with No Device, Open Approach */
"021P0ZB" = "1" /* Bypass Pulmonary Trunk from Subclavian with No Device, Open Approach */
"021P0ZD" = "1" /* Bypass Pulmonary Trunk from Carotid with No Device, Open Approach */
"021P48A" = "1" /* Bypass Pulmonary Trunk from Innominate Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021P48B" = "1" /* Bypass Pulmonary Trunk from Subclavian with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021P48D" = "1" /* Bypass Pulmonary Trunk from Carotid with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021P49A" = "1" /* Bypass Pulmonary Trunk from Innominate Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021P49B" = "1" /* Bypass Pulmonary Trunk from Subclavian with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021P49D" = "1" /* Bypass Pulmonary Trunk from Carotid with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021P4AA" = "1" /* Bypass Pulmonary Trunk from Innominate Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021P4AB" = "1" /* Bypass Pulmonary Trunk from Subclavian with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021P4AD" = "1" /* Bypass Pulmonary Trunk from Carotid with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021P4JA" = "1" /* Bypass Pulmonary Trunk from Innominate Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021P4JB" = "1" /* Bypass Pulmonary Trunk from Subclavian with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021P4JD" = "1" /* Bypass Pulmonary Trunk from Carotid with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021P4KA" = "1" /* Bypass Pulmonary Trunk from Innominate Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021P4KB" = "1" /* Bypass Pulmonary Trunk from Subclavian with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021P4KD" = "1" /* Bypass Pulmonary Trunk from Carotid with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021P4ZA" = "1" /* Bypass Pulmonary Trunk from Innominate Artery with No Device, Percutaneous Endoscopic Approach */
"021P4ZB" = "1" /* Bypass Pulmonary Trunk from Subclavian with No Device, Percutaneous Endoscopic Approach */
"021P4ZD" = "1" /* Bypass Pulmonary Trunk from Carotid with No Device, Percutaneous Endoscopic Approach */
"021Q08A" = "1" /* Bypass Right Pulmonary Artery from Innominate Artery with Zooplastic Tissue, Open Approach */
"021Q08B" = "1" /* Bypass Right Pulmonary Artery from Subclavian with Zooplastic Tissue, Open Approach */
"021Q08D" = "1" /* Bypass Right Pulmonary Artery from Carotid with Zooplastic Tissue, Open Approach */
"021Q09A" = "1" /* Bypass Right Pulmonary Artery from Innominate Artery with Autologous Venous Tissue, Open Approach */
"021Q09B" = "1" /* Bypass Right Pulmonary Artery from Subclavian with Autologous Venous Tissue, Open Approach */
"021Q09D" = "1" /* Bypass Right Pulmonary Artery from Carotid with Autologous Venous Tissue, Open Approach */
"021Q0AA" = "1" /* Bypass Right Pulmonary Artery from Innominate Artery with Autologous Arterial Tissue, Open Approach */
"021Q0AB" = "1" /* Bypass Right Pulmonary Artery from Subclavian with Autologous Arterial Tissue, Open Approach */
"021Q0AD" = "1" /* Bypass Right Pulmonary Artery from Carotid with Autologous Arterial Tissue, Open Approach */
"021Q0JA" = "1" /* Bypass Right Pulmonary Artery from Innominate Artery with Synthetic Substitute, Open Approach */
"021Q0JB" = "1" /* Bypass Right Pulmonary Artery from Subclavian with Synthetic Substitute, Open Approach */
"021Q0JD" = "1" /* Bypass Right Pulmonary Artery from Carotid with Synthetic Substitute, Open Approach */
"021Q0KA" = "1" /* Bypass Right Pulmonary Artery from Innominate Artery with Nonautologous Tissue Substitute, Open Approach */
"021Q0KB" = "1" /* Bypass Right Pulmonary Artery from Subclavian with Nonautologous Tissue Substitute, Open Approach */
"021Q0KD" = "1" /* Bypass Right Pulmonary Artery from Carotid with Nonautologous Tissue Substitute, Open Approach */
"021Q0ZA" = "1" /* Bypass Right Pulmonary Artery from Innominate Artery with No Device, Open Approach */
"021Q0ZB" = "1" /* Bypass Right Pulmonary Artery from Subclavian with No Device, Open Approach */
"021Q0ZD" = "1" /* Bypass Right Pulmonary Artery from Carotid with No Device, Open Approach */
"021Q48A" = "1" /* Bypass Right Pulmonary Artery from Innominate Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021Q48B" = "1" /* Bypass Right Pulmonary Artery from Subclavian with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021Q48D" = "1" /* Bypass Right Pulmonary Artery from Carotid with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021Q49A" = "1" /* Bypass Right Pulmonary Artery from Innominate Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021Q49B" = "1" /* Bypass Right Pulmonary Artery from Subclavian with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021Q49D" = "1" /* Bypass Right Pulmonary Artery from Carotid with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021Q4AA" = "1" /* Bypass Right Pulmonary Artery from Innominate Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021Q4AB" = "1" /* Bypass Right Pulmonary Artery from Subclavian with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021Q4AD" = "1" /* Bypass Right Pulmonary Artery from Carotid with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021Q4JA" = "1" /* Bypass Right Pulmonary Artery from Innominate Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021Q4JB" = "1" /* Bypass Right Pulmonary Artery from Subclavian with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021Q4JD" = "1" /* Bypass Right Pulmonary Artery from Carotid with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021Q4KA" = "1" /* Bypass Right Pulmonary Artery from Innominate Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021Q4KB" = "1" /* Bypass Right Pulmonary Artery from Subclavian with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021Q4KD" = "1" /* Bypass Right Pulmonary Artery from Carotid with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021Q4ZA" = "1" /* Bypass Right Pulmonary Artery from Innominate Artery with No Device, Percutaneous Endoscopic Approach */
"021Q4ZB" = "1" /* Bypass Right Pulmonary Artery from Subclavian with No Device, Percutaneous Endoscopic Approach */
"021Q4ZD" = "1" /* Bypass Right Pulmonary Artery from Carotid with No Device, Percutaneous Endoscopic Approach */
"021R08A" = "1" /* Bypass Left Pulmonary Artery from Innominate Artery with Zooplastic Tissue, Open Approach */
"021R08B" = "1" /* Bypass Left Pulmonary Artery from Subclavian with Zooplastic Tissue, Open Approach */
"021R08D" = "1" /* Bypass Left Pulmonary Artery from Carotid with Zooplastic Tissue, Open Approach */
"021R09A" = "1" /* Bypass Left Pulmonary Artery from Innominate Artery with Autologous Venous Tissue, Open Approach */
"021R09B" = "1" /* Bypass Left Pulmonary Artery from Subclavian with Autologous Venous Tissue, Open Approach */
"021R09D" = "1" /* Bypass Left Pulmonary Artery from Carotid with Autologous Venous Tissue, Open Approach */
"021R0AA" = "1" /* Bypass Left Pulmonary Artery from Innominate Artery with Autologous Arterial Tissue, Open Approach */
"021R0AB" = "1" /* Bypass Left Pulmonary Artery from Subclavian with Autologous Arterial Tissue, Open Approach */
"021R0AD" = "1" /* Bypass Left Pulmonary Artery from Carotid with Autologous Arterial Tissue, Open Approach */
"021R0JA" = "1" /* Bypass Left Pulmonary Artery from Innominate Artery with Synthetic Substitute, Open Approach */
"021R0JB" = "1" /* Bypass Left Pulmonary Artery from Subclavian with Synthetic Substitute, Open Approach */
"021R0JD" = "1" /* Bypass Left Pulmonary Artery from Carotid with Synthetic Substitute, Open Approach */
"021R0KA" = "1" /* Bypass Left Pulmonary Artery from Innominate Artery with Nonautologous Tissue Substitute, Open Approach */
"021R0KB" = "1" /* Bypass Left Pulmonary Artery from Subclavian with Nonautologous Tissue Substitute, Open Approach */
"021R0KD" = "1" /* Bypass Left Pulmonary Artery from Carotid with Nonautologous Tissue Substitute, Open Approach */
"021R0ZA" = "1" /* Bypass Left Pulmonary Artery from Innominate Artery with No Device, Open Approach */
"021R0ZB" = "1" /* Bypass Left Pulmonary Artery from Subclavian with No Device, Open Approach */
"021R0ZD" = "1" /* Bypass Left Pulmonary Artery from Carotid with No Device, Open Approach */
"021R48A" = "1" /* Bypass Left Pulmonary Artery from Innominate Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021R48B" = "1" /* Bypass Left Pulmonary Artery from Subclavian with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021R48D" = "1" /* Bypass Left Pulmonary Artery from Carotid with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021R49A" = "1" /* Bypass Left Pulmonary Artery from Innominate Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021R49B" = "1" /* Bypass Left Pulmonary Artery from Subclavian with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021R49D" = "1" /* Bypass Left Pulmonary Artery from Carotid with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021R4AA" = "1" /* Bypass Left Pulmonary Artery from Innominate Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021R4AB" = "1" /* Bypass Left Pulmonary Artery from Subclavian with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021R4AD" = "1" /* Bypass Left Pulmonary Artery from Carotid with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021R4JA" = "1" /* Bypass Left Pulmonary Artery from Innominate Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021R4JB" = "1" /* Bypass Left Pulmonary Artery from Subclavian with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021R4JD" = "1" /* Bypass Left Pulmonary Artery from Carotid with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021R4KA" = "1" /* Bypass Left Pulmonary Artery from Innominate Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021R4KB" = "1" /* Bypass Left Pulmonary Artery from Subclavian with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021R4KD" = "1" /* Bypass Left Pulmonary Artery from Carotid with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021R4ZA" = "1" /* Bypass Left Pulmonary Artery from Innominate Artery with No Device, Percutaneous Endoscopic Approach */
"021R4ZB" = "1" /* Bypass Left Pulmonary Artery from Subclavian with No Device, Percutaneous Endoscopic Approach */
"021R4ZD" = "1" /* Bypass Left Pulmonary Artery from Carotid with No Device, Percutaneous Endoscopic Approach */
"021V08P" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk with Zooplastic Tissue, Open Approach */
"021V08Q" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021V08R" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021V08S" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Vein with Zooplastic Tissue, Open Approach */
"021V08T" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Vein with Zooplastic Tissue, Open Approach */
"021V08U" = "1" /* Bypass Superior Vena Cava to Pulmonary Vein Confluence with Zooplastic Tissue, Open Approach */
"021V09P" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk with Autologous Venous Tissue, Open Approach */
"021V09Q" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021V09R" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021V09S" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Vein with Autologous Venous Tissue, Open Approach */
"021V09T" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Vein with Autologous Venous Tissue, Open Approach */
"021V09U" = "1" /* Bypass Superior Vena Cava to Pulmonary Vein Confluence with Autologous Venous Tissue, Open Approach */
"021V0AP" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk with Autologous Arterial Tissue, Open Approach */
"021V0AQ" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021V0AR" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021V0AS" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Vein with Autologous Arterial Tissue, Open Approach */
"021V0AT" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Vein with Autologous Arterial Tissue, Open Approach */
"021V0AU" = "1" /* Bypass Superior Vena Cava to Pulmonary Vein Confluence with Autologous Arterial Tissue, Open Approach */
"021V0JP" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk with Synthetic Substitute, Open Approach */
"021V0JQ" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"021V0JR" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"021V0JS" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Vein with Synthetic Substitute, Open Approach */
"021V0JT" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Vein with Synthetic Substitute, Open Approach */
"021V0JU" = "1" /* Bypass Superior Vena Cava to Pulmonary Vein Confluence with Synthetic Substitute, Open Approach */
"021V0KP" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk with Nonautologous Tissue Substitute, Open Approach */
"021V0KQ" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021V0KR" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021V0KS" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Vein with Nonautologous Tissue Substitute, Open Approach */
"021V0KT" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Vein with Nonautologous Tissue Substitute, Open Approach */
"021V0KU" = "1" /* Bypass Superior Vena Cava to Pulmonary Vein Confluence with Nonautologous Tissue Substitute, Open Approach */
"021V0ZP" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk, Open Approach */
"021V0ZQ" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery, Open Approach */
"021V0ZR" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery, Open Approach */
"021V0ZS" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Vein, Open Approach */
"021V0ZT" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Vein, Open Approach */
"021V0ZU" = "1" /* Bypass Superior Vena Cava to Pulmonary Vein Confluence, Open Approach */
"021V48P" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021V48Q" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021V48R" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021V48S" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Vein with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021V48T" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Vein with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021V48U" = "1" /* Bypass Superior Vena Cava to Pulmonary Vein Confluence with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021V49P" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021V49Q" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021V49R" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021V49S" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021V49T" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021V49U" = "1" /* Bypass Superior Vena Cava to Pulmonary Vein Confluence with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021V4AP" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021V4AQ" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021V4AR" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021V4AS" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021V4AT" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021V4AU" = "1" /* Bypass Superior Vena Cava to Pulmonary Vein Confluence with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021V4JP" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021V4JQ" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021V4JR" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021V4JS" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021V4JT" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021V4JU" = "1" /* Bypass Superior Vena Cava to Pulmonary Vein Confluence with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021V4KP" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021V4KQ" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021V4KR" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021V4KS" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021V4KT" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021V4KU" = "1" /* Bypass Superior Vena Cava to Pulmonary Vein Confluence with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021V4ZP" = "1" /* Bypass Superior Vena Cava to Pulmonary Trunk, Percutaneous Endoscopic Approach */
"021V4ZQ" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"021V4ZR" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"021V4ZS" = "1" /* Bypass Superior Vena Cava to Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"021V4ZT" = "1" /* Bypass Superior Vena Cava to Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"021V4ZU" = "1" /* Bypass Superior Vena Cava to Pulmonary Vein Confluence, Percutaneous Endoscopic Approach */
"021W08B" = "1" /* Bypass Thoracic Aorta, Descending to Subclavian with Zooplastic Tissue, Open Approach */
"021W08D" = "1" /* Bypass Thoracic Aorta, Descending to Carotid with Zooplastic Tissue, Open Approach */
"021W08P" = "1" /* Bypass Thoracic Aorta, Descending to Pulmonary Trunk with Zooplastic Tissue, Open Approach */
"021W08Q" = "1" /* Bypass Thoracic Aorta, Descending to Right Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021W08R" = "1" /* Bypass Thoracic Aorta, Descending to Left Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021W09B" = "1" /* Bypass Thoracic Aorta, Descending to Subclavian with Autologous Venous Tissue, Open Approach */
"021W09D" = "1" /* Bypass Thoracic Aorta, Descending to Carotid with Autologous Venous Tissue, Open Approach */
"021W09P" = "1" /* Bypass Thoracic Aorta, Descending to Pulmonary Trunk with Autologous Venous Tissue, Open Approach */
"021W09Q" = "1" /* Bypass Thoracic Aorta, Descending to Right Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021W09R" = "1" /* Bypass Thoracic Aorta, Descending to Left Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021W0AB" = "1" /* Bypass Thoracic Aorta, Descending to Subclavian with Autologous Arterial Tissue, Open Approach */
"021W0AD" = "1" /* Bypass Thoracic Aorta, Descending to Carotid with Autologous Arterial Tissue, Open Approach */
"021W0AP" = "1" /* Bypass Thoracic Aorta, Descending to Pulmonary Trunk with Autologous Arterial Tissue, Open Approach */
"021W0AQ" = "1" /* Bypass Thoracic Aorta, Descending to Right Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021W0AR" = "1" /* Bypass Thoracic Aorta, Descending to Left Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021W0JB" = "1" /* Bypass Thoracic Aorta, Descending to Subclavian with Synthetic Substitute, Open Approach */
"021W0JD" = "1" /* Bypass Thoracic Aorta, Descending to Carotid with Synthetic Substitute, Open Approach */
"021W0JP" = "1" /* Bypass Thoracic Aorta, Descending to Pulmonary Trunk with Synthetic Substitute, Open Approach */
"021W0JQ" = "1" /* Bypass Thoracic Aorta, Descending to Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"021W0JR" = "1" /* Bypass Thoracic Aorta, Descending to Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"021W0KB" = "1" /* Bypass Thoracic Aorta, Descending to Subclavian with Nonautologous Tissue Substitute, Open Approach */
"021W0KD" = "1" /* Bypass Thoracic Aorta, Descending to Carotid with Nonautologous Tissue Substitute, Open Approach */
"021W0KP" = "1" /* Bypass Thoracic Aorta, Descending to Pulmonary Trunk with Nonautologous Tissue Substitute, Open Approach */
"021W0KQ" = "1" /* Bypass Thoracic Aorta, Descending to Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021W0KR" = "1" /* Bypass Thoracic Aorta, Descending to Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021W0ZB" = "1" /* Bypass Thoracic Aorta, Descending to Subclavian, Open Approach */
"021W0ZD" = "1" /* Bypass Thoracic Aorta, Descending to Carotid, Open Approach */
"021W0ZP" = "1" /* Bypass Thoracic Aorta, Descending to Pulmonary Trunk, Open Approach */
"021W0ZQ" = "1" /* Bypass Thoracic Aorta, Descending to Right Pulmonary Artery, Open Approach */
"021W0ZR" = "1" /* Bypass Thoracic Aorta, Descending to Left Pulmonary Artery, Open Approach */
"021W48B" = "1" /* Bypass Thoracic Aorta, Descending to Subclavian with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021W48D" = "1" /* Bypass Thoracic Aorta, Descending to Carotid with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021W48P" = "1" /* Bypass Thoracic Aorta, Descending to Pulmonary Trunk with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021W48Q" = "1" /* Bypass Thoracic Aorta, Descending to Right Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021W48R" = "1" /* Bypass Thoracic Aorta, Descending to Left Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021W49B" = "1" /* Bypass Thoracic Aorta, Descending to Subclavian with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021W49D" = "1" /* Bypass Thoracic Aorta, Descending to Carotid with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021W49P" = "1" /* Bypass Thoracic Aorta, Descending to Pulmonary Trunk with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021W49Q" = "1" /* Bypass Thoracic Aorta, Descending to Right Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021W49R" = "1" /* Bypass Thoracic Aorta, Descending to Left Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021W4AB" = "1" /* Bypass Thoracic Aorta, Descending to Subclavian with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021W4AD" = "1" /* Bypass Thoracic Aorta, Descending to Carotid with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021W4AP" = "1" /* Bypass Thoracic Aorta, Descending to Pulmonary Trunk with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021W4AQ" = "1" /* Bypass Thoracic Aorta, Descending to Right Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021W4AR" = "1" /* Bypass Thoracic Aorta, Descending to Left Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021W4JB" = "1" /* Bypass Thoracic Aorta, Descending to Subclavian with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021W4JD" = "1" /* Bypass Thoracic Aorta, Descending to Carotid with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021W4JP" = "1" /* Bypass Thoracic Aorta, Descending to Pulmonary Trunk with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021W4JQ" = "1" /* Bypass Thoracic Aorta, Descending to Right Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021W4JR" = "1" /* Bypass Thoracic Aorta, Descending to Left Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021W4KB" = "1" /* Bypass Thoracic Aorta, Descending to Subclavian with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021W4KD" = "1" /* Bypass Thoracic Aorta, Descending to Carotid with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021W4KP" = "1" /* Bypass Thoracic Aorta, Descending to Pulmonary Trunk with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021W4KQ" = "1" /* Bypass Thoracic Aorta, Descending to Right Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021W4KR" = "1" /* Bypass Thoracic Aorta, Descending to Left Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021W4ZB" = "1" /* Bypass Thoracic Aorta, Descending to Subclavian, Percutaneous Endoscopic Approach */
"021W4ZD" = "1" /* Bypass Thoracic Aorta, Descending to Carotid, Percutaneous Endoscopic Approach */
"021W4ZP" = "1" /* Bypass Thoracic Aorta, Descending to Pulmonary Trunk, Percutaneous Endoscopic Approach */
"021W4ZQ" = "1" /* Bypass Thoracic Aorta, Descending to Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"021W4ZR" = "1" /* Bypass Thoracic Aorta, Descending to Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"021X08B" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian with Zooplastic Tissue, Open Approach */
"021X08D" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid with Zooplastic Tissue, Open Approach */
"021X08P" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk with Zooplastic Tissue, Open Approach */
"021X08Q" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021X08R" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021X09B" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian with Autologous Venous Tissue, Open Approach */
"021X09D" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid with Autologous Venous Tissue, Open Approach */
"021X09P" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk with Autologous Venous Tissue, Open Approach */
"021X09Q" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021X09R" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021X0AB" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian with Autologous Arterial Tissue, Open Approach */
"021X0AD" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid with Autologous Arterial Tissue, Open Approach */
"021X0AP" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk with Autologous Arterial Tissue, Open Approach */
"021X0AQ" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021X0AR" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021X0JB" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian with Synthetic Substitute, Open Approach */
"021X0JD" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid with Synthetic Substitute, Open Approach */
"021X0JP" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk with Synthetic Substitute, Open Approach */
"021X0JQ" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"021X0JR" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"021X0KB" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian with Nonautologous Tissue Substitute, Open Approach */
"021X0KD" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid with Nonautologous Tissue Substitute, Open Approach */
"021X0KP" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk with Nonautologous Tissue Substitute, Open Approach */
"021X0KQ" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021X0KR" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021X0ZB" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian, Open Approach */
"021X0ZD" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid, Open Approach */
"021X0ZP" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk, Open Approach */
"021X0ZQ" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery, Open Approach */
"021X0ZR" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery, Open Approach */
"021X48B" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021X48D" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021X48P" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021X48Q" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021X48R" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021X49B" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021X49D" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021X49P" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021X49Q" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021X49R" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021X4AB" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021X4AD" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021X4AP" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021X4AQ" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021X4AR" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021X4JB" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021X4JD" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021X4JP" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021X4JQ" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021X4JR" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021X4KB" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021X4KD" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021X4KP" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021X4KQ" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021X4KR" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021X4ZB" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Subclavian, Percutaneous Endoscopic Approach */
"021X4ZD" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Carotid, Percutaneous Endoscopic Approach */
"021X4ZP" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Pulmonary Trunk, Percutaneous Endoscopic Approach */
"021X4ZQ" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"021X4ZR" = "1" /* Bypass Thoracic Aorta, Ascending/Arch to Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"024F07J" = "1" /* Creation of Aortic Valve from Truncal Valve using Autologous Tissue Substitute, Open Approach */
"024F08J" = "1" /* Creation of Aortic Valve from Truncal Valve using Zooplastic Tissue, Open Approach */
"024F0JJ" = "1" /* Creation of Aortic Valve from Truncal Valve using Synthetic Substitute, Open Approach */
"024F0KJ" = "1" /* Creation of Aortic Valve from Truncal Valve using Nonautologous Tissue Substitute, Open Approach */
"024G072" = "1" /* Creation of Mitral Valve from Common Atrioventricular Valve using Autologous Tissue Substitute, Open Approach */
"024G082" = "1" /* Creation of Mitral Valve from Common Atrioventricular Valve using Zooplastic Tissue, Open Approach */
"024G0J2" = "1" /* Creation of Mitral Valve from Common Atrioventricular Valve using Synthetic Substitute, Open Approach */
"024G0K2" = "1" /* Creation of Mitral Valve from Common Atrioventricular Valve using Nonautologous Tissue Substitute, Open Approach */
"024J072" = "1" /* Creation of Tricuspid Valve from Common Atrioventricular Valve using Autologous Tissue Substitute, Open Approach */
"024J082" = "1" /* Creation of Tricuspid Valve from Common Atrioventricular Valve using Zooplastic Tissue, Open Approach */
"024J0J2" = "1" /* Creation of Tricuspid Valve from Common Atrioventricular Valve using Synthetic Substitute, Open Approach */
"024J0K2" = "1" /* Creation of Tricuspid Valve from Common Atrioventricular Valve using Nonautologous Tissue Substitute, Open Approach */
"02540ZZ" = "1" /* Destruction of Coronary Vein, Open Approach */
"02543ZZ" = "1" /* Destruction of Coronary Vein, Percutaneous Approach */
"02544ZZ" = "1" /* Destruction of Coronary Vein, Percutaneous Endoscopic Approach */
"02550ZZ" = "1" /* Destruction of Atrial Septum, Open Approach */
"02553ZZ" = "1" /* Destruction of Atrial Septum, Percutaneous Approach */
"02554ZZ" = "1" /* Destruction of Atrial Septum, Percutaneous Endoscopic Approach */
"02560ZZ" = "1" /* Destruction of Right Atrium, Open Approach */
"02563ZZ" = "1" /* Destruction of Right Atrium, Percutaneous Approach */
"02564ZZ" = "1" /* Destruction of Right Atrium, Percutaneous Endoscopic Approach */
"02570ZZ" = "1" /* Destruction of Left Atrium, Open Approach */
"02573ZZ" = "1" /* Destruction of Left Atrium, Percutaneous Approach */
"02574ZZ" = "1" /* Destruction of Left Atrium, Percutaneous Endoscopic Approach */
"02580ZZ" = "1" /* Destruction of Conduction Mechanism, Open Approach */
"02583ZZ" = "1" /* Destruction of Conduction Mechanism, Percutaneous Approach */
"02584ZZ" = "1" /* Destruction of Conduction Mechanism, Percutaneous Endoscopic Approach */
"02590ZZ" = "1" /* Destruction of Chordae Tendineae, Open Approach */
"02593ZZ" = "1" /* Destruction of Chordae Tendineae, Percutaneous Approach */
"02594ZZ" = "1" /* Destruction of Chordae Tendineae, Percutaneous Endoscopic Approach */
"025D0ZZ" = "1" /* Destruction of Papillary Muscle, Open Approach */
"025D3ZZ" = "1" /* Destruction of Papillary Muscle, Percutaneous Approach */
"025D4ZZ" = "1" /* Destruction of Papillary Muscle, Percutaneous Endoscopic Approach */
"025F0ZZ" = "1" /* Destruction of Aortic Valve, Open Approach */
"025F3ZZ" = "1" /* Destruction of Aortic Valve, Percutaneous Approach */
"025F4ZZ" = "1" /* Destruction of Aortic Valve, Percutaneous Endoscopic Approach */
"025G0ZZ" = "1" /* Destruction of Mitral Valve, Open Approach */
"025G3ZZ" = "1" /* Destruction of Mitral Valve, Percutaneous Approach */
"025G4ZZ" = "1" /* Destruction of Mitral Valve, Percutaneous Endoscopic Approach */
"025H0ZZ" = "1" /* Destruction of Pulmonary Valve, Open Approach */
"025H3ZZ" = "1" /* Destruction of Pulmonary Valve, Percutaneous Approach */
"025H4ZZ" = "1" /* Destruction of Pulmonary Valve, Percutaneous Endoscopic Approach */
"025J0ZZ" = "1" /* Destruction of Tricuspid Valve, Open Approach */
"025J3ZZ" = "1" /* Destruction of Tricuspid Valve, Percutaneous Approach */
"025J4ZZ" = "1" /* Destruction of Tricuspid Valve, Percutaneous Endoscopic Approach */
"025K0ZZ" = "1" /* Destruction of Right Ventricle, Open Approach */
"025K3ZZ" = "1" /* Destruction of Right Ventricle, Percutaneous Approach */
"025K4ZZ" = "1" /* Destruction of Right Ventricle, Percutaneous Endoscopic Approach */
"025L0ZZ" = "1" /* Destruction of Left Ventricle, Open Approach */
"025L3ZZ" = "1" /* Destruction of Left Ventricle, Percutaneous Approach */
"025L4ZZ" = "1" /* Destruction of Left Ventricle, Percutaneous Endoscopic Approach */
"025M0ZZ" = "1" /* Destruction of Ventricular Septum, Open Approach */
"025M3ZZ" = "1" /* Destruction of Ventricular Septum, Percutaneous Approach */
"025M4ZZ" = "1" /* Destruction of Ventricular Septum, Percutaneous Endoscopic Approach */
"025N0ZZ" = "1" /* Destruction of Pericardium, Open Approach */
"025N3ZZ" = "1" /* Destruction of Pericardium, Percutaneous Approach */
"025N4ZZ" = "1" /* Destruction of Pericardium, Percutaneous Endoscopic Approach */
"025P0ZZ" = "1" /* Destruction of Pulmonary Trunk, Open Approach */
"025P3ZZ" = "1" /* Destruction of Pulmonary Trunk, Percutaneous Approach */
"025P4ZZ" = "1" /* Destruction of Pulmonary Trunk, Percutaneous Endoscopic Approach */
"025Q0ZZ" = "1" /* Destruction of Right Pulmonary Artery, Open Approach */
"025Q3ZZ" = "1" /* Destruction of Right Pulmonary Artery, Percutaneous Approach */
"025Q4ZZ" = "1" /* Destruction of Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"025R0ZZ" = "1" /* Destruction of Left Pulmonary Artery, Open Approach */
"025R3ZZ" = "1" /* Destruction of Left Pulmonary Artery, Percutaneous Approach */
"025R4ZZ" = "1" /* Destruction of Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"025S0ZZ" = "1" /* Destruction of Right Pulmonary Vein, Open Approach */
"025S3ZZ" = "1" /* Destruction of Right Pulmonary Vein, Percutaneous Approach */
"025S4ZZ" = "1" /* Destruction of Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"025T0ZZ" = "1" /* Destruction of Left Pulmonary Vein, Open Approach */
"025T3ZZ" = "1" /* Destruction of Left Pulmonary Vein, Percutaneous Approach */
"025T4ZZ" = "1" /* Destruction of Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"025V0ZZ" = "1" /* Destruction of Superior Vena Cava, Open Approach */
"025V3ZZ" = "1" /* Destruction of Superior Vena Cava, Percutaneous Approach */
"025V4ZZ" = "1" /* Destruction of Superior Vena Cava, Percutaneous Endoscopic Approach */
"025W0ZZ" = "1" /* Destruction of Thoracic Aorta, Descending, Open Approach */
"025W3ZZ" = "1" /* Destruction of Thoracic Aorta, Descending, Percutaneous Approach */
"025W4ZZ" = "1" /* Destruction of Thoracic Aorta, Descending, Percutaneous Endoscopic Approach */
"025X0ZZ" = "1" /* Destruction of Thoracic Aorta, Ascending/Arch, Open Approach */
"025X3ZZ" = "1" /* Destruction of Thoracic Aorta, Ascending/Arch, Percutaneous Approach */
"025X4ZZ" = "1" /* Destruction of Thoracic Aorta, Ascending/Arch, Percutaneous Endoscopic Approach */
"0270046" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"027004Z" = "1" /* Dilation of Coronary Artery, One Artery with Drug-eluting Intraluminal Device, Open Approach */
"0270056" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"027005Z" = "1" /* Dilation of Coronary Artery, One Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0270066" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"027006Z" = "1" /* Dilation of Coronary Artery, One Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0270076" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"027007Z" = "1" /* Dilation of Coronary Artery, One Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"02700D6" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Intraluminal Device, Open Approach */
"02700DZ" = "1" /* Dilation of Coronary Artery, One Artery with Intraluminal Device, Open Approach */
"02700E6" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"02700EZ" = "1" /* Dilation of Coronary Artery, One Artery with Two Intraluminal Devices, Open Approach */
"02700F6" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"02700FZ" = "1" /* Dilation of Coronary Artery, One Artery with Three Intraluminal Devices, Open Approach */
"02700G6" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"02700GZ" = "1" /* Dilation of Coronary Artery, One Artery with Four or More Intraluminal Devices, Open Approach */
"02700T6" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Radioactive Intraluminal Device, Open Approach */
"02700TZ" = "1" /* Dilation of Coronary Artery, One Artery with Radioactive Intraluminal Device, Open Approach */
"02700Z6" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, Open Approach */
"02700ZZ" = "1" /* Dilation of Coronary Artery, One Artery, Open Approach */
"0270346" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027034Z" = "1" /* Dilation of Coronary Artery, One Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0270356" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027035Z" = "1" /* Dilation of Coronary Artery, One Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0270366" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027036Z" = "1" /* Dilation of Coronary Artery, One Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0270376" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027037Z" = "1" /* Dilation of Coronary Artery, One Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"02703D6" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"02703DZ" = "1" /* Dilation of Coronary Artery, One Artery with Intraluminal Device, Percutaneous Approach */
"02703E6" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"02703EZ" = "1" /* Dilation of Coronary Artery, One Artery with Two Intraluminal Devices, Percutaneous Approach */
"02703F6" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"02703FZ" = "1" /* Dilation of Coronary Artery, One Artery with Three Intraluminal Devices, Percutaneous Approach */
"02703G6" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"02703GZ" = "1" /* Dilation of Coronary Artery, One Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"02703T6" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Approach */
"02703TZ" = "1" /* Dilation of Coronary Artery, One Artery with Radioactive Intraluminal Device, Percutaneous Approach */
"02703Z6" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, Percutaneous Approach */
"02703ZZ" = "1" /* Dilation of Coronary Artery, One Artery, Percutaneous Approach */
"0270446" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027044Z" = "1" /* Dilation of Coronary Artery, One Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0270456" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027045Z" = "1" /* Dilation of Coronary Artery, One Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0270466" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027046Z" = "1" /* Dilation of Coronary Artery, One Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0270476" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027047Z" = "1" /* Dilation of Coronary Artery, One Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"02704D6" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"02704DZ" = "1" /* Dilation of Coronary Artery, One Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"02704E6" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02704EZ" = "1" /* Dilation of Coronary Artery, One Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02704F6" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02704FZ" = "1" /* Dilation of Coronary Artery, One Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02704G6" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"02704GZ" = "1" /* Dilation of Coronary Artery, One Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"02704T6" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02704TZ" = "1" /* Dilation of Coronary Artery, One Artery with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02704Z6" = "1" /* Dilation of Coronary Artery, One Artery, Bifurcation, Percutaneous Endoscopic Approach */
"02704ZZ" = "1" /* Dilation of Coronary Artery, One Artery, Percutaneous Endoscopic Approach */
"0271046" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"027104Z" = "1" /* Dilation of Coronary Artery, Two Arteries with Drug-eluting Intraluminal Device, Open Approach */
"0271056" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"027105Z" = "1" /* Dilation of Coronary Artery, Two Arteries with Two Drug-eluting Intraluminal Devices, Open Approach */
"0271066" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"027106Z" = "1" /* Dilation of Coronary Artery, Two Arteries with Three Drug-eluting Intraluminal Devices, Open Approach */
"0271076" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"027107Z" = "1" /* Dilation of Coronary Artery, Two Arteries with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"02710D6" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Intraluminal Device, Open Approach */
"02710DZ" = "1" /* Dilation of Coronary Artery, Two Arteries with Intraluminal Device, Open Approach */
"02710E6" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Two Intraluminal Devices, Open Approach */
"02710EZ" = "1" /* Dilation of Coronary Artery, Two Arteries with Two Intraluminal Devices, Open Approach */
"02710F6" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Three Intraluminal Devices, Open Approach */
"02710FZ" = "1" /* Dilation of Coronary Artery, Two Arteries with Three Intraluminal Devices, Open Approach */
"02710G6" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"02710GZ" = "1" /* Dilation of Coronary Artery, Two Arteries with Four or More Intraluminal Devices, Open Approach */
"02710T6" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Radioactive Intraluminal Device, Open Approach */
"02710TZ" = "1" /* Dilation of Coronary Artery, Two Arteries with Radioactive Intraluminal Device, Open Approach */
"02710Z6" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, Open Approach */
"02710ZZ" = "1" /* Dilation of Coronary Artery, Two Arteries, Open Approach */
"0271346" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027134Z" = "1" /* Dilation of Coronary Artery, Two Arteries with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0271356" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027135Z" = "1" /* Dilation of Coronary Artery, Two Arteries with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0271366" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027136Z" = "1" /* Dilation of Coronary Artery, Two Arteries with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0271376" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027137Z" = "1" /* Dilation of Coronary Artery, Two Arteries with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"02713D6" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"02713DZ" = "1" /* Dilation of Coronary Artery, Two Arteries with Intraluminal Device, Percutaneous Approach */
"02713E6" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"02713EZ" = "1" /* Dilation of Coronary Artery, Two Arteries with Two Intraluminal Devices, Percutaneous Approach */
"02713F6" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"02713FZ" = "1" /* Dilation of Coronary Artery, Two Arteries with Three Intraluminal Devices, Percutaneous Approach */
"02713G6" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"02713GZ" = "1" /* Dilation of Coronary Artery, Two Arteries with Four or More Intraluminal Devices, Percutaneous Approach */
"02713T6" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Approach */
"02713TZ" = "1" /* Dilation of Coronary Artery, Two Arteries with Radioactive Intraluminal Device, Percutaneous Approach */
"02713Z6" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, Percutaneous Approach */
"02713ZZ" = "1" /* Dilation of Coronary Artery, Two Arteries, Percutaneous Approach */
"0271446" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027144Z" = "1" /* Dilation of Coronary Artery, Two Arteries with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0271456" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027145Z" = "1" /* Dilation of Coronary Artery, Two Arteries with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0271466" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027146Z" = "1" /* Dilation of Coronary Artery, Two Arteries with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0271476" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027147Z" = "1" /* Dilation of Coronary Artery, Two Arteries with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"02714D6" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"02714DZ" = "1" /* Dilation of Coronary Artery, Two Arteries with Intraluminal Device, Percutaneous Endoscopic Approach */
"02714E6" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02714EZ" = "1" /* Dilation of Coronary Artery, Two Arteries with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02714F6" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02714FZ" = "1" /* Dilation of Coronary Artery, Two Arteries with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02714G6" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"02714GZ" = "1" /* Dilation of Coronary Artery, Two Arteries with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"02714T6" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02714TZ" = "1" /* Dilation of Coronary Artery, Two Arteries with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02714Z6" = "1" /* Dilation of Coronary Artery, Two Arteries, Bifurcation, Percutaneous Endoscopic Approach */
"02714ZZ" = "1" /* Dilation of Coronary Artery, Two Arteries, Percutaneous Endoscopic Approach */
"0272046" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"027204Z" = "1" /* Dilation of Coronary Artery, Three Arteries with Drug-eluting Intraluminal Device, Open Approach */
"0272056" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"027205Z" = "1" /* Dilation of Coronary Artery, Three Arteries with Two Drug-eluting Intraluminal Devices, Open Approach */
"0272066" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"027206Z" = "1" /* Dilation of Coronary Artery, Three Arteries with Three Drug-eluting Intraluminal Devices, Open Approach */
"0272076" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"027207Z" = "1" /* Dilation of Coronary Artery, Three Arteries with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"02720D6" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Intraluminal Device, Open Approach */
"02720DZ" = "1" /* Dilation of Coronary Artery, Three Arteries with Intraluminal Device, Open Approach */
"02720E6" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Two Intraluminal Devices, Open Approach */
"02720EZ" = "1" /* Dilation of Coronary Artery, Three Arteries with Two Intraluminal Devices, Open Approach */
"02720F6" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Three Intraluminal Devices, Open Approach */
"02720FZ" = "1" /* Dilation of Coronary Artery, Three Arteries with Three Intraluminal Devices, Open Approach */
"02720G6" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"02720GZ" = "1" /* Dilation of Coronary Artery, Three Arteries with Four or More Intraluminal Devices, Open Approach */
"02720T6" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Radioactive Intraluminal Device, Open Approach */
"02720TZ" = "1" /* Dilation of Coronary Artery, Three Arteries with Radioactive Intraluminal Device, Open Approach */
"02720Z6" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, Open Approach */
"02720ZZ" = "1" /* Dilation of Coronary Artery, Three Arteries, Open Approach */
"0272346" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027234Z" = "1" /* Dilation of Coronary Artery, Three Arteries with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0272356" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027235Z" = "1" /* Dilation of Coronary Artery, Three Arteries with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0272366" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027236Z" = "1" /* Dilation of Coronary Artery, Three Arteries with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0272376" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027237Z" = "1" /* Dilation of Coronary Artery, Three Arteries with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"02723D6" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"02723DZ" = "1" /* Dilation of Coronary Artery, Three Arteries with Intraluminal Device, Percutaneous Approach */
"02723E6" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"02723EZ" = "1" /* Dilation of Coronary Artery, Three Arteries with Two Intraluminal Devices, Percutaneous Approach */
"02723F6" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"02723FZ" = "1" /* Dilation of Coronary Artery, Three Arteries with Three Intraluminal Devices, Percutaneous Approach */
"02723G6" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"02723GZ" = "1" /* Dilation of Coronary Artery, Three Arteries with Four or More Intraluminal Devices, Percutaneous Approach */
"02723T6" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Approach */
"02723TZ" = "1" /* Dilation of Coronary Artery, Three Arteries with Radioactive Intraluminal Device, Percutaneous Approach */
"02723Z6" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, Percutaneous Approach */
"02723ZZ" = "1" /* Dilation of Coronary Artery, Three Arteries, Percutaneous Approach */
"0272446" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027244Z" = "1" /* Dilation of Coronary Artery, Three Arteries with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0272456" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027245Z" = "1" /* Dilation of Coronary Artery, Three Arteries with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0272466" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027246Z" = "1" /* Dilation of Coronary Artery, Three Arteries with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0272476" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027247Z" = "1" /* Dilation of Coronary Artery, Three Arteries with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"02724D6" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"02724DZ" = "1" /* Dilation of Coronary Artery, Three Arteries with Intraluminal Device, Percutaneous Endoscopic Approach */
"02724E6" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02724EZ" = "1" /* Dilation of Coronary Artery, Three Arteries with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02724F6" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02724FZ" = "1" /* Dilation of Coronary Artery, Three Arteries with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02724G6" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"02724GZ" = "1" /* Dilation of Coronary Artery, Three Arteries with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"02724T6" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02724TZ" = "1" /* Dilation of Coronary Artery, Three Arteries with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02724Z6" = "1" /* Dilation of Coronary Artery, Three Arteries, Bifurcation, Percutaneous Endoscopic Approach */
"02724ZZ" = "1" /* Dilation of Coronary Artery, Three Arteries, Percutaneous Endoscopic Approach */
"0273046" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"027304Z" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Drug-eluting Intraluminal Device, Open Approach */
"0273056" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"027305Z" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Two Drug-eluting Intraluminal Devices, Open Approach */
"0273066" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"027306Z" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Three Drug-eluting Intraluminal Devices, Open Approach */
"0273076" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"027307Z" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"02730D6" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Intraluminal Device, Open Approach */
"02730DZ" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Intraluminal Device, Open Approach */
"02730E6" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Two Intraluminal Devices, Open Approach */
"02730EZ" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Two Intraluminal Devices, Open Approach */
"02730F6" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Three Intraluminal Devices, Open Approach */
"02730FZ" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Three Intraluminal Devices, Open Approach */
"02730G6" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"02730GZ" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Four or More Intraluminal Devices, Open Approach */
"02730T6" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Radioactive Intraluminal Device, Open Approach */
"02730TZ" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Radioactive Intraluminal Device, Open Approach */
"02730Z6" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, Open Approach */
"02730ZZ" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Open Approach */
"0273346" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027334Z" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0273356" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027335Z" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0273366" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027336Z" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0273376" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027337Z" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"02733D6" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"02733DZ" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Intraluminal Device, Percutaneous Approach */
"02733E6" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"02733EZ" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Two Intraluminal Devices, Percutaneous Approach */
"02733F6" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"02733FZ" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Three Intraluminal Devices, Percutaneous Approach */
"02733G6" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"02733GZ" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Four or More Intraluminal Devices, Percutaneous Approach */
"02733T6" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Approach */
"02733TZ" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Radioactive Intraluminal Device, Percutaneous Approach */
"02733Z6" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, Percutaneous Approach */
"02733ZZ" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Percutaneous Approach */
"0273446" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027344Z" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0273456" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027345Z" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0273466" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027346Z" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0273476" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027347Z" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"02734D6" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"02734DZ" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Intraluminal Device, Percutaneous Endoscopic Approach */
"02734E6" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02734EZ" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02734F6" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02734FZ" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02734G6" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"02734GZ" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"02734T6" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02734TZ" = "1" /* Dilation of Coronary Artery, Four or More Arteries with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02734Z6" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Bifurcation, Percutaneous Endoscopic Approach */
"02734ZZ" = "1" /* Dilation of Coronary Artery, Four or More Arteries, Percutaneous Endoscopic Approach */
"027F04Z" = "1" /* Dilation of Aortic Valve with Drug-eluting Intraluminal Device, Open Approach */
"027F0DZ" = "1" /* Dilation of Aortic Valve with Intraluminal Device, Open Approach */
"027F0ZZ" = "1" /* Dilation of Aortic Valve, Open Approach */
"027F34Z" = "1" /* Dilation of Aortic Valve with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027F3DZ" = "1" /* Dilation of Aortic Valve with Intraluminal Device, Percutaneous Approach */
"027F3ZZ" = "1" /* Dilation of Aortic Valve, Percutaneous Approach */
"027F44Z" = "1" /* Dilation of Aortic Valve with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027F4DZ" = "1" /* Dilation of Aortic Valve with Intraluminal Device, Percutaneous Endoscopic Approach */
"027F4ZZ" = "1" /* Dilation of Aortic Valve, Percutaneous Endoscopic Approach */
"027G04Z" = "1" /* Dilation of Mitral Valve with Drug-eluting Intraluminal Device, Open Approach */
"027G0DZ" = "1" /* Dilation of Mitral Valve with Intraluminal Device, Open Approach */
"027G0ZZ" = "1" /* Dilation of Mitral Valve, Open Approach */
"027G34Z" = "1" /* Dilation of Mitral Valve with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027G3DZ" = "1" /* Dilation of Mitral Valve with Intraluminal Device, Percutaneous Approach */
"027G3ZZ" = "1" /* Dilation of Mitral Valve, Percutaneous Approach */
"027G44Z" = "1" /* Dilation of Mitral Valve with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027G4DZ" = "1" /* Dilation of Mitral Valve with Intraluminal Device, Percutaneous Endoscopic Approach */
"027G4ZZ" = "1" /* Dilation of Mitral Valve, Percutaneous Endoscopic Approach */
"027H04Z" = "1" /* Dilation of Pulmonary Valve with Drug-eluting Intraluminal Device, Open Approach */
"027H0DZ" = "1" /* Dilation of Pulmonary Valve with Intraluminal Device, Open Approach */
"027H0ZZ" = "1" /* Dilation of Pulmonary Valve, Open Approach */
"027H34Z" = "1" /* Dilation of Pulmonary Valve with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027H3DZ" = "1" /* Dilation of Pulmonary Valve with Intraluminal Device, Percutaneous Approach */
"027H3ZZ" = "1" /* Dilation of Pulmonary Valve, Percutaneous Approach */
"027H44Z" = "1" /* Dilation of Pulmonary Valve with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027H4DZ" = "1" /* Dilation of Pulmonary Valve with Intraluminal Device, Percutaneous Endoscopic Approach */
"027H4ZZ" = "1" /* Dilation of Pulmonary Valve, Percutaneous Endoscopic Approach */
"027J04Z" = "1" /* Dilation of Tricuspid Valve with Drug-eluting Intraluminal Device, Open Approach */
"027J0DZ" = "1" /* Dilation of Tricuspid Valve with Intraluminal Device, Open Approach */
"027J0ZZ" = "1" /* Dilation of Tricuspid Valve, Open Approach */
"027J34Z" = "1" /* Dilation of Tricuspid Valve with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027J3DZ" = "1" /* Dilation of Tricuspid Valve with Intraluminal Device, Percutaneous Approach */
"027J3ZZ" = "1" /* Dilation of Tricuspid Valve, Percutaneous Approach */
"027J44Z" = "1" /* Dilation of Tricuspid Valve with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027J4DZ" = "1" /* Dilation of Tricuspid Valve with Intraluminal Device, Percutaneous Endoscopic Approach */
"027J4ZZ" = "1" /* Dilation of Tricuspid Valve, Percutaneous Endoscopic Approach */
"027K04Z" = "1" /* Dilation of Right Ventricle with Drug-eluting Intraluminal Device, Open Approach */
"027K0DZ" = "1" /* Dilation of Right Ventricle with Intraluminal Device, Open Approach */
"027K0ZZ" = "1" /* Dilation of Right Ventricle, Open Approach */
"027K34Z" = "1" /* Dilation of Right Ventricle with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027K3DZ" = "1" /* Dilation of Right Ventricle with Intraluminal Device, Percutaneous Approach */
"027K3ZZ" = "1" /* Dilation of Right Ventricle, Percutaneous Approach */
"027K44Z" = "1" /* Dilation of Right Ventricle with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027K4DZ" = "1" /* Dilation of Right Ventricle with Intraluminal Device, Percutaneous Endoscopic Approach */
"027K4ZZ" = "1" /* Dilation of Right Ventricle, Percutaneous Endoscopic Approach */
"027P04Z" = "1" /* Dilation of Pulmonary Trunk with Drug-eluting Intraluminal Device, Open Approach */
"027P0DZ" = "1" /* Dilation of Pulmonary Trunk with Intraluminal Device, Open Approach */
"027P0ZZ" = "1" /* Dilation of Pulmonary Trunk, Open Approach */
"027P34Z" = "1" /* Dilation of Pulmonary Trunk with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027P3DZ" = "1" /* Dilation of Pulmonary Trunk with Intraluminal Device, Percutaneous Approach */
"027P3ZZ" = "1" /* Dilation of Pulmonary Trunk, Percutaneous Approach */
"027P44Z" = "1" /* Dilation of Pulmonary Trunk with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027P4DZ" = "1" /* Dilation of Pulmonary Trunk with Intraluminal Device, Percutaneous Endoscopic Approach */
"027P4ZZ" = "1" /* Dilation of Pulmonary Trunk, Percutaneous Endoscopic Approach */
"027Q04Z" = "1" /* Dilation of Right Pulmonary Artery with Drug-eluting Intraluminal Device, Open Approach */
"027Q0DZ" = "1" /* Dilation of Right Pulmonary Artery with Intraluminal Device, Open Approach */
"027Q0ZZ" = "1" /* Dilation of Right Pulmonary Artery, Open Approach */
"027Q34Z" = "1" /* Dilation of Right Pulmonary Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027Q3DZ" = "1" /* Dilation of Right Pulmonary Artery with Intraluminal Device, Percutaneous Approach */
"027Q3ZZ" = "1" /* Dilation of Right Pulmonary Artery, Percutaneous Approach */
"027Q44Z" = "1" /* Dilation of Right Pulmonary Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027Q4DZ" = "1" /* Dilation of Right Pulmonary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"027Q4ZZ" = "1" /* Dilation of Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"027R04T" = "1" /* Dilation of Ductus Arteriosus with Drug-eluting Intraluminal Device, Open Approach */
"027R04Z" = "1" /* Dilation of Left Pulmonary Artery with Drug-eluting Intraluminal Device, Open Approach */
"027R0DT" = "1" /* Dilation of Ductus Arteriosus with Intraluminal Device, Open Approach */
"027R0DZ" = "1" /* Dilation of Left Pulmonary Artery with Intraluminal Device, Open Approach */
"027R0ZT" = "1" /* Dilation of Ductus Arteriosus, Open Approach */
"027R0ZZ" = "1" /* Dilation of Left Pulmonary Artery, Open Approach */
"027R34T" = "1" /* Dilation of Ductus Arteriosus with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027R34Z" = "1" /* Dilation of Left Pulmonary Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027R3DT" = "1" /* Dilation of Ductus Arteriosus with Intraluminal Device, Percutaneous Approach */
"027R3DZ" = "1" /* Dilation of Left Pulmonary Artery with Intraluminal Device, Percutaneous Approach */
"027R3ZT" = "1" /* Dilation of Ductus Arteriosus, Percutaneous Approach */
"027R3ZZ" = "1" /* Dilation of Left Pulmonary Artery, Percutaneous Approach */
"027R44T" = "1" /* Dilation of Ductus Arteriosus with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027R44Z" = "1" /* Dilation of Left Pulmonary Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027R4DT" = "1" /* Dilation of Ductus Arteriosus with Intraluminal Device, Percutaneous Endoscopic Approach */
"027R4DZ" = "1" /* Dilation of Left Pulmonary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"027R4ZT" = "1" /* Dilation of Ductus Arteriosus, Percutaneous Endoscopic Approach */
"027R4ZZ" = "1" /* Dilation of Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"027S04Z" = "1" /* Dilation of Right Pulmonary Vein with Drug-eluting Intraluminal Device, Open Approach */
"027S0DZ" = "1" /* Dilation of Right Pulmonary Vein with Intraluminal Device, Open Approach */
"027S0ZZ" = "1" /* Dilation of Right Pulmonary Vein, Open Approach */
"027S34Z" = "1" /* Dilation of Right Pulmonary Vein with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027S3DZ" = "1" /* Dilation of Right Pulmonary Vein with Intraluminal Device, Percutaneous Approach */
"027S3ZZ" = "1" /* Dilation of Right Pulmonary Vein, Percutaneous Approach */
"027S44Z" = "1" /* Dilation of Right Pulmonary Vein with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027S4DZ" = "1" /* Dilation of Right Pulmonary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"027S4ZZ" = "1" /* Dilation of Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"027T04Z" = "1" /* Dilation of Left Pulmonary Vein with Drug-eluting Intraluminal Device, Open Approach */
"027T0DZ" = "1" /* Dilation of Left Pulmonary Vein with Intraluminal Device, Open Approach */
"027T0ZZ" = "1" /* Dilation of Left Pulmonary Vein, Open Approach */
"027T34Z" = "1" /* Dilation of Left Pulmonary Vein with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027T3DZ" = "1" /* Dilation of Left Pulmonary Vein with Intraluminal Device, Percutaneous Approach */
"027T3ZZ" = "1" /* Dilation of Left Pulmonary Vein, Percutaneous Approach */
"027T44Z" = "1" /* Dilation of Left Pulmonary Vein with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027T4DZ" = "1" /* Dilation of Left Pulmonary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"027T4ZZ" = "1" /* Dilation of Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"027V04Z" = "1" /* Dilation of Superior Vena Cava with Drug-eluting Intraluminal Device, Open Approach */
"027V0DZ" = "1" /* Dilation of Superior Vena Cava with Intraluminal Device, Open Approach */
"027V0ZZ" = "1" /* Dilation of Superior Vena Cava, Open Approach */
"027V34Z" = "1" /* Dilation of Superior Vena Cava with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027V3DZ" = "1" /* Dilation of Superior Vena Cava with Intraluminal Device, Percutaneous Approach */
"027V3ZZ" = "1" /* Dilation of Superior Vena Cava, Percutaneous Approach */
"027V44Z" = "1" /* Dilation of Superior Vena Cava with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027V4DZ" = "1" /* Dilation of Superior Vena Cava with Intraluminal Device, Percutaneous Endoscopic Approach */
"027V4ZZ" = "1" /* Dilation of Superior Vena Cava, Percutaneous Endoscopic Approach */
"027W04Z" = "1" /* Dilation of Thoracic Aorta, Descending with Drug-eluting Intraluminal Device, Open Approach */
"027W0DZ" = "1" /* Dilation of Thoracic Aorta, Descending with Intraluminal Device, Open Approach */
"027W0ZZ" = "1" /* Dilation of Thoracic Aorta, Descending, Open Approach */
"027W34Z" = "1" /* Dilation of Thoracic Aorta, Descending with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027W3DZ" = "1" /* Dilation of Thoracic Aorta, Descending with Intraluminal Device, Percutaneous Approach */
"027W3ZZ" = "1" /* Dilation of Thoracic Aorta, Descending, Percutaneous Approach */
"027W44Z" = "1" /* Dilation of Thoracic Aorta, Descending with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027W4DZ" = "1" /* Dilation of Thoracic Aorta, Descending with Intraluminal Device, Percutaneous Endoscopic Approach */
"027W4ZZ" = "1" /* Dilation of Thoracic Aorta, Descending, Percutaneous Endoscopic Approach */
"027X04Z" = "1" /* Dilation of Thoracic Aorta, Ascending/Arch with Drug-eluting Intraluminal Device, Open Approach */
"027X0DZ" = "1" /* Dilation of Thoracic Aorta, Ascending/Arch with Intraluminal Device, Open Approach */
"027X0ZZ" = "1" /* Dilation of Thoracic Aorta, Ascending/Arch, Open Approach */
"027X34Z" = "1" /* Dilation of Thoracic Aorta, Ascending/Arch with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027X3DZ" = "1" /* Dilation of Thoracic Aorta, Ascending/Arch with Intraluminal Device, Percutaneous Approach */
"027X3ZZ" = "1" /* Dilation of Thoracic Aorta, Ascending/Arch, Percutaneous Approach */
"027X44Z" = "1" /* Dilation of Thoracic Aorta, Ascending/Arch with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027X4DZ" = "1" /* Dilation of Thoracic Aorta, Ascending/Arch with Intraluminal Device, Percutaneous Endoscopic Approach */
"027X4ZZ" = "1" /* Dilation of Thoracic Aorta, Ascending/Arch, Percutaneous Endoscopic Approach */
"02880ZZ" = "1" /* Division of Conduction Mechanism, Open Approach */
"02883ZZ" = "1" /* Division of Conduction Mechanism, Percutaneous Approach */
"02884ZZ" = "1" /* Division of Conduction Mechanism, Percutaneous Endoscopic Approach */
"02890ZZ" = "1" /* Division of Chordae Tendineae, Open Approach */
"02893ZZ" = "1" /* Division of Chordae Tendineae, Percutaneous Approach */
"02894ZZ" = "1" /* Division of Chordae Tendineae, Percutaneous Endoscopic Approach */
"028D0ZZ" = "1" /* Division of Papillary Muscle, Open Approach */
"028D3ZZ" = "1" /* Division of Papillary Muscle, Percutaneous Approach */
"028D4ZZ" = "1" /* Division of Papillary Muscle, Percutaneous Endoscopic Approach */
"02B40ZZ" = "1" /* Excision of Coronary Vein, Open Approach */
"02B43ZZ" = "1" /* Excision of Coronary Vein, Percutaneous Approach */
"02B44ZZ" = "1" /* Excision of Coronary Vein, Percutaneous Endoscopic Approach */
"02B50ZZ" = "1" /* Excision of Atrial Septum, Open Approach */
"02B53ZZ" = "1" /* Excision of Atrial Septum, Percutaneous Approach */
"02B54ZZ" = "1" /* Excision of Atrial Septum, Percutaneous Endoscopic Approach */
"02B60ZZ" = "1" /* Excision of Right Atrium, Open Approach */
"02B63ZZ" = "1" /* Excision of Right Atrium, Percutaneous Approach */
"02B64ZZ" = "1" /* Excision of Right Atrium, Percutaneous Endoscopic Approach */
"02B70ZK" = "1" /* Excision of Left Atrial Appendage, Open Approach */
"02B70ZZ" = "1" /* Excision of Left Atrium, Open Approach */
"02B73ZZ" = "1" /* Excision of Left Atrium, Percutaneous Approach */
"02B74ZK" = "1" /* Excision of Left Atrial Appendage, Percutaneous Endoscopic Approach */
"02B74ZZ" = "1" /* Excision of Left Atrium, Percutaneous Endoscopic Approach */
"02B80ZZ" = "1" /* Excision of Conduction Mechanism, Open Approach */
"02B83ZZ" = "1" /* Excision of Conduction Mechanism, Percutaneous Approach */
"02B84ZZ" = "1" /* Excision of Conduction Mechanism, Percutaneous Endoscopic Approach */
"02B90ZZ" = "1" /* Excision of Chordae Tendineae, Open Approach */
"02B93ZZ" = "1" /* Excision of Chordae Tendineae, Percutaneous Approach */
"02B94ZZ" = "1" /* Excision of Chordae Tendineae, Percutaneous Endoscopic Approach */
"02BD0ZZ" = "1" /* Excision of Papillary Muscle, Open Approach */
"02BD3ZZ" = "1" /* Excision of Papillary Muscle, Percutaneous Approach */
"02BD4ZZ" = "1" /* Excision of Papillary Muscle, Percutaneous Endoscopic Approach */
"02BF0ZZ" = "1" /* Excision of Aortic Valve, Open Approach */
"02BF3ZZ" = "1" /* Excision of Aortic Valve, Percutaneous Approach */
"02BF4ZZ" = "1" /* Excision of Aortic Valve, Percutaneous Endoscopic Approach */
"02BG0ZZ" = "1" /* Excision of Mitral Valve, Open Approach */
"02BG3ZZ" = "1" /* Excision of Mitral Valve, Percutaneous Approach */
"02BG4ZZ" = "1" /* Excision of Mitral Valve, Percutaneous Endoscopic Approach */
"02BH0ZZ" = "1" /* Excision of Pulmonary Valve, Open Approach */
"02BH3ZZ" = "1" /* Excision of Pulmonary Valve, Percutaneous Approach */
"02BH4ZZ" = "1" /* Excision of Pulmonary Valve, Percutaneous Endoscopic Approach */
"02BJ0ZZ" = "1" /* Excision of Tricuspid Valve, Open Approach */
"02BJ3ZZ" = "1" /* Excision of Tricuspid Valve, Percutaneous Approach */
"02BJ4ZZ" = "1" /* Excision of Tricuspid Valve, Percutaneous Endoscopic Approach */
"02BK0ZZ" = "1" /* Excision of Right Ventricle, Open Approach */
"02BK3ZZ" = "1" /* Excision of Right Ventricle, Percutaneous Approach */
"02BK4ZZ" = "1" /* Excision of Right Ventricle, Percutaneous Endoscopic Approach */
"02BL0ZZ" = "1" /* Excision of Left Ventricle, Open Approach */
"02BL3ZZ" = "1" /* Excision of Left Ventricle, Percutaneous Approach */
"02BL4ZZ" = "1" /* Excision of Left Ventricle, Percutaneous Endoscopic Approach */
"02BM0ZZ" = "1" /* Excision of Ventricular Septum, Open Approach */
"02BM3ZZ" = "1" /* Excision of Ventricular Septum, Percutaneous Approach */
"02BM4ZZ" = "1" /* Excision of Ventricular Septum, Percutaneous Endoscopic Approach */
"02BN0ZX" = "1" /* Excision of Pericardium, Open Approach, Diagnostic */
"02BN0ZZ" = "1" /* Excision of Pericardium, Open Approach */
"02BN3ZX" = "1" /* Excision of Pericardium, Percutaneous Approach, Diagnostic */
"02BN3ZZ" = "1" /* Excision of Pericardium, Percutaneous Approach */
"02BN4ZX" = "1" /* Excision of Pericardium, Percutaneous Endoscopic Approach, Diagnostic */
"02BN4ZZ" = "1" /* Excision of Pericardium, Percutaneous Endoscopic Approach */
"02BP0ZX" = "1" /* Excision of Pulmonary Trunk, Open Approach, Diagnostic */
"02BP0ZZ" = "1" /* Excision of Pulmonary Trunk, Open Approach */
"02BP3ZX" = "1" /* Excision of Pulmonary Trunk, Percutaneous Approach, Diagnostic */
"02BP3ZZ" = "1" /* Excision of Pulmonary Trunk, Percutaneous Approach */
"02BP4ZX" = "1" /* Excision of Pulmonary Trunk, Percutaneous Endoscopic Approach, Diagnostic */
"02BP4ZZ" = "1" /* Excision of Pulmonary Trunk, Percutaneous Endoscopic Approach */
"02BQ0ZX" = "1" /* Excision of Right Pulmonary Artery, Open Approach, Diagnostic */
"02BQ0ZZ" = "1" /* Excision of Right Pulmonary Artery, Open Approach */
"02BQ3ZX" = "1" /* Excision of Right Pulmonary Artery, Percutaneous Approach, Diagnostic */
"02BQ3ZZ" = "1" /* Excision of Right Pulmonary Artery, Percutaneous Approach */
"02BQ4ZX" = "1" /* Excision of Right Pulmonary Artery, Percutaneous Endoscopic Approach, Diagnostic */
"02BQ4ZZ" = "1" /* Excision of Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"02BR0ZX" = "1" /* Excision of Left Pulmonary Artery, Open Approach, Diagnostic */
"02BR0ZZ" = "1" /* Excision of Left Pulmonary Artery, Open Approach */
"02BR3ZX" = "1" /* Excision of Left Pulmonary Artery, Percutaneous Approach, Diagnostic */
"02BR3ZZ" = "1" /* Excision of Left Pulmonary Artery, Percutaneous Approach */
"02BR4ZX" = "1" /* Excision of Left Pulmonary Artery, Percutaneous Endoscopic Approach, Diagnostic */
"02BR4ZZ" = "1" /* Excision of Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"02BS0ZX" = "1" /* Excision of Right Pulmonary Vein, Open Approach, Diagnostic */
"02BS0ZZ" = "1" /* Excision of Right Pulmonary Vein, Open Approach */
"02BS3ZX" = "1" /* Excision of Right Pulmonary Vein, Percutaneous Approach, Diagnostic */
"02BS3ZZ" = "1" /* Excision of Right Pulmonary Vein, Percutaneous Approach */
"02BS4ZX" = "1" /* Excision of Right Pulmonary Vein, Percutaneous Endoscopic Approach, Diagnostic */
"02BS4ZZ" = "1" /* Excision of Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"02BT0ZX" = "1" /* Excision of Left Pulmonary Vein, Open Approach, Diagnostic */
"02BT0ZZ" = "1" /* Excision of Left Pulmonary Vein, Open Approach */
"02BT3ZX" = "1" /* Excision of Left Pulmonary Vein, Percutaneous Approach, Diagnostic */
"02BT3ZZ" = "1" /* Excision of Left Pulmonary Vein, Percutaneous Approach */
"02BT4ZX" = "1" /* Excision of Left Pulmonary Vein, Percutaneous Endoscopic Approach, Diagnostic */
"02BT4ZZ" = "1" /* Excision of Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"02BV0ZX" = "1" /* Excision of Superior Vena Cava, Open Approach, Diagnostic */
"02BV0ZZ" = "1" /* Excision of Superior Vena Cava, Open Approach */
"02BV3ZX" = "1" /* Excision of Superior Vena Cava, Percutaneous Approach, Diagnostic */
"02BV3ZZ" = "1" /* Excision of Superior Vena Cava, Percutaneous Approach */
"02BV4ZX" = "1" /* Excision of Superior Vena Cava, Percutaneous Endoscopic Approach, Diagnostic */
"02BV4ZZ" = "1" /* Excision of Superior Vena Cava, Percutaneous Endoscopic Approach */
"02BW0ZX" = "1" /* Excision of Thoracic Aorta, Descending, Open Approach, Diagnostic */
"02BW0ZZ" = "1" /* Excision of Thoracic Aorta, Descending, Open Approach */
"02BW3ZX" = "1" /* Excision of Thoracic Aorta, Descending, Percutaneous Approach, Diagnostic */
"02BW3ZZ" = "1" /* Excision of Thoracic Aorta, Descending, Percutaneous Approach */
"02BW4ZX" = "1" /* Excision of Thoracic Aorta, Descending, Percutaneous Endoscopic Approach, Diagnostic */
"02BW4ZZ" = "1" /* Excision of Thoracic Aorta, Descending, Percutaneous Endoscopic Approach */
"02BX0ZX" = "1" /* Excision of Thoracic Aorta, Ascending/Arch, Open Approach, Diagnostic */
"02BX0ZZ" = "1" /* Excision of Thoracic Aorta, Ascending/Arch, Open Approach */
"02BX3ZX" = "1" /* Excision of Thoracic Aorta, Ascending/Arch, Percutaneous Approach, Diagnostic */
"02BX3ZZ" = "1" /* Excision of Thoracic Aorta, Ascending/Arch, Percutaneous Approach */
"02BX4ZX" = "1" /* Excision of Thoracic Aorta, Ascending/Arch, Percutaneous Endoscopic Approach, Diagnostic */
"02BX4ZZ" = "1" /* Excision of Thoracic Aorta, Ascending/Arch, Percutaneous Endoscopic Approach */
"02C00Z6" = "1" /* Extirpation of Matter from Coronary Artery, One Artery, Bifurcation, Open Approach */
"02C00ZZ" = "1" /* Extirpation of Matter from Coronary Artery, One Artery, Open Approach */
"02C03Z6" = "1" /* Extirpation of Matter from Coronary Artery, One Artery, Bifurcation, Percutaneous Approach */
"02C03ZZ" = "1" /* Extirpation of Matter from Coronary Artery, One Artery, Percutaneous Approach */
"02C04Z6" = "1" /* Extirpation of Matter from Coronary Artery, One Artery, Bifurcation, Percutaneous Endoscopic Approach */
"02C04ZZ" = "1" /* Extirpation of Matter from Coronary Artery, One Artery, Percutaneous Endoscopic Approach */
"02C10Z6" = "1" /* Extirpation of Matter from Coronary Artery, Two Arteries, Bifurcation, Open Approach */
"02C10ZZ" = "1" /* Extirpation of Matter from Coronary Artery, Two Arteries, Open Approach */
"02C13Z6" = "1" /* Extirpation of Matter from Coronary Artery, Two Arteries, Bifurcation, Percutaneous Approach */
"02C13ZZ" = "1" /* Extirpation of Matter from Coronary Artery, Two Arteries, Percutaneous Approach */
"02C14Z6" = "1" /* Extirpation of Matter from Coronary Artery, Two Arteries, Bifurcation, Percutaneous Endoscopic Approach */
"02C14ZZ" = "1" /* Extirpation of Matter from Coronary Artery, Two Arteries, Percutaneous Endoscopic Approach */
"02C20Z6" = "1" /* Extirpation of Matter from Coronary Artery, Three Arteries, Bifurcation, Open Approach */
"02C20ZZ" = "1" /* Extirpation of Matter from Coronary Artery, Three Arteries, Open Approach */
"02C23Z6" = "1" /* Extirpation of Matter from Coronary Artery, Three Arteries, Bifurcation, Percutaneous Approach */
"02C23ZZ" = "1" /* Extirpation of Matter from Coronary Artery, Three Arteries, Percutaneous Approach */
"02C24Z6" = "1" /* Extirpation of Matter from Coronary Artery, Three Arteries, Bifurcation, Percutaneous Endoscopic Approach */
"02C24ZZ" = "1" /* Extirpation of Matter from Coronary Artery, Three Arteries, Percutaneous Endoscopic Approach */
"02C30Z6" = "1" /* Extirpation of Matter from Coronary Artery, Four or More Arteries, Bifurcation, Open Approach */
"02C30ZZ" = "1" /* Extirpation of Matter from Coronary Artery, Four or More Arteries, Open Approach */
"02C33Z6" = "1" /* Extirpation of Matter from Coronary Artery, Four or More Arteries, Bifurcation, Percutaneous Approach */
"02C33ZZ" = "1" /* Extirpation of Matter from Coronary Artery, Four or More Arteries, Percutaneous Approach */
"02C34Z6" = "1" /* Extirpation of Matter from Coronary Artery, Four or More Arteries, Bifurcation, Percutaneous Endoscopic Approach */
"02C34ZZ" = "1" /* Extirpation of Matter from Coronary Artery, Four or More Arteries, Percutaneous Endoscopic Approach */
"02C40ZZ" = "1" /* Extirpation of Matter from Coronary Vein, Open Approach */
"02C43ZZ" = "1" /* Extirpation of Matter from Coronary Vein, Percutaneous Approach */
"02C44ZZ" = "1" /* Extirpation of Matter from Coronary Vein, Percutaneous Endoscopic Approach */
"02C50ZZ" = "1" /* Extirpation of Matter from Atrial Septum, Open Approach */
"02C53ZZ" = "1" /* Extirpation of Matter from Atrial Septum, Percutaneous Approach */
"02C54ZZ" = "1" /* Extirpation of Matter from Atrial Septum, Percutaneous Endoscopic Approach */
"02C60ZZ" = "1" /* Extirpation of Matter from Right Atrium, Open Approach */
"02C63ZZ" = "1" /* Extirpation of Matter from Right Atrium, Percutaneous Approach */
"02C64ZZ" = "1" /* Extirpation of Matter from Right Atrium, Percutaneous Endoscopic Approach */
"02C70ZZ" = "1" /* Extirpation of Matter from Left Atrium, Open Approach */
"02C73ZZ" = "1" /* Extirpation of Matter from Left Atrium, Percutaneous Approach */
"02C74ZZ" = "1" /* Extirpation of Matter from Left Atrium, Percutaneous Endoscopic Approach */
"02C80ZZ" = "1" /* Extirpation of Matter from Conduction Mechanism, Open Approach */
"02C83ZZ" = "1" /* Extirpation of Matter from Conduction Mechanism, Percutaneous Approach */
"02C84ZZ" = "1" /* Extirpation of Matter from Conduction Mechanism, Percutaneous Endoscopic Approach */
"02C90ZZ" = "1" /* Extirpation of Matter from Chordae Tendineae, Open Approach */
"02C93ZZ" = "1" /* Extirpation of Matter from Chordae Tendineae, Percutaneous Approach */
"02C94ZZ" = "1" /* Extirpation of Matter from Chordae Tendineae, Percutaneous Endoscopic Approach */
"02CD0ZZ" = "1" /* Extirpation of Matter from Papillary Muscle, Open Approach */
"02CD3ZZ" = "1" /* Extirpation of Matter from Papillary Muscle, Percutaneous Approach */
"02CD4ZZ" = "1" /* Extirpation of Matter from Papillary Muscle, Percutaneous Endoscopic Approach */
"02CF0ZZ" = "1" /* Extirpation of Matter from Aortic Valve, Open Approach */
"02CF3ZZ" = "1" /* Extirpation of Matter from Aortic Valve, Percutaneous Approach */
"02CF4ZZ" = "1" /* Extirpation of Matter from Aortic Valve, Percutaneous Endoscopic Approach */
"02CG0ZZ" = "1" /* Extirpation of Matter from Mitral Valve, Open Approach */
"02CG3ZZ" = "1" /* Extirpation of Matter from Mitral Valve, Percutaneous Approach */
"02CG4ZZ" = "1" /* Extirpation of Matter from Mitral Valve, Percutaneous Endoscopic Approach */
"02CH0ZZ" = "1" /* Extirpation of Matter from Pulmonary Valve, Open Approach */
"02CH3ZZ" = "1" /* Extirpation of Matter from Pulmonary Valve, Percutaneous Approach */
"02CH4ZZ" = "1" /* Extirpation of Matter from Pulmonary Valve, Percutaneous Endoscopic Approach */
"02CJ0ZZ" = "1" /* Extirpation of Matter from Tricuspid Valve, Open Approach */
"02CJ3ZZ" = "1" /* Extirpation of Matter from Tricuspid Valve, Percutaneous Approach */
"02CJ4ZZ" = "1" /* Extirpation of Matter from Tricuspid Valve, Percutaneous Endoscopic Approach */
"02CK0ZZ" = "1" /* Extirpation of Matter from Right Ventricle, Open Approach */
"02CK3ZZ" = "1" /* Extirpation of Matter from Right Ventricle, Percutaneous Approach */
"02CK4ZZ" = "1" /* Extirpation of Matter from Right Ventricle, Percutaneous Endoscopic Approach */
"02CL0ZZ" = "1" /* Extirpation of Matter from Left Ventricle, Open Approach */
"02CL3ZZ" = "1" /* Extirpation of Matter from Left Ventricle, Percutaneous Approach */
"02CL4ZZ" = "1" /* Extirpation of Matter from Left Ventricle, Percutaneous Endoscopic Approach */
"02CM0ZZ" = "1" /* Extirpation of Matter from Ventricular Septum, Open Approach */
"02CM3ZZ" = "1" /* Extirpation of Matter from Ventricular Septum, Percutaneous Approach */
"02CM4ZZ" = "1" /* Extirpation of Matter from Ventricular Septum, Percutaneous Endoscopic Approach */
"02CN0ZZ" = "1" /* Extirpation of Matter from Pericardium, Open Approach */
"02CN3ZZ" = "1" /* Extirpation of Matter from Pericardium, Percutaneous Approach */
"02CN4ZZ" = "1" /* Extirpation of Matter from Pericardium, Percutaneous Endoscopic Approach */
"02CP0ZZ" = "1" /* Extirpation of Matter from Pulmonary Trunk, Open Approach */
"02CP3ZZ" = "1" /* Extirpation of Matter from Pulmonary Trunk, Percutaneous Approach */
"02CP4ZZ" = "1" /* Extirpation of Matter from Pulmonary Trunk, Percutaneous Endoscopic Approach */
"02CQ0ZZ" = "1" /* Extirpation of Matter from Right Pulmonary Artery, Open Approach */
"02CQ3ZZ" = "1" /* Extirpation of Matter from Right Pulmonary Artery, Percutaneous Approach */
"02CQ4ZZ" = "1" /* Extirpation of Matter from Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"02CR0ZZ" = "1" /* Extirpation of Matter from Left Pulmonary Artery, Open Approach */
"02CR3ZZ" = "1" /* Extirpation of Matter from Left Pulmonary Artery, Percutaneous Approach */
"02CR4ZZ" = "1" /* Extirpation of Matter from Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"02CS0ZZ" = "1" /* Extirpation of Matter from Right Pulmonary Vein, Open Approach */
"02CS3ZZ" = "1" /* Extirpation of Matter from Right Pulmonary Vein, Percutaneous Approach */
"02CS4ZZ" = "1" /* Extirpation of Matter from Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"02CT0ZZ" = "1" /* Extirpation of Matter from Left Pulmonary Vein, Open Approach */
"02CT3ZZ" = "1" /* Extirpation of Matter from Left Pulmonary Vein, Percutaneous Approach */
"02CT4ZZ" = "1" /* Extirpation of Matter from Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"02CV0ZZ" = "1" /* Extirpation of Matter from Superior Vena Cava, Open Approach */
"02CV3ZZ" = "1" /* Extirpation of Matter from Superior Vena Cava, Percutaneous Approach */
"02CV4ZZ" = "1" /* Extirpation of Matter from Superior Vena Cava, Percutaneous Endoscopic Approach */
"02CW0ZZ" = "1" /* Extirpation of Matter from Thoracic Aorta, Descending, Open Approach */
"02CW3ZZ" = "1" /* Extirpation of Matter from Thoracic Aorta, Descending, Percutaneous Approach */
"02CW4ZZ" = "1" /* Extirpation of Matter from Thoracic Aorta, Descending, Percutaneous Endoscopic Approach */
"02CX0ZZ" = "1" /* Extirpation of Matter from Thoracic Aorta, Ascending/Arch, Open Approach */
"02CX3ZZ" = "1" /* Extirpation of Matter from Thoracic Aorta, Ascending/Arch, Percutaneous Approach */
"02CX4ZZ" = "1" /* Extirpation of Matter from Thoracic Aorta, Ascending/Arch, Percutaneous Endoscopic Approach */
"02FN0ZZ" = "1" /* Fragmentation in Pericardium, Open Approach */
"02FN3ZZ" = "1" /* Fragmentation in Pericardium, Percutaneous Approach */
"02FN4ZZ" = "1" /* Fragmentation in Pericardium, Percutaneous Endoscopic Approach */
"02H400Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Coronary Vein, Open Approach */
"02H402Z" = "1" /* Insertion of Monitoring Device into Coronary Vein, Open Approach */
"02H403Z" = "1" /* Insertion of Infusion Device into Coronary Vein, Open Approach */
"02H40DZ" = "1" /* Insertion of Intraluminal Device into Coronary Vein, Open Approach */
"02H40JZ" = "1" /* Insertion of Pacemaker Lead into Coronary Vein, Open Approach */
"02H40KZ" = "1" /* Insertion of Defibrillator Lead into Coronary Vein, Open Approach */
"02H40MZ" = "1" /* Insertion of Cardiac Lead into Coronary Vein, Open Approach */
"02H40NZ" = "1" /* Insertion of Intracardiac Pacemaker into Coronary Vein, Open Approach */
"02H430Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Coronary Vein, Percutaneous Approach */
"02H43JZ" = "1" /* Insertion of Pacemaker Lead into Coronary Vein, Percutaneous Approach */
"02H43KZ" = "1" /* Insertion of Defibrillator Lead into Coronary Vein, Percutaneous Approach */
"02H43MZ" = "1" /* Insertion of Cardiac Lead into Coronary Vein, Percutaneous Approach */
"02H43NZ" = "1" /* Insertion of Intracardiac Pacemaker into Coronary Vein, Percutaneous Approach */
"02H440Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Coronary Vein, Percutaneous Endoscopic Approach */
"02H442Z" = "1" /* Insertion of Monitoring Device into Coronary Vein, Percutaneous Endoscopic Approach */
"02H443Z" = "1" /* Insertion of Infusion Device into Coronary Vein, Percutaneous Endoscopic Approach */
"02H44DZ" = "1" /* Insertion of Intraluminal Device into Coronary Vein, Percutaneous Endoscopic Approach */
"02H44KZ" = "1" /* Insertion of Defibrillator Lead into Coronary Vein, Percutaneous Endoscopic Approach */
"02H44NZ" = "1" /* Insertion of Intracardiac Pacemaker into Coronary Vein, Percutaneous Endoscopic Approach */
"02H600Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Right Atrium, Open Approach */
"02H602Z" = "1" /* Insertion of Monitoring Device into Right Atrium, Open Approach */
"02H603Z" = "1" /* Insertion of Infusion Device into Right Atrium, Open Approach */
"02H60DZ" = "1" /* Insertion of Intraluminal Device into Right Atrium, Open Approach */
"02H60KZ" = "1" /* Insertion of Defibrillator Lead into Right Atrium, Open Approach */
"02H60NZ" = "1" /* Insertion of Intracardiac Pacemaker into Right Atrium, Open Approach */
"02H630Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Right Atrium, Percutaneous Approach */
"02H63KZ" = "1" /* Insertion of Defibrillator Lead into Right Atrium, Percutaneous Approach */
"02H63NZ" = "1" /* Insertion of Intracardiac Pacemaker into Right Atrium, Percutaneous Approach */
"02H640Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Right Atrium, Percutaneous Endoscopic Approach */
"02H642Z" = "1" /* Insertion of Monitoring Device into Right Atrium, Percutaneous Endoscopic Approach */
"02H643Z" = "1" /* Insertion of Infusion Device into Right Atrium, Percutaneous Endoscopic Approach */
"02H64DZ" = "1" /* Insertion of Intraluminal Device into Right Atrium, Percutaneous Endoscopic Approach */
"02H64KZ" = "1" /* Insertion of Defibrillator Lead into Right Atrium, Percutaneous Endoscopic Approach */
"02H64NZ" = "1" /* Insertion of Intracardiac Pacemaker into Right Atrium, Percutaneous Endoscopic Approach */
"02H700Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Left Atrium, Open Approach */
"02H702Z" = "1" /* Insertion of Monitoring Device into Left Atrium, Open Approach */
"02H703Z" = "1" /* Insertion of Infusion Device into Left Atrium, Open Approach */
"02H70DZ" = "1" /* Insertion of Intraluminal Device into Left Atrium, Open Approach */
"02H70KZ" = "1" /* Insertion of Defibrillator Lead into Left Atrium, Open Approach */
"02H70NZ" = "1" /* Insertion of Intracardiac Pacemaker into Left Atrium, Open Approach */
"02H730Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Left Atrium, Percutaneous Approach */
"02H73KZ" = "1" /* Insertion of Defibrillator Lead into Left Atrium, Percutaneous Approach */
"02H73NZ" = "1" /* Insertion of Intracardiac Pacemaker into Left Atrium, Percutaneous Approach */
"02H740Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Left Atrium, Percutaneous Endoscopic Approach */
"02H742Z" = "1" /* Insertion of Monitoring Device into Left Atrium, Percutaneous Endoscopic Approach */
"02H743Z" = "1" /* Insertion of Infusion Device into Left Atrium, Percutaneous Endoscopic Approach */
"02H74DZ" = "1" /* Insertion of Intraluminal Device into Left Atrium, Percutaneous Endoscopic Approach */
"02H74KZ" = "1" /* Insertion of Defibrillator Lead into Left Atrium, Percutaneous Endoscopic Approach */
"02H74NZ" = "1" /* Insertion of Intracardiac Pacemaker into Left Atrium, Percutaneous Endoscopic Approach */
"02HA0QZ" = "1" /* Insertion of Implantable Heart Assist System into Heart, Open Approach */
"02HA0RS" = "1" /* Insertion of Biventricular External Heart Assist System into Heart, Open Approach */
"02HA0RZ" = "1" /* Insertion of External Heart Assist System into Heart, Open Approach */
"02HA3QZ" = "1" /* Insertion of Implantable Heart Assist System into Heart, Percutaneous Approach */
"02HA3RS" = "1" /* Insertion of Biventricular External Heart Assist System into Heart, Percutaneous Approach */
"02HA3RZ" = "1" /* Insertion of External Heart Assist System into Heart, Percutaneous Approach */
"02HA4QZ" = "1" /* Insertion of Implantable Heart Assist System into Heart, Percutaneous Endoscopic Approach */
"02HA4RS" = "1" /* Insertion of Biventricular External Heart Assist System into Heart, Percutaneous Endoscopic Approach */
"02HA4RZ" = "1" /* Insertion of External Heart Assist System into Heart, Percutaneous Endoscopic Approach */
"02HK00Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Right Ventricle, Open Approach */
"02HK02Z" = "1" /* Insertion of Monitoring Device into Right Ventricle, Open Approach */
"02HK03Z" = "1" /* Insertion of Infusion Device into Right Ventricle, Open Approach */
"02HK0DZ" = "1" /* Insertion of Intraluminal Device into Right Ventricle, Open Approach */
"02HK0KZ" = "1" /* Insertion of Defibrillator Lead into Right Ventricle, Open Approach */
"02HK0NZ" = "1" /* Insertion of Intracardiac Pacemaker into Right Ventricle, Open Approach */
"02HK3KZ" = "1" /* Insertion of Defibrillator Lead into Right Ventricle, Percutaneous Approach */
"02HK3NZ" = "1" /* Insertion of Intracardiac Pacemaker into Right Ventricle, Percutaneous Approach */
"02HK40Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Right Ventricle, Percutaneous Endoscopic Approach */
"02HK42Z" = "1" /* Insertion of Monitoring Device into Right Ventricle, Percutaneous Endoscopic Approach */
"02HK43Z" = "1" /* Insertion of Infusion Device into Right Ventricle, Percutaneous Endoscopic Approach */
"02HK4DZ" = "1" /* Insertion of Intraluminal Device into Right Ventricle, Percutaneous Endoscopic Approach */
"02HK4KZ" = "1" /* Insertion of Defibrillator Lead into Right Ventricle, Percutaneous Endoscopic Approach */
"02HK4NZ" = "1" /* Insertion of Intracardiac Pacemaker into Right Ventricle, Percutaneous Endoscopic Approach */
"02HL00Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Left Ventricle, Open Approach */
"02HL02Z" = "1" /* Insertion of Monitoring Device into Left Ventricle, Open Approach */
"02HL03Z" = "1" /* Insertion of Infusion Device into Left Ventricle, Open Approach */
"02HL0DZ" = "1" /* Insertion of Intraluminal Device into Left Ventricle, Open Approach */
"02HL0KZ" = "1" /* Insertion of Defibrillator Lead into Left Ventricle, Open Approach */
"02HL0NZ" = "1" /* Insertion of Intracardiac Pacemaker into Left Ventricle, Open Approach */
"02HL30Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Left Ventricle, Percutaneous Approach */
"02HL3KZ" = "1" /* Insertion of Defibrillator Lead into Left Ventricle, Percutaneous Approach */
"02HL3NZ" = "1" /* Insertion of Intracardiac Pacemaker into Left Ventricle, Percutaneous Approach */
"02HL40Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Left Ventricle, Percutaneous Endoscopic Approach */
"02HL42Z" = "1" /* Insertion of Monitoring Device into Left Ventricle, Percutaneous Endoscopic Approach */
"02HL43Z" = "1" /* Insertion of Infusion Device into Left Ventricle, Percutaneous Endoscopic Approach */
"02HL4DZ" = "1" /* Insertion of Intraluminal Device into Left Ventricle, Percutaneous Endoscopic Approach */
"02HL4KZ" = "1" /* Insertion of Defibrillator Lead into Left Ventricle, Percutaneous Endoscopic Approach */
"02HL4NZ" = "1" /* Insertion of Intracardiac Pacemaker into Left Ventricle, Percutaneous Endoscopic Approach */
"02HN00Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Pericardium, Open Approach */
"02HN02Z" = "1" /* Insertion of Monitoring Device into Pericardium, Open Approach */
"02HN0JZ" = "1" /* Insertion of Pacemaker Lead into Pericardium, Open Approach */
"02HN0KZ" = "1" /* Insertion of Defibrillator Lead into Pericardium, Open Approach */
"02HN0MZ" = "1" /* Insertion of Cardiac Lead into Pericardium, Open Approach */
"02HN30Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Pericardium, Percutaneous Approach */
"02HN3JZ" = "1" /* Insertion of Pacemaker Lead into Pericardium, Percutaneous Approach */
"02HN3KZ" = "1" /* Insertion of Defibrillator Lead into Pericardium, Percutaneous Approach */
"02HN3MZ" = "1" /* Insertion of Cardiac Lead into Pericardium, Percutaneous Approach */
"02HN40Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Pericardium, Percutaneous Endoscopic Approach */
"02HN42Z" = "1" /* Insertion of Monitoring Device into Pericardium, Percutaneous Endoscopic Approach */
"02HN4JZ" = "1" /* Insertion of Pacemaker Lead into Pericardium, Percutaneous Endoscopic Approach */
"02HN4KZ" = "1" /* Insertion of Defibrillator Lead into Pericardium, Percutaneous Endoscopic Approach */
"02HN4MZ" = "1" /* Insertion of Cardiac Lead into Pericardium, Percutaneous Endoscopic Approach */
"02HP0DZ" = "1" /* Insertion of Intraluminal Device into Pulmonary Trunk, Open Approach */
"02HP4DZ" = "1" /* Insertion of Intraluminal Device into Pulmonary Trunk, Percutaneous Endoscopic Approach */
"02HQ00Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Right Pulmonary Artery, Open Approach */
"02HQ0DZ" = "1" /* Insertion of Intraluminal Device into Right Pulmonary Artery, Open Approach */
"02HQ40Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"02HQ4DZ" = "1" /* Insertion of Intraluminal Device into Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"02HR00Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Left Pulmonary Artery, Open Approach */
"02HR0DZ" = "1" /* Insertion of Intraluminal Device into Left Pulmonary Artery, Open Approach */
"02HR40Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"02HR4DZ" = "1" /* Insertion of Intraluminal Device into Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"02HS00Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Right Pulmonary Vein, Open Approach */
"02HS02Z" = "1" /* Insertion of Monitoring Device into Right Pulmonary Vein, Open Approach */
"02HS0DZ" = "1" /* Insertion of Intraluminal Device into Right Pulmonary Vein, Open Approach */
"02HS30Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Right Pulmonary Vein, Percutaneous Approach */
"02HS40Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"02HS42Z" = "1" /* Insertion of Monitoring Device into Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"02HS4DZ" = "1" /* Insertion of Intraluminal Device into Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"02HT00Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Left Pulmonary Vein, Open Approach */
"02HT02Z" = "1" /* Insertion of Monitoring Device into Left Pulmonary Vein, Open Approach */
"02HT0DZ" = "1" /* Insertion of Intraluminal Device into Left Pulmonary Vein, Open Approach */
"02HT30Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Left Pulmonary Vein, Percutaneous Approach */
"02HT40Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"02HT42Z" = "1" /* Insertion of Monitoring Device into Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"02HT4DZ" = "1" /* Insertion of Intraluminal Device into Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"02HV00Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Superior Vena Cava, Open Approach */
"02HV02Z" = "1" /* Insertion of Monitoring Device into Superior Vena Cava, Open Approach */
"02HV0DZ" = "1" /* Insertion of Intraluminal Device into Superior Vena Cava, Open Approach */
"02HV30Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Superior Vena Cava, Percutaneous Approach */
"02HV40Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Superior Vena Cava, Percutaneous Endoscopic Approach */
"02HV42Z" = "1" /* Insertion of Monitoring Device into Superior Vena Cava, Percutaneous Endoscopic Approach */
"02HV4DZ" = "1" /* Insertion of Intraluminal Device into Superior Vena Cava, Percutaneous Endoscopic Approach */
"02HW02Z" = "1" /* Insertion of Monitoring Device into Thoracic Aorta, Descending, Open Approach */
"02HW0DZ" = "1" /* Insertion of Intraluminal Device into Thoracic Aorta, Descending, Open Approach */
"02HW42Z" = "1" /* Insertion of Monitoring Device into Thoracic Aorta, Descending, Percutaneous Endoscopic Approach */
"02HW4DZ" = "1" /* Insertion of Intraluminal Device into Thoracic Aorta, Descending, Percutaneous Endoscopic Approach */
"02HX00Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Thoracic Aorta, Ascending/Arch, Open Approach */
"02HX02Z" = "1" /* Insertion of Monitoring Device into Thoracic Aorta, Ascending/Arch, Open Approach */
"02HX03Z" = "1" /* Insertion of Infusion Device into Thoracic Aorta, Ascending/Arch, Open Approach */
"02HX0DZ" = "1" /* Insertion of Intraluminal Device into Thoracic Aorta, Ascending/Arch, Open Approach */
"02HX40Z" = "1" /* Insertion of Pressure Sensor Monitoring Device into Thoracic Aorta, Ascending/Arch, Percutaneous Endoscopic Approach */
"02HX42Z" = "1" /* Insertion of Monitoring Device into Thoracic Aorta, Ascending/Arch, Percutaneous Endoscopic Approach */
"02HX43Z" = "1" /* Insertion of Infusion Device into Thoracic Aorta, Ascending/Arch, Percutaneous Endoscopic Approach */
"02HX4DZ" = "1" /* Insertion of Intraluminal Device into Thoracic Aorta, Ascending/Arch, Percutaneous Endoscopic Approach */
"02JA0ZZ" = "1" /* Inspection of Heart, Open Approach */
"02JA4ZZ" = "1" /* Inspection of Heart, Percutaneous Endoscopic Approach */
"02JY0ZZ" = "1" /* Inspection of Great Vessel, Open Approach */
"02JY4ZZ" = "1" /* Inspection of Great Vessel, Percutaneous Endoscopic Approach */
"02LH0CZ" = "1" /* Occlusion of Pulmonary Valve with Extraluminal Device, Open Approach */
"02LH0DZ" = "1" /* Occlusion of Pulmonary Valve with Intraluminal Device, Open Approach */
"02LH0ZZ" = "1" /* Occlusion of Pulmonary Valve, Open Approach */
"02LH3CZ" = "1" /* Occlusion of Pulmonary Valve with Extraluminal Device, Percutaneous Approach */
"02LH3DZ" = "1" /* Occlusion of Pulmonary Valve with Intraluminal Device, Percutaneous Approach */
"02LH3ZZ" = "1" /* Occlusion of Pulmonary Valve, Percutaneous Approach */
"02LH4CZ" = "1" /* Occlusion of Pulmonary Valve with Extraluminal Device, Percutaneous Endoscopic Approach */
"02LH4DZ" = "1" /* Occlusion of Pulmonary Valve with Intraluminal Device, Percutaneous Endoscopic Approach */
"02LH4ZZ" = "1" /* Occlusion of Pulmonary Valve, Percutaneous Endoscopic Approach */
"02LR0CT" = "1" /* Occlusion of Ductus Arteriosus with Extraluminal Device, Open Approach */
"02LR0DT" = "1" /* Occlusion of Ductus Arteriosus with Intraluminal Device, Open Approach */
"02LR0ZT" = "1" /* Occlusion of Ductus Arteriosus, Open Approach */
"02LR3CT" = "1" /* Occlusion of Ductus Arteriosus with Extraluminal Device, Percutaneous Approach */
"02LR3DT" = "1" /* Occlusion of Ductus Arteriosus with Intraluminal Device, Percutaneous Approach */
"02LR3ZT" = "1" /* Occlusion of Ductus Arteriosus, Percutaneous Approach */
"02LR4CT" = "1" /* Occlusion of Ductus Arteriosus with Extraluminal Device, Percutaneous Endoscopic Approach */
"02LR4DT" = "1" /* Occlusion of Ductus Arteriosus with Intraluminal Device, Percutaneous Endoscopic Approach */
"02LR4ZT" = "1" /* Occlusion of Ductus Arteriosus, Percutaneous Endoscopic Approach */
"02LS0CZ" = "1" /* Occlusion of Right Pulmonary Vein with Extraluminal Device, Open Approach */
"02LS0DZ" = "1" /* Occlusion of Right Pulmonary Vein with Intraluminal Device, Open Approach */
"02LS0ZZ" = "1" /* Occlusion of Right Pulmonary Vein, Open Approach */
"02LS3CZ" = "1" /* Occlusion of Right Pulmonary Vein with Extraluminal Device, Percutaneous Approach */
"02LS3DZ" = "1" /* Occlusion of Right Pulmonary Vein with Intraluminal Device, Percutaneous Approach */
"02LS3ZZ" = "1" /* Occlusion of Right Pulmonary Vein, Percutaneous Approach */
"02LS4CZ" = "1" /* Occlusion of Right Pulmonary Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"02LS4DZ" = "1" /* Occlusion of Right Pulmonary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"02LS4ZZ" = "1" /* Occlusion of Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"02LT0CZ" = "1" /* Occlusion of Left Pulmonary Vein with Extraluminal Device, Open Approach */
"02LT0DZ" = "1" /* Occlusion of Left Pulmonary Vein with Intraluminal Device, Open Approach */
"02LT0ZZ" = "1" /* Occlusion of Left Pulmonary Vein, Open Approach */
"02LT3CZ" = "1" /* Occlusion of Left Pulmonary Vein with Extraluminal Device, Percutaneous Approach */
"02LT3DZ" = "1" /* Occlusion of Left Pulmonary Vein with Intraluminal Device, Percutaneous Approach */
"02LT3ZZ" = "1" /* Occlusion of Left Pulmonary Vein, Percutaneous Approach */
"02LT4CZ" = "1" /* Occlusion of Left Pulmonary Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"02LT4DZ" = "1" /* Occlusion of Left Pulmonary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"02LT4ZZ" = "1" /* Occlusion of Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"02LV0CZ" = "1" /* Occlusion of Superior Vena Cava with Extraluminal Device, Open Approach */
"02LV0DZ" = "1" /* Occlusion of Superior Vena Cava with Intraluminal Device, Open Approach */
"02LV0ZZ" = "1" /* Occlusion of Superior Vena Cava, Open Approach */
"02LV3CZ" = "1" /* Occlusion of Superior Vena Cava with Extraluminal Device, Percutaneous Approach */
"02LV3DZ" = "1" /* Occlusion of Superior Vena Cava with Intraluminal Device, Percutaneous Approach */
"02LV3ZZ" = "1" /* Occlusion of Superior Vena Cava, Percutaneous Approach */
"02LV4CZ" = "1" /* Occlusion of Superior Vena Cava with Extraluminal Device, Percutaneous Endoscopic Approach */
"02LV4DZ" = "1" /* Occlusion of Superior Vena Cava with Intraluminal Device, Percutaneous Endoscopic Approach */
"02LV4ZZ" = "1" /* Occlusion of Superior Vena Cava, Percutaneous Endoscopic Approach */
"02N40ZZ" = "1" /* Release Coronary Vein, Open Approach */
"02N43ZZ" = "1" /* Release Coronary Vein, Percutaneous Approach */
"02N44ZZ" = "1" /* Release Coronary Vein, Percutaneous Endoscopic Approach */
"02N50ZZ" = "1" /* Release Atrial Septum, Open Approach */
"02N53ZZ" = "1" /* Release Atrial Septum, Percutaneous Approach */
"02N54ZZ" = "1" /* Release Atrial Septum, Percutaneous Endoscopic Approach */
"02N60ZZ" = "1" /* Release Right Atrium, Open Approach */
"02N63ZZ" = "1" /* Release Right Atrium, Percutaneous Approach */
"02N64ZZ" = "1" /* Release Right Atrium, Percutaneous Endoscopic Approach */
"02N70ZZ" = "1" /* Release Left Atrium, Open Approach */
"02N73ZZ" = "1" /* Release Left Atrium, Percutaneous Approach */
"02N74ZZ" = "1" /* Release Left Atrium, Percutaneous Endoscopic Approach */
"02N80ZZ" = "1" /* Release Conduction Mechanism, Open Approach */
"02N83ZZ" = "1" /* Release Conduction Mechanism, Percutaneous Approach */
"02N84ZZ" = "1" /* Release Conduction Mechanism, Percutaneous Endoscopic Approach */
"02N90ZZ" = "1" /* Release Chordae Tendineae, Open Approach */
"02N93ZZ" = "1" /* Release Chordae Tendineae, Percutaneous Approach */
"02N94ZZ" = "1" /* Release Chordae Tendineae, Percutaneous Endoscopic Approach */
"02ND0ZZ" = "1" /* Release Papillary Muscle, Open Approach */
"02ND3ZZ" = "1" /* Release Papillary Muscle, Percutaneous Approach */
"02ND4ZZ" = "1" /* Release Papillary Muscle, Percutaneous Endoscopic Approach */
"02NF0ZZ" = "1" /* Release Aortic Valve, Open Approach */
"02NF3ZZ" = "1" /* Release Aortic Valve, Percutaneous Approach */
"02NF4ZZ" = "1" /* Release Aortic Valve, Percutaneous Endoscopic Approach */
"02NG0ZZ" = "1" /* Release Mitral Valve, Open Approach */
"02NG3ZZ" = "1" /* Release Mitral Valve, Percutaneous Approach */
"02NG4ZZ" = "1" /* Release Mitral Valve, Percutaneous Endoscopic Approach */
"02NH0ZZ" = "1" /* Release Pulmonary Valve, Open Approach */
"02NH3ZZ" = "1" /* Release Pulmonary Valve, Percutaneous Approach */
"02NH4ZZ" = "1" /* Release Pulmonary Valve, Percutaneous Endoscopic Approach */
"02NJ0ZZ" = "1" /* Release Tricuspid Valve, Open Approach */
"02NJ3ZZ" = "1" /* Release Tricuspid Valve, Percutaneous Approach */
"02NJ4ZZ" = "1" /* Release Tricuspid Valve, Percutaneous Endoscopic Approach */
"02NK0ZZ" = "1" /* Release Right Ventricle, Open Approach */
"02NK3ZZ" = "1" /* Release Right Ventricle, Percutaneous Approach */
"02NK4ZZ" = "1" /* Release Right Ventricle, Percutaneous Endoscopic Approach */
"02NL0ZZ" = "1" /* Release Left Ventricle, Open Approach */
"02NL3ZZ" = "1" /* Release Left Ventricle, Percutaneous Approach */
"02NL4ZZ" = "1" /* Release Left Ventricle, Percutaneous Endoscopic Approach */
"02NM0ZZ" = "1" /* Release Ventricular Septum, Open Approach */
"02NM3ZZ" = "1" /* Release Ventricular Septum, Percutaneous Approach */
"02NM4ZZ" = "1" /* Release Ventricular Septum, Percutaneous Endoscopic Approach */
"02NN0ZZ" = "1" /* Release Pericardium, Open Approach */
"02NN3ZZ" = "1" /* Release Pericardium, Percutaneous Approach */
"02NN4ZZ" = "1" /* Release Pericardium, Percutaneous Endoscopic Approach */
"02NP0ZZ" = "1" /* Release Pulmonary Trunk, Open Approach */
"02NP3ZZ" = "1" /* Release Pulmonary Trunk, Percutaneous Approach */
"02NP4ZZ" = "1" /* Release Pulmonary Trunk, Percutaneous Endoscopic Approach */
"02NQ0ZZ" = "1" /* Release Right Pulmonary Artery, Open Approach */
"02NQ3ZZ" = "1" /* Release Right Pulmonary Artery, Percutaneous Approach */
"02NQ4ZZ" = "1" /* Release Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"02NR0ZZ" = "1" /* Release Left Pulmonary Artery, Open Approach */
"02NR3ZZ" = "1" /* Release Left Pulmonary Artery, Percutaneous Approach */
"02NR4ZZ" = "1" /* Release Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"02NS0ZZ" = "1" /* Release Right Pulmonary Vein, Open Approach */
"02NS3ZZ" = "1" /* Release Right Pulmonary Vein, Percutaneous Approach */
"02NS4ZZ" = "1" /* Release Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"02NT0ZZ" = "1" /* Release Left Pulmonary Vein, Open Approach */
"02NT3ZZ" = "1" /* Release Left Pulmonary Vein, Percutaneous Approach */
"02NT4ZZ" = "1" /* Release Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"02NV0ZZ" = "1" /* Release Superior Vena Cava, Open Approach */
"02NV3ZZ" = "1" /* Release Superior Vena Cava, Percutaneous Approach */
"02NV4ZZ" = "1" /* Release Superior Vena Cava, Percutaneous Endoscopic Approach */
"02NW0ZZ" = "1" /* Release Thoracic Aorta, Decending, Open Approach */
"02NW3ZZ" = "1" /* Release Thoracic Aorta, Decending, Percutaneous Approach */
"02NW4ZZ" = "1" /* Release Thoracic Aorta, Decending, Percutaneous Endoscopic Approach */
"02NX0ZZ" = "1" /* Release Thoracic Aorta, Ascending/Arch, Open Approach */
"02NX3ZZ" = "1" /* Release Thoracic Aorta, Ascending/Arch, Percutaneous Approach */
"02NX4ZZ" = "1" /* Release Thoracic Aorta, Ascending/Arch, Percutaneous Endoscopic Approach */
"02PA02Z" = "1" /* Removal of Monitoring Device from Heart, Open Approach */
"02PA03Z" = "1" /* Removal of Infusion Device from Heart, Open Approach */
"02PA07Z" = "1" /* Removal of Autologous Tissue Substitute from Heart, Open Approach */
"02PA08Z" = "1" /* Removal of Zooplastic Tissue from Heart, Open Approach */
"02PA0CZ" = "1" /* Removal of Extraluminal Device from Heart, Open Approach */
"02PA0DZ" = "1" /* Removal of Intraluminal Device from Heart, Open Approach */
"02PA0JZ" = "1" /* Removal of Synthetic Substitute from Heart, Open Approach */
"02PA0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Heart, Open Approach */
"02PA0MZ" = "1" /* Removal of Cardiac Lead from Heart, Open Approach */
"02PA0NZ" = "1" /* Removal of Intracardiac Pacemaker from Heart, Open Approach */
"02PA0QZ" = "1" /* Removal of Implantable Heart Assist System from Heart, Open Approach */
"02PA0RZ" = "1" /* Removal of External Heart Assist System from Heart, Open Approach */
"02PA37Z" = "1" /* Removal of Autologous Tissue Substitute from Heart, Percutaneous Approach */
"02PA38Z" = "1" /* Removal of Zooplastic Tissue from Heart, Percutaneous Approach */
"02PA3CZ" = "1" /* Removal of Extraluminal Device from Heart, Percutaneous Approach */
"02PA3JZ" = "1" /* Removal of Synthetic Substitute from Heart, Percutaneous Approach */
"02PA3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Heart, Percutaneous Approach */
"02PA3MZ" = "1" /* Removal of Cardiac Lead from Heart, Percutaneous Approach */
"02PA3NZ" = "1" /* Removal of Intracardiac Pacemaker from Heart, Percutaneous Approach */
"02PA3QZ" = "1" /* Removal of Implantable Heart Assist System from Heart, Percutaneous Approach */
"02PA3RZ" = "1" /* Removal of External Heart Assist System from Heart, Percutaneous Approach */
"02PA42Z" = "1" /* Removal of Monitoring Device from Heart, Percutaneous Endoscopic Approach */
"02PA43Z" = "1" /* Removal of Infusion Device from Heart, Percutaneous Endoscopic Approach */
"02PA47Z" = "1" /* Removal of Autologous Tissue Substitute from Heart, Percutaneous Endoscopic Approach */
"02PA48Z" = "1" /* Removal of Zooplastic Tissue from Heart, Percutaneous Endoscopic Approach */
"02PA4CZ" = "1" /* Removal of Extraluminal Device from Heart, Percutaneous Endoscopic Approach */
"02PA4DZ" = "1" /* Removal of Intraluminal Device from Heart, Percutaneous Endoscopic Approach */
"02PA4JZ" = "1" /* Removal of Synthetic Substitute from Heart, Percutaneous Endoscopic Approach */
"02PA4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Heart, Percutaneous Endoscopic Approach */
"02PA4MZ" = "1" /* Removal of Cardiac Lead from Heart, Percutaneous Endoscopic Approach */
"02PA4NZ" = "1" /* Removal of Intracardiac Pacemaker from Heart, Percutaneous Endoscopic Approach */
"02PA4QZ" = "1" /* Removal of Implantable Heart Assist System from Heart, Percutaneous Endoscopic Approach */
"02PA4RZ" = "1" /* Removal of External Heart Assist System from Heart, Percutaneous Endoscopic Approach */
"02PY02Z" = "1" /* Removal of Monitoring Device from Great Vessel, Open Approach */
"02PY03Z" = "1" /* Removal of Infusion Device from Great Vessel, Open Approach */
"02PY07Z" = "1" /* Removal of Autologous Tissue Substitute from Great Vessel, Open Approach */
"02PY08Z" = "1" /* Removal of Zooplastic Tissue from Great Vessel, Open Approach */
"02PY0CZ" = "1" /* Removal of Extraluminal Device from Great Vessel, Open Approach */
"02PY0DZ" = "1" /* Removal of Intraluminal Device from Great Vessel, Open Approach */
"02PY0JZ" = "1" /* Removal of Synthetic Substitute from Great Vessel, Open Approach */
"02PY0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Great Vessel, Open Approach */
"02PY37Z" = "1" /* Removal of Autologous Tissue Substitute from Great Vessel, Percutaneous Approach */
"02PY38Z" = "1" /* Removal of Zooplastic Tissue from Great Vessel, Percutaneous Approach */
"02PY3CZ" = "1" /* Removal of Extraluminal Device from Great Vessel, Percutaneous Approach */
"02PY3JZ" = "1" /* Removal of Synthetic Substitute from Great Vessel, Percutaneous Approach */
"02PY3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Great Vessel, Percutaneous Approach */
"02PY42Z" = "1" /* Removal of Monitoring Device from Great Vessel, Percutaneous Endoscopic Approach */
"02PY43Z" = "1" /* Removal of Infusion Device from Great Vessel, Percutaneous Endoscopic Approach */
"02PY47Z" = "1" /* Removal of Autologous Tissue Substitute from Great Vessel, Percutaneous Endoscopic Approach */
"02PY48Z" = "1" /* Removal of Zooplastic Tissue from Great Vessel, Percutaneous Endoscopic Approach */
"02PY4CZ" = "1" /* Removal of Extraluminal Device from Great Vessel, Percutaneous Endoscopic Approach */
"02PY4DZ" = "1" /* Removal of Intraluminal Device from Great Vessel, Percutaneous Endoscopic Approach */
"02PY4JZ" = "1" /* Removal of Synthetic Substitute from Great Vessel, Percutaneous Endoscopic Approach */
"02PY4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Great Vessel, Percutaneous Endoscopic Approach */
"02Q00ZZ" = "1" /* Repair Coronary Artery, One Artery, Open Approach */
"02Q03ZZ" = "1" /* Repair Coronary Artery, One Artery, Percutaneous Approach */
"02Q04ZZ" = "1" /* Repair Coronary Artery, One Artery, Percutaneous Endoscopic Approach */
"02Q10ZZ" = "1" /* Repair Coronary Artery, Two Arteries, Open Approach */
"02Q13ZZ" = "1" /* Repair Coronary Artery, Two Arteries, Percutaneous Approach */
"02Q14ZZ" = "1" /* Repair Coronary Artery, Two Arteries, Percutaneous Endoscopic Approach */
"02Q20ZZ" = "1" /* Repair Coronary Artery, Three Arteries, Open Approach */
"02Q23ZZ" = "1" /* Repair Coronary Artery, Three Arteries, Percutaneous Approach */
"02Q24ZZ" = "1" /* Repair Coronary Artery, Three Arteries, Percutaneous Endoscopic Approach */
"02Q30ZZ" = "1" /* Repair Coronary Artery, Four or More Arteries, Open Approach */
"02Q33ZZ" = "1" /* Repair Coronary Artery, Four or More Arteries, Percutaneous Approach */
"02Q34ZZ" = "1" /* Repair Coronary Artery, Four or More Arteries, Percutaneous Endoscopic Approach */
"02Q40ZZ" = "1" /* Repair Coronary Vein, Open Approach */
"02Q43ZZ" = "1" /* Repair Coronary Vein, Percutaneous Approach */
"02Q44ZZ" = "1" /* Repair Coronary Vein, Percutaneous Endoscopic Approach */
"02Q50ZZ" = "1" /* Repair Atrial Septum, Open Approach */
"02Q53ZZ" = "1" /* Repair Atrial Septum, Percutaneous Approach */
"02Q54ZZ" = "1" /* Repair Atrial Septum, Percutaneous Endoscopic Approach */
"02Q60ZZ" = "1" /* Repair Right Atrium, Open Approach */
"02Q63ZZ" = "1" /* Repair Right Atrium, Percutaneous Approach */
"02Q64ZZ" = "1" /* Repair Right Atrium, Percutaneous Endoscopic Approach */
"02Q70ZZ" = "1" /* Repair Left Atrium, Open Approach */
"02Q73ZZ" = "1" /* Repair Left Atrium, Percutaneous Approach */
"02Q74ZZ" = "1" /* Repair Left Atrium, Percutaneous Endoscopic Approach */
"02Q80ZZ" = "1" /* Repair Conduction Mechanism, Open Approach */
"02Q83ZZ" = "1" /* Repair Conduction Mechanism, Percutaneous Approach */
"02Q84ZZ" = "1" /* Repair Conduction Mechanism, Percutaneous Endoscopic Approach */
"02Q90ZZ" = "1" /* Repair Chordae Tendineae, Open Approach */
"02Q93ZZ" = "1" /* Repair Chordae Tendineae, Percutaneous Approach */
"02Q94ZZ" = "1" /* Repair Chordae Tendineae, Percutaneous Endoscopic Approach */
"02QA0ZZ" = "1" /* Repair Heart, Open Approach */
"02QA3ZZ" = "1" /* Repair Heart, Percutaneous Approach */
"02QA4ZZ" = "1" /* Repair Heart, Percutaneous Endoscopic Approach */
"02QB0ZZ" = "1" /* Repair Right Heart, Open Approach */
"02QB3ZZ" = "1" /* Repair Right Heart, Percutaneous Approach */
"02QB4ZZ" = "1" /* Repair Right Heart, Percutaneous Endoscopic Approach */
"02QC0ZZ" = "1" /* Repair Left Heart, Open Approach */
"02QC3ZZ" = "1" /* Repair Left Heart, Percutaneous Approach */
"02QC4ZZ" = "1" /* Repair Left Heart, Percutaneous Endoscopic Approach */
"02QD0ZZ" = "1" /* Repair Papillary Muscle, Open Approach */
"02QD3ZZ" = "1" /* Repair Papillary Muscle, Percutaneous Approach */
"02QD4ZZ" = "1" /* Repair Papillary Muscle, Percutaneous Endoscopic Approach */
"02QF0ZJ" = "1" /* Repair Aortic Valve created from Truncal Valve, Open Approach */
"02QF0ZZ" = "1" /* Repair Aortic Valve, Open Approach */
"02QF3ZJ" = "1" /* Repair Aortic Valve created from Truncal Valve, Percutaneous Approach */
"02QF3ZZ" = "1" /* Repair Aortic Valve, Percutaneous Approach */
"02QF4ZJ" = "1" /* Repair Aortic Valve created from Truncal Valve, Percutaneous Endoscopic Approach */
"02QF4ZZ" = "1" /* Repair Aortic Valve, Percutaneous Endoscopic Approach */
"02QG0ZE" = "1" /* Repair Mitral Valve created from Left Atrioventricular Valve, Open Approach */
"02QG0ZZ" = "1" /* Repair Mitral Valve, Open Approach */
"02QG3ZE" = "1" /* Repair Mitral Valve created from Left Atrioventricular Valve, Percutaneous Approach */
"02QG3ZZ" = "1" /* Repair Mitral Valve, Percutaneous Approach */
"02QG4ZE" = "1" /* Repair Mitral Valve created from Left Atrioventricular Valve, Percutaneous Endoscopic Approach */
"02QG4ZZ" = "1" /* Repair Mitral Valve, Percutaneous Endoscopic Approach */
"02QH0ZZ" = "1" /* Repair Pulmonary Valve, Open Approach */
"02QH3ZZ" = "1" /* Repair Pulmonary Valve, Percutaneous Approach */
"02QH4ZZ" = "1" /* Repair Pulmonary Valve, Percutaneous Endoscopic Approach */
"02QJ0ZG" = "1" /* Repair Tricuspid Valve created from Right Atrioventricular Valve, Open Approach */
"02QJ0ZZ" = "1" /* Repair Tricuspid Valve, Open Approach */
"02QJ3ZG" = "1" /* Repair Tricuspid Valve created from Right Atrioventricular Valve, Percutaneous Approach */
"02QJ3ZZ" = "1" /* Repair Tricuspid Valve, Percutaneous Approach */
"02QJ4ZG" = "1" /* Repair Tricuspid Valve created from Right Atrioventricular Valve, Percutaneous Endoscopic Approach */
"02QJ4ZZ" = "1" /* Repair Tricuspid Valve, Percutaneous Endoscopic Approach */
"02QK0ZZ" = "1" /* Repair Right Ventricle, Open Approach */
"02QK3ZZ" = "1" /* Repair Right Ventricle, Percutaneous Approach */
"02QK4ZZ" = "1" /* Repair Right Ventricle, Percutaneous Endoscopic Approach */
"02QL0ZZ" = "1" /* Repair Left Ventricle, Open Approach */
"02QL3ZZ" = "1" /* Repair Left Ventricle, Percutaneous Approach */
"02QL4ZZ" = "1" /* Repair Left Ventricle, Percutaneous Endoscopic Approach */
"02QM0ZZ" = "1" /* Repair Ventricular Septum, Open Approach */
"02QM3ZZ" = "1" /* Repair Ventricular Septum, Percutaneous Approach */
"02QM4ZZ" = "1" /* Repair Ventricular Septum, Percutaneous Endoscopic Approach */
"02QN0ZZ" = "1" /* Repair Pericardium, Open Approach */
"02QN3ZZ" = "1" /* Repair Pericardium, Percutaneous Approach */
"02QN4ZZ" = "1" /* Repair Pericardium, Percutaneous Endoscopic Approach */
"02QP0ZZ" = "1" /* Repair Pulmonary Trunk, Open Approach */
"02QP3ZZ" = "1" /* Repair Pulmonary Trunk, Percutaneous Approach */
"02QP4ZZ" = "1" /* Repair Pulmonary Trunk, Percutaneous Endoscopic Approach */
"02QQ0ZZ" = "1" /* Repair Right Pulmonary Artery, Open Approach */
"02QQ3ZZ" = "1" /* Repair Right Pulmonary Artery, Percutaneous Approach */
"02QQ4ZZ" = "1" /* Repair Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"02QR0ZZ" = "1" /* Repair Left Pulmonary Artery, Open Approach */
"02QR3ZZ" = "1" /* Repair Left Pulmonary Artery, Percutaneous Approach */
"02QR4ZZ" = "1" /* Repair Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"02QS0ZZ" = "1" /* Repair Right Pulmonary Vein, Open Approach */
"02QS3ZZ" = "1" /* Repair Right Pulmonary Vein, Percutaneous Approach */
"02QS4ZZ" = "1" /* Repair Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"02QT0ZZ" = "1" /* Repair Left Pulmonary Vein, Open Approach */
"02QT3ZZ" = "1" /* Repair Left Pulmonary Vein, Percutaneous Approach */
"02QT4ZZ" = "1" /* Repair Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"02QV0ZZ" = "1" /* Repair Superior Vena Cava, Open Approach */
"02QV3ZZ" = "1" /* Repair Superior Vena Cava, Percutaneous Approach */
"02QV4ZZ" = "1" /* Repair Superior Vena Cava, Percutaneous Endoscopic Approach */
"02QW0ZZ" = "1" /* Repair Thoracic Aorta, Decending, Open Approach */
"02QW3ZZ" = "1" /* Repair Thoracic Aorta, Decending, Percutaneous Approach */
"02QW4ZZ" = "1" /* Repair Thoracic Aorta, Decending, Percutaneous Endoscopic Approach */
"02QX0ZZ" = "1" /* Repair Thoracic Aorta, Ascending/Arch, Open Approach */
"02QX3ZZ" = "1" /* Repair Thoracic Aorta, Ascending/Arch, Percutaneous Approach */
"02QX4ZZ" = "1" /* Repair Thoracic Aorta, Ascending/Arch, Percutaneous Endoscopic Approach */
"02R507Z" = "1" /* Replacement of Atrial Septum with Autologous Tissue Substitute, Open Approach */
"02R508Z" = "1" /* Replacement of Atrial Septum with Zooplastic Tissue, Open Approach */
"02R50JZ" = "1" /* Replacement of Atrial Septum with Synthetic Substitute, Open Approach */
"02R50KZ" = "1" /* Replacement of Atrial Septum with Nonautologous Tissue Substitute, Open Approach */
"02R547Z" = "1" /* Replacement of Atrial Septum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02R548Z" = "1" /* Replacement of Atrial Septum with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02R54JZ" = "1" /* Replacement of Atrial Septum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02R54KZ" = "1" /* Replacement of Atrial Septum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02R607Z" = "1" /* Replacement of Right Atrium with Autologous Tissue Substitute, Open Approach */
"02R608Z" = "1" /* Replacement of Right Atrium with Zooplastic Tissue, Open Approach */
"02R60JZ" = "1" /* Replacement of Right Atrium with Synthetic Substitute, Open Approach */
"02R60KZ" = "1" /* Replacement of Right Atrium with Nonautologous Tissue Substitute, Open Approach */
"02R647Z" = "1" /* Replacement of Right Atrium with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02R648Z" = "1" /* Replacement of Right Atrium with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02R64JZ" = "1" /* Replacement of Right Atrium with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02R64KZ" = "1" /* Replacement of Right Atrium with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02R707Z" = "1" /* Replacement of Left Atrium with Autologous Tissue Substitute, Open Approach */
"02R708Z" = "1" /* Replacement of Left Atrium with Zooplastic Tissue, Open Approach */
"02R70JZ" = "1" /* Replacement of Left Atrium with Synthetic Substitute, Open Approach */
"02R70KZ" = "1" /* Replacement of Left Atrium with Nonautologous Tissue Substitute, Open Approach */
"02R747Z" = "1" /* Replacement of Left Atrium with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02R748Z" = "1" /* Replacement of Left Atrium with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02R74JZ" = "1" /* Replacement of Left Atrium with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02R74KZ" = "1" /* Replacement of Left Atrium with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02R907Z" = "1" /* Replacement of Chordae Tendineae with Autologous Tissue Substitute, Open Approach */
"02R908Z" = "1" /* Replacement of Chordae Tendineae with Zooplastic Tissue, Open Approach */
"02R90JZ" = "1" /* Replacement of Chordae Tendineae with Synthetic Substitute, Open Approach */
"02R90KZ" = "1" /* Replacement of Chordae Tendineae with Nonautologous Tissue Substitute, Open Approach */
"02R947Z" = "1" /* Replacement of Chordae Tendineae with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02R948Z" = "1" /* Replacement of Chordae Tendineae with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02R94JZ" = "1" /* Replacement of Chordae Tendineae with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02R94KZ" = "1" /* Replacement of Chordae Tendineae with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RD07Z" = "1" /* Replacement of Papillary Muscle with Autologous Tissue Substitute, Open Approach */
"02RD08Z" = "1" /* Replacement of Papillary Muscle with Zooplastic Tissue, Open Approach */
"02RD0JZ" = "1" /* Replacement of Papillary Muscle with Synthetic Substitute, Open Approach */
"02RD0KZ" = "1" /* Replacement of Papillary Muscle with Nonautologous Tissue Substitute, Open Approach */
"02RD47Z" = "1" /* Replacement of Papillary Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RD48Z" = "1" /* Replacement of Papillary Muscle with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RD4JZ" = "1" /* Replacement of Papillary Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RD4KZ" = "1" /* Replacement of Papillary Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RF07Z" = "1" /* Replacement of Aortic Valve with Autologous Tissue Substitute, Open Approach */
"02RF08Z" = "1" /* Replacement of Aortic Valve with Zooplastic Tissue, Open Approach */
"02RF0JZ" = "1" /* Replacement of Aortic Valve with Synthetic Substitute, Open Approach */
"02RF0KZ" = "1" /* Replacement of Aortic Valve with Nonautologous Tissue Substitute, Open Approach */
"02RF37H" = "1" /* Replacement of Aortic Valve with Autologous Tissue Substitute, Transapical, Percutaneous Approach */
"02RF37Z" = "1" /* Replacement of Aortic Valve with Autologous Tissue Substitute, Percutaneous Approach */
"02RF38H" = "1" /* Replacement of Aortic Valve with Zooplastic Tissue, Transapical, Percutaneous Approach */
"02RF38Z" = "1" /* Replacement of Aortic Valve with Zooplastic Tissue, Percutaneous Approach */
"02RF3JH" = "1" /* Replacement of Aortic Valve with Synthetic Substitute, Transapical, Percutaneous Approach */
"02RF3JZ" = "1" /* Replacement of Aortic Valve with Synthetic Substitute, Percutaneous Approach */
"02RF3KH" = "1" /* Replacement of Aortic Valve with Nonautologous Tissue Substitute, Transapical, Percutaneous Approach */
"02RF3KZ" = "1" /* Replacement of Aortic Valve with Nonautologous Tissue Substitute, Percutaneous Approach */
"02RF47Z" = "1" /* Replacement of Aortic Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RF48Z" = "1" /* Replacement of Aortic Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RF4JZ" = "1" /* Replacement of Aortic Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RF4KZ" = "1" /* Replacement of Aortic Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RG07Z" = "1" /* Replacement of Mitral Valve with Autologous Tissue Substitute, Open Approach */
"02RG08Z" = "1" /* Replacement of Mitral Valve with Zooplastic Tissue, Open Approach */
"02RG0JZ" = "1" /* Replacement of Mitral Valve with Synthetic Substitute, Open Approach */
"02RG0KZ" = "1" /* Replacement of Mitral Valve with Nonautologous Tissue Substitute, Open Approach */
"02RG37H" = "1" /* Replacement of Mitral Valve with Autologous Tissue Substitute, Transapical, Percutaneous Approach */
"02RG37Z" = "1" /* Replacement of Mitral Valve with Autologous Tissue Substitute, Percutaneous Approach */
"02RG38H" = "1" /* Replacement of Mitral Valve with Zooplastic Tissue, Transapical, Percutaneous Approach */
"02RG38Z" = "1" /* Replacement of Mitral Valve with Zooplastic Tissue, Percutaneous Approach */
"02RG3JH" = "1" /* Replacement of Mitral Valve with Synthetic Substitute, Transapical, Percutaneous Approach */
"02RG3JZ" = "1" /* Replacement of Mitral Valve with Synthetic Substitute, Percutaneous Approach */
"02RG3KH" = "1" /* Replacement of Mitral Valve with Nonautologous Tissue Substitute, Transapical, Percutaneous Approach */
"02RG3KZ" = "1" /* Replacement of Mitral Valve with Nonautologous Tissue Substitute, Percutaneous Approach */
"02RG47Z" = "1" /* Replacement of Mitral Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RG48Z" = "1" /* Replacement of Mitral Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RG4JZ" = "1" /* Replacement of Mitral Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RG4KZ" = "1" /* Replacement of Mitral Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RH07Z" = "1" /* Replacement of Pulmonary Valve with Autologous Tissue Substitute, Open Approach */
"02RH08Z" = "1" /* Replacement of Pulmonary Valve with Zooplastic Tissue, Open Approach */
"02RH0JZ" = "1" /* Replacement of Pulmonary Valve with Synthetic Substitute, Open Approach */
"02RH0KZ" = "1" /* Replacement of Pulmonary Valve with Nonautologous Tissue Substitute, Open Approach */
"02RH37H" = "1" /* Replacement of Pulmonary Valve with Autologous Tissue Substitute, Transapical, Percutaneous Approach */
"02RH37Z" = "1" /* Replacement of Pulmonary Valve with Autologous Tissue Substitute, Percutaneous Approach */
"02RH38H" = "1" /* Replacement of Pulmonary Valve with Zooplastic Tissue, Transapical, Percutaneous Approach */
"02RH38Z" = "1" /* Replacement of Pulmonary Valve with Zooplastic Tissue, Percutaneous Approach */
"02RH3JH" = "1" /* Replacement of Pulmonary Valve with Synthetic Substitute, Transapical, Percutaneous Approach */
"02RH3JZ" = "1" /* Replacement of Pulmonary Valve with Synthetic Substitute, Percutaneous Approach */
"02RH3KH" = "1" /* Replacement of Pulmonary Valve with Nonautologous Tissue Substitute, Transapical, Percutaneous Approach */
"02RH3KZ" = "1" /* Replacement of Pulmonary Valve with Nonautologous Tissue Substitute, Percutaneous Approach */
"02RH47Z" = "1" /* Replacement of Pulmonary Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RH48Z" = "1" /* Replacement of Pulmonary Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RH4JZ" = "1" /* Replacement of Pulmonary Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RH4KZ" = "1" /* Replacement of Pulmonary Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RJ07Z" = "1" /* Replacement of Tricuspid Valve with Autologous Tissue Substitute, Open Approach */
"02RJ08Z" = "1" /* Replacement of Tricuspid Valve with Zooplastic Tissue, Open Approach */
"02RJ0JZ" = "1" /* Replacement of Tricuspid Valve with Synthetic Substitute, Open Approach */
"02RJ0KZ" = "1" /* Replacement of Tricuspid Valve with Nonautologous Tissue Substitute, Open Approach */
"02RJ47Z" = "1" /* Replacement of Tricuspid Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RJ48Z" = "1" /* Replacement of Tricuspid Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RJ4JZ" = "1" /* Replacement of Tricuspid Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RJ4KZ" = "1" /* Replacement of Tricuspid Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RK07Z" = "1" /* Replacement of Right Ventricle with Autologous Tissue Substitute, Open Approach */
"02RK08Z" = "1" /* Replacement of Right Ventricle with Zooplastic Tissue, Open Approach */
"02RK0JZ" = "1" /* Replacement of Right Ventricle with Synthetic Substitute, Open Approach */
"02RK0KZ" = "1" /* Replacement of Right Ventricle with Nonautologous Tissue Substitute, Open Approach */
"02RK47Z" = "1" /* Replacement of Right Ventricle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RK48Z" = "1" /* Replacement of Right Ventricle with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RK4JZ" = "1" /* Replacement of Right Ventricle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RK4KZ" = "1" /* Replacement of Right Ventricle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RL07Z" = "1" /* Replacement of Left Ventricle with Autologous Tissue Substitute, Open Approach */
"02RL08Z" = "1" /* Replacement of Left Ventricle with Zooplastic Tissue, Open Approach */
"02RL0JZ" = "1" /* Replacement of Left Ventricle with Synthetic Substitute, Open Approach */
"02RL0KZ" = "1" /* Replacement of Left Ventricle with Nonautologous Tissue Substitute, Open Approach */
"02RL47Z" = "1" /* Replacement of Left Ventricle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RL48Z" = "1" /* Replacement of Left Ventricle with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RL4JZ" = "1" /* Replacement of Left Ventricle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RL4KZ" = "1" /* Replacement of Left Ventricle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RM07Z" = "1" /* Replacement of Ventricular Septum with Autologous Tissue Substitute, Open Approach */
"02RM08Z" = "1" /* Replacement of Ventricular Septum with Zooplastic Tissue, Open Approach */
"02RM0JZ" = "1" /* Replacement of Ventricular Septum with Synthetic Substitute, Open Approach */
"02RM0KZ" = "1" /* Replacement of Ventricular Septum with Nonautologous Tissue Substitute, Open Approach */
"02RM47Z" = "1" /* Replacement of Ventricular Septum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RM48Z" = "1" /* Replacement of Ventricular Septum with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RM4JZ" = "1" /* Replacement of Ventricular Septum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RM4KZ" = "1" /* Replacement of Ventricular Septum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RN07Z" = "1" /* Replacement of Pericardium with Autologous Tissue Substitute, Open Approach */
"02RN08Z" = "1" /* Replacement of Pericardium with Zooplastic Tissue, Open Approach */
"02RN0JZ" = "1" /* Replacement of Pericardium with Synthetic Substitute, Open Approach */
"02RN0KZ" = "1" /* Replacement of Pericardium with Nonautologous Tissue Substitute, Open Approach */
"02RN47Z" = "1" /* Replacement of Pericardium with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RN48Z" = "1" /* Replacement of Pericardium with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RN4JZ" = "1" /* Replacement of Pericardium with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RN4KZ" = "1" /* Replacement of Pericardium with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RP07Z" = "1" /* Replacement of Pulmonary Trunk with Autologous Tissue Substitute, Open Approach */
"02RP08Z" = "1" /* Replacement of Pulmonary Trunk with Zooplastic Tissue, Open Approach */
"02RP0JZ" = "1" /* Replacement of Pulmonary Trunk with Synthetic Substitute, Open Approach */
"02RP0KZ" = "1" /* Replacement of Pulmonary Trunk with Nonautologous Tissue Substitute, Open Approach */
"02RP47Z" = "1" /* Replacement of Pulmonary Trunk with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RP48Z" = "1" /* Replacement of Pulmonary Trunk with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RP4JZ" = "1" /* Replacement of Pulmonary Trunk with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RP4KZ" = "1" /* Replacement of Pulmonary Trunk with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RQ07Z" = "1" /* Replacement of Right Pulmonary Artery with Autologous Tissue Substitute, Open Approach */
"02RQ08Z" = "1" /* Replacement of Right Pulmonary Artery with Zooplastic Tissue, Open Approach */
"02RQ0JZ" = "1" /* Replacement of Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"02RQ0KZ" = "1" /* Replacement of Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"02RQ47Z" = "1" /* Replacement of Right Pulmonary Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RQ48Z" = "1" /* Replacement of Right Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RQ4JZ" = "1" /* Replacement of Right Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RQ4KZ" = "1" /* Replacement of Right Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RR07Z" = "1" /* Replacement of Left Pulmonary Artery with Autologous Tissue Substitute, Open Approach */
"02RR08Z" = "1" /* Replacement of Left Pulmonary Artery with Zooplastic Tissue, Open Approach */
"02RR0JZ" = "1" /* Replacement of Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"02RR0KZ" = "1" /* Replacement of Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"02RR47Z" = "1" /* Replacement of Left Pulmonary Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RR48Z" = "1" /* Replacement of Left Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RR4JZ" = "1" /* Replacement of Left Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RR4KZ" = "1" /* Replacement of Left Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RS07Z" = "1" /* Replacement of Right Pulmonary Vein with Autologous Tissue Substitute, Open Approach */
"02RS08Z" = "1" /* Replacement of Right Pulmonary Vein with Zooplastic Tissue, Open Approach */
"02RS0JZ" = "1" /* Replacement of Right Pulmonary Vein with Synthetic Substitute, Open Approach */
"02RS0KZ" = "1" /* Replacement of Right Pulmonary Vein with Nonautologous Tissue Substitute, Open Approach */
"02RS47Z" = "1" /* Replacement of Right Pulmonary Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RS48Z" = "1" /* Replacement of Right Pulmonary Vein with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RS4JZ" = "1" /* Replacement of Right Pulmonary Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RS4KZ" = "1" /* Replacement of Right Pulmonary Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RT07Z" = "1" /* Replacement of Left Pulmonary Vein with Autologous Tissue Substitute, Open Approach */
"02RT08Z" = "1" /* Replacement of Left Pulmonary Vein with Zooplastic Tissue, Open Approach */
"02RT0JZ" = "1" /* Replacement of Left Pulmonary Vein with Synthetic Substitute, Open Approach */
"02RT0KZ" = "1" /* Replacement of Left Pulmonary Vein with Nonautologous Tissue Substitute, Open Approach */
"02RT47Z" = "1" /* Replacement of Left Pulmonary Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RT48Z" = "1" /* Replacement of Left Pulmonary Vein with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RT4JZ" = "1" /* Replacement of Left Pulmonary Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RT4KZ" = "1" /* Replacement of Left Pulmonary Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RV07Z" = "1" /* Replacement of Superior Vena Cava with Autologous Tissue Substitute, Open Approach */
"02RV08Z" = "1" /* Replacement of Superior Vena Cava with Zooplastic Tissue, Open Approach */
"02RV0JZ" = "1" /* Replacement of Superior Vena Cava with Synthetic Substitute, Open Approach */
"02RV0KZ" = "1" /* Replacement of Superior Vena Cava with Nonautologous Tissue Substitute, Open Approach */
"02RV47Z" = "1" /* Replacement of Superior Vena Cava with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RV48Z" = "1" /* Replacement of Superior Vena Cava with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RV4JZ" = "1" /* Replacement of Superior Vena Cava with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RV4KZ" = "1" /* Replacement of Superior Vena Cava with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RW07Z" = "1" /* Replacement of Thoracic Aorta Decending, with Autologous Tissue Substitute, Open Approach */
"02RW08Z" = "1" /* Replacement of Thoracic Aorta, Decending, with Zooplastic Tissue, Open Approach */
"02RW0JZ" = "1" /* Replacement of Thoracic Aorta, Decending, with Synthetic Substitute, Open Approach */
"02RW0KZ" = "1" /* Replacement of Thoracic Aorta, Decending, with Nonautologous Tissue Substitute, Open Approach */
"02RW47Z" = "1" /* Replacement of Thoracic Aorta, Decending, with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RW48Z" = "1" /* Replacement of Thoracic Aorta, Decending, with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RW4JZ" = "1" /* Replacement of Thoracic Aorta, Decending, with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RW4KZ" = "1" /* Replacement of Thoracic Aorta, Decending, with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RX07Z" = "1" /* Replacement of Thoracic Aorta, Ascending/Arch with Autologous Tissue Substitute, Open Approach */
"02RX08Z" = "1" /* Replacement of Thoracic Aorta, Ascending/Arch with Zooplastic Tissue, Open Approach */
"02RX0JZ" = "1" /* Replacement of Thoracic Aorta, Ascending/Arch with Synthetic Substitute, Open Approach */
"02RX0KZ" = "1" /* Replacement of Thoracic Aorta, Ascending/Arch with Nonautologous Tissue Substitute, Open Approach */
"02RX47Z" = "1" /* Replacement of Thoracic Aorta, Ascending/Arch with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RX48Z" = "1" /* Replacement of Thoracic Aorta, Ascending/Arch with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RX4JZ" = "1" /* Replacement of Thoracic Aorta, Ascending/Arch with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RX4KZ" = "1" /* Replacement of Thoracic Aorta, Ascending/Arch with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02S00ZZ" = "1" /* Reposition Coronary Artery, One Artery, Open Approach */
"02S10ZZ" = "1" /* Reposition Coronary Artery, Two Arteries, Open Approach */
"02SP0ZZ" = "1" /* Reposition Pulmonary Trunk, Open Approach */
"02SQ0ZZ" = "1" /* Reposition Right Pulmonary Artery, Open Approach */
"02SR0ZZ" = "1" /* Reposition Left Pulmonary Artery, Open Approach */
"02SS0ZZ" = "1" /* Reposition Right Pulmonary Vein, Open Approach */
"02ST0ZZ" = "1" /* Reposition Left Pulmonary Vein, Open Approach */
"02SV0ZZ" = "1" /* Reposition Superior Vena Cava, Open Approach */
"02SW0ZZ" = "1" /* Reposition Thoracic Aorta, Decending, Open Approach */
"02SX0ZZ" = "1" /* Reposition Thoracic Aorta, Ascending/Arch, Open Approach */
"02T50ZZ" = "1" /* Resection of Atrial Septum, Open Approach */
"02T53ZZ" = "1" /* Resection of Atrial Septum, Percutaneous Approach */
"02T54ZZ" = "1" /* Resection of Atrial Septum, Percutaneous Endoscopic Approach */
"02T80ZZ" = "1" /* Resection of Conduction Mechanism, Open Approach */
"02T83ZZ" = "1" /* Resection of Conduction Mechanism, Percutaneous Approach */
"02T84ZZ" = "1" /* Resection of Conduction Mechanism, Percutaneous Endoscopic Approach */
"02T90ZZ" = "1" /* Resection of Chordae Tendineae, Open Approach */
"02T93ZZ" = "1" /* Resection of Chordae Tendineae, Percutaneous Approach */
"02T94ZZ" = "1" /* Resection of Chordae Tendineae, Percutaneous Endoscopic Approach */
"02TD0ZZ" = "1" /* Resection of Papillary Muscle, Open Approach */
"02TD3ZZ" = "1" /* Resection of Papillary Muscle, Percutaneous Approach */
"02TD4ZZ" = "1" /* Resection of Papillary Muscle, Percutaneous Endoscopic Approach */
"02TH0ZZ" = "1" /* Resection of Pulmonary Valve, Open Approach */
"02TH3ZZ" = "1" /* Resection of Pulmonary Valve, Percutaneous Approach */
"02TH4ZZ" = "1" /* Resection of Pulmonary Valve, Percutaneous Endoscopic Approach */
"02TM0ZZ" = "1" /* Resection of Ventricular Septum, Open Approach */
"02TM3ZZ" = "1" /* Resection of Ventricular Septum, Percutaneous Approach */
"02TM4ZZ" = "1" /* Resection of Ventricular Septum, Percutaneous Endoscopic Approach */
"02TN0ZZ" = "1" /* Resection of Pericardium, Open Approach */
"02TN3ZZ" = "1" /* Resection of Pericardium, Percutaneous Approach */
"02TN4ZZ" = "1" /* Resection of Pericardium, Percutaneous Endoscopic Approach */
"02U507Z" = "1" /* Supplement Atrial Septum with Autologous Tissue Substitute, Open Approach */
"02U508Z" = "1" /* Supplement Atrial Septum with Zooplastic Tissue, Open Approach */
"02U50JZ" = "1" /* Supplement Atrial Septum with Synthetic Substitute, Open Approach */
"02U50KZ" = "1" /* Supplement Atrial Septum with Nonautologous Tissue Substitute, Open Approach */
"02U537Z" = "1" /* Supplement Atrial Septum with Autologous Tissue Substitute, Percutaneous Approach */
"02U538Z" = "1" /* Supplement Atrial Septum with Zooplastic Tissue, Percutaneous Approach */
"02U53JZ" = "1" /* Supplement Atrial Septum with Synthetic Substitute, Percutaneous Approach */
"02U53KZ" = "1" /* Supplement Atrial Septum with Nonautologous Tissue Substitute, Percutaneous Approach */
"02U547Z" = "1" /* Supplement Atrial Septum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02U548Z" = "1" /* Supplement Atrial Septum with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02U54JZ" = "1" /* Supplement Atrial Septum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02U54KZ" = "1" /* Supplement Atrial Septum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02U607Z" = "1" /* Supplement Right Atrium with Autologous Tissue Substitute, Open Approach */
"02U608Z" = "1" /* Supplement Right Atrium with Zooplastic Tissue, Open Approach */
"02U60JZ" = "1" /* Supplement Right Atrium with Synthetic Substitute, Open Approach */
"02U60KZ" = "1" /* Supplement Right Atrium with Nonautologous Tissue Substitute, Open Approach */
"02U637Z" = "1" /* Supplement Right Atrium with Autologous Tissue Substitute, Percutaneous Approach */
"02U638Z" = "1" /* Supplement Right Atrium with Zooplastic Tissue, Percutaneous Approach */
"02U63JZ" = "1" /* Supplement Right Atrium with Synthetic Substitute, Percutaneous Approach */
"02U63KZ" = "1" /* Supplement Right Atrium with Nonautologous Tissue Substitute, Percutaneous Approach */
"02U647Z" = "1" /* Supplement Right Atrium with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02U648Z" = "1" /* Supplement Right Atrium with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02U64JZ" = "1" /* Supplement Right Atrium with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02U64KZ" = "1" /* Supplement Right Atrium with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02U707Z" = "1" /* Supplement Left Atrium with Autologous Tissue Substitute, Open Approach */
"02U708Z" = "1" /* Supplement Left Atrium with Zooplastic Tissue, Open Approach */
"02U70JZ" = "1" /* Supplement Left Atrium with Synthetic Substitute, Open Approach */
"02U70KZ" = "1" /* Supplement Left Atrium with Nonautologous Tissue Substitute, Open Approach */
"02U737Z" = "1" /* Supplement Left Atrium with Autologous Tissue Substitute, Percutaneous Approach */
"02U738Z" = "1" /* Supplement Left Atrium with Zooplastic Tissue, Percutaneous Approach */
"02U73KZ" = "1" /* Supplement Left Atrium with Nonautologous Tissue Substitute, Percutaneous Approach */
"02U747Z" = "1" /* Supplement Left Atrium with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02U748Z" = "1" /* Supplement Left Atrium with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02U74KZ" = "1" /* Supplement Left Atrium with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02U907Z" = "1" /* Supplement Chordae Tendineae with Autologous Tissue Substitute, Open Approach */
"02U908Z" = "1" /* Supplement Chordae Tendineae with Zooplastic Tissue, Open Approach */
"02U90JZ" = "1" /* Supplement Chordae Tendineae with Synthetic Substitute, Open Approach */
"02U90KZ" = "1" /* Supplement Chordae Tendineae with Nonautologous Tissue Substitute, Open Approach */
"02U937Z" = "1" /* Supplement Chordae Tendineae with Autologous Tissue Substitute, Percutaneous Approach */
"02U938Z" = "1" /* Supplement Chordae Tendineae with Zooplastic Tissue, Percutaneous Approach */
"02U93JZ" = "1" /* Supplement Chordae Tendineae with Synthetic Substitute, Percutaneous Approach */
"02U93KZ" = "1" /* Supplement Chordae Tendineae with Nonautologous Tissue Substitute, Percutaneous Approach */
"02U947Z" = "1" /* Supplement Chordae Tendineae with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02U948Z" = "1" /* Supplement Chordae Tendineae with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02U94JZ" = "1" /* Supplement Chordae Tendineae with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02U94KZ" = "1" /* Supplement Chordae Tendineae with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UA07Z" = "1" /* Supplement Heart with Autologous Tissue Substitute, Open Approach */
"02UA08Z" = "1" /* Supplement Heart with Zooplastic Tissue, Open Approach */
"02UA0JZ" = "1" /* Supplement Heart with Synthetic Substitute, Open Approach */
"02UA0KZ" = "1" /* Supplement Heart with Nonautologous Tissue Substitute, Open Approach */
"02UA37Z" = "1" /* Supplement Heart with Autologous Tissue Substitute, Percutaneous Approach */
"02UA38Z" = "1" /* Supplement Heart with Zooplastic Tissue, Percutaneous Approach */
"02UA3JZ" = "1" /* Supplement Heart with Synthetic Substitute, Percutaneous Approach */
"02UA3KZ" = "1" /* Supplement Heart with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UA47Z" = "1" /* Supplement Heart with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UA48Z" = "1" /* Supplement Heart with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UA4JZ" = "1" /* Supplement Heart with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UA4KZ" = "1" /* Supplement Heart with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UD07Z" = "1" /* Supplement Papillary Muscle with Autologous Tissue Substitute, Open Approach */
"02UD08Z" = "1" /* Supplement Papillary Muscle with Zooplastic Tissue, Open Approach */
"02UD0JZ" = "1" /* Supplement Papillary Muscle with Synthetic Substitute, Open Approach */
"02UD0KZ" = "1" /* Supplement Papillary Muscle with Nonautologous Tissue Substitute, Open Approach */
"02UD37Z" = "1" /* Supplement Papillary Muscle with Autologous Tissue Substitute, Percutaneous Approach */
"02UD38Z" = "1" /* Supplement Papillary Muscle with Zooplastic Tissue, Percutaneous Approach */
"02UD3JZ" = "1" /* Supplement Papillary Muscle with Synthetic Substitute, Percutaneous Approach */
"02UD3KZ" = "1" /* Supplement Papillary Muscle with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UD47Z" = "1" /* Supplement Papillary Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UD48Z" = "1" /* Supplement Papillary Muscle with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UD4JZ" = "1" /* Supplement Papillary Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UD4KZ" = "1" /* Supplement Papillary Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UF07J" = "1" /* Supplement Aortic Valve created from Truncal Valve with Autologous Tissue Substitute, Open Approach */
"02UF07Z" = "1" /* Supplement Aortic Valve with Autologous Tissue Substitute, Open Approach */
"02UF08J" = "1" /* Supplement Aortic Valve created from Truncal Valve with Zooplastic Tissue, Open Approach */
"02UF08Z" = "1" /* Supplement Aortic Valve with Zooplastic Tissue, Open Approach */
"02UF0JJ" = "1" /* Supplement Aortic Valve created from Truncal Valve with Synthetic Substitute, Open Approach */
"02UF0JZ" = "1" /* Supplement Aortic Valve with Synthetic Substitute, Open Approach */
"02UF0KJ" = "1" /* Supplement Aortic Valve created from Truncal Valve with Nonautologous Tissue Substitute, Open Approach */
"02UF0KZ" = "1" /* Supplement Aortic Valve with Nonautologous Tissue Substitute, Open Approach */
"02UF37J" = "1" /* Supplement Aortic Valve created from Truncal Valve with Autologous Tissue Substitute, Percutaneous Approach */
"02UF37Z" = "1" /* Supplement Aortic Valve with Autologous Tissue Substitute, Percutaneous Approach */
"02UF38J" = "1" /* Supplement Aortic Valve created from Truncal Valve with Zooplastic Tissue, Percutaneous Approach */
"02UF38Z" = "1" /* Supplement Aortic Valve with Zooplastic Tissue, Percutaneous Approach */
"02UF3JJ" = "1" /* Supplement Aortic Valve created from Truncal Valve with Synthetic Substitute, Percutaneous Approach */
"02UF3JZ" = "1" /* Supplement Aortic Valve with Synthetic Substitute, Percutaneous Approach */
"02UF3KJ" = "1" /* Supplement Aortic Valve created from Truncal Valve with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UF3KZ" = "1" /* Supplement Aortic Valve with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UF47J" = "1" /* Supplement Aortic Valve created from Truncal Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UF47Z" = "1" /* Supplement Aortic Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UF48J" = "1" /* Supplement Aortic Valve created from Truncal Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UF48Z" = "1" /* Supplement Aortic Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UF4JJ" = "1" /* Supplement Aortic Valve created from Truncal Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UF4JZ" = "1" /* Supplement Aortic Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UF4KJ" = "1" /* Supplement Aortic Valve created from Truncal Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UF4KZ" = "1" /* Supplement Aortic Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UG07E" = "1" /* Supplement Mitral Valve created from Left Atrioventricular Valve with Autologous Tissue Substitute, Open Approach */
"02UG07Z" = "1" /* Supplement Mitral Valve with Autologous Tissue Substitute, Open Approach */
"02UG08E" = "1" /* Supplement Mitral Valve created from Left Atrioventricular Valve with Zooplastic Tissue, Open Approach */
"02UG08Z" = "1" /* Supplement Mitral Valve with Zooplastic Tissue, Open Approach */
"02UG0JE" = "1" /* Supplement Mitral Valve created from Left Atrioventricular Valve with Synthetic Substitute, Open Approach */
"02UG0JZ" = "1" /* Supplement Mitral Valve with Synthetic Substitute, Open Approach */
"02UG0KE" = "1" /* Supplement Mitral Valve created from Left Atrioventricular Valve with Nonautologous Tissue Substitute, Open Approach */
"02UG0KZ" = "1" /* Supplement Mitral Valve with Nonautologous Tissue Substitute, Open Approach */
"02UG37E" = "1" /* Supplement Mitral Valve created from Left Atrioventricular Valve with Autologous Tissue Substitute, Percutaneous Approach */
"02UG37Z" = "1" /* Supplement Mitral Valve with Autologous Tissue Substitute, Percutaneous Approach */
"02UG38E" = "1" /* Supplement Mitral Valve created from Left Atrioventricular Valve with Zooplastic Tissue, Percutaneous Approach */
"02UG38Z" = "1" /* Supplement Mitral Valve with Zooplastic Tissue, Percutaneous Approach */
"02UG3JE" = "1" /* Supplement Mitral Valve created from Left Atrioventricular Valve with Synthetic Substitute, Percutaneous Approach */
"02UG3JZ" = "1" /* Supplement Mitral Valve with Synthetic Substitute, Percutaneous Approach */
"02UG3KE" = "1" /* Supplement Mitral Valve created from Left Atrioventricular Valve with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UG3KZ" = "1" /* Supplement Mitral Valve with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UG47E" = "1" /* Supplement Mitral Valve created from Left Atrioventricular Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UG47Z" = "1" /* Supplement Mitral Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UG48E" = "1" /* Supplement Mitral Valve created from Left Atrioventricular Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UG48Z" = "1" /* Supplement Mitral Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UG4JE" = "1" /* Supplement Mitral Valve created from Left Atrioventricular Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UG4JZ" = "1" /* Supplement Mitral Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UG4KE" = "1" /* Supplement Mitral Valve created from Left Atrioventricular Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UG4KZ" = "1" /* Supplement Mitral Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UH07Z" = "1" /* Supplement Pulmonary Valve with Autologous Tissue Substitute, Open Approach */
"02UH08Z" = "1" /* Supplement Pulmonary Valve with Zooplastic Tissue, Open Approach */
"02UH0JZ" = "1" /* Supplement Pulmonary Valve with Synthetic Substitute, Open Approach */
"02UH0KZ" = "1" /* Supplement Pulmonary Valve with Nonautologous Tissue Substitute, Open Approach */
"02UH37Z" = "1" /* Supplement Pulmonary Valve with Autologous Tissue Substitute, Percutaneous Approach */
"02UH38Z" = "1" /* Supplement Pulmonary Valve with Zooplastic Tissue, Percutaneous Approach */
"02UH3JZ" = "1" /* Supplement Pulmonary Valve with Synthetic Substitute, Percutaneous Approach */
"02UH3KZ" = "1" /* Supplement Pulmonary Valve with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UH47Z" = "1" /* Supplement Pulmonary Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UH48Z" = "1" /* Supplement Pulmonary Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UH4JZ" = "1" /* Supplement Pulmonary Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UH4KZ" = "1" /* Supplement Pulmonary Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UJ07G" = "1" /* Supplement Tricuspid Valve created from Right Atrioventricular Valve with Autologous Tissue Substitute, Open Approach */
"02UJ07Z" = "1" /* Supplement Tricuspid Valve with Autologous Tissue Substitute, Open Approach */
"02UJ08G" = "1" /* Supplement Tricuspid Valve created from Right Atrioventricular Valve with Zooplastic Tissue, Open Approach */
"02UJ08Z" = "1" /* Supplement Tricuspid Valve with Zooplastic Tissue, Open Approach */
"02UJ0JG" = "1" /* Supplement Tricuspid Valve created from Right Atrioventricular Valve with Synthetic Substitute, Open Approach */
"02UJ0JZ" = "1" /* Supplement Tricuspid Valve with Synthetic Substitute, Open Approach */
"02UJ0KG" = "1" /* Supplement Tricuspid Valve created from Right Atrioventricular Valve with Nonautologous Tissue Substitute, Open Approach */
"02UJ0KZ" = "1" /* Supplement Tricuspid Valve with Nonautologous Tissue Substitute, Open Approach */
"02UJ37G" = "1" /* Supplement Tricuspid Valve created from Right Atrioventricular Valve with Autologous Tissue Substitute, Percutaneous Approach */
"02UJ37Z" = "1" /* Supplement Tricuspid Valve with Autologous Tissue Substitute, Percutaneous Approach */
"02UJ38G" = "1" /* Supplement Tricuspid Valve created from Right Atrioventricular Valve with Zooplastic Tissue, Percutaneous Approach */
"02UJ38Z" = "1" /* Supplement Tricuspid Valve with Zooplastic Tissue, Percutaneous Approach */
"02UJ3JG" = "1" /* Supplement Tricuspid Valve created from Right Atrioventricular Valve with Synthetic Substitute, Percutaneous Approach */
"02UJ3JZ" = "1" /* Supplement Tricuspid Valve with Synthetic Substitute, Percutaneous Approach */
"02UJ3KG" = "1" /* Supplement Tricuspid Valve created from Right Atrioventricular Valve with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UJ3KZ" = "1" /* Supplement Tricuspid Valve with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UJ47G" = "1" /* Supplement Tricuspid Valve created from Right Atrioventricular Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UJ47Z" = "1" /* Supplement Tricuspid Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UJ48G" = "1" /* Supplement Tricuspid Valve created from Right Atrioventricular Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UJ48Z" = "1" /* Supplement Tricuspid Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UJ4JG" = "1" /* Supplement Tricuspid Valve created from Right Atrioventricular Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UJ4JZ" = "1" /* Supplement Tricuspid Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UJ4KG" = "1" /* Supplement Tricuspid Valve created from Right Atrioventricular Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UJ4KZ" = "1" /* Supplement Tricuspid Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UK07Z" = "1" /* Supplement Right Ventricle with Autologous Tissue Substitute, Open Approach */
"02UK08Z" = "1" /* Supplement Right Ventricle with Zooplastic Tissue, Open Approach */
"02UK0JZ" = "1" /* Supplement Right Ventricle with Synthetic Substitute, Open Approach */
"02UK0KZ" = "1" /* Supplement Right Ventricle with Nonautologous Tissue Substitute, Open Approach */
"02UK37Z" = "1" /* Supplement Right Ventricle with Autologous Tissue Substitute, Percutaneous Approach */
"02UK38Z" = "1" /* Supplement Right Ventricle with Zooplastic Tissue, Percutaneous Approach */
"02UK3JZ" = "1" /* Supplement Right Ventricle with Synthetic Substitute, Percutaneous Approach */
"02UK3KZ" = "1" /* Supplement Right Ventricle with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UK47Z" = "1" /* Supplement Right Ventricle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UK48Z" = "1" /* Supplement Right Ventricle with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UK4JZ" = "1" /* Supplement Right Ventricle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UK4KZ" = "1" /* Supplement Right Ventricle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UL07Z" = "1" /* Supplement Left Ventricle with Autologous Tissue Substitute, Open Approach */
"02UL08Z" = "1" /* Supplement Left Ventricle with Zooplastic Tissue, Open Approach */
"02UL0JZ" = "1" /* Supplement Left Ventricle with Synthetic Substitute, Open Approach */
"02UL0KZ" = "1" /* Supplement Left Ventricle with Nonautologous Tissue Substitute, Open Approach */
"02UL37Z" = "1" /* Supplement Left Ventricle with Autologous Tissue Substitute, Percutaneous Approach */
"02UL38Z" = "1" /* Supplement Left Ventricle with Zooplastic Tissue, Percutaneous Approach */
"02UL3JZ" = "1" /* Supplement Left Ventricle with Synthetic Substitute, Percutaneous Approach */
"02UL3KZ" = "1" /* Supplement Left Ventricle with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UL47Z" = "1" /* Supplement Left Ventricle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UL48Z" = "1" /* Supplement Left Ventricle with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UL4JZ" = "1" /* Supplement Left Ventricle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UL4KZ" = "1" /* Supplement Left Ventricle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UM07Z" = "1" /* Supplement Ventricular Septum with Autologous Tissue Substitute, Open Approach */
"02UM08Z" = "1" /* Supplement Ventricular Septum with Zooplastic Tissue, Open Approach */
"02UM0JZ" = "1" /* Supplement Ventricular Septum with Synthetic Substitute, Open Approach */
"02UM0KZ" = "1" /* Supplement Ventricular Septum with Nonautologous Tissue Substitute, Open Approach */
"02UM37Z" = "1" /* Supplement Ventricular Septum with Autologous Tissue Substitute, Percutaneous Approach */
"02UM38Z" = "1" /* Supplement Ventricular Septum with Zooplastic Tissue, Percutaneous Approach */
"02UM3JZ" = "1" /* Supplement Ventricular Septum with Synthetic Substitute, Percutaneous Approach */
"02UM3KZ" = "1" /* Supplement Ventricular Septum with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UM47Z" = "1" /* Supplement Ventricular Septum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UM48Z" = "1" /* Supplement Ventricular Septum with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UM4JZ" = "1" /* Supplement Ventricular Septum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UM4KZ" = "1" /* Supplement Ventricular Septum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UN07Z" = "1" /* Supplement Pericardium with Autologous Tissue Substitute, Open Approach */
"02UN08Z" = "1" /* Supplement Pericardium with Zooplastic Tissue, Open Approach */
"02UN0JZ" = "1" /* Supplement Pericardium with Synthetic Substitute, Open Approach */
"02UN0KZ" = "1" /* Supplement Pericardium with Nonautologous Tissue Substitute, Open Approach */
"02UN37Z" = "1" /* Supplement Pericardium with Autologous Tissue Substitute, Percutaneous Approach */
"02UN38Z" = "1" /* Supplement Pericardium with Zooplastic Tissue, Percutaneous Approach */
"02UN3JZ" = "1" /* Supplement Pericardium with Synthetic Substitute, Percutaneous Approach */
"02UN3KZ" = "1" /* Supplement Pericardium with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UN47Z" = "1" /* Supplement Pericardium with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UN48Z" = "1" /* Supplement Pericardium with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UN4JZ" = "1" /* Supplement Pericardium with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UN4KZ" = "1" /* Supplement Pericardium with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UP07Z" = "1" /* Supplement Pulmonary Trunk with Autologous Tissue Substitute, Open Approach */
"02UP08Z" = "1" /* Supplement Pulmonary Trunk with Zooplastic Tissue, Open Approach */
"02UP0JZ" = "1" /* Supplement Pulmonary Trunk with Synthetic Substitute, Open Approach */
"02UP0KZ" = "1" /* Supplement Pulmonary Trunk with Nonautologous Tissue Substitute, Open Approach */
"02UP37Z" = "1" /* Supplement Pulmonary Trunk with Autologous Tissue Substitute, Percutaneous Approach */
"02UP38Z" = "1" /* Supplement Pulmonary Trunk with Zooplastic Tissue, Percutaneous Approach */
"02UP3JZ" = "1" /* Supplement Pulmonary Trunk with Synthetic Substitute, Percutaneous Approach */
"02UP3KZ" = "1" /* Supplement Pulmonary Trunk with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UP47Z" = "1" /* Supplement Pulmonary Trunk with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UP48Z" = "1" /* Supplement Pulmonary Trunk with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UP4JZ" = "1" /* Supplement Pulmonary Trunk with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UP4KZ" = "1" /* Supplement Pulmonary Trunk with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UQ07Z" = "1" /* Supplement Right Pulmonary Artery with Autologous Tissue Substitute, Open Approach */
"02UQ08Z" = "1" /* Supplement Right Pulmonary Artery with Zooplastic Tissue, Open Approach */
"02UQ0JZ" = "1" /* Supplement Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"02UQ0KZ" = "1" /* Supplement Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"02UQ37Z" = "1" /* Supplement Right Pulmonary Artery with Autologous Tissue Substitute, Percutaneous Approach */
"02UQ38Z" = "1" /* Supplement Right Pulmonary Artery with Zooplastic Tissue, Percutaneous Approach */
"02UQ3JZ" = "1" /* Supplement Right Pulmonary Artery with Synthetic Substitute, Percutaneous Approach */
"02UQ3KZ" = "1" /* Supplement Right Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UQ47Z" = "1" /* Supplement Right Pulmonary Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UQ48Z" = "1" /* Supplement Right Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UQ4JZ" = "1" /* Supplement Right Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UQ4KZ" = "1" /* Supplement Right Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UR07Z" = "1" /* Supplement Left Pulmonary Artery with Autologous Tissue Substitute, Open Approach */
"02UR08Z" = "1" /* Supplement Left Pulmonary Artery with Zooplastic Tissue, Open Approach */
"02UR0JZ" = "1" /* Supplement Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"02UR0KZ" = "1" /* Supplement Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"02UR37Z" = "1" /* Supplement Left Pulmonary Artery with Autologous Tissue Substitute, Percutaneous Approach */
"02UR38Z" = "1" /* Supplement Left Pulmonary Artery with Zooplastic Tissue, Percutaneous Approach */
"02UR3JZ" = "1" /* Supplement Left Pulmonary Artery with Synthetic Substitute, Percutaneous Approach */
"02UR3KZ" = "1" /* Supplement Left Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UR47Z" = "1" /* Supplement Left Pulmonary Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UR48Z" = "1" /* Supplement Left Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UR4JZ" = "1" /* Supplement Left Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UR4KZ" = "1" /* Supplement Left Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02US07Z" = "1" /* Supplement Right Pulmonary Vein with Autologous Tissue Substitute, Open Approach */
"02US08Z" = "1" /* Supplement Right Pulmonary Vein with Zooplastic Tissue, Open Approach */
"02US0JZ" = "1" /* Supplement Right Pulmonary Vein with Synthetic Substitute, Open Approach */
"02US0KZ" = "1" /* Supplement Right Pulmonary Vein with Nonautologous Tissue Substitute, Open Approach */
"02US37Z" = "1" /* Supplement Right Pulmonary Vein with Autologous Tissue Substitute, Percutaneous Approach */
"02US38Z" = "1" /* Supplement Right Pulmonary Vein with Zooplastic Tissue, Percutaneous Approach */
"02US3JZ" = "1" /* Supplement Right Pulmonary Vein with Synthetic Substitute, Percutaneous Approach */
"02US3KZ" = "1" /* Supplement Right Pulmonary Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"02US47Z" = "1" /* Supplement Right Pulmonary Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02US48Z" = "1" /* Supplement Right Pulmonary Vein with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02US4JZ" = "1" /* Supplement Right Pulmonary Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02US4KZ" = "1" /* Supplement Right Pulmonary Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UT07Z" = "1" /* Supplement Left Pulmonary Vein with Autologous Tissue Substitute, Open Approach */
"02UT08Z" = "1" /* Supplement Left Pulmonary Vein with Zooplastic Tissue, Open Approach */
"02UT0JZ" = "1" /* Supplement Left Pulmonary Vein with Synthetic Substitute, Open Approach */
"02UT0KZ" = "1" /* Supplement Left Pulmonary Vein with Nonautologous Tissue Substitute, Open Approach */
"02UT37Z" = "1" /* Supplement Left Pulmonary Vein with Autologous Tissue Substitute, Percutaneous Approach */
"02UT38Z" = "1" /* Supplement Left Pulmonary Vein with Zooplastic Tissue, Percutaneous Approach */
"02UT3JZ" = "1" /* Supplement Left Pulmonary Vein with Synthetic Substitute, Percutaneous Approach */
"02UT3KZ" = "1" /* Supplement Left Pulmonary Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UT47Z" = "1" /* Supplement Left Pulmonary Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UT48Z" = "1" /* Supplement Left Pulmonary Vein with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UT4JZ" = "1" /* Supplement Left Pulmonary Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UT4KZ" = "1" /* Supplement Left Pulmonary Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UV07Z" = "1" /* Supplement Superior Vena Cava with Autologous Tissue Substitute, Open Approach */
"02UV08Z" = "1" /* Supplement Superior Vena Cava with Zooplastic Tissue, Open Approach */
"02UV0JZ" = "1" /* Supplement Superior Vena Cava with Synthetic Substitute, Open Approach */
"02UV0KZ" = "1" /* Supplement Superior Vena Cava with Nonautologous Tissue Substitute, Open Approach */
"02UV37Z" = "1" /* Supplement Superior Vena Cava with Autologous Tissue Substitute, Percutaneous Approach */
"02UV38Z" = "1" /* Supplement Superior Vena Cava with Zooplastic Tissue, Percutaneous Approach */
"02UV3JZ" = "1" /* Supplement Superior Vena Cava with Synthetic Substitute, Percutaneous Approach */
"02UV3KZ" = "1" /* Supplement Superior Vena Cava with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UV47Z" = "1" /* Supplement Superior Vena Cava with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UV48Z" = "1" /* Supplement Superior Vena Cava with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UV4JZ" = "1" /* Supplement Superior Vena Cava with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UV4KZ" = "1" /* Supplement Superior Vena Cava with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UW07Z" = "1" /* Supplement Thoracic Aorta, Decending, with Autologous Tissue Substitute, Open Approach */
"02UW08Z" = "1" /* Supplement Thoracic Aorta, Decending, with Zooplastic Tissue, Open Approach */
"02UW0JZ" = "1" /* Supplement Thoracic Aorta, Decending, with Synthetic Substitute, Open Approach */
"02UW0KZ" = "1" /* Supplement Thoracic Aorta, Decending, with Nonautologous Tissue Substitute, Open Approach */
"02UW37Z" = "1" /* Supplement Thoracic Aorta, Decending, with Autologous Tissue Substitute, Percutaneous Approach */
"02UW38Z" = "1" /* Supplement Thoracic Aorta, Decending, with Zooplastic Tissue, Percutaneous Approach */
"02UW3JZ" = "1" /* Supplement Thoracic Aorta, Decending, with Synthetic Substitute, Percutaneous Approach */
"02UW3KZ" = "1" /* Supplement Thoracic Aorta, Decending, with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UW47Z" = "1" /* Supplement Thoracic Aorta, Decending, with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UW48Z" = "1" /* Supplement Thoracic Aorta, Decending, with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UW4JZ" = "1" /* Supplement Thoracic Aorta, Decending, with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UW4KZ" = "1" /* Supplement Thoracic Aorta, Decending, with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UX07Z" = "1" /* Supplement Thoracic Aorta, Ascending/Arch with Autologous Tissue Substitute, Open Approach */
"02UX08Z" = "1" /* Supplement Thoracic Aorta, Ascending/Arch with Zooplastic Tissue, Open Approach */
"02UX0JZ" = "1" /* Supplement Thoracic Aorta, Ascending/Arch with Synthetic Substitute, Open Approach */
"02UX0KZ" = "1" /* Supplement Thoracic Aorta, Ascending/Arch with Nonautologous Tissue Substitute, Open Approach */
"02UX37Z" = "1" /* Supplement Thoracic Aorta, Ascending/Arch with Autologous Tissue Substitute, Percutaneous Approach */
"02UX38Z" = "1" /* Supplement Thoracic Aorta, Ascending/Arch with Zooplastic Tissue, Percutaneous Approach */
"02UX3JZ" = "1" /* Supplement Thoracic Aorta, Ascending/Arch with Synthetic Substitute, Percutaneous Approach */
"02UX3KZ" = "1" /* Supplement Thoracic Aorta, Ascending/Arch with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UX47Z" = "1" /* Supplement Thoracic Aorta, Ascending/Arch with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UX48Z" = "1" /* Supplement Thoracic Aorta, Ascending/Arch with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UX4JZ" = "1" /* Supplement Thoracic Aorta, Ascending/Arch with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UX4KZ" = "1" /* Supplement Thoracic Aorta, Ascending/Arch with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02VA0CZ" = "1" /* Restriction of Heart with Extraluminal Device, Open Approach */
"02VA0ZZ" = "1" /* Restriction of Heart, Open Approach */
"02VA3CZ" = "1" /* Restriction of Heart with Extraluminal Device, Percutaneous Approach */
"02VA3ZZ" = "1" /* Restriction of Heart, Percutaneous Approach */
"02VA4CZ" = "1" /* Restriction of Heart with Extraluminal Device, Percutaneous Endoscopic Approach */
"02VA4ZZ" = "1" /* Restriction of Heart, Percutaneous Endoscopic Approach */
"02VP0CZ" = "1" /* Restriction of Pulmonary Trunk with Extraluminal Device, Open Approach */
"02VP0DZ" = "1" /* Restriction of Pulmonary Trunk with Intraluminal Device, Open Approach */
"02VP0ZZ" = "1" /* Restriction of Pulmonary Trunk, Open Approach */
"02VP3CZ" = "1" /* Restriction of Pulmonary Trunk with Extraluminal Device, Percutaneous Approach */
"02VP3DZ" = "1" /* Restriction of Pulmonary Trunk with Intraluminal Device, Percutaneous Approach */
"02VP3ZZ" = "1" /* Restriction of Pulmonary Trunk, Percutaneous Approach */
"02VP4CZ" = "1" /* Restriction of Pulmonary Trunk with Extraluminal Device, Percutaneous Endoscopic Approach */
"02VP4DZ" = "1" /* Restriction of Pulmonary Trunk with Intraluminal Device, Percutaneous Endoscopic Approach */
"02VP4ZZ" = "1" /* Restriction of Pulmonary Trunk, Percutaneous Endoscopic Approach */
"02VQ0CZ" = "1" /* Restriction of Right Pulmonary Artery with Extraluminal Device, Open Approach */
"02VQ0DZ" = "1" /* Restriction of Right Pulmonary Artery with Intraluminal Device, Open Approach */
"02VQ0ZZ" = "1" /* Restriction of Right Pulmonary Artery, Open Approach */
"02VQ3CZ" = "1" /* Restriction of Right Pulmonary Artery with Extraluminal Device, Percutaneous Approach */
"02VQ3DZ" = "1" /* Restriction of Right Pulmonary Artery with Intraluminal Device, Percutaneous Approach */
"02VQ3ZZ" = "1" /* Restriction of Right Pulmonary Artery, Percutaneous Approach */
"02VQ4CZ" = "1" /* Restriction of Right Pulmonary Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"02VQ4DZ" = "1" /* Restriction of Right Pulmonary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"02VQ4ZZ" = "1" /* Restriction of Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"02VR0CT" = "1" /* Restriction of Ductus Arteriosus with Extraluminal Device, Open Approach */
"02VR0CZ" = "1" /* Restriction of Left Pulmonary Artery with Extraluminal Device, Open Approach */
"02VR0DT" = "1" /* Restriction of Ductus Arteriosus with Intraluminal Device, Open Approach */
"02VR0DZ" = "1" /* Restriction of Left Pulmonary Artery with Intraluminal Device, Open Approach */
"02VR0ZT" = "1" /* Restriction of Ductus Arteriosus, Open Approach */
"02VR0ZZ" = "1" /* Restriction of Left Pulmonary Artery, Open Approach */
"02VR3CT" = "1" /* Restriction of Ductus Arteriosus with Extraluminal Device, Percutaneous Approach */
"02VR3CZ" = "1" /* Restriction of Left Pulmonary Artery with Extraluminal Device, Percutaneous Approach */
"02VR3DT" = "1" /* Restriction of Ductus Arteriosus with Intraluminal Device, Percutaneous Approach */
"02VR3DZ" = "1" /* Restriction of Left Pulmonary Artery with Intraluminal Device, Percutaneous Approach */
"02VR3ZT" = "1" /* Restriction of Ductus Arteriosus, Percutaneous Approach */
"02VR3ZZ" = "1" /* Restriction of Left Pulmonary Artery, Percutaneous Approach */
"02VR4CT" = "1" /* Restriction of Ductus Arteriosus with Extraluminal Device, Percutaneous Endoscopic Approach */
"02VR4CZ" = "1" /* Restriction of Left Pulmonary Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"02VR4DT" = "1" /* Restriction of Ductus Arteriosus with Intraluminal Device, Percutaneous Endoscopic Approach */
"02VR4DZ" = "1" /* Restriction of Left Pulmonary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"02VR4ZT" = "1" /* Restriction of Ductus Arteriosus, Percutaneous Endoscopic Approach */
"02VR4ZZ" = "1" /* Restriction of Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"02VS0CZ" = "1" /* Restriction of Right Pulmonary Vein with Extraluminal Device, Open Approach */
"02VS0DZ" = "1" /* Restriction of Right Pulmonary Vein with Intraluminal Device, Open Approach */
"02VS0ZZ" = "1" /* Restriction of Right Pulmonary Vein, Open Approach */
"02VS3CZ" = "1" /* Restriction of Right Pulmonary Vein with Extraluminal Device, Percutaneous Approach */
"02VS3DZ" = "1" /* Restriction of Right Pulmonary Vein with Intraluminal Device, Percutaneous Approach */
"02VS3ZZ" = "1" /* Restriction of Right Pulmonary Vein, Percutaneous Approach */
"02VS4CZ" = "1" /* Restriction of Right Pulmonary Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"02VS4DZ" = "1" /* Restriction of Right Pulmonary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"02VS4ZZ" = "1" /* Restriction of Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"02VT0CZ" = "1" /* Restriction of Left Pulmonary Vein with Extraluminal Device, Open Approach */
"02VT0DZ" = "1" /* Restriction of Left Pulmonary Vein with Intraluminal Device, Open Approach */
"02VT0ZZ" = "1" /* Restriction of Left Pulmonary Vein, Open Approach */
"02VT3CZ" = "1" /* Restriction of Left Pulmonary Vein with Extraluminal Device, Percutaneous Approach */
"02VT3DZ" = "1" /* Restriction of Left Pulmonary Vein with Intraluminal Device, Percutaneous Approach */
"02VT3ZZ" = "1" /* Restriction of Left Pulmonary Vein, Percutaneous Approach */
"02VT4CZ" = "1" /* Restriction of Left Pulmonary Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"02VT4DZ" = "1" /* Restriction of Left Pulmonary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"02VT4ZZ" = "1" /* Restriction of Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"02VV0CZ" = "1" /* Restriction of Superior Vena Cava with Extraluminal Device, Open Approach */
"02VV0DZ" = "1" /* Restriction of Superior Vena Cava with Intraluminal Device, Open Approach */
"02VV0ZZ" = "1" /* Restriction of Superior Vena Cava, Open Approach */
"02VV3CZ" = "1" /* Restriction of Superior Vena Cava with Extraluminal Device, Percutaneous Approach */
"02VV3DZ" = "1" /* Restriction of Superior Vena Cava with Intraluminal Device, Percutaneous Approach */
"02VV3ZZ" = "1" /* Restriction of Superior Vena Cava, Percutaneous Approach */
"02VV4CZ" = "1" /* Restriction of Superior Vena Cava with Extraluminal Device, Percutaneous Endoscopic Approach */
"02VV4DZ" = "1" /* Restriction of Superior Vena Cava with Intraluminal Device, Percutaneous Endoscopic Approach */
"02VV4ZZ" = "1" /* Restriction of Superior Vena Cava, Percutaneous Endoscopic Approach */
"02VW0CZ" = "1" /* Restriction of Thoracic Aorta, Decending, with Extraluminal Device, Open Approach */
"02VW0DZ" = "1" /* Restriction of Thoracic Aorta, Decending, with Intraluminal Device, Open Approach */
"02VW0EZ" = "1" /* Restriction of Thoracic Aorta, Descending with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Open Approach */
"02VW0FZ" = "1" /* Restriction of Thoracic Aorta, Descending with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Open Approach */
"02VW0ZZ" = "1" /* Restriction of Thoracic Aorta, Decending, Open Approach */
"02VW3CZ" = "1" /* Restriction of Thoracic Aorta, Decending, with Extraluminal Device, Percutaneous Approach */
"02VW3DZ" = "1" /* Restriction of Thoracic Aorta, Decending, with Intraluminal Device, Percutaneous Approach */
"02VW3EZ" = "1" /* Restriction of Thoracic Aorta, Descending with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Percutaneous Approach */
"02VW3FZ" = "1" /* Restriction of Thoracic Aorta, Descending with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Percutaneous Approach */
"02VW3ZZ" = "1" /* Restriction of Thoracic Aorta, Decending, Percutaneous Approach */
"02VW4CZ" = "1" /* Restriction of Thoracic Aorta, Decending, with Extraluminal Device, Percutaneous Endoscopic Approach */
"02VW4DZ" = "1" /* Restriction of Thoracic Aorta, Decending, with Intraluminal Device, Percutaneous Endoscopic Approach */
"02VW4EZ" = "1" /* Restriction of Thoracic Aorta, Descending with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Percutaneous Endoscopic Approach */
"02VW4FZ" = "1" /* Restriction of Thoracic Aorta, Descending with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Percutaneous Endoscopic Approach */
"02VW4ZZ" = "1" /* Restriction of Thoracic Aorta, Decending, Percutaneous Endoscopic Approach */
"02VX0CZ" = "1" /* Restriction of Thoracic Aorta, Ascending/Arch with Extraluminal Device, Open Approach */
"02VX0DZ" = "1" /* Restriction of Thoracic Aorta, Ascending/Arch with Intraluminal Device, Open Approach */
"02VX0EZ" = "1" /* Restriction of Thoracic Aorta, Ascending/Arch with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Open Approach */
"02VX0FZ" = "1" /* Restriction of Thoracic Aorta, Ascending/Arch with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Open Approach */
"02VX0ZZ" = "1" /* Restriction of Thoracic Aorta, Ascending/Arch, Open Approach */
"02VX3CZ" = "1" /* Restriction of Thoracic Aorta, Ascending/Arch with Extraluminal Device, Percutaneous Approach */
"02VX3DZ" = "1" /* Restriction of Thoracic Aorta, Ascending/Arch with Intraluminal Device, Percutaneous Approach */
"02VX3EZ" = "1" /* Restriction of Thoracic Aorta, Ascending/Arch with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Percutaneous Approach */
"02VX3FZ" = "1" /* Restriction of Thoracic Aorta, Ascending/Arch with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Percutaneous Approach */
"02VX3ZZ" = "1" /* Restriction of Thoracic Aorta, Ascending/Arch, Percutaneous Approach */
"02VX4CZ" = "1" /* Restriction of Thoracic Aorta, Ascending/Arch with Extraluminal Device, Percutaneous Endoscopic Approach */
"02VX4DZ" = "1" /* Restriction of Thoracic Aorta, Ascending/Arch with Intraluminal Device, Percutaneous Endoscopic Approach */
"02VX4EZ" = "1" /* Restriction of Thoracic Aorta, Ascending/Arch with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Percutaneous Endoscopic Approach */
"02VX4FZ" = "1" /* Restriction of Thoracic Aorta, Ascending/Arch with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Percutaneous Endoscopic Approach */
"02VX4ZZ" = "1" /* Restriction of Thoracic Aorta, Ascending/Arch, Percutaneous Endoscopic Approach */
"02W50JZ" = "1" /* Revision of Synthetic Substitute in Atrial Septum, Open Approach */
"02W54JZ" = "1" /* Revision of Synthetic Substitute in Atrial Septum, Percutaneous Endoscopic Approach */
"02WA02Z" = "1" /* Revision of Monitoring Device in Heart, Open Approach */
"02WA03Z" = "1" /* Revision of Infusion Device in Heart, Open Approach */
"02WA07Z" = "1" /* Revision of Autologous Tissue Substitute in Heart, Open Approach */
"02WA08Z" = "1" /* Revision of Zooplastic Tissue in Heart, Open Approach */
"02WA0CZ" = "1" /* Revision of Extraluminal Device in Heart, Open Approach */
"02WA0DZ" = "1" /* Revision of Intraluminal Device in Heart, Open Approach */
"02WA0JZ" = "1" /* Revision of Synthetic Substitute in Heart, Open Approach */
"02WA0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Heart, Open Approach */
"02WA0MZ" = "1" /* Revision of Cardiac Lead in Heart, Open Approach */
"02WA0NZ" = "1" /* Revision of Intracardiac Pacemaker in Heart, Open Approach */
"02WA0QZ" = "1" /* Revision of Implantable Heart Assist System in Heart, Open Approach */
"02WA0RZ" = "1" /* Revision of External Heart Assist System in Heart, Open Approach */
"02WA37Z" = "1" /* Revision of Autologous Tissue Substitute in Heart, Percutaneous Approach */
"02WA38Z" = "1" /* Revision of Zooplastic Tissue in Heart, Percutaneous Approach */
"02WA3CZ" = "1" /* Revision of Extraluminal Device in Heart, Percutaneous Approach */
"02WA3JZ" = "1" /* Revision of Synthetic Substitute in Heart, Percutaneous Approach */
"02WA3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Heart, Percutaneous Approach */
"02WA3MZ" = "1" /* Revision of Cardiac Lead in Heart, Percutaneous Approach */
"02WA3NZ" = "1" /* Revision of Intracardiac Pacemaker in Heart, Percutaneous Approach */
"02WA3QZ" = "1" /* Revision of Implantable Heart Assist System in Heart, Percutaneous Approach */
"02WA3RZ" = "1" /* Revision of External Heart Assist System in Heart, Percutaneous Approach */
"02WA42Z" = "1" /* Revision of Monitoring Device in Heart, Percutaneous Endoscopic Approach */
"02WA43Z" = "1" /* Revision of Infusion Device in Heart, Percutaneous Endoscopic Approach */
"02WA47Z" = "1" /* Revision of Autologous Tissue Substitute in Heart, Percutaneous Endoscopic Approach */
"02WA48Z" = "1" /* Revision of Zooplastic Tissue in Heart, Percutaneous Endoscopic Approach */
"02WA4CZ" = "1" /* Revision of Extraluminal Device in Heart, Percutaneous Endoscopic Approach */
"02WA4DZ" = "1" /* Revision of Intraluminal Device in Heart, Percutaneous Endoscopic Approach */
"02WA4JZ" = "1" /* Revision of Synthetic Substitute in Heart, Percutaneous Endoscopic Approach */
"02WA4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Heart, Percutaneous Endoscopic Approach */
"02WA4MZ" = "1" /* Revision of Cardiac Lead in Heart, Percutaneous Endoscopic Approach */
"02WA4NZ" = "1" /* Revision of Intracardiac Pacemaker in Heart, Percutaneous Endoscopic Approach */
"02WA4QZ" = "1" /* Revision of Implantable Heart Assist System in Heart, Percutaneous Endoscopic Approach */
"02WA4RZ" = "1" /* Revision of External Heart Assist System in Heart, Percutaneous Endoscopic Approach */
"02WF07Z" = "1" /* Revision of Autologous Tissue Substitute in Aortic Valve, Open Approach */
"02WF08Z" = "1" /* Revision of Zooplastic Tissue in Aortic Valve, Open Approach */
"02WF0JZ" = "1" /* Revision of Synthetic Substitute in Aortic Valve, Open Approach */
"02WF0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Aortic Valve, Open Approach */
"02WF47Z" = "1" /* Revision of Autologous Tissue Substitute in Aortic Valve, Percutaneous Endoscopic Approach */
"02WF48Z" = "1" /* Revision of Zooplastic Tissue in Aortic Valve, Percutaneous Endoscopic Approach */
"02WF4JZ" = "1" /* Revision of Synthetic Substitute in Aortic Valve, Percutaneous Endoscopic Approach */
"02WF4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Aortic Valve, Percutaneous Endoscopic Approach */
"02WG07Z" = "1" /* Revision of Autologous Tissue Substitute in Mitral Valve, Open Approach */
"02WG08Z" = "1" /* Revision of Zooplastic Tissue in Mitral Valve, Open Approach */
"02WG0JZ" = "1" /* Revision of Synthetic Substitute in Mitral Valve, Open Approach */
"02WG0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mitral Valve, Open Approach */
"02WG47Z" = "1" /* Revision of Autologous Tissue Substitute in Mitral Valve, Percutaneous Endoscopic Approach */
"02WG48Z" = "1" /* Revision of Zooplastic Tissue in Mitral Valve, Percutaneous Endoscopic Approach */
"02WG4JZ" = "1" /* Revision of Synthetic Substitute in Mitral Valve, Percutaneous Endoscopic Approach */
"02WG4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mitral Valve, Percutaneous Endoscopic Approach */
"02WH07Z" = "1" /* Revision of Autologous Tissue Substitute in Pulmonary Valve, Open Approach */
"02WH08Z" = "1" /* Revision of Zooplastic Tissue in Pulmonary Valve, Open Approach */
"02WH0JZ" = "1" /* Revision of Synthetic Substitute in Pulmonary Valve, Open Approach */
"02WH0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Pulmonary Valve, Open Approach */
"02WH47Z" = "1" /* Revision of Autologous Tissue Substitute in Pulmonary Valve, Percutaneous Endoscopic Approach */
"02WH48Z" = "1" /* Revision of Zooplastic Tissue in Pulmonary Valve, Percutaneous Endoscopic Approach */
"02WH4JZ" = "1" /* Revision of Synthetic Substitute in Pulmonary Valve, Percutaneous Endoscopic Approach */
"02WH4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Pulmonary Valve, Percutaneous Endoscopic Approach */
"02WJ07Z" = "1" /* Revision of Autologous Tissue Substitute in Tricuspid Valve, Open Approach */
"02WJ08Z" = "1" /* Revision of Zooplastic Tissue in Tricuspid Valve, Open Approach */
"02WJ0JZ" = "1" /* Revision of Synthetic Substitute in Tricuspid Valve, Open Approach */
"02WJ0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Tricuspid Valve, Open Approach */
"02WJ47Z" = "1" /* Revision of Autologous Tissue Substitute in Tricuspid Valve, Percutaneous Endoscopic Approach */
"02WJ48Z" = "1" /* Revision of Zooplastic Tissue in Tricuspid Valve, Percutaneous Endoscopic Approach */
"02WJ4JZ" = "1" /* Revision of Synthetic Substitute in Tricuspid Valve, Percutaneous Endoscopic Approach */
"02WJ4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Tricuspid Valve, Percutaneous Endoscopic Approach */
"02WM0JZ" = "1" /* Revision of Synthetic Substitute in Ventricular Septum, Open Approach */
"02WM4JZ" = "1" /* Revision of Synthetic Substitute in Ventricular Septum, Percutaneous Endoscopic Approach */
"02WY02Z" = "1" /* Revision of Monitoring Device in Great Vessel, Open Approach */
"02WY03Z" = "1" /* Revision of Infusion Device in Great Vessel, Open Approach */
"02WY07Z" = "1" /* Revision of Autologous Tissue Substitute in Great Vessel, Open Approach */
"02WY08Z" = "1" /* Revision of Zooplastic Tissue in Great Vessel, Open Approach */
"02WY0CZ" = "1" /* Revision of Extraluminal Device in Great Vessel, Open Approach */
"02WY0DZ" = "1" /* Revision of Intraluminal Device in Great Vessel, Open Approach */
"02WY0JZ" = "1" /* Revision of Synthetic Substitute in Great Vessel, Open Approach */
"02WY0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Great Vessel, Open Approach */
"02WY37Z" = "1" /* Revision of Autologous Tissue Substitute in Great Vessel, Percutaneous Approach */
"02WY38Z" = "1" /* Revision of Zooplastic Tissue in Great Vessel, Percutaneous Approach */
"02WY3CZ" = "1" /* Revision of Extraluminal Device in Great Vessel, Percutaneous Approach */
"02WY3JZ" = "1" /* Revision of Synthetic Substitute in Great Vessel, Percutaneous Approach */
"02WY3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Great Vessel, Percutaneous Approach */
"02WY42Z" = "1" /* Revision of Monitoring Device in Great Vessel, Percutaneous Endoscopic Approach */
"02WY43Z" = "1" /* Revision of Infusion Device in Great Vessel, Percutaneous Endoscopic Approach */
"02WY47Z" = "1" /* Revision of Autologous Tissue Substitute in Great Vessel, Percutaneous Endoscopic Approach */
"02WY48Z" = "1" /* Revision of Zooplastic Tissue in Great Vessel, Percutaneous Endoscopic Approach */
"02WY4CZ" = "1" /* Revision of Extraluminal Device in Great Vessel, Percutaneous Endoscopic Approach */
"02WY4DZ" = "1" /* Revision of Intraluminal Device in Great Vessel, Percutaneous Endoscopic Approach */
"02WY4JZ" = "1" /* Revision of Synthetic Substitute in Great Vessel, Percutaneous Endoscopic Approach */
"02WY4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Great Vessel, Percutaneous Endoscopic Approach */
"02YA0Z0" = "1" /* Transplantation of Heart, Allogeneic, Open Approach */
"02YA0Z1" = "1" /* Transplantation of Heart, Syngeneic, Open Approach */
"02YA0Z2" = "1" /* Transplantation of Heart, Zooplastic, Open Approach */
"0312090" = "1" /* Bypass Innominate Artery to Right Upper Arm Artery with Autologous Venous Tissue, Open Approach */
"0312091" = "1" /* Bypass Innominate Artery to Left Upper Arm Artery with Autologous Venous Tissue, Open Approach */
"0312092" = "1" /* Bypass Innominate Artery to Bilateral Upper Arm Artery with Autologous Venous Tissue, Open Approach */
"0312093" = "1" /* Bypass Innominate Artery to Right Lower Arm Artery with Autologous Venous Tissue, Open Approach */
"0312094" = "1" /* Bypass Innominate Artery to Left Lower Arm Artery with Autologous Venous Tissue, Open Approach */
"0312095" = "1" /* Bypass Innominate Artery to Bilateral Lower Arm Artery with Autologous Venous Tissue, Open Approach */
"0312096" = "1" /* Bypass Innominate Artery to Right Upper Leg Artery with Autologous Venous Tissue, Open Approach */
"0312097" = "1" /* Bypass Innominate Artery to Left Upper Leg Artery with Autologous Venous Tissue, Open Approach */
"0312098" = "1" /* Bypass Innominate Artery to Bilateral Upper Leg Artery with Autologous Venous Tissue, Open Approach */
"0312099" = "1" /* Bypass Innominate Artery to Right Lower Leg Artery with Autologous Venous Tissue, Open Approach */
"031209B" = "1" /* Bypass Innominate Artery to Left Lower Leg Artery with Autologous Venous Tissue, Open Approach */
"031209C" = "1" /* Bypass Innominate Artery to Bilateral Lower Leg Artery with Autologous Venous Tissue, Open Approach */
"031209D" = "1" /* Bypass Innominate Artery to Upper Arm Vein with Autologous Venous Tissue, Open Approach */
"031209F" = "1" /* Bypass Innominate Artery to Lower Arm Vein with Autologous Venous Tissue, Open Approach */
"031209J" = "1" /* Bypass Innominate Artery to Right Extracranial Artery with Autologous Venous Tissue, Open Approach */
"031209K" = "1" /* Bypass Innominate Artery to Left Extracranial Artery with Autologous Venous Tissue, Open Approach */
"03120A0" = "1" /* Bypass Innominate Artery to Right Upper Arm Artery with Autologous Arterial Tissue, Open Approach */
"03120A1" = "1" /* Bypass Innominate Artery to Left Upper Arm Artery with Autologous Arterial Tissue, Open Approach */
"03120A2" = "1" /* Bypass Innominate Artery to Bilateral Upper Arm Artery with Autologous Arterial Tissue, Open Approach */
"03120A3" = "1" /* Bypass Innominate Artery to Right Lower Arm Artery with Autologous Arterial Tissue, Open Approach */
"03120A4" = "1" /* Bypass Innominate Artery to Left Lower Arm Artery with Autologous Arterial Tissue, Open Approach */
"03120A5" = "1" /* Bypass Innominate Artery to Bilateral Lower Arm Artery with Autologous Arterial Tissue, Open Approach */
"03120A6" = "1" /* Bypass Innominate Artery to Right Upper Leg Artery with Autologous Arterial Tissue, Open Approach */
"03120A7" = "1" /* Bypass Innominate Artery to Left Upper Leg Artery with Autologous Arterial Tissue, Open Approach */
"03120A8" = "1" /* Bypass Innominate Artery to Bilateral Upper Leg Artery with Autologous Arterial Tissue, Open Approach */
"03120A9" = "1" /* Bypass Innominate Artery to Right Lower Leg Artery with Autologous Arterial Tissue, Open Approach */
"03120AB" = "1" /* Bypass Innominate Artery to Left Lower Leg Artery with Autologous Arterial Tissue, Open Approach */
"03120AC" = "1" /* Bypass Innominate Artery to Bilateral Lower Leg Artery with Autologous Arterial Tissue, Open Approach */
"03120AD" = "1" /* Bypass Innominate Artery to Upper Arm Vein with Autologous Arterial Tissue, Open Approach */
"03120AF" = "1" /* Bypass Innominate Artery to Lower Arm Vein with Autologous Arterial Tissue, Open Approach */
"03120AJ" = "1" /* Bypass Innominate Artery to Right Extracranial Artery with Autologous Arterial Tissue, Open Approach */
"03120AK" = "1" /* Bypass Innominate Artery to Left Extracranial Artery with Autologous Arterial Tissue, Open Approach */
"03120J0" = "1" /* Bypass Innominate Artery to Right Upper Arm Artery with Synthetic Substitute, Open Approach */
"03120J1" = "1" /* Bypass Innominate Artery to Left Upper Arm Artery with Synthetic Substitute, Open Approach */
"03120J2" = "1" /* Bypass Innominate Artery to Bilateral Upper Arm Artery with Synthetic Substitute, Open Approach */
"03120J3" = "1" /* Bypass Innominate Artery to Right Lower Arm Artery with Synthetic Substitute, Open Approach */
"03120J4" = "1" /* Bypass Innominate Artery to Left Lower Arm Artery with Synthetic Substitute, Open Approach */
"03120J5" = "1" /* Bypass Innominate Artery to Bilateral Lower Arm Artery with Synthetic Substitute, Open Approach */
"03120J6" = "1" /* Bypass Innominate Artery to Right Upper Leg Artery with Synthetic Substitute, Open Approach */
"03120J7" = "1" /* Bypass Innominate Artery to Left Upper Leg Artery with Synthetic Substitute, Open Approach */
"03120J8" = "1" /* Bypass Innominate Artery to Bilateral Upper Leg Artery with Synthetic Substitute, Open Approach */
"03120J9" = "1" /* Bypass Innominate Artery to Right Lower Leg Artery with Synthetic Substitute, Open Approach */
"03120JB" = "1" /* Bypass Innominate Artery to Left Lower Leg Artery with Synthetic Substitute, Open Approach */
"03120JC" = "1" /* Bypass Innominate Artery to Bilateral Lower Leg Artery with Synthetic Substitute, Open Approach */
"03120JD" = "1" /* Bypass Innominate Artery to Upper Arm Vein with Synthetic Substitute, Open Approach */
"03120JF" = "1" /* Bypass Innominate Artery to Lower Arm Vein with Synthetic Substitute, Open Approach */
"03120JJ" = "1" /* Bypass Innominate Artery to Right Extracranial Artery with Synthetic Substitute, Open Approach */
"03120JK" = "1" /* Bypass Innominate Artery to Left Extracranial Artery with Synthetic Substitute, Open Approach */
"03120K0" = "1" /* Bypass Innominate Artery to Right Upper Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03120K1" = "1" /* Bypass Innominate Artery to Left Upper Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03120K2" = "1" /* Bypass Innominate Artery to Bilateral Upper Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03120K3" = "1" /* Bypass Innominate Artery to Right Lower Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03120K4" = "1" /* Bypass Innominate Artery to Left Lower Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03120K5" = "1" /* Bypass Innominate Artery to Bilateral Lower Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03120K6" = "1" /* Bypass Innominate Artery to Right Upper Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03120K7" = "1" /* Bypass Innominate Artery to Left Upper Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03120K8" = "1" /* Bypass Innominate Artery to Bilateral Upper Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03120K9" = "1" /* Bypass Innominate Artery to Right Lower Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03120KB" = "1" /* Bypass Innominate Artery to Left Lower Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03120KC" = "1" /* Bypass Innominate Artery to Bilateral Lower Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03120KD" = "1" /* Bypass Innominate Artery to Upper Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03120KF" = "1" /* Bypass Innominate Artery to Lower Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03120KJ" = "1" /* Bypass Innominate Artery to Right Extracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"03120KK" = "1" /* Bypass Innominate Artery to Left Extracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"03120Z0" = "1" /* Bypass Innominate Artery to Right Upper Arm Artery, Open Approach */
"03120Z1" = "1" /* Bypass Innominate Artery to Left Upper Arm Artery, Open Approach */
"03120Z2" = "1" /* Bypass Innominate Artery to Bilateral Upper Arm Artery, Open Approach */
"03120Z3" = "1" /* Bypass Innominate Artery to Right Lower Arm Artery, Open Approach */
"03120Z4" = "1" /* Bypass Innominate Artery to Left Lower Arm Artery, Open Approach */
"03120Z5" = "1" /* Bypass Innominate Artery to Bilateral Lower Arm Artery, Open Approach */
"03120Z6" = "1" /* Bypass Innominate Artery to Right Upper Leg Artery, Open Approach */
"03120Z7" = "1" /* Bypass Innominate Artery to Left Upper Leg Artery, Open Approach */
"03120Z8" = "1" /* Bypass Innominate Artery to Bilateral Upper Leg Artery, Open Approach */
"03120Z9" = "1" /* Bypass Innominate Artery to Right Lower Leg Artery, Open Approach */
"03120ZB" = "1" /* Bypass Innominate Artery to Left Lower Leg Artery, Open Approach */
"03120ZC" = "1" /* Bypass Innominate Artery to Bilateral Lower Leg Artery, Open Approach */
"03120ZD" = "1" /* Bypass Innominate Artery to Upper Arm Vein, Open Approach */
"03120ZF" = "1" /* Bypass Innominate Artery to Lower Arm Vein, Open Approach */
"03120ZJ" = "1" /* Bypass Innominate Artery to Right Extracranial Artery, Open Approach */
"03120ZK" = "1" /* Bypass Innominate Artery to Left Extracranial Artery, Open Approach */
"0313090" = "1" /* Bypass Right Subclavian Artery to Right Upper Arm Artery with Autologous Venous Tissue, Open Approach */
"0313091" = "1" /* Bypass Right Subclavian Artery to Left Upper Arm Artery with Autologous Venous Tissue, Open Approach */
"0313092" = "1" /* Bypass Right Subclavian Artery to Bilateral Upper Arm Artery with Autologous Venous Tissue, Open Approach */
"0313093" = "1" /* Bypass Right Subclavian Artery to Right Lower Arm Artery with Autologous Venous Tissue, Open Approach */
"0313094" = "1" /* Bypass Right Subclavian Artery to Left Lower Arm Artery with Autologous Venous Tissue, Open Approach */
"0313095" = "1" /* Bypass Right Subclavian Artery to Bilateral Lower Arm Artery with Autologous Venous Tissue, Open Approach */
"0313096" = "1" /* Bypass Right Subclavian Artery to Right Upper Leg Artery with Autologous Venous Tissue, Open Approach */
"0313097" = "1" /* Bypass Right Subclavian Artery to Left Upper Leg Artery with Autologous Venous Tissue, Open Approach */
"0313098" = "1" /* Bypass Right Subclavian Artery to Bilateral Upper Leg Artery with Autologous Venous Tissue, Open Approach */
"0313099" = "1" /* Bypass Right Subclavian Artery to Right Lower Leg Artery with Autologous Venous Tissue, Open Approach */
"031309B" = "1" /* Bypass Right Subclavian Artery to Left Lower Leg Artery with Autologous Venous Tissue, Open Approach */
"031309C" = "1" /* Bypass Right Subclavian Artery to Bilateral Lower Leg Artery with Autologous Venous Tissue, Open Approach */
"031309D" = "1" /* Bypass Right Subclavian Artery to Upper Arm Vein with Autologous Venous Tissue, Open Approach */
"031309F" = "1" /* Bypass Right Subclavian Artery to Lower Arm Vein with Autologous Venous Tissue, Open Approach */
"031309J" = "1" /* Bypass Right Subclavian Artery to Right Extracranial Artery with Autologous Venous Tissue, Open Approach */
"031309K" = "1" /* Bypass Right Subclavian Artery to Left Extracranial Artery with Autologous Venous Tissue, Open Approach */
"031309M" = "1" /* Bypass Right Subclavian Artery to Right Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"031309N" = "1" /* Bypass Right Subclavian Artery to Left Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"03130A0" = "1" /* Bypass Right Subclavian Artery to Right Upper Arm Artery with Autologous Arterial Tissue, Open Approach */
"03130A1" = "1" /* Bypass Right Subclavian Artery to Left Upper Arm Artery with Autologous Arterial Tissue, Open Approach */
"03130A2" = "1" /* Bypass Right Subclavian Artery to Bilateral Upper Arm Artery with Autologous Arterial Tissue, Open Approach */
"03130A3" = "1" /* Bypass Right Subclavian Artery to Right Lower Arm Artery with Autologous Arterial Tissue, Open Approach */
"03130A4" = "1" /* Bypass Right Subclavian Artery to Left Lower Arm Artery with Autologous Arterial Tissue, Open Approach */
"03130A5" = "1" /* Bypass Right Subclavian Artery to Bilateral Lower Arm Artery with Autologous Arterial Tissue, Open Approach */
"03130A6" = "1" /* Bypass Right Subclavian Artery to Right Upper Leg Artery with Autologous Arterial Tissue, Open Approach */
"03130A7" = "1" /* Bypass Right Subclavian Artery to Left Upper Leg Artery with Autologous Arterial Tissue, Open Approach */
"03130A8" = "1" /* Bypass Right Subclavian Artery to Bilateral Upper Leg Artery with Autologous Arterial Tissue, Open Approach */
"03130A9" = "1" /* Bypass Right Subclavian Artery to Right Lower Leg Artery with Autologous Arterial Tissue, Open Approach */
"03130AB" = "1" /* Bypass Right Subclavian Artery to Left Lower Leg Artery with Autologous Arterial Tissue, Open Approach */
"03130AC" = "1" /* Bypass Right Subclavian Artery to Bilateral Lower Leg Artery with Autologous Arterial Tissue, Open Approach */
"03130AD" = "1" /* Bypass Right Subclavian Artery to Upper Arm Vein with Autologous Arterial Tissue, Open Approach */
"03130AF" = "1" /* Bypass Right Subclavian Artery to Lower Arm Vein with Autologous Arterial Tissue, Open Approach */
"03130AJ" = "1" /* Bypass Right Subclavian Artery to Right Extracranial Artery with Autologous Arterial Tissue, Open Approach */
"03130AK" = "1" /* Bypass Right Subclavian Artery to Left Extracranial Artery with Autologous Arterial Tissue, Open Approach */
"03130AM" = "1" /* Bypass Right Subclavian Artery to Right Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"03130AN" = "1" /* Bypass Right Subclavian Artery to Left Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"03130J0" = "1" /* Bypass Right Subclavian Artery to Right Upper Arm Artery with Synthetic Substitute, Open Approach */
"03130J1" = "1" /* Bypass Right Subclavian Artery to Left Upper Arm Artery with Synthetic Substitute, Open Approach */
"03130J2" = "1" /* Bypass Right Subclavian Artery to Bilateral Upper Arm Artery with Synthetic Substitute, Open Approach */
"03130J3" = "1" /* Bypass Right Subclavian Artery to Right Lower Arm Artery with Synthetic Substitute, Open Approach */
"03130J4" = "1" /* Bypass Right Subclavian Artery to Left Lower Arm Artery with Synthetic Substitute, Open Approach */
"03130J5" = "1" /* Bypass Right Subclavian Artery to Bilateral Lower Arm Artery with Synthetic Substitute, Open Approach */
"03130J6" = "1" /* Bypass Right Subclavian Artery to Right Upper Leg Artery with Synthetic Substitute, Open Approach */
"03130J7" = "1" /* Bypass Right Subclavian Artery to Left Upper Leg Artery with Synthetic Substitute, Open Approach */
"03130J8" = "1" /* Bypass Right Subclavian Artery to Bilateral Upper Leg Artery with Synthetic Substitute, Open Approach */
"03130J9" = "1" /* Bypass Right Subclavian Artery to Right Lower Leg Artery with Synthetic Substitute, Open Approach */
"03130JB" = "1" /* Bypass Right Subclavian Artery to Left Lower Leg Artery with Synthetic Substitute, Open Approach */
"03130JC" = "1" /* Bypass Right Subclavian Artery to Bilateral Lower Leg Artery with Synthetic Substitute, Open Approach */
"03130JD" = "1" /* Bypass Right Subclavian Artery to Upper Arm Vein with Synthetic Substitute, Open Approach */
"03130JF" = "1" /* Bypass Right Subclavian Artery to Lower Arm Vein with Synthetic Substitute, Open Approach */
"03130JJ" = "1" /* Bypass Right Subclavian Artery to Right Extracranial Artery with Synthetic Substitute, Open Approach */
"03130JK" = "1" /* Bypass Right Subclavian Artery to Left Extracranial Artery with Synthetic Substitute, Open Approach */
"03130JM" = "1" /* Bypass Right Subclavian Artery to Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"03130JN" = "1" /* Bypass Right Subclavian Artery to Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"03130K0" = "1" /* Bypass Right Subclavian Artery to Right Upper Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03130K1" = "1" /* Bypass Right Subclavian Artery to Left Upper Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03130K2" = "1" /* Bypass Right Subclavian Artery to Bilateral Upper Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03130K3" = "1" /* Bypass Right Subclavian Artery to Right Lower Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03130K4" = "1" /* Bypass Right Subclavian Artery to Left Lower Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03130K5" = "1" /* Bypass Right Subclavian Artery to Bilateral Lower Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03130K6" = "1" /* Bypass Right Subclavian Artery to Right Upper Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03130K7" = "1" /* Bypass Right Subclavian Artery to Left Upper Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03130K8" = "1" /* Bypass Right Subclavian Artery to Bilateral Upper Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03130K9" = "1" /* Bypass Right Subclavian Artery to Right Lower Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03130KB" = "1" /* Bypass Right Subclavian Artery to Left Lower Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03130KC" = "1" /* Bypass Right Subclavian Artery to Bilateral Lower Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03130KD" = "1" /* Bypass Right Subclavian Artery to Upper Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03130KF" = "1" /* Bypass Right Subclavian Artery to Lower Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03130KJ" = "1" /* Bypass Right Subclavian Artery to Right Extracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"03130KK" = "1" /* Bypass Right Subclavian Artery to Left Extracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"03130KM" = "1" /* Bypass Right Subclavian Artery to Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"03130KN" = "1" /* Bypass Right Subclavian Artery to Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"03130Z0" = "1" /* Bypass Right Subclavian Artery to Right Upper Arm Artery, Open Approach */
"03130Z1" = "1" /* Bypass Right Subclavian Artery to Left Upper Arm Artery, Open Approach */
"03130Z2" = "1" /* Bypass Right Subclavian Artery to Bilateral Upper Arm Artery, Open Approach */
"03130Z3" = "1" /* Bypass Right Subclavian Artery to Right Lower Arm Artery, Open Approach */
"03130Z4" = "1" /* Bypass Right Subclavian Artery to Left Lower Arm Artery, Open Approach */
"03130Z5" = "1" /* Bypass Right Subclavian Artery to Bilateral Lower Arm Artery, Open Approach */
"03130Z6" = "1" /* Bypass Right Subclavian Artery to Right Upper Leg Artery, Open Approach */
"03130Z7" = "1" /* Bypass Right Subclavian Artery to Left Upper Leg Artery, Open Approach */
"03130Z8" = "1" /* Bypass Right Subclavian Artery to Bilateral Upper Leg Artery, Open Approach */
"03130Z9" = "1" /* Bypass Right Subclavian Artery to Right Lower Leg Artery, Open Approach */
"03130ZB" = "1" /* Bypass Right Subclavian Artery to Left Lower Leg Artery, Open Approach */
"03130ZC" = "1" /* Bypass Right Subclavian Artery to Bilateral Lower Leg Artery, Open Approach */
"03130ZD" = "1" /* Bypass Right Subclavian Artery to Upper Arm Vein, Open Approach */
"03130ZF" = "1" /* Bypass Right Subclavian Artery to Lower Arm Vein, Open Approach */
"03130ZJ" = "1" /* Bypass Right Subclavian Artery to Right Extracranial Artery, Open Approach */
"03130ZK" = "1" /* Bypass Right Subclavian Artery to Left Extracranial Artery, Open Approach */
"03130ZM" = "1" /* Bypass Right Subclavian Artery to Right Pulmonary Artery, Open Approach */
"03130ZN" = "1" /* Bypass Right Subclavian Artery to Left Pulmonary Artery, Open Approach */
"0314090" = "1" /* Bypass Left Subclavian Artery to Right Upper Arm Artery with Autologous Venous Tissue, Open Approach */
"0314091" = "1" /* Bypass Left Subclavian Artery to Left Upper Arm Artery with Autologous Venous Tissue, Open Approach */
"0314092" = "1" /* Bypass Left Subclavian Artery to Bilateral Upper Arm Artery with Autologous Venous Tissue, Open Approach */
"0314093" = "1" /* Bypass Left Subclavian Artery to Right Lower Arm Artery with Autologous Venous Tissue, Open Approach */
"0314094" = "1" /* Bypass Left Subclavian Artery to Left Lower Arm Artery with Autologous Venous Tissue, Open Approach */
"0314095" = "1" /* Bypass Left Subclavian Artery to Bilateral Lower Arm Artery with Autologous Venous Tissue, Open Approach */
"0314096" = "1" /* Bypass Left Subclavian Artery to Right Upper Leg Artery with Autologous Venous Tissue, Open Approach */
"0314097" = "1" /* Bypass Left Subclavian Artery to Left Upper Leg Artery with Autologous Venous Tissue, Open Approach */
"0314098" = "1" /* Bypass Left Subclavian Artery to Bilateral Upper Leg Artery with Autologous Venous Tissue, Open Approach */
"0314099" = "1" /* Bypass Left Subclavian Artery to Right Lower Leg Artery with Autologous Venous Tissue, Open Approach */
"031409B" = "1" /* Bypass Left Subclavian Artery to Left Lower Leg Artery with Autologous Venous Tissue, Open Approach */
"031409C" = "1" /* Bypass Left Subclavian Artery to Bilateral Lower Leg Artery with Autologous Venous Tissue, Open Approach */
"031409D" = "1" /* Bypass Left Subclavian Artery to Upper Arm Vein with Autologous Venous Tissue, Open Approach */
"031409F" = "1" /* Bypass Left Subclavian Artery to Lower Arm Vein with Autologous Venous Tissue, Open Approach */
"031409J" = "1" /* Bypass Left Subclavian Artery to Right Extracranial Artery with Autologous Venous Tissue, Open Approach */
"031409K" = "1" /* Bypass Left Subclavian Artery to Left Extracranial Artery with Autologous Venous Tissue, Open Approach */
"031409M" = "1" /* Bypass Left Subclavian Artery to Right Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"031409N" = "1" /* Bypass Left Subclavian Artery to Left Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"03140A0" = "1" /* Bypass Left Subclavian Artery to Right Upper Arm Artery with Autologous Arterial Tissue, Open Approach */
"03140A1" = "1" /* Bypass Left Subclavian Artery to Left Upper Arm Artery with Autologous Arterial Tissue, Open Approach */
"03140A2" = "1" /* Bypass Left Subclavian Artery to Bilateral Upper Arm Artery with Autologous Arterial Tissue, Open Approach */
"03140A3" = "1" /* Bypass Left Subclavian Artery to Right Lower Arm Artery with Autologous Arterial Tissue, Open Approach */
"03140A4" = "1" /* Bypass Left Subclavian Artery to Left Lower Arm Artery with Autologous Arterial Tissue, Open Approach */
"03140A5" = "1" /* Bypass Left Subclavian Artery to Bilateral Lower Arm Artery with Autologous Arterial Tissue, Open Approach */
"03140A6" = "1" /* Bypass Left Subclavian Artery to Right Upper Leg Artery with Autologous Arterial Tissue, Open Approach */
"03140A7" = "1" /* Bypass Left Subclavian Artery to Left Upper Leg Artery with Autologous Arterial Tissue, Open Approach */
"03140A8" = "1" /* Bypass Left Subclavian Artery to Bilateral Upper Leg Artery with Autologous Arterial Tissue, Open Approach */
"03140A9" = "1" /* Bypass Left Subclavian Artery to Right Lower Leg Artery with Autologous Arterial Tissue, Open Approach */
"03140AB" = "1" /* Bypass Left Subclavian Artery to Left Lower Leg Artery with Autologous Arterial Tissue, Open Approach */
"03140AC" = "1" /* Bypass Left Subclavian Artery to Bilateral Lower Leg Artery with Autologous Arterial Tissue, Open Approach */
"03140AD" = "1" /* Bypass Left Subclavian Artery to Upper Arm Vein with Autologous Arterial Tissue, Open Approach */
"03140AF" = "1" /* Bypass Left Subclavian Artery to Lower Arm Vein with Autologous Arterial Tissue, Open Approach */
"03140AJ" = "1" /* Bypass Left Subclavian Artery to Right Extracranial Artery with Autologous Arterial Tissue, Open Approach */
"03140AK" = "1" /* Bypass Left Subclavian Artery to Left Extracranial Artery with Autologous Arterial Tissue, Open Approach */
"03140AM" = "1" /* Bypass Left Subclavian Artery to Right Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"03140AN" = "1" /* Bypass Left Subclavian Artery to Left Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"03140J0" = "1" /* Bypass Left Subclavian Artery to Right Upper Arm Artery with Synthetic Substitute, Open Approach */
"03140J1" = "1" /* Bypass Left Subclavian Artery to Left Upper Arm Artery with Synthetic Substitute, Open Approach */
"03140J2" = "1" /* Bypass Left Subclavian Artery to Bilateral Upper Arm Artery with Synthetic Substitute, Open Approach */
"03140J3" = "1" /* Bypass Left Subclavian Artery to Right Lower Arm Artery with Synthetic Substitute, Open Approach */
"03140J4" = "1" /* Bypass Left Subclavian Artery to Left Lower Arm Artery with Synthetic Substitute, Open Approach */
"03140J5" = "1" /* Bypass Left Subclavian Artery to Bilateral Lower Arm Artery with Synthetic Substitute, Open Approach */
"03140J6" = "1" /* Bypass Left Subclavian Artery to Right Upper Leg Artery with Synthetic Substitute, Open Approach */
"03140J7" = "1" /* Bypass Left Subclavian Artery to Left Upper Leg Artery with Synthetic Substitute, Open Approach */
"03140J8" = "1" /* Bypass Left Subclavian Artery to Bilateral Upper Leg Artery with Synthetic Substitute, Open Approach */
"03140J9" = "1" /* Bypass Left Subclavian Artery to Right Lower Leg Artery with Synthetic Substitute, Open Approach */
"03140JB" = "1" /* Bypass Left Subclavian Artery to Left Lower Leg Artery with Synthetic Substitute, Open Approach */
"03140JC" = "1" /* Bypass Left Subclavian Artery to Bilateral Lower Leg Artery with Synthetic Substitute, Open Approach */
"03140JD" = "1" /* Bypass Left Subclavian Artery to Upper Arm Vein with Synthetic Substitute, Open Approach */
"03140JF" = "1" /* Bypass Left Subclavian Artery to Lower Arm Vein with Synthetic Substitute, Open Approach */
"03140JJ" = "1" /* Bypass Left Subclavian Artery to Right Extracranial Artery with Synthetic Substitute, Open Approach */
"03140JK" = "1" /* Bypass Left Subclavian Artery to Left Extracranial Artery with Synthetic Substitute, Open Approach */
"03140JM" = "1" /* Bypass Left Subclavian Artery to Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"03140JN" = "1" /* Bypass Left Subclavian Artery to Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"03140K0" = "1" /* Bypass Left Subclavian Artery to Right Upper Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03140K1" = "1" /* Bypass Left Subclavian Artery to Left Upper Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03140K2" = "1" /* Bypass Left Subclavian Artery to Bilateral Upper Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03140K3" = "1" /* Bypass Left Subclavian Artery to Right Lower Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03140K4" = "1" /* Bypass Left Subclavian Artery to Left Lower Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03140K5" = "1" /* Bypass Left Subclavian Artery to Bilateral Lower Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03140K6" = "1" /* Bypass Left Subclavian Artery to Right Upper Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03140K7" = "1" /* Bypass Left Subclavian Artery to Left Upper Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03140K8" = "1" /* Bypass Left Subclavian Artery to Bilateral Upper Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03140K9" = "1" /* Bypass Left Subclavian Artery to Right Lower Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03140KB" = "1" /* Bypass Left Subclavian Artery to Left Lower Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03140KC" = "1" /* Bypass Left Subclavian Artery to Bilateral Lower Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03140KD" = "1" /* Bypass Left Subclavian Artery to Upper Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03140KF" = "1" /* Bypass Left Subclavian Artery to Lower Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03140KJ" = "1" /* Bypass Left Subclavian Artery to Right Extracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"03140KK" = "1" /* Bypass Left Subclavian Artery to Left Extracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"03140KM" = "1" /* Bypass Left Subclavian Artery to Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"03140KN" = "1" /* Bypass Left Subclavian Artery to Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"03140Z0" = "1" /* Bypass Left Subclavian Artery to Right Upper Arm Artery, Open Approach */
"03140Z1" = "1" /* Bypass Left Subclavian Artery to Left Upper Arm Artery, Open Approach */
"03140Z2" = "1" /* Bypass Left Subclavian Artery to Bilateral Upper Arm Artery, Open Approach */
"03140Z3" = "1" /* Bypass Left Subclavian Artery to Right Lower Arm Artery, Open Approach */
"03140Z4" = "1" /* Bypass Left Subclavian Artery to Left Lower Arm Artery, Open Approach */
"03140Z5" = "1" /* Bypass Left Subclavian Artery to Bilateral Lower Arm Artery, Open Approach */
"03140Z6" = "1" /* Bypass Left Subclavian Artery to Right Upper Leg Artery, Open Approach */
"03140Z7" = "1" /* Bypass Left Subclavian Artery to Left Upper Leg Artery, Open Approach */
"03140Z8" = "1" /* Bypass Left Subclavian Artery to Bilateral Upper Leg Artery, Open Approach */
"03140Z9" = "1" /* Bypass Left Subclavian Artery to Right Lower Leg Artery, Open Approach */
"03140ZB" = "1" /* Bypass Left Subclavian Artery to Left Lower Leg Artery, Open Approach */
"03140ZC" = "1" /* Bypass Left Subclavian Artery to Bilateral Lower Leg Artery, Open Approach */
"03140ZD" = "1" /* Bypass Left Subclavian Artery to Upper Arm Vein, Open Approach */
"03140ZF" = "1" /* Bypass Left Subclavian Artery to Lower Arm Vein, Open Approach */
"03140ZJ" = "1" /* Bypass Left Subclavian Artery to Right Extracranial Artery, Open Approach */
"03140ZK" = "1" /* Bypass Left Subclavian Artery to Left Extracranial Artery, Open Approach */
"03140ZM" = "1" /* Bypass Left Subclavian Artery to Right Pulmonary Artery, Open Approach */
"03140ZN" = "1" /* Bypass Left Subclavian Artery to Left Pulmonary Artery, Open Approach */
"0315090" = "1" /* Bypass Right Axillary Artery to Right Upper Arm Artery with Autologous Venous Tissue, Open Approach */
"0315091" = "1" /* Bypass Right Axillary Artery to Left Upper Arm Artery with Autologous Venous Tissue, Open Approach */
"0315092" = "1" /* Bypass Right Axillary Artery to Bilateral Upper Arm Artery with Autologous Venous Tissue, Open Approach */
"0315093" = "1" /* Bypass Right Axillary Artery to Right Lower Arm Artery with Autologous Venous Tissue, Open Approach */
"0315094" = "1" /* Bypass Right Axillary Artery to Left Lower Arm Artery with Autologous Venous Tissue, Open Approach */
"0315095" = "1" /* Bypass Right Axillary Artery to Bilateral Lower Arm Artery with Autologous Venous Tissue, Open Approach */
"0315096" = "1" /* Bypass Right Axillary Artery to Right Upper Leg Artery with Autologous Venous Tissue, Open Approach */
"0315097" = "1" /* Bypass Right Axillary Artery to Left Upper Leg Artery with Autologous Venous Tissue, Open Approach */
"0315098" = "1" /* Bypass Right Axillary Artery to Bilateral Upper Leg Artery with Autologous Venous Tissue, Open Approach */
"0315099" = "1" /* Bypass Right Axillary Artery to Right Lower Leg Artery with Autologous Venous Tissue, Open Approach */
"031509B" = "1" /* Bypass Right Axillary Artery to Left Lower Leg Artery with Autologous Venous Tissue, Open Approach */
"031509C" = "1" /* Bypass Right Axillary Artery to Bilateral Lower Leg Artery with Autologous Venous Tissue, Open Approach */
"031509D" = "1" /* Bypass Right Axillary Artery to Upper Arm Vein with Autologous Venous Tissue, Open Approach */
"031509F" = "1" /* Bypass Right Axillary Artery to Lower Arm Vein with Autologous Venous Tissue, Open Approach */
"031509J" = "1" /* Bypass Right Axillary Artery to Right Extracranial Artery with Autologous Venous Tissue, Open Approach */
"031509K" = "1" /* Bypass Right Axillary Artery to Left Extracranial Artery with Autologous Venous Tissue, Open Approach */
"03150A0" = "1" /* Bypass Right Axillary Artery to Right Upper Arm Artery with Autologous Arterial Tissue, Open Approach */
"03150A1" = "1" /* Bypass Right Axillary Artery to Left Upper Arm Artery with Autologous Arterial Tissue, Open Approach */
"03150A2" = "1" /* Bypass Right Axillary Artery to Bilateral Upper Arm Artery with Autologous Arterial Tissue, Open Approach */
"03150A3" = "1" /* Bypass Right Axillary Artery to Right Lower Arm Artery with Autologous Arterial Tissue, Open Approach */
"03150A4" = "1" /* Bypass Right Axillary Artery to Left Lower Arm Artery with Autologous Arterial Tissue, Open Approach */
"03150A5" = "1" /* Bypass Right Axillary Artery to Bilateral Lower Arm Artery with Autologous Arterial Tissue, Open Approach */
"03150A6" = "1" /* Bypass Right Axillary Artery to Right Upper Leg Artery with Autologous Arterial Tissue, Open Approach */
"03150A7" = "1" /* Bypass Right Axillary Artery to Left Upper Leg Artery with Autologous Arterial Tissue, Open Approach */
"03150A8" = "1" /* Bypass Right Axillary Artery to Bilateral Upper Leg Artery with Autologous Arterial Tissue, Open Approach */
"03150A9" = "1" /* Bypass Right Axillary Artery to Right Lower Leg Artery with Autologous Arterial Tissue, Open Approach */
"03150AB" = "1" /* Bypass Right Axillary Artery to Left Lower Leg Artery with Autologous Arterial Tissue, Open Approach */
"03150AC" = "1" /* Bypass Right Axillary Artery to Bilateral Lower Leg Artery with Autologous Arterial Tissue, Open Approach */
"03150AD" = "1" /* Bypass Right Axillary Artery to Upper Arm Vein with Autologous Arterial Tissue, Open Approach */
"03150AF" = "1" /* Bypass Right Axillary Artery to Lower Arm Vein with Autologous Arterial Tissue, Open Approach */
"03150AJ" = "1" /* Bypass Right Axillary Artery to Right Extracranial Artery with Autologous Arterial Tissue, Open Approach */
"03150AK" = "1" /* Bypass Right Axillary Artery to Left Extracranial Artery with Autologous Arterial Tissue, Open Approach */
"03150J0" = "1" /* Bypass Right Axillary Artery to Right Upper Arm Artery with Synthetic Substitute, Open Approach */
"03150J1" = "1" /* Bypass Right Axillary Artery to Left Upper Arm Artery with Synthetic Substitute, Open Approach */
"03150J2" = "1" /* Bypass Right Axillary Artery to Bilateral Upper Arm Artery with Synthetic Substitute, Open Approach */
"03150J3" = "1" /* Bypass Right Axillary Artery to Right Lower Arm Artery with Synthetic Substitute, Open Approach */
"03150J4" = "1" /* Bypass Right Axillary Artery to Left Lower Arm Artery with Synthetic Substitute, Open Approach */
"03150J5" = "1" /* Bypass Right Axillary Artery to Bilateral Lower Arm Artery with Synthetic Substitute, Open Approach */
"03150J6" = "1" /* Bypass Right Axillary Artery to Right Upper Leg Artery with Synthetic Substitute, Open Approach */
"03150J7" = "1" /* Bypass Right Axillary Artery to Left Upper Leg Artery with Synthetic Substitute, Open Approach */
"03150J8" = "1" /* Bypass Right Axillary Artery to Bilateral Upper Leg Artery with Synthetic Substitute, Open Approach */
"03150J9" = "1" /* Bypass Right Axillary Artery to Right Lower Leg Artery with Synthetic Substitute, Open Approach */
"03150JB" = "1" /* Bypass Right Axillary Artery to Left Lower Leg Artery with Synthetic Substitute, Open Approach */
"03150JC" = "1" /* Bypass Right Axillary Artery to Bilateral Lower Leg Artery with Synthetic Substitute, Open Approach */
"03150JD" = "1" /* Bypass Right Axillary Artery to Upper Arm Vein with Synthetic Substitute, Open Approach */
"03150JF" = "1" /* Bypass Right Axillary Artery to Lower Arm Vein with Synthetic Substitute, Open Approach */
"03150JJ" = "1" /* Bypass Right Axillary Artery to Right Extracranial Artery with Synthetic Substitute, Open Approach */
"03150JK" = "1" /* Bypass Right Axillary Artery to Left Extracranial Artery with Synthetic Substitute, Open Approach */
"03150K0" = "1" /* Bypass Right Axillary Artery to Right Upper Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03150K1" = "1" /* Bypass Right Axillary Artery to Left Upper Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03150K2" = "1" /* Bypass Right Axillary Artery to Bilateral Upper Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03150K3" = "1" /* Bypass Right Axillary Artery to Right Lower Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03150K4" = "1" /* Bypass Right Axillary Artery to Left Lower Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03150K5" = "1" /* Bypass Right Axillary Artery to Bilateral Lower Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03150K6" = "1" /* Bypass Right Axillary Artery to Right Upper Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03150K7" = "1" /* Bypass Right Axillary Artery to Left Upper Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03150K8" = "1" /* Bypass Right Axillary Artery to Bilateral Upper Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03150K9" = "1" /* Bypass Right Axillary Artery to Right Lower Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03150KB" = "1" /* Bypass Right Axillary Artery to Left Lower Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03150KC" = "1" /* Bypass Right Axillary Artery to Bilateral Lower Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03150KD" = "1" /* Bypass Right Axillary Artery to Upper Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03150KF" = "1" /* Bypass Right Axillary Artery to Lower Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03150KJ" = "1" /* Bypass Right Axillary Artery to Right Extracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"03150KK" = "1" /* Bypass Right Axillary Artery to Left Extracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"03150Z0" = "1" /* Bypass Right Axillary Artery to Right Upper Arm Artery, Open Approach */
"03150Z1" = "1" /* Bypass Right Axillary Artery to Left Upper Arm Artery, Open Approach */
"03150Z2" = "1" /* Bypass Right Axillary Artery to Bilateral Upper Arm Artery, Open Approach */
"03150Z3" = "1" /* Bypass Right Axillary Artery to Right Lower Arm Artery, Open Approach */
"03150Z4" = "1" /* Bypass Right Axillary Artery to Left Lower Arm Artery, Open Approach */
"03150Z5" = "1" /* Bypass Right Axillary Artery to Bilateral Lower Arm Artery, Open Approach */
"03150Z6" = "1" /* Bypass Right Axillary Artery to Right Upper Leg Artery, Open Approach */
"03150Z7" = "1" /* Bypass Right Axillary Artery to Left Upper Leg Artery, Open Approach */
"03150Z8" = "1" /* Bypass Right Axillary Artery to Bilateral Upper Leg Artery, Open Approach */
"03150Z9" = "1" /* Bypass Right Axillary Artery to Right Lower Leg Artery, Open Approach */
"03150ZB" = "1" /* Bypass Right Axillary Artery to Left Lower Leg Artery, Open Approach */
"03150ZC" = "1" /* Bypass Right Axillary Artery to Bilateral Lower Leg Artery, Open Approach */
"03150ZD" = "1" /* Bypass Right Axillary Artery to Upper Arm Vein, Open Approach */
"03150ZF" = "1" /* Bypass Right Axillary Artery to Lower Arm Vein, Open Approach */
"03150ZJ" = "1" /* Bypass Right Axillary Artery to Right Extracranial Artery, Open Approach */
"03150ZK" = "1" /* Bypass Right Axillary Artery to Left Extracranial Artery, Open Approach */
"0316090" = "1" /* Bypass Left Axillary Artery to Right Upper Arm Artery with Autologous Venous Tissue, Open Approach */
"0316091" = "1" /* Bypass Left Axillary Artery to Left Upper Arm Artery with Autologous Venous Tissue, Open Approach */
"0316092" = "1" /* Bypass Left Axillary Artery to Bilateral Upper Arm Artery with Autologous Venous Tissue, Open Approach */
"0316093" = "1" /* Bypass Left Axillary Artery to Right Lower Arm Artery with Autologous Venous Tissue, Open Approach */
"0316094" = "1" /* Bypass Left Axillary Artery to Left Lower Arm Artery with Autologous Venous Tissue, Open Approach */
"0316095" = "1" /* Bypass Left Axillary Artery to Bilateral Lower Arm Artery with Autologous Venous Tissue, Open Approach */
"0316096" = "1" /* Bypass Left Axillary Artery to Right Upper Leg Artery with Autologous Venous Tissue, Open Approach */
"0316097" = "1" /* Bypass Left Axillary Artery to Left Upper Leg Artery with Autologous Venous Tissue, Open Approach */
"0316098" = "1" /* Bypass Left Axillary Artery to Bilateral Upper Leg Artery with Autologous Venous Tissue, Open Approach */
"0316099" = "1" /* Bypass Left Axillary Artery to Right Lower Leg Artery with Autologous Venous Tissue, Open Approach */
"031609B" = "1" /* Bypass Left Axillary Artery to Left Lower Leg Artery with Autologous Venous Tissue, Open Approach */
"031609C" = "1" /* Bypass Left Axillary Artery to Bilateral Lower Leg Artery with Autologous Venous Tissue, Open Approach */
"031609D" = "1" /* Bypass Left Axillary Artery to Upper Arm Vein with Autologous Venous Tissue, Open Approach */
"031609F" = "1" /* Bypass Left Axillary Artery to Lower Arm Vein with Autologous Venous Tissue, Open Approach */
"031609J" = "1" /* Bypass Left Axillary Artery to Right Extracranial Artery with Autologous Venous Tissue, Open Approach */
"031609K" = "1" /* Bypass Left Axillary Artery to Left Extracranial Artery with Autologous Venous Tissue, Open Approach */
"03160A0" = "1" /* Bypass Left Axillary Artery to Right Upper Arm Artery with Autologous Arterial Tissue, Open Approach */
"03160A1" = "1" /* Bypass Left Axillary Artery to Left Upper Arm Artery with Autologous Arterial Tissue, Open Approach */
"03160A2" = "1" /* Bypass Left Axillary Artery to Bilateral Upper Arm Artery with Autologous Arterial Tissue, Open Approach */
"03160A3" = "1" /* Bypass Left Axillary Artery to Right Lower Arm Artery with Autologous Arterial Tissue, Open Approach */
"03160A4" = "1" /* Bypass Left Axillary Artery to Left Lower Arm Artery with Autologous Arterial Tissue, Open Approach */
"03160A5" = "1" /* Bypass Left Axillary Artery to Bilateral Lower Arm Artery with Autologous Arterial Tissue, Open Approach */
"03160A6" = "1" /* Bypass Left Axillary Artery to Right Upper Leg Artery with Autologous Arterial Tissue, Open Approach */
"03160A7" = "1" /* Bypass Left Axillary Artery to Left Upper Leg Artery with Autologous Arterial Tissue, Open Approach */
"03160A8" = "1" /* Bypass Left Axillary Artery to Bilateral Upper Leg Artery with Autologous Arterial Tissue, Open Approach */
"03160A9" = "1" /* Bypass Left Axillary Artery to Right Lower Leg Artery with Autologous Arterial Tissue, Open Approach */
"03160AB" = "1" /* Bypass Left Axillary Artery to Left Lower Leg Artery with Autologous Arterial Tissue, Open Approach */
"03160AC" = "1" /* Bypass Left Axillary Artery to Bilateral Lower Leg Artery with Autologous Arterial Tissue, Open Approach */
"03160AD" = "1" /* Bypass Left Axillary Artery to Upper Arm Vein with Autologous Arterial Tissue, Open Approach */
"03160AF" = "1" /* Bypass Left Axillary Artery to Lower Arm Vein with Autologous Arterial Tissue, Open Approach */
"03160AJ" = "1" /* Bypass Left Axillary Artery to Right Extracranial Artery with Autologous Arterial Tissue, Open Approach */
"03160AK" = "1" /* Bypass Left Axillary Artery to Left Extracranial Artery with Autologous Arterial Tissue, Open Approach */
"03160J0" = "1" /* Bypass Left Axillary Artery to Right Upper Arm Artery with Synthetic Substitute, Open Approach */
"03160J1" = "1" /* Bypass Left Axillary Artery to Left Upper Arm Artery with Synthetic Substitute, Open Approach */
"03160J2" = "1" /* Bypass Left Axillary Artery to Bilateral Upper Arm Artery with Synthetic Substitute, Open Approach */
"03160J3" = "1" /* Bypass Left Axillary Artery to Right Lower Arm Artery with Synthetic Substitute, Open Approach */
"03160J4" = "1" /* Bypass Left Axillary Artery to Left Lower Arm Artery with Synthetic Substitute, Open Approach */
"03160J5" = "1" /* Bypass Left Axillary Artery to Bilateral Lower Arm Artery with Synthetic Substitute, Open Approach */
"03160J6" = "1" /* Bypass Left Axillary Artery to Right Upper Leg Artery with Synthetic Substitute, Open Approach */
"03160J7" = "1" /* Bypass Left Axillary Artery to Left Upper Leg Artery with Synthetic Substitute, Open Approach */
"03160J8" = "1" /* Bypass Left Axillary Artery to Bilateral Upper Leg Artery with Synthetic Substitute, Open Approach */
"03160J9" = "1" /* Bypass Left Axillary Artery to Right Lower Leg Artery with Synthetic Substitute, Open Approach */
"03160JB" = "1" /* Bypass Left Axillary Artery to Left Lower Leg Artery with Synthetic Substitute, Open Approach */
"03160JC" = "1" /* Bypass Left Axillary Artery to Bilateral Lower Leg Artery with Synthetic Substitute, Open Approach */
"03160JD" = "1" /* Bypass Left Axillary Artery to Upper Arm Vein with Synthetic Substitute, Open Approach */
"03160JF" = "1" /* Bypass Left Axillary Artery to Lower Arm Vein with Synthetic Substitute, Open Approach */
"03160JJ" = "1" /* Bypass Left Axillary Artery to Right Extracranial Artery with Synthetic Substitute, Open Approach */
"03160JK" = "1" /* Bypass Left Axillary Artery to Left Extracranial Artery with Synthetic Substitute, Open Approach */
"03160K0" = "1" /* Bypass Left Axillary Artery to Right Upper Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03160K1" = "1" /* Bypass Left Axillary Artery to Left Upper Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03160K2" = "1" /* Bypass Left Axillary Artery to Bilateral Upper Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03160K3" = "1" /* Bypass Left Axillary Artery to Right Lower Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03160K4" = "1" /* Bypass Left Axillary Artery to Left Lower Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03160K5" = "1" /* Bypass Left Axillary Artery to Bilateral Lower Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03160K6" = "1" /* Bypass Left Axillary Artery to Right Upper Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03160K7" = "1" /* Bypass Left Axillary Artery to Left Upper Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03160K8" = "1" /* Bypass Left Axillary Artery to Bilateral Upper Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03160K9" = "1" /* Bypass Left Axillary Artery to Right Lower Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03160KB" = "1" /* Bypass Left Axillary Artery to Left Lower Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03160KC" = "1" /* Bypass Left Axillary Artery to Bilateral Lower Leg Artery with Nonautologous Tissue Substitute, Open Approach */
"03160KD" = "1" /* Bypass Left Axillary Artery to Upper Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03160KF" = "1" /* Bypass Left Axillary Artery to Lower Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03160KJ" = "1" /* Bypass Left Axillary Artery to Right Extracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"03160KK" = "1" /* Bypass Left Axillary Artery to Left Extracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"03160Z0" = "1" /* Bypass Left Axillary Artery to Right Upper Arm Artery, Open Approach */
"03160Z1" = "1" /* Bypass Left Axillary Artery to Left Upper Arm Artery, Open Approach */
"03160Z2" = "1" /* Bypass Left Axillary Artery to Bilateral Upper Arm Artery, Open Approach */
"03160Z3" = "1" /* Bypass Left Axillary Artery to Right Lower Arm Artery, Open Approach */
"03160Z4" = "1" /* Bypass Left Axillary Artery to Left Lower Arm Artery, Open Approach */
"03160Z5" = "1" /* Bypass Left Axillary Artery to Bilateral Lower Arm Artery, Open Approach */
"03160Z6" = "1" /* Bypass Left Axillary Artery to Right Upper Leg Artery, Open Approach */
"03160Z7" = "1" /* Bypass Left Axillary Artery to Left Upper Leg Artery, Open Approach */
"03160Z8" = "1" /* Bypass Left Axillary Artery to Bilateral Upper Leg Artery, Open Approach */
"03160Z9" = "1" /* Bypass Left Axillary Artery to Right Lower Leg Artery, Open Approach */
"03160ZB" = "1" /* Bypass Left Axillary Artery to Left Lower Leg Artery, Open Approach */
"03160ZC" = "1" /* Bypass Left Axillary Artery to Bilateral Lower Leg Artery, Open Approach */
"03160ZD" = "1" /* Bypass Left Axillary Artery to Upper Arm Vein, Open Approach */
"03160ZF" = "1" /* Bypass Left Axillary Artery to Lower Arm Vein, Open Approach */
"03160ZJ" = "1" /* Bypass Left Axillary Artery to Right Extracranial Artery, Open Approach */
"03160ZK" = "1" /* Bypass Left Axillary Artery to Left Extracranial Artery, Open Approach */
"0317090" = "1" /* Bypass Right Brachial Artery to Right Upper Arm Artery with Autologous Venous Tissue, Open Approach */
"0317093" = "1" /* Bypass Right Brachial Artery to Right Lower Arm Artery with Autologous Venous Tissue, Open Approach */
"031709D" = "1" /* Bypass Right Brachial Artery to Upper Arm Vein with Autologous Venous Tissue, Open Approach */
"031709F" = "1" /* Bypass Right Brachial Artery to Lower Arm Vein with Autologous Venous Tissue, Open Approach */
"03170A0" = "1" /* Bypass Right Brachial Artery to Right Upper Arm Artery with Autologous Arterial Tissue, Open Approach */
"03170A3" = "1" /* Bypass Right Brachial Artery to Right Lower Arm Artery with Autologous Arterial Tissue, Open Approach */
"03170AD" = "1" /* Bypass Right Brachial Artery to Upper Arm Vein with Autologous Arterial Tissue, Open Approach */
"03170AF" = "1" /* Bypass Right Brachial Artery to Lower Arm Vein with Autologous Arterial Tissue, Open Approach */
"03170J0" = "1" /* Bypass Right Brachial Artery to Right Upper Arm Artery with Synthetic Substitute, Open Approach */
"03170J3" = "1" /* Bypass Right Brachial Artery to Right Lower Arm Artery with Synthetic Substitute, Open Approach */
"03170JD" = "1" /* Bypass Right Brachial Artery to Upper Arm Vein with Synthetic Substitute, Open Approach */
"03170JF" = "1" /* Bypass Right Brachial Artery to Lower Arm Vein with Synthetic Substitute, Open Approach */
"03170K0" = "1" /* Bypass Right Brachial Artery to Right Upper Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03170K3" = "1" /* Bypass Right Brachial Artery to Right Lower Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03170KD" = "1" /* Bypass Right Brachial Artery to Upper Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03170KF" = "1" /* Bypass Right Brachial Artery to Lower Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03170Z0" = "1" /* Bypass Right Brachial Artery to Right Upper Arm Artery, Open Approach */
"03170Z3" = "1" /* Bypass Right Brachial Artery to Right Lower Arm Artery, Open Approach */
"03170ZD" = "1" /* Bypass Right Brachial Artery to Upper Arm Vein, Open Approach */
"03170ZF" = "1" /* Bypass Right Brachial Artery to Lower Arm Vein, Open Approach */
"0318091" = "1" /* Bypass Left Brachial Artery to Left Upper Arm Artery with Autologous Venous Tissue, Open Approach */
"0318094" = "1" /* Bypass Left Brachial Artery to Left Lower Arm Artery with Autologous Venous Tissue, Open Approach */
"031809D" = "1" /* Bypass Left Brachial Artery to Upper Arm Vein with Autologous Venous Tissue, Open Approach */
"031809F" = "1" /* Bypass Left Brachial Artery to Lower Arm Vein with Autologous Venous Tissue, Open Approach */
"03180A1" = "1" /* Bypass Left Brachial Artery to Left Upper Arm Artery with Autologous Arterial Tissue, Open Approach */
"03180A4" = "1" /* Bypass Left Brachial Artery to Left Lower Arm Artery with Autologous Arterial Tissue, Open Approach */
"03180AD" = "1" /* Bypass Left Brachial Artery to Upper Arm Vein with Autologous Arterial Tissue, Open Approach */
"03180AF" = "1" /* Bypass Left Brachial Artery to Lower Arm Vein with Autologous Arterial Tissue, Open Approach */
"03180J1" = "1" /* Bypass Left Brachial Artery to Left Upper Arm Artery with Synthetic Substitute, Open Approach */
"03180J4" = "1" /* Bypass Left Brachial Artery to Left Lower Arm Artery with Synthetic Substitute, Open Approach */
"03180JD" = "1" /* Bypass Left Brachial Artery to Upper Arm Vein with Synthetic Substitute, Open Approach */
"03180JF" = "1" /* Bypass Left Brachial Artery to Lower Arm Vein with Synthetic Substitute, Open Approach */
"03180K1" = "1" /* Bypass Left Brachial Artery to Left Upper Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03180K4" = "1" /* Bypass Left Brachial Artery to Left Lower Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03180KD" = "1" /* Bypass Left Brachial Artery to Upper Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03180KF" = "1" /* Bypass Left Brachial Artery to Lower Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03180Z1" = "1" /* Bypass Left Brachial Artery to Left Upper Arm Artery, Open Approach */
"03180Z4" = "1" /* Bypass Left Brachial Artery to Left Lower Arm Artery, Open Approach */
"03180ZD" = "1" /* Bypass Left Brachial Artery to Upper Arm Vein, Open Approach */
"03180ZF" = "1" /* Bypass Left Brachial Artery to Lower Arm Vein, Open Approach */
"0319093" = "1" /* Bypass Right Ulnar Artery to Right Lower Arm Artery with Autologous Venous Tissue, Open Approach */
"031909F" = "1" /* Bypass Right Ulnar Artery to Lower Arm Vein with Autologous Venous Tissue, Open Approach */
"03190A3" = "1" /* Bypass Right Ulnar Artery to Right Lower Arm Artery with Autologous Arterial Tissue, Open Approach */
"03190AF" = "1" /* Bypass Right Ulnar Artery to Lower Arm Vein with Autologous Arterial Tissue, Open Approach */
"03190J3" = "1" /* Bypass Right Ulnar Artery to Right Lower Arm Artery with Synthetic Substitute, Open Approach */
"03190JF" = "1" /* Bypass Right Ulnar Artery to Lower Arm Vein with Synthetic Substitute, Open Approach */
"03190K3" = "1" /* Bypass Right Ulnar Artery to Right Lower Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"03190KF" = "1" /* Bypass Right Ulnar Artery to Lower Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03190Z3" = "1" /* Bypass Right Ulnar Artery to Right Lower Arm Artery, Open Approach */
"03190ZF" = "1" /* Bypass Right Ulnar Artery to Lower Arm Vein, Open Approach */
"031A094" = "1" /* Bypass Left Ulnar Artery to Left Lower Arm Artery with Autologous Venous Tissue, Open Approach */
"031A09F" = "1" /* Bypass Left Ulnar Artery to Lower Arm Vein with Autologous Venous Tissue, Open Approach */
"031A0A4" = "1" /* Bypass Left Ulnar Artery to Left Lower Arm Artery with Autologous Arterial Tissue, Open Approach */
"031A0AF" = "1" /* Bypass Left Ulnar Artery to Lower Arm Vein with Autologous Arterial Tissue, Open Approach */
"031A0J4" = "1" /* Bypass Left Ulnar Artery to Left Lower Arm Artery with Synthetic Substitute, Open Approach */
"031A0JF" = "1" /* Bypass Left Ulnar Artery to Lower Arm Vein with Synthetic Substitute, Open Approach */
"031A0K4" = "1" /* Bypass Left Ulnar Artery to Left Lower Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"031A0KF" = "1" /* Bypass Left Ulnar Artery to Lower Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"031A0Z4" = "1" /* Bypass Left Ulnar Artery to Left Lower Arm Artery, Open Approach */
"031A0ZF" = "1" /* Bypass Left Ulnar Artery to Lower Arm Vein, Open Approach */
"031B093" = "1" /* Bypass Right Radial Artery to Right Lower Arm Artery with Autologous Venous Tissue, Open Approach */
"031B09F" = "1" /* Bypass Right Radial Artery to Lower Arm Vein with Autologous Venous Tissue, Open Approach */
"031B0A3" = "1" /* Bypass Right Radial Artery to Right Lower Arm Artery with Autologous Arterial Tissue, Open Approach */
"031B0AF" = "1" /* Bypass Right Radial Artery to Lower Arm Vein with Autologous Arterial Tissue, Open Approach */
"031B0J3" = "1" /* Bypass Right Radial Artery to Right Lower Arm Artery with Synthetic Substitute, Open Approach */
"031B0JF" = "1" /* Bypass Right Radial Artery to Lower Arm Vein with Synthetic Substitute, Open Approach */
"031B0K3" = "1" /* Bypass Right Radial Artery to Right Lower Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"031B0KF" = "1" /* Bypass Right Radial Artery to Lower Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"031B0Z3" = "1" /* Bypass Right Radial Artery to Right Lower Arm Artery, Open Approach */
"031B0ZF" = "1" /* Bypass Right Radial Artery to Lower Arm Vein, Open Approach */
"031C094" = "1" /* Bypass Left Radial Artery to Left Lower Arm Artery with Autologous Venous Tissue, Open Approach */
"031C09F" = "1" /* Bypass Left Radial Artery to Lower Arm Vein with Autologous Venous Tissue, Open Approach */
"031C0A4" = "1" /* Bypass Left Radial Artery to Left Lower Arm Artery with Autologous Arterial Tissue, Open Approach */
"031C0AF" = "1" /* Bypass Left Radial Artery to Lower Arm Vein with Autologous Arterial Tissue, Open Approach */
"031C0J4" = "1" /* Bypass Left Radial Artery to Left Lower Arm Artery with Synthetic Substitute, Open Approach */
"031C0JF" = "1" /* Bypass Left Radial Artery to Lower Arm Vein with Synthetic Substitute, Open Approach */
"031C0K4" = "1" /* Bypass Left Radial Artery to Left Lower Arm Artery with Nonautologous Tissue Substitute, Open Approach */
"031C0KF" = "1" /* Bypass Left Radial Artery to Lower Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"031C0Z4" = "1" /* Bypass Left Radial Artery to Left Lower Arm Artery, Open Approach */
"031C0ZF" = "1" /* Bypass Left Radial Artery to Lower Arm Vein, Open Approach */
"031G09G" = "1" /* Bypass Intracranial Artery to Intracranial Artery with Autologous Venous Tissue, Open Approach */
"031G0AG" = "1" /* Bypass Intracranial Artery to Intracranial Artery with Autologous Arterial Tissue, Open Approach */
"031G0JG" = "1" /* Bypass Intracranial Artery to Intracranial Artery with Synthetic Substitute, Open Approach */
"031G0KG" = "1" /* Bypass Intracranial Artery to Intracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"031G0ZG" = "1" /* Bypass Intracranial Artery to Intracranial Artery, Open Approach */
"031H09G" = "1" /* Bypass Right Common Carotid Artery to Intracranial Artery with Autologous Venous Tissue, Open Approach */
"031H09J" = "1" /* Bypass Right Common Carotid Artery to Right Extracranial Artery with Autologous Venous Tissue, Open Approach */
"031H0AG" = "1" /* Bypass Right Common Carotid Artery to Intracranial Artery with Autologous Arterial Tissue, Open Approach */
"031H0AJ" = "1" /* Bypass Right Common Carotid Artery to Right Extracranial Artery with Autologous Arterial Tissue, Open Approach */
"031H0JG" = "1" /* Bypass Right Common Carotid Artery to Intracranial Artery with Synthetic Substitute, Open Approach */
"031H0JJ" = "1" /* Bypass Right Common Carotid Artery to Right Extracranial Artery with Synthetic Substitute, Open Approach */
"031H0KG" = "1" /* Bypass Right Common Carotid Artery to Intracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"031H0KJ" = "1" /* Bypass Right Common Carotid Artery to Right Extracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"031H0ZG" = "1" /* Bypass Right Common Carotid Artery to Intracranial Artery, Open Approach */
"031H0ZJ" = "1" /* Bypass Right Common Carotid Artery to Right Extracranial Artery, Open Approach */
"031J09G" = "1" /* Bypass Left Common Carotid Artery to Intracranial Artery with Autologous Venous Tissue, Open Approach */
"031J09K" = "1" /* Bypass Left Common Carotid Artery to Left Extracranial Artery with Autologous Venous Tissue, Open Approach */
"031J0AG" = "1" /* Bypass Left Common Carotid Artery to Intracranial Artery with Autologous Arterial Tissue, Open Approach */
"031J0AK" = "1" /* Bypass Left Common Carotid Artery to Left Extracranial Artery with Autologous Arterial Tissue, Open Approach */
"031J0JG" = "1" /* Bypass Left Common Carotid Artery to Intracranial Artery with Synthetic Substitute, Open Approach */
"031J0JK" = "1" /* Bypass Left Common Carotid Artery to Left Extracranial Artery with Synthetic Substitute, Open Approach */
"031J0KG" = "1" /* Bypass Left Common Carotid Artery to Intracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"031J0KK" = "1" /* Bypass Left Common Carotid Artery to Left Extracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"031J0ZG" = "1" /* Bypass Left Common Carotid Artery to Intracranial Artery, Open Approach */
"031J0ZK" = "1" /* Bypass Left Common Carotid Artery to Left Extracranial Artery, Open Approach */
"031K09J" = "1" /* Bypass Right Internal Carotid Artery to Right Extracranial Artery with Autologous Venous Tissue, Open Approach */
"031K0AJ" = "1" /* Bypass Right Internal Carotid Artery to Right Extracranial Artery with Autologous Arterial Tissue, Open Approach */
"031K0JJ" = "1" /* Bypass Right Internal Carotid Artery to Right Extracranial Artery with Synthetic Substitute, Open Approach */
"031K0KJ" = "1" /* Bypass Right Internal Carotid Artery to Right Extracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"031K0ZJ" = "1" /* Bypass Right Internal Carotid Artery to Right Extracranial Artery, Open Approach */
"031L09K" = "1" /* Bypass Left Internal Carotid Artery to Left Extracranial Artery with Autologous Venous Tissue, Open Approach */
"031L0AK" = "1" /* Bypass Left Internal Carotid Artery to Left Extracranial Artery with Autologous Arterial Tissue, Open Approach */
"031L0JK" = "1" /* Bypass Left Internal Carotid Artery to Left Extracranial Artery with Synthetic Substitute, Open Approach */
"031L0KK" = "1" /* Bypass Left Internal Carotid Artery to Left Extracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"031L0ZK" = "1" /* Bypass Left Internal Carotid Artery to Left Extracranial Artery, Open Approach */
"031M09J" = "1" /* Bypass Right External Carotid Artery to Right Extracranial Artery with Autologous Venous Tissue, Open Approach */
"031M0AJ" = "1" /* Bypass Right External Carotid Artery to Right Extracranial Artery with Autologous Arterial Tissue, Open Approach */
"031M0JJ" = "1" /* Bypass Right External Carotid Artery to Right Extracranial Artery with Synthetic Substitute, Open Approach */
"031M0KJ" = "1" /* Bypass Right External Carotid Artery to Right Extracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"031M0ZJ" = "1" /* Bypass Right External Carotid Artery to Right Extracranial Artery, Open Approach */
"031N09K" = "1" /* Bypass Left External Carotid Artery to Left Extracranial Artery with Autologous Venous Tissue, Open Approach */
"031N0AK" = "1" /* Bypass Left External Carotid Artery to Left Extracranial Artery with Autologous Arterial Tissue, Open Approach */
"031N0JK" = "1" /* Bypass Left External Carotid Artery to Left Extracranial Artery with Synthetic Substitute, Open Approach */
"031N0KK" = "1" /* Bypass Left External Carotid Artery to Left Extracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"031N0ZK" = "1" /* Bypass Left External Carotid Artery to Left Extracranial Artery, Open Approach */
"031S09G" = "1" /* Bypass Right Temporal Artery to Intracranial Artery with Autologous Venous Tissue, Open Approach */
"031S0AG" = "1" /* Bypass Right Temporal Artery to Intracranial Artery with Autologous Arterial Tissue, Open Approach */
"031S0JG" = "1" /* Bypass Right Temporal Artery to Intracranial Artery with Synthetic Substitute, Open Approach */
"031S0KG" = "1" /* Bypass Right Temporal Artery to Intracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"031S0ZG" = "1" /* Bypass Right Temporal Artery to Intracranial Artery, Open Approach */
"031T09G" = "1" /* Bypass Left Temporal Artery to Intracranial Artery with Autologous Venous Tissue, Open Approach */
"031T0AG" = "1" /* Bypass Left Temporal Artery to Intracranial Artery with Autologous Arterial Tissue, Open Approach */
"031T0JG" = "1" /* Bypass Left Temporal Artery to Intracranial Artery with Synthetic Substitute, Open Approach */
"031T0KG" = "1" /* Bypass Left Temporal Artery to Intracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"031T0ZG" = "1" /* Bypass Left Temporal Artery to Intracranial Artery, Open Approach */
"03500ZZ" = "1" /* Destruction of Right Internal Mammary Artery, Open Approach */
"03503ZZ" = "1" /* Destruction of Right Internal Mammary Artery, Percutaneous Approach */
"03504ZZ" = "1" /* Destruction of Right Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03510ZZ" = "1" /* Destruction of Left Internal Mammary Artery, Open Approach */
"03513ZZ" = "1" /* Destruction of Left Internal Mammary Artery, Percutaneous Approach */
"03514ZZ" = "1" /* Destruction of Left Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03520ZZ" = "1" /* Destruction of Innominate Artery, Open Approach */
"03523ZZ" = "1" /* Destruction of Innominate Artery, Percutaneous Approach */
"03524ZZ" = "1" /* Destruction of Innominate Artery, Percutaneous Endoscopic Approach */
"03530ZZ" = "1" /* Destruction of Right Subclavian Artery, Open Approach */
"03533ZZ" = "1" /* Destruction of Right Subclavian Artery, Percutaneous Approach */
"03534ZZ" = "1" /* Destruction of Right Subclavian Artery, Percutaneous Endoscopic Approach */
"03540ZZ" = "1" /* Destruction of Left Subclavian Artery, Open Approach */
"03543ZZ" = "1" /* Destruction of Left Subclavian Artery, Percutaneous Approach */
"03544ZZ" = "1" /* Destruction of Left Subclavian Artery, Percutaneous Endoscopic Approach */
"03550ZZ" = "1" /* Destruction of Right Axillary Artery, Open Approach */
"03553ZZ" = "1" /* Destruction of Right Axillary Artery, Percutaneous Approach */
"03554ZZ" = "1" /* Destruction of Right Axillary Artery, Percutaneous Endoscopic Approach */
"03560ZZ" = "1" /* Destruction of Left Axillary Artery, Open Approach */
"03563ZZ" = "1" /* Destruction of Left Axillary Artery, Percutaneous Approach */
"03564ZZ" = "1" /* Destruction of Left Axillary Artery, Percutaneous Endoscopic Approach */
"03570ZZ" = "1" /* Destruction of Right Brachial Artery, Open Approach */
"03573ZZ" = "1" /* Destruction of Right Brachial Artery, Percutaneous Approach */
"03574ZZ" = "1" /* Destruction of Right Brachial Artery, Percutaneous Endoscopic Approach */
"03580ZZ" = "1" /* Destruction of Left Brachial Artery, Open Approach */
"03583ZZ" = "1" /* Destruction of Left Brachial Artery, Percutaneous Approach */
"03584ZZ" = "1" /* Destruction of Left Brachial Artery, Percutaneous Endoscopic Approach */
"03590ZZ" = "1" /* Destruction of Right Ulnar Artery, Open Approach */
"03593ZZ" = "1" /* Destruction of Right Ulnar Artery, Percutaneous Approach */
"03594ZZ" = "1" /* Destruction of Right Ulnar Artery, Percutaneous Endoscopic Approach */
"035A0ZZ" = "1" /* Destruction of Left Ulnar Artery, Open Approach */
"035A3ZZ" = "1" /* Destruction of Left Ulnar Artery, Percutaneous Approach */
"035A4ZZ" = "1" /* Destruction of Left Ulnar Artery, Percutaneous Endoscopic Approach */
"035B0ZZ" = "1" /* Destruction of Right Radial Artery, Open Approach */
"035B3ZZ" = "1" /* Destruction of Right Radial Artery, Percutaneous Approach */
"035B4ZZ" = "1" /* Destruction of Right Radial Artery, Percutaneous Endoscopic Approach */
"035C0ZZ" = "1" /* Destruction of Left Radial Artery, Open Approach */
"035C3ZZ" = "1" /* Destruction of Left Radial Artery, Percutaneous Approach */
"035C4ZZ" = "1" /* Destruction of Left Radial Artery, Percutaneous Endoscopic Approach */
"035D0ZZ" = "1" /* Destruction of Right Hand Artery, Open Approach */
"035D3ZZ" = "1" /* Destruction of Right Hand Artery, Percutaneous Approach */
"035D4ZZ" = "1" /* Destruction of Right Hand Artery, Percutaneous Endoscopic Approach */
"035F0ZZ" = "1" /* Destruction of Left Hand Artery, Open Approach */
"035F3ZZ" = "1" /* Destruction of Left Hand Artery, Percutaneous Approach */
"035F4ZZ" = "1" /* Destruction of Left Hand Artery, Percutaneous Endoscopic Approach */
"035G0ZZ" = "1" /* Destruction of Intracranial Artery, Open Approach */
"035G3ZZ" = "1" /* Destruction of Intracranial Artery, Percutaneous Approach */
"035G4ZZ" = "1" /* Destruction of Intracranial Artery, Percutaneous Endoscopic Approach */
"035H0ZZ" = "1" /* Destruction of Right Common Carotid Artery, Open Approach */
"035H3ZZ" = "1" /* Destruction of Right Common Carotid Artery, Percutaneous Approach */
"035H4ZZ" = "1" /* Destruction of Right Common Carotid Artery, Percutaneous Endoscopic Approach */
"035J0ZZ" = "1" /* Destruction of Left Common Carotid Artery, Open Approach */
"035J3ZZ" = "1" /* Destruction of Left Common Carotid Artery, Percutaneous Approach */
"035J4ZZ" = "1" /* Destruction of Left Common Carotid Artery, Percutaneous Endoscopic Approach */
"035K0ZZ" = "1" /* Destruction of Right Internal Carotid Artery, Open Approach */
"035K3ZZ" = "1" /* Destruction of Right Internal Carotid Artery, Percutaneous Approach */
"035K4ZZ" = "1" /* Destruction of Right Internal Carotid Artery, Percutaneous Endoscopic Approach */
"035L0ZZ" = "1" /* Destruction of Left Internal Carotid Artery, Open Approach */
"035L3ZZ" = "1" /* Destruction of Left Internal Carotid Artery, Percutaneous Approach */
"035L4ZZ" = "1" /* Destruction of Left Internal Carotid Artery, Percutaneous Endoscopic Approach */
"035M0ZZ" = "1" /* Destruction of Right External Carotid Artery, Open Approach */
"035M3ZZ" = "1" /* Destruction of Right External Carotid Artery, Percutaneous Approach */
"035M4ZZ" = "1" /* Destruction of Right External Carotid Artery, Percutaneous Endoscopic Approach */
"035N0ZZ" = "1" /* Destruction of Left External Carotid Artery, Open Approach */
"035N3ZZ" = "1" /* Destruction of Left External Carotid Artery, Percutaneous Approach */
"035N4ZZ" = "1" /* Destruction of Left External Carotid Artery, Percutaneous Endoscopic Approach */
"035P0ZZ" = "1" /* Destruction of Right Vertebral Artery, Open Approach */
"035P3ZZ" = "1" /* Destruction of Right Vertebral Artery, Percutaneous Approach */
"035P4ZZ" = "1" /* Destruction of Right Vertebral Artery, Percutaneous Endoscopic Approach */
"035Q0ZZ" = "1" /* Destruction of Left Vertebral Artery, Open Approach */
"035Q3ZZ" = "1" /* Destruction of Left Vertebral Artery, Percutaneous Approach */
"035Q4ZZ" = "1" /* Destruction of Left Vertebral Artery, Percutaneous Endoscopic Approach */
"035R0ZZ" = "1" /* Destruction of Face Artery, Open Approach */
"035R3ZZ" = "1" /* Destruction of Face Artery, Percutaneous Approach */
"035R4ZZ" = "1" /* Destruction of Face Artery, Percutaneous Endoscopic Approach */
"035S0ZZ" = "1" /* Destruction of Right Temporal Artery, Open Approach */
"035S3ZZ" = "1" /* Destruction of Right Temporal Artery, Percutaneous Approach */
"035S4ZZ" = "1" /* Destruction of Right Temporal Artery, Percutaneous Endoscopic Approach */
"035T0ZZ" = "1" /* Destruction of Left Temporal Artery, Open Approach */
"035T3ZZ" = "1" /* Destruction of Left Temporal Artery, Percutaneous Approach */
"035T4ZZ" = "1" /* Destruction of Left Temporal Artery, Percutaneous Endoscopic Approach */
"035U0ZZ" = "1" /* Destruction of Right Thyroid Artery, Open Approach */
"035U3ZZ" = "1" /* Destruction of Right Thyroid Artery, Percutaneous Approach */
"035U4ZZ" = "1" /* Destruction of Right Thyroid Artery, Percutaneous Endoscopic Approach */
"035V0ZZ" = "1" /* Destruction of Left Thyroid Artery, Open Approach */
"035V3ZZ" = "1" /* Destruction of Left Thyroid Artery, Percutaneous Approach */
"035V4ZZ" = "1" /* Destruction of Left Thyroid Artery, Percutaneous Endoscopic Approach */
"035Y0ZZ" = "1" /* Destruction of Upper Artery, Open Approach */
"035Y3ZZ" = "1" /* Destruction of Upper Artery, Percutaneous Approach */
"035Y4ZZ" = "1" /* Destruction of Upper Artery, Percutaneous Endoscopic Approach */
"0370046" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037004Z" = "1" /* Dilation of Right Internal Mammary Artery with Drug-eluting Intraluminal Device, Open Approach */
"0370056" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037005Z" = "1" /* Dilation of Right Internal Mammary Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0370066" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037006Z" = "1" /* Dilation of Right Internal Mammary Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0370076" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037007Z" = "1" /* Dilation of Right Internal Mammary Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"03700D6" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Intraluminal Device, Open Approach */
"03700DZ" = "1" /* Dilation of Right Internal Mammary Artery with Intraluminal Device, Open Approach */
"03700E6" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"03700EZ" = "1" /* Dilation of Right Internal Mammary Artery with Two Intraluminal Devices, Open Approach */
"03700F6" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"03700FZ" = "1" /* Dilation of Right Internal Mammary Artery with Three Intraluminal Devices, Open Approach */
"03700G6" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"03700GZ" = "1" /* Dilation of Right Internal Mammary Artery with Four or More Intraluminal Devices, Open Approach */
"03700Z6" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, Open Approach */
"03700ZZ" = "1" /* Dilation of Right Internal Mammary Artery, Open Approach */
"0370346" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037034Z" = "1" /* Dilation of Right Internal Mammary Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0370356" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037035Z" = "1" /* Dilation of Right Internal Mammary Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0370366" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037036Z" = "1" /* Dilation of Right Internal Mammary Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0370376" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037037Z" = "1" /* Dilation of Right Internal Mammary Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"03703D6" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"03703DZ" = "1" /* Dilation of Right Internal Mammary Artery with Intraluminal Device, Percutaneous Approach */
"03703E6" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"03703EZ" = "1" /* Dilation of Right Internal Mammary Artery with Two Intraluminal Devices, Percutaneous Approach */
"03703F6" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"03703FZ" = "1" /* Dilation of Right Internal Mammary Artery with Three Intraluminal Devices, Percutaneous Approach */
"03703G6" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"03703GZ" = "1" /* Dilation of Right Internal Mammary Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"03703Z6" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, Percutaneous Approach */
"03703ZZ" = "1" /* Dilation of Right Internal Mammary Artery, Percutaneous Approach */
"0370446" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037044Z" = "1" /* Dilation of Right Internal Mammary Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0370456" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037045Z" = "1" /* Dilation of Right Internal Mammary Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0370466" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037046Z" = "1" /* Dilation of Right Internal Mammary Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0370476" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037047Z" = "1" /* Dilation of Right Internal Mammary Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"03704D6" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"03704DZ" = "1" /* Dilation of Right Internal Mammary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03704E6" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"03704EZ" = "1" /* Dilation of Right Internal Mammary Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"03704F6" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"03704FZ" = "1" /* Dilation of Right Internal Mammary Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"03704G6" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"03704GZ" = "1" /* Dilation of Right Internal Mammary Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"03704Z6" = "1" /* Dilation of Right Internal Mammary Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03704ZZ" = "1" /* Dilation of Right Internal Mammary Artery, Percutaneous Endoscopic Approach */
"0371046" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037104Z" = "1" /* Dilation of Left Internal Mammary Artery with Drug-eluting Intraluminal Device, Open Approach */
"0371056" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037105Z" = "1" /* Dilation of Left Internal Mammary Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0371066" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037106Z" = "1" /* Dilation of Left Internal Mammary Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0371076" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037107Z" = "1" /* Dilation of Left Internal Mammary Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"03710D6" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Intraluminal Device, Open Approach */
"03710DZ" = "1" /* Dilation of Left Internal Mammary Artery with Intraluminal Device, Open Approach */
"03710E6" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"03710EZ" = "1" /* Dilation of Left Internal Mammary Artery with Two Intraluminal Devices, Open Approach */
"03710F6" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"03710FZ" = "1" /* Dilation of Left Internal Mammary Artery with Three Intraluminal Devices, Open Approach */
"03710G6" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"03710GZ" = "1" /* Dilation of Left Internal Mammary Artery with Four or More Intraluminal Devices, Open Approach */
"03710Z6" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, Open Approach */
"03710ZZ" = "1" /* Dilation of Left Internal Mammary Artery, Open Approach */
"0371346" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037134Z" = "1" /* Dilation of Left Internal Mammary Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0371356" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037135Z" = "1" /* Dilation of Left Internal Mammary Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0371366" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037136Z" = "1" /* Dilation of Left Internal Mammary Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0371376" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037137Z" = "1" /* Dilation of Left Internal Mammary Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"03713D6" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"03713DZ" = "1" /* Dilation of Left Internal Mammary Artery with Intraluminal Device, Percutaneous Approach */
"03713E6" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"03713EZ" = "1" /* Dilation of Left Internal Mammary Artery with Two Intraluminal Devices, Percutaneous Approach */
"03713F6" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"03713FZ" = "1" /* Dilation of Left Internal Mammary Artery with Three Intraluminal Devices, Percutaneous Approach */
"03713G6" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"03713GZ" = "1" /* Dilation of Left Internal Mammary Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"03713Z6" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, Percutaneous Approach */
"03713ZZ" = "1" /* Dilation of Left Internal Mammary Artery, Percutaneous Approach */
"0371446" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037144Z" = "1" /* Dilation of Left Internal Mammary Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0371456" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037145Z" = "1" /* Dilation of Left Internal Mammary Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0371466" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037146Z" = "1" /* Dilation of Left Internal Mammary Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0371476" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037147Z" = "1" /* Dilation of Left Internal Mammary Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"03714D6" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"03714DZ" = "1" /* Dilation of Left Internal Mammary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03714E6" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"03714EZ" = "1" /* Dilation of Left Internal Mammary Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"03714F6" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"03714FZ" = "1" /* Dilation of Left Internal Mammary Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"03714G6" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"03714GZ" = "1" /* Dilation of Left Internal Mammary Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"03714Z6" = "1" /* Dilation of Left Internal Mammary Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03714ZZ" = "1" /* Dilation of Left Internal Mammary Artery, Percutaneous Endoscopic Approach */
"0372046" = "1" /* Dilation of Innominate Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037204Z" = "1" /* Dilation of Innominate Artery with Drug-eluting Intraluminal Device, Open Approach */
"0372056" = "1" /* Dilation of Innominate Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037205Z" = "1" /* Dilation of Innominate Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0372066" = "1" /* Dilation of Innominate Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037206Z" = "1" /* Dilation of Innominate Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0372076" = "1" /* Dilation of Innominate Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037207Z" = "1" /* Dilation of Innominate Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"03720D6" = "1" /* Dilation of Innominate Artery, Bifurcation, with Intraluminal Device, Open Approach */
"03720DZ" = "1" /* Dilation of Innominate Artery with Intraluminal Device, Open Approach */
"03720E6" = "1" /* Dilation of Innominate Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"03720EZ" = "1" /* Dilation of Innominate Artery with Two Intraluminal Devices, Open Approach */
"03720F6" = "1" /* Dilation of Innominate Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"03720FZ" = "1" /* Dilation of Innominate Artery with Three Intraluminal Devices, Open Approach */
"03720G6" = "1" /* Dilation of Innominate Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"03720GZ" = "1" /* Dilation of Innominate Artery with Four or More Intraluminal Devices, Open Approach */
"03720Z6" = "1" /* Dilation of Innominate Artery, Bifurcation, Open Approach */
"03720ZZ" = "1" /* Dilation of Innominate Artery, Open Approach */
"0372346" = "1" /* Dilation of Innominate Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037234Z" = "1" /* Dilation of Innominate Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0372356" = "1" /* Dilation of Innominate Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037235Z" = "1" /* Dilation of Innominate Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0372366" = "1" /* Dilation of Innominate Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037236Z" = "1" /* Dilation of Innominate Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0372376" = "1" /* Dilation of Innominate Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037237Z" = "1" /* Dilation of Innominate Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"03723D6" = "1" /* Dilation of Innominate Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"03723DZ" = "1" /* Dilation of Innominate Artery with Intraluminal Device, Percutaneous Approach */
"03723E6" = "1" /* Dilation of Innominate Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"03723EZ" = "1" /* Dilation of Innominate Artery with Two Intraluminal Devices, Percutaneous Approach */
"03723F6" = "1" /* Dilation of Innominate Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"03723FZ" = "1" /* Dilation of Innominate Artery with Three Intraluminal Devices, Percutaneous Approach */
"03723G6" = "1" /* Dilation of Innominate Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"03723GZ" = "1" /* Dilation of Innominate Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"03723Z6" = "1" /* Dilation of Innominate Artery, Bifurcation, Percutaneous Approach */
"03723ZZ" = "1" /* Dilation of Innominate Artery, Percutaneous Approach */
"0372446" = "1" /* Dilation of Innominate Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037244Z" = "1" /* Dilation of Innominate Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0372456" = "1" /* Dilation of Innominate Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037245Z" = "1" /* Dilation of Innominate Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0372466" = "1" /* Dilation of Innominate Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037246Z" = "1" /* Dilation of Innominate Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0372476" = "1" /* Dilation of Innominate Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037247Z" = "1" /* Dilation of Innominate Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"03724D6" = "1" /* Dilation of Innominate Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"03724DZ" = "1" /* Dilation of Innominate Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03724E6" = "1" /* Dilation of Innominate Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"03724EZ" = "1" /* Dilation of Innominate Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"03724F6" = "1" /* Dilation of Innominate Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"03724FZ" = "1" /* Dilation of Innominate Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"03724G6" = "1" /* Dilation of Innominate Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"03724GZ" = "1" /* Dilation of Innominate Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"03724Z6" = "1" /* Dilation of Innominate Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03724ZZ" = "1" /* Dilation of Innominate Artery, Percutaneous Endoscopic Approach */
"0373046" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037304Z" = "1" /* Dilation of Right Subclavian Artery with Drug-eluting Intraluminal Device, Open Approach */
"0373056" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037305Z" = "1" /* Dilation of Right Subclavian Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0373066" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037306Z" = "1" /* Dilation of Right Subclavian Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0373076" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037307Z" = "1" /* Dilation of Right Subclavian Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"03730D6" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Intraluminal Device, Open Approach */
"03730DZ" = "1" /* Dilation of Right Subclavian Artery with Intraluminal Device, Open Approach */
"03730E6" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"03730EZ" = "1" /* Dilation of Right Subclavian Artery with Two Intraluminal Devices, Open Approach */
"03730F6" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"03730FZ" = "1" /* Dilation of Right Subclavian Artery with Three Intraluminal Devices, Open Approach */
"03730G6" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"03730GZ" = "1" /* Dilation of Right Subclavian Artery with Four or More Intraluminal Devices, Open Approach */
"03730Z6" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, Open Approach */
"03730ZZ" = "1" /* Dilation of Right Subclavian Artery, Open Approach */
"0373346" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037334Z" = "1" /* Dilation of Right Subclavian Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0373356" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037335Z" = "1" /* Dilation of Right Subclavian Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0373366" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037336Z" = "1" /* Dilation of Right Subclavian Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0373376" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037337Z" = "1" /* Dilation of Right Subclavian Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"03733D6" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"03733DZ" = "1" /* Dilation of Right Subclavian Artery with Intraluminal Device, Percutaneous Approach */
"03733E6" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"03733EZ" = "1" /* Dilation of Right Subclavian Artery with Two Intraluminal Devices, Percutaneous Approach */
"03733F6" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"03733FZ" = "1" /* Dilation of Right Subclavian Artery with Three Intraluminal Devices, Percutaneous Approach */
"03733G6" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"03733GZ" = "1" /* Dilation of Right Subclavian Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"03733Z6" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, Percutaneous Approach */
"03733ZZ" = "1" /* Dilation of Right Subclavian Artery, Percutaneous Approach */
"0373446" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037344Z" = "1" /* Dilation of Right Subclavian Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0373456" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037345Z" = "1" /* Dilation of Right Subclavian Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0373466" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037346Z" = "1" /* Dilation of Right Subclavian Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0373476" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037347Z" = "1" /* Dilation of Right Subclavian Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"03734D6" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"03734DZ" = "1" /* Dilation of Right Subclavian Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03734E6" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"03734EZ" = "1" /* Dilation of Right Subclavian Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"03734F6" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"03734FZ" = "1" /* Dilation of Right Subclavian Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"03734G6" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"03734GZ" = "1" /* Dilation of Right Subclavian Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"03734Z6" = "1" /* Dilation of Right Subclavian Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03734ZZ" = "1" /* Dilation of Right Subclavian Artery, Percutaneous Endoscopic Approach */
"0374046" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037404Z" = "1" /* Dilation of Left Subclavian Artery with Drug-eluting Intraluminal Device, Open Approach */
"0374056" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037405Z" = "1" /* Dilation of Left Subclavian Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0374066" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037406Z" = "1" /* Dilation of Left Subclavian Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0374076" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037407Z" = "1" /* Dilation of Left Subclavian Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"03740D6" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Intraluminal Device, Open Approach */
"03740DZ" = "1" /* Dilation of Left Subclavian Artery with Intraluminal Device, Open Approach */
"03740E6" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"03740EZ" = "1" /* Dilation of Left Subclavian Artery with Two Intraluminal Devices, Open Approach */
"03740F6" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"03740FZ" = "1" /* Dilation of Left Subclavian Artery with Three Intraluminal Devices, Open Approach */
"03740G6" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"03740GZ" = "1" /* Dilation of Left Subclavian Artery with Four or More Intraluminal Devices, Open Approach */
"03740Z6" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, Open Approach */
"03740ZZ" = "1" /* Dilation of Left Subclavian Artery, Open Approach */
"0374346" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037434Z" = "1" /* Dilation of Left Subclavian Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0374356" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037435Z" = "1" /* Dilation of Left Subclavian Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0374366" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037436Z" = "1" /* Dilation of Left Subclavian Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0374376" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037437Z" = "1" /* Dilation of Left Subclavian Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"03743D6" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"03743DZ" = "1" /* Dilation of Left Subclavian Artery with Intraluminal Device, Percutaneous Approach */
"03743E6" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"03743EZ" = "1" /* Dilation of Left Subclavian Artery with Two Intraluminal Devices, Percutaneous Approach */
"03743F6" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"03743FZ" = "1" /* Dilation of Left Subclavian Artery with Three Intraluminal Devices, Percutaneous Approach */
"03743G6" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"03743GZ" = "1" /* Dilation of Left Subclavian Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"03743Z6" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, Percutaneous Approach */
"03743ZZ" = "1" /* Dilation of Left Subclavian Artery, Percutaneous Approach */
"0374446" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037444Z" = "1" /* Dilation of Left Subclavian Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0374456" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037445Z" = "1" /* Dilation of Left Subclavian Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0374466" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037446Z" = "1" /* Dilation of Left Subclavian Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0374476" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037447Z" = "1" /* Dilation of Left Subclavian Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"03744D6" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"03744DZ" = "1" /* Dilation of Left Subclavian Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03744E6" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"03744EZ" = "1" /* Dilation of Left Subclavian Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"03744F6" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"03744FZ" = "1" /* Dilation of Left Subclavian Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"03744G6" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"03744GZ" = "1" /* Dilation of Left Subclavian Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"03744Z6" = "1" /* Dilation of Left Subclavian Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03744ZZ" = "1" /* Dilation of Left Subclavian Artery, Percutaneous Endoscopic Approach */
"0375046" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037504Z" = "1" /* Dilation of Right Axillary Artery with Drug-eluting Intraluminal Device, Open Approach */
"0375056" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037505Z" = "1" /* Dilation of Right Axillary Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0375066" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037506Z" = "1" /* Dilation of Right Axillary Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0375076" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037507Z" = "1" /* Dilation of Right Axillary Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"03750D6" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Intraluminal Device, Open Approach */
"03750DZ" = "1" /* Dilation of Right Axillary Artery with Intraluminal Device, Open Approach */
"03750E6" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"03750EZ" = "1" /* Dilation of Right Axillary Artery with Two Intraluminal Devices, Open Approach */
"03750F6" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"03750FZ" = "1" /* Dilation of Right Axillary Artery with Three Intraluminal Devices, Open Approach */
"03750G6" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"03750GZ" = "1" /* Dilation of Right Axillary Artery with Four or More Intraluminal Devices, Open Approach */
"03750Z6" = "1" /* Dilation of Right Axillary Artery, Bifurcation, Open Approach */
"03750ZZ" = "1" /* Dilation of Right Axillary Artery, Open Approach */
"0375346" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037534Z" = "1" /* Dilation of Right Axillary Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0375356" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037535Z" = "1" /* Dilation of Right Axillary Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0375366" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037536Z" = "1" /* Dilation of Right Axillary Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0375376" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037537Z" = "1" /* Dilation of Right Axillary Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"03753D6" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"03753DZ" = "1" /* Dilation of Right Axillary Artery with Intraluminal Device, Percutaneous Approach */
"03753E6" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"03753EZ" = "1" /* Dilation of Right Axillary Artery with Two Intraluminal Devices, Percutaneous Approach */
"03753F6" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"03753FZ" = "1" /* Dilation of Right Axillary Artery with Three Intraluminal Devices, Percutaneous Approach */
"03753G6" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"03753GZ" = "1" /* Dilation of Right Axillary Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"03753Z6" = "1" /* Dilation of Right Axillary Artery, Bifurcation, Percutaneous Approach */
"03753ZZ" = "1" /* Dilation of Right Axillary Artery, Percutaneous Approach */
"0375446" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037544Z" = "1" /* Dilation of Right Axillary Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0375456" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037545Z" = "1" /* Dilation of Right Axillary Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0375466" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037546Z" = "1" /* Dilation of Right Axillary Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0375476" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037547Z" = "1" /* Dilation of Right Axillary Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"03754D6" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"03754DZ" = "1" /* Dilation of Right Axillary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03754E6" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"03754EZ" = "1" /* Dilation of Right Axillary Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"03754F6" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"03754FZ" = "1" /* Dilation of Right Axillary Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"03754G6" = "1" /* Dilation of Right Axillary Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"03754GZ" = "1" /* Dilation of Right Axillary Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"03754Z6" = "1" /* Dilation of Right Axillary Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03754ZZ" = "1" /* Dilation of Right Axillary Artery, Percutaneous Endoscopic Approach */
"0376046" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037604Z" = "1" /* Dilation of Left Axillary Artery with Drug-eluting Intraluminal Device, Open Approach */
"0376056" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037605Z" = "1" /* Dilation of Left Axillary Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0376066" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037606Z" = "1" /* Dilation of Left Axillary Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0376076" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037607Z" = "1" /* Dilation of Left Axillary Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"03760D6" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Intraluminal Device, Open Approach */
"03760DZ" = "1" /* Dilation of Left Axillary Artery with Intraluminal Device, Open Approach */
"03760E6" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"03760EZ" = "1" /* Dilation of Left Axillary Artery with Two Intraluminal Devices, Open Approach */
"03760F6" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"03760FZ" = "1" /* Dilation of Left Axillary Artery with Three Intraluminal Devices, Open Approach */
"03760G6" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"03760GZ" = "1" /* Dilation of Left Axillary Artery with Four or More Intraluminal Devices, Open Approach */
"03760Z6" = "1" /* Dilation of Left Axillary Artery, Bifurcation, Open Approach */
"03760ZZ" = "1" /* Dilation of Left Axillary Artery, Open Approach */
"0376346" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037634Z" = "1" /* Dilation of Left Axillary Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0376356" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037635Z" = "1" /* Dilation of Left Axillary Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0376366" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037636Z" = "1" /* Dilation of Left Axillary Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0376376" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037637Z" = "1" /* Dilation of Left Axillary Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"03763D6" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"03763DZ" = "1" /* Dilation of Left Axillary Artery with Intraluminal Device, Percutaneous Approach */
"03763E6" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"03763EZ" = "1" /* Dilation of Left Axillary Artery with Two Intraluminal Devices, Percutaneous Approach */
"03763F6" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"03763FZ" = "1" /* Dilation of Left Axillary Artery with Three Intraluminal Devices, Percutaneous Approach */
"03763G6" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"03763GZ" = "1" /* Dilation of Left Axillary Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"03763Z6" = "1" /* Dilation of Left Axillary Artery, Bifurcation, Percutaneous Approach */
"03763ZZ" = "1" /* Dilation of Left Axillary Artery, Percutaneous Approach */
"0376446" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037644Z" = "1" /* Dilation of Left Axillary Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0376456" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037645Z" = "1" /* Dilation of Left Axillary Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0376466" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037646Z" = "1" /* Dilation of Left Axillary Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0376476" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037647Z" = "1" /* Dilation of Left Axillary Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"03764D6" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"03764DZ" = "1" /* Dilation of Left Axillary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03764E6" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"03764EZ" = "1" /* Dilation of Left Axillary Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"03764F6" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"03764FZ" = "1" /* Dilation of Left Axillary Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"03764G6" = "1" /* Dilation of Left Axillary Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"03764GZ" = "1" /* Dilation of Left Axillary Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"03764Z6" = "1" /* Dilation of Left Axillary Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03764ZZ" = "1" /* Dilation of Left Axillary Artery, Percutaneous Endoscopic Approach */
"0377046" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037704Z" = "1" /* Dilation of Right Brachial Artery with Drug-eluting Intraluminal Device, Open Approach */
"0377056" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037705Z" = "1" /* Dilation of Right Brachial Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0377066" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037706Z" = "1" /* Dilation of Right Brachial Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0377076" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037707Z" = "1" /* Dilation of Right Brachial Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"03770D6" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Intraluminal Device, Open Approach */
"03770DZ" = "1" /* Dilation of Right Brachial Artery with Intraluminal Device, Open Approach */
"03770E6" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"03770EZ" = "1" /* Dilation of Right Brachial Artery with Two Intraluminal Devices, Open Approach */
"03770F6" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"03770FZ" = "1" /* Dilation of Right Brachial Artery with Three Intraluminal Devices, Open Approach */
"03770G6" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"03770GZ" = "1" /* Dilation of Right Brachial Artery with Four or More Intraluminal Devices, Open Approach */
"03770Z6" = "1" /* Dilation of Right Brachial Artery, Bifurcation, Open Approach */
"03770ZZ" = "1" /* Dilation of Right Brachial Artery, Open Approach */
"0377346" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037734Z" = "1" /* Dilation of Right Brachial Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0377356" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037735Z" = "1" /* Dilation of Right Brachial Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0377366" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037736Z" = "1" /* Dilation of Right Brachial Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0377376" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037737Z" = "1" /* Dilation of Right Brachial Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"03773D6" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"03773DZ" = "1" /* Dilation of Right Brachial Artery with Intraluminal Device, Percutaneous Approach */
"03773E6" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"03773EZ" = "1" /* Dilation of Right Brachial Artery with Two Intraluminal Devices, Percutaneous Approach */
"03773F6" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"03773FZ" = "1" /* Dilation of Right Brachial Artery with Three Intraluminal Devices, Percutaneous Approach */
"03773G6" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"03773GZ" = "1" /* Dilation of Right Brachial Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"03773Z6" = "1" /* Dilation of Right Brachial Artery, Bifurcation, Percutaneous Approach */
"03773ZZ" = "1" /* Dilation of Right Brachial Artery, Percutaneous Approach */
"0377446" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037744Z" = "1" /* Dilation of Right Brachial Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0377456" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037745Z" = "1" /* Dilation of Right Brachial Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0377466" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037746Z" = "1" /* Dilation of Right Brachial Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0377476" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037747Z" = "1" /* Dilation of Right Brachial Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"03774D6" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"03774DZ" = "1" /* Dilation of Right Brachial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03774E6" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"03774EZ" = "1" /* Dilation of Right Brachial Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"03774F6" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"03774FZ" = "1" /* Dilation of Right Brachial Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"03774G6" = "1" /* Dilation of Right Brachial Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"03774GZ" = "1" /* Dilation of Right Brachial Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"03774Z6" = "1" /* Dilation of Right Brachial Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03774ZZ" = "1" /* Dilation of Right Brachial Artery, Percutaneous Endoscopic Approach */
"0378046" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037804Z" = "1" /* Dilation of Left Brachial Artery with Drug-eluting Intraluminal Device, Open Approach */
"0378056" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037805Z" = "1" /* Dilation of Left Brachial Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0378066" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037806Z" = "1" /* Dilation of Left Brachial Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0378076" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037807Z" = "1" /* Dilation of Left Brachial Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"03780D6" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Intraluminal Device, Open Approach */
"03780DZ" = "1" /* Dilation of Left Brachial Artery with Intraluminal Device, Open Approach */
"03780E6" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"03780EZ" = "1" /* Dilation of Left Brachial Artery with Two Intraluminal Devices, Open Approach */
"03780F6" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"03780FZ" = "1" /* Dilation of Left Brachial Artery with Three Intraluminal Devices, Open Approach */
"03780G6" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"03780GZ" = "1" /* Dilation of Left Brachial Artery with Four or More Intraluminal Devices, Open Approach */
"03780Z6" = "1" /* Dilation of Left Brachial Artery, Bifurcation, Open Approach */
"03780ZZ" = "1" /* Dilation of Left Brachial Artery, Open Approach */
"0378346" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037834Z" = "1" /* Dilation of Left Brachial Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0378356" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037835Z" = "1" /* Dilation of Left Brachial Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0378366" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037836Z" = "1" /* Dilation of Left Brachial Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0378376" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037837Z" = "1" /* Dilation of Left Brachial Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"03783D6" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"03783DZ" = "1" /* Dilation of Left Brachial Artery with Intraluminal Device, Percutaneous Approach */
"03783E6" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"03783EZ" = "1" /* Dilation of Left Brachial Artery with Two Intraluminal Devices, Percutaneous Approach */
"03783F6" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"03783FZ" = "1" /* Dilation of Left Brachial Artery with Three Intraluminal Devices, Percutaneous Approach */
"03783G6" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"03783GZ" = "1" /* Dilation of Left Brachial Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"03783Z6" = "1" /* Dilation of Left Brachial Artery, Bifurcation, Percutaneous Approach */
"03783ZZ" = "1" /* Dilation of Left Brachial Artery, Percutaneous Approach */
"0378446" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037844Z" = "1" /* Dilation of Left Brachial Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0378456" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037845Z" = "1" /* Dilation of Left Brachial Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0378466" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037846Z" = "1" /* Dilation of Left Brachial Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0378476" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037847Z" = "1" /* Dilation of Left Brachial Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"03784D6" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"03784DZ" = "1" /* Dilation of Left Brachial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03784E6" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"03784EZ" = "1" /* Dilation of Left Brachial Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"03784F6" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"03784FZ" = "1" /* Dilation of Left Brachial Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"03784G6" = "1" /* Dilation of Left Brachial Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"03784GZ" = "1" /* Dilation of Left Brachial Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"03784Z6" = "1" /* Dilation of Left Brachial Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03784ZZ" = "1" /* Dilation of Left Brachial Artery, Percutaneous Endoscopic Approach */
"0379046" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037904Z" = "1" /* Dilation of Right Ulnar Artery with Drug-eluting Intraluminal Device, Open Approach */
"0379056" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037905Z" = "1" /* Dilation of Right Ulnar Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0379066" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037906Z" = "1" /* Dilation of Right Ulnar Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0379076" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037907Z" = "1" /* Dilation of Right Ulnar Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"03790D6" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Intraluminal Device, Open Approach */
"03790DZ" = "1" /* Dilation of Right Ulnar Artery with Intraluminal Device, Open Approach */
"03790E6" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"03790EZ" = "1" /* Dilation of Right Ulnar Artery with Two Intraluminal Devices, Open Approach */
"03790F6" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"03790FZ" = "1" /* Dilation of Right Ulnar Artery with Three Intraluminal Devices, Open Approach */
"03790G6" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"03790GZ" = "1" /* Dilation of Right Ulnar Artery with Four or More Intraluminal Devices, Open Approach */
"03790Z6" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, Open Approach */
"03790ZZ" = "1" /* Dilation of Right Ulnar Artery, Open Approach */
"0379346" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037934Z" = "1" /* Dilation of Right Ulnar Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0379356" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037935Z" = "1" /* Dilation of Right Ulnar Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0379366" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037936Z" = "1" /* Dilation of Right Ulnar Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0379376" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037937Z" = "1" /* Dilation of Right Ulnar Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"03793D6" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"03793DZ" = "1" /* Dilation of Right Ulnar Artery with Intraluminal Device, Percutaneous Approach */
"03793E6" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"03793EZ" = "1" /* Dilation of Right Ulnar Artery with Two Intraluminal Devices, Percutaneous Approach */
"03793F6" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"03793FZ" = "1" /* Dilation of Right Ulnar Artery with Three Intraluminal Devices, Percutaneous Approach */
"03793G6" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"03793GZ" = "1" /* Dilation of Right Ulnar Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"03793Z6" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, Percutaneous Approach */
"03793ZZ" = "1" /* Dilation of Right Ulnar Artery, Percutaneous Approach */
"0379446" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037944Z" = "1" /* Dilation of Right Ulnar Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0379456" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037945Z" = "1" /* Dilation of Right Ulnar Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0379466" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037946Z" = "1" /* Dilation of Right Ulnar Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0379476" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037947Z" = "1" /* Dilation of Right Ulnar Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"03794D6" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"03794DZ" = "1" /* Dilation of Right Ulnar Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03794E6" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"03794EZ" = "1" /* Dilation of Right Ulnar Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"03794F6" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"03794FZ" = "1" /* Dilation of Right Ulnar Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"03794G6" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"03794GZ" = "1" /* Dilation of Right Ulnar Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"03794Z6" = "1" /* Dilation of Right Ulnar Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03794ZZ" = "1" /* Dilation of Right Ulnar Artery, Percutaneous Endoscopic Approach */
"037A046" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037A04Z" = "1" /* Dilation of Left Ulnar Artery with Drug-eluting Intraluminal Device, Open Approach */
"037A056" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037A05Z" = "1" /* Dilation of Left Ulnar Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"037A066" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037A06Z" = "1" /* Dilation of Left Ulnar Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"037A076" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037A07Z" = "1" /* Dilation of Left Ulnar Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037A0D6" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Intraluminal Device, Open Approach */
"037A0DZ" = "1" /* Dilation of Left Ulnar Artery with Intraluminal Device, Open Approach */
"037A0E6" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"037A0EZ" = "1" /* Dilation of Left Ulnar Artery with Two Intraluminal Devices, Open Approach */
"037A0F6" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"037A0FZ" = "1" /* Dilation of Left Ulnar Artery with Three Intraluminal Devices, Open Approach */
"037A0G6" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"037A0GZ" = "1" /* Dilation of Left Ulnar Artery with Four or More Intraluminal Devices, Open Approach */
"037A0Z6" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, Open Approach */
"037A0ZZ" = "1" /* Dilation of Left Ulnar Artery, Open Approach */
"037A346" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037A34Z" = "1" /* Dilation of Left Ulnar Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037A356" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037A35Z" = "1" /* Dilation of Left Ulnar Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037A366" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037A36Z" = "1" /* Dilation of Left Ulnar Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037A376" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037A37Z" = "1" /* Dilation of Left Ulnar Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037A3D6" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"037A3DZ" = "1" /* Dilation of Left Ulnar Artery with Intraluminal Device, Percutaneous Approach */
"037A3E6" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"037A3EZ" = "1" /* Dilation of Left Ulnar Artery with Two Intraluminal Devices, Percutaneous Approach */
"037A3F6" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"037A3FZ" = "1" /* Dilation of Left Ulnar Artery with Three Intraluminal Devices, Percutaneous Approach */
"037A3G6" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"037A3GZ" = "1" /* Dilation of Left Ulnar Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"037A3Z6" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, Percutaneous Approach */
"037A3ZZ" = "1" /* Dilation of Left Ulnar Artery, Percutaneous Approach */
"037A446" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037A44Z" = "1" /* Dilation of Left Ulnar Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037A456" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037A45Z" = "1" /* Dilation of Left Ulnar Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037A466" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037A46Z" = "1" /* Dilation of Left Ulnar Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037A476" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037A47Z" = "1" /* Dilation of Left Ulnar Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037A4D6" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"037A4DZ" = "1" /* Dilation of Left Ulnar Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"037A4E6" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037A4EZ" = "1" /* Dilation of Left Ulnar Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037A4F6" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037A4FZ" = "1" /* Dilation of Left Ulnar Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037A4G6" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037A4GZ" = "1" /* Dilation of Left Ulnar Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037A4Z6" = "1" /* Dilation of Left Ulnar Artery, Bifurcation, Percutaneous Endoscopic Approach */
"037A4ZZ" = "1" /* Dilation of Left Ulnar Artery, Percutaneous Endoscopic Approach */
"037B046" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037B04Z" = "1" /* Dilation of Right Radial Artery with Drug-eluting Intraluminal Device, Open Approach */
"037B056" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037B05Z" = "1" /* Dilation of Right Radial Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"037B066" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037B06Z" = "1" /* Dilation of Right Radial Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"037B076" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037B07Z" = "1" /* Dilation of Right Radial Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037B0D6" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Intraluminal Device, Open Approach */
"037B0DZ" = "1" /* Dilation of Right Radial Artery with Intraluminal Device, Open Approach */
"037B0E6" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"037B0EZ" = "1" /* Dilation of Right Radial Artery with Two Intraluminal Devices, Open Approach */
"037B0F6" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"037B0FZ" = "1" /* Dilation of Right Radial Artery with Three Intraluminal Devices, Open Approach */
"037B0G6" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"037B0GZ" = "1" /* Dilation of Right Radial Artery with Four or More Intraluminal Devices, Open Approach */
"037B0Z6" = "1" /* Dilation of Right Radial Artery, Bifurcation, Open Approach */
"037B0ZZ" = "1" /* Dilation of Right Radial Artery, Open Approach */
"037B346" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037B34Z" = "1" /* Dilation of Right Radial Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037B356" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037B35Z" = "1" /* Dilation of Right Radial Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037B366" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037B36Z" = "1" /* Dilation of Right Radial Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037B376" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037B37Z" = "1" /* Dilation of Right Radial Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037B3D6" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"037B3DZ" = "1" /* Dilation of Right Radial Artery with Intraluminal Device, Percutaneous Approach */
"037B3E6" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"037B3EZ" = "1" /* Dilation of Right Radial Artery with Two Intraluminal Devices, Percutaneous Approach */
"037B3F6" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"037B3FZ" = "1" /* Dilation of Right Radial Artery with Three Intraluminal Devices, Percutaneous Approach */
"037B3G6" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"037B3GZ" = "1" /* Dilation of Right Radial Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"037B3Z6" = "1" /* Dilation of Right Radial Artery, Bifurcation, Percutaneous Approach */
"037B3ZZ" = "1" /* Dilation of Right Radial Artery, Percutaneous Approach */
"037B446" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037B44Z" = "1" /* Dilation of Right Radial Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037B456" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037B45Z" = "1" /* Dilation of Right Radial Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037B466" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037B46Z" = "1" /* Dilation of Right Radial Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037B476" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037B47Z" = "1" /* Dilation of Right Radial Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037B4D6" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"037B4DZ" = "1" /* Dilation of Right Radial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"037B4E6" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037B4EZ" = "1" /* Dilation of Right Radial Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037B4F6" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037B4FZ" = "1" /* Dilation of Right Radial Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037B4G6" = "1" /* Dilation of Right Radial Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037B4GZ" = "1" /* Dilation of Right Radial Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037B4Z6" = "1" /* Dilation of Right Radial Artery, Bifurcation, Percutaneous Endoscopic Approach */
"037B4ZZ" = "1" /* Dilation of Right Radial Artery, Percutaneous Endoscopic Approach */
"037C046" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037C04Z" = "1" /* Dilation of Left Radial Artery with Drug-eluting Intraluminal Device, Open Approach */
"037C056" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037C05Z" = "1" /* Dilation of Left Radial Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"037C066" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037C06Z" = "1" /* Dilation of Left Radial Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"037C076" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037C07Z" = "1" /* Dilation of Left Radial Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037C0D6" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Intraluminal Device, Open Approach */
"037C0DZ" = "1" /* Dilation of Left Radial Artery with Intraluminal Device, Open Approach */
"037C0E6" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"037C0EZ" = "1" /* Dilation of Left Radial Artery with Two Intraluminal Devices, Open Approach */
"037C0F6" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"037C0FZ" = "1" /* Dilation of Left Radial Artery with Three Intraluminal Devices, Open Approach */
"037C0G6" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"037C0GZ" = "1" /* Dilation of Left Radial Artery with Four or More Intraluminal Devices, Open Approach */
"037C0Z6" = "1" /* Dilation of Left Radial Artery, Bifurcation, Open Approach */
"037C0ZZ" = "1" /* Dilation of Left Radial Artery, Open Approach */
"037C346" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037C34Z" = "1" /* Dilation of Left Radial Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037C356" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037C35Z" = "1" /* Dilation of Left Radial Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037C366" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037C36Z" = "1" /* Dilation of Left Radial Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037C376" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037C37Z" = "1" /* Dilation of Left Radial Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037C3D6" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"037C3DZ" = "1" /* Dilation of Left Radial Artery with Intraluminal Device, Percutaneous Approach */
"037C3E6" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"037C3EZ" = "1" /* Dilation of Left Radial Artery with Two Intraluminal Devices, Percutaneous Approach */
"037C3F6" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"037C3FZ" = "1" /* Dilation of Left Radial Artery with Three Intraluminal Devices, Percutaneous Approach */
"037C3G6" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"037C3GZ" = "1" /* Dilation of Left Radial Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"037C3Z6" = "1" /* Dilation of Left Radial Artery, Bifurcation, Percutaneous Approach */
"037C3ZZ" = "1" /* Dilation of Left Radial Artery, Percutaneous Approach */
"037C446" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037C44Z" = "1" /* Dilation of Left Radial Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037C456" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037C45Z" = "1" /* Dilation of Left Radial Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037C466" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037C46Z" = "1" /* Dilation of Left Radial Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037C476" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037C47Z" = "1" /* Dilation of Left Radial Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037C4D6" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"037C4DZ" = "1" /* Dilation of Left Radial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"037C4E6" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037C4EZ" = "1" /* Dilation of Left Radial Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037C4F6" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037C4FZ" = "1" /* Dilation of Left Radial Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037C4G6" = "1" /* Dilation of Left Radial Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037C4GZ" = "1" /* Dilation of Left Radial Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037C4Z6" = "1" /* Dilation of Left Radial Artery, Bifurcation, Percutaneous Endoscopic Approach */
"037C4ZZ" = "1" /* Dilation of Left Radial Artery, Percutaneous Endoscopic Approach */
"037D046" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037D04Z" = "1" /* Dilation of Right Hand Artery with Drug-eluting Intraluminal Device, Open Approach */
"037D056" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037D05Z" = "1" /* Dilation of Right Hand Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"037D066" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037D06Z" = "1" /* Dilation of Right Hand Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"037D076" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037D07Z" = "1" /* Dilation of Right Hand Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037D0D6" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Intraluminal Device, Open Approach */
"037D0DZ" = "1" /* Dilation of Right Hand Artery with Intraluminal Device, Open Approach */
"037D0E6" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"037D0EZ" = "1" /* Dilation of Right Hand Artery with Two Intraluminal Devices, Open Approach */
"037D0F6" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"037D0FZ" = "1" /* Dilation of Right Hand Artery with Three Intraluminal Devices, Open Approach */
"037D0G6" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"037D0GZ" = "1" /* Dilation of Right Hand Artery with Four or More Intraluminal Devices, Open Approach */
"037D0Z6" = "1" /* Dilation of Right Hand Artery, Bifurcation, Open Approach */
"037D0ZZ" = "1" /* Dilation of Right Hand Artery, Open Approach */
"037D346" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037D34Z" = "1" /* Dilation of Right Hand Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037D356" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037D35Z" = "1" /* Dilation of Right Hand Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037D366" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037D36Z" = "1" /* Dilation of Right Hand Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037D376" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037D37Z" = "1" /* Dilation of Right Hand Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037D3D6" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"037D3DZ" = "1" /* Dilation of Right Hand Artery with Intraluminal Device, Percutaneous Approach */
"037D3E6" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"037D3EZ" = "1" /* Dilation of Right Hand Artery with Two Intraluminal Devices, Percutaneous Approach */
"037D3F6" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"037D3FZ" = "1" /* Dilation of Right Hand Artery with Three Intraluminal Devices, Percutaneous Approach */
"037D3G6" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"037D3GZ" = "1" /* Dilation of Right Hand Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"037D3Z6" = "1" /* Dilation of Right Hand Artery, Bifurcation, Percutaneous Approach */
"037D3ZZ" = "1" /* Dilation of Right Hand Artery, Percutaneous Approach */
"037D446" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037D44Z" = "1" /* Dilation of Right Hand Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037D456" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037D45Z" = "1" /* Dilation of Right Hand Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037D466" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037D46Z" = "1" /* Dilation of Right Hand Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037D476" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037D47Z" = "1" /* Dilation of Right Hand Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037D4D6" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"037D4DZ" = "1" /* Dilation of Right Hand Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"037D4E6" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037D4EZ" = "1" /* Dilation of Right Hand Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037D4F6" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037D4FZ" = "1" /* Dilation of Right Hand Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037D4G6" = "1" /* Dilation of Right Hand Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037D4GZ" = "1" /* Dilation of Right Hand Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037D4Z6" = "1" /* Dilation of Right Hand Artery, Bifurcation, Percutaneous Endoscopic Approach */
"037D4ZZ" = "1" /* Dilation of Right Hand Artery, Percutaneous Endoscopic Approach */
"037F046" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037F04Z" = "1" /* Dilation of Left Hand Artery with Drug-eluting Intraluminal Device, Open Approach */
"037F056" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037F05Z" = "1" /* Dilation of Left Hand Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"037F066" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037F06Z" = "1" /* Dilation of Left Hand Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"037F076" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037F07Z" = "1" /* Dilation of Left Hand Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037F0D6" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Intraluminal Device, Open Approach */
"037F0DZ" = "1" /* Dilation of Left Hand Artery with Intraluminal Device, Open Approach */
"037F0E6" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"037F0EZ" = "1" /* Dilation of Left Hand Artery with Two Intraluminal Devices, Open Approach */
"037F0F6" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"037F0FZ" = "1" /* Dilation of Left Hand Artery with Three Intraluminal Devices, Open Approach */
"037F0G6" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"037F0GZ" = "1" /* Dilation of Left Hand Artery with Four or More Intraluminal Devices, Open Approach */
"037F0Z6" = "1" /* Dilation of Left Hand Artery, Bifurcation, Open Approach */
"037F0ZZ" = "1" /* Dilation of Left Hand Artery, Open Approach */
"037F346" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037F34Z" = "1" /* Dilation of Left Hand Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037F356" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037F35Z" = "1" /* Dilation of Left Hand Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037F366" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037F36Z" = "1" /* Dilation of Left Hand Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037F376" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037F37Z" = "1" /* Dilation of Left Hand Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037F3D6" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"037F3DZ" = "1" /* Dilation of Left Hand Artery with Intraluminal Device, Percutaneous Approach */
"037F3E6" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"037F3EZ" = "1" /* Dilation of Left Hand Artery with Two Intraluminal Devices, Percutaneous Approach */
"037F3F6" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"037F3FZ" = "1" /* Dilation of Left Hand Artery with Three Intraluminal Devices, Percutaneous Approach */
"037F3G6" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"037F3GZ" = "1" /* Dilation of Left Hand Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"037F3Z6" = "1" /* Dilation of Left Hand Artery, Bifurcation, Percutaneous Approach */
"037F3ZZ" = "1" /* Dilation of Left Hand Artery, Percutaneous Approach */
"037F446" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037F44Z" = "1" /* Dilation of Left Hand Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037F456" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037F45Z" = "1" /* Dilation of Left Hand Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037F466" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037F46Z" = "1" /* Dilation of Left Hand Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037F476" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037F47Z" = "1" /* Dilation of Left Hand Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037F4D6" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"037F4DZ" = "1" /* Dilation of Left Hand Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"037F4E6" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037F4EZ" = "1" /* Dilation of Left Hand Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037F4F6" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037F4FZ" = "1" /* Dilation of Left Hand Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037F4G6" = "1" /* Dilation of Left Hand Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037F4GZ" = "1" /* Dilation of Left Hand Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037F4Z6" = "1" /* Dilation of Left Hand Artery, Bifurcation, Percutaneous Endoscopic Approach */
"037F4ZZ" = "1" /* Dilation of Left Hand Artery, Percutaneous Endoscopic Approach */
"037G046" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037G04Z" = "1" /* Dilation of Intracranial Artery with Drug-eluting Intraluminal Device, Open Approach */
"037G056" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037G05Z" = "1" /* Dilation of Intracranial Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"037G066" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037G06Z" = "1" /* Dilation of Intracranial Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"037G076" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037G07Z" = "1" /* Dilation of Intracranial Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037G0D6" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Intraluminal Device, Open Approach */
"037G0DZ" = "1" /* Dilation of Intracranial Artery with Intraluminal Device, Open Approach */
"037G0E6" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"037G0EZ" = "1" /* Dilation of Intracranial Artery with Two Intraluminal Devices, Open Approach */
"037G0F6" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"037G0FZ" = "1" /* Dilation of Intracranial Artery with Three Intraluminal Devices, Open Approach */
"037G0G6" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"037G0GZ" = "1" /* Dilation of Intracranial Artery with Four or More Intraluminal Devices, Open Approach */
"037G0Z6" = "1" /* Dilation of Intracranial Artery, Bifurcation, Open Approach */
"037G0ZZ" = "1" /* Dilation of Intracranial Artery, Open Approach */
"037G346" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037G34Z" = "1" /* Dilation of Intracranial Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037G356" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037G35Z" = "1" /* Dilation of Intracranial Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037G366" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037G36Z" = "1" /* Dilation of Intracranial Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037G376" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037G37Z" = "1" /* Dilation of Intracranial Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037G3D6" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"037G3DZ" = "1" /* Dilation of Intracranial Artery with Intraluminal Device, Percutaneous Approach */
"037G3E6" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"037G3EZ" = "1" /* Dilation of Intracranial Artery with Two Intraluminal Devices, Percutaneous Approach */
"037G3F6" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"037G3FZ" = "1" /* Dilation of Intracranial Artery with Three Intraluminal Devices, Percutaneous Approach */
"037G3G6" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"037G3GZ" = "1" /* Dilation of Intracranial Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"037G3Z6" = "1" /* Dilation of Intracranial Artery, Bifurcation, Percutaneous Approach */
"037G3ZZ" = "1" /* Dilation of Intracranial Artery, Percutaneous Approach */
"037G446" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037G44Z" = "1" /* Dilation of Intracranial Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037G456" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037G45Z" = "1" /* Dilation of Intracranial Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037G466" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037G46Z" = "1" /* Dilation of Intracranial Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037G476" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037G47Z" = "1" /* Dilation of Intracranial Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037G4D6" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"037G4DZ" = "1" /* Dilation of Intracranial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"037G4E6" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037G4EZ" = "1" /* Dilation of Intracranial Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037G4F6" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037G4FZ" = "1" /* Dilation of Intracranial Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037G4G6" = "1" /* Dilation of Intracranial Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037G4GZ" = "1" /* Dilation of Intracranial Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037G4Z6" = "1" /* Dilation of Intracranial Artery, Bifurcation, Percutaneous Endoscopic Approach */
"037G4ZZ" = "1" /* Dilation of Intracranial Artery, Percutaneous Endoscopic Approach */
"037H046" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037H04Z" = "1" /* Dilation of Right Common Carotid Artery with Drug-eluting Intraluminal Device, Open Approach */
"037H056" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037H05Z" = "1" /* Dilation of Right Common Carotid Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"037H066" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037H06Z" = "1" /* Dilation of Right Common Carotid Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"037H076" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037H07Z" = "1" /* Dilation of Right Common Carotid Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037H0D6" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Intraluminal Device, Open Approach */
"037H0DZ" = "1" /* Dilation of Right Common Carotid Artery with Intraluminal Device, Open Approach */
"037H0E6" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"037H0EZ" = "1" /* Dilation of Right Common Carotid Artery with Two Intraluminal Devices, Open Approach */
"037H0F6" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"037H0FZ" = "1" /* Dilation of Right Common Carotid Artery with Three Intraluminal Devices, Open Approach */
"037H0G6" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"037H0GZ" = "1" /* Dilation of Right Common Carotid Artery with Four or More Intraluminal Devices, Open Approach */
"037H0Z6" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, Open Approach */
"037H0ZZ" = "1" /* Dilation of Right Common Carotid Artery, Open Approach */
"037H346" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037H34Z" = "1" /* Dilation of Right Common Carotid Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037H356" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037H35Z" = "1" /* Dilation of Right Common Carotid Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037H366" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037H36Z" = "1" /* Dilation of Right Common Carotid Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037H376" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037H37Z" = "1" /* Dilation of Right Common Carotid Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037H3D6" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"037H3DZ" = "1" /* Dilation of Right Common Carotid Artery with Intraluminal Device, Percutaneous Approach */
"037H3E6" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"037H3EZ" = "1" /* Dilation of Right Common Carotid Artery with Two Intraluminal Devices, Percutaneous Approach */
"037H3F6" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"037H3FZ" = "1" /* Dilation of Right Common Carotid Artery with Three Intraluminal Devices, Percutaneous Approach */
"037H3G6" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"037H3GZ" = "1" /* Dilation of Right Common Carotid Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"037H3Z6" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, Percutaneous Approach */
"037H3ZZ" = "1" /* Dilation of Right Common Carotid Artery, Percutaneous Approach */
"037H446" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037H44Z" = "1" /* Dilation of Right Common Carotid Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037H456" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037H45Z" = "1" /* Dilation of Right Common Carotid Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037H466" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037H46Z" = "1" /* Dilation of Right Common Carotid Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037H476" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037H47Z" = "1" /* Dilation of Right Common Carotid Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037H4D6" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"037H4DZ" = "1" /* Dilation of Right Common Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"037H4E6" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037H4EZ" = "1" /* Dilation of Right Common Carotid Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037H4F6" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037H4FZ" = "1" /* Dilation of Right Common Carotid Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037H4G6" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037H4GZ" = "1" /* Dilation of Right Common Carotid Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037H4Z6" = "1" /* Dilation of Right Common Carotid Artery, Bifurcation, Percutaneous Endoscopic Approach */
"037H4ZZ" = "1" /* Dilation of Right Common Carotid Artery, Percutaneous Endoscopic Approach */
"037J046" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037J04Z" = "1" /* Dilation of Left Common Carotid Artery with Drug-eluting Intraluminal Device, Open Approach */
"037J056" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037J05Z" = "1" /* Dilation of Left Common Carotid Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"037J066" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037J06Z" = "1" /* Dilation of Left Common Carotid Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"037J076" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037J07Z" = "1" /* Dilation of Left Common Carotid Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037J0D6" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Intraluminal Device, Open Approach */
"037J0DZ" = "1" /* Dilation of Left Common Carotid Artery with Intraluminal Device, Open Approach */
"037J0E6" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"037J0EZ" = "1" /* Dilation of Left Common Carotid Artery with Two Intraluminal Devices, Open Approach */
"037J0F6" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"037J0FZ" = "1" /* Dilation of Left Common Carotid Artery with Three Intraluminal Devices, Open Approach */
"037J0G6" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"037J0GZ" = "1" /* Dilation of Left Common Carotid Artery with Four or More Intraluminal Devices, Open Approach */
"037J0Z6" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, Open Approach */
"037J0ZZ" = "1" /* Dilation of Left Common Carotid Artery, Open Approach */
"037J346" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037J34Z" = "1" /* Dilation of Left Common Carotid Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037J356" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037J35Z" = "1" /* Dilation of Left Common Carotid Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037J366" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037J36Z" = "1" /* Dilation of Left Common Carotid Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037J376" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037J37Z" = "1" /* Dilation of Left Common Carotid Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037J3D6" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"037J3DZ" = "1" /* Dilation of Left Common Carotid Artery with Intraluminal Device, Percutaneous Approach */
"037J3E6" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"037J3EZ" = "1" /* Dilation of Left Common Carotid Artery with Two Intraluminal Devices, Percutaneous Approach */
"037J3F6" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"037J3FZ" = "1" /* Dilation of Left Common Carotid Artery with Three Intraluminal Devices, Percutaneous Approach */
"037J3G6" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"037J3GZ" = "1" /* Dilation of Left Common Carotid Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"037J3Z6" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, Percutaneous Approach */
"037J3ZZ" = "1" /* Dilation of Left Common Carotid Artery, Percutaneous Approach */
"037J446" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037J44Z" = "1" /* Dilation of Left Common Carotid Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037J456" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037J45Z" = "1" /* Dilation of Left Common Carotid Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037J466" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037J46Z" = "1" /* Dilation of Left Common Carotid Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037J476" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037J47Z" = "1" /* Dilation of Left Common Carotid Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037J4D6" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"037J4DZ" = "1" /* Dilation of Left Common Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"037J4E6" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037J4EZ" = "1" /* Dilation of Left Common Carotid Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037J4F6" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037J4FZ" = "1" /* Dilation of Left Common Carotid Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037J4G6" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037J4GZ" = "1" /* Dilation of Left Common Carotid Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037J4Z6" = "1" /* Dilation of Left Common Carotid Artery, Bifurcation, Percutaneous Endoscopic Approach */
"037J4ZZ" = "1" /* Dilation of Left Common Carotid Artery, Percutaneous Endoscopic Approach */
"037K046" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037K04Z" = "1" /* Dilation of Right Internal Carotid Artery with Drug-eluting Intraluminal Device, Open Approach */
"037K056" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037K05Z" = "1" /* Dilation of Right Internal Carotid Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"037K066" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037K06Z" = "1" /* Dilation of Right Internal Carotid Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"037K076" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037K07Z" = "1" /* Dilation of Right Internal Carotid Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037K0D6" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Intraluminal Device, Open Approach */
"037K0DZ" = "1" /* Dilation of Right Internal Carotid Artery with Intraluminal Device, Open Approach */
"037K0E6" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"037K0EZ" = "1" /* Dilation of Right Internal Carotid Artery with Two Intraluminal Devices, Open Approach */
"037K0F6" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"037K0FZ" = "1" /* Dilation of Right Internal Carotid Artery with Three Intraluminal Devices, Open Approach */
"037K0G6" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"037K0GZ" = "1" /* Dilation of Right Internal Carotid Artery with Four or More Intraluminal Devices, Open Approach */
"037K0Z6" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, Open Approach */
"037K0ZZ" = "1" /* Dilation of Right Internal Carotid Artery, Open Approach */
"037K346" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037K34Z" = "1" /* Dilation of Right Internal Carotid Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037K356" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037K35Z" = "1" /* Dilation of Right Internal Carotid Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037K366" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037K36Z" = "1" /* Dilation of Right Internal Carotid Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037K376" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037K37Z" = "1" /* Dilation of Right Internal Carotid Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037K3D6" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"037K3DZ" = "1" /* Dilation of Right Internal Carotid Artery with Intraluminal Device, Percutaneous Approach */
"037K3E6" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"037K3EZ" = "1" /* Dilation of Right Internal Carotid Artery with Two Intraluminal Devices, Percutaneous Approach */
"037K3F6" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"037K3FZ" = "1" /* Dilation of Right Internal Carotid Artery with Three Intraluminal Devices, Percutaneous Approach */
"037K3G6" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"037K3GZ" = "1" /* Dilation of Right Internal Carotid Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"037K3Z6" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, Percutaneous Approach */
"037K3ZZ" = "1" /* Dilation of Right Internal Carotid Artery, Percutaneous Approach */
"037K446" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037K44Z" = "1" /* Dilation of Right Internal Carotid Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037K456" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037K45Z" = "1" /* Dilation of Right Internal Carotid Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037K466" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037K46Z" = "1" /* Dilation of Right Internal Carotid Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037K476" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037K47Z" = "1" /* Dilation of Right Internal Carotid Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037K4D6" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"037K4DZ" = "1" /* Dilation of Right Internal Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"037K4E6" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037K4EZ" = "1" /* Dilation of Right Internal Carotid Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037K4F6" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037K4FZ" = "1" /* Dilation of Right Internal Carotid Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037K4G6" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037K4GZ" = "1" /* Dilation of Right Internal Carotid Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037K4Z6" = "1" /* Dilation of Right Internal Carotid Artery, Bifurcation, Percutaneous Endoscopic Approach */
"037K4ZZ" = "1" /* Dilation of Right Internal Carotid Artery, Percutaneous Endoscopic Approach */
"037L046" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037L04Z" = "1" /* Dilation of Left Internal Carotid Artery with Drug-eluting Intraluminal Device, Open Approach */
"037L056" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037L05Z" = "1" /* Dilation of Left Internal Carotid Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"037L066" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037L06Z" = "1" /* Dilation of Left Internal Carotid Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"037L076" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037L07Z" = "1" /* Dilation of Left Internal Carotid Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037L0D6" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Intraluminal Device, Open Approach */
"037L0DZ" = "1" /* Dilation of Left Internal Carotid Artery with Intraluminal Device, Open Approach */
"037L0E6" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"037L0EZ" = "1" /* Dilation of Left Internal Carotid Artery with Two Intraluminal Devices, Open Approach */
"037L0F6" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"037L0FZ" = "1" /* Dilation of Left Internal Carotid Artery with Three Intraluminal Devices, Open Approach */
"037L0G6" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"037L0GZ" = "1" /* Dilation of Left Internal Carotid Artery with Four or More Intraluminal Devices, Open Approach */
"037L0Z6" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, Open Approach */
"037L0ZZ" = "1" /* Dilation of Left Internal Carotid Artery, Open Approach */
"037L346" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037L34Z" = "1" /* Dilation of Left Internal Carotid Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037L356" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037L35Z" = "1" /* Dilation of Left Internal Carotid Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037L366" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037L36Z" = "1" /* Dilation of Left Internal Carotid Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037L376" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037L37Z" = "1" /* Dilation of Left Internal Carotid Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037L3D6" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"037L3DZ" = "1" /* Dilation of Left Internal Carotid Artery with Intraluminal Device, Percutaneous Approach */
"037L3E6" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"037L3EZ" = "1" /* Dilation of Left Internal Carotid Artery with Two Intraluminal Devices, Percutaneous Approach */
"037L3F6" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"037L3FZ" = "1" /* Dilation of Left Internal Carotid Artery with Three Intraluminal Devices, Percutaneous Approach */
"037L3G6" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"037L3GZ" = "1" /* Dilation of Left Internal Carotid Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"037L3Z6" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, Percutaneous Approach */
"037L3ZZ" = "1" /* Dilation of Left Internal Carotid Artery, Percutaneous Approach */
"037L446" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037L44Z" = "1" /* Dilation of Left Internal Carotid Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037L456" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037L45Z" = "1" /* Dilation of Left Internal Carotid Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037L466" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037L46Z" = "1" /* Dilation of Left Internal Carotid Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037L476" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037L47Z" = "1" /* Dilation of Left Internal Carotid Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037L4D6" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"037L4DZ" = "1" /* Dilation of Left Internal Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"037L4E6" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037L4EZ" = "1" /* Dilation of Left Internal Carotid Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037L4F6" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037L4FZ" = "1" /* Dilation of Left Internal Carotid Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037L4G6" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037L4GZ" = "1" /* Dilation of Left Internal Carotid Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037L4Z6" = "1" /* Dilation of Left Internal Carotid Artery, Bifurcation, Percutaneous Endoscopic Approach */
"037L4ZZ" = "1" /* Dilation of Left Internal Carotid Artery, Percutaneous Endoscopic Approach */
"037M046" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037M04Z" = "1" /* Dilation of Right External Carotid Artery with Drug-eluting Intraluminal Device, Open Approach */
"037M056" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037M05Z" = "1" /* Dilation of Right External Carotid Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"037M066" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037M06Z" = "1" /* Dilation of Right External Carotid Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"037M076" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037M07Z" = "1" /* Dilation of Right External Carotid Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037M0D6" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Intraluminal Device, Open Approach */
"037M0DZ" = "1" /* Dilation of Right External Carotid Artery with Intraluminal Device, Open Approach */
"037M0E6" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"037M0EZ" = "1" /* Dilation of Right External Carotid Artery with Two Intraluminal Devices, Open Approach */
"037M0F6" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"037M0FZ" = "1" /* Dilation of Right External Carotid Artery with Three Intraluminal Devices, Open Approach */
"037M0G6" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"037M0GZ" = "1" /* Dilation of Right External Carotid Artery with Four or More Intraluminal Devices, Open Approach */
"037M0Z6" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, Open Approach */
"037M0ZZ" = "1" /* Dilation of Right External Carotid Artery, Open Approach */
"037M346" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037M34Z" = "1" /* Dilation of Right External Carotid Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037M356" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037M35Z" = "1" /* Dilation of Right External Carotid Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037M366" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037M36Z" = "1" /* Dilation of Right External Carotid Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037M376" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037M37Z" = "1" /* Dilation of Right External Carotid Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037M3D6" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"037M3DZ" = "1" /* Dilation of Right External Carotid Artery with Intraluminal Device, Percutaneous Approach */
"037M3E6" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"037M3EZ" = "1" /* Dilation of Right External Carotid Artery with Two Intraluminal Devices, Percutaneous Approach */
"037M3F6" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"037M3FZ" = "1" /* Dilation of Right External Carotid Artery with Three Intraluminal Devices, Percutaneous Approach */
"037M3G6" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"037M3GZ" = "1" /* Dilation of Right External Carotid Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"037M3Z6" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, Percutaneous Approach */
"037M3ZZ" = "1" /* Dilation of Right External Carotid Artery, Percutaneous Approach */
"037M446" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037M44Z" = "1" /* Dilation of Right External Carotid Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037M456" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037M45Z" = "1" /* Dilation of Right External Carotid Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037M466" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037M46Z" = "1" /* Dilation of Right External Carotid Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037M476" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037M47Z" = "1" /* Dilation of Right External Carotid Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037M4D6" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"037M4DZ" = "1" /* Dilation of Right External Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"037M4E6" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037M4EZ" = "1" /* Dilation of Right External Carotid Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037M4F6" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037M4FZ" = "1" /* Dilation of Right External Carotid Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037M4G6" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037M4GZ" = "1" /* Dilation of Right External Carotid Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037M4Z6" = "1" /* Dilation of Right External Carotid Artery, Bifurcation, Percutaneous Endoscopic Approach */
"037M4ZZ" = "1" /* Dilation of Right External Carotid Artery, Percutaneous Endoscopic Approach */
"037N046" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037N04Z" = "1" /* Dilation of Left External Carotid Artery with Drug-eluting Intraluminal Device, Open Approach */
"037N056" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037N05Z" = "1" /* Dilation of Left External Carotid Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"037N066" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037N06Z" = "1" /* Dilation of Left External Carotid Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"037N076" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037N07Z" = "1" /* Dilation of Left External Carotid Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037N0D6" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Intraluminal Device, Open Approach */
"037N0DZ" = "1" /* Dilation of Left External Carotid Artery with Intraluminal Device, Open Approach */
"037N0E6" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"037N0EZ" = "1" /* Dilation of Left External Carotid Artery with Two Intraluminal Devices, Open Approach */
"037N0F6" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"037N0FZ" = "1" /* Dilation of Left External Carotid Artery with Three Intraluminal Devices, Open Approach */
"037N0G6" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"037N0GZ" = "1" /* Dilation of Left External Carotid Artery with Four or More Intraluminal Devices, Open Approach */
"037N0Z6" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, Open Approach */
"037N0ZZ" = "1" /* Dilation of Left External Carotid Artery, Open Approach */
"037N346" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037N34Z" = "1" /* Dilation of Left External Carotid Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037N356" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037N35Z" = "1" /* Dilation of Left External Carotid Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037N366" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037N36Z" = "1" /* Dilation of Left External Carotid Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037N376" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037N37Z" = "1" /* Dilation of Left External Carotid Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037N3D6" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"037N3DZ" = "1" /* Dilation of Left External Carotid Artery with Intraluminal Device, Percutaneous Approach */
"037N3E6" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"037N3EZ" = "1" /* Dilation of Left External Carotid Artery with Two Intraluminal Devices, Percutaneous Approach */
"037N3F6" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"037N3FZ" = "1" /* Dilation of Left External Carotid Artery with Three Intraluminal Devices, Percutaneous Approach */
"037N3G6" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"037N3GZ" = "1" /* Dilation of Left External Carotid Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"037N3Z6" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, Percutaneous Approach */
"037N3ZZ" = "1" /* Dilation of Left External Carotid Artery, Percutaneous Approach */
"037N446" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037N44Z" = "1" /* Dilation of Left External Carotid Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037N456" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037N45Z" = "1" /* Dilation of Left External Carotid Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037N466" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037N46Z" = "1" /* Dilation of Left External Carotid Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037N476" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037N47Z" = "1" /* Dilation of Left External Carotid Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037N4D6" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"037N4DZ" = "1" /* Dilation of Left External Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"037N4E6" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037N4EZ" = "1" /* Dilation of Left External Carotid Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037N4F6" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037N4FZ" = "1" /* Dilation of Left External Carotid Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037N4G6" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037N4GZ" = "1" /* Dilation of Left External Carotid Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037N4Z6" = "1" /* Dilation of Left External Carotid Artery, Bifurcation, Percutaneous Endoscopic Approach */
"037N4ZZ" = "1" /* Dilation of Left External Carotid Artery, Percutaneous Endoscopic Approach */
"037P046" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037P04Z" = "1" /* Dilation of Right Vertebral Artery with Drug-eluting Intraluminal Device, Open Approach */
"037P056" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037P05Z" = "1" /* Dilation of Right Vertebral Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"037P066" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037P06Z" = "1" /* Dilation of Right Vertebral Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"037P076" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037P07Z" = "1" /* Dilation of Right Vertebral Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037P0D6" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Intraluminal Device, Open Approach */
"037P0DZ" = "1" /* Dilation of Right Vertebral Artery with Intraluminal Device, Open Approach */
"037P0E6" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"037P0EZ" = "1" /* Dilation of Right Vertebral Artery with Two Intraluminal Devices, Open Approach */
"037P0F6" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"037P0FZ" = "1" /* Dilation of Right Vertebral Artery with Three Intraluminal Devices, Open Approach */
"037P0G6" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"037P0GZ" = "1" /* Dilation of Right Vertebral Artery with Four or More Intraluminal Devices, Open Approach */
"037P0Z6" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, Open Approach */
"037P0ZZ" = "1" /* Dilation of Right Vertebral Artery, Open Approach */
"037P346" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037P34Z" = "1" /* Dilation of Right Vertebral Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037P356" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037P35Z" = "1" /* Dilation of Right Vertebral Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037P366" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037P36Z" = "1" /* Dilation of Right Vertebral Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037P376" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037P37Z" = "1" /* Dilation of Right Vertebral Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037P3D6" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"037P3DZ" = "1" /* Dilation of Right Vertebral Artery with Intraluminal Device, Percutaneous Approach */
"037P3E6" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"037P3EZ" = "1" /* Dilation of Right Vertebral Artery with Two Intraluminal Devices, Percutaneous Approach */
"037P3F6" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"037P3FZ" = "1" /* Dilation of Right Vertebral Artery with Three Intraluminal Devices, Percutaneous Approach */
"037P3G6" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"037P3GZ" = "1" /* Dilation of Right Vertebral Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"037P3Z6" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, Percutaneous Approach */
"037P3ZZ" = "1" /* Dilation of Right Vertebral Artery, Percutaneous Approach */
"037P446" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037P44Z" = "1" /* Dilation of Right Vertebral Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037P456" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037P45Z" = "1" /* Dilation of Right Vertebral Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037P466" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037P46Z" = "1" /* Dilation of Right Vertebral Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037P476" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037P47Z" = "1" /* Dilation of Right Vertebral Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037P4D6" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"037P4DZ" = "1" /* Dilation of Right Vertebral Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"037P4E6" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037P4EZ" = "1" /* Dilation of Right Vertebral Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037P4F6" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037P4FZ" = "1" /* Dilation of Right Vertebral Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037P4G6" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037P4GZ" = "1" /* Dilation of Right Vertebral Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037P4Z6" = "1" /* Dilation of Right Vertebral Artery, Bifurcation, Percutaneous Endoscopic Approach */
"037P4ZZ" = "1" /* Dilation of Right Vertebral Artery, Percutaneous Endoscopic Approach */
"037Q046" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037Q04Z" = "1" /* Dilation of Left Vertebral Artery with Drug-eluting Intraluminal Device, Open Approach */
"037Q056" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037Q05Z" = "1" /* Dilation of Left Vertebral Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"037Q066" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037Q06Z" = "1" /* Dilation of Left Vertebral Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"037Q076" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037Q07Z" = "1" /* Dilation of Left Vertebral Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037Q0D6" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Intraluminal Device, Open Approach */
"037Q0DZ" = "1" /* Dilation of Left Vertebral Artery with Intraluminal Device, Open Approach */
"037Q0E6" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"037Q0EZ" = "1" /* Dilation of Left Vertebral Artery with Two Intraluminal Devices, Open Approach */
"037Q0F6" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"037Q0FZ" = "1" /* Dilation of Left Vertebral Artery with Three Intraluminal Devices, Open Approach */
"037Q0G6" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"037Q0GZ" = "1" /* Dilation of Left Vertebral Artery with Four or More Intraluminal Devices, Open Approach */
"037Q0Z6" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, Open Approach */
"037Q0ZZ" = "1" /* Dilation of Left Vertebral Artery, Open Approach */
"037Q346" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037Q34Z" = "1" /* Dilation of Left Vertebral Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037Q356" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037Q35Z" = "1" /* Dilation of Left Vertebral Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037Q366" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037Q36Z" = "1" /* Dilation of Left Vertebral Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037Q376" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037Q37Z" = "1" /* Dilation of Left Vertebral Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037Q3D6" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"037Q3DZ" = "1" /* Dilation of Left Vertebral Artery with Intraluminal Device, Percutaneous Approach */
"037Q3E6" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"037Q3EZ" = "1" /* Dilation of Left Vertebral Artery with Two Intraluminal Devices, Percutaneous Approach */
"037Q3F6" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"037Q3FZ" = "1" /* Dilation of Left Vertebral Artery with Three Intraluminal Devices, Percutaneous Approach */
"037Q3G6" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"037Q3GZ" = "1" /* Dilation of Left Vertebral Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"037Q3Z6" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, Percutaneous Approach */
"037Q3ZZ" = "1" /* Dilation of Left Vertebral Artery, Percutaneous Approach */
"037Q446" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037Q44Z" = "1" /* Dilation of Left Vertebral Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037Q456" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Q45Z" = "1" /* Dilation of Left Vertebral Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Q466" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Q46Z" = "1" /* Dilation of Left Vertebral Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Q476" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Q47Z" = "1" /* Dilation of Left Vertebral Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Q4D6" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"037Q4DZ" = "1" /* Dilation of Left Vertebral Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"037Q4E6" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Q4EZ" = "1" /* Dilation of Left Vertebral Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Q4F6" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Q4FZ" = "1" /* Dilation of Left Vertebral Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Q4G6" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Q4GZ" = "1" /* Dilation of Left Vertebral Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Q4Z6" = "1" /* Dilation of Left Vertebral Artery, Bifurcation, Percutaneous Endoscopic Approach */
"037Q4ZZ" = "1" /* Dilation of Left Vertebral Artery, Percutaneous Endoscopic Approach */
"037R046" = "1" /* Dilation of Face Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037R04Z" = "1" /* Dilation of Face Artery with Drug-eluting Intraluminal Device, Open Approach */
"037R056" = "1" /* Dilation of Face Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037R05Z" = "1" /* Dilation of Face Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"037R066" = "1" /* Dilation of Face Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037R06Z" = "1" /* Dilation of Face Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"037R076" = "1" /* Dilation of Face Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037R07Z" = "1" /* Dilation of Face Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037R0D6" = "1" /* Dilation of Face Artery, Bifurcation, with Intraluminal Device, Open Approach */
"037R0DZ" = "1" /* Dilation of Face Artery with Intraluminal Device, Open Approach */
"037R0E6" = "1" /* Dilation of Face Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"037R0EZ" = "1" /* Dilation of Face Artery with Two Intraluminal Devices, Open Approach */
"037R0F6" = "1" /* Dilation of Face Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"037R0FZ" = "1" /* Dilation of Face Artery with Three Intraluminal Devices, Open Approach */
"037R0G6" = "1" /* Dilation of Face Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"037R0GZ" = "1" /* Dilation of Face Artery with Four or More Intraluminal Devices, Open Approach */
"037R0Z6" = "1" /* Dilation of Face Artery, Bifurcation, Open Approach */
"037R0ZZ" = "1" /* Dilation of Face Artery, Open Approach */
"037R346" = "1" /* Dilation of Face Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037R34Z" = "1" /* Dilation of Face Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037R356" = "1" /* Dilation of Face Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037R35Z" = "1" /* Dilation of Face Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037R366" = "1" /* Dilation of Face Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037R36Z" = "1" /* Dilation of Face Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037R376" = "1" /* Dilation of Face Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037R37Z" = "1" /* Dilation of Face Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037R3D6" = "1" /* Dilation of Face Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"037R3DZ" = "1" /* Dilation of Face Artery with Intraluminal Device, Percutaneous Approach */
"037R3E6" = "1" /* Dilation of Face Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"037R3EZ" = "1" /* Dilation of Face Artery with Two Intraluminal Devices, Percutaneous Approach */
"037R3F6" = "1" /* Dilation of Face Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"037R3FZ" = "1" /* Dilation of Face Artery with Three Intraluminal Devices, Percutaneous Approach */
"037R3G6" = "1" /* Dilation of Face Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"037R3GZ" = "1" /* Dilation of Face Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"037R3Z6" = "1" /* Dilation of Face Artery, Bifurcation, Percutaneous Approach */
"037R3ZZ" = "1" /* Dilation of Face Artery, Percutaneous Approach */
"037R446" = "1" /* Dilation of Face Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037R44Z" = "1" /* Dilation of Face Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037R456" = "1" /* Dilation of Face Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037R45Z" = "1" /* Dilation of Face Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037R466" = "1" /* Dilation of Face Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037R46Z" = "1" /* Dilation of Face Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037R476" = "1" /* Dilation of Face Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037R47Z" = "1" /* Dilation of Face Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037R4D6" = "1" /* Dilation of Face Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"037R4DZ" = "1" /* Dilation of Face Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"037R4E6" = "1" /* Dilation of Face Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037R4EZ" = "1" /* Dilation of Face Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037R4F6" = "1" /* Dilation of Face Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037R4FZ" = "1" /* Dilation of Face Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037R4G6" = "1" /* Dilation of Face Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037R4GZ" = "1" /* Dilation of Face Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037R4Z6" = "1" /* Dilation of Face Artery, Bifurcation, Percutaneous Endoscopic Approach */
"037R4ZZ" = "1" /* Dilation of Face Artery, Percutaneous Endoscopic Approach */
"037S046" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037S04Z" = "1" /* Dilation of Right Temporal Artery with Drug-eluting Intraluminal Device, Open Approach */
"037S056" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037S05Z" = "1" /* Dilation of Right Temporal Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"037S066" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037S06Z" = "1" /* Dilation of Right Temporal Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"037S076" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037S07Z" = "1" /* Dilation of Right Temporal Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037S0D6" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Intraluminal Device, Open Approach */
"037S0DZ" = "1" /* Dilation of Right Temporal Artery with Intraluminal Device, Open Approach */
"037S0E6" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"037S0EZ" = "1" /* Dilation of Right Temporal Artery with Two Intraluminal Devices, Open Approach */
"037S0F6" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"037S0FZ" = "1" /* Dilation of Right Temporal Artery with Three Intraluminal Devices, Open Approach */
"037S0G6" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"037S0GZ" = "1" /* Dilation of Right Temporal Artery with Four or More Intraluminal Devices, Open Approach */
"037S0Z6" = "1" /* Dilation of Right Temporal Artery, Bifurcation, Open Approach */
"037S0ZZ" = "1" /* Dilation of Right Temporal Artery, Open Approach */
"037S346" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037S34Z" = "1" /* Dilation of Right Temporal Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037S356" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037S35Z" = "1" /* Dilation of Right Temporal Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037S366" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037S36Z" = "1" /* Dilation of Right Temporal Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037S376" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037S37Z" = "1" /* Dilation of Right Temporal Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037S3D6" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"037S3DZ" = "1" /* Dilation of Right Temporal Artery with Intraluminal Device, Percutaneous Approach */
"037S3E6" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"037S3EZ" = "1" /* Dilation of Right Temporal Artery with Two Intraluminal Devices, Percutaneous Approach */
"037S3F6" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"037S3FZ" = "1" /* Dilation of Right Temporal Artery with Three Intraluminal Devices, Percutaneous Approach */
"037S3G6" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"037S3GZ" = "1" /* Dilation of Right Temporal Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"037S3Z6" = "1" /* Dilation of Right Temporal Artery, Bifurcation, Percutaneous Approach */
"037S3ZZ" = "1" /* Dilation of Right Temporal Artery, Percutaneous Approach */
"037S446" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037S44Z" = "1" /* Dilation of Right Temporal Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037S456" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037S45Z" = "1" /* Dilation of Right Temporal Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037S466" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037S46Z" = "1" /* Dilation of Right Temporal Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037S476" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037S47Z" = "1" /* Dilation of Right Temporal Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037S4D6" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"037S4DZ" = "1" /* Dilation of Right Temporal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"037S4E6" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037S4EZ" = "1" /* Dilation of Right Temporal Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037S4F6" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037S4FZ" = "1" /* Dilation of Right Temporal Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037S4G6" = "1" /* Dilation of Right Temporal Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037S4GZ" = "1" /* Dilation of Right Temporal Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037S4Z6" = "1" /* Dilation of Right Temporal Artery, Bifurcation, Percutaneous Endoscopic Approach */
"037S4ZZ" = "1" /* Dilation of Right Temporal Artery, Percutaneous Endoscopic Approach */
"037T046" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037T04Z" = "1" /* Dilation of Left Temporal Artery with Drug-eluting Intraluminal Device, Open Approach */
"037T056" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037T05Z" = "1" /* Dilation of Left Temporal Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"037T066" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037T06Z" = "1" /* Dilation of Left Temporal Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"037T076" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037T07Z" = "1" /* Dilation of Left Temporal Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037T0D6" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Intraluminal Device, Open Approach */
"037T0DZ" = "1" /* Dilation of Left Temporal Artery with Intraluminal Device, Open Approach */
"037T0E6" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"037T0EZ" = "1" /* Dilation of Left Temporal Artery with Two Intraluminal Devices, Open Approach */
"037T0F6" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"037T0FZ" = "1" /* Dilation of Left Temporal Artery with Three Intraluminal Devices, Open Approach */
"037T0G6" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"037T0GZ" = "1" /* Dilation of Left Temporal Artery with Four or More Intraluminal Devices, Open Approach */
"037T0Z6" = "1" /* Dilation of Left Temporal Artery, Bifurcation, Open Approach */
"037T0ZZ" = "1" /* Dilation of Left Temporal Artery, Open Approach */
"037T346" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037T34Z" = "1" /* Dilation of Left Temporal Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037T356" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037T35Z" = "1" /* Dilation of Left Temporal Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037T366" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037T36Z" = "1" /* Dilation of Left Temporal Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037T376" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037T37Z" = "1" /* Dilation of Left Temporal Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037T3D6" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"037T3DZ" = "1" /* Dilation of Left Temporal Artery with Intraluminal Device, Percutaneous Approach */
"037T3E6" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"037T3EZ" = "1" /* Dilation of Left Temporal Artery with Two Intraluminal Devices, Percutaneous Approach */
"037T3F6" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"037T3FZ" = "1" /* Dilation of Left Temporal Artery with Three Intraluminal Devices, Percutaneous Approach */
"037T3G6" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"037T3GZ" = "1" /* Dilation of Left Temporal Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"037T3Z6" = "1" /* Dilation of Left Temporal Artery, Bifurcation, Percutaneous Approach */
"037T3ZZ" = "1" /* Dilation of Left Temporal Artery, Percutaneous Approach */
"037T446" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037T44Z" = "1" /* Dilation of Left Temporal Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037T456" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037T45Z" = "1" /* Dilation of Left Temporal Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037T466" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037T46Z" = "1" /* Dilation of Left Temporal Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037T476" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037T47Z" = "1" /* Dilation of Left Temporal Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037T4D6" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"037T4DZ" = "1" /* Dilation of Left Temporal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"037T4E6" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037T4EZ" = "1" /* Dilation of Left Temporal Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037T4F6" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037T4FZ" = "1" /* Dilation of Left Temporal Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037T4G6" = "1" /* Dilation of Left Temporal Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037T4GZ" = "1" /* Dilation of Left Temporal Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037T4Z6" = "1" /* Dilation of Left Temporal Artery, Bifurcation, Percutaneous Endoscopic Approach */
"037T4ZZ" = "1" /* Dilation of Left Temporal Artery, Percutaneous Endoscopic Approach */
"037U046" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037U04Z" = "1" /* Dilation of Right Thyroid Artery with Drug-eluting Intraluminal Device, Open Approach */
"037U056" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037U05Z" = "1" /* Dilation of Right Thyroid Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"037U066" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037U06Z" = "1" /* Dilation of Right Thyroid Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"037U076" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037U07Z" = "1" /* Dilation of Right Thyroid Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037U0D6" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Intraluminal Device, Open Approach */
"037U0DZ" = "1" /* Dilation of Right Thyroid Artery with Intraluminal Device, Open Approach */
"037U0E6" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"037U0EZ" = "1" /* Dilation of Right Thyroid Artery with Two Intraluminal Devices, Open Approach */
"037U0F6" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"037U0FZ" = "1" /* Dilation of Right Thyroid Artery with Three Intraluminal Devices, Open Approach */
"037U0G6" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"037U0GZ" = "1" /* Dilation of Right Thyroid Artery with Four or More Intraluminal Devices, Open Approach */
"037U0Z6" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, Open Approach */
"037U0ZZ" = "1" /* Dilation of Right Thyroid Artery, Open Approach */
"037U346" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037U34Z" = "1" /* Dilation of Right Thyroid Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037U356" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037U35Z" = "1" /* Dilation of Right Thyroid Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037U366" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037U36Z" = "1" /* Dilation of Right Thyroid Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037U376" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037U37Z" = "1" /* Dilation of Right Thyroid Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037U3D6" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"037U3DZ" = "1" /* Dilation of Right Thyroid Artery with Intraluminal Device, Percutaneous Approach */
"037U3E6" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"037U3EZ" = "1" /* Dilation of Right Thyroid Artery with Two Intraluminal Devices, Percutaneous Approach */
"037U3F6" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"037U3FZ" = "1" /* Dilation of Right Thyroid Artery with Three Intraluminal Devices, Percutaneous Approach */
"037U3G6" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"037U3GZ" = "1" /* Dilation of Right Thyroid Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"037U3Z6" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, Percutaneous Approach */
"037U3ZZ" = "1" /* Dilation of Right Thyroid Artery, Percutaneous Approach */
"037U446" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037U44Z" = "1" /* Dilation of Right Thyroid Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037U456" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037U45Z" = "1" /* Dilation of Right Thyroid Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037U466" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037U46Z" = "1" /* Dilation of Right Thyroid Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037U476" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037U47Z" = "1" /* Dilation of Right Thyroid Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037U4D6" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"037U4DZ" = "1" /* Dilation of Right Thyroid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"037U4E6" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037U4EZ" = "1" /* Dilation of Right Thyroid Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037U4F6" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037U4FZ" = "1" /* Dilation of Right Thyroid Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037U4G6" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037U4GZ" = "1" /* Dilation of Right Thyroid Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037U4Z6" = "1" /* Dilation of Right Thyroid Artery, Bifurcation, Percutaneous Endoscopic Approach */
"037U4ZZ" = "1" /* Dilation of Right Thyroid Artery, Percutaneous Endoscopic Approach */
"037V046" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037V04Z" = "1" /* Dilation of Left Thyroid Artery with Drug-eluting Intraluminal Device, Open Approach */
"037V056" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037V05Z" = "1" /* Dilation of Left Thyroid Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"037V066" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037V06Z" = "1" /* Dilation of Left Thyroid Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"037V076" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037V07Z" = "1" /* Dilation of Left Thyroid Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037V0D6" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Intraluminal Device, Open Approach */
"037V0DZ" = "1" /* Dilation of Left Thyroid Artery with Intraluminal Device, Open Approach */
"037V0E6" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"037V0EZ" = "1" /* Dilation of Left Thyroid Artery with Two Intraluminal Devices, Open Approach */
"037V0F6" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"037V0FZ" = "1" /* Dilation of Left Thyroid Artery with Three Intraluminal Devices, Open Approach */
"037V0G6" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"037V0GZ" = "1" /* Dilation of Left Thyroid Artery with Four or More Intraluminal Devices, Open Approach */
"037V0Z6" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, Open Approach */
"037V0ZZ" = "1" /* Dilation of Left Thyroid Artery, Open Approach */
"037V346" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037V34Z" = "1" /* Dilation of Left Thyroid Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037V356" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037V35Z" = "1" /* Dilation of Left Thyroid Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037V366" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037V36Z" = "1" /* Dilation of Left Thyroid Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037V376" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037V37Z" = "1" /* Dilation of Left Thyroid Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037V3D6" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"037V3DZ" = "1" /* Dilation of Left Thyroid Artery with Intraluminal Device, Percutaneous Approach */
"037V3E6" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"037V3EZ" = "1" /* Dilation of Left Thyroid Artery with Two Intraluminal Devices, Percutaneous Approach */
"037V3F6" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"037V3FZ" = "1" /* Dilation of Left Thyroid Artery with Three Intraluminal Devices, Percutaneous Approach */
"037V3G6" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"037V3GZ" = "1" /* Dilation of Left Thyroid Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"037V3Z6" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, Percutaneous Approach */
"037V3ZZ" = "1" /* Dilation of Left Thyroid Artery, Percutaneous Approach */
"037V446" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037V44Z" = "1" /* Dilation of Left Thyroid Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037V456" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037V45Z" = "1" /* Dilation of Left Thyroid Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037V466" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037V46Z" = "1" /* Dilation of Left Thyroid Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037V476" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037V47Z" = "1" /* Dilation of Left Thyroid Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037V4D6" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"037V4DZ" = "1" /* Dilation of Left Thyroid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"037V4E6" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037V4EZ" = "1" /* Dilation of Left Thyroid Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037V4F6" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037V4FZ" = "1" /* Dilation of Left Thyroid Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037V4G6" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037V4GZ" = "1" /* Dilation of Left Thyroid Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037V4Z6" = "1" /* Dilation of Left Thyroid Artery, Bifurcation, Percutaneous Endoscopic Approach */
"037V4ZZ" = "1" /* Dilation of Left Thyroid Artery, Percutaneous Endoscopic Approach */
"037Y046" = "1" /* Dilation of Upper Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"037Y04Z" = "1" /* Dilation of Upper Artery with Drug-eluting Intraluminal Device, Open Approach */
"037Y056" = "1" /* Dilation of Upper Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"037Y05Z" = "1" /* Dilation of Upper Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"037Y066" = "1" /* Dilation of Upper Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"037Y06Z" = "1" /* Dilation of Upper Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"037Y076" = "1" /* Dilation of Upper Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037Y07Z" = "1" /* Dilation of Upper Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"037Y0D6" = "1" /* Dilation of Upper Artery, Bifurcation, with Intraluminal Device, Open Approach */
"037Y0DZ" = "1" /* Dilation of Upper Artery with Intraluminal Device, Open Approach */
"037Y0E6" = "1" /* Dilation of Upper Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"037Y0EZ" = "1" /* Dilation of Upper Artery with Two Intraluminal Devices, Open Approach */
"037Y0F6" = "1" /* Dilation of Upper Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"037Y0FZ" = "1" /* Dilation of Upper Artery with Three Intraluminal Devices, Open Approach */
"037Y0G6" = "1" /* Dilation of Upper Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"037Y0GZ" = "1" /* Dilation of Upper Artery with Four or More Intraluminal Devices, Open Approach */
"037Y0Z6" = "1" /* Dilation of Upper Artery, Bifurcation, Open Approach */
"037Y0ZZ" = "1" /* Dilation of Upper Artery, Open Approach */
"037Y346" = "1" /* Dilation of Upper Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037Y34Z" = "1" /* Dilation of Upper Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"037Y356" = "1" /* Dilation of Upper Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037Y35Z" = "1" /* Dilation of Upper Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037Y366" = "1" /* Dilation of Upper Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037Y36Z" = "1" /* Dilation of Upper Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037Y376" = "1" /* Dilation of Upper Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037Y37Z" = "1" /* Dilation of Upper Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"037Y3D6" = "1" /* Dilation of Upper Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"037Y3DZ" = "1" /* Dilation of Upper Artery with Intraluminal Device, Percutaneous Approach */
"037Y3E6" = "1" /* Dilation of Upper Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"037Y3EZ" = "1" /* Dilation of Upper Artery with Two Intraluminal Devices, Percutaneous Approach */
"037Y3F6" = "1" /* Dilation of Upper Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"037Y3FZ" = "1" /* Dilation of Upper Artery with Three Intraluminal Devices, Percutaneous Approach */
"037Y3G6" = "1" /* Dilation of Upper Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"037Y3GZ" = "1" /* Dilation of Upper Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"037Y3Z6" = "1" /* Dilation of Upper Artery, Bifurcation, Percutaneous Approach */
"037Y3ZZ" = "1" /* Dilation of Upper Artery, Percutaneous Approach */
"037Y446" = "1" /* Dilation of Upper Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037Y44Z" = "1" /* Dilation of Upper Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"037Y456" = "1" /* Dilation of Upper Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Y45Z" = "1" /* Dilation of Upper Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Y466" = "1" /* Dilation of Upper Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Y46Z" = "1" /* Dilation of Upper Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Y476" = "1" /* Dilation of Upper Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Y47Z" = "1" /* Dilation of Upper Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Y4D6" = "1" /* Dilation of Upper Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"037Y4DZ" = "1" /* Dilation of Upper Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"037Y4E6" = "1" /* Dilation of Upper Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Y4EZ" = "1" /* Dilation of Upper Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Y4F6" = "1" /* Dilation of Upper Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Y4FZ" = "1" /* Dilation of Upper Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Y4G6" = "1" /* Dilation of Upper Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Y4GZ" = "1" /* Dilation of Upper Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"037Y4Z6" = "1" /* Dilation of Upper Artery, Bifurcation, Percutaneous Endoscopic Approach */
"037Y4ZZ" = "1" /* Dilation of Upper Artery, Percutaneous Endoscopic Approach */
"03900ZX" = "1" /* Drainage of Right Internal Mammary Artery, Open Approach, Diagnostic */
"03904ZX" = "1" /* Drainage of Right Internal Mammary Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03910ZX" = "1" /* Drainage of Left Internal Mammary Artery, Open Approach, Diagnostic */
"03914ZX" = "1" /* Drainage of Left Internal Mammary Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03920ZX" = "1" /* Drainage of Innominate Artery, Open Approach, Diagnostic */
"03924ZX" = "1" /* Drainage of Innominate Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03930ZX" = "1" /* Drainage of Right Subclavian Artery, Open Approach, Diagnostic */
"03934ZX" = "1" /* Drainage of Right Subclavian Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03940ZX" = "1" /* Drainage of Left Subclavian Artery, Open Approach, Diagnostic */
"03944ZX" = "1" /* Drainage of Left Subclavian Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03950ZX" = "1" /* Drainage of Right Axillary Artery, Open Approach, Diagnostic */
"03954ZX" = "1" /* Drainage of Right Axillary Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03960ZX" = "1" /* Drainage of Left Axillary Artery, Open Approach, Diagnostic */
"03964ZX" = "1" /* Drainage of Left Axillary Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03970ZX" = "1" /* Drainage of Right Brachial Artery, Open Approach, Diagnostic */
"03974ZX" = "1" /* Drainage of Right Brachial Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03980ZX" = "1" /* Drainage of Left Brachial Artery, Open Approach, Diagnostic */
"03984ZX" = "1" /* Drainage of Left Brachial Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03990ZX" = "1" /* Drainage of Right Ulnar Artery, Open Approach, Diagnostic */
"03994ZX" = "1" /* Drainage of Right Ulnar Artery, Percutaneous Endoscopic Approach, Diagnostic */
"039A0ZX" = "1" /* Drainage of Left Ulnar Artery, Open Approach, Diagnostic */
"039A4ZX" = "1" /* Drainage of Left Ulnar Artery, Percutaneous Endoscopic Approach, Diagnostic */
"039B0ZX" = "1" /* Drainage of Right Radial Artery, Open Approach, Diagnostic */
"039B4ZX" = "1" /* Drainage of Right Radial Artery, Percutaneous Endoscopic Approach, Diagnostic */
"039C0ZX" = "1" /* Drainage of Left Radial Artery, Open Approach, Diagnostic */
"039C4ZX" = "1" /* Drainage of Left Radial Artery, Percutaneous Endoscopic Approach, Diagnostic */
"039D0ZX" = "1" /* Drainage of Right Hand Artery, Open Approach, Diagnostic */
"039D4ZX" = "1" /* Drainage of Right Hand Artery, Percutaneous Endoscopic Approach, Diagnostic */
"039F0ZX" = "1" /* Drainage of Left Hand Artery, Open Approach, Diagnostic */
"039F4ZX" = "1" /* Drainage of Left Hand Artery, Percutaneous Endoscopic Approach, Diagnostic */
"039G0ZX" = "1" /* Drainage of Intracranial Artery, Open Approach, Diagnostic */
"039G4ZX" = "1" /* Drainage of Intracranial Artery, Percutaneous Endoscopic Approach, Diagnostic */
"039H0ZX" = "1" /* Drainage of Right Common Carotid Artery, Open Approach, Diagnostic */
"039H4ZX" = "1" /* Drainage of Right Common Carotid Artery, Percutaneous Endoscopic Approach, Diagnostic */
"039J0ZX" = "1" /* Drainage of Left Common Carotid Artery, Open Approach, Diagnostic */
"039J4ZX" = "1" /* Drainage of Left Common Carotid Artery, Percutaneous Endoscopic Approach, Diagnostic */
"039K0ZX" = "1" /* Drainage of Right Internal Carotid Artery, Open Approach, Diagnostic */
"039K4ZX" = "1" /* Drainage of Right Internal Carotid Artery, Percutaneous Endoscopic Approach, Diagnostic */
"039L0ZX" = "1" /* Drainage of Left Internal Carotid Artery, Open Approach, Diagnostic */
"039L4ZX" = "1" /* Drainage of Left Internal Carotid Artery, Percutaneous Endoscopic Approach, Diagnostic */
"039M0ZX" = "1" /* Drainage of Right External Carotid Artery, Open Approach, Diagnostic */
"039M4ZX" = "1" /* Drainage of Right External Carotid Artery, Percutaneous Endoscopic Approach, Diagnostic */
"039N0ZX" = "1" /* Drainage of Left External Carotid Artery, Open Approach, Diagnostic */
"039N4ZX" = "1" /* Drainage of Left External Carotid Artery, Percutaneous Endoscopic Approach, Diagnostic */
"039P0ZX" = "1" /* Drainage of Right Vertebral Artery, Open Approach, Diagnostic */
"039P4ZX" = "1" /* Drainage of Right Vertebral Artery, Percutaneous Endoscopic Approach, Diagnostic */
"039Q0ZX" = "1" /* Drainage of Left Vertebral Artery, Open Approach, Diagnostic */
"039Q4ZX" = "1" /* Drainage of Left Vertebral Artery, Percutaneous Endoscopic Approach, Diagnostic */
"039R0ZX" = "1" /* Drainage of Face Artery, Open Approach, Diagnostic */
"039R4ZX" = "1" /* Drainage of Face Artery, Percutaneous Endoscopic Approach, Diagnostic */
"039S0ZX" = "1" /* Drainage of Right Temporal Artery, Open Approach, Diagnostic */
"039S4ZX" = "1" /* Drainage of Right Temporal Artery, Percutaneous Endoscopic Approach, Diagnostic */
"039T0ZX" = "1" /* Drainage of Left Temporal Artery, Open Approach, Diagnostic */
"039T4ZX" = "1" /* Drainage of Left Temporal Artery, Percutaneous Endoscopic Approach, Diagnostic */
"039U0ZX" = "1" /* Drainage of Right Thyroid Artery, Open Approach, Diagnostic */
"039U4ZX" = "1" /* Drainage of Right Thyroid Artery, Percutaneous Endoscopic Approach, Diagnostic */
"039V0ZX" = "1" /* Drainage of Left Thyroid Artery, Open Approach, Diagnostic */
"039V4ZX" = "1" /* Drainage of Left Thyroid Artery, Percutaneous Endoscopic Approach, Diagnostic */
"039Y0ZX" = "1" /* Drainage of Upper Artery, Open Approach, Diagnostic */
"039Y4ZX" = "1" /* Drainage of Upper Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03B00ZX" = "1" /* Excision of Right Internal Mammary Artery, Open Approach, Diagnostic */
"03B00ZZ" = "1" /* Excision of Right Internal Mammary Artery, Open Approach */
"03B03ZX" = "1" /* Excision of Right Internal Mammary Artery, Percutaneous Approach, Diagnostic */
"03B03ZZ" = "1" /* Excision of Right Internal Mammary Artery, Percutaneous Approach */
"03B04ZX" = "1" /* Excision of Right Internal Mammary Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03B04ZZ" = "1" /* Excision of Right Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03B10ZX" = "1" /* Excision of Left Internal Mammary Artery, Open Approach, Diagnostic */
"03B10ZZ" = "1" /* Excision of Left Internal Mammary Artery, Open Approach */
"03B13ZX" = "1" /* Excision of Left Internal Mammary Artery, Percutaneous Approach, Diagnostic */
"03B13ZZ" = "1" /* Excision of Left Internal Mammary Artery, Percutaneous Approach */
"03B14ZX" = "1" /* Excision of Left Internal Mammary Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03B14ZZ" = "1" /* Excision of Left Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03B20ZX" = "1" /* Excision of Innominate Artery, Open Approach, Diagnostic */
"03B20ZZ" = "1" /* Excision of Innominate Artery, Open Approach */
"03B23ZX" = "1" /* Excision of Innominate Artery, Percutaneous Approach, Diagnostic */
"03B23ZZ" = "1" /* Excision of Innominate Artery, Percutaneous Approach */
"03B24ZX" = "1" /* Excision of Innominate Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03B24ZZ" = "1" /* Excision of Innominate Artery, Percutaneous Endoscopic Approach */
"03B30ZX" = "1" /* Excision of Right Subclavian Artery, Open Approach, Diagnostic */
"03B30ZZ" = "1" /* Excision of Right Subclavian Artery, Open Approach */
"03B33ZX" = "1" /* Excision of Right Subclavian Artery, Percutaneous Approach, Diagnostic */
"03B33ZZ" = "1" /* Excision of Right Subclavian Artery, Percutaneous Approach */
"03B34ZX" = "1" /* Excision of Right Subclavian Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03B34ZZ" = "1" /* Excision of Right Subclavian Artery, Percutaneous Endoscopic Approach */
"03B40ZX" = "1" /* Excision of Left Subclavian Artery, Open Approach, Diagnostic */
"03B40ZZ" = "1" /* Excision of Left Subclavian Artery, Open Approach */
"03B43ZX" = "1" /* Excision of Left Subclavian Artery, Percutaneous Approach, Diagnostic */
"03B43ZZ" = "1" /* Excision of Left Subclavian Artery, Percutaneous Approach */
"03B44ZX" = "1" /* Excision of Left Subclavian Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03B44ZZ" = "1" /* Excision of Left Subclavian Artery, Percutaneous Endoscopic Approach */
"03B50ZX" = "1" /* Excision of Right Axillary Artery, Open Approach, Diagnostic */
"03B50ZZ" = "1" /* Excision of Right Axillary Artery, Open Approach */
"03B53ZX" = "1" /* Excision of Right Axillary Artery, Percutaneous Approach, Diagnostic */
"03B53ZZ" = "1" /* Excision of Right Axillary Artery, Percutaneous Approach */
"03B54ZX" = "1" /* Excision of Right Axillary Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03B54ZZ" = "1" /* Excision of Right Axillary Artery, Percutaneous Endoscopic Approach */
"03B60ZX" = "1" /* Excision of Left Axillary Artery, Open Approach, Diagnostic */
"03B60ZZ" = "1" /* Excision of Left Axillary Artery, Open Approach */
"03B63ZX" = "1" /* Excision of Left Axillary Artery, Percutaneous Approach, Diagnostic */
"03B63ZZ" = "1" /* Excision of Left Axillary Artery, Percutaneous Approach */
"03B64ZX" = "1" /* Excision of Left Axillary Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03B64ZZ" = "1" /* Excision of Left Axillary Artery, Percutaneous Endoscopic Approach */
"03B70ZX" = "1" /* Excision of Right Brachial Artery, Open Approach, Diagnostic */
"03B70ZZ" = "1" /* Excision of Right Brachial Artery, Open Approach */
"03B73ZX" = "1" /* Excision of Right Brachial Artery, Percutaneous Approach, Diagnostic */
"03B73ZZ" = "1" /* Excision of Right Brachial Artery, Percutaneous Approach */
"03B74ZX" = "1" /* Excision of Right Brachial Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03B74ZZ" = "1" /* Excision of Right Brachial Artery, Percutaneous Endoscopic Approach */
"03B80ZX" = "1" /* Excision of Left Brachial Artery, Open Approach, Diagnostic */
"03B80ZZ" = "1" /* Excision of Left Brachial Artery, Open Approach */
"03B83ZX" = "1" /* Excision of Left Brachial Artery, Percutaneous Approach, Diagnostic */
"03B83ZZ" = "1" /* Excision of Left Brachial Artery, Percutaneous Approach */
"03B84ZX" = "1" /* Excision of Left Brachial Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03B84ZZ" = "1" /* Excision of Left Brachial Artery, Percutaneous Endoscopic Approach */
"03B90ZX" = "1" /* Excision of Right Ulnar Artery, Open Approach, Diagnostic */
"03B90ZZ" = "1" /* Excision of Right Ulnar Artery, Open Approach */
"03B93ZX" = "1" /* Excision of Right Ulnar Artery, Percutaneous Approach, Diagnostic */
"03B93ZZ" = "1" /* Excision of Right Ulnar Artery, Percutaneous Approach */
"03B94ZX" = "1" /* Excision of Right Ulnar Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03B94ZZ" = "1" /* Excision of Right Ulnar Artery, Percutaneous Endoscopic Approach */
"03BA0ZX" = "1" /* Excision of Left Ulnar Artery, Open Approach, Diagnostic */
"03BA0ZZ" = "1" /* Excision of Left Ulnar Artery, Open Approach */
"03BA3ZX" = "1" /* Excision of Left Ulnar Artery, Percutaneous Approach, Diagnostic */
"03BA3ZZ" = "1" /* Excision of Left Ulnar Artery, Percutaneous Approach */
"03BA4ZX" = "1" /* Excision of Left Ulnar Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03BA4ZZ" = "1" /* Excision of Left Ulnar Artery, Percutaneous Endoscopic Approach */
"03BB0ZX" = "1" /* Excision of Right Radial Artery, Open Approach, Diagnostic */
"03BB0ZZ" = "1" /* Excision of Right Radial Artery, Open Approach */
"03BB3ZX" = "1" /* Excision of Right Radial Artery, Percutaneous Approach, Diagnostic */
"03BB3ZZ" = "1" /* Excision of Right Radial Artery, Percutaneous Approach */
"03BB4ZX" = "1" /* Excision of Right Radial Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03BB4ZZ" = "1" /* Excision of Right Radial Artery, Percutaneous Endoscopic Approach */
"03BC0ZX" = "1" /* Excision of Left Radial Artery, Open Approach, Diagnostic */
"03BC0ZZ" = "1" /* Excision of Left Radial Artery, Open Approach */
"03BC3ZX" = "1" /* Excision of Left Radial Artery, Percutaneous Approach, Diagnostic */
"03BC3ZZ" = "1" /* Excision of Left Radial Artery, Percutaneous Approach */
"03BC4ZX" = "1" /* Excision of Left Radial Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03BC4ZZ" = "1" /* Excision of Left Radial Artery, Percutaneous Endoscopic Approach */
"03BD0ZX" = "1" /* Excision of Right Hand Artery, Open Approach, Diagnostic */
"03BD0ZZ" = "1" /* Excision of Right Hand Artery, Open Approach */
"03BD3ZX" = "1" /* Excision of Right Hand Artery, Percutaneous Approach, Diagnostic */
"03BD3ZZ" = "1" /* Excision of Right Hand Artery, Percutaneous Approach */
"03BD4ZX" = "1" /* Excision of Right Hand Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03BD4ZZ" = "1" /* Excision of Right Hand Artery, Percutaneous Endoscopic Approach */
"03BF0ZX" = "1" /* Excision of Left Hand Artery, Open Approach, Diagnostic */
"03BF0ZZ" = "1" /* Excision of Left Hand Artery, Open Approach */
"03BF3ZX" = "1" /* Excision of Left Hand Artery, Percutaneous Approach, Diagnostic */
"03BF3ZZ" = "1" /* Excision of Left Hand Artery, Percutaneous Approach */
"03BF4ZX" = "1" /* Excision of Left Hand Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03BF4ZZ" = "1" /* Excision of Left Hand Artery, Percutaneous Endoscopic Approach */
"03BG0ZX" = "1" /* Excision of Intracranial Artery, Open Approach, Diagnostic */
"03BG0ZZ" = "1" /* Excision of Intracranial Artery, Open Approach */
"03BG3ZX" = "1" /* Excision of Intracranial Artery, Percutaneous Approach, Diagnostic */
"03BG3ZZ" = "1" /* Excision of Intracranial Artery, Percutaneous Approach */
"03BG4ZX" = "1" /* Excision of Intracranial Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03BG4ZZ" = "1" /* Excision of Intracranial Artery, Percutaneous Endoscopic Approach */
"03BH0ZX" = "1" /* Excision of Right Common Carotid Artery, Open Approach, Diagnostic */
"03BH0ZZ" = "1" /* Excision of Right Common Carotid Artery, Open Approach */
"03BH3ZX" = "1" /* Excision of Right Common Carotid Artery, Percutaneous Approach, Diagnostic */
"03BH3ZZ" = "1" /* Excision of Right Common Carotid Artery, Percutaneous Approach */
"03BH4ZX" = "1" /* Excision of Right Common Carotid Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03BH4ZZ" = "1" /* Excision of Right Common Carotid Artery, Percutaneous Endoscopic Approach */
"03BJ0ZX" = "1" /* Excision of Left Common Carotid Artery, Open Approach, Diagnostic */
"03BJ0ZZ" = "1" /* Excision of Left Common Carotid Artery, Open Approach */
"03BJ3ZX" = "1" /* Excision of Left Common Carotid Artery, Percutaneous Approach, Diagnostic */
"03BJ3ZZ" = "1" /* Excision of Left Common Carotid Artery, Percutaneous Approach */
"03BJ4ZX" = "1" /* Excision of Left Common Carotid Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03BJ4ZZ" = "1" /* Excision of Left Common Carotid Artery, Percutaneous Endoscopic Approach */
"03BK0ZX" = "1" /* Excision of Right Internal Carotid Artery, Open Approach, Diagnostic */
"03BK0ZZ" = "1" /* Excision of Right Internal Carotid Artery, Open Approach */
"03BK3ZX" = "1" /* Excision of Right Internal Carotid Artery, Percutaneous Approach, Diagnostic */
"03BK3ZZ" = "1" /* Excision of Right Internal Carotid Artery, Percutaneous Approach */
"03BK4ZX" = "1" /* Excision of Right Internal Carotid Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03BK4ZZ" = "1" /* Excision of Right Internal Carotid Artery, Percutaneous Endoscopic Approach */
"03BL0ZX" = "1" /* Excision of Left Internal Carotid Artery, Open Approach, Diagnostic */
"03BL0ZZ" = "1" /* Excision of Left Internal Carotid Artery, Open Approach */
"03BL3ZX" = "1" /* Excision of Left Internal Carotid Artery, Percutaneous Approach, Diagnostic */
"03BL3ZZ" = "1" /* Excision of Left Internal Carotid Artery, Percutaneous Approach */
"03BL4ZX" = "1" /* Excision of Left Internal Carotid Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03BL4ZZ" = "1" /* Excision of Left Internal Carotid Artery, Percutaneous Endoscopic Approach */
"03BM0ZX" = "1" /* Excision of Right External Carotid Artery, Open Approach, Diagnostic */
"03BM0ZZ" = "1" /* Excision of Right External Carotid Artery, Open Approach */
"03BM3ZX" = "1" /* Excision of Right External Carotid Artery, Percutaneous Approach, Diagnostic */
"03BM3ZZ" = "1" /* Excision of Right External Carotid Artery, Percutaneous Approach */
"03BM4ZX" = "1" /* Excision of Right External Carotid Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03BM4ZZ" = "1" /* Excision of Right External Carotid Artery, Percutaneous Endoscopic Approach */
"03BN0ZX" = "1" /* Excision of Left External Carotid Artery, Open Approach, Diagnostic */
"03BN0ZZ" = "1" /* Excision of Left External Carotid Artery, Open Approach */
"03BN3ZX" = "1" /* Excision of Left External Carotid Artery, Percutaneous Approach, Diagnostic */
"03BN3ZZ" = "1" /* Excision of Left External Carotid Artery, Percutaneous Approach */
"03BN4ZX" = "1" /* Excision of Left External Carotid Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03BN4ZZ" = "1" /* Excision of Left External Carotid Artery, Percutaneous Endoscopic Approach */
"03BP0ZX" = "1" /* Excision of Right Vertebral Artery, Open Approach, Diagnostic */
"03BP0ZZ" = "1" /* Excision of Right Vertebral Artery, Open Approach */
"03BP3ZX" = "1" /* Excision of Right Vertebral Artery, Percutaneous Approach, Diagnostic */
"03BP3ZZ" = "1" /* Excision of Right Vertebral Artery, Percutaneous Approach */
"03BP4ZX" = "1" /* Excision of Right Vertebral Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03BP4ZZ" = "1" /* Excision of Right Vertebral Artery, Percutaneous Endoscopic Approach */
"03BQ0ZX" = "1" /* Excision of Left Vertebral Artery, Open Approach, Diagnostic */
"03BQ0ZZ" = "1" /* Excision of Left Vertebral Artery, Open Approach */
"03BQ3ZX" = "1" /* Excision of Left Vertebral Artery, Percutaneous Approach, Diagnostic */
"03BQ3ZZ" = "1" /* Excision of Left Vertebral Artery, Percutaneous Approach */
"03BQ4ZX" = "1" /* Excision of Left Vertebral Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03BQ4ZZ" = "1" /* Excision of Left Vertebral Artery, Percutaneous Endoscopic Approach */
"03BR0ZX" = "1" /* Excision of Face Artery, Open Approach, Diagnostic */
"03BR0ZZ" = "1" /* Excision of Face Artery, Open Approach */
"03BR3ZX" = "1" /* Excision of Face Artery, Percutaneous Approach, Diagnostic */
"03BR3ZZ" = "1" /* Excision of Face Artery, Percutaneous Approach */
"03BR4ZX" = "1" /* Excision of Face Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03BR4ZZ" = "1" /* Excision of Face Artery, Percutaneous Endoscopic Approach */
"03BS0ZX" = "1" /* Excision of Right Temporal Artery, Open Approach, Diagnostic */
"03BS0ZZ" = "1" /* Excision of Right Temporal Artery, Open Approach */
"03BS3ZX" = "1" /* Excision of Right Temporal Artery, Percutaneous Approach, Diagnostic */
"03BS3ZZ" = "1" /* Excision of Right Temporal Artery, Percutaneous Approach */
"03BS4ZX" = "1" /* Excision of Right Temporal Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03BS4ZZ" = "1" /* Excision of Right Temporal Artery, Percutaneous Endoscopic Approach */
"03BT0ZX" = "1" /* Excision of Left Temporal Artery, Open Approach, Diagnostic */
"03BT0ZZ" = "1" /* Excision of Left Temporal Artery, Open Approach */
"03BT3ZX" = "1" /* Excision of Left Temporal Artery, Percutaneous Approach, Diagnostic */
"03BT3ZZ" = "1" /* Excision of Left Temporal Artery, Percutaneous Approach */
"03BT4ZX" = "1" /* Excision of Left Temporal Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03BT4ZZ" = "1" /* Excision of Left Temporal Artery, Percutaneous Endoscopic Approach */
"03BU0ZX" = "1" /* Excision of Right Thyroid Artery, Open Approach, Diagnostic */
"03BU0ZZ" = "1" /* Excision of Right Thyroid Artery, Open Approach */
"03BU3ZX" = "1" /* Excision of Right Thyroid Artery, Percutaneous Approach, Diagnostic */
"03BU3ZZ" = "1" /* Excision of Right Thyroid Artery, Percutaneous Approach */
"03BU4ZX" = "1" /* Excision of Right Thyroid Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03BU4ZZ" = "1" /* Excision of Right Thyroid Artery, Percutaneous Endoscopic Approach */
"03BV0ZX" = "1" /* Excision of Left Thyroid Artery, Open Approach, Diagnostic */
"03BV0ZZ" = "1" /* Excision of Left Thyroid Artery, Open Approach */
"03BV3ZX" = "1" /* Excision of Left Thyroid Artery, Percutaneous Approach, Diagnostic */
"03BV3ZZ" = "1" /* Excision of Left Thyroid Artery, Percutaneous Approach */
"03BV4ZX" = "1" /* Excision of Left Thyroid Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03BV4ZZ" = "1" /* Excision of Left Thyroid Artery, Percutaneous Endoscopic Approach */
"03BY0ZX" = "1" /* Excision of Upper Artery, Open Approach, Diagnostic */
"03BY0ZZ" = "1" /* Excision of Upper Artery, Open Approach */
"03BY3ZX" = "1" /* Excision of Upper Artery, Percutaneous Approach, Diagnostic */
"03BY3ZZ" = "1" /* Excision of Upper Artery, Percutaneous Approach */
"03BY4ZX" = "1" /* Excision of Upper Artery, Percutaneous Endoscopic Approach, Diagnostic */
"03BY4ZZ" = "1" /* Excision of Upper Artery, Percutaneous Endoscopic Approach */
"03C00Z6" = "1" /* Extirpation of Matter from Right Internal Mammary Artery, Bifurcation, Open Approach */
"03C00ZZ" = "1" /* Extirpation of Matter from Right Internal Mammary Artery, Open Approach */
"03C03Z6" = "1" /* Extirpation of Matter from Right Internal Mammary Artery, Bifurcation, Percutaneous Approach */
"03C03ZZ" = "1" /* Extirpation of Matter from Right Internal Mammary Artery, Percutaneous Approach */
"03C04Z6" = "1" /* Extirpation of Matter from Right Internal Mammary Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03C04ZZ" = "1" /* Extirpation of Matter from Right Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03C10Z6" = "1" /* Extirpation of Matter from Left Internal Mammary Artery, Bifurcation, Open Approach */
"03C10ZZ" = "1" /* Extirpation of Matter from Left Internal Mammary Artery, Open Approach */
"03C13Z6" = "1" /* Extirpation of Matter from Left Internal Mammary Artery, Bifurcation, Percutaneous Approach */
"03C13ZZ" = "1" /* Extirpation of Matter from Left Internal Mammary Artery, Percutaneous Approach */
"03C14Z6" = "1" /* Extirpation of Matter from Left Internal Mammary Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03C14ZZ" = "1" /* Extirpation of Matter from Left Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03C20Z6" = "1" /* Extirpation of Matter from Innominate Artery, Bifurcation, Open Approach */
"03C20ZZ" = "1" /* Extirpation of Matter from Innominate Artery, Open Approach */
"03C23Z6" = "1" /* Extirpation of Matter from Innominate Artery, Bifurcation, Percutaneous Approach */
"03C23ZZ" = "1" /* Extirpation of Matter from Innominate Artery, Percutaneous Approach */
"03C24Z6" = "1" /* Extirpation of Matter from Innominate Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03C24ZZ" = "1" /* Extirpation of Matter from Innominate Artery, Percutaneous Endoscopic Approach */
"03C30Z6" = "1" /* Extirpation of Matter from Right Subclavian Artery, Bifurcation, Open Approach */
"03C30ZZ" = "1" /* Extirpation of Matter from Right Subclavian Artery, Open Approach */
"03C33Z6" = "1" /* Extirpation of Matter from Right Subclavian Artery, Bifurcation, Percutaneous Approach */
"03C33ZZ" = "1" /* Extirpation of Matter from Right Subclavian Artery, Percutaneous Approach */
"03C34Z6" = "1" /* Extirpation of Matter from Right Subclavian Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03C34ZZ" = "1" /* Extirpation of Matter from Right Subclavian Artery, Percutaneous Endoscopic Approach */
"03C40Z6" = "1" /* Extirpation of Matter from Left Subclavian Artery, Bifurcation, Open Approach */
"03C40ZZ" = "1" /* Extirpation of Matter from Left Subclavian Artery, Open Approach */
"03C43Z6" = "1" /* Extirpation of Matter from Left Subclavian Artery, Bifurcation, Percutaneous Approach */
"03C43ZZ" = "1" /* Extirpation of Matter from Left Subclavian Artery, Percutaneous Approach */
"03C44Z6" = "1" /* Extirpation of Matter from Left Subclavian Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03C44ZZ" = "1" /* Extirpation of Matter from Left Subclavian Artery, Percutaneous Endoscopic Approach */
"03C50Z6" = "1" /* Extirpation of Matter from Right Axillary Artery, Bifurcation, Open Approach */
"03C50ZZ" = "1" /* Extirpation of Matter from Right Axillary Artery, Open Approach */
"03C53Z6" = "1" /* Extirpation of Matter from Right Axillary Artery, Bifurcation, Percutaneous Approach */
"03C53ZZ" = "1" /* Extirpation of Matter from Right Axillary Artery, Percutaneous Approach */
"03C54Z6" = "1" /* Extirpation of Matter from Right Axillary Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03C54ZZ" = "1" /* Extirpation of Matter from Right Axillary Artery, Percutaneous Endoscopic Approach */
"03C60Z6" = "1" /* Extirpation of Matter from Left Axillary Artery, Bifurcation, Open Approach */
"03C60ZZ" = "1" /* Extirpation of Matter from Left Axillary Artery, Open Approach */
"03C63Z6" = "1" /* Extirpation of Matter from Left Axillary Artery, Bifurcation, Percutaneous Approach */
"03C63ZZ" = "1" /* Extirpation of Matter from Left Axillary Artery, Percutaneous Approach */
"03C64Z6" = "1" /* Extirpation of Matter from Left Axillary Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03C64ZZ" = "1" /* Extirpation of Matter from Left Axillary Artery, Percutaneous Endoscopic Approach */
"03C70Z6" = "1" /* Extirpation of Matter from Right Brachial Artery, Bifurcation, Open Approach */
"03C70ZZ" = "1" /* Extirpation of Matter from Right Brachial Artery, Open Approach */
"03C73Z6" = "1" /* Extirpation of Matter from Right Brachial Artery, Bifurcation, Percutaneous Approach */
"03C73ZZ" = "1" /* Extirpation of Matter from Right Brachial Artery, Percutaneous Approach */
"03C74Z6" = "1" /* Extirpation of Matter from Right Brachial Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03C74ZZ" = "1" /* Extirpation of Matter from Right Brachial Artery, Percutaneous Endoscopic Approach */
"03C80Z6" = "1" /* Extirpation of Matter from Left Brachial Artery, Bifurcation, Open Approach */
"03C80ZZ" = "1" /* Extirpation of Matter from Left Brachial Artery, Open Approach */
"03C83Z6" = "1" /* Extirpation of Matter from Left Brachial Artery, Bifurcation, Percutaneous Approach */
"03C83ZZ" = "1" /* Extirpation of Matter from Left Brachial Artery, Percutaneous Approach */
"03C84Z6" = "1" /* Extirpation of Matter from Left Brachial Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03C84ZZ" = "1" /* Extirpation of Matter from Left Brachial Artery, Percutaneous Endoscopic Approach */
"03C90Z6" = "1" /* Extirpation of Matter from Right Ulnar Artery, Bifurcation, Open Approach */
"03C90ZZ" = "1" /* Extirpation of Matter from Right Ulnar Artery, Open Approach */
"03C93Z6" = "1" /* Extirpation of Matter from Right Ulnar Artery, Bifurcation, Percutaneous Approach */
"03C93ZZ" = "1" /* Extirpation of Matter from Right Ulnar Artery, Percutaneous Approach */
"03C94Z6" = "1" /* Extirpation of Matter from Right Ulnar Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03C94ZZ" = "1" /* Extirpation of Matter from Right Ulnar Artery, Percutaneous Endoscopic Approach */
"03CA0Z6" = "1" /* Extirpation of Matter from Left Ulnar Artery, Bifurcation, Open Approach */
"03CA0ZZ" = "1" /* Extirpation of Matter from Left Ulnar Artery, Open Approach */
"03CA3Z6" = "1" /* Extirpation of Matter from Left Ulnar Artery, Bifurcation, Percutaneous Approach */
"03CA3ZZ" = "1" /* Extirpation of Matter from Left Ulnar Artery, Percutaneous Approach */
"03CA4Z6" = "1" /* Extirpation of Matter from Left Ulnar Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03CA4ZZ" = "1" /* Extirpation of Matter from Left Ulnar Artery, Percutaneous Endoscopic Approach */
"03CB0Z6" = "1" /* Extirpation of Matter from Right Radial Artery, Bifurcation, Open Approach */
"03CB0ZZ" = "1" /* Extirpation of Matter from Right Radial Artery, Open Approach */
"03CB3Z6" = "1" /* Extirpation of Matter from Right Radial Artery, Bifurcation, Percutaneous Approach */
"03CB3ZZ" = "1" /* Extirpation of Matter from Right Radial Artery, Percutaneous Approach */
"03CB4Z6" = "1" /* Extirpation of Matter from Right Radial Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03CB4ZZ" = "1" /* Extirpation of Matter from Right Radial Artery, Percutaneous Endoscopic Approach */
"03CC0Z6" = "1" /* Extirpation of Matter from Left Radial Artery, Bifurcation, Open Approach */
"03CC0ZZ" = "1" /* Extirpation of Matter from Left Radial Artery, Open Approach */
"03CC3Z6" = "1" /* Extirpation of Matter from Left Radial Artery, Bifurcation, Percutaneous Approach */
"03CC3ZZ" = "1" /* Extirpation of Matter from Left Radial Artery, Percutaneous Approach */
"03CC4Z6" = "1" /* Extirpation of Matter from Left Radial Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03CC4ZZ" = "1" /* Extirpation of Matter from Left Radial Artery, Percutaneous Endoscopic Approach */
"03CD0Z6" = "1" /* Extirpation of Matter from Right Hand Artery, Bifurcation, Open Approach */
"03CD0ZZ" = "1" /* Extirpation of Matter from Right Hand Artery, Open Approach */
"03CD3Z6" = "1" /* Extirpation of Matter from Right Hand Artery, Bifurcation, Percutaneous Approach */
"03CD3ZZ" = "1" /* Extirpation of Matter from Right Hand Artery, Percutaneous Approach */
"03CD4Z6" = "1" /* Extirpation of Matter from Right Hand Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03CD4ZZ" = "1" /* Extirpation of Matter from Right Hand Artery, Percutaneous Endoscopic Approach */
"03CF0Z6" = "1" /* Extirpation of Matter from Left Hand Artery, Bifurcation, Open Approach */
"03CF0ZZ" = "1" /* Extirpation of Matter from Left Hand Artery, Open Approach */
"03CF3Z6" = "1" /* Extirpation of Matter from Left Hand Artery, Bifurcation, Percutaneous Approach */
"03CF3ZZ" = "1" /* Extirpation of Matter from Left Hand Artery, Percutaneous Approach */
"03CF4Z6" = "1" /* Extirpation of Matter from Left Hand Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03CF4ZZ" = "1" /* Extirpation of Matter from Left Hand Artery, Percutaneous Endoscopic Approach */
"03CG0Z6" = "1" /* Extirpation of Matter from Intracranial Artery, Bifurcation, Open Approach */
"03CG0ZZ" = "1" /* Extirpation of Matter from Intracranial Artery, Open Approach */
"03CG3Z6" = "1" /* Extirpation of Matter from Intracranial Artery, Bifurcation, Percutaneous Approach */
"03CG3ZZ" = "1" /* Extirpation of Matter from Intracranial Artery, Percutaneous Approach */
"03CG4Z6" = "1" /* Extirpation of Matter from Intracranial Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03CG4ZZ" = "1" /* Extirpation of Matter from Intracranial Artery, Percutaneous Endoscopic Approach */
"03CH0Z6" = "1" /* Extirpation of Matter from Right Common Carotid Artery, Bifurcation, Open Approach */
"03CH0ZZ" = "1" /* Extirpation of Matter from Right Common Carotid Artery, Open Approach */
"03CH3Z6" = "1" /* Extirpation of Matter from Right Common Carotid Artery, Bifurcation, Percutaneous Approach */
"03CH3ZZ" = "1" /* Extirpation of Matter from Right Common Carotid Artery, Percutaneous Approach */
"03CH4Z6" = "1" /* Extirpation of Matter from Right Common Carotid Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03CH4ZZ" = "1" /* Extirpation of Matter from Right Common Carotid Artery, Percutaneous Endoscopic Approach */
"03CJ0Z6" = "1" /* Extirpation of Matter from Left Common Carotid Artery, Bifurcation, Open Approach */
"03CJ0ZZ" = "1" /* Extirpation of Matter from Left Common Carotid Artery, Open Approach */
"03CJ3Z6" = "1" /* Extirpation of Matter from Left Common Carotid Artery, Bifurcation, Percutaneous Approach */
"03CJ3ZZ" = "1" /* Extirpation of Matter from Left Common Carotid Artery, Percutaneous Approach */
"03CJ4Z6" = "1" /* Extirpation of Matter from Left Common Carotid Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03CJ4ZZ" = "1" /* Extirpation of Matter from Left Common Carotid Artery, Percutaneous Endoscopic Approach */
"03CK0Z6" = "1" /* Extirpation of Matter from Right Internal Carotid Artery, Bifurcation, Open Approach */
"03CK0ZZ" = "1" /* Extirpation of Matter from Right Internal Carotid Artery, Open Approach */
"03CK3Z6" = "1" /* Extirpation of Matter from Right Internal Carotid Artery, Bifurcation, Percutaneous Approach */
"03CK3ZZ" = "1" /* Extirpation of Matter from Right Internal Carotid Artery, Percutaneous Approach */
"03CK4Z6" = "1" /* Extirpation of Matter from Right Internal Carotid Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03CK4ZZ" = "1" /* Extirpation of Matter from Right Internal Carotid Artery, Percutaneous Endoscopic Approach */
"03CL0Z6" = "1" /* Extirpation of Matter from Left Internal Carotid Artery, Bifurcation, Open Approach */
"03CL0ZZ" = "1" /* Extirpation of Matter from Left Internal Carotid Artery, Open Approach */
"03CL3Z6" = "1" /* Extirpation of Matter from Left Internal Carotid Artery, Bifurcation, Percutaneous Approach */
"03CL3ZZ" = "1" /* Extirpation of Matter from Left Internal Carotid Artery, Percutaneous Approach */
"03CL4Z6" = "1" /* Extirpation of Matter from Left Internal Carotid Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03CL4ZZ" = "1" /* Extirpation of Matter from Left Internal Carotid Artery, Percutaneous Endoscopic Approach */
"03CM0Z6" = "1" /* Extirpation of Matter from Right External Carotid Artery, Bifurcation, Open Approach */
"03CM0ZZ" = "1" /* Extirpation of Matter from Right External Carotid Artery, Open Approach */
"03CM3Z6" = "1" /* Extirpation of Matter from Right External Carotid Artery, Bifurcation, Percutaneous Approach */
"03CM3ZZ" = "1" /* Extirpation of Matter from Right External Carotid Artery, Percutaneous Approach */
"03CM4Z6" = "1" /* Extirpation of Matter from Right External Carotid Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03CM4ZZ" = "1" /* Extirpation of Matter from Right External Carotid Artery, Percutaneous Endoscopic Approach */
"03CN0Z6" = "1" /* Extirpation of Matter from Left External Carotid Artery, Bifurcation, Open Approach */
"03CN0ZZ" = "1" /* Extirpation of Matter from Left External Carotid Artery, Open Approach */
"03CN3Z6" = "1" /* Extirpation of Matter from Left External Carotid Artery, Bifurcation, Percutaneous Approach */
"03CN3ZZ" = "1" /* Extirpation of Matter from Left External Carotid Artery, Percutaneous Approach */
"03CN4Z6" = "1" /* Extirpation of Matter from Left External Carotid Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03CN4ZZ" = "1" /* Extirpation of Matter from Left External Carotid Artery, Percutaneous Endoscopic Approach */
"03CP0Z6" = "1" /* Extirpation of Matter from Right Vertebral Artery, Bifurcation, Open Approach */
"03CP0ZZ" = "1" /* Extirpation of Matter from Right Vertebral Artery, Open Approach */
"03CP3Z6" = "1" /* Extirpation of Matter from Right Vertebral Artery, Bifurcation, Percutaneous Approach */
"03CP3ZZ" = "1" /* Extirpation of Matter from Right Vertebral Artery, Percutaneous Approach */
"03CP4Z6" = "1" /* Extirpation of Matter from Right Vertebral Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03CP4ZZ" = "1" /* Extirpation of Matter from Right Vertebral Artery, Percutaneous Endoscopic Approach */
"03CQ0Z6" = "1" /* Extirpation of Matter from Left Vertebral Artery, Bifurcation, Open Approach */
"03CQ0ZZ" = "1" /* Extirpation of Matter from Left Vertebral Artery, Open Approach */
"03CQ3Z6" = "1" /* Extirpation of Matter from Left Vertebral Artery, Bifurcation, Percutaneous Approach */
"03CQ3ZZ" = "1" /* Extirpation of Matter from Left Vertebral Artery, Percutaneous Approach */
"03CQ4Z6" = "1" /* Extirpation of Matter from Left Vertebral Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03CQ4ZZ" = "1" /* Extirpation of Matter from Left Vertebral Artery, Percutaneous Endoscopic Approach */
"03CR0Z6" = "1" /* Extirpation of Matter from Face Artery, Bifurcation, Open Approach */
"03CR0ZZ" = "1" /* Extirpation of Matter from Face Artery, Open Approach */
"03CR3Z6" = "1" /* Extirpation of Matter from Face Artery, Bifurcation, Percutaneous Approach */
"03CR3ZZ" = "1" /* Extirpation of Matter from Face Artery, Percutaneous Approach */
"03CR4Z6" = "1" /* Extirpation of Matter from Face Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03CR4ZZ" = "1" /* Extirpation of Matter from Face Artery, Percutaneous Endoscopic Approach */
"03CS0Z6" = "1" /* Extirpation of Matter from Right Temporal Artery, Bifurcation, Open Approach */
"03CS0ZZ" = "1" /* Extirpation of Matter from Right Temporal Artery, Open Approach */
"03CS3Z6" = "1" /* Extirpation of Matter from Right Temporal Artery, Bifurcation, Percutaneous Approach */
"03CS3ZZ" = "1" /* Extirpation of Matter from Right Temporal Artery, Percutaneous Approach */
"03CS4Z6" = "1" /* Extirpation of Matter from Right Temporal Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03CS4ZZ" = "1" /* Extirpation of Matter from Right Temporal Artery, Percutaneous Endoscopic Approach */
"03CT0Z6" = "1" /* Extirpation of Matter from Left Temporal Artery, Bifurcation, Open Approach */
"03CT0ZZ" = "1" /* Extirpation of Matter from Left Temporal Artery, Open Approach */
"03CT3Z6" = "1" /* Extirpation of Matter from Left Temporal Artery, Bifurcation, Percutaneous Approach */
"03CT3ZZ" = "1" /* Extirpation of Matter from Left Temporal Artery, Percutaneous Approach */
"03CT4Z6" = "1" /* Extirpation of Matter from Left Temporal Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03CT4ZZ" = "1" /* Extirpation of Matter from Left Temporal Artery, Percutaneous Endoscopic Approach */
"03CU0Z6" = "1" /* Extirpation of Matter from Right Thyroid Artery, Bifurcation, Open Approach */
"03CU0ZZ" = "1" /* Extirpation of Matter from Right Thyroid Artery, Open Approach */
"03CU3Z6" = "1" /* Extirpation of Matter from Right Thyroid Artery, Bifurcation, Percutaneous Approach */
"03CU3ZZ" = "1" /* Extirpation of Matter from Right Thyroid Artery, Percutaneous Approach */
"03CU4Z6" = "1" /* Extirpation of Matter from Right Thyroid Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03CU4ZZ" = "1" /* Extirpation of Matter from Right Thyroid Artery, Percutaneous Endoscopic Approach */
"03CV0Z6" = "1" /* Extirpation of Matter from Left Thyroid Artery, Bifurcation, Open Approach */
"03CV0ZZ" = "1" /* Extirpation of Matter from Left Thyroid Artery, Open Approach */
"03CV3Z6" = "1" /* Extirpation of Matter from Left Thyroid Artery, Bifurcation, Percutaneous Approach */
"03CV3ZZ" = "1" /* Extirpation of Matter from Left Thyroid Artery, Percutaneous Approach */
"03CV4Z6" = "1" /* Extirpation of Matter from Left Thyroid Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03CV4ZZ" = "1" /* Extirpation of Matter from Left Thyroid Artery, Percutaneous Endoscopic Approach */
"03CY0Z6" = "1" /* Extirpation of Matter from Upper Artery, Bifurcation, Open Approach */
"03CY0ZZ" = "1" /* Extirpation of Matter from Upper Artery, Open Approach */
"03CY3Z6" = "1" /* Extirpation of Matter from Upper Artery, Bifurcation, Percutaneous Approach */
"03CY3ZZ" = "1" /* Extirpation of Matter from Upper Artery, Percutaneous Approach */
"03CY4Z6" = "1" /* Extirpation of Matter from Upper Artery, Bifurcation, Percutaneous Endoscopic Approach */
"03CY4ZZ" = "1" /* Extirpation of Matter from Upper Artery, Percutaneous Endoscopic Approach */
"03H00DZ" = "1" /* Insertion of Intraluminal Device into Right Internal Mammary Artery, Open Approach */
"03H03DZ" = "1" /* Insertion of Intraluminal Device into Right Internal Mammary Artery, Percutaneous Approach */
"03H04DZ" = "1" /* Insertion of Intraluminal Device into Right Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03H10DZ" = "1" /* Insertion of Intraluminal Device into Left Internal Mammary Artery, Open Approach */
"03H13DZ" = "1" /* Insertion of Intraluminal Device into Left Internal Mammary Artery, Percutaneous Approach */
"03H14DZ" = "1" /* Insertion of Intraluminal Device into Left Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03H20DZ" = "1" /* Insertion of Intraluminal Device into Innominate Artery, Open Approach */
"03H23DZ" = "1" /* Insertion of Intraluminal Device into Innominate Artery, Percutaneous Approach */
"03H24DZ" = "1" /* Insertion of Intraluminal Device into Innominate Artery, Percutaneous Endoscopic Approach */
"03H30DZ" = "1" /* Insertion of Intraluminal Device into Right Subclavian Artery, Open Approach */
"03H33DZ" = "1" /* Insertion of Intraluminal Device into Right Subclavian Artery, Percutaneous Approach */
"03H34DZ" = "1" /* Insertion of Intraluminal Device into Right Subclavian Artery, Percutaneous Endoscopic Approach */
"03H40DZ" = "1" /* Insertion of Intraluminal Device into Left Subclavian Artery, Open Approach */
"03H43DZ" = "1" /* Insertion of Intraluminal Device into Left Subclavian Artery, Percutaneous Approach */
"03H44DZ" = "1" /* Insertion of Intraluminal Device into Left Subclavian Artery, Percutaneous Endoscopic Approach */
"03H50DZ" = "1" /* Insertion of Intraluminal Device into Right Axillary Artery, Open Approach */
"03H53DZ" = "1" /* Insertion of Intraluminal Device into Right Axillary Artery, Percutaneous Approach */
"03H54DZ" = "1" /* Insertion of Intraluminal Device into Right Axillary Artery, Percutaneous Endoscopic Approach */
"03H60DZ" = "1" /* Insertion of Intraluminal Device into Left Axillary Artery, Open Approach */
"03H63DZ" = "1" /* Insertion of Intraluminal Device into Left Axillary Artery, Percutaneous Approach */
"03H64DZ" = "1" /* Insertion of Intraluminal Device into Left Axillary Artery, Percutaneous Endoscopic Approach */
"03H70DZ" = "1" /* Insertion of Intraluminal Device into Right Brachial Artery, Open Approach */
"03H73DZ" = "1" /* Insertion of Intraluminal Device into Right Brachial Artery, Percutaneous Approach */
"03H74DZ" = "1" /* Insertion of Intraluminal Device into Right Brachial Artery, Percutaneous Endoscopic Approach */
"03H80DZ" = "1" /* Insertion of Intraluminal Device into Left Brachial Artery, Open Approach */
"03H83DZ" = "1" /* Insertion of Intraluminal Device into Left Brachial Artery, Percutaneous Approach */
"03H84DZ" = "1" /* Insertion of Intraluminal Device into Left Brachial Artery, Percutaneous Endoscopic Approach */
"03H90DZ" = "1" /* Insertion of Intraluminal Device into Right Ulnar Artery, Open Approach */
"03H93DZ" = "1" /* Insertion of Intraluminal Device into Right Ulnar Artery, Percutaneous Approach */
"03H94DZ" = "1" /* Insertion of Intraluminal Device into Right Ulnar Artery, Percutaneous Endoscopic Approach */
"03HA0DZ" = "1" /* Insertion of Intraluminal Device into Left Ulnar Artery, Open Approach */
"03HA3DZ" = "1" /* Insertion of Intraluminal Device into Left Ulnar Artery, Percutaneous Approach */
"03HA4DZ" = "1" /* Insertion of Intraluminal Device into Left Ulnar Artery, Percutaneous Endoscopic Approach */
"03HB0DZ" = "1" /* Insertion of Intraluminal Device into Right Radial Artery, Open Approach */
"03HB3DZ" = "1" /* Insertion of Intraluminal Device into Right Radial Artery, Percutaneous Approach */
"03HB4DZ" = "1" /* Insertion of Intraluminal Device into Right Radial Artery, Percutaneous Endoscopic Approach */
"03HC0DZ" = "1" /* Insertion of Intraluminal Device into Left Radial Artery, Open Approach */
"03HC3DZ" = "1" /* Insertion of Intraluminal Device into Left Radial Artery, Percutaneous Approach */
"03HC4DZ" = "1" /* Insertion of Intraluminal Device into Left Radial Artery, Percutaneous Endoscopic Approach */
"03HD0DZ" = "1" /* Insertion of Intraluminal Device into Right Hand Artery, Open Approach */
"03HD3DZ" = "1" /* Insertion of Intraluminal Device into Right Hand Artery, Percutaneous Approach */
"03HD4DZ" = "1" /* Insertion of Intraluminal Device into Right Hand Artery, Percutaneous Endoscopic Approach */
"03HF0DZ" = "1" /* Insertion of Intraluminal Device into Left Hand Artery, Open Approach */
"03HF3DZ" = "1" /* Insertion of Intraluminal Device into Left Hand Artery, Percutaneous Approach */
"03HF4DZ" = "1" /* Insertion of Intraluminal Device into Left Hand Artery, Percutaneous Endoscopic Approach */
"03HG0DZ" = "1" /* Insertion of Intraluminal Device into Intracranial Artery, Open Approach */
"03HG3DZ" = "1" /* Insertion of Intraluminal Device into Intracranial Artery, Percutaneous Approach */
"03HG4DZ" = "1" /* Insertion of Intraluminal Device into Intracranial Artery, Percutaneous Endoscopic Approach */
"03HH0DZ" = "1" /* Insertion of Intraluminal Device into Right Common Carotid Artery, Open Approach */
"03HH3DZ" = "1" /* Insertion of Intraluminal Device into Right Common Carotid Artery, Percutaneous Approach */
"03HH4DZ" = "1" /* Insertion of Intraluminal Device into Right Common Carotid Artery, Percutaneous Endoscopic Approach */
"03HJ0DZ" = "1" /* Insertion of Intraluminal Device into Left Common Carotid Artery, Open Approach */
"03HJ3DZ" = "1" /* Insertion of Intraluminal Device into Left Common Carotid Artery, Percutaneous Approach */
"03HJ4DZ" = "1" /* Insertion of Intraluminal Device into Left Common Carotid Artery, Percutaneous Endoscopic Approach */
"03HK0DZ" = "1" /* Insertion of Intraluminal Device into Right Internal Carotid Artery, Open Approach */
"03HK0MZ" = "1" /* Insertion of Stimulator Lead into Right Internal Carotid Artery, Open Approach */
"03HK3DZ" = "1" /* Insertion of Intraluminal Device into Right Internal Carotid Artery, Percutaneous Approach */
"03HK3MZ" = "1" /* Insertion of Stimulator Lead into Right Internal Carotid Artery, Percutaneous Approach */
"03HK4DZ" = "1" /* Insertion of Intraluminal Device into Right Internal Carotid Artery, Percutaneous Endoscopic Approach */
"03HK4MZ" = "1" /* Insertion of Stimulator Lead into Right Internal Carotid Artery, Percutaneous Endoscopic Approach */
"03HL0DZ" = "1" /* Insertion of Intraluminal Device into Left Internal Carotid Artery, Open Approach */
"03HL0MZ" = "1" /* Insertion of Stimulator Lead into Left Internal Carotid Artery, Open Approach */
"03HL3DZ" = "1" /* Insertion of Intraluminal Device into Left Internal Carotid Artery, Percutaneous Approach */
"03HL3MZ" = "1" /* Insertion of Stimulator Lead into Left Internal Carotid Artery, Percutaneous Approach */
"03HL4DZ" = "1" /* Insertion of Intraluminal Device into Left Internal Carotid Artery, Percutaneous Endoscopic Approach */
"03HL4MZ" = "1" /* Insertion of Stimulator Lead into Left Internal Carotid Artery, Percutaneous Endoscopic Approach */
"03HM0DZ" = "1" /* Insertion of Intraluminal Device into Right External Carotid Artery, Open Approach */
"03HM3DZ" = "1" /* Insertion of Intraluminal Device into Right External Carotid Artery, Percutaneous Approach */
"03HM4DZ" = "1" /* Insertion of Intraluminal Device into Right External Carotid Artery, Percutaneous Endoscopic Approach */
"03HN0DZ" = "1" /* Insertion of Intraluminal Device into Left External Carotid Artery, Open Approach */
"03HN3DZ" = "1" /* Insertion of Intraluminal Device into Left External Carotid Artery, Percutaneous Approach */
"03HN4DZ" = "1" /* Insertion of Intraluminal Device into Left External Carotid Artery, Percutaneous Endoscopic Approach */
"03HP0DZ" = "1" /* Insertion of Intraluminal Device into Right Vertebral Artery, Open Approach */
"03HP3DZ" = "1" /* Insertion of Intraluminal Device into Right Vertebral Artery, Percutaneous Approach */
"03HP4DZ" = "1" /* Insertion of Intraluminal Device into Right Vertebral Artery, Percutaneous Endoscopic Approach */
"03HQ0DZ" = "1" /* Insertion of Intraluminal Device into Left Vertebral Artery, Open Approach */
"03HQ3DZ" = "1" /* Insertion of Intraluminal Device into Left Vertebral Artery, Percutaneous Approach */
"03HQ4DZ" = "1" /* Insertion of Intraluminal Device into Left Vertebral Artery, Percutaneous Endoscopic Approach */
"03HR0DZ" = "1" /* Insertion of Intraluminal Device into Face Artery, Open Approach */
"03HR3DZ" = "1" /* Insertion of Intraluminal Device into Face Artery, Percutaneous Approach */
"03HR4DZ" = "1" /* Insertion of Intraluminal Device into Face Artery, Percutaneous Endoscopic Approach */
"03HS0DZ" = "1" /* Insertion of Intraluminal Device into Right Temporal Artery, Open Approach */
"03HS3DZ" = "1" /* Insertion of Intraluminal Device into Right Temporal Artery, Percutaneous Approach */
"03HS4DZ" = "1" /* Insertion of Intraluminal Device into Right Temporal Artery, Percutaneous Endoscopic Approach */
"03HT0DZ" = "1" /* Insertion of Intraluminal Device into Left Temporal Artery, Open Approach */
"03HT3DZ" = "1" /* Insertion of Intraluminal Device into Left Temporal Artery, Percutaneous Approach */
"03HT4DZ" = "1" /* Insertion of Intraluminal Device into Left Temporal Artery, Percutaneous Endoscopic Approach */
"03HU0DZ" = "1" /* Insertion of Intraluminal Device into Right Thyroid Artery, Open Approach */
"03HU3DZ" = "1" /* Insertion of Intraluminal Device into Right Thyroid Artery, Percutaneous Approach */
"03HU4DZ" = "1" /* Insertion of Intraluminal Device into Right Thyroid Artery, Percutaneous Endoscopic Approach */
"03HV0DZ" = "1" /* Insertion of Intraluminal Device into Left Thyroid Artery, Open Approach */
"03HV3DZ" = "1" /* Insertion of Intraluminal Device into Left Thyroid Artery, Percutaneous Approach */
"03HV4DZ" = "1" /* Insertion of Intraluminal Device into Left Thyroid Artery, Percutaneous Endoscopic Approach */
"03HY02Z" = "1" /* Insertion of Monitoring Device into Upper Artery, Open Approach */
"03HY0DZ" = "1" /* Insertion of Intraluminal Device into Upper Artery, Open Approach */
"03HY3DZ" = "1" /* Insertion of Intraluminal Device into Upper Artery, Percutaneous Approach */
"03HY42Z" = "1" /* Insertion of Monitoring Device into Upper Artery, Percutaneous Endoscopic Approach */
"03HY4DZ" = "1" /* Insertion of Intraluminal Device into Upper Artery, Percutaneous Endoscopic Approach */
"03JY0ZZ" = "1" /* Inspection of Upper Artery, Open Approach */
"03L00CZ" = "1" /* Occlusion of Right Internal Mammary Artery with Extraluminal Device, Open Approach */
"03L00DZ" = "1" /* Occlusion of Right Internal Mammary Artery with Intraluminal Device, Open Approach */
"03L00ZZ" = "1" /* Occlusion of Right Internal Mammary Artery, Open Approach */
"03L03CZ" = "1" /* Occlusion of Right Internal Mammary Artery with Extraluminal Device, Percutaneous Approach */
"03L03DZ" = "1" /* Occlusion of Right Internal Mammary Artery with Intraluminal Device, Percutaneous Approach */
"03L03ZZ" = "1" /* Occlusion of Right Internal Mammary Artery, Percutaneous Approach */
"03L04CZ" = "1" /* Occlusion of Right Internal Mammary Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L04DZ" = "1" /* Occlusion of Right Internal Mammary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L04ZZ" = "1" /* Occlusion of Right Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03L10CZ" = "1" /* Occlusion of Left Internal Mammary Artery with Extraluminal Device, Open Approach */
"03L10DZ" = "1" /* Occlusion of Left Internal Mammary Artery with Intraluminal Device, Open Approach */
"03L10ZZ" = "1" /* Occlusion of Left Internal Mammary Artery, Open Approach */
"03L13CZ" = "1" /* Occlusion of Left Internal Mammary Artery with Extraluminal Device, Percutaneous Approach */
"03L13DZ" = "1" /* Occlusion of Left Internal Mammary Artery with Intraluminal Device, Percutaneous Approach */
"03L13ZZ" = "1" /* Occlusion of Left Internal Mammary Artery, Percutaneous Approach */
"03L14CZ" = "1" /* Occlusion of Left Internal Mammary Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L14DZ" = "1" /* Occlusion of Left Internal Mammary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L14ZZ" = "1" /* Occlusion of Left Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03L20CZ" = "1" /* Occlusion of Innominate Artery with Extraluminal Device, Open Approach */
"03L20DZ" = "1" /* Occlusion of Innominate Artery with Intraluminal Device, Open Approach */
"03L20ZZ" = "1" /* Occlusion of Innominate Artery, Open Approach */
"03L23CZ" = "1" /* Occlusion of Innominate Artery with Extraluminal Device, Percutaneous Approach */
"03L23DZ" = "1" /* Occlusion of Innominate Artery with Intraluminal Device, Percutaneous Approach */
"03L23ZZ" = "1" /* Occlusion of Innominate Artery, Percutaneous Approach */
"03L24CZ" = "1" /* Occlusion of Innominate Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L24DZ" = "1" /* Occlusion of Innominate Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L24ZZ" = "1" /* Occlusion of Innominate Artery, Percutaneous Endoscopic Approach */
"03L30CZ" = "1" /* Occlusion of Right Subclavian Artery with Extraluminal Device, Open Approach */
"03L30DZ" = "1" /* Occlusion of Right Subclavian Artery with Intraluminal Device, Open Approach */
"03L30ZZ" = "1" /* Occlusion of Right Subclavian Artery, Open Approach */
"03L33CZ" = "1" /* Occlusion of Right Subclavian Artery with Extraluminal Device, Percutaneous Approach */
"03L33DZ" = "1" /* Occlusion of Right Subclavian Artery with Intraluminal Device, Percutaneous Approach */
"03L33ZZ" = "1" /* Occlusion of Right Subclavian Artery, Percutaneous Approach */
"03L34CZ" = "1" /* Occlusion of Right Subclavian Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L34DZ" = "1" /* Occlusion of Right Subclavian Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L34ZZ" = "1" /* Occlusion of Right Subclavian Artery, Percutaneous Endoscopic Approach */
"03L40CZ" = "1" /* Occlusion of Left Subclavian Artery with Extraluminal Device, Open Approach */
"03L40DZ" = "1" /* Occlusion of Left Subclavian Artery with Intraluminal Device, Open Approach */
"03L40ZZ" = "1" /* Occlusion of Left Subclavian Artery, Open Approach */
"03L43CZ" = "1" /* Occlusion of Left Subclavian Artery with Extraluminal Device, Percutaneous Approach */
"03L43DZ" = "1" /* Occlusion of Left Subclavian Artery with Intraluminal Device, Percutaneous Approach */
"03L43ZZ" = "1" /* Occlusion of Left Subclavian Artery, Percutaneous Approach */
"03L44CZ" = "1" /* Occlusion of Left Subclavian Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L44DZ" = "1" /* Occlusion of Left Subclavian Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L44ZZ" = "1" /* Occlusion of Left Subclavian Artery, Percutaneous Endoscopic Approach */
"03L50CZ" = "1" /* Occlusion of Right Axillary Artery with Extraluminal Device, Open Approach */
"03L50DZ" = "1" /* Occlusion of Right Axillary Artery with Intraluminal Device, Open Approach */
"03L50ZZ" = "1" /* Occlusion of Right Axillary Artery, Open Approach */
"03L53CZ" = "1" /* Occlusion of Right Axillary Artery with Extraluminal Device, Percutaneous Approach */
"03L53DZ" = "1" /* Occlusion of Right Axillary Artery with Intraluminal Device, Percutaneous Approach */
"03L53ZZ" = "1" /* Occlusion of Right Axillary Artery, Percutaneous Approach */
"03L54CZ" = "1" /* Occlusion of Right Axillary Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L54DZ" = "1" /* Occlusion of Right Axillary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L54ZZ" = "1" /* Occlusion of Right Axillary Artery, Percutaneous Endoscopic Approach */
"03L60CZ" = "1" /* Occlusion of Left Axillary Artery with Extraluminal Device, Open Approach */
"03L60DZ" = "1" /* Occlusion of Left Axillary Artery with Intraluminal Device, Open Approach */
"03L60ZZ" = "1" /* Occlusion of Left Axillary Artery, Open Approach */
"03L63CZ" = "1" /* Occlusion of Left Axillary Artery with Extraluminal Device, Percutaneous Approach */
"03L63DZ" = "1" /* Occlusion of Left Axillary Artery with Intraluminal Device, Percutaneous Approach */
"03L63ZZ" = "1" /* Occlusion of Left Axillary Artery, Percutaneous Approach */
"03L64CZ" = "1" /* Occlusion of Left Axillary Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L64DZ" = "1" /* Occlusion of Left Axillary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L64ZZ" = "1" /* Occlusion of Left Axillary Artery, Percutaneous Endoscopic Approach */
"03L70CZ" = "1" /* Occlusion of Right Brachial Artery with Extraluminal Device, Open Approach */
"03L70DZ" = "1" /* Occlusion of Right Brachial Artery with Intraluminal Device, Open Approach */
"03L70ZZ" = "1" /* Occlusion of Right Brachial Artery, Open Approach */
"03L73CZ" = "1" /* Occlusion of Right Brachial Artery with Extraluminal Device, Percutaneous Approach */
"03L73DZ" = "1" /* Occlusion of Right Brachial Artery with Intraluminal Device, Percutaneous Approach */
"03L73ZZ" = "1" /* Occlusion of Right Brachial Artery, Percutaneous Approach */
"03L74CZ" = "1" /* Occlusion of Right Brachial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L74DZ" = "1" /* Occlusion of Right Brachial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L74ZZ" = "1" /* Occlusion of Right Brachial Artery, Percutaneous Endoscopic Approach */
"03L80CZ" = "1" /* Occlusion of Left Brachial Artery with Extraluminal Device, Open Approach */
"03L80DZ" = "1" /* Occlusion of Left Brachial Artery with Intraluminal Device, Open Approach */
"03L80ZZ" = "1" /* Occlusion of Left Brachial Artery, Open Approach */
"03L83CZ" = "1" /* Occlusion of Left Brachial Artery with Extraluminal Device, Percutaneous Approach */
"03L83DZ" = "1" /* Occlusion of Left Brachial Artery with Intraluminal Device, Percutaneous Approach */
"03L83ZZ" = "1" /* Occlusion of Left Brachial Artery, Percutaneous Approach */
"03L84CZ" = "1" /* Occlusion of Left Brachial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L84DZ" = "1" /* Occlusion of Left Brachial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L84ZZ" = "1" /* Occlusion of Left Brachial Artery, Percutaneous Endoscopic Approach */
"03L90CZ" = "1" /* Occlusion of Right Ulnar Artery with Extraluminal Device, Open Approach */
"03L90DZ" = "1" /* Occlusion of Right Ulnar Artery with Intraluminal Device, Open Approach */
"03L90ZZ" = "1" /* Occlusion of Right Ulnar Artery, Open Approach */
"03L93CZ" = "1" /* Occlusion of Right Ulnar Artery with Extraluminal Device, Percutaneous Approach */
"03L93DZ" = "1" /* Occlusion of Right Ulnar Artery with Intraluminal Device, Percutaneous Approach */
"03L93ZZ" = "1" /* Occlusion of Right Ulnar Artery, Percutaneous Approach */
"03L94CZ" = "1" /* Occlusion of Right Ulnar Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03L94DZ" = "1" /* Occlusion of Right Ulnar Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03L94ZZ" = "1" /* Occlusion of Right Ulnar Artery, Percutaneous Endoscopic Approach */
"03LA0CZ" = "1" /* Occlusion of Left Ulnar Artery with Extraluminal Device, Open Approach */
"03LA0DZ" = "1" /* Occlusion of Left Ulnar Artery with Intraluminal Device, Open Approach */
"03LA0ZZ" = "1" /* Occlusion of Left Ulnar Artery, Open Approach */
"03LA3CZ" = "1" /* Occlusion of Left Ulnar Artery with Extraluminal Device, Percutaneous Approach */
"03LA3DZ" = "1" /* Occlusion of Left Ulnar Artery with Intraluminal Device, Percutaneous Approach */
"03LA3ZZ" = "1" /* Occlusion of Left Ulnar Artery, Percutaneous Approach */
"03LA4CZ" = "1" /* Occlusion of Left Ulnar Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LA4DZ" = "1" /* Occlusion of Left Ulnar Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LA4ZZ" = "1" /* Occlusion of Left Ulnar Artery, Percutaneous Endoscopic Approach */
"03LB0CZ" = "1" /* Occlusion of Right Radial Artery with Extraluminal Device, Open Approach */
"03LB0DZ" = "1" /* Occlusion of Right Radial Artery with Intraluminal Device, Open Approach */
"03LB0ZZ" = "1" /* Occlusion of Right Radial Artery, Open Approach */
"03LB3CZ" = "1" /* Occlusion of Right Radial Artery with Extraluminal Device, Percutaneous Approach */
"03LB3DZ" = "1" /* Occlusion of Right Radial Artery with Intraluminal Device, Percutaneous Approach */
"03LB3ZZ" = "1" /* Occlusion of Right Radial Artery, Percutaneous Approach */
"03LB4CZ" = "1" /* Occlusion of Right Radial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LB4DZ" = "1" /* Occlusion of Right Radial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LB4ZZ" = "1" /* Occlusion of Right Radial Artery, Percutaneous Endoscopic Approach */
"03LC0CZ" = "1" /* Occlusion of Left Radial Artery with Extraluminal Device, Open Approach */
"03LC0DZ" = "1" /* Occlusion of Left Radial Artery with Intraluminal Device, Open Approach */
"03LC0ZZ" = "1" /* Occlusion of Left Radial Artery, Open Approach */
"03LC3CZ" = "1" /* Occlusion of Left Radial Artery with Extraluminal Device, Percutaneous Approach */
"03LC3DZ" = "1" /* Occlusion of Left Radial Artery with Intraluminal Device, Percutaneous Approach */
"03LC3ZZ" = "1" /* Occlusion of Left Radial Artery, Percutaneous Approach */
"03LC4CZ" = "1" /* Occlusion of Left Radial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LC4DZ" = "1" /* Occlusion of Left Radial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LC4ZZ" = "1" /* Occlusion of Left Radial Artery, Percutaneous Endoscopic Approach */
"03LD0CZ" = "1" /* Occlusion of Right Hand Artery with Extraluminal Device, Open Approach */
"03LD0DZ" = "1" /* Occlusion of Right Hand Artery with Intraluminal Device, Open Approach */
"03LD0ZZ" = "1" /* Occlusion of Right Hand Artery, Open Approach */
"03LD3CZ" = "1" /* Occlusion of Right Hand Artery with Extraluminal Device, Percutaneous Approach */
"03LD3DZ" = "1" /* Occlusion of Right Hand Artery with Intraluminal Device, Percutaneous Approach */
"03LD3ZZ" = "1" /* Occlusion of Right Hand Artery, Percutaneous Approach */
"03LD4CZ" = "1" /* Occlusion of Right Hand Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LD4DZ" = "1" /* Occlusion of Right Hand Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LD4ZZ" = "1" /* Occlusion of Right Hand Artery, Percutaneous Endoscopic Approach */
"03LF0CZ" = "1" /* Occlusion of Left Hand Artery with Extraluminal Device, Open Approach */
"03LF0DZ" = "1" /* Occlusion of Left Hand Artery with Intraluminal Device, Open Approach */
"03LF0ZZ" = "1" /* Occlusion of Left Hand Artery, Open Approach */
"03LF3CZ" = "1" /* Occlusion of Left Hand Artery with Extraluminal Device, Percutaneous Approach */
"03LF3DZ" = "1" /* Occlusion of Left Hand Artery with Intraluminal Device, Percutaneous Approach */
"03LF3ZZ" = "1" /* Occlusion of Left Hand Artery, Percutaneous Approach */
"03LF4CZ" = "1" /* Occlusion of Left Hand Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LF4DZ" = "1" /* Occlusion of Left Hand Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LF4ZZ" = "1" /* Occlusion of Left Hand Artery, Percutaneous Endoscopic Approach */
"03LG0BZ" = "1" /* Occlusion of Intracranial Artery with Bioactive Intraluminal Device, Open Approach */
"03LG0CZ" = "1" /* Occlusion of Intracranial Artery with Extraluminal Device, Open Approach */
"03LG0DZ" = "1" /* Occlusion of Intracranial Artery with Intraluminal Device, Open Approach */
"03LG0ZZ" = "1" /* Occlusion of Intracranial Artery, Open Approach */
"03LG3BZ" = "1" /* Occlusion of Intracranial Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03LG3CZ" = "1" /* Occlusion of Intracranial Artery with Extraluminal Device, Percutaneous Approach */
"03LG3DZ" = "1" /* Occlusion of Intracranial Artery with Intraluminal Device, Percutaneous Approach */
"03LG3ZZ" = "1" /* Occlusion of Intracranial Artery, Percutaneous Approach */
"03LG4BZ" = "1" /* Occlusion of Intracranial Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03LG4CZ" = "1" /* Occlusion of Intracranial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LG4DZ" = "1" /* Occlusion of Intracranial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LG4ZZ" = "1" /* Occlusion of Intracranial Artery, Percutaneous Endoscopic Approach */
"03LH0BZ" = "1" /* Occlusion of Right Common Carotid Artery with Bioactive Intraluminal Device, Open Approach */
"03LH0CZ" = "1" /* Occlusion of Right Common Carotid Artery with Extraluminal Device, Open Approach */
"03LH0DZ" = "1" /* Occlusion of Right Common Carotid Artery with Intraluminal Device, Open Approach */
"03LH0ZZ" = "1" /* Occlusion of Right Common Carotid Artery, Open Approach */
"03LH3BZ" = "1" /* Occlusion of Right Common Carotid Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03LH3CZ" = "1" /* Occlusion of Right Common Carotid Artery with Extraluminal Device, Percutaneous Approach */
"03LH3DZ" = "1" /* Occlusion of Right Common Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03LH3ZZ" = "1" /* Occlusion of Right Common Carotid Artery, Percutaneous Approach */
"03LH4BZ" = "1" /* Occlusion of Right Common Carotid Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03LH4CZ" = "1" /* Occlusion of Right Common Carotid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LH4DZ" = "1" /* Occlusion of Right Common Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LH4ZZ" = "1" /* Occlusion of Right Common Carotid Artery, Percutaneous Endoscopic Approach */
"03LJ0BZ" = "1" /* Occlusion of Left Common Carotid Artery with Bioactive Intraluminal Device, Open Approach */
"03LJ0CZ" = "1" /* Occlusion of Left Common Carotid Artery with Extraluminal Device, Open Approach */
"03LJ0DZ" = "1" /* Occlusion of Left Common Carotid Artery with Intraluminal Device, Open Approach */
"03LJ0ZZ" = "1" /* Occlusion of Left Common Carotid Artery, Open Approach */
"03LJ3BZ" = "1" /* Occlusion of Left Common Carotid Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03LJ3CZ" = "1" /* Occlusion of Left Common Carotid Artery with Extraluminal Device, Percutaneous Approach */
"03LJ3DZ" = "1" /* Occlusion of Left Common Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03LJ3ZZ" = "1" /* Occlusion of Left Common Carotid Artery, Percutaneous Approach */
"03LJ4BZ" = "1" /* Occlusion of Left Common Carotid Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03LJ4CZ" = "1" /* Occlusion of Left Common Carotid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LJ4DZ" = "1" /* Occlusion of Left Common Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LJ4ZZ" = "1" /* Occlusion of Left Common Carotid Artery, Percutaneous Endoscopic Approach */
"03LK0BZ" = "1" /* Occlusion of Right Internal Carotid Artery with Bioactive Intraluminal Device, Open Approach */
"03LK0CZ" = "1" /* Occlusion of Right Internal Carotid Artery with Extraluminal Device, Open Approach */
"03LK0DZ" = "1" /* Occlusion of Right Internal Carotid Artery with Intraluminal Device, Open Approach */
"03LK0ZZ" = "1" /* Occlusion of Right Internal Carotid Artery, Open Approach */
"03LK3BZ" = "1" /* Occlusion of Right Internal Carotid Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03LK3CZ" = "1" /* Occlusion of Right Internal Carotid Artery with Extraluminal Device, Percutaneous Approach */
"03LK3DZ" = "1" /* Occlusion of Right Internal Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03LK3ZZ" = "1" /* Occlusion of Right Internal Carotid Artery, Percutaneous Approach */
"03LK4BZ" = "1" /* Occlusion of Right Internal Carotid Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03LK4CZ" = "1" /* Occlusion of Right Internal Carotid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LK4DZ" = "1" /* Occlusion of Right Internal Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LK4ZZ" = "1" /* Occlusion of Right Internal Carotid Artery, Percutaneous Endoscopic Approach */
"03LL0BZ" = "1" /* Occlusion of Left Internal Carotid Artery with Bioactive Intraluminal Device, Open Approach */
"03LL0CZ" = "1" /* Occlusion of Left Internal Carotid Artery with Extraluminal Device, Open Approach */
"03LL0DZ" = "1" /* Occlusion of Left Internal Carotid Artery with Intraluminal Device, Open Approach */
"03LL0ZZ" = "1" /* Occlusion of Left Internal Carotid Artery, Open Approach */
"03LL3BZ" = "1" /* Occlusion of Left Internal Carotid Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03LL3CZ" = "1" /* Occlusion of Left Internal Carotid Artery with Extraluminal Device, Percutaneous Approach */
"03LL3DZ" = "1" /* Occlusion of Left Internal Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03LL3ZZ" = "1" /* Occlusion of Left Internal Carotid Artery, Percutaneous Approach */
"03LL4BZ" = "1" /* Occlusion of Left Internal Carotid Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03LL4CZ" = "1" /* Occlusion of Left Internal Carotid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LL4DZ" = "1" /* Occlusion of Left Internal Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LL4ZZ" = "1" /* Occlusion of Left Internal Carotid Artery, Percutaneous Endoscopic Approach */
"03LM0BZ" = "1" /* Occlusion of Right External Carotid Artery with Bioactive Intraluminal Device, Open Approach */
"03LM0CZ" = "1" /* Occlusion of Right External Carotid Artery with Extraluminal Device, Open Approach */
"03LM0DZ" = "1" /* Occlusion of Right External Carotid Artery with Intraluminal Device, Open Approach */
"03LM0ZZ" = "1" /* Occlusion of Right External Carotid Artery, Open Approach */
"03LM3BZ" = "1" /* Occlusion of Right External Carotid Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03LM3CZ" = "1" /* Occlusion of Right External Carotid Artery with Extraluminal Device, Percutaneous Approach */
"03LM3DZ" = "1" /* Occlusion of Right External Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03LM3ZZ" = "1" /* Occlusion of Right External Carotid Artery, Percutaneous Approach */
"03LM4BZ" = "1" /* Occlusion of Right External Carotid Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03LM4CZ" = "1" /* Occlusion of Right External Carotid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LM4DZ" = "1" /* Occlusion of Right External Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LM4ZZ" = "1" /* Occlusion of Right External Carotid Artery, Percutaneous Endoscopic Approach */
"03LN0BZ" = "1" /* Occlusion of Left External Carotid Artery with Bioactive Intraluminal Device, Open Approach */
"03LN0CZ" = "1" /* Occlusion of Left External Carotid Artery with Extraluminal Device, Open Approach */
"03LN0DZ" = "1" /* Occlusion of Left External Carotid Artery with Intraluminal Device, Open Approach */
"03LN0ZZ" = "1" /* Occlusion of Left External Carotid Artery, Open Approach */
"03LN3BZ" = "1" /* Occlusion of Left External Carotid Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03LN3CZ" = "1" /* Occlusion of Left External Carotid Artery with Extraluminal Device, Percutaneous Approach */
"03LN3DZ" = "1" /* Occlusion of Left External Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03LN3ZZ" = "1" /* Occlusion of Left External Carotid Artery, Percutaneous Approach */
"03LN4BZ" = "1" /* Occlusion of Left External Carotid Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03LN4CZ" = "1" /* Occlusion of Left External Carotid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LN4DZ" = "1" /* Occlusion of Left External Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LN4ZZ" = "1" /* Occlusion of Left External Carotid Artery, Percutaneous Endoscopic Approach */
"03LP0BZ" = "1" /* Occlusion of Right Vertebral Artery with Bioactive Intraluminal Device, Open Approach */
"03LP0CZ" = "1" /* Occlusion of Right Vertebral Artery with Extraluminal Device, Open Approach */
"03LP0DZ" = "1" /* Occlusion of Right Vertebral Artery with Intraluminal Device, Open Approach */
"03LP0ZZ" = "1" /* Occlusion of Right Vertebral Artery, Open Approach */
"03LP3BZ" = "1" /* Occlusion of Right Vertebral Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03LP3CZ" = "1" /* Occlusion of Right Vertebral Artery with Extraluminal Device, Percutaneous Approach */
"03LP3DZ" = "1" /* Occlusion of Right Vertebral Artery with Intraluminal Device, Percutaneous Approach */
"03LP3ZZ" = "1" /* Occlusion of Right Vertebral Artery, Percutaneous Approach */
"03LP4BZ" = "1" /* Occlusion of Right Vertebral Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03LP4CZ" = "1" /* Occlusion of Right Vertebral Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LP4DZ" = "1" /* Occlusion of Right Vertebral Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LP4ZZ" = "1" /* Occlusion of Right Vertebral Artery, Percutaneous Endoscopic Approach */
"03LQ0BZ" = "1" /* Occlusion of Left Vertebral Artery with Bioactive Intraluminal Device, Open Approach */
"03LQ0CZ" = "1" /* Occlusion of Left Vertebral Artery with Extraluminal Device, Open Approach */
"03LQ0DZ" = "1" /* Occlusion of Left Vertebral Artery with Intraluminal Device, Open Approach */
"03LQ0ZZ" = "1" /* Occlusion of Left Vertebral Artery, Open Approach */
"03LQ3BZ" = "1" /* Occlusion of Left Vertebral Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03LQ3CZ" = "1" /* Occlusion of Left Vertebral Artery with Extraluminal Device, Percutaneous Approach */
"03LQ3DZ" = "1" /* Occlusion of Left Vertebral Artery with Intraluminal Device, Percutaneous Approach */
"03LQ3ZZ" = "1" /* Occlusion of Left Vertebral Artery, Percutaneous Approach */
"03LQ4BZ" = "1" /* Occlusion of Left Vertebral Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03LQ4CZ" = "1" /* Occlusion of Left Vertebral Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LQ4DZ" = "1" /* Occlusion of Left Vertebral Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LQ4ZZ" = "1" /* Occlusion of Left Vertebral Artery, Percutaneous Endoscopic Approach */
"03LR0CZ" = "1" /* Occlusion of Face Artery with Extraluminal Device, Open Approach */
"03LR0DZ" = "1" /* Occlusion of Face Artery with Intraluminal Device, Open Approach */
"03LR0ZZ" = "1" /* Occlusion of Face Artery, Open Approach */
"03LR3CZ" = "1" /* Occlusion of Face Artery with Extraluminal Device, Percutaneous Approach */
"03LR3DZ" = "1" /* Occlusion of Face Artery with Intraluminal Device, Percutaneous Approach */
"03LR3ZZ" = "1" /* Occlusion of Face Artery, Percutaneous Approach */
"03LR4CZ" = "1" /* Occlusion of Face Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LR4DZ" = "1" /* Occlusion of Face Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LR4ZZ" = "1" /* Occlusion of Face Artery, Percutaneous Endoscopic Approach */
"03LS0CZ" = "1" /* Occlusion of Right Temporal Artery with Extraluminal Device, Open Approach */
"03LS0DZ" = "1" /* Occlusion of Right Temporal Artery with Intraluminal Device, Open Approach */
"03LS0ZZ" = "1" /* Occlusion of Right Temporal Artery, Open Approach */
"03LS3CZ" = "1" /* Occlusion of Right Temporal Artery with Extraluminal Device, Percutaneous Approach */
"03LS3DZ" = "1" /* Occlusion of Right Temporal Artery with Intraluminal Device, Percutaneous Approach */
"03LS3ZZ" = "1" /* Occlusion of Right Temporal Artery, Percutaneous Approach */
"03LS4CZ" = "1" /* Occlusion of Right Temporal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LS4DZ" = "1" /* Occlusion of Right Temporal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LS4ZZ" = "1" /* Occlusion of Right Temporal Artery, Percutaneous Endoscopic Approach */
"03LT0CZ" = "1" /* Occlusion of Left Temporal Artery with Extraluminal Device, Open Approach */
"03LT0DZ" = "1" /* Occlusion of Left Temporal Artery with Intraluminal Device, Open Approach */
"03LT0ZZ" = "1" /* Occlusion of Left Temporal Artery, Open Approach */
"03LT3CZ" = "1" /* Occlusion of Left Temporal Artery with Extraluminal Device, Percutaneous Approach */
"03LT3DZ" = "1" /* Occlusion of Left Temporal Artery with Intraluminal Device, Percutaneous Approach */
"03LT3ZZ" = "1" /* Occlusion of Left Temporal Artery, Percutaneous Approach */
"03LT4CZ" = "1" /* Occlusion of Left Temporal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LT4DZ" = "1" /* Occlusion of Left Temporal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LT4ZZ" = "1" /* Occlusion of Left Temporal Artery, Percutaneous Endoscopic Approach */
"03LU0CZ" = "1" /* Occlusion of Right Thyroid Artery with Extraluminal Device, Open Approach */
"03LU0DZ" = "1" /* Occlusion of Right Thyroid Artery with Intraluminal Device, Open Approach */
"03LU0ZZ" = "1" /* Occlusion of Right Thyroid Artery, Open Approach */
"03LU3CZ" = "1" /* Occlusion of Right Thyroid Artery with Extraluminal Device, Percutaneous Approach */
"03LU3DZ" = "1" /* Occlusion of Right Thyroid Artery with Intraluminal Device, Percutaneous Approach */
"03LU3ZZ" = "1" /* Occlusion of Right Thyroid Artery, Percutaneous Approach */
"03LU4CZ" = "1" /* Occlusion of Right Thyroid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LU4DZ" = "1" /* Occlusion of Right Thyroid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LU4ZZ" = "1" /* Occlusion of Right Thyroid Artery, Percutaneous Endoscopic Approach */
"03LV0CZ" = "1" /* Occlusion of Left Thyroid Artery with Extraluminal Device, Open Approach */
"03LV0DZ" = "1" /* Occlusion of Left Thyroid Artery with Intraluminal Device, Open Approach */
"03LV0ZZ" = "1" /* Occlusion of Left Thyroid Artery, Open Approach */
"03LV3CZ" = "1" /* Occlusion of Left Thyroid Artery with Extraluminal Device, Percutaneous Approach */
"03LV3DZ" = "1" /* Occlusion of Left Thyroid Artery with Intraluminal Device, Percutaneous Approach */
"03LV3ZZ" = "1" /* Occlusion of Left Thyroid Artery, Percutaneous Approach */
"03LV4CZ" = "1" /* Occlusion of Left Thyroid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LV4DZ" = "1" /* Occlusion of Left Thyroid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LV4ZZ" = "1" /* Occlusion of Left Thyroid Artery, Percutaneous Endoscopic Approach */
"03LY0CZ" = "1" /* Occlusion of Upper Artery with Extraluminal Device, Open Approach */
"03LY0DZ" = "1" /* Occlusion of Upper Artery with Intraluminal Device, Open Approach */
"03LY0ZZ" = "1" /* Occlusion of Upper Artery, Open Approach */
"03LY3CZ" = "1" /* Occlusion of Upper Artery with Extraluminal Device, Percutaneous Approach */
"03LY3DZ" = "1" /* Occlusion of Upper Artery with Intraluminal Device, Percutaneous Approach */
"03LY3ZZ" = "1" /* Occlusion of Upper Artery, Percutaneous Approach */
"03LY4CZ" = "1" /* Occlusion of Upper Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03LY4DZ" = "1" /* Occlusion of Upper Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03LY4ZZ" = "1" /* Occlusion of Upper Artery, Percutaneous Endoscopic Approach */
"03N00ZZ" = "1" /* Release Right Internal Mammary Artery, Open Approach */
"03N03ZZ" = "1" /* Release Right Internal Mammary Artery, Percutaneous Approach */
"03N04ZZ" = "1" /* Release Right Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03N10ZZ" = "1" /* Release Left Internal Mammary Artery, Open Approach */
"03N13ZZ" = "1" /* Release Left Internal Mammary Artery, Percutaneous Approach */
"03N14ZZ" = "1" /* Release Left Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03N20ZZ" = "1" /* Release Innominate Artery, Open Approach */
"03N23ZZ" = "1" /* Release Innominate Artery, Percutaneous Approach */
"03N24ZZ" = "1" /* Release Innominate Artery, Percutaneous Endoscopic Approach */
"03N30ZZ" = "1" /* Release Right Subclavian Artery, Open Approach */
"03N33ZZ" = "1" /* Release Right Subclavian Artery, Percutaneous Approach */
"03N34ZZ" = "1" /* Release Right Subclavian Artery, Percutaneous Endoscopic Approach */
"03N40ZZ" = "1" /* Release Left Subclavian Artery, Open Approach */
"03N43ZZ" = "1" /* Release Left Subclavian Artery, Percutaneous Approach */
"03N44ZZ" = "1" /* Release Left Subclavian Artery, Percutaneous Endoscopic Approach */
"03N50ZZ" = "1" /* Release Right Axillary Artery, Open Approach */
"03N53ZZ" = "1" /* Release Right Axillary Artery, Percutaneous Approach */
"03N54ZZ" = "1" /* Release Right Axillary Artery, Percutaneous Endoscopic Approach */
"03N60ZZ" = "1" /* Release Left Axillary Artery, Open Approach */
"03N63ZZ" = "1" /* Release Left Axillary Artery, Percutaneous Approach */
"03N64ZZ" = "1" /* Release Left Axillary Artery, Percutaneous Endoscopic Approach */
"03N70ZZ" = "1" /* Release Right Brachial Artery, Open Approach */
"03N73ZZ" = "1" /* Release Right Brachial Artery, Percutaneous Approach */
"03N74ZZ" = "1" /* Release Right Brachial Artery, Percutaneous Endoscopic Approach */
"03N80ZZ" = "1" /* Release Left Brachial Artery, Open Approach */
"03N83ZZ" = "1" /* Release Left Brachial Artery, Percutaneous Approach */
"03N84ZZ" = "1" /* Release Left Brachial Artery, Percutaneous Endoscopic Approach */
"03N90ZZ" = "1" /* Release Right Ulnar Artery, Open Approach */
"03N93ZZ" = "1" /* Release Right Ulnar Artery, Percutaneous Approach */
"03N94ZZ" = "1" /* Release Right Ulnar Artery, Percutaneous Endoscopic Approach */
"03NA0ZZ" = "1" /* Release Left Ulnar Artery, Open Approach */
"03NA3ZZ" = "1" /* Release Left Ulnar Artery, Percutaneous Approach */
"03NA4ZZ" = "1" /* Release Left Ulnar Artery, Percutaneous Endoscopic Approach */
"03NB0ZZ" = "1" /* Release Right Radial Artery, Open Approach */
"03NB3ZZ" = "1" /* Release Right Radial Artery, Percutaneous Approach */
"03NB4ZZ" = "1" /* Release Right Radial Artery, Percutaneous Endoscopic Approach */
"03NC0ZZ" = "1" /* Release Left Radial Artery, Open Approach */
"03NC3ZZ" = "1" /* Release Left Radial Artery, Percutaneous Approach */
"03NC4ZZ" = "1" /* Release Left Radial Artery, Percutaneous Endoscopic Approach */
"03ND0ZZ" = "1" /* Release Right Hand Artery, Open Approach */
"03ND3ZZ" = "1" /* Release Right Hand Artery, Percutaneous Approach */
"03ND4ZZ" = "1" /* Release Right Hand Artery, Percutaneous Endoscopic Approach */
"03NF0ZZ" = "1" /* Release Left Hand Artery, Open Approach */
"03NF3ZZ" = "1" /* Release Left Hand Artery, Percutaneous Approach */
"03NF4ZZ" = "1" /* Release Left Hand Artery, Percutaneous Endoscopic Approach */
"03NG0ZZ" = "1" /* Release Intracranial Artery, Open Approach */
"03NG3ZZ" = "1" /* Release Intracranial Artery, Percutaneous Approach */
"03NG4ZZ" = "1" /* Release Intracranial Artery, Percutaneous Endoscopic Approach */
"03NH0ZZ" = "1" /* Release Right Common Carotid Artery, Open Approach */
"03NH3ZZ" = "1" /* Release Right Common Carotid Artery, Percutaneous Approach */
"03NH4ZZ" = "1" /* Release Right Common Carotid Artery, Percutaneous Endoscopic Approach */
"03NJ0ZZ" = "1" /* Release Left Common Carotid Artery, Open Approach */
"03NJ3ZZ" = "1" /* Release Left Common Carotid Artery, Percutaneous Approach */
"03NJ4ZZ" = "1" /* Release Left Common Carotid Artery, Percutaneous Endoscopic Approach */
"03NK0ZZ" = "1" /* Release Right Internal Carotid Artery, Open Approach */
"03NK3ZZ" = "1" /* Release Right Internal Carotid Artery, Percutaneous Approach */
"03NK4ZZ" = "1" /* Release Right Internal Carotid Artery, Percutaneous Endoscopic Approach */
"03NL0ZZ" = "1" /* Release Left Internal Carotid Artery, Open Approach */
"03NL3ZZ" = "1" /* Release Left Internal Carotid Artery, Percutaneous Approach */
"03NL4ZZ" = "1" /* Release Left Internal Carotid Artery, Percutaneous Endoscopic Approach */
"03NM0ZZ" = "1" /* Release Right External Carotid Artery, Open Approach */
"03NM3ZZ" = "1" /* Release Right External Carotid Artery, Percutaneous Approach */
"03NM4ZZ" = "1" /* Release Right External Carotid Artery, Percutaneous Endoscopic Approach */
"03NN0ZZ" = "1" /* Release Left External Carotid Artery, Open Approach */
"03NN3ZZ" = "1" /* Release Left External Carotid Artery, Percutaneous Approach */
"03NN4ZZ" = "1" /* Release Left External Carotid Artery, Percutaneous Endoscopic Approach */
"03NP0ZZ" = "1" /* Release Right Vertebral Artery, Open Approach */
"03NP3ZZ" = "1" /* Release Right Vertebral Artery, Percutaneous Approach */
"03NP4ZZ" = "1" /* Release Right Vertebral Artery, Percutaneous Endoscopic Approach */
"03NQ0ZZ" = "1" /* Release Left Vertebral Artery, Open Approach */
"03NQ3ZZ" = "1" /* Release Left Vertebral Artery, Percutaneous Approach */
"03NQ4ZZ" = "1" /* Release Left Vertebral Artery, Percutaneous Endoscopic Approach */
"03NR0ZZ" = "1" /* Release Face Artery, Open Approach */
"03NR3ZZ" = "1" /* Release Face Artery, Percutaneous Approach */
"03NR4ZZ" = "1" /* Release Face Artery, Percutaneous Endoscopic Approach */
"03NS0ZZ" = "1" /* Release Right Temporal Artery, Open Approach */
"03NS3ZZ" = "1" /* Release Right Temporal Artery, Percutaneous Approach */
"03NS4ZZ" = "1" /* Release Right Temporal Artery, Percutaneous Endoscopic Approach */
"03NT0ZZ" = "1" /* Release Left Temporal Artery, Open Approach */
"03NT3ZZ" = "1" /* Release Left Temporal Artery, Percutaneous Approach */
"03NT4ZZ" = "1" /* Release Left Temporal Artery, Percutaneous Endoscopic Approach */
"03NU0ZZ" = "1" /* Release Right Thyroid Artery, Open Approach */
"03NU3ZZ" = "1" /* Release Right Thyroid Artery, Percutaneous Approach */
"03NU4ZZ" = "1" /* Release Right Thyroid Artery, Percutaneous Endoscopic Approach */
"03NV0ZZ" = "1" /* Release Left Thyroid Artery, Open Approach */
"03NV3ZZ" = "1" /* Release Left Thyroid Artery, Percutaneous Approach */
"03NV4ZZ" = "1" /* Release Left Thyroid Artery, Percutaneous Endoscopic Approach */
"03NY0ZZ" = "1" /* Release Upper Artery, Open Approach */
"03NY3ZZ" = "1" /* Release Upper Artery, Percutaneous Approach */
"03NY4ZZ" = "1" /* Release Upper Artery, Percutaneous Endoscopic Approach */
"03PY00Z" = "1" /* Removal of Drainage Device from Upper Artery, Open Approach */
"03PY02Z" = "1" /* Removal of Monitoring Device from Upper Artery, Open Approach */
"03PY03Z" = "1" /* Removal of Infusion Device from Upper Artery, Open Approach */
"03PY07Z" = "1" /* Removal of Autologous Tissue Substitute from Upper Artery, Open Approach */
"03PY0CZ" = "1" /* Removal of Extraluminal Device from Upper Artery, Open Approach */
"03PY0DZ" = "1" /* Removal of Intraluminal Device from Upper Artery, Open Approach */
"03PY0JZ" = "1" /* Removal of Synthetic Substitute from Upper Artery, Open Approach */
"03PY0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Upper Artery, Open Approach */
"03PY0MZ" = "1" /* Removal of Stimulator Lead from Upper Artery, Open Approach */
"03PY37Z" = "1" /* Removal of Autologous Tissue Substitute from Upper Artery, Percutaneous Approach */
"03PY3CZ" = "1" /* Removal of Extraluminal Device from Upper Artery, Percutaneous Approach */
"03PY3JZ" = "1" /* Removal of Synthetic Substitute from Upper Artery, Percutaneous Approach */
"03PY3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Upper Artery, Percutaneous Approach */
"03PY3MZ" = "1" /* Removal of Stimulator Lead from Upper Artery, Percutaneous Approach */
"03PY40Z" = "1" /* Removal of Drainage Device from Upper Artery, Percutaneous Endoscopic Approach */
"03PY42Z" = "1" /* Removal of Monitoring Device from Upper Artery, Percutaneous Endoscopic Approach */
"03PY43Z" = "1" /* Removal of Infusion Device from Upper Artery, Percutaneous Endoscopic Approach */
"03PY47Z" = "1" /* Removal of Autologous Tissue Substitute from Upper Artery, Percutaneous Endoscopic Approach */
"03PY4CZ" = "1" /* Removal of Extraluminal Device from Upper Artery, Percutaneous Endoscopic Approach */
"03PY4DZ" = "1" /* Removal of Intraluminal Device from Upper Artery, Percutaneous Endoscopic Approach */
"03PY4JZ" = "1" /* Removal of Synthetic Substitute from Upper Artery, Percutaneous Endoscopic Approach */
"03PY4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Upper Artery, Percutaneous Endoscopic Approach */
"03PY4MZ" = "1" /* Removal of Stimulator Lead from Upper Artery, Percutaneous Endoscopic Approach */
"03Q00ZZ" = "1" /* Repair Right Internal Mammary Artery, Open Approach */
"03Q03ZZ" = "1" /* Repair Right Internal Mammary Artery, Percutaneous Approach */
"03Q04ZZ" = "1" /* Repair Right Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03Q10ZZ" = "1" /* Repair Left Internal Mammary Artery, Open Approach */
"03Q13ZZ" = "1" /* Repair Left Internal Mammary Artery, Percutaneous Approach */
"03Q14ZZ" = "1" /* Repair Left Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03Q20ZZ" = "1" /* Repair Innominate Artery, Open Approach */
"03Q23ZZ" = "1" /* Repair Innominate Artery, Percutaneous Approach */
"03Q24ZZ" = "1" /* Repair Innominate Artery, Percutaneous Endoscopic Approach */
"03Q30ZZ" = "1" /* Repair Right Subclavian Artery, Open Approach */
"03Q33ZZ" = "1" /* Repair Right Subclavian Artery, Percutaneous Approach */
"03Q34ZZ" = "1" /* Repair Right Subclavian Artery, Percutaneous Endoscopic Approach */
"03Q40ZZ" = "1" /* Repair Left Subclavian Artery, Open Approach */
"03Q43ZZ" = "1" /* Repair Left Subclavian Artery, Percutaneous Approach */
"03Q44ZZ" = "1" /* Repair Left Subclavian Artery, Percutaneous Endoscopic Approach */
"03Q50ZZ" = "1" /* Repair Right Axillary Artery, Open Approach */
"03Q53ZZ" = "1" /* Repair Right Axillary Artery, Percutaneous Approach */
"03Q54ZZ" = "1" /* Repair Right Axillary Artery, Percutaneous Endoscopic Approach */
"03Q60ZZ" = "1" /* Repair Left Axillary Artery, Open Approach */
"03Q63ZZ" = "1" /* Repair Left Axillary Artery, Percutaneous Approach */
"03Q64ZZ" = "1" /* Repair Left Axillary Artery, Percutaneous Endoscopic Approach */
"03Q70ZZ" = "1" /* Repair Right Brachial Artery, Open Approach */
"03Q73ZZ" = "1" /* Repair Right Brachial Artery, Percutaneous Approach */
"03Q74ZZ" = "1" /* Repair Right Brachial Artery, Percutaneous Endoscopic Approach */
"03Q80ZZ" = "1" /* Repair Left Brachial Artery, Open Approach */
"03Q83ZZ" = "1" /* Repair Left Brachial Artery, Percutaneous Approach */
"03Q84ZZ" = "1" /* Repair Left Brachial Artery, Percutaneous Endoscopic Approach */
"03Q90ZZ" = "1" /* Repair Right Ulnar Artery, Open Approach */
"03Q93ZZ" = "1" /* Repair Right Ulnar Artery, Percutaneous Approach */
"03Q94ZZ" = "1" /* Repair Right Ulnar Artery, Percutaneous Endoscopic Approach */
"03QA0ZZ" = "1" /* Repair Left Ulnar Artery, Open Approach */
"03QA3ZZ" = "1" /* Repair Left Ulnar Artery, Percutaneous Approach */
"03QA4ZZ" = "1" /* Repair Left Ulnar Artery, Percutaneous Endoscopic Approach */
"03QB0ZZ" = "1" /* Repair Right Radial Artery, Open Approach */
"03QB3ZZ" = "1" /* Repair Right Radial Artery, Percutaneous Approach */
"03QB4ZZ" = "1" /* Repair Right Radial Artery, Percutaneous Endoscopic Approach */
"03QC0ZZ" = "1" /* Repair Left Radial Artery, Open Approach */
"03QC3ZZ" = "1" /* Repair Left Radial Artery, Percutaneous Approach */
"03QC4ZZ" = "1" /* Repair Left Radial Artery, Percutaneous Endoscopic Approach */
"03QD0ZZ" = "1" /* Repair Right Hand Artery, Open Approach */
"03QD3ZZ" = "1" /* Repair Right Hand Artery, Percutaneous Approach */
"03QD4ZZ" = "1" /* Repair Right Hand Artery, Percutaneous Endoscopic Approach */
"03QF0ZZ" = "1" /* Repair Left Hand Artery, Open Approach */
"03QF3ZZ" = "1" /* Repair Left Hand Artery, Percutaneous Approach */
"03QF4ZZ" = "1" /* Repair Left Hand Artery, Percutaneous Endoscopic Approach */
"03QG0ZZ" = "1" /* Repair Intracranial Artery, Open Approach */
"03QG3ZZ" = "1" /* Repair Intracranial Artery, Percutaneous Approach */
"03QG4ZZ" = "1" /* Repair Intracranial Artery, Percutaneous Endoscopic Approach */
"03QH0ZZ" = "1" /* Repair Right Common Carotid Artery, Open Approach */
"03QH3ZZ" = "1" /* Repair Right Common Carotid Artery, Percutaneous Approach */
"03QH4ZZ" = "1" /* Repair Right Common Carotid Artery, Percutaneous Endoscopic Approach */
"03QJ0ZZ" = "1" /* Repair Left Common Carotid Artery, Open Approach */
"03QJ3ZZ" = "1" /* Repair Left Common Carotid Artery, Percutaneous Approach */
"03QJ4ZZ" = "1" /* Repair Left Common Carotid Artery, Percutaneous Endoscopic Approach */
"03QK0ZZ" = "1" /* Repair Right Internal Carotid Artery, Open Approach */
"03QK3ZZ" = "1" /* Repair Right Internal Carotid Artery, Percutaneous Approach */
"03QK4ZZ" = "1" /* Repair Right Internal Carotid Artery, Percutaneous Endoscopic Approach */
"03QL0ZZ" = "1" /* Repair Left Internal Carotid Artery, Open Approach */
"03QL3ZZ" = "1" /* Repair Left Internal Carotid Artery, Percutaneous Approach */
"03QL4ZZ" = "1" /* Repair Left Internal Carotid Artery, Percutaneous Endoscopic Approach */
"03QM0ZZ" = "1" /* Repair Right External Carotid Artery, Open Approach */
"03QM3ZZ" = "1" /* Repair Right External Carotid Artery, Percutaneous Approach */
"03QM4ZZ" = "1" /* Repair Right External Carotid Artery, Percutaneous Endoscopic Approach */
"03QN0ZZ" = "1" /* Repair Left External Carotid Artery, Open Approach */
"03QN3ZZ" = "1" /* Repair Left External Carotid Artery, Percutaneous Approach */
"03QN4ZZ" = "1" /* Repair Left External Carotid Artery, Percutaneous Endoscopic Approach */
"03QP0ZZ" = "1" /* Repair Right Vertebral Artery, Open Approach */
"03QP3ZZ" = "1" /* Repair Right Vertebral Artery, Percutaneous Approach */
"03QP4ZZ" = "1" /* Repair Right Vertebral Artery, Percutaneous Endoscopic Approach */
"03QQ0ZZ" = "1" /* Repair Left Vertebral Artery, Open Approach */
"03QQ3ZZ" = "1" /* Repair Left Vertebral Artery, Percutaneous Approach */
"03QQ4ZZ" = "1" /* Repair Left Vertebral Artery, Percutaneous Endoscopic Approach */
"03QR0ZZ" = "1" /* Repair Face Artery, Open Approach */
"03QR3ZZ" = "1" /* Repair Face Artery, Percutaneous Approach */
"03QR4ZZ" = "1" /* Repair Face Artery, Percutaneous Endoscopic Approach */
"03QS0ZZ" = "1" /* Repair Right Temporal Artery, Open Approach */
"03QS3ZZ" = "1" /* Repair Right Temporal Artery, Percutaneous Approach */
"03QS4ZZ" = "1" /* Repair Right Temporal Artery, Percutaneous Endoscopic Approach */
"03QT0ZZ" = "1" /* Repair Left Temporal Artery, Open Approach */
"03QT3ZZ" = "1" /* Repair Left Temporal Artery, Percutaneous Approach */
"03QT4ZZ" = "1" /* Repair Left Temporal Artery, Percutaneous Endoscopic Approach */
"03QU0ZZ" = "1" /* Repair Right Thyroid Artery, Open Approach */
"03QU3ZZ" = "1" /* Repair Right Thyroid Artery, Percutaneous Approach */
"03QU4ZZ" = "1" /* Repair Right Thyroid Artery, Percutaneous Endoscopic Approach */
"03QV0ZZ" = "1" /* Repair Left Thyroid Artery, Open Approach */
"03QV3ZZ" = "1" /* Repair Left Thyroid Artery, Percutaneous Approach */
"03QV4ZZ" = "1" /* Repair Left Thyroid Artery, Percutaneous Endoscopic Approach */
"03QY0ZZ" = "1" /* Repair Upper Artery, Open Approach */
"03QY3ZZ" = "1" /* Repair Upper Artery, Percutaneous Approach */
"03QY4ZZ" = "1" /* Repair Upper Artery, Percutaneous Endoscopic Approach */
"03R007Z" = "1" /* Replacement of Right Internal Mammary Artery with Autologous Tissue Substitute, Open Approach */
"03R00JZ" = "1" /* Replacement of Right Internal Mammary Artery with Synthetic Substitute, Open Approach */
"03R00KZ" = "1" /* Replacement of Right Internal Mammary Artery with Nonautologous Tissue Substitute, Open Approach */
"03R047Z" = "1" /* Replacement of Right Internal Mammary Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R04JZ" = "1" /* Replacement of Right Internal Mammary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03R04KZ" = "1" /* Replacement of Right Internal Mammary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R107Z" = "1" /* Replacement of Left Internal Mammary Artery with Autologous Tissue Substitute, Open Approach */
"03R10JZ" = "1" /* Replacement of Left Internal Mammary Artery with Synthetic Substitute, Open Approach */
"03R10KZ" = "1" /* Replacement of Left Internal Mammary Artery with Nonautologous Tissue Substitute, Open Approach */
"03R147Z" = "1" /* Replacement of Left Internal Mammary Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R14JZ" = "1" /* Replacement of Left Internal Mammary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03R14KZ" = "1" /* Replacement of Left Internal Mammary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R207Z" = "1" /* Replacement of Innominate Artery with Autologous Tissue Substitute, Open Approach */
"03R20JZ" = "1" /* Replacement of Innominate Artery with Synthetic Substitute, Open Approach */
"03R20KZ" = "1" /* Replacement of Innominate Artery with Nonautologous Tissue Substitute, Open Approach */
"03R247Z" = "1" /* Replacement of Innominate Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R24JZ" = "1" /* Replacement of Innominate Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03R24KZ" = "1" /* Replacement of Innominate Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R307Z" = "1" /* Replacement of Right Subclavian Artery with Autologous Tissue Substitute, Open Approach */
"03R30JZ" = "1" /* Replacement of Right Subclavian Artery with Synthetic Substitute, Open Approach */
"03R30KZ" = "1" /* Replacement of Right Subclavian Artery with Nonautologous Tissue Substitute, Open Approach */
"03R347Z" = "1" /* Replacement of Right Subclavian Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R34JZ" = "1" /* Replacement of Right Subclavian Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03R34KZ" = "1" /* Replacement of Right Subclavian Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R407Z" = "1" /* Replacement of Left Subclavian Artery with Autologous Tissue Substitute, Open Approach */
"03R40JZ" = "1" /* Replacement of Left Subclavian Artery with Synthetic Substitute, Open Approach */
"03R40KZ" = "1" /* Replacement of Left Subclavian Artery with Nonautologous Tissue Substitute, Open Approach */
"03R447Z" = "1" /* Replacement of Left Subclavian Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R44JZ" = "1" /* Replacement of Left Subclavian Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03R44KZ" = "1" /* Replacement of Left Subclavian Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R507Z" = "1" /* Replacement of Right Axillary Artery with Autologous Tissue Substitute, Open Approach */
"03R50JZ" = "1" /* Replacement of Right Axillary Artery with Synthetic Substitute, Open Approach */
"03R50KZ" = "1" /* Replacement of Right Axillary Artery with Nonautologous Tissue Substitute, Open Approach */
"03R547Z" = "1" /* Replacement of Right Axillary Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R54JZ" = "1" /* Replacement of Right Axillary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03R54KZ" = "1" /* Replacement of Right Axillary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R607Z" = "1" /* Replacement of Left Axillary Artery with Autologous Tissue Substitute, Open Approach */
"03R60JZ" = "1" /* Replacement of Left Axillary Artery with Synthetic Substitute, Open Approach */
"03R60KZ" = "1" /* Replacement of Left Axillary Artery with Nonautologous Tissue Substitute, Open Approach */
"03R647Z" = "1" /* Replacement of Left Axillary Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R64JZ" = "1" /* Replacement of Left Axillary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03R64KZ" = "1" /* Replacement of Left Axillary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R707Z" = "1" /* Replacement of Right Brachial Artery with Autologous Tissue Substitute, Open Approach */
"03R70JZ" = "1" /* Replacement of Right Brachial Artery with Synthetic Substitute, Open Approach */
"03R70KZ" = "1" /* Replacement of Right Brachial Artery with Nonautologous Tissue Substitute, Open Approach */
"03R747Z" = "1" /* Replacement of Right Brachial Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R74JZ" = "1" /* Replacement of Right Brachial Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03R74KZ" = "1" /* Replacement of Right Brachial Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R807Z" = "1" /* Replacement of Left Brachial Artery with Autologous Tissue Substitute, Open Approach */
"03R80JZ" = "1" /* Replacement of Left Brachial Artery with Synthetic Substitute, Open Approach */
"03R80KZ" = "1" /* Replacement of Left Brachial Artery with Nonautologous Tissue Substitute, Open Approach */
"03R847Z" = "1" /* Replacement of Left Brachial Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R84JZ" = "1" /* Replacement of Left Brachial Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03R84KZ" = "1" /* Replacement of Left Brachial Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R907Z" = "1" /* Replacement of Right Ulnar Artery with Autologous Tissue Substitute, Open Approach */
"03R90JZ" = "1" /* Replacement of Right Ulnar Artery with Synthetic Substitute, Open Approach */
"03R90KZ" = "1" /* Replacement of Right Ulnar Artery with Nonautologous Tissue Substitute, Open Approach */
"03R947Z" = "1" /* Replacement of Right Ulnar Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03R94JZ" = "1" /* Replacement of Right Ulnar Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03R94KZ" = "1" /* Replacement of Right Ulnar Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RA07Z" = "1" /* Replacement of Left Ulnar Artery with Autologous Tissue Substitute, Open Approach */
"03RA0JZ" = "1" /* Replacement of Left Ulnar Artery with Synthetic Substitute, Open Approach */
"03RA0KZ" = "1" /* Replacement of Left Ulnar Artery with Nonautologous Tissue Substitute, Open Approach */
"03RA47Z" = "1" /* Replacement of Left Ulnar Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RA4JZ" = "1" /* Replacement of Left Ulnar Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03RA4KZ" = "1" /* Replacement of Left Ulnar Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RB07Z" = "1" /* Replacement of Right Radial Artery with Autologous Tissue Substitute, Open Approach */
"03RB0JZ" = "1" /* Replacement of Right Radial Artery with Synthetic Substitute, Open Approach */
"03RB0KZ" = "1" /* Replacement of Right Radial Artery with Nonautologous Tissue Substitute, Open Approach */
"03RB47Z" = "1" /* Replacement of Right Radial Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RB4JZ" = "1" /* Replacement of Right Radial Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03RB4KZ" = "1" /* Replacement of Right Radial Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RC07Z" = "1" /* Replacement of Left Radial Artery with Autologous Tissue Substitute, Open Approach */
"03RC0JZ" = "1" /* Replacement of Left Radial Artery with Synthetic Substitute, Open Approach */
"03RC0KZ" = "1" /* Replacement of Left Radial Artery with Nonautologous Tissue Substitute, Open Approach */
"03RC47Z" = "1" /* Replacement of Left Radial Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RC4JZ" = "1" /* Replacement of Left Radial Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03RC4KZ" = "1" /* Replacement of Left Radial Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RD07Z" = "1" /* Replacement of Right Hand Artery with Autologous Tissue Substitute, Open Approach */
"03RD0JZ" = "1" /* Replacement of Right Hand Artery with Synthetic Substitute, Open Approach */
"03RD0KZ" = "1" /* Replacement of Right Hand Artery with Nonautologous Tissue Substitute, Open Approach */
"03RD47Z" = "1" /* Replacement of Right Hand Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RD4JZ" = "1" /* Replacement of Right Hand Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03RD4KZ" = "1" /* Replacement of Right Hand Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RF07Z" = "1" /* Replacement of Left Hand Artery with Autologous Tissue Substitute, Open Approach */
"03RF0JZ" = "1" /* Replacement of Left Hand Artery with Synthetic Substitute, Open Approach */
"03RF0KZ" = "1" /* Replacement of Left Hand Artery with Nonautologous Tissue Substitute, Open Approach */
"03RF47Z" = "1" /* Replacement of Left Hand Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RF4JZ" = "1" /* Replacement of Left Hand Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03RF4KZ" = "1" /* Replacement of Left Hand Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RG07Z" = "1" /* Replacement of Intracranial Artery with Autologous Tissue Substitute, Open Approach */
"03RG0JZ" = "1" /* Replacement of Intracranial Artery with Synthetic Substitute, Open Approach */
"03RG0KZ" = "1" /* Replacement of Intracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"03RG47Z" = "1" /* Replacement of Intracranial Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RG4JZ" = "1" /* Replacement of Intracranial Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03RG4KZ" = "1" /* Replacement of Intracranial Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RH07Z" = "1" /* Replacement of Right Common Carotid Artery with Autologous Tissue Substitute, Open Approach */
"03RH0JZ" = "1" /* Replacement of Right Common Carotid Artery with Synthetic Substitute, Open Approach */
"03RH0KZ" = "1" /* Replacement of Right Common Carotid Artery with Nonautologous Tissue Substitute, Open Approach */
"03RH47Z" = "1" /* Replacement of Right Common Carotid Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RH4JZ" = "1" /* Replacement of Right Common Carotid Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03RH4KZ" = "1" /* Replacement of Right Common Carotid Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RJ07Z" = "1" /* Replacement of Left Common Carotid Artery with Autologous Tissue Substitute, Open Approach */
"03RJ0JZ" = "1" /* Replacement of Left Common Carotid Artery with Synthetic Substitute, Open Approach */
"03RJ0KZ" = "1" /* Replacement of Left Common Carotid Artery with Nonautologous Tissue Substitute, Open Approach */
"03RJ47Z" = "1" /* Replacement of Left Common Carotid Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RJ4JZ" = "1" /* Replacement of Left Common Carotid Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03RJ4KZ" = "1" /* Replacement of Left Common Carotid Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RK07Z" = "1" /* Replacement of Right Internal Carotid Artery with Autologous Tissue Substitute, Open Approach */
"03RK0JZ" = "1" /* Replacement of Right Internal Carotid Artery with Synthetic Substitute, Open Approach */
"03RK0KZ" = "1" /* Replacement of Right Internal Carotid Artery with Nonautologous Tissue Substitute, Open Approach */
"03RK47Z" = "1" /* Replacement of Right Internal Carotid Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RK4JZ" = "1" /* Replacement of Right Internal Carotid Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03RK4KZ" = "1" /* Replacement of Right Internal Carotid Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RL07Z" = "1" /* Replacement of Left Internal Carotid Artery with Autologous Tissue Substitute, Open Approach */
"03RL0JZ" = "1" /* Replacement of Left Internal Carotid Artery with Synthetic Substitute, Open Approach */
"03RL0KZ" = "1" /* Replacement of Left Internal Carotid Artery with Nonautologous Tissue Substitute, Open Approach */
"03RL47Z" = "1" /* Replacement of Left Internal Carotid Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RL4JZ" = "1" /* Replacement of Left Internal Carotid Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03RL4KZ" = "1" /* Replacement of Left Internal Carotid Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RM07Z" = "1" /* Replacement of Right External Carotid Artery with Autologous Tissue Substitute, Open Approach */
"03RM0JZ" = "1" /* Replacement of Right External Carotid Artery with Synthetic Substitute, Open Approach */
"03RM0KZ" = "1" /* Replacement of Right External Carotid Artery with Nonautologous Tissue Substitute, Open Approach */
"03RM47Z" = "1" /* Replacement of Right External Carotid Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RM4JZ" = "1" /* Replacement of Right External Carotid Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03RM4KZ" = "1" /* Replacement of Right External Carotid Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RN07Z" = "1" /* Replacement of Left External Carotid Artery with Autologous Tissue Substitute, Open Approach */
"03RN0JZ" = "1" /* Replacement of Left External Carotid Artery with Synthetic Substitute, Open Approach */
"03RN0KZ" = "1" /* Replacement of Left External Carotid Artery with Nonautologous Tissue Substitute, Open Approach */
"03RN47Z" = "1" /* Replacement of Left External Carotid Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RN4JZ" = "1" /* Replacement of Left External Carotid Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03RN4KZ" = "1" /* Replacement of Left External Carotid Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RP07Z" = "1" /* Replacement of Right Vertebral Artery with Autologous Tissue Substitute, Open Approach */
"03RP0JZ" = "1" /* Replacement of Right Vertebral Artery with Synthetic Substitute, Open Approach */
"03RP0KZ" = "1" /* Replacement of Right Vertebral Artery with Nonautologous Tissue Substitute, Open Approach */
"03RP47Z" = "1" /* Replacement of Right Vertebral Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RP4JZ" = "1" /* Replacement of Right Vertebral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03RP4KZ" = "1" /* Replacement of Right Vertebral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RQ07Z" = "1" /* Replacement of Left Vertebral Artery with Autologous Tissue Substitute, Open Approach */
"03RQ0JZ" = "1" /* Replacement of Left Vertebral Artery with Synthetic Substitute, Open Approach */
"03RQ0KZ" = "1" /* Replacement of Left Vertebral Artery with Nonautologous Tissue Substitute, Open Approach */
"03RQ47Z" = "1" /* Replacement of Left Vertebral Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RQ4JZ" = "1" /* Replacement of Left Vertebral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03RQ4KZ" = "1" /* Replacement of Left Vertebral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RR07Z" = "1" /* Replacement of Face Artery with Autologous Tissue Substitute, Open Approach */
"03RR0JZ" = "1" /* Replacement of Face Artery with Synthetic Substitute, Open Approach */
"03RR0KZ" = "1" /* Replacement of Face Artery with Nonautologous Tissue Substitute, Open Approach */
"03RR47Z" = "1" /* Replacement of Face Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RR4JZ" = "1" /* Replacement of Face Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03RR4KZ" = "1" /* Replacement of Face Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RS07Z" = "1" /* Replacement of Right Temporal Artery with Autologous Tissue Substitute, Open Approach */
"03RS0JZ" = "1" /* Replacement of Right Temporal Artery with Synthetic Substitute, Open Approach */
"03RS0KZ" = "1" /* Replacement of Right Temporal Artery with Nonautologous Tissue Substitute, Open Approach */
"03RS47Z" = "1" /* Replacement of Right Temporal Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RS4JZ" = "1" /* Replacement of Right Temporal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03RS4KZ" = "1" /* Replacement of Right Temporal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RT07Z" = "1" /* Replacement of Left Temporal Artery with Autologous Tissue Substitute, Open Approach */
"03RT0JZ" = "1" /* Replacement of Left Temporal Artery with Synthetic Substitute, Open Approach */
"03RT0KZ" = "1" /* Replacement of Left Temporal Artery with Nonautologous Tissue Substitute, Open Approach */
"03RT47Z" = "1" /* Replacement of Left Temporal Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RT4JZ" = "1" /* Replacement of Left Temporal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03RT4KZ" = "1" /* Replacement of Left Temporal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RU07Z" = "1" /* Replacement of Right Thyroid Artery with Autologous Tissue Substitute, Open Approach */
"03RU0JZ" = "1" /* Replacement of Right Thyroid Artery with Synthetic Substitute, Open Approach */
"03RU0KZ" = "1" /* Replacement of Right Thyroid Artery with Nonautologous Tissue Substitute, Open Approach */
"03RU47Z" = "1" /* Replacement of Right Thyroid Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RU4JZ" = "1" /* Replacement of Right Thyroid Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03RU4KZ" = "1" /* Replacement of Right Thyroid Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RV07Z" = "1" /* Replacement of Left Thyroid Artery with Autologous Tissue Substitute, Open Approach */
"03RV0JZ" = "1" /* Replacement of Left Thyroid Artery with Synthetic Substitute, Open Approach */
"03RV0KZ" = "1" /* Replacement of Left Thyroid Artery with Nonautologous Tissue Substitute, Open Approach */
"03RV47Z" = "1" /* Replacement of Left Thyroid Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RV4JZ" = "1" /* Replacement of Left Thyroid Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03RV4KZ" = "1" /* Replacement of Left Thyroid Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RY07Z" = "1" /* Replacement of Upper Artery with Autologous Tissue Substitute, Open Approach */
"03RY0JZ" = "1" /* Replacement of Upper Artery with Synthetic Substitute, Open Approach */
"03RY0KZ" = "1" /* Replacement of Upper Artery with Nonautologous Tissue Substitute, Open Approach */
"03RY47Z" = "1" /* Replacement of Upper Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03RY4JZ" = "1" /* Replacement of Upper Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03RY4KZ" = "1" /* Replacement of Upper Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03S00ZZ" = "1" /* Reposition Right Internal Mammary Artery, Open Approach */
"03S03ZZ" = "1" /* Reposition Right Internal Mammary Artery, Percutaneous Approach */
"03S04ZZ" = "1" /* Reposition Right Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03S10ZZ" = "1" /* Reposition Left Internal Mammary Artery, Open Approach */
"03S13ZZ" = "1" /* Reposition Left Internal Mammary Artery, Percutaneous Approach */
"03S14ZZ" = "1" /* Reposition Left Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03S20ZZ" = "1" /* Reposition Innominate Artery, Open Approach */
"03S23ZZ" = "1" /* Reposition Innominate Artery, Percutaneous Approach */
"03S24ZZ" = "1" /* Reposition Innominate Artery, Percutaneous Endoscopic Approach */
"03S30ZZ" = "1" /* Reposition Right Subclavian Artery, Open Approach */
"03S33ZZ" = "1" /* Reposition Right Subclavian Artery, Percutaneous Approach */
"03S34ZZ" = "1" /* Reposition Right Subclavian Artery, Percutaneous Endoscopic Approach */
"03S40ZZ" = "1" /* Reposition Left Subclavian Artery, Open Approach */
"03S43ZZ" = "1" /* Reposition Left Subclavian Artery, Percutaneous Approach */
"03S44ZZ" = "1" /* Reposition Left Subclavian Artery, Percutaneous Endoscopic Approach */
"03S50ZZ" = "1" /* Reposition Right Axillary Artery, Open Approach */
"03S53ZZ" = "1" /* Reposition Right Axillary Artery, Percutaneous Approach */
"03S54ZZ" = "1" /* Reposition Right Axillary Artery, Percutaneous Endoscopic Approach */
"03S60ZZ" = "1" /* Reposition Left Axillary Artery, Open Approach */
"03S63ZZ" = "1" /* Reposition Left Axillary Artery, Percutaneous Approach */
"03S64ZZ" = "1" /* Reposition Left Axillary Artery, Percutaneous Endoscopic Approach */
"03S70ZZ" = "1" /* Reposition Right Brachial Artery, Open Approach */
"03S73ZZ" = "1" /* Reposition Right Brachial Artery, Percutaneous Approach */
"03S74ZZ" = "1" /* Reposition Right Brachial Artery, Percutaneous Endoscopic Approach */
"03S80ZZ" = "1" /* Reposition Left Brachial Artery, Open Approach */
"03S83ZZ" = "1" /* Reposition Left Brachial Artery, Percutaneous Approach */
"03S84ZZ" = "1" /* Reposition Left Brachial Artery, Percutaneous Endoscopic Approach */
"03S90ZZ" = "1" /* Reposition Right Ulnar Artery, Open Approach */
"03S93ZZ" = "1" /* Reposition Right Ulnar Artery, Percutaneous Approach */
"03S94ZZ" = "1" /* Reposition Right Ulnar Artery, Percutaneous Endoscopic Approach */
"03SA0ZZ" = "1" /* Reposition Left Ulnar Artery, Open Approach */
"03SA3ZZ" = "1" /* Reposition Left Ulnar Artery, Percutaneous Approach */
"03SA4ZZ" = "1" /* Reposition Left Ulnar Artery, Percutaneous Endoscopic Approach */
"03SB0ZZ" = "1" /* Reposition Right Radial Artery, Open Approach */
"03SB3ZZ" = "1" /* Reposition Right Radial Artery, Percutaneous Approach */
"03SB4ZZ" = "1" /* Reposition Right Radial Artery, Percutaneous Endoscopic Approach */
"03SC0ZZ" = "1" /* Reposition Left Radial Artery, Open Approach */
"03SC3ZZ" = "1" /* Reposition Left Radial Artery, Percutaneous Approach */
"03SC4ZZ" = "1" /* Reposition Left Radial Artery, Percutaneous Endoscopic Approach */
"03SD0ZZ" = "1" /* Reposition Right Hand Artery, Open Approach */
"03SD3ZZ" = "1" /* Reposition Right Hand Artery, Percutaneous Approach */
"03SD4ZZ" = "1" /* Reposition Right Hand Artery, Percutaneous Endoscopic Approach */
"03SF0ZZ" = "1" /* Reposition Left Hand Artery, Open Approach */
"03SF3ZZ" = "1" /* Reposition Left Hand Artery, Percutaneous Approach */
"03SF4ZZ" = "1" /* Reposition Left Hand Artery, Percutaneous Endoscopic Approach */
"03SG0ZZ" = "1" /* Reposition Intracranial Artery, Open Approach */
"03SG3ZZ" = "1" /* Reposition Intracranial Artery, Percutaneous Approach */
"03SG4ZZ" = "1" /* Reposition Intracranial Artery, Percutaneous Endoscopic Approach */
"03SH0ZZ" = "1" /* Reposition Right Common Carotid Artery, Open Approach */
"03SH3ZZ" = "1" /* Reposition Right Common Carotid Artery, Percutaneous Approach */
"03SH4ZZ" = "1" /* Reposition Right Common Carotid Artery, Percutaneous Endoscopic Approach */
"03SJ0ZZ" = "1" /* Reposition Left Common Carotid Artery, Open Approach */
"03SJ3ZZ" = "1" /* Reposition Left Common Carotid Artery, Percutaneous Approach */
"03SJ4ZZ" = "1" /* Reposition Left Common Carotid Artery, Percutaneous Endoscopic Approach */
"03SK0ZZ" = "1" /* Reposition Right Internal Carotid Artery, Open Approach */
"03SK3ZZ" = "1" /* Reposition Right Internal Carotid Artery, Percutaneous Approach */
"03SK4ZZ" = "1" /* Reposition Right Internal Carotid Artery, Percutaneous Endoscopic Approach */
"03SL0ZZ" = "1" /* Reposition Left Internal Carotid Artery, Open Approach */
"03SL3ZZ" = "1" /* Reposition Left Internal Carotid Artery, Percutaneous Approach */
"03SL4ZZ" = "1" /* Reposition Left Internal Carotid Artery, Percutaneous Endoscopic Approach */
"03SM0ZZ" = "1" /* Reposition Right External Carotid Artery, Open Approach */
"03SM3ZZ" = "1" /* Reposition Right External Carotid Artery, Percutaneous Approach */
"03SM4ZZ" = "1" /* Reposition Right External Carotid Artery, Percutaneous Endoscopic Approach */
"03SN0ZZ" = "1" /* Reposition Left External Carotid Artery, Open Approach */
"03SN3ZZ" = "1" /* Reposition Left External Carotid Artery, Percutaneous Approach */
"03SN4ZZ" = "1" /* Reposition Left External Carotid Artery, Percutaneous Endoscopic Approach */
"03SP0ZZ" = "1" /* Reposition Right Vertebral Artery, Open Approach */
"03SP3ZZ" = "1" /* Reposition Right Vertebral Artery, Percutaneous Approach */
"03SP4ZZ" = "1" /* Reposition Right Vertebral Artery, Percutaneous Endoscopic Approach */
"03SQ0ZZ" = "1" /* Reposition Left Vertebral Artery, Open Approach */
"03SQ3ZZ" = "1" /* Reposition Left Vertebral Artery, Percutaneous Approach */
"03SQ4ZZ" = "1" /* Reposition Left Vertebral Artery, Percutaneous Endoscopic Approach */
"03SR0ZZ" = "1" /* Reposition Face Artery, Open Approach */
"03SR3ZZ" = "1" /* Reposition Face Artery, Percutaneous Approach */
"03SR4ZZ" = "1" /* Reposition Face Artery, Percutaneous Endoscopic Approach */
"03SS0ZZ" = "1" /* Reposition Right Temporal Artery, Open Approach */
"03SS3ZZ" = "1" /* Reposition Right Temporal Artery, Percutaneous Approach */
"03SS4ZZ" = "1" /* Reposition Right Temporal Artery, Percutaneous Endoscopic Approach */
"03ST0ZZ" = "1" /* Reposition Left Temporal Artery, Open Approach */
"03ST3ZZ" = "1" /* Reposition Left Temporal Artery, Percutaneous Approach */
"03ST4ZZ" = "1" /* Reposition Left Temporal Artery, Percutaneous Endoscopic Approach */
"03SU0ZZ" = "1" /* Reposition Right Thyroid Artery, Open Approach */
"03SU3ZZ" = "1" /* Reposition Right Thyroid Artery, Percutaneous Approach */
"03SU4ZZ" = "1" /* Reposition Right Thyroid Artery, Percutaneous Endoscopic Approach */
"03SV0ZZ" = "1" /* Reposition Left Thyroid Artery, Open Approach */
"03SV3ZZ" = "1" /* Reposition Left Thyroid Artery, Percutaneous Approach */
"03SV4ZZ" = "1" /* Reposition Left Thyroid Artery, Percutaneous Endoscopic Approach */
"03SY0ZZ" = "1" /* Reposition Upper Artery, Open Approach */
"03SY3ZZ" = "1" /* Reposition Upper Artery, Percutaneous Approach */
"03SY4ZZ" = "1" /* Reposition Upper Artery, Percutaneous Endoscopic Approach */
"03U007Z" = "1" /* Supplement Right Internal Mammary Artery with Autologous Tissue Substitute, Open Approach */
"03U00JZ" = "1" /* Supplement Right Internal Mammary Artery with Synthetic Substitute, Open Approach */
"03U00KZ" = "1" /* Supplement Right Internal Mammary Artery with Nonautologous Tissue Substitute, Open Approach */
"03U037Z" = "1" /* Supplement Right Internal Mammary Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03U03JZ" = "1" /* Supplement Right Internal Mammary Artery with Synthetic Substitute, Percutaneous Approach */
"03U03KZ" = "1" /* Supplement Right Internal Mammary Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03U047Z" = "1" /* Supplement Right Internal Mammary Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03U04JZ" = "1" /* Supplement Right Internal Mammary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03U04KZ" = "1" /* Supplement Right Internal Mammary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03U107Z" = "1" /* Supplement Left Internal Mammary Artery with Autologous Tissue Substitute, Open Approach */
"03U10JZ" = "1" /* Supplement Left Internal Mammary Artery with Synthetic Substitute, Open Approach */
"03U10KZ" = "1" /* Supplement Left Internal Mammary Artery with Nonautologous Tissue Substitute, Open Approach */
"03U137Z" = "1" /* Supplement Left Internal Mammary Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03U13JZ" = "1" /* Supplement Left Internal Mammary Artery with Synthetic Substitute, Percutaneous Approach */
"03U13KZ" = "1" /* Supplement Left Internal Mammary Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03U147Z" = "1" /* Supplement Left Internal Mammary Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03U14JZ" = "1" /* Supplement Left Internal Mammary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03U14KZ" = "1" /* Supplement Left Internal Mammary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03U207Z" = "1" /* Supplement Innominate Artery with Autologous Tissue Substitute, Open Approach */
"03U20JZ" = "1" /* Supplement Innominate Artery with Synthetic Substitute, Open Approach */
"03U20KZ" = "1" /* Supplement Innominate Artery with Nonautologous Tissue Substitute, Open Approach */
"03U237Z" = "1" /* Supplement Innominate Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03U23JZ" = "1" /* Supplement Innominate Artery with Synthetic Substitute, Percutaneous Approach */
"03U23KZ" = "1" /* Supplement Innominate Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03U247Z" = "1" /* Supplement Innominate Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03U24JZ" = "1" /* Supplement Innominate Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03U24KZ" = "1" /* Supplement Innominate Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03U307Z" = "1" /* Supplement Right Subclavian Artery with Autologous Tissue Substitute, Open Approach */
"03U30JZ" = "1" /* Supplement Right Subclavian Artery with Synthetic Substitute, Open Approach */
"03U30KZ" = "1" /* Supplement Right Subclavian Artery with Nonautologous Tissue Substitute, Open Approach */
"03U337Z" = "1" /* Supplement Right Subclavian Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03U33JZ" = "1" /* Supplement Right Subclavian Artery with Synthetic Substitute, Percutaneous Approach */
"03U33KZ" = "1" /* Supplement Right Subclavian Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03U347Z" = "1" /* Supplement Right Subclavian Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03U34JZ" = "1" /* Supplement Right Subclavian Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03U34KZ" = "1" /* Supplement Right Subclavian Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03U407Z" = "1" /* Supplement Left Subclavian Artery with Autologous Tissue Substitute, Open Approach */
"03U40JZ" = "1" /* Supplement Left Subclavian Artery with Synthetic Substitute, Open Approach */
"03U40KZ" = "1" /* Supplement Left Subclavian Artery with Nonautologous Tissue Substitute, Open Approach */
"03U437Z" = "1" /* Supplement Left Subclavian Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03U43JZ" = "1" /* Supplement Left Subclavian Artery with Synthetic Substitute, Percutaneous Approach */
"03U43KZ" = "1" /* Supplement Left Subclavian Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03U447Z" = "1" /* Supplement Left Subclavian Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03U44JZ" = "1" /* Supplement Left Subclavian Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03U44KZ" = "1" /* Supplement Left Subclavian Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03U507Z" = "1" /* Supplement Right Axillary Artery with Autologous Tissue Substitute, Open Approach */
"03U50JZ" = "1" /* Supplement Right Axillary Artery with Synthetic Substitute, Open Approach */
"03U50KZ" = "1" /* Supplement Right Axillary Artery with Nonautologous Tissue Substitute, Open Approach */
"03U537Z" = "1" /* Supplement Right Axillary Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03U53JZ" = "1" /* Supplement Right Axillary Artery with Synthetic Substitute, Percutaneous Approach */
"03U53KZ" = "1" /* Supplement Right Axillary Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03U547Z" = "1" /* Supplement Right Axillary Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03U54JZ" = "1" /* Supplement Right Axillary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03U54KZ" = "1" /* Supplement Right Axillary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03U607Z" = "1" /* Supplement Left Axillary Artery with Autologous Tissue Substitute, Open Approach */
"03U60JZ" = "1" /* Supplement Left Axillary Artery with Synthetic Substitute, Open Approach */
"03U60KZ" = "1" /* Supplement Left Axillary Artery with Nonautologous Tissue Substitute, Open Approach */
"03U637Z" = "1" /* Supplement Left Axillary Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03U63JZ" = "1" /* Supplement Left Axillary Artery with Synthetic Substitute, Percutaneous Approach */
"03U63KZ" = "1" /* Supplement Left Axillary Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03U647Z" = "1" /* Supplement Left Axillary Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03U64JZ" = "1" /* Supplement Left Axillary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03U64KZ" = "1" /* Supplement Left Axillary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03U707Z" = "1" /* Supplement Right Brachial Artery with Autologous Tissue Substitute, Open Approach */
"03U70JZ" = "1" /* Supplement Right Brachial Artery with Synthetic Substitute, Open Approach */
"03U70KZ" = "1" /* Supplement Right Brachial Artery with Nonautologous Tissue Substitute, Open Approach */
"03U737Z" = "1" /* Supplement Right Brachial Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03U73JZ" = "1" /* Supplement Right Brachial Artery with Synthetic Substitute, Percutaneous Approach */
"03U73KZ" = "1" /* Supplement Right Brachial Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03U747Z" = "1" /* Supplement Right Brachial Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03U74JZ" = "1" /* Supplement Right Brachial Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03U74KZ" = "1" /* Supplement Right Brachial Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03U807Z" = "1" /* Supplement Left Brachial Artery with Autologous Tissue Substitute, Open Approach */
"03U80JZ" = "1" /* Supplement Left Brachial Artery with Synthetic Substitute, Open Approach */
"03U80KZ" = "1" /* Supplement Left Brachial Artery with Nonautologous Tissue Substitute, Open Approach */
"03U837Z" = "1" /* Supplement Left Brachial Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03U83JZ" = "1" /* Supplement Left Brachial Artery with Synthetic Substitute, Percutaneous Approach */
"03U83KZ" = "1" /* Supplement Left Brachial Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03U847Z" = "1" /* Supplement Left Brachial Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03U84JZ" = "1" /* Supplement Left Brachial Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03U84KZ" = "1" /* Supplement Left Brachial Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03U907Z" = "1" /* Supplement Right Ulnar Artery with Autologous Tissue Substitute, Open Approach */
"03U90JZ" = "1" /* Supplement Right Ulnar Artery with Synthetic Substitute, Open Approach */
"03U90KZ" = "1" /* Supplement Right Ulnar Artery with Nonautologous Tissue Substitute, Open Approach */
"03U937Z" = "1" /* Supplement Right Ulnar Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03U93JZ" = "1" /* Supplement Right Ulnar Artery with Synthetic Substitute, Percutaneous Approach */
"03U93KZ" = "1" /* Supplement Right Ulnar Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03U947Z" = "1" /* Supplement Right Ulnar Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03U94JZ" = "1" /* Supplement Right Ulnar Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03U94KZ" = "1" /* Supplement Right Ulnar Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UA07Z" = "1" /* Supplement Left Ulnar Artery with Autologous Tissue Substitute, Open Approach */
"03UA0JZ" = "1" /* Supplement Left Ulnar Artery with Synthetic Substitute, Open Approach */
"03UA0KZ" = "1" /* Supplement Left Ulnar Artery with Nonautologous Tissue Substitute, Open Approach */
"03UA37Z" = "1" /* Supplement Left Ulnar Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03UA3JZ" = "1" /* Supplement Left Ulnar Artery with Synthetic Substitute, Percutaneous Approach */
"03UA3KZ" = "1" /* Supplement Left Ulnar Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03UA47Z" = "1" /* Supplement Left Ulnar Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UA4JZ" = "1" /* Supplement Left Ulnar Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03UA4KZ" = "1" /* Supplement Left Ulnar Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UB07Z" = "1" /* Supplement Right Radial Artery with Autologous Tissue Substitute, Open Approach */
"03UB0JZ" = "1" /* Supplement Right Radial Artery with Synthetic Substitute, Open Approach */
"03UB0KZ" = "1" /* Supplement Right Radial Artery with Nonautologous Tissue Substitute, Open Approach */
"03UB37Z" = "1" /* Supplement Right Radial Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03UB3JZ" = "1" /* Supplement Right Radial Artery with Synthetic Substitute, Percutaneous Approach */
"03UB3KZ" = "1" /* Supplement Right Radial Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03UB47Z" = "1" /* Supplement Right Radial Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UB4JZ" = "1" /* Supplement Right Radial Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03UB4KZ" = "1" /* Supplement Right Radial Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UC07Z" = "1" /* Supplement Left Radial Artery with Autologous Tissue Substitute, Open Approach */
"03UC0JZ" = "1" /* Supplement Left Radial Artery with Synthetic Substitute, Open Approach */
"03UC0KZ" = "1" /* Supplement Left Radial Artery with Nonautologous Tissue Substitute, Open Approach */
"03UC37Z" = "1" /* Supplement Left Radial Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03UC3JZ" = "1" /* Supplement Left Radial Artery with Synthetic Substitute, Percutaneous Approach */
"03UC3KZ" = "1" /* Supplement Left Radial Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03UC47Z" = "1" /* Supplement Left Radial Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UC4JZ" = "1" /* Supplement Left Radial Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03UC4KZ" = "1" /* Supplement Left Radial Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UD07Z" = "1" /* Supplement Right Hand Artery with Autologous Tissue Substitute, Open Approach */
"03UD0JZ" = "1" /* Supplement Right Hand Artery with Synthetic Substitute, Open Approach */
"03UD0KZ" = "1" /* Supplement Right Hand Artery with Nonautologous Tissue Substitute, Open Approach */
"03UD37Z" = "1" /* Supplement Right Hand Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03UD3JZ" = "1" /* Supplement Right Hand Artery with Synthetic Substitute, Percutaneous Approach */
"03UD3KZ" = "1" /* Supplement Right Hand Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03UD47Z" = "1" /* Supplement Right Hand Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UD4JZ" = "1" /* Supplement Right Hand Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03UD4KZ" = "1" /* Supplement Right Hand Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UF07Z" = "1" /* Supplement Left Hand Artery with Autologous Tissue Substitute, Open Approach */
"03UF0JZ" = "1" /* Supplement Left Hand Artery with Synthetic Substitute, Open Approach */
"03UF0KZ" = "1" /* Supplement Left Hand Artery with Nonautologous Tissue Substitute, Open Approach */
"03UF37Z" = "1" /* Supplement Left Hand Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03UF3JZ" = "1" /* Supplement Left Hand Artery with Synthetic Substitute, Percutaneous Approach */
"03UF3KZ" = "1" /* Supplement Left Hand Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03UF47Z" = "1" /* Supplement Left Hand Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UF4JZ" = "1" /* Supplement Left Hand Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03UF4KZ" = "1" /* Supplement Left Hand Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UG07Z" = "1" /* Supplement Intracranial Artery with Autologous Tissue Substitute, Open Approach */
"03UG0JZ" = "1" /* Supplement Intracranial Artery with Synthetic Substitute, Open Approach */
"03UG0KZ" = "1" /* Supplement Intracranial Artery with Nonautologous Tissue Substitute, Open Approach */
"03UG37Z" = "1" /* Supplement Intracranial Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03UG3JZ" = "1" /* Supplement Intracranial Artery with Synthetic Substitute, Percutaneous Approach */
"03UG3KZ" = "1" /* Supplement Intracranial Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03UG47Z" = "1" /* Supplement Intracranial Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UG4JZ" = "1" /* Supplement Intracranial Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03UG4KZ" = "1" /* Supplement Intracranial Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UH07Z" = "1" /* Supplement Right Common Carotid Artery with Autologous Tissue Substitute, Open Approach */
"03UH0JZ" = "1" /* Supplement Right Common Carotid Artery with Synthetic Substitute, Open Approach */
"03UH0KZ" = "1" /* Supplement Right Common Carotid Artery with Nonautologous Tissue Substitute, Open Approach */
"03UH37Z" = "1" /* Supplement Right Common Carotid Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03UH3JZ" = "1" /* Supplement Right Common Carotid Artery with Synthetic Substitute, Percutaneous Approach */
"03UH3KZ" = "1" /* Supplement Right Common Carotid Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03UH47Z" = "1" /* Supplement Right Common Carotid Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UH4JZ" = "1" /* Supplement Right Common Carotid Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03UH4KZ" = "1" /* Supplement Right Common Carotid Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UJ07Z" = "1" /* Supplement Left Common Carotid Artery with Autologous Tissue Substitute, Open Approach */
"03UJ0JZ" = "1" /* Supplement Left Common Carotid Artery with Synthetic Substitute, Open Approach */
"03UJ0KZ" = "1" /* Supplement Left Common Carotid Artery with Nonautologous Tissue Substitute, Open Approach */
"03UJ37Z" = "1" /* Supplement Left Common Carotid Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03UJ3JZ" = "1" /* Supplement Left Common Carotid Artery with Synthetic Substitute, Percutaneous Approach */
"03UJ3KZ" = "1" /* Supplement Left Common Carotid Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03UJ47Z" = "1" /* Supplement Left Common Carotid Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UJ4JZ" = "1" /* Supplement Left Common Carotid Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03UJ4KZ" = "1" /* Supplement Left Common Carotid Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UK07Z" = "1" /* Supplement Right Internal Carotid Artery with Autologous Tissue Substitute, Open Approach */
"03UK0JZ" = "1" /* Supplement Right Internal Carotid Artery with Synthetic Substitute, Open Approach */
"03UK0KZ" = "1" /* Supplement Right Internal Carotid Artery with Nonautologous Tissue Substitute, Open Approach */
"03UK37Z" = "1" /* Supplement Right Internal Carotid Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03UK3JZ" = "1" /* Supplement Right Internal Carotid Artery with Synthetic Substitute, Percutaneous Approach */
"03UK3KZ" = "1" /* Supplement Right Internal Carotid Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03UK47Z" = "1" /* Supplement Right Internal Carotid Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UK4JZ" = "1" /* Supplement Right Internal Carotid Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03UK4KZ" = "1" /* Supplement Right Internal Carotid Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UL07Z" = "1" /* Supplement Left Internal Carotid Artery with Autologous Tissue Substitute, Open Approach */
"03UL0JZ" = "1" /* Supplement Left Internal Carotid Artery with Synthetic Substitute, Open Approach */
"03UL0KZ" = "1" /* Supplement Left Internal Carotid Artery with Nonautologous Tissue Substitute, Open Approach */
"03UL37Z" = "1" /* Supplement Left Internal Carotid Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03UL3JZ" = "1" /* Supplement Left Internal Carotid Artery with Synthetic Substitute, Percutaneous Approach */
"03UL3KZ" = "1" /* Supplement Left Internal Carotid Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03UL47Z" = "1" /* Supplement Left Internal Carotid Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UL4JZ" = "1" /* Supplement Left Internal Carotid Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03UL4KZ" = "1" /* Supplement Left Internal Carotid Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UM07Z" = "1" /* Supplement Right External Carotid Artery with Autologous Tissue Substitute, Open Approach */
"03UM0JZ" = "1" /* Supplement Right External Carotid Artery with Synthetic Substitute, Open Approach */
"03UM0KZ" = "1" /* Supplement Right External Carotid Artery with Nonautologous Tissue Substitute, Open Approach */
"03UM37Z" = "1" /* Supplement Right External Carotid Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03UM3JZ" = "1" /* Supplement Right External Carotid Artery with Synthetic Substitute, Percutaneous Approach */
"03UM3KZ" = "1" /* Supplement Right External Carotid Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03UM47Z" = "1" /* Supplement Right External Carotid Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UM4JZ" = "1" /* Supplement Right External Carotid Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03UM4KZ" = "1" /* Supplement Right External Carotid Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UN07Z" = "1" /* Supplement Left External Carotid Artery with Autologous Tissue Substitute, Open Approach */
"03UN0JZ" = "1" /* Supplement Left External Carotid Artery with Synthetic Substitute, Open Approach */
"03UN0KZ" = "1" /* Supplement Left External Carotid Artery with Nonautologous Tissue Substitute, Open Approach */
"03UN37Z" = "1" /* Supplement Left External Carotid Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03UN3JZ" = "1" /* Supplement Left External Carotid Artery with Synthetic Substitute, Percutaneous Approach */
"03UN3KZ" = "1" /* Supplement Left External Carotid Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03UN47Z" = "1" /* Supplement Left External Carotid Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UN4JZ" = "1" /* Supplement Left External Carotid Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03UN4KZ" = "1" /* Supplement Left External Carotid Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UP07Z" = "1" /* Supplement Right Vertebral Artery with Autologous Tissue Substitute, Open Approach */
"03UP0JZ" = "1" /* Supplement Right Vertebral Artery with Synthetic Substitute, Open Approach */
"03UP0KZ" = "1" /* Supplement Right Vertebral Artery with Nonautologous Tissue Substitute, Open Approach */
"03UP37Z" = "1" /* Supplement Right Vertebral Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03UP3JZ" = "1" /* Supplement Right Vertebral Artery with Synthetic Substitute, Percutaneous Approach */
"03UP3KZ" = "1" /* Supplement Right Vertebral Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03UP47Z" = "1" /* Supplement Right Vertebral Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UP4JZ" = "1" /* Supplement Right Vertebral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03UP4KZ" = "1" /* Supplement Right Vertebral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UQ07Z" = "1" /* Supplement Left Vertebral Artery with Autologous Tissue Substitute, Open Approach */
"03UQ0JZ" = "1" /* Supplement Left Vertebral Artery with Synthetic Substitute, Open Approach */
"03UQ0KZ" = "1" /* Supplement Left Vertebral Artery with Nonautologous Tissue Substitute, Open Approach */
"03UQ37Z" = "1" /* Supplement Left Vertebral Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03UQ3JZ" = "1" /* Supplement Left Vertebral Artery with Synthetic Substitute, Percutaneous Approach */
"03UQ3KZ" = "1" /* Supplement Left Vertebral Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03UQ47Z" = "1" /* Supplement Left Vertebral Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UQ4JZ" = "1" /* Supplement Left Vertebral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03UQ4KZ" = "1" /* Supplement Left Vertebral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UR07Z" = "1" /* Supplement Face Artery with Autologous Tissue Substitute, Open Approach */
"03UR0JZ" = "1" /* Supplement Face Artery with Synthetic Substitute, Open Approach */
"03UR0KZ" = "1" /* Supplement Face Artery with Nonautologous Tissue Substitute, Open Approach */
"03UR37Z" = "1" /* Supplement Face Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03UR3JZ" = "1" /* Supplement Face Artery with Synthetic Substitute, Percutaneous Approach */
"03UR3KZ" = "1" /* Supplement Face Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03UR47Z" = "1" /* Supplement Face Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UR4JZ" = "1" /* Supplement Face Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03UR4KZ" = "1" /* Supplement Face Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03US07Z" = "1" /* Supplement Right Temporal Artery with Autologous Tissue Substitute, Open Approach */
"03US0JZ" = "1" /* Supplement Right Temporal Artery with Synthetic Substitute, Open Approach */
"03US0KZ" = "1" /* Supplement Right Temporal Artery with Nonautologous Tissue Substitute, Open Approach */
"03US37Z" = "1" /* Supplement Right Temporal Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03US3JZ" = "1" /* Supplement Right Temporal Artery with Synthetic Substitute, Percutaneous Approach */
"03US3KZ" = "1" /* Supplement Right Temporal Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03US47Z" = "1" /* Supplement Right Temporal Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03US4JZ" = "1" /* Supplement Right Temporal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03US4KZ" = "1" /* Supplement Right Temporal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UT07Z" = "1" /* Supplement Left Temporal Artery with Autologous Tissue Substitute, Open Approach */
"03UT0JZ" = "1" /* Supplement Left Temporal Artery with Synthetic Substitute, Open Approach */
"03UT0KZ" = "1" /* Supplement Left Temporal Artery with Nonautologous Tissue Substitute, Open Approach */
"03UT37Z" = "1" /* Supplement Left Temporal Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03UT3JZ" = "1" /* Supplement Left Temporal Artery with Synthetic Substitute, Percutaneous Approach */
"03UT3KZ" = "1" /* Supplement Left Temporal Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03UT47Z" = "1" /* Supplement Left Temporal Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UT4JZ" = "1" /* Supplement Left Temporal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03UT4KZ" = "1" /* Supplement Left Temporal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UU07Z" = "1" /* Supplement Right Thyroid Artery with Autologous Tissue Substitute, Open Approach */
"03UU0JZ" = "1" /* Supplement Right Thyroid Artery with Synthetic Substitute, Open Approach */
"03UU0KZ" = "1" /* Supplement Right Thyroid Artery with Nonautologous Tissue Substitute, Open Approach */
"03UU37Z" = "1" /* Supplement Right Thyroid Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03UU3JZ" = "1" /* Supplement Right Thyroid Artery with Synthetic Substitute, Percutaneous Approach */
"03UU3KZ" = "1" /* Supplement Right Thyroid Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03UU47Z" = "1" /* Supplement Right Thyroid Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UU4JZ" = "1" /* Supplement Right Thyroid Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03UU4KZ" = "1" /* Supplement Right Thyroid Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UV07Z" = "1" /* Supplement Left Thyroid Artery with Autologous Tissue Substitute, Open Approach */
"03UV0JZ" = "1" /* Supplement Left Thyroid Artery with Synthetic Substitute, Open Approach */
"03UV0KZ" = "1" /* Supplement Left Thyroid Artery with Nonautologous Tissue Substitute, Open Approach */
"03UV37Z" = "1" /* Supplement Left Thyroid Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03UV3JZ" = "1" /* Supplement Left Thyroid Artery with Synthetic Substitute, Percutaneous Approach */
"03UV3KZ" = "1" /* Supplement Left Thyroid Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03UV47Z" = "1" /* Supplement Left Thyroid Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UV4JZ" = "1" /* Supplement Left Thyroid Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03UV4KZ" = "1" /* Supplement Left Thyroid Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UY07Z" = "1" /* Supplement Upper Artery with Autologous Tissue Substitute, Open Approach */
"03UY0JZ" = "1" /* Supplement Upper Artery with Synthetic Substitute, Open Approach */
"03UY0KZ" = "1" /* Supplement Upper Artery with Nonautologous Tissue Substitute, Open Approach */
"03UY37Z" = "1" /* Supplement Upper Artery with Autologous Tissue Substitute, Percutaneous Approach */
"03UY3JZ" = "1" /* Supplement Upper Artery with Synthetic Substitute, Percutaneous Approach */
"03UY3KZ" = "1" /* Supplement Upper Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"03UY47Z" = "1" /* Supplement Upper Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03UY4JZ" = "1" /* Supplement Upper Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"03UY4KZ" = "1" /* Supplement Upper Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"03V00CZ" = "1" /* Restriction of Right Internal Mammary Artery with Extraluminal Device, Open Approach */
"03V00DZ" = "1" /* Restriction of Right Internal Mammary Artery with Intraluminal Device, Open Approach */
"03V00ZZ" = "1" /* Restriction of Right Internal Mammary Artery, Open Approach */
"03V03CZ" = "1" /* Restriction of Right Internal Mammary Artery with Extraluminal Device, Percutaneous Approach */
"03V03DZ" = "1" /* Restriction of Right Internal Mammary Artery with Intraluminal Device, Percutaneous Approach */
"03V03ZZ" = "1" /* Restriction of Right Internal Mammary Artery, Percutaneous Approach */
"03V04CZ" = "1" /* Restriction of Right Internal Mammary Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03V04DZ" = "1" /* Restriction of Right Internal Mammary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03V04ZZ" = "1" /* Restriction of Right Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03V10CZ" = "1" /* Restriction of Left Internal Mammary Artery with Extraluminal Device, Open Approach */
"03V10DZ" = "1" /* Restriction of Left Internal Mammary Artery with Intraluminal Device, Open Approach */
"03V10ZZ" = "1" /* Restriction of Left Internal Mammary Artery, Open Approach */
"03V13CZ" = "1" /* Restriction of Left Internal Mammary Artery with Extraluminal Device, Percutaneous Approach */
"03V13DZ" = "1" /* Restriction of Left Internal Mammary Artery with Intraluminal Device, Percutaneous Approach */
"03V13ZZ" = "1" /* Restriction of Left Internal Mammary Artery, Percutaneous Approach */
"03V14CZ" = "1" /* Restriction of Left Internal Mammary Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03V14DZ" = "1" /* Restriction of Left Internal Mammary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03V14ZZ" = "1" /* Restriction of Left Internal Mammary Artery, Percutaneous Endoscopic Approach */
"03V20CZ" = "1" /* Restriction of Innominate Artery with Extraluminal Device, Open Approach */
"03V20DZ" = "1" /* Restriction of Innominate Artery with Intraluminal Device, Open Approach */
"03V20ZZ" = "1" /* Restriction of Innominate Artery, Open Approach */
"03V23CZ" = "1" /* Restriction of Innominate Artery with Extraluminal Device, Percutaneous Approach */
"03V23DZ" = "1" /* Restriction of Innominate Artery with Intraluminal Device, Percutaneous Approach */
"03V23ZZ" = "1" /* Restriction of Innominate Artery, Percutaneous Approach */
"03V24CZ" = "1" /* Restriction of Innominate Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03V24DZ" = "1" /* Restriction of Innominate Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03V24ZZ" = "1" /* Restriction of Innominate Artery, Percutaneous Endoscopic Approach */
"03V30CZ" = "1" /* Restriction of Right Subclavian Artery with Extraluminal Device, Open Approach */
"03V30DZ" = "1" /* Restriction of Right Subclavian Artery with Intraluminal Device, Open Approach */
"03V30ZZ" = "1" /* Restriction of Right Subclavian Artery, Open Approach */
"03V33CZ" = "1" /* Restriction of Right Subclavian Artery with Extraluminal Device, Percutaneous Approach */
"03V33DZ" = "1" /* Restriction of Right Subclavian Artery with Intraluminal Device, Percutaneous Approach */
"03V33ZZ" = "1" /* Restriction of Right Subclavian Artery, Percutaneous Approach */
"03V34CZ" = "1" /* Restriction of Right Subclavian Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03V34DZ" = "1" /* Restriction of Right Subclavian Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03V34ZZ" = "1" /* Restriction of Right Subclavian Artery, Percutaneous Endoscopic Approach */
"03V40CZ" = "1" /* Restriction of Left Subclavian Artery with Extraluminal Device, Open Approach */
"03V40DZ" = "1" /* Restriction of Left Subclavian Artery with Intraluminal Device, Open Approach */
"03V40ZZ" = "1" /* Restriction of Left Subclavian Artery, Open Approach */
"03V43CZ" = "1" /* Restriction of Left Subclavian Artery with Extraluminal Device, Percutaneous Approach */
"03V43DZ" = "1" /* Restriction of Left Subclavian Artery with Intraluminal Device, Percutaneous Approach */
"03V43ZZ" = "1" /* Restriction of Left Subclavian Artery, Percutaneous Approach */
"03V44CZ" = "1" /* Restriction of Left Subclavian Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03V44DZ" = "1" /* Restriction of Left Subclavian Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03V44ZZ" = "1" /* Restriction of Left Subclavian Artery, Percutaneous Endoscopic Approach */
"03V50CZ" = "1" /* Restriction of Right Axillary Artery with Extraluminal Device, Open Approach */
"03V50DZ" = "1" /* Restriction of Right Axillary Artery with Intraluminal Device, Open Approach */
"03V50ZZ" = "1" /* Restriction of Right Axillary Artery, Open Approach */
"03V53CZ" = "1" /* Restriction of Right Axillary Artery with Extraluminal Device, Percutaneous Approach */
"03V53DZ" = "1" /* Restriction of Right Axillary Artery with Intraluminal Device, Percutaneous Approach */
"03V53ZZ" = "1" /* Restriction of Right Axillary Artery, Percutaneous Approach */
"03V54CZ" = "1" /* Restriction of Right Axillary Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03V54DZ" = "1" /* Restriction of Right Axillary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03V54ZZ" = "1" /* Restriction of Right Axillary Artery, Percutaneous Endoscopic Approach */
"03V60CZ" = "1" /* Restriction of Left Axillary Artery with Extraluminal Device, Open Approach */
"03V60DZ" = "1" /* Restriction of Left Axillary Artery with Intraluminal Device, Open Approach */
"03V60ZZ" = "1" /* Restriction of Left Axillary Artery, Open Approach */
"03V63CZ" = "1" /* Restriction of Left Axillary Artery with Extraluminal Device, Percutaneous Approach */
"03V63DZ" = "1" /* Restriction of Left Axillary Artery with Intraluminal Device, Percutaneous Approach */
"03V63ZZ" = "1" /* Restriction of Left Axillary Artery, Percutaneous Approach */
"03V64CZ" = "1" /* Restriction of Left Axillary Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03V64DZ" = "1" /* Restriction of Left Axillary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03V64ZZ" = "1" /* Restriction of Left Axillary Artery, Percutaneous Endoscopic Approach */
"03V70CZ" = "1" /* Restriction of Right Brachial Artery with Extraluminal Device, Open Approach */
"03V70DZ" = "1" /* Restriction of Right Brachial Artery with Intraluminal Device, Open Approach */
"03V70ZZ" = "1" /* Restriction of Right Brachial Artery, Open Approach */
"03V73CZ" = "1" /* Restriction of Right Brachial Artery with Extraluminal Device, Percutaneous Approach */
"03V73DZ" = "1" /* Restriction of Right Brachial Artery with Intraluminal Device, Percutaneous Approach */
"03V73ZZ" = "1" /* Restriction of Right Brachial Artery, Percutaneous Approach */
"03V74CZ" = "1" /* Restriction of Right Brachial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03V74DZ" = "1" /* Restriction of Right Brachial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03V74ZZ" = "1" /* Restriction of Right Brachial Artery, Percutaneous Endoscopic Approach */
"03V80CZ" = "1" /* Restriction of Left Brachial Artery with Extraluminal Device, Open Approach */
"03V80DZ" = "1" /* Restriction of Left Brachial Artery with Intraluminal Device, Open Approach */
"03V80ZZ" = "1" /* Restriction of Left Brachial Artery, Open Approach */
"03V83CZ" = "1" /* Restriction of Left Brachial Artery with Extraluminal Device, Percutaneous Approach */
"03V83DZ" = "1" /* Restriction of Left Brachial Artery with Intraluminal Device, Percutaneous Approach */
"03V83ZZ" = "1" /* Restriction of Left Brachial Artery, Percutaneous Approach */
"03V84CZ" = "1" /* Restriction of Left Brachial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03V84DZ" = "1" /* Restriction of Left Brachial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03V84ZZ" = "1" /* Restriction of Left Brachial Artery, Percutaneous Endoscopic Approach */
"03V90CZ" = "1" /* Restriction of Right Ulnar Artery with Extraluminal Device, Open Approach */
"03V90DZ" = "1" /* Restriction of Right Ulnar Artery with Intraluminal Device, Open Approach */
"03V90ZZ" = "1" /* Restriction of Right Ulnar Artery, Open Approach */
"03V93CZ" = "1" /* Restriction of Right Ulnar Artery with Extraluminal Device, Percutaneous Approach */
"03V93DZ" = "1" /* Restriction of Right Ulnar Artery with Intraluminal Device, Percutaneous Approach */
"03V93ZZ" = "1" /* Restriction of Right Ulnar Artery, Percutaneous Approach */
"03V94CZ" = "1" /* Restriction of Right Ulnar Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03V94DZ" = "1" /* Restriction of Right Ulnar Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03V94ZZ" = "1" /* Restriction of Right Ulnar Artery, Percutaneous Endoscopic Approach */
"03VA0CZ" = "1" /* Restriction of Left Ulnar Artery with Extraluminal Device, Open Approach */
"03VA0DZ" = "1" /* Restriction of Left Ulnar Artery with Intraluminal Device, Open Approach */
"03VA0ZZ" = "1" /* Restriction of Left Ulnar Artery, Open Approach */
"03VA3CZ" = "1" /* Restriction of Left Ulnar Artery with Extraluminal Device, Percutaneous Approach */
"03VA3DZ" = "1" /* Restriction of Left Ulnar Artery with Intraluminal Device, Percutaneous Approach */
"03VA3ZZ" = "1" /* Restriction of Left Ulnar Artery, Percutaneous Approach */
"03VA4CZ" = "1" /* Restriction of Left Ulnar Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03VA4DZ" = "1" /* Restriction of Left Ulnar Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VA4ZZ" = "1" /* Restriction of Left Ulnar Artery, Percutaneous Endoscopic Approach */
"03VB0CZ" = "1" /* Restriction of Right Radial Artery with Extraluminal Device, Open Approach */
"03VB0DZ" = "1" /* Restriction of Right Radial Artery with Intraluminal Device, Open Approach */
"03VB0ZZ" = "1" /* Restriction of Right Radial Artery, Open Approach */
"03VB3CZ" = "1" /* Restriction of Right Radial Artery with Extraluminal Device, Percutaneous Approach */
"03VB3DZ" = "1" /* Restriction of Right Radial Artery with Intraluminal Device, Percutaneous Approach */
"03VB3ZZ" = "1" /* Restriction of Right Radial Artery, Percutaneous Approach */
"03VB4CZ" = "1" /* Restriction of Right Radial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03VB4DZ" = "1" /* Restriction of Right Radial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VB4ZZ" = "1" /* Restriction of Right Radial Artery, Percutaneous Endoscopic Approach */
"03VC0CZ" = "1" /* Restriction of Left Radial Artery with Extraluminal Device, Open Approach */
"03VC0DZ" = "1" /* Restriction of Left Radial Artery with Intraluminal Device, Open Approach */
"03VC0ZZ" = "1" /* Restriction of Left Radial Artery, Open Approach */
"03VC3CZ" = "1" /* Restriction of Left Radial Artery with Extraluminal Device, Percutaneous Approach */
"03VC3DZ" = "1" /* Restriction of Left Radial Artery with Intraluminal Device, Percutaneous Approach */
"03VC3ZZ" = "1" /* Restriction of Left Radial Artery, Percutaneous Approach */
"03VC4CZ" = "1" /* Restriction of Left Radial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03VC4DZ" = "1" /* Restriction of Left Radial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VC4ZZ" = "1" /* Restriction of Left Radial Artery, Percutaneous Endoscopic Approach */
"03VD0CZ" = "1" /* Restriction of Right Hand Artery with Extraluminal Device, Open Approach */
"03VD0DZ" = "1" /* Restriction of Right Hand Artery with Intraluminal Device, Open Approach */
"03VD0ZZ" = "1" /* Restriction of Right Hand Artery, Open Approach */
"03VD3CZ" = "1" /* Restriction of Right Hand Artery with Extraluminal Device, Percutaneous Approach */
"03VD3DZ" = "1" /* Restriction of Right Hand Artery with Intraluminal Device, Percutaneous Approach */
"03VD3ZZ" = "1" /* Restriction of Right Hand Artery, Percutaneous Approach */
"03VD4CZ" = "1" /* Restriction of Right Hand Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03VD4DZ" = "1" /* Restriction of Right Hand Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VD4ZZ" = "1" /* Restriction of Right Hand Artery, Percutaneous Endoscopic Approach */
"03VF0CZ" = "1" /* Restriction of Left Hand Artery with Extraluminal Device, Open Approach */
"03VF0DZ" = "1" /* Restriction of Left Hand Artery with Intraluminal Device, Open Approach */
"03VF0ZZ" = "1" /* Restriction of Left Hand Artery, Open Approach */
"03VF3CZ" = "1" /* Restriction of Left Hand Artery with Extraluminal Device, Percutaneous Approach */
"03VF3DZ" = "1" /* Restriction of Left Hand Artery with Intraluminal Device, Percutaneous Approach */
"03VF3ZZ" = "1" /* Restriction of Left Hand Artery, Percutaneous Approach */
"03VF4CZ" = "1" /* Restriction of Left Hand Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03VF4DZ" = "1" /* Restriction of Left Hand Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VF4ZZ" = "1" /* Restriction of Left Hand Artery, Percutaneous Endoscopic Approach */
"03VG0BZ" = "1" /* Restriction of Intracranial Artery with Bioactive Intraluminal Device, Open Approach */
"03VG0CZ" = "1" /* Restriction of Intracranial Artery with Extraluminal Device, Open Approach */
"03VG0DZ" = "1" /* Restriction of Intracranial Artery with Intraluminal Device, Open Approach */
"03VG0ZZ" = "1" /* Restriction of Intracranial Artery, Open Approach */
"03VG3BZ" = "1" /* Restriction of Intracranial Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03VG3CZ" = "1" /* Restriction of Intracranial Artery with Extraluminal Device, Percutaneous Approach */
"03VG3DZ" = "1" /* Restriction of Intracranial Artery with Intraluminal Device, Percutaneous Approach */
"03VG3ZZ" = "1" /* Restriction of Intracranial Artery, Percutaneous Approach */
"03VG4BZ" = "1" /* Restriction of Intracranial Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03VG4CZ" = "1" /* Restriction of Intracranial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03VG4DZ" = "1" /* Restriction of Intracranial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VG4ZZ" = "1" /* Restriction of Intracranial Artery, Percutaneous Endoscopic Approach */
"03VH0BZ" = "1" /* Restriction of Right Common Carotid Artery with Bioactive Intraluminal Device, Open Approach */
"03VH0CZ" = "1" /* Restriction of Right Common Carotid Artery with Extraluminal Device, Open Approach */
"03VH0DZ" = "1" /* Restriction of Right Common Carotid Artery with Intraluminal Device, Open Approach */
"03VH0ZZ" = "1" /* Restriction of Right Common Carotid Artery, Open Approach */
"03VH3BZ" = "1" /* Restriction of Right Common Carotid Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03VH3CZ" = "1" /* Restriction of Right Common Carotid Artery with Extraluminal Device, Percutaneous Approach */
"03VH3DZ" = "1" /* Restriction of Right Common Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03VH3ZZ" = "1" /* Restriction of Right Common Carotid Artery, Percutaneous Approach */
"03VH4BZ" = "1" /* Restriction of Right Common Carotid Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03VH4CZ" = "1" /* Restriction of Right Common Carotid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03VH4DZ" = "1" /* Restriction of Right Common Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VH4ZZ" = "1" /* Restriction of Right Common Carotid Artery, Percutaneous Endoscopic Approach */
"03VJ0BZ" = "1" /* Restriction of Left Common Carotid Artery with Bioactive Intraluminal Device, Open Approach */
"03VJ0CZ" = "1" /* Restriction of Left Common Carotid Artery with Extraluminal Device, Open Approach */
"03VJ0DZ" = "1" /* Restriction of Left Common Carotid Artery with Intraluminal Device, Open Approach */
"03VJ0ZZ" = "1" /* Restriction of Left Common Carotid Artery, Open Approach */
"03VJ3BZ" = "1" /* Restriction of Left Common Carotid Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03VJ3CZ" = "1" /* Restriction of Left Common Carotid Artery with Extraluminal Device, Percutaneous Approach */
"03VJ3DZ" = "1" /* Restriction of Left Common Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03VJ3ZZ" = "1" /* Restriction of Left Common Carotid Artery, Percutaneous Approach */
"03VJ4BZ" = "1" /* Restriction of Left Common Carotid Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03VJ4CZ" = "1" /* Restriction of Left Common Carotid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03VJ4DZ" = "1" /* Restriction of Left Common Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VJ4ZZ" = "1" /* Restriction of Left Common Carotid Artery, Percutaneous Endoscopic Approach */
"03VK0BZ" = "1" /* Restriction of Right Internal Carotid Artery with Bioactive Intraluminal Device, Open Approach */
"03VK0CZ" = "1" /* Restriction of Right Internal Carotid Artery with Extraluminal Device, Open Approach */
"03VK0DZ" = "1" /* Restriction of Right Internal Carotid Artery with Intraluminal Device, Open Approach */
"03VK0ZZ" = "1" /* Restriction of Right Internal Carotid Artery, Open Approach */
"03VK3BZ" = "1" /* Restriction of Right Internal Carotid Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03VK3CZ" = "1" /* Restriction of Right Internal Carotid Artery with Extraluminal Device, Percutaneous Approach */
"03VK3DZ" = "1" /* Restriction of Right Internal Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03VK3ZZ" = "1" /* Restriction of Right Internal Carotid Artery, Percutaneous Approach */
"03VK4BZ" = "1" /* Restriction of Right Internal Carotid Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03VK4CZ" = "1" /* Restriction of Right Internal Carotid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03VK4DZ" = "1" /* Restriction of Right Internal Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VK4ZZ" = "1" /* Restriction of Right Internal Carotid Artery, Percutaneous Endoscopic Approach */
"03VL0BZ" = "1" /* Restriction of Left Internal Carotid Artery with Bioactive Intraluminal Device, Open Approach */
"03VL0CZ" = "1" /* Restriction of Left Internal Carotid Artery with Extraluminal Device, Open Approach */
"03VL0DZ" = "1" /* Restriction of Left Internal Carotid Artery with Intraluminal Device, Open Approach */
"03VL0ZZ" = "1" /* Restriction of Left Internal Carotid Artery, Open Approach */
"03VL3BZ" = "1" /* Restriction of Left Internal Carotid Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03VL3CZ" = "1" /* Restriction of Left Internal Carotid Artery with Extraluminal Device, Percutaneous Approach */
"03VL3DZ" = "1" /* Restriction of Left Internal Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03VL3ZZ" = "1" /* Restriction of Left Internal Carotid Artery, Percutaneous Approach */
"03VL4BZ" = "1" /* Restriction of Left Internal Carotid Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03VL4CZ" = "1" /* Restriction of Left Internal Carotid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03VL4DZ" = "1" /* Restriction of Left Internal Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VL4ZZ" = "1" /* Restriction of Left Internal Carotid Artery, Percutaneous Endoscopic Approach */
"03VM0BZ" = "1" /* Restriction of Right External Carotid Artery with Bioactive Intraluminal Device, Open Approach */
"03VM0CZ" = "1" /* Restriction of Right External Carotid Artery with Extraluminal Device, Open Approach */
"03VM0DZ" = "1" /* Restriction of Right External Carotid Artery with Intraluminal Device, Open Approach */
"03VM0ZZ" = "1" /* Restriction of Right External Carotid Artery, Open Approach */
"03VM3BZ" = "1" /* Restriction of Right External Carotid Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03VM3CZ" = "1" /* Restriction of Right External Carotid Artery with Extraluminal Device, Percutaneous Approach */
"03VM3DZ" = "1" /* Restriction of Right External Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03VM3ZZ" = "1" /* Restriction of Right External Carotid Artery, Percutaneous Approach */
"03VM4BZ" = "1" /* Restriction of Right External Carotid Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03VM4CZ" = "1" /* Restriction of Right External Carotid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03VM4DZ" = "1" /* Restriction of Right External Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VM4ZZ" = "1" /* Restriction of Right External Carotid Artery, Percutaneous Endoscopic Approach */
"03VN0BZ" = "1" /* Restriction of Left External Carotid Artery with Bioactive Intraluminal Device, Open Approach */
"03VN0CZ" = "1" /* Restriction of Left External Carotid Artery with Extraluminal Device, Open Approach */
"03VN0DZ" = "1" /* Restriction of Left External Carotid Artery with Intraluminal Device, Open Approach */
"03VN0ZZ" = "1" /* Restriction of Left External Carotid Artery, Open Approach */
"03VN3BZ" = "1" /* Restriction of Left External Carotid Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03VN3CZ" = "1" /* Restriction of Left External Carotid Artery with Extraluminal Device, Percutaneous Approach */
"03VN3DZ" = "1" /* Restriction of Left External Carotid Artery with Intraluminal Device, Percutaneous Approach */
"03VN3ZZ" = "1" /* Restriction of Left External Carotid Artery, Percutaneous Approach */
"03VN4BZ" = "1" /* Restriction of Left External Carotid Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03VN4CZ" = "1" /* Restriction of Left External Carotid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03VN4DZ" = "1" /* Restriction of Left External Carotid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VN4ZZ" = "1" /* Restriction of Left External Carotid Artery, Percutaneous Endoscopic Approach */
"03VP0BZ" = "1" /* Restriction of Right Vertebral Artery with Bioactive Intraluminal Device, Open Approach */
"03VP0CZ" = "1" /* Restriction of Right Vertebral Artery with Extraluminal Device, Open Approach */
"03VP0DZ" = "1" /* Restriction of Right Vertebral Artery with Intraluminal Device, Open Approach */
"03VP0ZZ" = "1" /* Restriction of Right Vertebral Artery, Open Approach */
"03VP3BZ" = "1" /* Restriction of Right Vertebral Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03VP3CZ" = "1" /* Restriction of Right Vertebral Artery with Extraluminal Device, Percutaneous Approach */
"03VP3DZ" = "1" /* Restriction of Right Vertebral Artery with Intraluminal Device, Percutaneous Approach */
"03VP3ZZ" = "1" /* Restriction of Right Vertebral Artery, Percutaneous Approach */
"03VP4BZ" = "1" /* Restriction of Right Vertebral Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03VP4CZ" = "1" /* Restriction of Right Vertebral Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03VP4DZ" = "1" /* Restriction of Right Vertebral Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VP4ZZ" = "1" /* Restriction of Right Vertebral Artery, Percutaneous Endoscopic Approach */
"03VQ0BZ" = "1" /* Restriction of Left Vertebral Artery with Bioactive Intraluminal Device, Open Approach */
"03VQ0CZ" = "1" /* Restriction of Left Vertebral Artery with Extraluminal Device, Open Approach */
"03VQ0DZ" = "1" /* Restriction of Left Vertebral Artery with Intraluminal Device, Open Approach */
"03VQ0ZZ" = "1" /* Restriction of Left Vertebral Artery, Open Approach */
"03VQ3BZ" = "1" /* Restriction of Left Vertebral Artery with Bioactive Intraluminal Device, Percutaneous Approach */
"03VQ3CZ" = "1" /* Restriction of Left Vertebral Artery with Extraluminal Device, Percutaneous Approach */
"03VQ3DZ" = "1" /* Restriction of Left Vertebral Artery with Intraluminal Device, Percutaneous Approach */
"03VQ3ZZ" = "1" /* Restriction of Left Vertebral Artery, Percutaneous Approach */
"03VQ4BZ" = "1" /* Restriction of Left Vertebral Artery with Bioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"03VQ4CZ" = "1" /* Restriction of Left Vertebral Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03VQ4DZ" = "1" /* Restriction of Left Vertebral Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VQ4ZZ" = "1" /* Restriction of Left Vertebral Artery, Percutaneous Endoscopic Approach */
"03VR0CZ" = "1" /* Restriction of Face Artery with Extraluminal Device, Open Approach */
"03VR0DZ" = "1" /* Restriction of Face Artery with Intraluminal Device, Open Approach */
"03VR0ZZ" = "1" /* Restriction of Face Artery, Open Approach */
"03VR3CZ" = "1" /* Restriction of Face Artery with Extraluminal Device, Percutaneous Approach */
"03VR3DZ" = "1" /* Restriction of Face Artery with Intraluminal Device, Percutaneous Approach */
"03VR3ZZ" = "1" /* Restriction of Face Artery, Percutaneous Approach */
"03VR4CZ" = "1" /* Restriction of Face Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03VR4DZ" = "1" /* Restriction of Face Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VR4ZZ" = "1" /* Restriction of Face Artery, Percutaneous Endoscopic Approach */
"03VS0CZ" = "1" /* Restriction of Right Temporal Artery with Extraluminal Device, Open Approach */
"03VS0DZ" = "1" /* Restriction of Right Temporal Artery with Intraluminal Device, Open Approach */
"03VS0ZZ" = "1" /* Restriction of Right Temporal Artery, Open Approach */
"03VS3CZ" = "1" /* Restriction of Right Temporal Artery with Extraluminal Device, Percutaneous Approach */
"03VS3DZ" = "1" /* Restriction of Right Temporal Artery with Intraluminal Device, Percutaneous Approach */
"03VS3ZZ" = "1" /* Restriction of Right Temporal Artery, Percutaneous Approach */
"03VS4CZ" = "1" /* Restriction of Right Temporal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03VS4DZ" = "1" /* Restriction of Right Temporal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VS4ZZ" = "1" /* Restriction of Right Temporal Artery, Percutaneous Endoscopic Approach */
"03VT0CZ" = "1" /* Restriction of Left Temporal Artery with Extraluminal Device, Open Approach */
"03VT0DZ" = "1" /* Restriction of Left Temporal Artery with Intraluminal Device, Open Approach */
"03VT0ZZ" = "1" /* Restriction of Left Temporal Artery, Open Approach */
"03VT3CZ" = "1" /* Restriction of Left Temporal Artery with Extraluminal Device, Percutaneous Approach */
"03VT3DZ" = "1" /* Restriction of Left Temporal Artery with Intraluminal Device, Percutaneous Approach */
"03VT3ZZ" = "1" /* Restriction of Left Temporal Artery, Percutaneous Approach */
"03VT4CZ" = "1" /* Restriction of Left Temporal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03VT4DZ" = "1" /* Restriction of Left Temporal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VT4ZZ" = "1" /* Restriction of Left Temporal Artery, Percutaneous Endoscopic Approach */
"03VU0CZ" = "1" /* Restriction of Right Thyroid Artery with Extraluminal Device, Open Approach */
"03VU0DZ" = "1" /* Restriction of Right Thyroid Artery with Intraluminal Device, Open Approach */
"03VU0ZZ" = "1" /* Restriction of Right Thyroid Artery, Open Approach */
"03VU3CZ" = "1" /* Restriction of Right Thyroid Artery with Extraluminal Device, Percutaneous Approach */
"03VU3DZ" = "1" /* Restriction of Right Thyroid Artery with Intraluminal Device, Percutaneous Approach */
"03VU3ZZ" = "1" /* Restriction of Right Thyroid Artery, Percutaneous Approach */
"03VU4CZ" = "1" /* Restriction of Right Thyroid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03VU4DZ" = "1" /* Restriction of Right Thyroid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VU4ZZ" = "1" /* Restriction of Right Thyroid Artery, Percutaneous Endoscopic Approach */
"03VV0CZ" = "1" /* Restriction of Left Thyroid Artery with Extraluminal Device, Open Approach */
"03VV0DZ" = "1" /* Restriction of Left Thyroid Artery with Intraluminal Device, Open Approach */
"03VV0ZZ" = "1" /* Restriction of Left Thyroid Artery, Open Approach */
"03VV3CZ" = "1" /* Restriction of Left Thyroid Artery with Extraluminal Device, Percutaneous Approach */
"03VV3DZ" = "1" /* Restriction of Left Thyroid Artery with Intraluminal Device, Percutaneous Approach */
"03VV3ZZ" = "1" /* Restriction of Left Thyroid Artery, Percutaneous Approach */
"03VV4CZ" = "1" /* Restriction of Left Thyroid Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03VV4DZ" = "1" /* Restriction of Left Thyroid Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VV4ZZ" = "1" /* Restriction of Left Thyroid Artery, Percutaneous Endoscopic Approach */
"03VY0CZ" = "1" /* Restriction of Upper Artery with Extraluminal Device, Open Approach */
"03VY0DZ" = "1" /* Restriction of Upper Artery with Intraluminal Device, Open Approach */
"03VY0ZZ" = "1" /* Restriction of Upper Artery, Open Approach */
"03VY3CZ" = "1" /* Restriction of Upper Artery with Extraluminal Device, Percutaneous Approach */
"03VY3DZ" = "1" /* Restriction of Upper Artery with Intraluminal Device, Percutaneous Approach */
"03VY3ZZ" = "1" /* Restriction of Upper Artery, Percutaneous Approach */
"03VY4CZ" = "1" /* Restriction of Upper Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"03VY4DZ" = "1" /* Restriction of Upper Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"03VY4ZZ" = "1" /* Restriction of Upper Artery, Percutaneous Endoscopic Approach */
"03WY00Z" = "1" /* Revision of Drainage Device in Upper Artery, Open Approach */
"03WY02Z" = "1" /* Revision of Monitoring Device in Upper Artery, Open Approach */
"03WY03Z" = "1" /* Revision of Infusion Device in Upper Artery, Open Approach */
"03WY07Z" = "1" /* Revision of Autologous Tissue Substitute in Upper Artery, Open Approach */
"03WY0CZ" = "1" /* Revision of Extraluminal Device in Upper Artery, Open Approach */
"03WY0DZ" = "1" /* Revision of Intraluminal Device in Upper Artery, Open Approach */
"03WY0JZ" = "1" /* Revision of Synthetic Substitute in Upper Artery, Open Approach */
"03WY0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Artery, Open Approach */
"03WY0MZ" = "1" /* Revision of Stimulator Lead in Upper Artery, Open Approach */
"03WY37Z" = "1" /* Revision of Autologous Tissue Substitute in Upper Artery, Percutaneous Approach */
"03WY3CZ" = "1" /* Revision of Extraluminal Device in Upper Artery, Percutaneous Approach */
"03WY3JZ" = "1" /* Revision of Synthetic Substitute in Upper Artery, Percutaneous Approach */
"03WY3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Artery, Percutaneous Approach */
"03WY3MZ" = "1" /* Revision of Stimulator Lead in Upper Artery, Percutaneous Approach */
"03WY40Z" = "1" /* Revision of Drainage Device in Upper Artery, Percutaneous Endoscopic Approach */
"03WY42Z" = "1" /* Revision of Monitoring Device in Upper Artery, Percutaneous Endoscopic Approach */
"03WY43Z" = "1" /* Revision of Infusion Device in Upper Artery, Percutaneous Endoscopic Approach */
"03WY47Z" = "1" /* Revision of Autologous Tissue Substitute in Upper Artery, Percutaneous Endoscopic Approach */
"03WY4CZ" = "1" /* Revision of Extraluminal Device in Upper Artery, Percutaneous Endoscopic Approach */
"03WY4DZ" = "1" /* Revision of Intraluminal Device in Upper Artery, Percutaneous Endoscopic Approach */
"03WY4JZ" = "1" /* Revision of Synthetic Substitute in Upper Artery, Percutaneous Endoscopic Approach */
"03WY4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Artery, Percutaneous Endoscopic Approach */
"03WY4MZ" = "1" /* Revision of Stimulator Lead in Upper Artery, Percutaneous Endoscopic Approach */
"0410090" = "1" /* Bypass Abdominal Aorta to Abdominal Aorta with Autologous Venous Tissue, Open Approach */
"0410091" = "1" /* Bypass Abdominal Aorta to Celiac Artery with Autologous Venous Tissue, Open Approach */
"0410092" = "1" /* Bypass Abdominal Aorta to Mesenteric Artery with Autologous Venous Tissue, Open Approach */
"0410093" = "1" /* Bypass Abdominal Aorta to Right Renal Artery with Autologous Venous Tissue, Open Approach */
"0410094" = "1" /* Bypass Abdominal Aorta to Left Renal Artery with Autologous Venous Tissue, Open Approach */
"0410095" = "1" /* Bypass Abdominal Aorta to Bilateral Renal Artery with Autologous Venous Tissue, Open Approach */
"0410096" = "1" /* Bypass Abdominal Aorta to Right Common Iliac Artery with Autologous Venous Tissue, Open Approach */
"0410097" = "1" /* Bypass Abdominal Aorta to Left Common Iliac Artery with Autologous Venous Tissue, Open Approach */
"0410098" = "1" /* Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Autologous Venous Tissue, Open Approach */
"0410099" = "1" /* Bypass Abdominal Aorta to Right Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041009B" = "1" /* Bypass Abdominal Aorta to Left Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041009C" = "1" /* Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041009D" = "1" /* Bypass Abdominal Aorta to Right External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041009F" = "1" /* Bypass Abdominal Aorta to Left External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041009G" = "1" /* Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041009H" = "1" /* Bypass Abdominal Aorta to Right Femoral Artery with Autologous Venous Tissue, Open Approach */
"041009J" = "1" /* Bypass Abdominal Aorta to Left Femoral Artery with Autologous Venous Tissue, Open Approach */
"041009K" = "1" /* Bypass Abdominal Aorta to Bilateral Femoral Arteries with Autologous Venous Tissue, Open Approach */
"041009Q" = "1" /* Bypass Abdominal Aorta to Lower Extremity Artery with Autologous Venous Tissue, Open Approach */
"041009R" = "1" /* Bypass Abdominal Aorta to Lower Artery with Autologous Venous Tissue, Open Approach */
"04100A0" = "1" /* Bypass Abdominal Aorta to Abdominal Aorta with Autologous Arterial Tissue, Open Approach */
"04100A1" = "1" /* Bypass Abdominal Aorta to Celiac Artery with Autologous Arterial Tissue, Open Approach */
"04100A2" = "1" /* Bypass Abdominal Aorta to Mesenteric Artery with Autologous Arterial Tissue, Open Approach */
"04100A3" = "1" /* Bypass Abdominal Aorta to Right Renal Artery with Autologous Arterial Tissue, Open Approach */
"04100A4" = "1" /* Bypass Abdominal Aorta to Left Renal Artery with Autologous Arterial Tissue, Open Approach */
"04100A5" = "1" /* Bypass Abdominal Aorta to Bilateral Renal Artery with Autologous Arterial Tissue, Open Approach */
"04100A6" = "1" /* Bypass Abdominal Aorta to Right Common Iliac Artery with Autologous Arterial Tissue, Open Approach */
"04100A7" = "1" /* Bypass Abdominal Aorta to Left Common Iliac Artery with Autologous Arterial Tissue, Open Approach */
"04100A8" = "1" /* Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"04100A9" = "1" /* Bypass Abdominal Aorta to Right Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"04100AB" = "1" /* Bypass Abdominal Aorta to Left Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"04100AC" = "1" /* Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"04100AD" = "1" /* Bypass Abdominal Aorta to Right External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"04100AF" = "1" /* Bypass Abdominal Aorta to Left External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"04100AG" = "1" /* Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"04100AH" = "1" /* Bypass Abdominal Aorta to Right Femoral Artery with Autologous Arterial Tissue, Open Approach */
"04100AJ" = "1" /* Bypass Abdominal Aorta to Left Femoral Artery with Autologous Arterial Tissue, Open Approach */
"04100AK" = "1" /* Bypass Abdominal Aorta to Bilateral Femoral Arteries with Autologous Arterial Tissue, Open Approach */
"04100AQ" = "1" /* Bypass Abdominal Aorta to Lower Extremity Artery with Autologous Arterial Tissue, Open Approach */
"04100AR" = "1" /* Bypass Abdominal Aorta to Lower Artery with Autologous Arterial Tissue, Open Approach */
"04100J0" = "1" /* Bypass Abdominal Aorta to Abdominal Aorta with Synthetic Substitute, Open Approach */
"04100J1" = "1" /* Bypass Abdominal Aorta to Celiac Artery with Synthetic Substitute, Open Approach */
"04100J2" = "1" /* Bypass Abdominal Aorta to Mesenteric Artery with Synthetic Substitute, Open Approach */
"04100J3" = "1" /* Bypass Abdominal Aorta to Right Renal Artery with Synthetic Substitute, Open Approach */
"04100J4" = "1" /* Bypass Abdominal Aorta to Left Renal Artery with Synthetic Substitute, Open Approach */
"04100J5" = "1" /* Bypass Abdominal Aorta to Bilateral Renal Artery with Synthetic Substitute, Open Approach */
"04100J6" = "1" /* Bypass Abdominal Aorta to Right Common Iliac Artery with Synthetic Substitute, Open Approach */
"04100J7" = "1" /* Bypass Abdominal Aorta to Left Common Iliac Artery with Synthetic Substitute, Open Approach */
"04100J8" = "1" /* Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Synthetic Substitute, Open Approach */
"04100J9" = "1" /* Bypass Abdominal Aorta to Right Internal Iliac Artery with Synthetic Substitute, Open Approach */
"04100JB" = "1" /* Bypass Abdominal Aorta to Left Internal Iliac Artery with Synthetic Substitute, Open Approach */
"04100JC" = "1" /* Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Synthetic Substitute, Open Approach */
"04100JD" = "1" /* Bypass Abdominal Aorta to Right External Iliac Artery with Synthetic Substitute, Open Approach */
"04100JF" = "1" /* Bypass Abdominal Aorta to Left External Iliac Artery with Synthetic Substitute, Open Approach */
"04100JG" = "1" /* Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Synthetic Substitute, Open Approach */
"04100JH" = "1" /* Bypass Abdominal Aorta to Right Femoral Artery with Synthetic Substitute, Open Approach */
"04100JJ" = "1" /* Bypass Abdominal Aorta to Left Femoral Artery with Synthetic Substitute, Open Approach */
"04100JK" = "1" /* Bypass Abdominal Aorta to Bilateral Femoral Arteries with Synthetic Substitute, Open Approach */
"04100JQ" = "1" /* Bypass Abdominal Aorta to Lower Extremity Artery with Synthetic Substitute, Open Approach */
"04100JR" = "1" /* Bypass Abdominal Aorta to Lower Artery with Synthetic Substitute, Open Approach */
"04100K0" = "1" /* Bypass Abdominal Aorta to Abdominal Aorta with Nonautologous Tissue Substitute, Open Approach */
"04100K1" = "1" /* Bypass Abdominal Aorta to Celiac Artery with Nonautologous Tissue Substitute, Open Approach */
"04100K2" = "1" /* Bypass Abdominal Aorta to Mesenteric Artery with Nonautologous Tissue Substitute, Open Approach */
"04100K3" = "1" /* Bypass Abdominal Aorta to Right Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"04100K4" = "1" /* Bypass Abdominal Aorta to Left Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"04100K5" = "1" /* Bypass Abdominal Aorta to Bilateral Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"04100K6" = "1" /* Bypass Abdominal Aorta to Right Common Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04100K7" = "1" /* Bypass Abdominal Aorta to Left Common Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04100K8" = "1" /* Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"04100K9" = "1" /* Bypass Abdominal Aorta to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04100KB" = "1" /* Bypass Abdominal Aorta to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04100KC" = "1" /* Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"04100KD" = "1" /* Bypass Abdominal Aorta to Right External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04100KF" = "1" /* Bypass Abdominal Aorta to Left External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04100KG" = "1" /* Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"04100KH" = "1" /* Bypass Abdominal Aorta to Right Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"04100KJ" = "1" /* Bypass Abdominal Aorta to Left Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"04100KK" = "1" /* Bypass Abdominal Aorta to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Open Approach */
"04100KQ" = "1" /* Bypass Abdominal Aorta to Lower Extremity Artery with Nonautologous Tissue Substitute, Open Approach */
"04100KR" = "1" /* Bypass Abdominal Aorta to Lower Artery with Nonautologous Tissue Substitute, Open Approach */
"04100Z0" = "1" /* Bypass Abdominal Aorta to Abdominal Aorta, Open Approach */
"04100Z1" = "1" /* Bypass Abdominal Aorta to Celiac Artery, Open Approach */
"04100Z2" = "1" /* Bypass Abdominal Aorta to Mesenteric Artery, Open Approach */
"04100Z3" = "1" /* Bypass Abdominal Aorta to Right Renal Artery, Open Approach */
"04100Z4" = "1" /* Bypass Abdominal Aorta to Left Renal Artery, Open Approach */
"04100Z5" = "1" /* Bypass Abdominal Aorta to Bilateral Renal Artery, Open Approach */
"04100Z6" = "1" /* Bypass Abdominal Aorta to Right Common Iliac Artery, Open Approach */
"04100Z7" = "1" /* Bypass Abdominal Aorta to Left Common Iliac Artery, Open Approach */
"04100Z8" = "1" /* Bypass Abdominal Aorta to Bilateral Common Iliac Arteries, Open Approach */
"04100Z9" = "1" /* Bypass Abdominal Aorta to Right Internal Iliac Artery, Open Approach */
"04100ZB" = "1" /* Bypass Abdominal Aorta to Left Internal Iliac Artery, Open Approach */
"04100ZC" = "1" /* Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries, Open Approach */
"04100ZD" = "1" /* Bypass Abdominal Aorta to Right External Iliac Artery, Open Approach */
"04100ZF" = "1" /* Bypass Abdominal Aorta to Left External Iliac Artery, Open Approach */
"04100ZG" = "1" /* Bypass Abdominal Aorta to Bilateral External Iliac Arteries, Open Approach */
"04100ZH" = "1" /* Bypass Abdominal Aorta to Right Femoral Artery, Open Approach */
"04100ZJ" = "1" /* Bypass Abdominal Aorta to Left Femoral Artery, Open Approach */
"04100ZK" = "1" /* Bypass Abdominal Aorta to Bilateral Femoral Arteries, Open Approach */
"04100ZQ" = "1" /* Bypass Abdominal Aorta to Lower Extremity Artery, Open Approach */
"04100ZR" = "1" /* Bypass Abdominal Aorta to Lower Artery, Open Approach */
"0410490" = "1" /* Bypass Abdominal Aorta to Abdominal Aorta with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0410491" = "1" /* Bypass Abdominal Aorta to Celiac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0410492" = "1" /* Bypass Abdominal Aorta to Mesenteric Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0410493" = "1" /* Bypass Abdominal Aorta to Right Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0410494" = "1" /* Bypass Abdominal Aorta to Left Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0410495" = "1" /* Bypass Abdominal Aorta to Bilateral Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0410496" = "1" /* Bypass Abdominal Aorta to Right Common Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0410497" = "1" /* Bypass Abdominal Aorta to Left Common Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0410498" = "1" /* Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0410499" = "1" /* Bypass Abdominal Aorta to Right Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049B" = "1" /* Bypass Abdominal Aorta to Left Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049C" = "1" /* Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049D" = "1" /* Bypass Abdominal Aorta to Right External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049F" = "1" /* Bypass Abdominal Aorta to Left External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049G" = "1" /* Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049H" = "1" /* Bypass Abdominal Aorta to Right Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049J" = "1" /* Bypass Abdominal Aorta to Left Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049K" = "1" /* Bypass Abdominal Aorta to Bilateral Femoral Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049Q" = "1" /* Bypass Abdominal Aorta to Lower Extremity Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049R" = "1" /* Bypass Abdominal Aorta to Lower Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"04104A0" = "1" /* Bypass Abdominal Aorta to Abdominal Aorta with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104A1" = "1" /* Bypass Abdominal Aorta to Celiac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104A2" = "1" /* Bypass Abdominal Aorta to Mesenteric Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104A3" = "1" /* Bypass Abdominal Aorta to Right Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104A4" = "1" /* Bypass Abdominal Aorta to Left Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104A5" = "1" /* Bypass Abdominal Aorta to Bilateral Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104A6" = "1" /* Bypass Abdominal Aorta to Right Common Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104A7" = "1" /* Bypass Abdominal Aorta to Left Common Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104A8" = "1" /* Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104A9" = "1" /* Bypass Abdominal Aorta to Right Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AB" = "1" /* Bypass Abdominal Aorta to Left Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AC" = "1" /* Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AD" = "1" /* Bypass Abdominal Aorta to Right External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AF" = "1" /* Bypass Abdominal Aorta to Left External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AG" = "1" /* Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AH" = "1" /* Bypass Abdominal Aorta to Right Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AJ" = "1" /* Bypass Abdominal Aorta to Left Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AK" = "1" /* Bypass Abdominal Aorta to Bilateral Femoral Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AQ" = "1" /* Bypass Abdominal Aorta to Lower Extremity Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AR" = "1" /* Bypass Abdominal Aorta to Lower Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104J0" = "1" /* Bypass Abdominal Aorta to Abdominal Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104J1" = "1" /* Bypass Abdominal Aorta to Celiac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104J2" = "1" /* Bypass Abdominal Aorta to Mesenteric Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104J3" = "1" /* Bypass Abdominal Aorta to Right Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104J4" = "1" /* Bypass Abdominal Aorta to Left Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104J5" = "1" /* Bypass Abdominal Aorta to Bilateral Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104J6" = "1" /* Bypass Abdominal Aorta to Right Common Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104J7" = "1" /* Bypass Abdominal Aorta to Left Common Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104J8" = "1" /* Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104J9" = "1" /* Bypass Abdominal Aorta to Right Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JB" = "1" /* Bypass Abdominal Aorta to Left Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JC" = "1" /* Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JD" = "1" /* Bypass Abdominal Aorta to Right External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JF" = "1" /* Bypass Abdominal Aorta to Left External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JG" = "1" /* Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JH" = "1" /* Bypass Abdominal Aorta to Right Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JJ" = "1" /* Bypass Abdominal Aorta to Left Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JK" = "1" /* Bypass Abdominal Aorta to Bilateral Femoral Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JQ" = "1" /* Bypass Abdominal Aorta to Lower Extremity Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JR" = "1" /* Bypass Abdominal Aorta to Lower Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104K0" = "1" /* Bypass Abdominal Aorta to Abdominal Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104K1" = "1" /* Bypass Abdominal Aorta to Celiac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104K2" = "1" /* Bypass Abdominal Aorta to Mesenteric Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104K3" = "1" /* Bypass Abdominal Aorta to Right Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104K4" = "1" /* Bypass Abdominal Aorta to Left Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104K5" = "1" /* Bypass Abdominal Aorta to Bilateral Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104K6" = "1" /* Bypass Abdominal Aorta to Right Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104K7" = "1" /* Bypass Abdominal Aorta to Left Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104K8" = "1" /* Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104K9" = "1" /* Bypass Abdominal Aorta to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KB" = "1" /* Bypass Abdominal Aorta to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KC" = "1" /* Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KD" = "1" /* Bypass Abdominal Aorta to Right External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KF" = "1" /* Bypass Abdominal Aorta to Left External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KG" = "1" /* Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KH" = "1" /* Bypass Abdominal Aorta to Right Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KJ" = "1" /* Bypass Abdominal Aorta to Left Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KK" = "1" /* Bypass Abdominal Aorta to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KQ" = "1" /* Bypass Abdominal Aorta to Lower Extremity Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KR" = "1" /* Bypass Abdominal Aorta to Lower Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104Z0" = "1" /* Bypass Abdominal Aorta to Abdominal Aorta, Percutaneous Endoscopic Approach */
"04104Z1" = "1" /* Bypass Abdominal Aorta to Celiac Artery, Percutaneous Endoscopic Approach */
"04104Z2" = "1" /* Bypass Abdominal Aorta to Mesenteric Artery, Percutaneous Endoscopic Approach */
"04104Z3" = "1" /* Bypass Abdominal Aorta to Right Renal Artery, Percutaneous Endoscopic Approach */
"04104Z4" = "1" /* Bypass Abdominal Aorta to Left Renal Artery, Percutaneous Endoscopic Approach */
"04104Z5" = "1" /* Bypass Abdominal Aorta to Bilateral Renal Artery, Percutaneous Endoscopic Approach */
"04104Z6" = "1" /* Bypass Abdominal Aorta to Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"04104Z7" = "1" /* Bypass Abdominal Aorta to Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"04104Z8" = "1" /* Bypass Abdominal Aorta to Bilateral Common Iliac Arteries, Percutaneous Endoscopic Approach */
"04104Z9" = "1" /* Bypass Abdominal Aorta to Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04104ZB" = "1" /* Bypass Abdominal Aorta to Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04104ZC" = "1" /* Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries, Percutaneous Endoscopic Approach */
"04104ZD" = "1" /* Bypass Abdominal Aorta to Right External Iliac Artery, Percutaneous Endoscopic Approach */
"04104ZF" = "1" /* Bypass Abdominal Aorta to Left External Iliac Artery, Percutaneous Endoscopic Approach */
"04104ZG" = "1" /* Bypass Abdominal Aorta to Bilateral External Iliac Arteries, Percutaneous Endoscopic Approach */
"04104ZH" = "1" /* Bypass Abdominal Aorta to Right Femoral Artery, Percutaneous Endoscopic Approach */
"04104ZJ" = "1" /* Bypass Abdominal Aorta to Left Femoral Artery, Percutaneous Endoscopic Approach */
"04104ZK" = "1" /* Bypass Abdominal Aorta to Bilateral Femoral Arteries, Percutaneous Endoscopic Approach */
"04104ZQ" = "1" /* Bypass Abdominal Aorta to Lower Extremity Artery, Percutaneous Endoscopic Approach */
"04104ZR" = "1" /* Bypass Abdominal Aorta to Lower Artery, Percutaneous Endoscopic Approach */
"0414093" = "1" /* Bypass Splenic Artery to Right Renal Artery with Autologous Venous Tissue, Open Approach */
"0414094" = "1" /* Bypass Splenic Artery to Left Renal Artery with Autologous Venous Tissue, Open Approach */
"0414095" = "1" /* Bypass Splenic Artery to Bilateral Renal Artery with Autologous Venous Tissue, Open Approach */
"04140A3" = "1" /* Bypass Splenic Artery to Right Renal Artery with Autologous Arterial Tissue, Open Approach */
"04140A4" = "1" /* Bypass Splenic Artery to Left Renal Artery with Autologous Arterial Tissue, Open Approach */
"04140A5" = "1" /* Bypass Splenic Artery to Bilateral Renal Artery with Autologous Arterial Tissue, Open Approach */
"04140J3" = "1" /* Bypass Splenic Artery to Right Renal Artery with Synthetic Substitute, Open Approach */
"04140J4" = "1" /* Bypass Splenic Artery to Left Renal Artery with Synthetic Substitute, Open Approach */
"04140J5" = "1" /* Bypass Splenic Artery to Bilateral Renal Artery with Synthetic Substitute, Open Approach */
"04140K3" = "1" /* Bypass Splenic Artery to Right Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"04140K4" = "1" /* Bypass Splenic Artery to Left Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"04140K5" = "1" /* Bypass Splenic Artery to Bilateral Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"04140Z3" = "1" /* Bypass Splenic Artery to Right Renal Artery, Open Approach */
"04140Z4" = "1" /* Bypass Splenic Artery to Left Renal Artery, Open Approach */
"04140Z5" = "1" /* Bypass Splenic Artery to Bilateral Renal Artery, Open Approach */
"0414493" = "1" /* Bypass Splenic Artery to Right Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0414494" = "1" /* Bypass Splenic Artery to Left Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0414495" = "1" /* Bypass Splenic Artery to Bilateral Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"04144A3" = "1" /* Bypass Splenic Artery to Right Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04144A4" = "1" /* Bypass Splenic Artery to Left Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04144A5" = "1" /* Bypass Splenic Artery to Bilateral Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04144J3" = "1" /* Bypass Splenic Artery to Right Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04144J4" = "1" /* Bypass Splenic Artery to Left Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04144J5" = "1" /* Bypass Splenic Artery to Bilateral Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04144K3" = "1" /* Bypass Splenic Artery to Right Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04144K4" = "1" /* Bypass Splenic Artery to Left Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04144K5" = "1" /* Bypass Splenic Artery to Bilateral Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04144Z3" = "1" /* Bypass Splenic Artery to Right Renal Artery, Percutaneous Endoscopic Approach */
"04144Z4" = "1" /* Bypass Splenic Artery to Left Renal Artery, Percutaneous Endoscopic Approach */
"04144Z5" = "1" /* Bypass Splenic Artery to Bilateral Renal Artery, Percutaneous Endoscopic Approach */
"041C090" = "1" /* Bypass Right Common Iliac Artery to Abdominal Aorta with Autologous Venous Tissue, Open Approach */
"041C091" = "1" /* Bypass Right Common Iliac Artery to Celiac Artery with Autologous Venous Tissue, Open Approach */
"041C092" = "1" /* Bypass Right Common Iliac Artery to Mesenteric Artery with Autologous Venous Tissue, Open Approach */
"041C093" = "1" /* Bypass Right Common Iliac Artery to Right Renal Artery with Autologous Venous Tissue, Open Approach */
"041C094" = "1" /* Bypass Right Common Iliac Artery to Left Renal Artery with Autologous Venous Tissue, Open Approach */
"041C095" = "1" /* Bypass Right Common Iliac Artery to Bilateral Renal Artery with Autologous Venous Tissue, Open Approach */
"041C096" = "1" /* Bypass Right Common Iliac Artery to Right Common Iliac Artery with Autologous Venous Tissue, Open Approach */
"041C097" = "1" /* Bypass Right Common Iliac Artery to Left Common Iliac Artery with Autologous Venous Tissue, Open Approach */
"041C098" = "1" /* Bypass Right Common Iliac Artery to Bilateral Common Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041C099" = "1" /* Bypass Right Common Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041C09B" = "1" /* Bypass Right Common Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041C09C" = "1" /* Bypass Right Common Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041C09D" = "1" /* Bypass Right Common Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041C09F" = "1" /* Bypass Right Common Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041C09G" = "1" /* Bypass Right Common Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041C09H" = "1" /* Bypass Right Common Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Open Approach */
"041C09J" = "1" /* Bypass Right Common Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Open Approach */
"041C09K" = "1" /* Bypass Right Common Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Open Approach */
"041C09Q" = "1" /* Bypass Right Common Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Open Approach */
"041C09R" = "1" /* Bypass Right Common Iliac Artery to Lower Artery with Autologous Venous Tissue, Open Approach */
"041C0A0" = "1" /* Bypass Right Common Iliac Artery to Abdominal Aorta with Autologous Arterial Tissue, Open Approach */
"041C0A1" = "1" /* Bypass Right Common Iliac Artery to Celiac Artery with Autologous Arterial Tissue, Open Approach */
"041C0A2" = "1" /* Bypass Right Common Iliac Artery to Mesenteric Artery with Autologous Arterial Tissue, Open Approach */
"041C0A3" = "1" /* Bypass Right Common Iliac Artery to Right Renal Artery with Autologous Arterial Tissue, Open Approach */
"041C0A4" = "1" /* Bypass Right Common Iliac Artery to Left Renal Artery with Autologous Arterial Tissue, Open Approach */
"041C0A5" = "1" /* Bypass Right Common Iliac Artery to Bilateral Renal Artery with Autologous Arterial Tissue, Open Approach */
"041C0A6" = "1" /* Bypass Right Common Iliac Artery to Right Common Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041C0A7" = "1" /* Bypass Right Common Iliac Artery to Left Common Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041C0A8" = "1" /* Bypass Right Common Iliac Artery to Bilateral Common Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041C0A9" = "1" /* Bypass Right Common Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041C0AB" = "1" /* Bypass Right Common Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041C0AC" = "1" /* Bypass Right Common Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041C0AD" = "1" /* Bypass Right Common Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041C0AF" = "1" /* Bypass Right Common Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041C0AG" = "1" /* Bypass Right Common Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041C0AH" = "1" /* Bypass Right Common Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041C0AJ" = "1" /* Bypass Right Common Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041C0AK" = "1" /* Bypass Right Common Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Open Approach */
"041C0AQ" = "1" /* Bypass Right Common Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Open Approach */
"041C0AR" = "1" /* Bypass Right Common Iliac Artery to Lower Artery with Autologous Arterial Tissue, Open Approach */
"041C0J0" = "1" /* Bypass Right Common Iliac Artery to Abdominal Aorta with Synthetic Substitute, Open Approach */
"041C0J1" = "1" /* Bypass Right Common Iliac Artery to Celiac Artery with Synthetic Substitute, Open Approach */
"041C0J2" = "1" /* Bypass Right Common Iliac Artery to Mesenteric Artery with Synthetic Substitute, Open Approach */
"041C0J3" = "1" /* Bypass Right Common Iliac Artery to Right Renal Artery with Synthetic Substitute, Open Approach */
"041C0J4" = "1" /* Bypass Right Common Iliac Artery to Left Renal Artery with Synthetic Substitute, Open Approach */
"041C0J5" = "1" /* Bypass Right Common Iliac Artery to Bilateral Renal Artery with Synthetic Substitute, Open Approach */
"041C0J6" = "1" /* Bypass Right Common Iliac Artery to Right Common Iliac Artery with Synthetic Substitute, Open Approach */
"041C0J7" = "1" /* Bypass Right Common Iliac Artery to Left Common Iliac Artery with Synthetic Substitute, Open Approach */
"041C0J8" = "1" /* Bypass Right Common Iliac Artery to Bilateral Common Iliac Arteries with Synthetic Substitute, Open Approach */
"041C0J9" = "1" /* Bypass Right Common Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041C0JB" = "1" /* Bypass Right Common Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041C0JC" = "1" /* Bypass Right Common Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Open Approach */
"041C0JD" = "1" /* Bypass Right Common Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Open Approach */
"041C0JF" = "1" /* Bypass Right Common Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Open Approach */
"041C0JG" = "1" /* Bypass Right Common Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Open Approach */
"041C0JH" = "1" /* Bypass Right Common Iliac Artery to Right Femoral Artery with Synthetic Substitute, Open Approach */
"041C0JJ" = "1" /* Bypass Right Common Iliac Artery to Left Femoral Artery with Synthetic Substitute, Open Approach */
"041C0JK" = "1" /* Bypass Right Common Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Open Approach */
"041C0JQ" = "1" /* Bypass Right Common Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Open Approach */
"041C0JR" = "1" /* Bypass Right Common Iliac Artery to Lower Artery with Synthetic Substitute, Open Approach */
"041C0K0" = "1" /* Bypass Right Common Iliac Artery to Abdominal Aorta with Nonautologous Tissue Substitute, Open Approach */
"041C0K1" = "1" /* Bypass Right Common Iliac Artery to Celiac Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0K2" = "1" /* Bypass Right Common Iliac Artery to Mesenteric Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0K3" = "1" /* Bypass Right Common Iliac Artery to Right Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0K4" = "1" /* Bypass Right Common Iliac Artery to Left Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0K5" = "1" /* Bypass Right Common Iliac Artery to Bilateral Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0K6" = "1" /* Bypass Right Common Iliac Artery to Right Common Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0K7" = "1" /* Bypass Right Common Iliac Artery to Left Common Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0K8" = "1" /* Bypass Right Common Iliac Artery to Bilateral Common Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041C0K9" = "1" /* Bypass Right Common Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0KB" = "1" /* Bypass Right Common Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0KC" = "1" /* Bypass Right Common Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041C0KD" = "1" /* Bypass Right Common Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0KF" = "1" /* Bypass Right Common Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0KG" = "1" /* Bypass Right Common Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041C0KH" = "1" /* Bypass Right Common Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0KJ" = "1" /* Bypass Right Common Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0KK" = "1" /* Bypass Right Common Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Open Approach */
"041C0KQ" = "1" /* Bypass Right Common Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0KR" = "1" /* Bypass Right Common Iliac Artery to Lower Artery with Nonautologous Tissue Substitute, Open Approach */
"041C0Z0" = "1" /* Bypass Right Common Iliac Artery to Abdominal Aorta, Open Approach */
"041C0Z1" = "1" /* Bypass Right Common Iliac Artery to Celiac Artery, Open Approach */
"041C0Z2" = "1" /* Bypass Right Common Iliac Artery to Mesenteric Artery, Open Approach */
"041C0Z3" = "1" /* Bypass Right Common Iliac Artery to Right Renal Artery, Open Approach */
"041C0Z4" = "1" /* Bypass Right Common Iliac Artery to Left Renal Artery, Open Approach */
"041C0Z5" = "1" /* Bypass Right Common Iliac Artery to Bilateral Renal Artery, Open Approach */
"041C0Z6" = "1" /* Bypass Right Common Iliac Artery to Right Common Iliac Artery, Open Approach */
"041C0Z7" = "1" /* Bypass Right Common Iliac Artery to Left Common Iliac Artery, Open Approach */
"041C0Z8" = "1" /* Bypass Right Common Iliac Artery to Bilateral Common Iliac Arteries, Open Approach */
"041C0Z9" = "1" /* Bypass Right Common Iliac Artery to Right Internal Iliac Artery, Open Approach */
"041C0ZB" = "1" /* Bypass Right Common Iliac Artery to Left Internal Iliac Artery, Open Approach */
"041C0ZC" = "1" /* Bypass Right Common Iliac Artery to Bilateral Internal Iliac Arteries, Open Approach */
"041C0ZD" = "1" /* Bypass Right Common Iliac Artery to Right External Iliac Artery, Open Approach */
"041C0ZF" = "1" /* Bypass Right Common Iliac Artery to Left External Iliac Artery, Open Approach */
"041C0ZG" = "1" /* Bypass Right Common Iliac Artery to Bilateral External Iliac Arteries, Open Approach */
"041C0ZH" = "1" /* Bypass Right Common Iliac Artery to Right Femoral Artery, Open Approach */
"041C0ZJ" = "1" /* Bypass Right Common Iliac Artery to Left Femoral Artery, Open Approach */
"041C0ZK" = "1" /* Bypass Right Common Iliac Artery to Bilateral Femoral Arteries, Open Approach */
"041C0ZQ" = "1" /* Bypass Right Common Iliac Artery to Lower Extremity Artery, Open Approach */
"041C0ZR" = "1" /* Bypass Right Common Iliac Artery to Lower Artery, Open Approach */
"041C490" = "1" /* Bypass Right Common Iliac Artery to Abdominal Aorta with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C491" = "1" /* Bypass Right Common Iliac Artery to Celiac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C492" = "1" /* Bypass Right Common Iliac Artery to Mesenteric Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C493" = "1" /* Bypass Right Common Iliac Artery to Right Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C494" = "1" /* Bypass Right Common Iliac Artery to Left Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C495" = "1" /* Bypass Right Common Iliac Artery to Bilateral Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C496" = "1" /* Bypass Right Common Iliac Artery to Right Common Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C497" = "1" /* Bypass Right Common Iliac Artery to Left Common Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C498" = "1" /* Bypass Right Common Iliac Artery to Bilateral Common Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C499" = "1" /* Bypass Right Common Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C49B" = "1" /* Bypass Right Common Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C49C" = "1" /* Bypass Right Common Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C49D" = "1" /* Bypass Right Common Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C49F" = "1" /* Bypass Right Common Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C49G" = "1" /* Bypass Right Common Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C49H" = "1" /* Bypass Right Common Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C49J" = "1" /* Bypass Right Common Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C49K" = "1" /* Bypass Right Common Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C49Q" = "1" /* Bypass Right Common Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C49R" = "1" /* Bypass Right Common Iliac Artery to Lower Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041C4A0" = "1" /* Bypass Right Common Iliac Artery to Abdominal Aorta with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4A1" = "1" /* Bypass Right Common Iliac Artery to Celiac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4A2" = "1" /* Bypass Right Common Iliac Artery to Mesenteric Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4A3" = "1" /* Bypass Right Common Iliac Artery to Right Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4A4" = "1" /* Bypass Right Common Iliac Artery to Left Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4A5" = "1" /* Bypass Right Common Iliac Artery to Bilateral Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4A6" = "1" /* Bypass Right Common Iliac Artery to Right Common Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4A7" = "1" /* Bypass Right Common Iliac Artery to Left Common Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4A8" = "1" /* Bypass Right Common Iliac Artery to Bilateral Common Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4A9" = "1" /* Bypass Right Common Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4AB" = "1" /* Bypass Right Common Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4AC" = "1" /* Bypass Right Common Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4AD" = "1" /* Bypass Right Common Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4AF" = "1" /* Bypass Right Common Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4AG" = "1" /* Bypass Right Common Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4AH" = "1" /* Bypass Right Common Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4AJ" = "1" /* Bypass Right Common Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4AK" = "1" /* Bypass Right Common Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4AQ" = "1" /* Bypass Right Common Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4AR" = "1" /* Bypass Right Common Iliac Artery to Lower Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041C4J0" = "1" /* Bypass Right Common Iliac Artery to Abdominal Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4J1" = "1" /* Bypass Right Common Iliac Artery to Celiac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4J2" = "1" /* Bypass Right Common Iliac Artery to Mesenteric Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4J3" = "1" /* Bypass Right Common Iliac Artery to Right Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4J4" = "1" /* Bypass Right Common Iliac Artery to Left Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4J5" = "1" /* Bypass Right Common Iliac Artery to Bilateral Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4J6" = "1" /* Bypass Right Common Iliac Artery to Right Common Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4J7" = "1" /* Bypass Right Common Iliac Artery to Left Common Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4J8" = "1" /* Bypass Right Common Iliac Artery to Bilateral Common Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4J9" = "1" /* Bypass Right Common Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4JB" = "1" /* Bypass Right Common Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4JC" = "1" /* Bypass Right Common Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4JD" = "1" /* Bypass Right Common Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4JF" = "1" /* Bypass Right Common Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4JG" = "1" /* Bypass Right Common Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4JH" = "1" /* Bypass Right Common Iliac Artery to Right Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4JJ" = "1" /* Bypass Right Common Iliac Artery to Left Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4JK" = "1" /* Bypass Right Common Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4JQ" = "1" /* Bypass Right Common Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4JR" = "1" /* Bypass Right Common Iliac Artery to Lower Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041C4K0" = "1" /* Bypass Right Common Iliac Artery to Abdominal Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4K1" = "1" /* Bypass Right Common Iliac Artery to Celiac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4K2" = "1" /* Bypass Right Common Iliac Artery to Mesenteric Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4K3" = "1" /* Bypass Right Common Iliac Artery to Right Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4K4" = "1" /* Bypass Right Common Iliac Artery to Left Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4K5" = "1" /* Bypass Right Common Iliac Artery to Bilateral Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4K6" = "1" /* Bypass Right Common Iliac Artery to Right Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4K7" = "1" /* Bypass Right Common Iliac Artery to Left Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4K8" = "1" /* Bypass Right Common Iliac Artery to Bilateral Common Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4K9" = "1" /* Bypass Right Common Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4KB" = "1" /* Bypass Right Common Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4KC" = "1" /* Bypass Right Common Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4KD" = "1" /* Bypass Right Common Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4KF" = "1" /* Bypass Right Common Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4KG" = "1" /* Bypass Right Common Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4KH" = "1" /* Bypass Right Common Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4KJ" = "1" /* Bypass Right Common Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4KK" = "1" /* Bypass Right Common Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4KQ" = "1" /* Bypass Right Common Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4KR" = "1" /* Bypass Right Common Iliac Artery to Lower Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041C4Z0" = "1" /* Bypass Right Common Iliac Artery to Abdominal Aorta, Percutaneous Endoscopic Approach */
"041C4Z1" = "1" /* Bypass Right Common Iliac Artery to Celiac Artery, Percutaneous Endoscopic Approach */
"041C4Z2" = "1" /* Bypass Right Common Iliac Artery to Mesenteric Artery, Percutaneous Endoscopic Approach */
"041C4Z3" = "1" /* Bypass Right Common Iliac Artery to Right Renal Artery, Percutaneous Endoscopic Approach */
"041C4Z4" = "1" /* Bypass Right Common Iliac Artery to Left Renal Artery, Percutaneous Endoscopic Approach */
"041C4Z5" = "1" /* Bypass Right Common Iliac Artery to Bilateral Renal Artery, Percutaneous Endoscopic Approach */
"041C4Z6" = "1" /* Bypass Right Common Iliac Artery to Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"041C4Z7" = "1" /* Bypass Right Common Iliac Artery to Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"041C4Z8" = "1" /* Bypass Right Common Iliac Artery to Bilateral Common Iliac Arteries, Percutaneous Endoscopic Approach */
"041C4Z9" = "1" /* Bypass Right Common Iliac Artery to Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041C4ZB" = "1" /* Bypass Right Common Iliac Artery to Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041C4ZC" = "1" /* Bypass Right Common Iliac Artery to Bilateral Internal Iliac Arteries, Percutaneous Endoscopic Approach */
"041C4ZD" = "1" /* Bypass Right Common Iliac Artery to Right External Iliac Artery, Percutaneous Endoscopic Approach */
"041C4ZF" = "1" /* Bypass Right Common Iliac Artery to Left External Iliac Artery, Percutaneous Endoscopic Approach */
"041C4ZG" = "1" /* Bypass Right Common Iliac Artery to Bilateral External Iliac Arteries, Percutaneous Endoscopic Approach */
"041C4ZH" = "1" /* Bypass Right Common Iliac Artery to Right Femoral Artery, Percutaneous Endoscopic Approach */
"041C4ZJ" = "1" /* Bypass Right Common Iliac Artery to Left Femoral Artery, Percutaneous Endoscopic Approach */
"041C4ZK" = "1" /* Bypass Right Common Iliac Artery to Bilateral Femoral Arteries, Percutaneous Endoscopic Approach */
"041C4ZQ" = "1" /* Bypass Right Common Iliac Artery to Lower Extremity Artery, Percutaneous Endoscopic Approach */
"041C4ZR" = "1" /* Bypass Right Common Iliac Artery to Lower Artery, Percutaneous Endoscopic Approach */
"041D090" = "1" /* Bypass Left Common Iliac Artery to Abdominal Aorta with Autologous Venous Tissue, Open Approach */
"041D091" = "1" /* Bypass Left Common Iliac Artery to Celiac Artery with Autologous Venous Tissue, Open Approach */
"041D092" = "1" /* Bypass Left Common Iliac Artery to Mesenteric Artery with Autologous Venous Tissue, Open Approach */
"041D093" = "1" /* Bypass Left Common Iliac Artery to Right Renal Artery with Autologous Venous Tissue, Open Approach */
"041D094" = "1" /* Bypass Left Common Iliac Artery to Left Renal Artery with Autologous Venous Tissue, Open Approach */
"041D095" = "1" /* Bypass Left Common Iliac Artery to Bilateral Renal Artery with Autologous Venous Tissue, Open Approach */
"041D096" = "1" /* Bypass Left Common Iliac Artery to Right Common Iliac Artery with Autologous Venous Tissue, Open Approach */
"041D097" = "1" /* Bypass Left Common Iliac Artery to Left Common Iliac Artery with Autologous Venous Tissue, Open Approach */
"041D098" = "1" /* Bypass Left Common Iliac Artery to Bilateral Common Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041D099" = "1" /* Bypass Left Common Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041D09B" = "1" /* Bypass Left Common Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041D09C" = "1" /* Bypass Left Common Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041D09D" = "1" /* Bypass Left Common Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041D09F" = "1" /* Bypass Left Common Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041D09G" = "1" /* Bypass Left Common Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041D09H" = "1" /* Bypass Left Common Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Open Approach */
"041D09J" = "1" /* Bypass Left Common Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Open Approach */
"041D09K" = "1" /* Bypass Left Common Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Open Approach */
"041D09Q" = "1" /* Bypass Left Common Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Open Approach */
"041D09R" = "1" /* Bypass Left Common Iliac Artery to Lower Artery with Autologous Venous Tissue, Open Approach */
"041D0A0" = "1" /* Bypass Left Common Iliac Artery to Abdominal Aorta with Autologous Arterial Tissue, Open Approach */
"041D0A1" = "1" /* Bypass Left Common Iliac Artery to Celiac Artery with Autologous Arterial Tissue, Open Approach */
"041D0A2" = "1" /* Bypass Left Common Iliac Artery to Mesenteric Artery with Autologous Arterial Tissue, Open Approach */
"041D0A3" = "1" /* Bypass Left Common Iliac Artery to Right Renal Artery with Autologous Arterial Tissue, Open Approach */
"041D0A4" = "1" /* Bypass Left Common Iliac Artery to Left Renal Artery with Autologous Arterial Tissue, Open Approach */
"041D0A5" = "1" /* Bypass Left Common Iliac Artery to Bilateral Renal Artery with Autologous Arterial Tissue, Open Approach */
"041D0A6" = "1" /* Bypass Left Common Iliac Artery to Right Common Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041D0A7" = "1" /* Bypass Left Common Iliac Artery to Left Common Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041D0A8" = "1" /* Bypass Left Common Iliac Artery to Bilateral Common Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041D0A9" = "1" /* Bypass Left Common Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041D0AB" = "1" /* Bypass Left Common Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041D0AC" = "1" /* Bypass Left Common Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041D0AD" = "1" /* Bypass Left Common Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041D0AF" = "1" /* Bypass Left Common Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041D0AG" = "1" /* Bypass Left Common Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041D0AH" = "1" /* Bypass Left Common Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041D0AJ" = "1" /* Bypass Left Common Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041D0AK" = "1" /* Bypass Left Common Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Open Approach */
"041D0AQ" = "1" /* Bypass Left Common Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Open Approach */
"041D0AR" = "1" /* Bypass Left Common Iliac Artery to Lower Artery with Autologous Arterial Tissue, Open Approach */
"041D0J0" = "1" /* Bypass Left Common Iliac Artery to Abdominal Aorta with Synthetic Substitute, Open Approach */
"041D0J1" = "1" /* Bypass Left Common Iliac Artery to Celiac Artery with Synthetic Substitute, Open Approach */
"041D0J2" = "1" /* Bypass Left Common Iliac Artery to Mesenteric Artery with Synthetic Substitute, Open Approach */
"041D0J3" = "1" /* Bypass Left Common Iliac Artery to Right Renal Artery with Synthetic Substitute, Open Approach */
"041D0J4" = "1" /* Bypass Left Common Iliac Artery to Left Renal Artery with Synthetic Substitute, Open Approach */
"041D0J5" = "1" /* Bypass Left Common Iliac Artery to Bilateral Renal Artery with Synthetic Substitute, Open Approach */
"041D0J6" = "1" /* Bypass Left Common Iliac Artery to Right Common Iliac Artery with Synthetic Substitute, Open Approach */
"041D0J7" = "1" /* Bypass Left Common Iliac Artery to Left Common Iliac Artery with Synthetic Substitute, Open Approach */
"041D0J8" = "1" /* Bypass Left Common Iliac Artery to Bilateral Common Iliac Arteries with Synthetic Substitute, Open Approach */
"041D0J9" = "1" /* Bypass Left Common Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041D0JB" = "1" /* Bypass Left Common Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041D0JC" = "1" /* Bypass Left Common Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Open Approach */
"041D0JD" = "1" /* Bypass Left Common Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Open Approach */
"041D0JF" = "1" /* Bypass Left Common Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Open Approach */
"041D0JG" = "1" /* Bypass Left Common Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Open Approach */
"041D0JH" = "1" /* Bypass Left Common Iliac Artery to Right Femoral Artery with Synthetic Substitute, Open Approach */
"041D0JJ" = "1" /* Bypass Left Common Iliac Artery to Left Femoral Artery with Synthetic Substitute, Open Approach */
"041D0JK" = "1" /* Bypass Left Common Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Open Approach */
"041D0JQ" = "1" /* Bypass Left Common Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Open Approach */
"041D0JR" = "1" /* Bypass Left Common Iliac Artery to Lower Artery with Synthetic Substitute, Open Approach */
"041D0K0" = "1" /* Bypass Left Common Iliac Artery to Abdominal Aorta with Nonautologous Tissue Substitute, Open Approach */
"041D0K1" = "1" /* Bypass Left Common Iliac Artery to Celiac Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0K2" = "1" /* Bypass Left Common Iliac Artery to Mesenteric Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0K3" = "1" /* Bypass Left Common Iliac Artery to Right Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0K4" = "1" /* Bypass Left Common Iliac Artery to Left Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0K5" = "1" /* Bypass Left Common Iliac Artery to Bilateral Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0K6" = "1" /* Bypass Left Common Iliac Artery to Right Common Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0K7" = "1" /* Bypass Left Common Iliac Artery to Left Common Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0K8" = "1" /* Bypass Left Common Iliac Artery to Bilateral Common Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041D0K9" = "1" /* Bypass Left Common Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0KB" = "1" /* Bypass Left Common Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0KC" = "1" /* Bypass Left Common Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041D0KD" = "1" /* Bypass Left Common Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0KF" = "1" /* Bypass Left Common Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0KG" = "1" /* Bypass Left Common Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041D0KH" = "1" /* Bypass Left Common Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0KJ" = "1" /* Bypass Left Common Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0KK" = "1" /* Bypass Left Common Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Open Approach */
"041D0KQ" = "1" /* Bypass Left Common Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0KR" = "1" /* Bypass Left Common Iliac Artery to Lower Artery with Nonautologous Tissue Substitute, Open Approach */
"041D0Z0" = "1" /* Bypass Left Common Iliac Artery to Abdominal Aorta, Open Approach */
"041D0Z1" = "1" /* Bypass Left Common Iliac Artery to Celiac Artery, Open Approach */
"041D0Z2" = "1" /* Bypass Left Common Iliac Artery to Mesenteric Artery, Open Approach */
"041D0Z3" = "1" /* Bypass Left Common Iliac Artery to Right Renal Artery, Open Approach */
"041D0Z4" = "1" /* Bypass Left Common Iliac Artery to Left Renal Artery, Open Approach */
"041D0Z5" = "1" /* Bypass Left Common Iliac Artery to Bilateral Renal Artery, Open Approach */
"041D0Z6" = "1" /* Bypass Left Common Iliac Artery to Right Common Iliac Artery, Open Approach */
"041D0Z7" = "1" /* Bypass Left Common Iliac Artery to Left Common Iliac Artery, Open Approach */
"041D0Z8" = "1" /* Bypass Left Common Iliac Artery to Bilateral Common Iliac Arteries, Open Approach */
"041D0Z9" = "1" /* Bypass Left Common Iliac Artery to Right Internal Iliac Artery, Open Approach */
"041D0ZB" = "1" /* Bypass Left Common Iliac Artery to Left Internal Iliac Artery, Open Approach */
"041D0ZC" = "1" /* Bypass Left Common Iliac Artery to Bilateral Internal Iliac Arteries, Open Approach */
"041D0ZD" = "1" /* Bypass Left Common Iliac Artery to Right External Iliac Artery, Open Approach */
"041D0ZF" = "1" /* Bypass Left Common Iliac Artery to Left External Iliac Artery, Open Approach */
"041D0ZG" = "1" /* Bypass Left Common Iliac Artery to Bilateral External Iliac Arteries, Open Approach */
"041D0ZH" = "1" /* Bypass Left Common Iliac Artery to Right Femoral Artery, Open Approach */
"041D0ZJ" = "1" /* Bypass Left Common Iliac Artery to Left Femoral Artery, Open Approach */
"041D0ZK" = "1" /* Bypass Left Common Iliac Artery to Bilateral Femoral Arteries, Open Approach */
"041D0ZQ" = "1" /* Bypass Left Common Iliac Artery to Lower Extremity Artery, Open Approach */
"041D0ZR" = "1" /* Bypass Left Common Iliac Artery to Lower Artery, Open Approach */
"041D490" = "1" /* Bypass Left Common Iliac Artery to Abdominal Aorta with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D491" = "1" /* Bypass Left Common Iliac Artery to Celiac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D492" = "1" /* Bypass Left Common Iliac Artery to Mesenteric Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D493" = "1" /* Bypass Left Common Iliac Artery to Right Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D494" = "1" /* Bypass Left Common Iliac Artery to Left Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D495" = "1" /* Bypass Left Common Iliac Artery to Bilateral Renal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D496" = "1" /* Bypass Left Common Iliac Artery to Right Common Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D497" = "1" /* Bypass Left Common Iliac Artery to Left Common Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D498" = "1" /* Bypass Left Common Iliac Artery to Bilateral Common Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D499" = "1" /* Bypass Left Common Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D49B" = "1" /* Bypass Left Common Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D49C" = "1" /* Bypass Left Common Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D49D" = "1" /* Bypass Left Common Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D49F" = "1" /* Bypass Left Common Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D49G" = "1" /* Bypass Left Common Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D49H" = "1" /* Bypass Left Common Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D49J" = "1" /* Bypass Left Common Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D49K" = "1" /* Bypass Left Common Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D49Q" = "1" /* Bypass Left Common Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D49R" = "1" /* Bypass Left Common Iliac Artery to Lower Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041D4A0" = "1" /* Bypass Left Common Iliac Artery to Abdominal Aorta with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4A1" = "1" /* Bypass Left Common Iliac Artery to Celiac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4A2" = "1" /* Bypass Left Common Iliac Artery to Mesenteric Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4A3" = "1" /* Bypass Left Common Iliac Artery to Right Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4A4" = "1" /* Bypass Left Common Iliac Artery to Left Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4A5" = "1" /* Bypass Left Common Iliac Artery to Bilateral Renal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4A6" = "1" /* Bypass Left Common Iliac Artery to Right Common Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4A7" = "1" /* Bypass Left Common Iliac Artery to Left Common Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4A8" = "1" /* Bypass Left Common Iliac Artery to Bilateral Common Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4A9" = "1" /* Bypass Left Common Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4AB" = "1" /* Bypass Left Common Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4AC" = "1" /* Bypass Left Common Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4AD" = "1" /* Bypass Left Common Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4AF" = "1" /* Bypass Left Common Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4AG" = "1" /* Bypass Left Common Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4AH" = "1" /* Bypass Left Common Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4AJ" = "1" /* Bypass Left Common Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4AK" = "1" /* Bypass Left Common Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4AQ" = "1" /* Bypass Left Common Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4AR" = "1" /* Bypass Left Common Iliac Artery to Lower Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041D4J0" = "1" /* Bypass Left Common Iliac Artery to Abdominal Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4J1" = "1" /* Bypass Left Common Iliac Artery to Celiac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4J2" = "1" /* Bypass Left Common Iliac Artery to Mesenteric Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4J3" = "1" /* Bypass Left Common Iliac Artery to Right Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4J4" = "1" /* Bypass Left Common Iliac Artery to Left Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4J5" = "1" /* Bypass Left Common Iliac Artery to Bilateral Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4J6" = "1" /* Bypass Left Common Iliac Artery to Right Common Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4J7" = "1" /* Bypass Left Common Iliac Artery to Left Common Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4J8" = "1" /* Bypass Left Common Iliac Artery to Bilateral Common Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4J9" = "1" /* Bypass Left Common Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4JB" = "1" /* Bypass Left Common Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4JC" = "1" /* Bypass Left Common Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4JD" = "1" /* Bypass Left Common Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4JF" = "1" /* Bypass Left Common Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4JG" = "1" /* Bypass Left Common Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4JH" = "1" /* Bypass Left Common Iliac Artery to Right Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4JJ" = "1" /* Bypass Left Common Iliac Artery to Left Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4JK" = "1" /* Bypass Left Common Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4JQ" = "1" /* Bypass Left Common Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4JR" = "1" /* Bypass Left Common Iliac Artery to Lower Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041D4K0" = "1" /* Bypass Left Common Iliac Artery to Abdominal Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4K1" = "1" /* Bypass Left Common Iliac Artery to Celiac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4K2" = "1" /* Bypass Left Common Iliac Artery to Mesenteric Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4K3" = "1" /* Bypass Left Common Iliac Artery to Right Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4K4" = "1" /* Bypass Left Common Iliac Artery to Left Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4K5" = "1" /* Bypass Left Common Iliac Artery to Bilateral Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4K6" = "1" /* Bypass Left Common Iliac Artery to Right Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4K7" = "1" /* Bypass Left Common Iliac Artery to Left Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4K8" = "1" /* Bypass Left Common Iliac Artery to Bilateral Common Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4K9" = "1" /* Bypass Left Common Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4KB" = "1" /* Bypass Left Common Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4KC" = "1" /* Bypass Left Common Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4KD" = "1" /* Bypass Left Common Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4KF" = "1" /* Bypass Left Common Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4KG" = "1" /* Bypass Left Common Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4KH" = "1" /* Bypass Left Common Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4KJ" = "1" /* Bypass Left Common Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4KK" = "1" /* Bypass Left Common Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4KQ" = "1" /* Bypass Left Common Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4KR" = "1" /* Bypass Left Common Iliac Artery to Lower Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041D4Z0" = "1" /* Bypass Left Common Iliac Artery to Abdominal Aorta, Percutaneous Endoscopic Approach */
"041D4Z1" = "1" /* Bypass Left Common Iliac Artery to Celiac Artery, Percutaneous Endoscopic Approach */
"041D4Z2" = "1" /* Bypass Left Common Iliac Artery to Mesenteric Artery, Percutaneous Endoscopic Approach */
"041D4Z3" = "1" /* Bypass Left Common Iliac Artery to Right Renal Artery, Percutaneous Endoscopic Approach */
"041D4Z4" = "1" /* Bypass Left Common Iliac Artery to Left Renal Artery, Percutaneous Endoscopic Approach */
"041D4Z5" = "1" /* Bypass Left Common Iliac Artery to Bilateral Renal Artery, Percutaneous Endoscopic Approach */
"041D4Z6" = "1" /* Bypass Left Common Iliac Artery to Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"041D4Z7" = "1" /* Bypass Left Common Iliac Artery to Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"041D4Z8" = "1" /* Bypass Left Common Iliac Artery to Bilateral Common Iliac Arteries, Percutaneous Endoscopic Approach */
"041D4Z9" = "1" /* Bypass Left Common Iliac Artery to Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041D4ZB" = "1" /* Bypass Left Common Iliac Artery to Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041D4ZC" = "1" /* Bypass Left Common Iliac Artery to Bilateral Internal Iliac Arteries, Percutaneous Endoscopic Approach */
"041D4ZD" = "1" /* Bypass Left Common Iliac Artery to Right External Iliac Artery, Percutaneous Endoscopic Approach */
"041D4ZF" = "1" /* Bypass Left Common Iliac Artery to Left External Iliac Artery, Percutaneous Endoscopic Approach */
"041D4ZG" = "1" /* Bypass Left Common Iliac Artery to Bilateral External Iliac Arteries, Percutaneous Endoscopic Approach */
"041D4ZH" = "1" /* Bypass Left Common Iliac Artery to Right Femoral Artery, Percutaneous Endoscopic Approach */
"041D4ZJ" = "1" /* Bypass Left Common Iliac Artery to Left Femoral Artery, Percutaneous Endoscopic Approach */
"041D4ZK" = "1" /* Bypass Left Common Iliac Artery to Bilateral Femoral Arteries, Percutaneous Endoscopic Approach */
"041D4ZQ" = "1" /* Bypass Left Common Iliac Artery to Lower Extremity Artery, Percutaneous Endoscopic Approach */
"041D4ZR" = "1" /* Bypass Left Common Iliac Artery to Lower Artery, Percutaneous Endoscopic Approach */
"041E099" = "1" /* Bypass Right Internal Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041E09B" = "1" /* Bypass Right Internal Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041E09C" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041E09D" = "1" /* Bypass Right Internal Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041E09F" = "1" /* Bypass Right Internal Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041E09G" = "1" /* Bypass Right Internal Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041E09H" = "1" /* Bypass Right Internal Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Open Approach */
"041E09J" = "1" /* Bypass Right Internal Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Open Approach */
"041E09K" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Open Approach */
"041E09P" = "1" /* Bypass Right Internal Iliac Artery to Foot Artery with Autologous Venous Tissue, Open Approach */
"041E09Q" = "1" /* Bypass Right Internal Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Open Approach */
"041E0A9" = "1" /* Bypass Right Internal Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041E0AB" = "1" /* Bypass Right Internal Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041E0AC" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041E0AD" = "1" /* Bypass Right Internal Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041E0AF" = "1" /* Bypass Right Internal Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041E0AG" = "1" /* Bypass Right Internal Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041E0AH" = "1" /* Bypass Right Internal Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041E0AJ" = "1" /* Bypass Right Internal Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041E0AK" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Open Approach */
"041E0AP" = "1" /* Bypass Right Internal Iliac Artery to Foot Artery with Autologous Arterial Tissue, Open Approach */
"041E0AQ" = "1" /* Bypass Right Internal Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Open Approach */
"041E0J9" = "1" /* Bypass Right Internal Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041E0JB" = "1" /* Bypass Right Internal Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041E0JC" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Open Approach */
"041E0JD" = "1" /* Bypass Right Internal Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Open Approach */
"041E0JF" = "1" /* Bypass Right Internal Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Open Approach */
"041E0JG" = "1" /* Bypass Right Internal Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Open Approach */
"041E0JH" = "1" /* Bypass Right Internal Iliac Artery to Right Femoral Artery with Synthetic Substitute, Open Approach */
"041E0JJ" = "1" /* Bypass Right Internal Iliac Artery to Left Femoral Artery with Synthetic Substitute, Open Approach */
"041E0JK" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Open Approach */
"041E0JP" = "1" /* Bypass Right Internal Iliac Artery to Foot Artery with Synthetic Substitute, Open Approach */
"041E0JQ" = "1" /* Bypass Right Internal Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Open Approach */
"041E0K9" = "1" /* Bypass Right Internal Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041E0KB" = "1" /* Bypass Right Internal Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041E0KC" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041E0KD" = "1" /* Bypass Right Internal Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041E0KF" = "1" /* Bypass Right Internal Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041E0KG" = "1" /* Bypass Right Internal Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041E0KH" = "1" /* Bypass Right Internal Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041E0KJ" = "1" /* Bypass Right Internal Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041E0KK" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Open Approach */
"041E0KP" = "1" /* Bypass Right Internal Iliac Artery to Foot Artery with Nonautologous Tissue Substitute, Open Approach */
"041E0KQ" = "1" /* Bypass Right Internal Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Open Approach */
"041E0Z9" = "1" /* Bypass Right Internal Iliac Artery to Right Internal Iliac Artery, Open Approach */
"041E0ZB" = "1" /* Bypass Right Internal Iliac Artery to Left Internal Iliac Artery, Open Approach */
"041E0ZC" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Internal Iliac Arteries, Open Approach */
"041E0ZD" = "1" /* Bypass Right Internal Iliac Artery to Right External Iliac Artery, Open Approach */
"041E0ZF" = "1" /* Bypass Right Internal Iliac Artery to Left External Iliac Artery, Open Approach */
"041E0ZG" = "1" /* Bypass Right Internal Iliac Artery to Bilateral External Iliac Arteries, Open Approach */
"041E0ZH" = "1" /* Bypass Right Internal Iliac Artery to Right Femoral Artery, Open Approach */
"041E0ZJ" = "1" /* Bypass Right Internal Iliac Artery to Left Femoral Artery, Open Approach */
"041E0ZK" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Femoral Arteries, Open Approach */
"041E0ZP" = "1" /* Bypass Right Internal Iliac Artery to Foot Artery, Open Approach */
"041E0ZQ" = "1" /* Bypass Right Internal Iliac Artery to Lower Extremity Artery, Open Approach */
"041E499" = "1" /* Bypass Right Internal Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041E49B" = "1" /* Bypass Right Internal Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041E49C" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041E49D" = "1" /* Bypass Right Internal Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041E49F" = "1" /* Bypass Right Internal Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041E49G" = "1" /* Bypass Right Internal Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041E49H" = "1" /* Bypass Right Internal Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041E49J" = "1" /* Bypass Right Internal Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041E49K" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041E49P" = "1" /* Bypass Right Internal Iliac Artery to Foot Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041E49Q" = "1" /* Bypass Right Internal Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041E4A9" = "1" /* Bypass Right Internal Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041E4AB" = "1" /* Bypass Right Internal Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041E4AC" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041E4AD" = "1" /* Bypass Right Internal Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041E4AF" = "1" /* Bypass Right Internal Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041E4AG" = "1" /* Bypass Right Internal Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041E4AH" = "1" /* Bypass Right Internal Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041E4AJ" = "1" /* Bypass Right Internal Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041E4AK" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041E4AP" = "1" /* Bypass Right Internal Iliac Artery to Foot Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041E4AQ" = "1" /* Bypass Right Internal Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041E4J9" = "1" /* Bypass Right Internal Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041E4JB" = "1" /* Bypass Right Internal Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041E4JC" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041E4JD" = "1" /* Bypass Right Internal Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041E4JF" = "1" /* Bypass Right Internal Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041E4JG" = "1" /* Bypass Right Internal Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041E4JH" = "1" /* Bypass Right Internal Iliac Artery to Right Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041E4JJ" = "1" /* Bypass Right Internal Iliac Artery to Left Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041E4JK" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041E4JP" = "1" /* Bypass Right Internal Iliac Artery to Foot Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041E4JQ" = "1" /* Bypass Right Internal Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041E4K9" = "1" /* Bypass Right Internal Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041E4KB" = "1" /* Bypass Right Internal Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041E4KC" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041E4KD" = "1" /* Bypass Right Internal Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041E4KF" = "1" /* Bypass Right Internal Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041E4KG" = "1" /* Bypass Right Internal Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041E4KH" = "1" /* Bypass Right Internal Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041E4KJ" = "1" /* Bypass Right Internal Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041E4KK" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041E4KP" = "1" /* Bypass Right Internal Iliac Artery to Foot Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041E4KQ" = "1" /* Bypass Right Internal Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041E4Z9" = "1" /* Bypass Right Internal Iliac Artery to Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041E4ZB" = "1" /* Bypass Right Internal Iliac Artery to Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041E4ZC" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Internal Iliac Arteries, Percutaneous Endoscopic Approach */
"041E4ZD" = "1" /* Bypass Right Internal Iliac Artery to Right External Iliac Artery, Percutaneous Endoscopic Approach */
"041E4ZF" = "1" /* Bypass Right Internal Iliac Artery to Left External Iliac Artery, Percutaneous Endoscopic Approach */
"041E4ZG" = "1" /* Bypass Right Internal Iliac Artery to Bilateral External Iliac Arteries, Percutaneous Endoscopic Approach */
"041E4ZH" = "1" /* Bypass Right Internal Iliac Artery to Right Femoral Artery, Percutaneous Endoscopic Approach */
"041E4ZJ" = "1" /* Bypass Right Internal Iliac Artery to Left Femoral Artery, Percutaneous Endoscopic Approach */
"041E4ZK" = "1" /* Bypass Right Internal Iliac Artery to Bilateral Femoral Arteries, Percutaneous Endoscopic Approach */
"041E4ZP" = "1" /* Bypass Right Internal Iliac Artery to Foot Artery, Percutaneous Endoscopic Approach */
"041E4ZQ" = "1" /* Bypass Right Internal Iliac Artery to Lower Extremity Artery, Percutaneous Endoscopic Approach */
"041F099" = "1" /* Bypass Left Internal Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041F09B" = "1" /* Bypass Left Internal Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041F09C" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041F09D" = "1" /* Bypass Left Internal Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041F09F" = "1" /* Bypass Left Internal Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041F09G" = "1" /* Bypass Left Internal Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041F09H" = "1" /* Bypass Left Internal Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Open Approach */
"041F09J" = "1" /* Bypass Left Internal Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Open Approach */
"041F09K" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Open Approach */
"041F09P" = "1" /* Bypass Left Internal Iliac Artery to Foot Artery with Autologous Venous Tissue, Open Approach */
"041F09Q" = "1" /* Bypass Left Internal Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Open Approach */
"041F0A9" = "1" /* Bypass Left Internal Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041F0AB" = "1" /* Bypass Left Internal Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041F0AC" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041F0AD" = "1" /* Bypass Left Internal Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041F0AF" = "1" /* Bypass Left Internal Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041F0AG" = "1" /* Bypass Left Internal Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041F0AH" = "1" /* Bypass Left Internal Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041F0AJ" = "1" /* Bypass Left Internal Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041F0AK" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Open Approach */
"041F0AP" = "1" /* Bypass Left Internal Iliac Artery to Foot Artery with Autologous Arterial Tissue, Open Approach */
"041F0AQ" = "1" /* Bypass Left Internal Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Open Approach */
"041F0J9" = "1" /* Bypass Left Internal Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041F0JB" = "1" /* Bypass Left Internal Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041F0JC" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Open Approach */
"041F0JD" = "1" /* Bypass Left Internal Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Open Approach */
"041F0JF" = "1" /* Bypass Left Internal Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Open Approach */
"041F0JG" = "1" /* Bypass Left Internal Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Open Approach */
"041F0JH" = "1" /* Bypass Left Internal Iliac Artery to Right Femoral Artery with Synthetic Substitute, Open Approach */
"041F0JJ" = "1" /* Bypass Left Internal Iliac Artery to Left Femoral Artery with Synthetic Substitute, Open Approach */
"041F0JK" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Open Approach */
"041F0JP" = "1" /* Bypass Left Internal Iliac Artery to Foot Artery with Synthetic Substitute, Open Approach */
"041F0JQ" = "1" /* Bypass Left Internal Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Open Approach */
"041F0K9" = "1" /* Bypass Left Internal Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041F0KB" = "1" /* Bypass Left Internal Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041F0KC" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041F0KD" = "1" /* Bypass Left Internal Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041F0KF" = "1" /* Bypass Left Internal Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041F0KG" = "1" /* Bypass Left Internal Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041F0KH" = "1" /* Bypass Left Internal Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041F0KJ" = "1" /* Bypass Left Internal Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041F0KK" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Open Approach */
"041F0KP" = "1" /* Bypass Left Internal Iliac Artery to Foot Artery with Nonautologous Tissue Substitute, Open Approach */
"041F0KQ" = "1" /* Bypass Left Internal Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Open Approach */
"041F0Z9" = "1" /* Bypass Left Internal Iliac Artery to Right Internal Iliac Artery, Open Approach */
"041F0ZB" = "1" /* Bypass Left Internal Iliac Artery to Left Internal Iliac Artery, Open Approach */
"041F0ZC" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Internal Iliac Arteries, Open Approach */
"041F0ZD" = "1" /* Bypass Left Internal Iliac Artery to Right External Iliac Artery, Open Approach */
"041F0ZF" = "1" /* Bypass Left Internal Iliac Artery to Left External Iliac Artery, Open Approach */
"041F0ZG" = "1" /* Bypass Left Internal Iliac Artery to Bilateral External Iliac Arteries, Open Approach */
"041F0ZH" = "1" /* Bypass Left Internal Iliac Artery to Right Femoral Artery, Open Approach */
"041F0ZJ" = "1" /* Bypass Left Internal Iliac Artery to Left Femoral Artery, Open Approach */
"041F0ZK" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Femoral Arteries, Open Approach */
"041F0ZP" = "1" /* Bypass Left Internal Iliac Artery to Foot Artery, Open Approach */
"041F0ZQ" = "1" /* Bypass Left Internal Iliac Artery to Lower Extremity Artery, Open Approach */
"041F499" = "1" /* Bypass Left Internal Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041F49B" = "1" /* Bypass Left Internal Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041F49C" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041F49D" = "1" /* Bypass Left Internal Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041F49F" = "1" /* Bypass Left Internal Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041F49G" = "1" /* Bypass Left Internal Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041F49H" = "1" /* Bypass Left Internal Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041F49J" = "1" /* Bypass Left Internal Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041F49K" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041F49P" = "1" /* Bypass Left Internal Iliac Artery to Foot Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041F49Q" = "1" /* Bypass Left Internal Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041F4A9" = "1" /* Bypass Left Internal Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041F4AB" = "1" /* Bypass Left Internal Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041F4AC" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041F4AD" = "1" /* Bypass Left Internal Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041F4AF" = "1" /* Bypass Left Internal Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041F4AG" = "1" /* Bypass Left Internal Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041F4AH" = "1" /* Bypass Left Internal Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041F4AJ" = "1" /* Bypass Left Internal Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041F4AK" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041F4AP" = "1" /* Bypass Left Internal Iliac Artery to Foot Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041F4AQ" = "1" /* Bypass Left Internal Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041F4J9" = "1" /* Bypass Left Internal Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041F4JB" = "1" /* Bypass Left Internal Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041F4JC" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041F4JD" = "1" /* Bypass Left Internal Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041F4JF" = "1" /* Bypass Left Internal Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041F4JG" = "1" /* Bypass Left Internal Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041F4JH" = "1" /* Bypass Left Internal Iliac Artery to Right Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041F4JJ" = "1" /* Bypass Left Internal Iliac Artery to Left Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041F4JK" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041F4JP" = "1" /* Bypass Left Internal Iliac Artery to Foot Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041F4JQ" = "1" /* Bypass Left Internal Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041F4K9" = "1" /* Bypass Left Internal Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041F4KB" = "1" /* Bypass Left Internal Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041F4KC" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041F4KD" = "1" /* Bypass Left Internal Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041F4KF" = "1" /* Bypass Left Internal Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041F4KG" = "1" /* Bypass Left Internal Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041F4KH" = "1" /* Bypass Left Internal Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041F4KJ" = "1" /* Bypass Left Internal Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041F4KK" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041F4KP" = "1" /* Bypass Left Internal Iliac Artery to Foot Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041F4KQ" = "1" /* Bypass Left Internal Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041F4Z9" = "1" /* Bypass Left Internal Iliac Artery to Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041F4ZB" = "1" /* Bypass Left Internal Iliac Artery to Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041F4ZC" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Internal Iliac Arteries, Percutaneous Endoscopic Approach */
"041F4ZD" = "1" /* Bypass Left Internal Iliac Artery to Right External Iliac Artery, Percutaneous Endoscopic Approach */
"041F4ZF" = "1" /* Bypass Left Internal Iliac Artery to Left External Iliac Artery, Percutaneous Endoscopic Approach */
"041F4ZG" = "1" /* Bypass Left Internal Iliac Artery to Bilateral External Iliac Arteries, Percutaneous Endoscopic Approach */
"041F4ZH" = "1" /* Bypass Left Internal Iliac Artery to Right Femoral Artery, Percutaneous Endoscopic Approach */
"041F4ZJ" = "1" /* Bypass Left Internal Iliac Artery to Left Femoral Artery, Percutaneous Endoscopic Approach */
"041F4ZK" = "1" /* Bypass Left Internal Iliac Artery to Bilateral Femoral Arteries, Percutaneous Endoscopic Approach */
"041F4ZP" = "1" /* Bypass Left Internal Iliac Artery to Foot Artery, Percutaneous Endoscopic Approach */
"041F4ZQ" = "1" /* Bypass Left Internal Iliac Artery to Lower Extremity Artery, Percutaneous Endoscopic Approach */
"041H099" = "1" /* Bypass Right External Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041H09B" = "1" /* Bypass Right External Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041H09C" = "1" /* Bypass Right External Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041H09D" = "1" /* Bypass Right External Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041H09F" = "1" /* Bypass Right External Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041H09G" = "1" /* Bypass Right External Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041H09H" = "1" /* Bypass Right External Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Open Approach */
"041H09J" = "1" /* Bypass Right External Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Open Approach */
"041H09K" = "1" /* Bypass Right External Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Open Approach */
"041H09P" = "1" /* Bypass Right External Iliac Artery to Foot Artery with Autologous Venous Tissue, Open Approach */
"041H09Q" = "1" /* Bypass Right External Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Open Approach */
"041H0A9" = "1" /* Bypass Right External Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041H0AB" = "1" /* Bypass Right External Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041H0AC" = "1" /* Bypass Right External Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041H0AD" = "1" /* Bypass Right External Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041H0AF" = "1" /* Bypass Right External Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041H0AG" = "1" /* Bypass Right External Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041H0AH" = "1" /* Bypass Right External Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041H0AJ" = "1" /* Bypass Right External Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041H0AK" = "1" /* Bypass Right External Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Open Approach */
"041H0AP" = "1" /* Bypass Right External Iliac Artery to Foot Artery with Autologous Arterial Tissue, Open Approach */
"041H0AQ" = "1" /* Bypass Right External Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Open Approach */
"041H0J9" = "1" /* Bypass Right External Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041H0JB" = "1" /* Bypass Right External Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041H0JC" = "1" /* Bypass Right External Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Open Approach */
"041H0JD" = "1" /* Bypass Right External Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Open Approach */
"041H0JF" = "1" /* Bypass Right External Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Open Approach */
"041H0JG" = "1" /* Bypass Right External Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Open Approach */
"041H0JH" = "1" /* Bypass Right External Iliac Artery to Right Femoral Artery with Synthetic Substitute, Open Approach */
"041H0JJ" = "1" /* Bypass Right External Iliac Artery to Left Femoral Artery with Synthetic Substitute, Open Approach */
"041H0JK" = "1" /* Bypass Right External Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Open Approach */
"041H0JP" = "1" /* Bypass Right External Iliac Artery to Foot Artery with Synthetic Substitute, Open Approach */
"041H0JQ" = "1" /* Bypass Right External Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Open Approach */
"041H0K9" = "1" /* Bypass Right External Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041H0KB" = "1" /* Bypass Right External Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041H0KC" = "1" /* Bypass Right External Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041H0KD" = "1" /* Bypass Right External Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041H0KF" = "1" /* Bypass Right External Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041H0KG" = "1" /* Bypass Right External Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041H0KH" = "1" /* Bypass Right External Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041H0KJ" = "1" /* Bypass Right External Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041H0KK" = "1" /* Bypass Right External Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Open Approach */
"041H0KP" = "1" /* Bypass Right External Iliac Artery to Foot Artery with Nonautologous Tissue Substitute, Open Approach */
"041H0KQ" = "1" /* Bypass Right External Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Open Approach */
"041H0Z9" = "1" /* Bypass Right External Iliac Artery to Right Internal Iliac Artery, Open Approach */
"041H0ZB" = "1" /* Bypass Right External Iliac Artery to Left Internal Iliac Artery, Open Approach */
"041H0ZC" = "1" /* Bypass Right External Iliac Artery to Bilateral Internal Iliac Arteries, Open Approach */
"041H0ZD" = "1" /* Bypass Right External Iliac Artery to Right External Iliac Artery, Open Approach */
"041H0ZF" = "1" /* Bypass Right External Iliac Artery to Left External Iliac Artery, Open Approach */
"041H0ZG" = "1" /* Bypass Right External Iliac Artery to Bilateral External Iliac Arteries, Open Approach */
"041H0ZH" = "1" /* Bypass Right External Iliac Artery to Right Femoral Artery, Open Approach */
"041H0ZJ" = "1" /* Bypass Right External Iliac Artery to Left Femoral Artery, Open Approach */
"041H0ZK" = "1" /* Bypass Right External Iliac Artery to Bilateral Femoral Arteries, Open Approach */
"041H0ZP" = "1" /* Bypass Right External Iliac Artery to Foot Artery, Open Approach */
"041H0ZQ" = "1" /* Bypass Right External Iliac Artery to Lower Extremity Artery, Open Approach */
"041H499" = "1" /* Bypass Right External Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041H49B" = "1" /* Bypass Right External Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041H49C" = "1" /* Bypass Right External Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041H49D" = "1" /* Bypass Right External Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041H49F" = "1" /* Bypass Right External Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041H49G" = "1" /* Bypass Right External Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041H49H" = "1" /* Bypass Right External Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041H49J" = "1" /* Bypass Right External Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041H49K" = "1" /* Bypass Right External Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041H49P" = "1" /* Bypass Right External Iliac Artery to Foot Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041H49Q" = "1" /* Bypass Right External Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041H4A9" = "1" /* Bypass Right External Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041H4AB" = "1" /* Bypass Right External Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041H4AC" = "1" /* Bypass Right External Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041H4AD" = "1" /* Bypass Right External Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041H4AF" = "1" /* Bypass Right External Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041H4AG" = "1" /* Bypass Right External Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041H4AH" = "1" /* Bypass Right External Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041H4AJ" = "1" /* Bypass Right External Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041H4AK" = "1" /* Bypass Right External Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041H4AP" = "1" /* Bypass Right External Iliac Artery to Foot Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041H4AQ" = "1" /* Bypass Right External Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041H4J9" = "1" /* Bypass Right External Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041H4JB" = "1" /* Bypass Right External Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041H4JC" = "1" /* Bypass Right External Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041H4JD" = "1" /* Bypass Right External Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041H4JF" = "1" /* Bypass Right External Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041H4JG" = "1" /* Bypass Right External Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041H4JH" = "1" /* Bypass Right External Iliac Artery to Right Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041H4JJ" = "1" /* Bypass Right External Iliac Artery to Left Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041H4JK" = "1" /* Bypass Right External Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041H4JP" = "1" /* Bypass Right External Iliac Artery to Foot Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041H4JQ" = "1" /* Bypass Right External Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041H4K9" = "1" /* Bypass Right External Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041H4KB" = "1" /* Bypass Right External Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041H4KC" = "1" /* Bypass Right External Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041H4KD" = "1" /* Bypass Right External Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041H4KF" = "1" /* Bypass Right External Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041H4KG" = "1" /* Bypass Right External Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041H4KH" = "1" /* Bypass Right External Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041H4KJ" = "1" /* Bypass Right External Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041H4KK" = "1" /* Bypass Right External Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041H4KP" = "1" /* Bypass Right External Iliac Artery to Foot Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041H4KQ" = "1" /* Bypass Right External Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041H4Z9" = "1" /* Bypass Right External Iliac Artery to Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041H4ZB" = "1" /* Bypass Right External Iliac Artery to Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041H4ZC" = "1" /* Bypass Right External Iliac Artery to Bilateral Internal Iliac Arteries, Percutaneous Endoscopic Approach */
"041H4ZD" = "1" /* Bypass Right External Iliac Artery to Right External Iliac Artery, Percutaneous Endoscopic Approach */
"041H4ZF" = "1" /* Bypass Right External Iliac Artery to Left External Iliac Artery, Percutaneous Endoscopic Approach */
"041H4ZG" = "1" /* Bypass Right External Iliac Artery to Bilateral External Iliac Arteries, Percutaneous Endoscopic Approach */
"041H4ZH" = "1" /* Bypass Right External Iliac Artery to Right Femoral Artery, Percutaneous Endoscopic Approach */
"041H4ZJ" = "1" /* Bypass Right External Iliac Artery to Left Femoral Artery, Percutaneous Endoscopic Approach */
"041H4ZK" = "1" /* Bypass Right External Iliac Artery to Bilateral Femoral Arteries, Percutaneous Endoscopic Approach */
"041H4ZP" = "1" /* Bypass Right External Iliac Artery to Foot Artery, Percutaneous Endoscopic Approach */
"041H4ZQ" = "1" /* Bypass Right External Iliac Artery to Lower Extremity Artery, Percutaneous Endoscopic Approach */
"041J099" = "1" /* Bypass Left External Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041J09B" = "1" /* Bypass Left External Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041J09C" = "1" /* Bypass Left External Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041J09D" = "1" /* Bypass Left External Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041J09F" = "1" /* Bypass Left External Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041J09G" = "1" /* Bypass Left External Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041J09H" = "1" /* Bypass Left External Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Open Approach */
"041J09J" = "1" /* Bypass Left External Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Open Approach */
"041J09K" = "1" /* Bypass Left External Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Open Approach */
"041J09P" = "1" /* Bypass Left External Iliac Artery to Foot Artery with Autologous Venous Tissue, Open Approach */
"041J09Q" = "1" /* Bypass Left External Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Open Approach */
"041J0A9" = "1" /* Bypass Left External Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041J0AB" = "1" /* Bypass Left External Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041J0AC" = "1" /* Bypass Left External Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041J0AD" = "1" /* Bypass Left External Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041J0AF" = "1" /* Bypass Left External Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"041J0AG" = "1" /* Bypass Left External Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"041J0AH" = "1" /* Bypass Left External Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041J0AJ" = "1" /* Bypass Left External Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041J0AK" = "1" /* Bypass Left External Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Open Approach */
"041J0AP" = "1" /* Bypass Left External Iliac Artery to Foot Artery with Autologous Arterial Tissue, Open Approach */
"041J0AQ" = "1" /* Bypass Left External Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Open Approach */
"041J0J9" = "1" /* Bypass Left External Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041J0JB" = "1" /* Bypass Left External Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Open Approach */
"041J0JC" = "1" /* Bypass Left External Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Open Approach */
"041J0JD" = "1" /* Bypass Left External Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Open Approach */
"041J0JF" = "1" /* Bypass Left External Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Open Approach */
"041J0JG" = "1" /* Bypass Left External Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Open Approach */
"041J0JH" = "1" /* Bypass Left External Iliac Artery to Right Femoral Artery with Synthetic Substitute, Open Approach */
"041J0JJ" = "1" /* Bypass Left External Iliac Artery to Left Femoral Artery with Synthetic Substitute, Open Approach */
"041J0JK" = "1" /* Bypass Left External Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Open Approach */
"041J0JP" = "1" /* Bypass Left External Iliac Artery to Foot Artery with Synthetic Substitute, Open Approach */
"041J0JQ" = "1" /* Bypass Left External Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Open Approach */
"041J0K9" = "1" /* Bypass Left External Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041J0KB" = "1" /* Bypass Left External Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041J0KC" = "1" /* Bypass Left External Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041J0KD" = "1" /* Bypass Left External Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041J0KF" = "1" /* Bypass Left External Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"041J0KG" = "1" /* Bypass Left External Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"041J0KH" = "1" /* Bypass Left External Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041J0KJ" = "1" /* Bypass Left External Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041J0KK" = "1" /* Bypass Left External Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Open Approach */
"041J0KP" = "1" /* Bypass Left External Iliac Artery to Foot Artery with Nonautologous Tissue Substitute, Open Approach */
"041J0KQ" = "1" /* Bypass Left External Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Open Approach */
"041J0Z9" = "1" /* Bypass Left External Iliac Artery to Right Internal Iliac Artery, Open Approach */
"041J0ZB" = "1" /* Bypass Left External Iliac Artery to Left Internal Iliac Artery, Open Approach */
"041J0ZC" = "1" /* Bypass Left External Iliac Artery to Bilateral Internal Iliac Arteries, Open Approach */
"041J0ZD" = "1" /* Bypass Left External Iliac Artery to Right External Iliac Artery, Open Approach */
"041J0ZF" = "1" /* Bypass Left External Iliac Artery to Left External Iliac Artery, Open Approach */
"041J0ZG" = "1" /* Bypass Left External Iliac Artery to Bilateral External Iliac Arteries, Open Approach */
"041J0ZH" = "1" /* Bypass Left External Iliac Artery to Right Femoral Artery, Open Approach */
"041J0ZJ" = "1" /* Bypass Left External Iliac Artery to Left Femoral Artery, Open Approach */
"041J0ZK" = "1" /* Bypass Left External Iliac Artery to Bilateral Femoral Arteries, Open Approach */
"041J0ZP" = "1" /* Bypass Left External Iliac Artery to Foot Artery, Open Approach */
"041J0ZQ" = "1" /* Bypass Left External Iliac Artery to Lower Extremity Artery, Open Approach */
"041J499" = "1" /* Bypass Left External Iliac Artery to Right Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041J49B" = "1" /* Bypass Left External Iliac Artery to Left Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041J49C" = "1" /* Bypass Left External Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041J49D" = "1" /* Bypass Left External Iliac Artery to Right External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041J49F" = "1" /* Bypass Left External Iliac Artery to Left External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041J49G" = "1" /* Bypass Left External Iliac Artery to Bilateral External Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041J49H" = "1" /* Bypass Left External Iliac Artery to Right Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041J49J" = "1" /* Bypass Left External Iliac Artery to Left Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041J49K" = "1" /* Bypass Left External Iliac Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041J49P" = "1" /* Bypass Left External Iliac Artery to Foot Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041J49Q" = "1" /* Bypass Left External Iliac Artery to Lower Extremity Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041J4A9" = "1" /* Bypass Left External Iliac Artery to Right Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041J4AB" = "1" /* Bypass Left External Iliac Artery to Left Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041J4AC" = "1" /* Bypass Left External Iliac Artery to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041J4AD" = "1" /* Bypass Left External Iliac Artery to Right External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041J4AF" = "1" /* Bypass Left External Iliac Artery to Left External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041J4AG" = "1" /* Bypass Left External Iliac Artery to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041J4AH" = "1" /* Bypass Left External Iliac Artery to Right Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041J4AJ" = "1" /* Bypass Left External Iliac Artery to Left Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041J4AK" = "1" /* Bypass Left External Iliac Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041J4AP" = "1" /* Bypass Left External Iliac Artery to Foot Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041J4AQ" = "1" /* Bypass Left External Iliac Artery to Lower Extremity Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041J4J9" = "1" /* Bypass Left External Iliac Artery to Right Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041J4JB" = "1" /* Bypass Left External Iliac Artery to Left Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041J4JC" = "1" /* Bypass Left External Iliac Artery to Bilateral Internal Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041J4JD" = "1" /* Bypass Left External Iliac Artery to Right External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041J4JF" = "1" /* Bypass Left External Iliac Artery to Left External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041J4JG" = "1" /* Bypass Left External Iliac Artery to Bilateral External Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041J4JH" = "1" /* Bypass Left External Iliac Artery to Right Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041J4JJ" = "1" /* Bypass Left External Iliac Artery to Left Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041J4JK" = "1" /* Bypass Left External Iliac Artery to Bilateral Femoral Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041J4JP" = "1" /* Bypass Left External Iliac Artery to Foot Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041J4JQ" = "1" /* Bypass Left External Iliac Artery to Lower Extremity Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041J4K9" = "1" /* Bypass Left External Iliac Artery to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041J4KB" = "1" /* Bypass Left External Iliac Artery to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041J4KC" = "1" /* Bypass Left External Iliac Artery to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041J4KD" = "1" /* Bypass Left External Iliac Artery to Right External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041J4KF" = "1" /* Bypass Left External Iliac Artery to Left External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041J4KG" = "1" /* Bypass Left External Iliac Artery to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041J4KH" = "1" /* Bypass Left External Iliac Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041J4KJ" = "1" /* Bypass Left External Iliac Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041J4KK" = "1" /* Bypass Left External Iliac Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041J4KP" = "1" /* Bypass Left External Iliac Artery to Foot Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041J4KQ" = "1" /* Bypass Left External Iliac Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041J4Z9" = "1" /* Bypass Left External Iliac Artery to Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041J4ZB" = "1" /* Bypass Left External Iliac Artery to Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"041J4ZC" = "1" /* Bypass Left External Iliac Artery to Bilateral Internal Iliac Arteries, Percutaneous Endoscopic Approach */
"041J4ZD" = "1" /* Bypass Left External Iliac Artery to Right External Iliac Artery, Percutaneous Endoscopic Approach */
"041J4ZF" = "1" /* Bypass Left External Iliac Artery to Left External Iliac Artery, Percutaneous Endoscopic Approach */
"041J4ZG" = "1" /* Bypass Left External Iliac Artery to Bilateral External Iliac Arteries, Percutaneous Endoscopic Approach */
"041J4ZH" = "1" /* Bypass Left External Iliac Artery to Right Femoral Artery, Percutaneous Endoscopic Approach */
"041J4ZJ" = "1" /* Bypass Left External Iliac Artery to Left Femoral Artery, Percutaneous Endoscopic Approach */
"041J4ZK" = "1" /* Bypass Left External Iliac Artery to Bilateral Femoral Arteries, Percutaneous Endoscopic Approach */
"041J4ZP" = "1" /* Bypass Left External Iliac Artery to Foot Artery, Percutaneous Endoscopic Approach */
"041J4ZQ" = "1" /* Bypass Left External Iliac Artery to Lower Extremity Artery, Percutaneous Endoscopic Approach */
"041K09H" = "1" /* Bypass Right Femoral Artery to Right Femoral Artery with Autologous Venous Tissue, Open Approach */
"041K09J" = "1" /* Bypass Right Femoral Artery to Left Femoral Artery with Autologous Venous Tissue, Open Approach */
"041K09K" = "1" /* Bypass Right Femoral Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Open Approach */
"041K09L" = "1" /* Bypass Right Femoral Artery to Popliteal Artery with Autologous Venous Tissue, Open Approach */
"041K09M" = "1" /* Bypass Right Femoral Artery to Peroneal Artery with Autologous Venous Tissue, Open Approach */
"041K09N" = "1" /* Bypass Right Femoral Artery to Posterior Tibial Artery with Autologous Venous Tissue, Open Approach */
"041K09P" = "1" /* Bypass Right Femoral Artery to Foot Artery with Autologous Venous Tissue, Open Approach */
"041K09Q" = "1" /* Bypass Right Femoral Artery to Lower Extremity Artery with Autologous Venous Tissue, Open Approach */
"041K09S" = "1" /* Bypass Right Femoral Artery to Lower Extremity Vein with Autologous Venous Tissue, Open Approach */
"041K0AH" = "1" /* Bypass Right Femoral Artery to Right Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041K0AJ" = "1" /* Bypass Right Femoral Artery to Left Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041K0AK" = "1" /* Bypass Right Femoral Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Open Approach */
"041K0AL" = "1" /* Bypass Right Femoral Artery to Popliteal Artery with Autologous Arterial Tissue, Open Approach */
"041K0AM" = "1" /* Bypass Right Femoral Artery to Peroneal Artery with Autologous Arterial Tissue, Open Approach */
"041K0AN" = "1" /* Bypass Right Femoral Artery to Posterior Tibial Artery with Autologous Arterial Tissue, Open Approach */
"041K0AP" = "1" /* Bypass Right Femoral Artery to Foot Artery with Autologous Arterial Tissue, Open Approach */
"041K0AQ" = "1" /* Bypass Right Femoral Artery to Lower Extremity Artery with Autologous Arterial Tissue, Open Approach */
"041K0AS" = "1" /* Bypass Right Femoral Artery to Lower Extremity Vein with Autologous Arterial Tissue, Open Approach */
"041K0JH" = "1" /* Bypass Right Femoral Artery to Right Femoral Artery with Synthetic Substitute, Open Approach */
"041K0JJ" = "1" /* Bypass Right Femoral Artery to Left Femoral Artery with Synthetic Substitute, Open Approach */
"041K0JK" = "1" /* Bypass Right Femoral Artery to Bilateral Femoral Arteries with Synthetic Substitute, Open Approach */
"041K0JL" = "1" /* Bypass Right Femoral Artery to Popliteal Artery with Synthetic Substitute, Open Approach */
"041K0JM" = "1" /* Bypass Right Femoral Artery to Peroneal Artery with Synthetic Substitute, Open Approach */
"041K0JN" = "1" /* Bypass Right Femoral Artery to Posterior Tibial Artery with Synthetic Substitute, Open Approach */
"041K0JP" = "1" /* Bypass Right Femoral Artery to Foot Artery with Synthetic Substitute, Open Approach */
"041K0JQ" = "1" /* Bypass Right Femoral Artery to Lower Extremity Artery with Synthetic Substitute, Open Approach */
"041K0JS" = "1" /* Bypass Right Femoral Artery to Lower Extremity Vein with Synthetic Substitute, Open Approach */
"041K0KH" = "1" /* Bypass Right Femoral Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041K0KJ" = "1" /* Bypass Right Femoral Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041K0KK" = "1" /* Bypass Right Femoral Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Open Approach */
"041K0KL" = "1" /* Bypass Right Femoral Artery to Popliteal Artery with Nonautologous Tissue Substitute, Open Approach */
"041K0KM" = "1" /* Bypass Right Femoral Artery to Peroneal Artery with Nonautologous Tissue Substitute, Open Approach */
"041K0KN" = "1" /* Bypass Right Femoral Artery to Posterior Tibial Artery with Nonautologous Tissue Substitute, Open Approach */
"041K0KP" = "1" /* Bypass Right Femoral Artery to Foot Artery with Nonautologous Tissue Substitute, Open Approach */
"041K0KQ" = "1" /* Bypass Right Femoral Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Open Approach */
"041K0KS" = "1" /* Bypass Right Femoral Artery to Lower Extremity Vein with Nonautologous Tissue Substitute, Open Approach */
"041K0ZH" = "1" /* Bypass Right Femoral Artery to Right Femoral Artery, Open Approach */
"041K0ZJ" = "1" /* Bypass Right Femoral Artery to Left Femoral Artery, Open Approach */
"041K0ZK" = "1" /* Bypass Right Femoral Artery to Bilateral Femoral Arteries, Open Approach */
"041K0ZL" = "1" /* Bypass Right Femoral Artery to Popliteal Artery, Open Approach */
"041K0ZM" = "1" /* Bypass Right Femoral Artery to Peroneal Artery, Open Approach */
"041K0ZN" = "1" /* Bypass Right Femoral Artery to Posterior Tibial Artery, Open Approach */
"041K0ZP" = "1" /* Bypass Right Femoral Artery to Foot Artery, Open Approach */
"041K0ZQ" = "1" /* Bypass Right Femoral Artery to Lower Extremity Artery, Open Approach */
"041K0ZS" = "1" /* Bypass Right Femoral Artery to Lower Extremity Vein, Open Approach */
"041K49H" = "1" /* Bypass Right Femoral Artery to Right Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041K49J" = "1" /* Bypass Right Femoral Artery to Left Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041K49K" = "1" /* Bypass Right Femoral Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041K49L" = "1" /* Bypass Right Femoral Artery to Popliteal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041K49M" = "1" /* Bypass Right Femoral Artery to Peroneal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041K49N" = "1" /* Bypass Right Femoral Artery to Posterior Tibial Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041K49P" = "1" /* Bypass Right Femoral Artery to Foot Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041K49Q" = "1" /* Bypass Right Femoral Artery to Lower Extremity Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041K49S" = "1" /* Bypass Right Femoral Artery to Lower Extremity Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041K4AH" = "1" /* Bypass Right Femoral Artery to Right Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041K4AJ" = "1" /* Bypass Right Femoral Artery to Left Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041K4AK" = "1" /* Bypass Right Femoral Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041K4AL" = "1" /* Bypass Right Femoral Artery to Popliteal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041K4AM" = "1" /* Bypass Right Femoral Artery to Peroneal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041K4AN" = "1" /* Bypass Right Femoral Artery to Posterior Tibial Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041K4AP" = "1" /* Bypass Right Femoral Artery to Foot Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041K4AQ" = "1" /* Bypass Right Femoral Artery to Lower Extremity Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041K4AS" = "1" /* Bypass Right Femoral Artery to Lower Extremity Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041K4JH" = "1" /* Bypass Right Femoral Artery to Right Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041K4JJ" = "1" /* Bypass Right Femoral Artery to Left Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041K4JK" = "1" /* Bypass Right Femoral Artery to Bilateral Femoral Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041K4JL" = "1" /* Bypass Right Femoral Artery to Popliteal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041K4JM" = "1" /* Bypass Right Femoral Artery to Peroneal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041K4JN" = "1" /* Bypass Right Femoral Artery to Posterior Tibial Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041K4JP" = "1" /* Bypass Right Femoral Artery to Foot Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041K4JQ" = "1" /* Bypass Right Femoral Artery to Lower Extremity Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041K4JS" = "1" /* Bypass Right Femoral Artery to Lower Extremity Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041K4KH" = "1" /* Bypass Right Femoral Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041K4KJ" = "1" /* Bypass Right Femoral Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041K4KK" = "1" /* Bypass Right Femoral Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041K4KL" = "1" /* Bypass Right Femoral Artery to Popliteal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041K4KM" = "1" /* Bypass Right Femoral Artery to Peroneal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041K4KN" = "1" /* Bypass Right Femoral Artery to Posterior Tibial Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041K4KP" = "1" /* Bypass Right Femoral Artery to Foot Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041K4KQ" = "1" /* Bypass Right Femoral Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041K4KS" = "1" /* Bypass Right Femoral Artery to Lower Extremity Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041K4ZH" = "1" /* Bypass Right Femoral Artery to Right Femoral Artery, Percutaneous Endoscopic Approach */
"041K4ZJ" = "1" /* Bypass Right Femoral Artery to Left Femoral Artery, Percutaneous Endoscopic Approach */
"041K4ZK" = "1" /* Bypass Right Femoral Artery to Bilateral Femoral Arteries, Percutaneous Endoscopic Approach */
"041K4ZL" = "1" /* Bypass Right Femoral Artery to Popliteal Artery, Percutaneous Endoscopic Approach */
"041K4ZM" = "1" /* Bypass Right Femoral Artery to Peroneal Artery, Percutaneous Endoscopic Approach */
"041K4ZN" = "1" /* Bypass Right Femoral Artery to Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"041K4ZP" = "1" /* Bypass Right Femoral Artery to Foot Artery, Percutaneous Endoscopic Approach */
"041K4ZQ" = "1" /* Bypass Right Femoral Artery to Lower Extremity Artery, Percutaneous Endoscopic Approach */
"041K4ZS" = "1" /* Bypass Right Femoral Artery to Lower Extremity Vein, Percutaneous Endoscopic Approach */
"041L09H" = "1" /* Bypass Left Femoral Artery to Right Femoral Artery with Autologous Venous Tissue, Open Approach */
"041L09J" = "1" /* Bypass Left Femoral Artery to Left Femoral Artery with Autologous Venous Tissue, Open Approach */
"041L09K" = "1" /* Bypass Left Femoral Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Open Approach */
"041L09L" = "1" /* Bypass Left Femoral Artery to Popliteal Artery with Autologous Venous Tissue, Open Approach */
"041L09M" = "1" /* Bypass Left Femoral Artery to Peroneal Artery with Autologous Venous Tissue, Open Approach */
"041L09N" = "1" /* Bypass Left Femoral Artery to Posterior Tibial Artery with Autologous Venous Tissue, Open Approach */
"041L09P" = "1" /* Bypass Left Femoral Artery to Foot Artery with Autologous Venous Tissue, Open Approach */
"041L09Q" = "1" /* Bypass Left Femoral Artery to Lower Extremity Artery with Autologous Venous Tissue, Open Approach */
"041L09S" = "1" /* Bypass Left Femoral Artery to Lower Extremity Vein with Autologous Venous Tissue, Open Approach */
"041L0AH" = "1" /* Bypass Left Femoral Artery to Right Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041L0AJ" = "1" /* Bypass Left Femoral Artery to Left Femoral Artery with Autologous Arterial Tissue, Open Approach */
"041L0AK" = "1" /* Bypass Left Femoral Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Open Approach */
"041L0AL" = "1" /* Bypass Left Femoral Artery to Popliteal Artery with Autologous Arterial Tissue, Open Approach */
"041L0AM" = "1" /* Bypass Left Femoral Artery to Peroneal Artery with Autologous Arterial Tissue, Open Approach */
"041L0AN" = "1" /* Bypass Left Femoral Artery to Posterior Tibial Artery with Autologous Arterial Tissue, Open Approach */
"041L0AP" = "1" /* Bypass Left Femoral Artery to Foot Artery with Autologous Arterial Tissue, Open Approach */
"041L0AQ" = "1" /* Bypass Left Femoral Artery to Lower Extremity Artery with Autologous Arterial Tissue, Open Approach */
"041L0AS" = "1" /* Bypass Left Femoral Artery to Lower Extremity Vein with Autologous Arterial Tissue, Open Approach */
"041L0JH" = "1" /* Bypass Left Femoral Artery to Right Femoral Artery with Synthetic Substitute, Open Approach */
"041L0JJ" = "1" /* Bypass Left Femoral Artery to Left Femoral Artery with Synthetic Substitute, Open Approach */
"041L0JK" = "1" /* Bypass Left Femoral Artery to Bilateral Femoral Arteries with Synthetic Substitute, Open Approach */
"041L0JL" = "1" /* Bypass Left Femoral Artery to Popliteal Artery with Synthetic Substitute, Open Approach */
"041L0JM" = "1" /* Bypass Left Femoral Artery to Peroneal Artery with Synthetic Substitute, Open Approach */
"041L0JN" = "1" /* Bypass Left Femoral Artery to Posterior Tibial Artery with Synthetic Substitute, Open Approach */
"041L0JP" = "1" /* Bypass Left Femoral Artery to Foot Artery with Synthetic Substitute, Open Approach */
"041L0JQ" = "1" /* Bypass Left Femoral Artery to Lower Extremity Artery with Synthetic Substitute, Open Approach */
"041L0JS" = "1" /* Bypass Left Femoral Artery to Lower Extremity Vein with Synthetic Substitute, Open Approach */
"041L0KH" = "1" /* Bypass Left Femoral Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041L0KJ" = "1" /* Bypass Left Femoral Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"041L0KK" = "1" /* Bypass Left Femoral Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Open Approach */
"041L0KL" = "1" /* Bypass Left Femoral Artery to Popliteal Artery with Nonautologous Tissue Substitute, Open Approach */
"041L0KM" = "1" /* Bypass Left Femoral Artery to Peroneal Artery with Nonautologous Tissue Substitute, Open Approach */
"041L0KN" = "1" /* Bypass Left Femoral Artery to Posterior Tibial Artery with Nonautologous Tissue Substitute, Open Approach */
"041L0KP" = "1" /* Bypass Left Femoral Artery to Foot Artery with Nonautologous Tissue Substitute, Open Approach */
"041L0KQ" = "1" /* Bypass Left Femoral Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Open Approach */
"041L0KS" = "1" /* Bypass Left Femoral Artery to Lower Extremity Vein with Nonautologous Tissue Substitute, Open Approach */
"041L0ZH" = "1" /* Bypass Left Femoral Artery to Right Femoral Artery, Open Approach */
"041L0ZJ" = "1" /* Bypass Left Femoral Artery to Left Femoral Artery, Open Approach */
"041L0ZK" = "1" /* Bypass Left Femoral Artery to Bilateral Femoral Arteries, Open Approach */
"041L0ZL" = "1" /* Bypass Left Femoral Artery to Popliteal Artery, Open Approach */
"041L0ZM" = "1" /* Bypass Left Femoral Artery to Peroneal Artery, Open Approach */
"041L0ZN" = "1" /* Bypass Left Femoral Artery to Posterior Tibial Artery, Open Approach */
"041L0ZP" = "1" /* Bypass Left Femoral Artery to Foot Artery, Open Approach */
"041L0ZQ" = "1" /* Bypass Left Femoral Artery to Lower Extremity Artery, Open Approach */
"041L0ZS" = "1" /* Bypass Left Femoral Artery to Lower Extremity Vein, Open Approach */
"041L49H" = "1" /* Bypass Left Femoral Artery to Right Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041L49J" = "1" /* Bypass Left Femoral Artery to Left Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041L49K" = "1" /* Bypass Left Femoral Artery to Bilateral Femoral Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041L49L" = "1" /* Bypass Left Femoral Artery to Popliteal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041L49M" = "1" /* Bypass Left Femoral Artery to Peroneal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041L49N" = "1" /* Bypass Left Femoral Artery to Posterior Tibial Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041L49P" = "1" /* Bypass Left Femoral Artery to Foot Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041L49Q" = "1" /* Bypass Left Femoral Artery to Lower Extremity Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041L49S" = "1" /* Bypass Left Femoral Artery to Lower Extremity Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041L4AH" = "1" /* Bypass Left Femoral Artery to Right Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041L4AJ" = "1" /* Bypass Left Femoral Artery to Left Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041L4AK" = "1" /* Bypass Left Femoral Artery to Bilateral Femoral Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041L4AL" = "1" /* Bypass Left Femoral Artery to Popliteal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041L4AM" = "1" /* Bypass Left Femoral Artery to Peroneal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041L4AN" = "1" /* Bypass Left Femoral Artery to Posterior Tibial Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041L4AP" = "1" /* Bypass Left Femoral Artery to Foot Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041L4AQ" = "1" /* Bypass Left Femoral Artery to Lower Extremity Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041L4AS" = "1" /* Bypass Left Femoral Artery to Lower Extremity Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041L4JH" = "1" /* Bypass Left Femoral Artery to Right Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041L4JJ" = "1" /* Bypass Left Femoral Artery to Left Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041L4JK" = "1" /* Bypass Left Femoral Artery to Bilateral Femoral Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041L4JL" = "1" /* Bypass Left Femoral Artery to Popliteal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041L4JM" = "1" /* Bypass Left Femoral Artery to Peroneal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041L4JN" = "1" /* Bypass Left Femoral Artery to Posterior Tibial Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041L4JP" = "1" /* Bypass Left Femoral Artery to Foot Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041L4JQ" = "1" /* Bypass Left Femoral Artery to Lower Extremity Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041L4JS" = "1" /* Bypass Left Femoral Artery to Lower Extremity Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041L4KH" = "1" /* Bypass Left Femoral Artery to Right Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041L4KJ" = "1" /* Bypass Left Femoral Artery to Left Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041L4KK" = "1" /* Bypass Left Femoral Artery to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041L4KL" = "1" /* Bypass Left Femoral Artery to Popliteal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041L4KM" = "1" /* Bypass Left Femoral Artery to Peroneal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041L4KN" = "1" /* Bypass Left Femoral Artery to Posterior Tibial Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041L4KP" = "1" /* Bypass Left Femoral Artery to Foot Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041L4KQ" = "1" /* Bypass Left Femoral Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041L4KS" = "1" /* Bypass Left Femoral Artery to Lower Extremity Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041L4ZH" = "1" /* Bypass Left Femoral Artery to Right Femoral Artery, Percutaneous Endoscopic Approach */
"041L4ZJ" = "1" /* Bypass Left Femoral Artery to Left Femoral Artery, Percutaneous Endoscopic Approach */
"041L4ZK" = "1" /* Bypass Left Femoral Artery to Bilateral Femoral Arteries, Percutaneous Endoscopic Approach */
"041L4ZL" = "1" /* Bypass Left Femoral Artery to Popliteal Artery, Percutaneous Endoscopic Approach */
"041L4ZM" = "1" /* Bypass Left Femoral Artery to Peroneal Artery, Percutaneous Endoscopic Approach */
"041L4ZN" = "1" /* Bypass Left Femoral Artery to Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"041L4ZP" = "1" /* Bypass Left Femoral Artery to Foot Artery, Percutaneous Endoscopic Approach */
"041L4ZQ" = "1" /* Bypass Left Femoral Artery to Lower Extremity Artery, Percutaneous Endoscopic Approach */
"041L4ZS" = "1" /* Bypass Left Femoral Artery to Lower Extremity Vein, Percutaneous Endoscopic Approach */
"041M09L" = "1" /* Bypass Right Popliteal Artery to Popliteal Artery with Autologous Venous Tissue, Open Approach */
"041M09M" = "1" /* Bypass Right Popliteal Artery to Peroneal Artery with Autologous Venous Tissue, Open Approach */
"041M09P" = "1" /* Bypass Right Popliteal Artery to Foot Artery with Autologous Venous Tissue, Open Approach */
"041M09Q" = "1" /* Bypass Right Popliteal Artery to Lower Extremity Artery with Autologous Venous Tissue, Open Approach */
"041M09S" = "1" /* Bypass Right Popliteal Artery to Lower Extremity Vein with Autologous Venous Tissue, Open Approach */
"041M0AL" = "1" /* Bypass Right Popliteal Artery to Popliteal Artery with Autologous Arterial Tissue, Open Approach */
"041M0AM" = "1" /* Bypass Right Popliteal Artery to Peroneal Artery with Autologous Arterial Tissue, Open Approach */
"041M0AP" = "1" /* Bypass Right Popliteal Artery to Foot Artery with Autologous Arterial Tissue, Open Approach */
"041M0AQ" = "1" /* Bypass Right Popliteal Artery to Lower Extremity Artery with Autologous Arterial Tissue, Open Approach */
"041M0AS" = "1" /* Bypass Right Popliteal Artery to Lower Extremity Vein with Autologous Arterial Tissue, Open Approach */
"041M0JL" = "1" /* Bypass Right Popliteal Artery to Popliteal Artery with Synthetic Substitute, Open Approach */
"041M0JM" = "1" /* Bypass Right Popliteal Artery to Peroneal Artery with Synthetic Substitute, Open Approach */
"041M0JP" = "1" /* Bypass Right Popliteal Artery to Foot Artery with Synthetic Substitute, Open Approach */
"041M0JQ" = "1" /* Bypass Right Popliteal Artery to Lower Extremity Artery with Synthetic Substitute, Open Approach */
"041M0JS" = "1" /* Bypass Right Popliteal Artery to Lower Extremity Vein with Synthetic Substitute, Open Approach */
"041M0KL" = "1" /* Bypass Right Popliteal Artery to Popliteal Artery with Nonautologous Tissue Substitute, Open Approach */
"041M0KM" = "1" /* Bypass Right Popliteal Artery to Peroneal Artery with Nonautologous Tissue Substitute, Open Approach */
"041M0KP" = "1" /* Bypass Right Popliteal Artery to Foot Artery with Nonautologous Tissue Substitute, Open Approach */
"041M0KQ" = "1" /* Bypass Right Popliteal Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Open Approach */
"041M0KS" = "1" /* Bypass Right Popliteal Artery to Lower Extremity Vein with Nonautologous Tissue Substitute, Open Approach */
"041M0ZL" = "1" /* Bypass Right Popliteal Artery to Popliteal Artery, Open Approach */
"041M0ZM" = "1" /* Bypass Right Popliteal Artery to Peroneal Artery, Open Approach */
"041M0ZP" = "1" /* Bypass Right Popliteal Artery to Foot Artery, Open Approach */
"041M0ZQ" = "1" /* Bypass Right Popliteal Artery to Lower Extremity Artery, Open Approach */
"041M0ZS" = "1" /* Bypass Right Popliteal Artery to Lower Extremity Vein, Open Approach */
"041M49L" = "1" /* Bypass Right Popliteal Artery to Popliteal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041M49M" = "1" /* Bypass Right Popliteal Artery to Peroneal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041M49P" = "1" /* Bypass Right Popliteal Artery to Foot Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041M49Q" = "1" /* Bypass Right Popliteal Artery to Lower Extremity Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041M49S" = "1" /* Bypass Right Popliteal Artery to Lower Extremity Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041M4AL" = "1" /* Bypass Right Popliteal Artery to Popliteal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041M4AM" = "1" /* Bypass Right Popliteal Artery to Peroneal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041M4AP" = "1" /* Bypass Right Popliteal Artery to Foot Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041M4AQ" = "1" /* Bypass Right Popliteal Artery to Lower Extremity Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041M4AS" = "1" /* Bypass Right Popliteal Artery to Lower Extremity Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041M4JL" = "1" /* Bypass Right Popliteal Artery to Popliteal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041M4JM" = "1" /* Bypass Right Popliteal Artery to Peroneal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041M4JP" = "1" /* Bypass Right Popliteal Artery to Foot Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041M4JQ" = "1" /* Bypass Right Popliteal Artery to Lower Extremity Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041M4JS" = "1" /* Bypass Right Popliteal Artery to Lower Extremity Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041M4KL" = "1" /* Bypass Right Popliteal Artery to Popliteal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041M4KM" = "1" /* Bypass Right Popliteal Artery to Peroneal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041M4KP" = "1" /* Bypass Right Popliteal Artery to Foot Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041M4KQ" = "1" /* Bypass Right Popliteal Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041M4KS" = "1" /* Bypass Right Popliteal Artery to Lower Extremity Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041M4ZL" = "1" /* Bypass Right Popliteal Artery to Popliteal Artery, Percutaneous Endoscopic Approach */
"041M4ZM" = "1" /* Bypass Right Popliteal Artery to Peroneal Artery, Percutaneous Endoscopic Approach */
"041M4ZP" = "1" /* Bypass Right Popliteal Artery to Foot Artery, Percutaneous Endoscopic Approach */
"041M4ZQ" = "1" /* Bypass Right Popliteal Artery to Lower Extremity Artery, Percutaneous Endoscopic Approach */
"041M4ZS" = "1" /* Bypass Right Popliteal Artery to Lower Extremity Vein, Percutaneous Endoscopic Approach */
"041N09L" = "1" /* Bypass Left Popliteal Artery to Popliteal Artery with Autologous Venous Tissue, Open Approach */
"041N09M" = "1" /* Bypass Left Popliteal Artery to Peroneal Artery with Autologous Venous Tissue, Open Approach */
"041N09P" = "1" /* Bypass Left Popliteal Artery to Foot Artery with Autologous Venous Tissue, Open Approach */
"041N09Q" = "1" /* Bypass Left Popliteal Artery to Lower Extremity Artery with Autologous Venous Tissue, Open Approach */
"041N09S" = "1" /* Bypass Left Popliteal Artery to Lower Extremity Vein with Autologous Venous Tissue, Open Approach */
"041N0AL" = "1" /* Bypass Left Popliteal Artery to Popliteal Artery with Autologous Arterial Tissue, Open Approach */
"041N0AM" = "1" /* Bypass Left Popliteal Artery to Peroneal Artery with Autologous Arterial Tissue, Open Approach */
"041N0AP" = "1" /* Bypass Left Popliteal Artery to Foot Artery with Autologous Arterial Tissue, Open Approach */
"041N0AQ" = "1" /* Bypass Left Popliteal Artery to Lower Extremity Artery with Autologous Arterial Tissue, Open Approach */
"041N0AS" = "1" /* Bypass Left Popliteal Artery to Lower Extremity Vein with Autologous Arterial Tissue, Open Approach */
"041N0JL" = "1" /* Bypass Left Popliteal Artery to Popliteal Artery with Synthetic Substitute, Open Approach */
"041N0JM" = "1" /* Bypass Left Popliteal Artery to Peroneal Artery with Synthetic Substitute, Open Approach */
"041N0JP" = "1" /* Bypass Left Popliteal Artery to Foot Artery with Synthetic Substitute, Open Approach */
"041N0JQ" = "1" /* Bypass Left Popliteal Artery to Lower Extremity Artery with Synthetic Substitute, Open Approach */
"041N0JS" = "1" /* Bypass Left Popliteal Artery to Lower Extremity Vein with Synthetic Substitute, Open Approach */
"041N0KL" = "1" /* Bypass Left Popliteal Artery to Popliteal Artery with Nonautologous Tissue Substitute, Open Approach */
"041N0KM" = "1" /* Bypass Left Popliteal Artery to Peroneal Artery with Nonautologous Tissue Substitute, Open Approach */
"041N0KP" = "1" /* Bypass Left Popliteal Artery to Foot Artery with Nonautologous Tissue Substitute, Open Approach */
"041N0KQ" = "1" /* Bypass Left Popliteal Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Open Approach */
"041N0KS" = "1" /* Bypass Left Popliteal Artery to Lower Extremity Vein with Nonautologous Tissue Substitute, Open Approach */
"041N0ZL" = "1" /* Bypass Left Popliteal Artery to Popliteal Artery, Open Approach */
"041N0ZM" = "1" /* Bypass Left Popliteal Artery to Peroneal Artery, Open Approach */
"041N0ZP" = "1" /* Bypass Left Popliteal Artery to Foot Artery, Open Approach */
"041N0ZQ" = "1" /* Bypass Left Popliteal Artery to Lower Extremity Artery, Open Approach */
"041N0ZS" = "1" /* Bypass Left Popliteal Artery to Lower Extremity Vein, Open Approach */
"041N49L" = "1" /* Bypass Left Popliteal Artery to Popliteal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041N49M" = "1" /* Bypass Left Popliteal Artery to Peroneal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041N49P" = "1" /* Bypass Left Popliteal Artery to Foot Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041N49Q" = "1" /* Bypass Left Popliteal Artery to Lower Extremity Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041N49S" = "1" /* Bypass Left Popliteal Artery to Lower Extremity Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041N4AL" = "1" /* Bypass Left Popliteal Artery to Popliteal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041N4AM" = "1" /* Bypass Left Popliteal Artery to Peroneal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041N4AP" = "1" /* Bypass Left Popliteal Artery to Foot Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041N4AQ" = "1" /* Bypass Left Popliteal Artery to Lower Extremity Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041N4AS" = "1" /* Bypass Left Popliteal Artery to Lower Extremity Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"041N4JL" = "1" /* Bypass Left Popliteal Artery to Popliteal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041N4JM" = "1" /* Bypass Left Popliteal Artery to Peroneal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041N4JP" = "1" /* Bypass Left Popliteal Artery to Foot Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041N4JQ" = "1" /* Bypass Left Popliteal Artery to Lower Extremity Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041N4JS" = "1" /* Bypass Left Popliteal Artery to Lower Extremity Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"041N4KL" = "1" /* Bypass Left Popliteal Artery to Popliteal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041N4KM" = "1" /* Bypass Left Popliteal Artery to Peroneal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041N4KP" = "1" /* Bypass Left Popliteal Artery to Foot Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041N4KQ" = "1" /* Bypass Left Popliteal Artery to Lower Extremity Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041N4KS" = "1" /* Bypass Left Popliteal Artery to Lower Extremity Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"041N4ZL" = "1" /* Bypass Left Popliteal Artery to Popliteal Artery, Percutaneous Endoscopic Approach */
"041N4ZM" = "1" /* Bypass Left Popliteal Artery to Peroneal Artery, Percutaneous Endoscopic Approach */
"041N4ZP" = "1" /* Bypass Left Popliteal Artery to Foot Artery, Percutaneous Endoscopic Approach */
"041N4ZQ" = "1" /* Bypass Left Popliteal Artery to Lower Extremity Artery, Percutaneous Endoscopic Approach */
"041N4ZS" = "1" /* Bypass Left Popliteal Artery to Lower Extremity Vein, Percutaneous Endoscopic Approach */
"04500ZZ" = "1" /* Destruction of Abdominal Aorta, Open Approach */
"04503ZZ" = "1" /* Destruction of Abdominal Aorta, Percutaneous Approach */
"04504ZZ" = "1" /* Destruction of Abdominal Aorta, Percutaneous Endoscopic Approach */
"04510ZZ" = "1" /* Destruction of Celiac Artery, Open Approach */
"04513ZZ" = "1" /* Destruction of Celiac Artery, Percutaneous Approach */
"04514ZZ" = "1" /* Destruction of Celiac Artery, Percutaneous Endoscopic Approach */
"04520ZZ" = "1" /* Destruction of Gastric Artery, Open Approach */
"04523ZZ" = "1" /* Destruction of Gastric Artery, Percutaneous Approach */
"04524ZZ" = "1" /* Destruction of Gastric Artery, Percutaneous Endoscopic Approach */
"04530ZZ" = "1" /* Destruction of Hepatic Artery, Open Approach */
"04533ZZ" = "1" /* Destruction of Hepatic Artery, Percutaneous Approach */
"04534ZZ" = "1" /* Destruction of Hepatic Artery, Percutaneous Endoscopic Approach */
"04540ZZ" = "1" /* Destruction of Splenic Artery, Open Approach */
"04543ZZ" = "1" /* Destruction of Splenic Artery, Percutaneous Approach */
"04544ZZ" = "1" /* Destruction of Splenic Artery, Percutaneous Endoscopic Approach */
"04550ZZ" = "1" /* Destruction of Superior Mesenteric Artery, Open Approach */
"04553ZZ" = "1" /* Destruction of Superior Mesenteric Artery, Percutaneous Approach */
"04554ZZ" = "1" /* Destruction of Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04560ZZ" = "1" /* Destruction of Right Colic Artery, Open Approach */
"04563ZZ" = "1" /* Destruction of Right Colic Artery, Percutaneous Approach */
"04564ZZ" = "1" /* Destruction of Right Colic Artery, Percutaneous Endoscopic Approach */
"04570ZZ" = "1" /* Destruction of Left Colic Artery, Open Approach */
"04573ZZ" = "1" /* Destruction of Left Colic Artery, Percutaneous Approach */
"04574ZZ" = "1" /* Destruction of Left Colic Artery, Percutaneous Endoscopic Approach */
"04580ZZ" = "1" /* Destruction of Middle Colic Artery, Open Approach */
"04583ZZ" = "1" /* Destruction of Middle Colic Artery, Percutaneous Approach */
"04584ZZ" = "1" /* Destruction of Middle Colic Artery, Percutaneous Endoscopic Approach */
"04590ZZ" = "1" /* Destruction of Right Renal Artery, Open Approach */
"04593ZZ" = "1" /* Destruction of Right Renal Artery, Percutaneous Approach */
"04594ZZ" = "1" /* Destruction of Right Renal Artery, Percutaneous Endoscopic Approach */
"045A0ZZ" = "1" /* Destruction of Left Renal Artery, Open Approach */
"045A3ZZ" = "1" /* Destruction of Left Renal Artery, Percutaneous Approach */
"045A4ZZ" = "1" /* Destruction of Left Renal Artery, Percutaneous Endoscopic Approach */
"045B0ZZ" = "1" /* Destruction of Inferior Mesenteric Artery, Open Approach */
"045B3ZZ" = "1" /* Destruction of Inferior Mesenteric Artery, Percutaneous Approach */
"045B4ZZ" = "1" /* Destruction of Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"045C0ZZ" = "1" /* Destruction of Right Common Iliac Artery, Open Approach */
"045C3ZZ" = "1" /* Destruction of Right Common Iliac Artery, Percutaneous Approach */
"045C4ZZ" = "1" /* Destruction of Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"045D0ZZ" = "1" /* Destruction of Left Common Iliac Artery, Open Approach */
"045D3ZZ" = "1" /* Destruction of Left Common Iliac Artery, Percutaneous Approach */
"045D4ZZ" = "1" /* Destruction of Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"045E0ZZ" = "1" /* Destruction of Right Internal Iliac Artery, Open Approach */
"045E3ZZ" = "1" /* Destruction of Right Internal Iliac Artery, Percutaneous Approach */
"045E4ZZ" = "1" /* Destruction of Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"045F0ZZ" = "1" /* Destruction of Left Internal Iliac Artery, Open Approach */
"045F3ZZ" = "1" /* Destruction of Left Internal Iliac Artery, Percutaneous Approach */
"045F4ZZ" = "1" /* Destruction of Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"045H0ZZ" = "1" /* Destruction of Right External Iliac Artery, Open Approach */
"045H3ZZ" = "1" /* Destruction of Right External Iliac Artery, Percutaneous Approach */
"045H4ZZ" = "1" /* Destruction of Right External Iliac Artery, Percutaneous Endoscopic Approach */
"045J0ZZ" = "1" /* Destruction of Left External Iliac Artery, Open Approach */
"045J3ZZ" = "1" /* Destruction of Left External Iliac Artery, Percutaneous Approach */
"045J4ZZ" = "1" /* Destruction of Left External Iliac Artery, Percutaneous Endoscopic Approach */
"045K0ZZ" = "1" /* Destruction of Right Femoral Artery, Open Approach */
"045K3ZZ" = "1" /* Destruction of Right Femoral Artery, Percutaneous Approach */
"045K4ZZ" = "1" /* Destruction of Right Femoral Artery, Percutaneous Endoscopic Approach */
"045L0ZZ" = "1" /* Destruction of Left Femoral Artery, Open Approach */
"045L3ZZ" = "1" /* Destruction of Left Femoral Artery, Percutaneous Approach */
"045L4ZZ" = "1" /* Destruction of Left Femoral Artery, Percutaneous Endoscopic Approach */
"045M0ZZ" = "1" /* Destruction of Right Popliteal Artery, Open Approach */
"045M3ZZ" = "1" /* Destruction of Right Popliteal Artery, Percutaneous Approach */
"045M4ZZ" = "1" /* Destruction of Right Popliteal Artery, Percutaneous Endoscopic Approach */
"045N0ZZ" = "1" /* Destruction of Left Popliteal Artery, Open Approach */
"045N3ZZ" = "1" /* Destruction of Left Popliteal Artery, Percutaneous Approach */
"045N4ZZ" = "1" /* Destruction of Left Popliteal Artery, Percutaneous Endoscopic Approach */
"045P0ZZ" = "1" /* Destruction of Right Anterior Tibial Artery, Open Approach */
"045P3ZZ" = "1" /* Destruction of Right Anterior Tibial Artery, Percutaneous Approach */
"045P4ZZ" = "1" /* Destruction of Right Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"045Q0ZZ" = "1" /* Destruction of Left Anterior Tibial Artery, Open Approach */
"045Q3ZZ" = "1" /* Destruction of Left Anterior Tibial Artery, Percutaneous Approach */
"045Q4ZZ" = "1" /* Destruction of Left Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"045R0ZZ" = "1" /* Destruction of Right Posterior Tibial Artery, Open Approach */
"045R3ZZ" = "1" /* Destruction of Right Posterior Tibial Artery, Percutaneous Approach */
"045R4ZZ" = "1" /* Destruction of Right Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"045S0ZZ" = "1" /* Destruction of Left Posterior Tibial Artery, Open Approach */
"045S3ZZ" = "1" /* Destruction of Left Posterior Tibial Artery, Percutaneous Approach */
"045S4ZZ" = "1" /* Destruction of Left Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"045T0ZZ" = "1" /* Destruction of Right Peroneal Artery, Open Approach */
"045T3ZZ" = "1" /* Destruction of Right Peroneal Artery, Percutaneous Approach */
"045T4ZZ" = "1" /* Destruction of Right Peroneal Artery, Percutaneous Endoscopic Approach */
"045U0ZZ" = "1" /* Destruction of Left Peroneal Artery, Open Approach */
"045U3ZZ" = "1" /* Destruction of Left Peroneal Artery, Percutaneous Approach */
"045U4ZZ" = "1" /* Destruction of Left Peroneal Artery, Percutaneous Endoscopic Approach */
"045V0ZZ" = "1" /* Destruction of Right Foot Artery, Open Approach */
"045V3ZZ" = "1" /* Destruction of Right Foot Artery, Percutaneous Approach */
"045V4ZZ" = "1" /* Destruction of Right Foot Artery, Percutaneous Endoscopic Approach */
"045W0ZZ" = "1" /* Destruction of Left Foot Artery, Open Approach */
"045W3ZZ" = "1" /* Destruction of Left Foot Artery, Percutaneous Approach */
"045W4ZZ" = "1" /* Destruction of Left Foot Artery, Percutaneous Endoscopic Approach */
"045Y0ZZ" = "1" /* Destruction of Lower Artery, Open Approach */
"045Y3ZZ" = "1" /* Destruction of Lower Artery, Percutaneous Approach */
"045Y4ZZ" = "1" /* Destruction of Lower Artery, Percutaneous Endoscopic Approach */
"0470046" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047004Z" = "1" /* Dilation of Abdominal Aorta with Drug-eluting Intraluminal Device, Open Approach */
"0470056" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047005Z" = "1" /* Dilation of Abdominal Aorta with Two Drug-eluting Intraluminal Devices, Open Approach */
"0470066" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047006Z" = "1" /* Dilation of Abdominal Aorta with Three Drug-eluting Intraluminal Devices, Open Approach */
"0470076" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047007Z" = "1" /* Dilation of Abdominal Aorta with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"04700D6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Intraluminal Device, Open Approach */
"04700DZ" = "1" /* Dilation of Abdominal Aorta with Intraluminal Device, Open Approach */
"04700E6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Two Intraluminal Devices, Open Approach */
"04700EZ" = "1" /* Dilation of Abdominal Aorta with Two Intraluminal Devices, Open Approach */
"04700F6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Three Intraluminal Devices, Open Approach */
"04700FZ" = "1" /* Dilation of Abdominal Aorta with Three Intraluminal Devices, Open Approach */
"04700G6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"04700GZ" = "1" /* Dilation of Abdominal Aorta with Four or More Intraluminal Devices, Open Approach */
"04700Z6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, Open Approach */
"04700ZZ" = "1" /* Dilation of Abdominal Aorta, Open Approach */
"0470346" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047034Z" = "1" /* Dilation of Abdominal Aorta with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0470356" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047035Z" = "1" /* Dilation of Abdominal Aorta with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0470366" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047036Z" = "1" /* Dilation of Abdominal Aorta with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0470376" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047037Z" = "1" /* Dilation of Abdominal Aorta with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"04703D6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"04703DZ" = "1" /* Dilation of Abdominal Aorta with Intraluminal Device, Percutaneous Approach */
"04703E6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"04703EZ" = "1" /* Dilation of Abdominal Aorta with Two Intraluminal Devices, Percutaneous Approach */
"04703F6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"04703FZ" = "1" /* Dilation of Abdominal Aorta with Three Intraluminal Devices, Percutaneous Approach */
"04703G6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"04703GZ" = "1" /* Dilation of Abdominal Aorta with Four or More Intraluminal Devices, Percutaneous Approach */
"04703Z6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, Percutaneous Approach */
"04703ZZ" = "1" /* Dilation of Abdominal Aorta, Percutaneous Approach */
"0470446" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047044Z" = "1" /* Dilation of Abdominal Aorta with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0470456" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047045Z" = "1" /* Dilation of Abdominal Aorta with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0470466" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047046Z" = "1" /* Dilation of Abdominal Aorta with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0470476" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047047Z" = "1" /* Dilation of Abdominal Aorta with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"04704D6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"04704DZ" = "1" /* Dilation of Abdominal Aorta with Intraluminal Device, Percutaneous Endoscopic Approach */
"04704E6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04704EZ" = "1" /* Dilation of Abdominal Aorta with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04704F6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04704FZ" = "1" /* Dilation of Abdominal Aorta with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04704G6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04704GZ" = "1" /* Dilation of Abdominal Aorta with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04704Z6" = "1" /* Dilation of Abdominal Aorta, Bifurcation, Percutaneous Endoscopic Approach */
"04704ZZ" = "1" /* Dilation of Abdominal Aorta, Percutaneous Endoscopic Approach */
"0471046" = "1" /* Dilation of Celiac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047104Z" = "1" /* Dilation of Celiac Artery with Drug-eluting Intraluminal Device, Open Approach */
"0471056" = "1" /* Dilation of Celiac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047105Z" = "1" /* Dilation of Celiac Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0471066" = "1" /* Dilation of Celiac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047106Z" = "1" /* Dilation of Celiac Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0471076" = "1" /* Dilation of Celiac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047107Z" = "1" /* Dilation of Celiac Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"04710D6" = "1" /* Dilation of Celiac Artery, Bifurcation, with Intraluminal Device, Open Approach */
"04710DZ" = "1" /* Dilation of Celiac Artery with Intraluminal Device, Open Approach */
"04710E6" = "1" /* Dilation of Celiac Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"04710EZ" = "1" /* Dilation of Celiac Artery with Two Intraluminal Devices, Open Approach */
"04710F6" = "1" /* Dilation of Celiac Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"04710FZ" = "1" /* Dilation of Celiac Artery with Three Intraluminal Devices, Open Approach */
"04710G6" = "1" /* Dilation of Celiac Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"04710GZ" = "1" /* Dilation of Celiac Artery with Four or More Intraluminal Devices, Open Approach */
"04710Z6" = "1" /* Dilation of Celiac Artery, Bifurcation, Open Approach */
"04710ZZ" = "1" /* Dilation of Celiac Artery, Open Approach */
"0471346" = "1" /* Dilation of Celiac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047134Z" = "1" /* Dilation of Celiac Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0471356" = "1" /* Dilation of Celiac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047135Z" = "1" /* Dilation of Celiac Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0471366" = "1" /* Dilation of Celiac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047136Z" = "1" /* Dilation of Celiac Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0471376" = "1" /* Dilation of Celiac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047137Z" = "1" /* Dilation of Celiac Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"04713D6" = "1" /* Dilation of Celiac Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"04713DZ" = "1" /* Dilation of Celiac Artery with Intraluminal Device, Percutaneous Approach */
"04713E6" = "1" /* Dilation of Celiac Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"04713EZ" = "1" /* Dilation of Celiac Artery with Two Intraluminal Devices, Percutaneous Approach */
"04713F6" = "1" /* Dilation of Celiac Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"04713FZ" = "1" /* Dilation of Celiac Artery with Three Intraluminal Devices, Percutaneous Approach */
"04713G6" = "1" /* Dilation of Celiac Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"04713GZ" = "1" /* Dilation of Celiac Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"04713Z6" = "1" /* Dilation of Celiac Artery, Bifurcation, Percutaneous Approach */
"04713ZZ" = "1" /* Dilation of Celiac Artery, Percutaneous Approach */
"0471446" = "1" /* Dilation of Celiac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047144Z" = "1" /* Dilation of Celiac Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0471456" = "1" /* Dilation of Celiac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047145Z" = "1" /* Dilation of Celiac Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0471466" = "1" /* Dilation of Celiac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047146Z" = "1" /* Dilation of Celiac Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0471476" = "1" /* Dilation of Celiac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047147Z" = "1" /* Dilation of Celiac Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"04714D6" = "1" /* Dilation of Celiac Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"04714DZ" = "1" /* Dilation of Celiac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04714E6" = "1" /* Dilation of Celiac Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04714EZ" = "1" /* Dilation of Celiac Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04714F6" = "1" /* Dilation of Celiac Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04714FZ" = "1" /* Dilation of Celiac Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04714G6" = "1" /* Dilation of Celiac Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04714GZ" = "1" /* Dilation of Celiac Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04714Z6" = "1" /* Dilation of Celiac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04714ZZ" = "1" /* Dilation of Celiac Artery, Percutaneous Endoscopic Approach */
"0472046" = "1" /* Dilation of Gastric Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047204Z" = "1" /* Dilation of Gastric Artery with Drug-eluting Intraluminal Device, Open Approach */
"0472056" = "1" /* Dilation of Gastric Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047205Z" = "1" /* Dilation of Gastric Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0472066" = "1" /* Dilation of Gastric Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047206Z" = "1" /* Dilation of Gastric Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0472076" = "1" /* Dilation of Gastric Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047207Z" = "1" /* Dilation of Gastric Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"04720D6" = "1" /* Dilation of Gastric Artery, Bifurcation, with Intraluminal Device, Open Approach */
"04720DZ" = "1" /* Dilation of Gastric Artery with Intraluminal Device, Open Approach */
"04720E6" = "1" /* Dilation of Gastric Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"04720EZ" = "1" /* Dilation of Gastric Artery with Two Intraluminal Devices, Open Approach */
"04720F6" = "1" /* Dilation of Gastric Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"04720FZ" = "1" /* Dilation of Gastric Artery with Three Intraluminal Devices, Open Approach */
"04720G6" = "1" /* Dilation of Gastric Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"04720GZ" = "1" /* Dilation of Gastric Artery with Four or More Intraluminal Devices, Open Approach */
"04720Z6" = "1" /* Dilation of Gastric Artery, Bifurcation, Open Approach */
"04720ZZ" = "1" /* Dilation of Gastric Artery, Open Approach */
"0472346" = "1" /* Dilation of Gastric Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047234Z" = "1" /* Dilation of Gastric Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0472356" = "1" /* Dilation of Gastric Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047235Z" = "1" /* Dilation of Gastric Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0472366" = "1" /* Dilation of Gastric Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047236Z" = "1" /* Dilation of Gastric Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0472376" = "1" /* Dilation of Gastric Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047237Z" = "1" /* Dilation of Gastric Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"04723D6" = "1" /* Dilation of Gastric Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"04723DZ" = "1" /* Dilation of Gastric Artery with Intraluminal Device, Percutaneous Approach */
"04723E6" = "1" /* Dilation of Gastric Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"04723EZ" = "1" /* Dilation of Gastric Artery with Two Intraluminal Devices, Percutaneous Approach */
"04723F6" = "1" /* Dilation of Gastric Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"04723FZ" = "1" /* Dilation of Gastric Artery with Three Intraluminal Devices, Percutaneous Approach */
"04723G6" = "1" /* Dilation of Gastric Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"04723GZ" = "1" /* Dilation of Gastric Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"04723Z6" = "1" /* Dilation of Gastric Artery, Bifurcation, Percutaneous Approach */
"04723ZZ" = "1" /* Dilation of Gastric Artery, Percutaneous Approach */
"0472446" = "1" /* Dilation of Gastric Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047244Z" = "1" /* Dilation of Gastric Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0472456" = "1" /* Dilation of Gastric Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047245Z" = "1" /* Dilation of Gastric Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0472466" = "1" /* Dilation of Gastric Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047246Z" = "1" /* Dilation of Gastric Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0472476" = "1" /* Dilation of Gastric Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047247Z" = "1" /* Dilation of Gastric Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"04724D6" = "1" /* Dilation of Gastric Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"04724DZ" = "1" /* Dilation of Gastric Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04724E6" = "1" /* Dilation of Gastric Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04724EZ" = "1" /* Dilation of Gastric Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04724F6" = "1" /* Dilation of Gastric Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04724FZ" = "1" /* Dilation of Gastric Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04724G6" = "1" /* Dilation of Gastric Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04724GZ" = "1" /* Dilation of Gastric Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04724Z6" = "1" /* Dilation of Gastric Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04724ZZ" = "1" /* Dilation of Gastric Artery, Percutaneous Endoscopic Approach */
"0473046" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047304Z" = "1" /* Dilation of Hepatic Artery with Drug-eluting Intraluminal Device, Open Approach */
"0473056" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047305Z" = "1" /* Dilation of Hepatic Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0473066" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047306Z" = "1" /* Dilation of Hepatic Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0473076" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047307Z" = "1" /* Dilation of Hepatic Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"04730D6" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Intraluminal Device, Open Approach */
"04730DZ" = "1" /* Dilation of Hepatic Artery with Intraluminal Device, Open Approach */
"04730E6" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"04730EZ" = "1" /* Dilation of Hepatic Artery with Two Intraluminal Devices, Open Approach */
"04730F6" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"04730FZ" = "1" /* Dilation of Hepatic Artery with Three Intraluminal Devices, Open Approach */
"04730G6" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"04730GZ" = "1" /* Dilation of Hepatic Artery with Four or More Intraluminal Devices, Open Approach */
"04730Z6" = "1" /* Dilation of Hepatic Artery, Bifurcation, Open Approach */
"04730ZZ" = "1" /* Dilation of Hepatic Artery, Open Approach */
"0473346" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047334Z" = "1" /* Dilation of Hepatic Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0473356" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047335Z" = "1" /* Dilation of Hepatic Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0473366" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047336Z" = "1" /* Dilation of Hepatic Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0473376" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047337Z" = "1" /* Dilation of Hepatic Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"04733D6" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"04733DZ" = "1" /* Dilation of Hepatic Artery with Intraluminal Device, Percutaneous Approach */
"04733E6" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"04733EZ" = "1" /* Dilation of Hepatic Artery with Two Intraluminal Devices, Percutaneous Approach */
"04733F6" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"04733FZ" = "1" /* Dilation of Hepatic Artery with Three Intraluminal Devices, Percutaneous Approach */
"04733G6" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"04733GZ" = "1" /* Dilation of Hepatic Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"04733Z6" = "1" /* Dilation of Hepatic Artery, Bifurcation, Percutaneous Approach */
"04733ZZ" = "1" /* Dilation of Hepatic Artery, Percutaneous Approach */
"0473446" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047344Z" = "1" /* Dilation of Hepatic Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0473456" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047345Z" = "1" /* Dilation of Hepatic Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0473466" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047346Z" = "1" /* Dilation of Hepatic Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0473476" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047347Z" = "1" /* Dilation of Hepatic Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"04734D6" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"04734DZ" = "1" /* Dilation of Hepatic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04734E6" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04734EZ" = "1" /* Dilation of Hepatic Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04734F6" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04734FZ" = "1" /* Dilation of Hepatic Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04734G6" = "1" /* Dilation of Hepatic Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04734GZ" = "1" /* Dilation of Hepatic Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04734Z6" = "1" /* Dilation of Hepatic Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04734ZZ" = "1" /* Dilation of Hepatic Artery, Percutaneous Endoscopic Approach */
"0474046" = "1" /* Dilation of Splenic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047404Z" = "1" /* Dilation of Splenic Artery with Drug-eluting Intraluminal Device, Open Approach */
"0474056" = "1" /* Dilation of Splenic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047405Z" = "1" /* Dilation of Splenic Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0474066" = "1" /* Dilation of Splenic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047406Z" = "1" /* Dilation of Splenic Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0474076" = "1" /* Dilation of Splenic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047407Z" = "1" /* Dilation of Splenic Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"04740D6" = "1" /* Dilation of Splenic Artery, Bifurcation, with Intraluminal Device, Open Approach */
"04740DZ" = "1" /* Dilation of Splenic Artery with Intraluminal Device, Open Approach */
"04740E6" = "1" /* Dilation of Splenic Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"04740EZ" = "1" /* Dilation of Splenic Artery with Two Intraluminal Devices, Open Approach */
"04740F6" = "1" /* Dilation of Splenic Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"04740FZ" = "1" /* Dilation of Splenic Artery with Three Intraluminal Devices, Open Approach */
"04740G6" = "1" /* Dilation of Splenic Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"04740GZ" = "1" /* Dilation of Splenic Artery with Four or More Intraluminal Devices, Open Approach */
"04740Z6" = "1" /* Dilation of Splenic Artery, Bifurcation, Open Approach */
"04740ZZ" = "1" /* Dilation of Splenic Artery, Open Approach */
"0474346" = "1" /* Dilation of Splenic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047434Z" = "1" /* Dilation of Splenic Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0474356" = "1" /* Dilation of Splenic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047435Z" = "1" /* Dilation of Splenic Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0474366" = "1" /* Dilation of Splenic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047436Z" = "1" /* Dilation of Splenic Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0474376" = "1" /* Dilation of Splenic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047437Z" = "1" /* Dilation of Splenic Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"04743D6" = "1" /* Dilation of Splenic Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"04743DZ" = "1" /* Dilation of Splenic Artery with Intraluminal Device, Percutaneous Approach */
"04743E6" = "1" /* Dilation of Splenic Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"04743EZ" = "1" /* Dilation of Splenic Artery with Two Intraluminal Devices, Percutaneous Approach */
"04743F6" = "1" /* Dilation of Splenic Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"04743FZ" = "1" /* Dilation of Splenic Artery with Three Intraluminal Devices, Percutaneous Approach */
"04743G6" = "1" /* Dilation of Splenic Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"04743GZ" = "1" /* Dilation of Splenic Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"04743Z6" = "1" /* Dilation of Splenic Artery, Bifurcation, Percutaneous Approach */
"04743ZZ" = "1" /* Dilation of Splenic Artery, Percutaneous Approach */
"0474446" = "1" /* Dilation of Splenic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047444Z" = "1" /* Dilation of Splenic Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0474456" = "1" /* Dilation of Splenic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047445Z" = "1" /* Dilation of Splenic Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0474466" = "1" /* Dilation of Splenic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047446Z" = "1" /* Dilation of Splenic Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0474476" = "1" /* Dilation of Splenic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047447Z" = "1" /* Dilation of Splenic Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"04744D6" = "1" /* Dilation of Splenic Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"04744DZ" = "1" /* Dilation of Splenic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04744E6" = "1" /* Dilation of Splenic Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04744EZ" = "1" /* Dilation of Splenic Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04744F6" = "1" /* Dilation of Splenic Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04744FZ" = "1" /* Dilation of Splenic Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04744G6" = "1" /* Dilation of Splenic Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04744GZ" = "1" /* Dilation of Splenic Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04744Z6" = "1" /* Dilation of Splenic Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04744ZZ" = "1" /* Dilation of Splenic Artery, Percutaneous Endoscopic Approach */
"0475046" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047504Z" = "1" /* Dilation of Superior Mesenteric Artery with Drug-eluting Intraluminal Device, Open Approach */
"0475056" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047505Z" = "1" /* Dilation of Superior Mesenteric Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0475066" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047506Z" = "1" /* Dilation of Superior Mesenteric Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0475076" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047507Z" = "1" /* Dilation of Superior Mesenteric Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"04750D6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Intraluminal Device, Open Approach */
"04750DZ" = "1" /* Dilation of Superior Mesenteric Artery with Intraluminal Device, Open Approach */
"04750E6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"04750EZ" = "1" /* Dilation of Superior Mesenteric Artery with Two Intraluminal Devices, Open Approach */
"04750F6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"04750FZ" = "1" /* Dilation of Superior Mesenteric Artery with Three Intraluminal Devices, Open Approach */
"04750G6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"04750GZ" = "1" /* Dilation of Superior Mesenteric Artery with Four or More Intraluminal Devices, Open Approach */
"04750Z6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, Open Approach */
"04750ZZ" = "1" /* Dilation of Superior Mesenteric Artery, Open Approach */
"0475346" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047534Z" = "1" /* Dilation of Superior Mesenteric Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0475356" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047535Z" = "1" /* Dilation of Superior Mesenteric Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0475366" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047536Z" = "1" /* Dilation of Superior Mesenteric Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0475376" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047537Z" = "1" /* Dilation of Superior Mesenteric Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"04753D6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"04753DZ" = "1" /* Dilation of Superior Mesenteric Artery with Intraluminal Device, Percutaneous Approach */
"04753E6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"04753EZ" = "1" /* Dilation of Superior Mesenteric Artery with Two Intraluminal Devices, Percutaneous Approach */
"04753F6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"04753FZ" = "1" /* Dilation of Superior Mesenteric Artery with Three Intraluminal Devices, Percutaneous Approach */
"04753G6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"04753GZ" = "1" /* Dilation of Superior Mesenteric Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"04753Z6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, Percutaneous Approach */
"04753ZZ" = "1" /* Dilation of Superior Mesenteric Artery, Percutaneous Approach */
"0475446" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047544Z" = "1" /* Dilation of Superior Mesenteric Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0475456" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047545Z" = "1" /* Dilation of Superior Mesenteric Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0475466" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047546Z" = "1" /* Dilation of Superior Mesenteric Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0475476" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047547Z" = "1" /* Dilation of Superior Mesenteric Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"04754D6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"04754DZ" = "1" /* Dilation of Superior Mesenteric Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04754E6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04754EZ" = "1" /* Dilation of Superior Mesenteric Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04754F6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04754FZ" = "1" /* Dilation of Superior Mesenteric Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04754G6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04754GZ" = "1" /* Dilation of Superior Mesenteric Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04754Z6" = "1" /* Dilation of Superior Mesenteric Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04754ZZ" = "1" /* Dilation of Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"0476046" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047604Z" = "1" /* Dilation of Right Colic Artery with Drug-eluting Intraluminal Device, Open Approach */
"0476056" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047605Z" = "1" /* Dilation of Right Colic Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0476066" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047606Z" = "1" /* Dilation of Right Colic Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0476076" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047607Z" = "1" /* Dilation of Right Colic Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"04760D6" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Intraluminal Device, Open Approach */
"04760DZ" = "1" /* Dilation of Right Colic Artery with Intraluminal Device, Open Approach */
"04760E6" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"04760EZ" = "1" /* Dilation of Right Colic Artery with Two Intraluminal Devices, Open Approach */
"04760F6" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"04760FZ" = "1" /* Dilation of Right Colic Artery with Three Intraluminal Devices, Open Approach */
"04760G6" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"04760GZ" = "1" /* Dilation of Right Colic Artery with Four or More Intraluminal Devices, Open Approach */
"04760Z6" = "1" /* Dilation of Right Colic Artery, Bifurcation, Open Approach */
"04760ZZ" = "1" /* Dilation of Right Colic Artery, Open Approach */
"0476346" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047634Z" = "1" /* Dilation of Right Colic Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0476356" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047635Z" = "1" /* Dilation of Right Colic Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0476366" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047636Z" = "1" /* Dilation of Right Colic Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0476376" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047637Z" = "1" /* Dilation of Right Colic Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"04763D6" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"04763DZ" = "1" /* Dilation of Right Colic Artery with Intraluminal Device, Percutaneous Approach */
"04763E6" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"04763EZ" = "1" /* Dilation of Right Colic Artery with Two Intraluminal Devices, Percutaneous Approach */
"04763F6" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"04763FZ" = "1" /* Dilation of Right Colic Artery with Three Intraluminal Devices, Percutaneous Approach */
"04763G6" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"04763GZ" = "1" /* Dilation of Right Colic Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"04763Z6" = "1" /* Dilation of Right Colic Artery, Bifurcation, Percutaneous Approach */
"04763ZZ" = "1" /* Dilation of Right Colic Artery, Percutaneous Approach */
"0476446" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047644Z" = "1" /* Dilation of Right Colic Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0476456" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047645Z" = "1" /* Dilation of Right Colic Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0476466" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047646Z" = "1" /* Dilation of Right Colic Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0476476" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047647Z" = "1" /* Dilation of Right Colic Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"04764D6" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"04764DZ" = "1" /* Dilation of Right Colic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04764E6" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04764EZ" = "1" /* Dilation of Right Colic Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04764F6" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04764FZ" = "1" /* Dilation of Right Colic Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04764G6" = "1" /* Dilation of Right Colic Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04764GZ" = "1" /* Dilation of Right Colic Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04764Z6" = "1" /* Dilation of Right Colic Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04764ZZ" = "1" /* Dilation of Right Colic Artery, Percutaneous Endoscopic Approach */
"0477046" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047704Z" = "1" /* Dilation of Left Colic Artery with Drug-eluting Intraluminal Device, Open Approach */
"0477056" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047705Z" = "1" /* Dilation of Left Colic Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0477066" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047706Z" = "1" /* Dilation of Left Colic Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0477076" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047707Z" = "1" /* Dilation of Left Colic Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"04770D6" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Intraluminal Device, Open Approach */
"04770DZ" = "1" /* Dilation of Left Colic Artery with Intraluminal Device, Open Approach */
"04770E6" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"04770EZ" = "1" /* Dilation of Left Colic Artery with Two Intraluminal Devices, Open Approach */
"04770F6" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"04770FZ" = "1" /* Dilation of Left Colic Artery with Three Intraluminal Devices, Open Approach */
"04770G6" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"04770GZ" = "1" /* Dilation of Left Colic Artery with Four or More Intraluminal Devices, Open Approach */
"04770Z6" = "1" /* Dilation of Left Colic Artery, Bifurcation, Open Approach */
"04770ZZ" = "1" /* Dilation of Left Colic Artery, Open Approach */
"0477346" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047734Z" = "1" /* Dilation of Left Colic Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0477356" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047735Z" = "1" /* Dilation of Left Colic Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0477366" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047736Z" = "1" /* Dilation of Left Colic Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0477376" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047737Z" = "1" /* Dilation of Left Colic Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"04773D6" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"04773DZ" = "1" /* Dilation of Left Colic Artery with Intraluminal Device, Percutaneous Approach */
"04773E6" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"04773EZ" = "1" /* Dilation of Left Colic Artery with Two Intraluminal Devices, Percutaneous Approach */
"04773F6" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"04773FZ" = "1" /* Dilation of Left Colic Artery with Three Intraluminal Devices, Percutaneous Approach */
"04773G6" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"04773GZ" = "1" /* Dilation of Left Colic Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"04773Z6" = "1" /* Dilation of Left Colic Artery, Bifurcation, Percutaneous Approach */
"04773ZZ" = "1" /* Dilation of Left Colic Artery, Percutaneous Approach */
"0477446" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047744Z" = "1" /* Dilation of Left Colic Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0477456" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047745Z" = "1" /* Dilation of Left Colic Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0477466" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047746Z" = "1" /* Dilation of Left Colic Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0477476" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047747Z" = "1" /* Dilation of Left Colic Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"04774D6" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"04774DZ" = "1" /* Dilation of Left Colic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04774E6" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04774EZ" = "1" /* Dilation of Left Colic Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04774F6" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04774FZ" = "1" /* Dilation of Left Colic Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04774G6" = "1" /* Dilation of Left Colic Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04774GZ" = "1" /* Dilation of Left Colic Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04774Z6" = "1" /* Dilation of Left Colic Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04774ZZ" = "1" /* Dilation of Left Colic Artery, Percutaneous Endoscopic Approach */
"0478046" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047804Z" = "1" /* Dilation of Middle Colic Artery with Drug-eluting Intraluminal Device, Open Approach */
"0478056" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047805Z" = "1" /* Dilation of Middle Colic Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0478066" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047806Z" = "1" /* Dilation of Middle Colic Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0478076" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047807Z" = "1" /* Dilation of Middle Colic Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"04780D6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Intraluminal Device, Open Approach */
"04780DZ" = "1" /* Dilation of Middle Colic Artery with Intraluminal Device, Open Approach */
"04780E6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"04780EZ" = "1" /* Dilation of Middle Colic Artery with Two Intraluminal Devices, Open Approach */
"04780F6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"04780FZ" = "1" /* Dilation of Middle Colic Artery with Three Intraluminal Devices, Open Approach */
"04780G6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"04780GZ" = "1" /* Dilation of Middle Colic Artery with Four or More Intraluminal Devices, Open Approach */
"04780Z6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, Open Approach */
"04780ZZ" = "1" /* Dilation of Middle Colic Artery, Open Approach */
"0478346" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047834Z" = "1" /* Dilation of Middle Colic Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0478356" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047835Z" = "1" /* Dilation of Middle Colic Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0478366" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047836Z" = "1" /* Dilation of Middle Colic Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0478376" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047837Z" = "1" /* Dilation of Middle Colic Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"04783D6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"04783DZ" = "1" /* Dilation of Middle Colic Artery with Intraluminal Device, Percutaneous Approach */
"04783E6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"04783EZ" = "1" /* Dilation of Middle Colic Artery with Two Intraluminal Devices, Percutaneous Approach */
"04783F6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"04783FZ" = "1" /* Dilation of Middle Colic Artery with Three Intraluminal Devices, Percutaneous Approach */
"04783G6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"04783GZ" = "1" /* Dilation of Middle Colic Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"04783Z6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, Percutaneous Approach */
"04783ZZ" = "1" /* Dilation of Middle Colic Artery, Percutaneous Approach */
"0478446" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047844Z" = "1" /* Dilation of Middle Colic Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0478456" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047845Z" = "1" /* Dilation of Middle Colic Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0478466" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047846Z" = "1" /* Dilation of Middle Colic Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0478476" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047847Z" = "1" /* Dilation of Middle Colic Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"04784D6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"04784DZ" = "1" /* Dilation of Middle Colic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04784E6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04784EZ" = "1" /* Dilation of Middle Colic Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04784F6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04784FZ" = "1" /* Dilation of Middle Colic Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04784G6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04784GZ" = "1" /* Dilation of Middle Colic Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04784Z6" = "1" /* Dilation of Middle Colic Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04784ZZ" = "1" /* Dilation of Middle Colic Artery, Percutaneous Endoscopic Approach */
"0479046" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047904Z" = "1" /* Dilation of Right Renal Artery with Drug-eluting Intraluminal Device, Open Approach */
"0479056" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047905Z" = "1" /* Dilation of Right Renal Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0479066" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047906Z" = "1" /* Dilation of Right Renal Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0479076" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047907Z" = "1" /* Dilation of Right Renal Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"04790D6" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Intraluminal Device, Open Approach */
"04790DZ" = "1" /* Dilation of Right Renal Artery with Intraluminal Device, Open Approach */
"04790E6" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"04790EZ" = "1" /* Dilation of Right Renal Artery with Two Intraluminal Devices, Open Approach */
"04790F6" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"04790FZ" = "1" /* Dilation of Right Renal Artery with Three Intraluminal Devices, Open Approach */
"04790G6" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"04790GZ" = "1" /* Dilation of Right Renal Artery with Four or More Intraluminal Devices, Open Approach */
"04790Z6" = "1" /* Dilation of Right Renal Artery, Bifurcation, Open Approach */
"04790ZZ" = "1" /* Dilation of Right Renal Artery, Open Approach */
"0479346" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047934Z" = "1" /* Dilation of Right Renal Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0479356" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047935Z" = "1" /* Dilation of Right Renal Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0479366" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047936Z" = "1" /* Dilation of Right Renal Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0479376" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047937Z" = "1" /* Dilation of Right Renal Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"04793D6" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"04793DZ" = "1" /* Dilation of Right Renal Artery with Intraluminal Device, Percutaneous Approach */
"04793E6" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"04793EZ" = "1" /* Dilation of Right Renal Artery with Two Intraluminal Devices, Percutaneous Approach */
"04793F6" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"04793FZ" = "1" /* Dilation of Right Renal Artery with Three Intraluminal Devices, Percutaneous Approach */
"04793G6" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"04793GZ" = "1" /* Dilation of Right Renal Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"04793Z6" = "1" /* Dilation of Right Renal Artery, Bifurcation, Percutaneous Approach */
"04793ZZ" = "1" /* Dilation of Right Renal Artery, Percutaneous Approach */
"0479446" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047944Z" = "1" /* Dilation of Right Renal Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0479456" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047945Z" = "1" /* Dilation of Right Renal Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0479466" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047946Z" = "1" /* Dilation of Right Renal Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0479476" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047947Z" = "1" /* Dilation of Right Renal Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"04794D6" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"04794DZ" = "1" /* Dilation of Right Renal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04794E6" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04794EZ" = "1" /* Dilation of Right Renal Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"04794F6" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04794FZ" = "1" /* Dilation of Right Renal Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"04794G6" = "1" /* Dilation of Right Renal Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04794GZ" = "1" /* Dilation of Right Renal Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"04794Z6" = "1" /* Dilation of Right Renal Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04794ZZ" = "1" /* Dilation of Right Renal Artery, Percutaneous Endoscopic Approach */
"047A046" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047A04Z" = "1" /* Dilation of Left Renal Artery with Drug-eluting Intraluminal Device, Open Approach */
"047A056" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047A05Z" = "1" /* Dilation of Left Renal Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047A066" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047A06Z" = "1" /* Dilation of Left Renal Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047A076" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047A07Z" = "1" /* Dilation of Left Renal Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047A0D6" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047A0DZ" = "1" /* Dilation of Left Renal Artery with Intraluminal Device, Open Approach */
"047A0E6" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047A0EZ" = "1" /* Dilation of Left Renal Artery with Two Intraluminal Devices, Open Approach */
"047A0F6" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047A0FZ" = "1" /* Dilation of Left Renal Artery with Three Intraluminal Devices, Open Approach */
"047A0G6" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047A0GZ" = "1" /* Dilation of Left Renal Artery with Four or More Intraluminal Devices, Open Approach */
"047A0Z6" = "1" /* Dilation of Left Renal Artery, Bifurcation, Open Approach */
"047A0ZZ" = "1" /* Dilation of Left Renal Artery, Open Approach */
"047A346" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047A34Z" = "1" /* Dilation of Left Renal Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047A356" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047A35Z" = "1" /* Dilation of Left Renal Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047A366" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047A36Z" = "1" /* Dilation of Left Renal Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047A376" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047A37Z" = "1" /* Dilation of Left Renal Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047A3D6" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"047A3DZ" = "1" /* Dilation of Left Renal Artery with Intraluminal Device, Percutaneous Approach */
"047A3E6" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"047A3EZ" = "1" /* Dilation of Left Renal Artery with Two Intraluminal Devices, Percutaneous Approach */
"047A3F6" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"047A3FZ" = "1" /* Dilation of Left Renal Artery with Three Intraluminal Devices, Percutaneous Approach */
"047A3G6" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"047A3GZ" = "1" /* Dilation of Left Renal Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"047A3Z6" = "1" /* Dilation of Left Renal Artery, Bifurcation, Percutaneous Approach */
"047A3ZZ" = "1" /* Dilation of Left Renal Artery, Percutaneous Approach */
"047A446" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047A44Z" = "1" /* Dilation of Left Renal Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047A456" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A45Z" = "1" /* Dilation of Left Renal Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A466" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A46Z" = "1" /* Dilation of Left Renal Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A476" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A47Z" = "1" /* Dilation of Left Renal Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A4D6" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047A4DZ" = "1" /* Dilation of Left Renal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047A4E6" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A4EZ" = "1" /* Dilation of Left Renal Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A4F6" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A4FZ" = "1" /* Dilation of Left Renal Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A4G6" = "1" /* Dilation of Left Renal Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A4GZ" = "1" /* Dilation of Left Renal Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047A4Z6" = "1" /* Dilation of Left Renal Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047A4ZZ" = "1" /* Dilation of Left Renal Artery, Percutaneous Endoscopic Approach */
"047B046" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047B04Z" = "1" /* Dilation of Inferior Mesenteric Artery with Drug-eluting Intraluminal Device, Open Approach */
"047B056" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047B05Z" = "1" /* Dilation of Inferior Mesenteric Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047B066" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047B06Z" = "1" /* Dilation of Inferior Mesenteric Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047B076" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047B07Z" = "1" /* Dilation of Inferior Mesenteric Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047B0D6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047B0DZ" = "1" /* Dilation of Inferior Mesenteric Artery with Intraluminal Device, Open Approach */
"047B0E6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047B0EZ" = "1" /* Dilation of Inferior Mesenteric Artery with Two Intraluminal Devices, Open Approach */
"047B0F6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047B0FZ" = "1" /* Dilation of Inferior Mesenteric Artery with Three Intraluminal Devices, Open Approach */
"047B0G6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047B0GZ" = "1" /* Dilation of Inferior Mesenteric Artery with Four or More Intraluminal Devices, Open Approach */
"047B0Z6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, Open Approach */
"047B0ZZ" = "1" /* Dilation of Inferior Mesenteric Artery, Open Approach */
"047B346" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047B34Z" = "1" /* Dilation of Inferior Mesenteric Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047B356" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047B35Z" = "1" /* Dilation of Inferior Mesenteric Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047B366" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047B36Z" = "1" /* Dilation of Inferior Mesenteric Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047B376" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047B37Z" = "1" /* Dilation of Inferior Mesenteric Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047B3D6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"047B3DZ" = "1" /* Dilation of Inferior Mesenteric Artery with Intraluminal Device, Percutaneous Approach */
"047B3E6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"047B3EZ" = "1" /* Dilation of Inferior Mesenteric Artery with Two Intraluminal Devices, Percutaneous Approach */
"047B3F6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"047B3FZ" = "1" /* Dilation of Inferior Mesenteric Artery with Three Intraluminal Devices, Percutaneous Approach */
"047B3G6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"047B3GZ" = "1" /* Dilation of Inferior Mesenteric Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"047B3Z6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, Percutaneous Approach */
"047B3ZZ" = "1" /* Dilation of Inferior Mesenteric Artery, Percutaneous Approach */
"047B446" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047B44Z" = "1" /* Dilation of Inferior Mesenteric Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047B456" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B45Z" = "1" /* Dilation of Inferior Mesenteric Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B466" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B46Z" = "1" /* Dilation of Inferior Mesenteric Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B476" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B47Z" = "1" /* Dilation of Inferior Mesenteric Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B4D6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047B4DZ" = "1" /* Dilation of Inferior Mesenteric Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047B4E6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B4EZ" = "1" /* Dilation of Inferior Mesenteric Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B4F6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B4FZ" = "1" /* Dilation of Inferior Mesenteric Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B4G6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B4GZ" = "1" /* Dilation of Inferior Mesenteric Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047B4Z6" = "1" /* Dilation of Inferior Mesenteric Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047B4ZZ" = "1" /* Dilation of Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"047C046" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047C04Z" = "1" /* Dilation of Right Common Iliac Artery with Drug-eluting Intraluminal Device, Open Approach */
"047C056" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047C05Z" = "1" /* Dilation of Right Common Iliac Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047C066" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047C06Z" = "1" /* Dilation of Right Common Iliac Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047C076" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047C07Z" = "1" /* Dilation of Right Common Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047C0D6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047C0DZ" = "1" /* Dilation of Right Common Iliac Artery with Intraluminal Device, Open Approach */
"047C0E6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047C0EZ" = "1" /* Dilation of Right Common Iliac Artery with Two Intraluminal Devices, Open Approach */
"047C0F6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047C0FZ" = "1" /* Dilation of Right Common Iliac Artery with Three Intraluminal Devices, Open Approach */
"047C0G6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047C0GZ" = "1" /* Dilation of Right Common Iliac Artery with Four or More Intraluminal Devices, Open Approach */
"047C0Z6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, Open Approach */
"047C0ZZ" = "1" /* Dilation of Right Common Iliac Artery, Open Approach */
"047C346" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047C34Z" = "1" /* Dilation of Right Common Iliac Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047C356" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047C35Z" = "1" /* Dilation of Right Common Iliac Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047C366" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047C36Z" = "1" /* Dilation of Right Common Iliac Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047C376" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047C37Z" = "1" /* Dilation of Right Common Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047C3D6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"047C3DZ" = "1" /* Dilation of Right Common Iliac Artery with Intraluminal Device, Percutaneous Approach */
"047C3E6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"047C3EZ" = "1" /* Dilation of Right Common Iliac Artery with Two Intraluminal Devices, Percutaneous Approach */
"047C3F6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"047C3FZ" = "1" /* Dilation of Right Common Iliac Artery with Three Intraluminal Devices, Percutaneous Approach */
"047C3G6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"047C3GZ" = "1" /* Dilation of Right Common Iliac Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"047C3Z6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, Percutaneous Approach */
"047C3ZZ" = "1" /* Dilation of Right Common Iliac Artery, Percutaneous Approach */
"047C446" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047C44Z" = "1" /* Dilation of Right Common Iliac Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047C456" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C45Z" = "1" /* Dilation of Right Common Iliac Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C466" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C46Z" = "1" /* Dilation of Right Common Iliac Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C476" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C47Z" = "1" /* Dilation of Right Common Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C4D6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047C4DZ" = "1" /* Dilation of Right Common Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047C4E6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C4EZ" = "1" /* Dilation of Right Common Iliac Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C4F6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C4FZ" = "1" /* Dilation of Right Common Iliac Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C4G6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C4GZ" = "1" /* Dilation of Right Common Iliac Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047C4Z6" = "1" /* Dilation of Right Common Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047C4ZZ" = "1" /* Dilation of Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"047D046" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047D04Z" = "1" /* Dilation of Left Common Iliac Artery with Drug-eluting Intraluminal Device, Open Approach */
"047D056" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047D05Z" = "1" /* Dilation of Left Common Iliac Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047D066" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047D06Z" = "1" /* Dilation of Left Common Iliac Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047D076" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047D07Z" = "1" /* Dilation of Left Common Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047D0D6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047D0DZ" = "1" /* Dilation of Left Common Iliac Artery with Intraluminal Device, Open Approach */
"047D0E6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047D0EZ" = "1" /* Dilation of Left Common Iliac Artery with Two Intraluminal Devices, Open Approach */
"047D0F6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047D0FZ" = "1" /* Dilation of Left Common Iliac Artery with Three Intraluminal Devices, Open Approach */
"047D0G6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047D0GZ" = "1" /* Dilation of Left Common Iliac Artery with Four or More Intraluminal Devices, Open Approach */
"047D0Z6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, Open Approach */
"047D0ZZ" = "1" /* Dilation of Left Common Iliac Artery, Open Approach */
"047D346" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047D34Z" = "1" /* Dilation of Left Common Iliac Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047D356" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047D35Z" = "1" /* Dilation of Left Common Iliac Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047D366" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047D36Z" = "1" /* Dilation of Left Common Iliac Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047D376" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047D37Z" = "1" /* Dilation of Left Common Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047D3D6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"047D3DZ" = "1" /* Dilation of Left Common Iliac Artery with Intraluminal Device, Percutaneous Approach */
"047D3E6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"047D3EZ" = "1" /* Dilation of Left Common Iliac Artery with Two Intraluminal Devices, Percutaneous Approach */
"047D3F6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"047D3FZ" = "1" /* Dilation of Left Common Iliac Artery with Three Intraluminal Devices, Percutaneous Approach */
"047D3G6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"047D3GZ" = "1" /* Dilation of Left Common Iliac Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"047D3Z6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, Percutaneous Approach */
"047D3ZZ" = "1" /* Dilation of Left Common Iliac Artery, Percutaneous Approach */
"047D446" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047D44Z" = "1" /* Dilation of Left Common Iliac Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047D456" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D45Z" = "1" /* Dilation of Left Common Iliac Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D466" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D46Z" = "1" /* Dilation of Left Common Iliac Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D476" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D47Z" = "1" /* Dilation of Left Common Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D4D6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047D4DZ" = "1" /* Dilation of Left Common Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047D4E6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D4EZ" = "1" /* Dilation of Left Common Iliac Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D4F6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D4FZ" = "1" /* Dilation of Left Common Iliac Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D4G6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D4GZ" = "1" /* Dilation of Left Common Iliac Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047D4Z6" = "1" /* Dilation of Left Common Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047D4ZZ" = "1" /* Dilation of Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"047E046" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047E04Z" = "1" /* Dilation of Right Internal Iliac Artery with Drug-eluting Intraluminal Device, Open Approach */
"047E056" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047E05Z" = "1" /* Dilation of Right Internal Iliac Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047E066" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047E06Z" = "1" /* Dilation of Right Internal Iliac Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047E076" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047E07Z" = "1" /* Dilation of Right Internal Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047E0D6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047E0DZ" = "1" /* Dilation of Right Internal Iliac Artery with Intraluminal Device, Open Approach */
"047E0E6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047E0EZ" = "1" /* Dilation of Right Internal Iliac Artery with Two Intraluminal Devices, Open Approach */
"047E0F6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047E0FZ" = "1" /* Dilation of Right Internal Iliac Artery with Three Intraluminal Devices, Open Approach */
"047E0G6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047E0GZ" = "1" /* Dilation of Right Internal Iliac Artery with Four or More Intraluminal Devices, Open Approach */
"047E0Z6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, Open Approach */
"047E0ZZ" = "1" /* Dilation of Right Internal Iliac Artery, Open Approach */
"047E346" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047E34Z" = "1" /* Dilation of Right Internal Iliac Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047E356" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047E35Z" = "1" /* Dilation of Right Internal Iliac Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047E366" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047E36Z" = "1" /* Dilation of Right Internal Iliac Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047E376" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047E37Z" = "1" /* Dilation of Right Internal Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047E3D6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"047E3DZ" = "1" /* Dilation of Right Internal Iliac Artery with Intraluminal Device, Percutaneous Approach */
"047E3E6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"047E3EZ" = "1" /* Dilation of Right Internal Iliac Artery with Two Intraluminal Devices, Percutaneous Approach */
"047E3F6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"047E3FZ" = "1" /* Dilation of Right Internal Iliac Artery with Three Intraluminal Devices, Percutaneous Approach */
"047E3G6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"047E3GZ" = "1" /* Dilation of Right Internal Iliac Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"047E3Z6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, Percutaneous Approach */
"047E3ZZ" = "1" /* Dilation of Right Internal Iliac Artery, Percutaneous Approach */
"047E446" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047E44Z" = "1" /* Dilation of Right Internal Iliac Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047E456" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E45Z" = "1" /* Dilation of Right Internal Iliac Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E466" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E46Z" = "1" /* Dilation of Right Internal Iliac Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E476" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E47Z" = "1" /* Dilation of Right Internal Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E4D6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047E4DZ" = "1" /* Dilation of Right Internal Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047E4E6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E4EZ" = "1" /* Dilation of Right Internal Iliac Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E4F6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E4FZ" = "1" /* Dilation of Right Internal Iliac Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E4G6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E4GZ" = "1" /* Dilation of Right Internal Iliac Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047E4Z6" = "1" /* Dilation of Right Internal Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047E4ZZ" = "1" /* Dilation of Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"047F046" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047F04Z" = "1" /* Dilation of Left Internal Iliac Artery with Drug-eluting Intraluminal Device, Open Approach */
"047F056" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047F05Z" = "1" /* Dilation of Left Internal Iliac Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047F066" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047F06Z" = "1" /* Dilation of Left Internal Iliac Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047F076" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047F07Z" = "1" /* Dilation of Left Internal Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047F0D6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047F0DZ" = "1" /* Dilation of Left Internal Iliac Artery with Intraluminal Device, Open Approach */
"047F0E6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047F0EZ" = "1" /* Dilation of Left Internal Iliac Artery with Two Intraluminal Devices, Open Approach */
"047F0F6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047F0FZ" = "1" /* Dilation of Left Internal Iliac Artery with Three Intraluminal Devices, Open Approach */
"047F0G6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047F0GZ" = "1" /* Dilation of Left Internal Iliac Artery with Four or More Intraluminal Devices, Open Approach */
"047F0Z6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, Open Approach */
"047F0ZZ" = "1" /* Dilation of Left Internal Iliac Artery, Open Approach */
"047F346" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047F34Z" = "1" /* Dilation of Left Internal Iliac Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047F356" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047F35Z" = "1" /* Dilation of Left Internal Iliac Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047F366" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047F36Z" = "1" /* Dilation of Left Internal Iliac Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047F376" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047F37Z" = "1" /* Dilation of Left Internal Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047F3D6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"047F3DZ" = "1" /* Dilation of Left Internal Iliac Artery with Intraluminal Device, Percutaneous Approach */
"047F3E6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"047F3EZ" = "1" /* Dilation of Left Internal Iliac Artery with Two Intraluminal Devices, Percutaneous Approach */
"047F3F6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"047F3FZ" = "1" /* Dilation of Left Internal Iliac Artery with Three Intraluminal Devices, Percutaneous Approach */
"047F3G6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"047F3GZ" = "1" /* Dilation of Left Internal Iliac Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"047F3Z6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, Percutaneous Approach */
"047F3ZZ" = "1" /* Dilation of Left Internal Iliac Artery, Percutaneous Approach */
"047F446" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047F44Z" = "1" /* Dilation of Left Internal Iliac Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047F456" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F45Z" = "1" /* Dilation of Left Internal Iliac Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F466" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F46Z" = "1" /* Dilation of Left Internal Iliac Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F476" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F47Z" = "1" /* Dilation of Left Internal Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F4D6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047F4DZ" = "1" /* Dilation of Left Internal Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047F4E6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F4EZ" = "1" /* Dilation of Left Internal Iliac Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F4F6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F4FZ" = "1" /* Dilation of Left Internal Iliac Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F4G6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F4GZ" = "1" /* Dilation of Left Internal Iliac Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047F4Z6" = "1" /* Dilation of Left Internal Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047F4ZZ" = "1" /* Dilation of Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"047H046" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047H04Z" = "1" /* Dilation of Right External Iliac Artery with Drug-eluting Intraluminal Device, Open Approach */
"047H056" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047H05Z" = "1" /* Dilation of Right External Iliac Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047H066" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047H06Z" = "1" /* Dilation of Right External Iliac Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047H076" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047H07Z" = "1" /* Dilation of Right External Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047H0D6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047H0DZ" = "1" /* Dilation of Right External Iliac Artery with Intraluminal Device, Open Approach */
"047H0E6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047H0EZ" = "1" /* Dilation of Right External Iliac Artery with Two Intraluminal Devices, Open Approach */
"047H0F6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047H0FZ" = "1" /* Dilation of Right External Iliac Artery with Three Intraluminal Devices, Open Approach */
"047H0G6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047H0GZ" = "1" /* Dilation of Right External Iliac Artery with Four or More Intraluminal Devices, Open Approach */
"047H0Z6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, Open Approach */
"047H0ZZ" = "1" /* Dilation of Right External Iliac Artery, Open Approach */
"047H346" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047H34Z" = "1" /* Dilation of Right External Iliac Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047H356" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047H35Z" = "1" /* Dilation of Right External Iliac Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047H366" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047H36Z" = "1" /* Dilation of Right External Iliac Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047H376" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047H37Z" = "1" /* Dilation of Right External Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047H3D6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"047H3DZ" = "1" /* Dilation of Right External Iliac Artery with Intraluminal Device, Percutaneous Approach */
"047H3E6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"047H3EZ" = "1" /* Dilation of Right External Iliac Artery with Two Intraluminal Devices, Percutaneous Approach */
"047H3F6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"047H3FZ" = "1" /* Dilation of Right External Iliac Artery with Three Intraluminal Devices, Percutaneous Approach */
"047H3G6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"047H3GZ" = "1" /* Dilation of Right External Iliac Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"047H3Z6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, Percutaneous Approach */
"047H3ZZ" = "1" /* Dilation of Right External Iliac Artery, Percutaneous Approach */
"047H446" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047H44Z" = "1" /* Dilation of Right External Iliac Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047H456" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H45Z" = "1" /* Dilation of Right External Iliac Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H466" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H46Z" = "1" /* Dilation of Right External Iliac Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H476" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H47Z" = "1" /* Dilation of Right External Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H4D6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047H4DZ" = "1" /* Dilation of Right External Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047H4E6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H4EZ" = "1" /* Dilation of Right External Iliac Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H4F6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H4FZ" = "1" /* Dilation of Right External Iliac Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H4G6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H4GZ" = "1" /* Dilation of Right External Iliac Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047H4Z6" = "1" /* Dilation of Right External Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047H4ZZ" = "1" /* Dilation of Right External Iliac Artery, Percutaneous Endoscopic Approach */
"047J046" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047J04Z" = "1" /* Dilation of Left External Iliac Artery with Drug-eluting Intraluminal Device, Open Approach */
"047J056" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047J05Z" = "1" /* Dilation of Left External Iliac Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047J066" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047J06Z" = "1" /* Dilation of Left External Iliac Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047J076" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047J07Z" = "1" /* Dilation of Left External Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047J0D6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047J0DZ" = "1" /* Dilation of Left External Iliac Artery with Intraluminal Device, Open Approach */
"047J0E6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047J0EZ" = "1" /* Dilation of Left External Iliac Artery with Two Intraluminal Devices, Open Approach */
"047J0F6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047J0FZ" = "1" /* Dilation of Left External Iliac Artery with Three Intraluminal Devices, Open Approach */
"047J0G6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047J0GZ" = "1" /* Dilation of Left External Iliac Artery with Four or More Intraluminal Devices, Open Approach */
"047J0Z6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, Open Approach */
"047J0ZZ" = "1" /* Dilation of Left External Iliac Artery, Open Approach */
"047J346" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047J34Z" = "1" /* Dilation of Left External Iliac Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047J356" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047J35Z" = "1" /* Dilation of Left External Iliac Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047J366" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047J36Z" = "1" /* Dilation of Left External Iliac Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047J376" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047J37Z" = "1" /* Dilation of Left External Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047J3D6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"047J3DZ" = "1" /* Dilation of Left External Iliac Artery with Intraluminal Device, Percutaneous Approach */
"047J3E6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"047J3EZ" = "1" /* Dilation of Left External Iliac Artery with Two Intraluminal Devices, Percutaneous Approach */
"047J3F6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"047J3FZ" = "1" /* Dilation of Left External Iliac Artery with Three Intraluminal Devices, Percutaneous Approach */
"047J3G6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"047J3GZ" = "1" /* Dilation of Left External Iliac Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"047J3Z6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, Percutaneous Approach */
"047J3ZZ" = "1" /* Dilation of Left External Iliac Artery, Percutaneous Approach */
"047J446" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047J44Z" = "1" /* Dilation of Left External Iliac Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047J456" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J45Z" = "1" /* Dilation of Left External Iliac Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J466" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J46Z" = "1" /* Dilation of Left External Iliac Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J476" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J47Z" = "1" /* Dilation of Left External Iliac Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J4D6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047J4DZ" = "1" /* Dilation of Left External Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047J4E6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J4EZ" = "1" /* Dilation of Left External Iliac Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J4F6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J4FZ" = "1" /* Dilation of Left External Iliac Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J4G6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J4GZ" = "1" /* Dilation of Left External Iliac Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047J4Z6" = "1" /* Dilation of Left External Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047J4ZZ" = "1" /* Dilation of Left External Iliac Artery, Percutaneous Endoscopic Approach */
"047K041" = "1" /* Dilation of Right Femoral Artery with Drug-eluting Intraluminal Device, using Drug-Coated Balloon, Open Approach */
"047K046" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047K04Z" = "1" /* Dilation of Right Femoral Artery with Drug-eluting Intraluminal Device, Open Approach */
"047K056" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047K05Z" = "1" /* Dilation of Right Femoral Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047K066" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047K06Z" = "1" /* Dilation of Right Femoral Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047K076" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047K07Z" = "1" /* Dilation of Right Femoral Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047K0D1" = "1" /* Dilation of Right Femoral Artery with Intraluminal Device, using Drug-Coated Balloon, Open Approach */
"047K0D6" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047K0DZ" = "1" /* Dilation of Right Femoral Artery with Intraluminal Device, Open Approach */
"047K0E6" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047K0EZ" = "1" /* Dilation of Right Femoral Artery with Two Intraluminal Devices, Open Approach */
"047K0F6" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047K0FZ" = "1" /* Dilation of Right Femoral Artery with Three Intraluminal Devices, Open Approach */
"047K0G6" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047K0GZ" = "1" /* Dilation of Right Femoral Artery with Four or More Intraluminal Devices, Open Approach */
"047K0Z1" = "1" /* Dilation of Right Femoral Artery using Drug-Coated Balloon, Open Approach */
"047K0Z6" = "1" /* Dilation of Right Femoral Artery, Bifurcation, Open Approach */
"047K0ZZ" = "1" /* Dilation of Right Femoral Artery, Open Approach */
"047K341" = "1" /* Dilation of Right Femoral Artery with Drug-eluting Intraluminal Device, using Drug-Coated Balloon, Percutaneous Approach */
"047K346" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047K34Z" = "1" /* Dilation of Right Femoral Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047K356" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047K35Z" = "1" /* Dilation of Right Femoral Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047K366" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047K36Z" = "1" /* Dilation of Right Femoral Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047K376" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047K37Z" = "1" /* Dilation of Right Femoral Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047K3D1" = "1" /* Dilation of Right Femoral Artery with Intraluminal Device, using Drug-Coated Balloon, Percutaneous Approach */
"047K3D6" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"047K3DZ" = "1" /* Dilation of Right Femoral Artery with Intraluminal Device, Percutaneous Approach */
"047K3E6" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"047K3EZ" = "1" /* Dilation of Right Femoral Artery with Two Intraluminal Devices, Percutaneous Approach */
"047K3F6" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"047K3FZ" = "1" /* Dilation of Right Femoral Artery with Three Intraluminal Devices, Percutaneous Approach */
"047K3G6" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"047K3GZ" = "1" /* Dilation of Right Femoral Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"047K3Z1" = "1" /* Dilation of Right Femoral Artery using Drug-Coated Balloon, Percutaneous Approach */
"047K3Z6" = "1" /* Dilation of Right Femoral Artery, Bifurcation, Percutaneous Approach */
"047K3ZZ" = "1" /* Dilation of Right Femoral Artery, Percutaneous Approach */
"047K441" = "1" /* Dilation of Right Femoral Artery with Drug-eluting Intraluminal Device, using Drug-Coated Balloon, Percutaneous Endoscopic Approach */
"047K446" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047K44Z" = "1" /* Dilation of Right Femoral Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047K456" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047K45Z" = "1" /* Dilation of Right Femoral Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047K466" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047K46Z" = "1" /* Dilation of Right Femoral Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047K476" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047K47Z" = "1" /* Dilation of Right Femoral Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047K4D1" = "1" /* Dilation of Right Femoral Artery with Intraluminal Device, using Drug-Coated Balloon, Percutaneous Endoscopic Approach */
"047K4D6" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047K4DZ" = "1" /* Dilation of Right Femoral Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047K4E6" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047K4EZ" = "1" /* Dilation of Right Femoral Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047K4F6" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047K4FZ" = "1" /* Dilation of Right Femoral Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047K4G6" = "1" /* Dilation of Right Femoral Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047K4GZ" = "1" /* Dilation of Right Femoral Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047K4Z1" = "1" /* Dilation of Right Femoral Artery using Drug-Coated Balloon, Percutaneous Endoscopic Approach */
"047K4Z6" = "1" /* Dilation of Right Femoral Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047K4ZZ" = "1" /* Dilation of Right Femoral Artery, Percutaneous Endoscopic Approach */
"047L041" = "1" /* Dilation of Left Femoral Artery with Drug-eluting Intraluminal Device, using Drug-Coated Balloon, Open Approach */
"047L046" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047L04Z" = "1" /* Dilation of Left Femoral Artery with Drug-eluting Intraluminal Device, Open Approach */
"047L056" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047L05Z" = "1" /* Dilation of Left Femoral Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047L066" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047L06Z" = "1" /* Dilation of Left Femoral Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047L076" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047L07Z" = "1" /* Dilation of Left Femoral Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047L0D1" = "1" /* Dilation of Left Femoral Artery with Intraluminal Device, using Drug-Coated Balloon, Open Approach */
"047L0D6" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047L0DZ" = "1" /* Dilation of Left Femoral Artery with Intraluminal Device, Open Approach */
"047L0E6" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047L0EZ" = "1" /* Dilation of Left Femoral Artery with Two Intraluminal Devices, Open Approach */
"047L0F6" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047L0FZ" = "1" /* Dilation of Left Femoral Artery with Three Intraluminal Devices, Open Approach */
"047L0G6" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047L0GZ" = "1" /* Dilation of Left Femoral Artery with Four or More Intraluminal Devices, Open Approach */
"047L0Z1" = "1" /* Dilation of Left Femoral Artery using Drug-Coated Balloon, Open Approach */
"047L0Z6" = "1" /* Dilation of Left Femoral Artery, Bifurcation, Open Approach */
"047L0ZZ" = "1" /* Dilation of Left Femoral Artery, Open Approach */
"047L341" = "1" /* Dilation of Left Femoral Artery with Drug-eluting Intraluminal Device, using Drug-Coated Balloon, Percutaneous Approach */
"047L346" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047L34Z" = "1" /* Dilation of Left Femoral Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047L356" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047L35Z" = "1" /* Dilation of Left Femoral Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047L366" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047L36Z" = "1" /* Dilation of Left Femoral Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047L376" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047L37Z" = "1" /* Dilation of Left Femoral Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047L3D1" = "1" /* Dilation of Left Femoral Artery with Intraluminal Device, using Drug-Coated Balloon, Percutaneous Approach */
"047L3D6" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"047L3DZ" = "1" /* Dilation of Left Femoral Artery with Intraluminal Device, Percutaneous Approach */
"047L3E6" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"047L3EZ" = "1" /* Dilation of Left Femoral Artery with Two Intraluminal Devices, Percutaneous Approach */
"047L3F6" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"047L3FZ" = "1" /* Dilation of Left Femoral Artery with Three Intraluminal Devices, Percutaneous Approach */
"047L3G6" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"047L3GZ" = "1" /* Dilation of Left Femoral Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"047L3Z1" = "1" /* Dilation of Left Femoral Artery using Drug-Coated Balloon, Percutaneous Approach */
"047L3Z6" = "1" /* Dilation of Left Femoral Artery, Bifurcation, Percutaneous Approach */
"047L3ZZ" = "1" /* Dilation of Left Femoral Artery, Percutaneous Approach */
"047L441" = "1" /* Dilation of Left Femoral Artery with Drug-eluting Intraluminal Device, using Drug-Coated Balloon, Percutaneous Endoscopic Approach */
"047L446" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047L44Z" = "1" /* Dilation of Left Femoral Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047L456" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047L45Z" = "1" /* Dilation of Left Femoral Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047L466" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047L46Z" = "1" /* Dilation of Left Femoral Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047L476" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047L47Z" = "1" /* Dilation of Left Femoral Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047L4D1" = "1" /* Dilation of Left Femoral Artery with Intraluminal Device, using Drug-Coated Balloon, Percutaneous Endoscopic Approach */
"047L4D6" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047L4DZ" = "1" /* Dilation of Left Femoral Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047L4E6" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047L4EZ" = "1" /* Dilation of Left Femoral Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047L4F6" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047L4FZ" = "1" /* Dilation of Left Femoral Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047L4G6" = "1" /* Dilation of Left Femoral Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047L4GZ" = "1" /* Dilation of Left Femoral Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047L4Z1" = "1" /* Dilation of Left Femoral Artery using Drug-Coated Balloon, Percutaneous Endoscopic Approach */
"047L4Z6" = "1" /* Dilation of Left Femoral Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047L4ZZ" = "1" /* Dilation of Left Femoral Artery, Percutaneous Endoscopic Approach */
"047M041" = "1" /* Dilation of Right Popliteal Artery with Drug-eluting Intraluminal Device, using Drug-Coated Balloon, Open Approach */
"047M046" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047M04Z" = "1" /* Dilation of Right Popliteal Artery with Drug-eluting Intraluminal Device, Open Approach */
"047M056" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047M05Z" = "1" /* Dilation of Right Popliteal Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047M066" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047M06Z" = "1" /* Dilation of Right Popliteal Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047M076" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047M07Z" = "1" /* Dilation of Right Popliteal Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047M0D1" = "1" /* Dilation of Right Popliteal Artery with Intraluminal Device, using Drug-Coated Balloon, Open Approach */
"047M0D6" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047M0DZ" = "1" /* Dilation of Right Popliteal Artery with Intraluminal Device, Open Approach */
"047M0E6" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047M0EZ" = "1" /* Dilation of Right Popliteal Artery with Two Intraluminal Devices, Open Approach */
"047M0F6" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047M0FZ" = "1" /* Dilation of Right Popliteal Artery with Three Intraluminal Devices, Open Approach */
"047M0G6" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047M0GZ" = "1" /* Dilation of Right Popliteal Artery with Four or More Intraluminal Devices, Open Approach */
"047M0Z1" = "1" /* Dilation of Right Popliteal Artery using Drug-Coated Balloon, Open Approach */
"047M0Z6" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, Open Approach */
"047M0ZZ" = "1" /* Dilation of Right Popliteal Artery, Open Approach */
"047M341" = "1" /* Dilation of Right Popliteal Artery with Drug-eluting Intraluminal Device, using Drug-Coated Balloon, Percutaneous Approach */
"047M346" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047M34Z" = "1" /* Dilation of Right Popliteal Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047M356" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047M35Z" = "1" /* Dilation of Right Popliteal Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047M366" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047M36Z" = "1" /* Dilation of Right Popliteal Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047M376" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047M37Z" = "1" /* Dilation of Right Popliteal Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047M3D1" = "1" /* Dilation of Right Popliteal Artery with Intraluminal Device, using Drug-Coated Balloon, Percutaneous Approach */
"047M3D6" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"047M3DZ" = "1" /* Dilation of Right Popliteal Artery with Intraluminal Device, Percutaneous Approach */
"047M3E6" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"047M3EZ" = "1" /* Dilation of Right Popliteal Artery with Two Intraluminal Devices, Percutaneous Approach */
"047M3F6" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"047M3FZ" = "1" /* Dilation of Right Popliteal Artery with Three Intraluminal Devices, Percutaneous Approach */
"047M3G6" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"047M3GZ" = "1" /* Dilation of Right Popliteal Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"047M3Z1" = "1" /* Dilation of Right Popliteal Artery using Drug-Coated Balloon, Percutaneous Approach */
"047M3Z6" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, Percutaneous Approach */
"047M3ZZ" = "1" /* Dilation of Right Popliteal Artery, Percutaneous Approach */
"047M441" = "1" /* Dilation of Right Popliteal Artery with Drug-eluting Intraluminal Device, using Drug-Coated Balloon, Percutaneous Endoscopic Approach */
"047M446" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047M44Z" = "1" /* Dilation of Right Popliteal Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047M456" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047M45Z" = "1" /* Dilation of Right Popliteal Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047M466" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047M46Z" = "1" /* Dilation of Right Popliteal Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047M476" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047M47Z" = "1" /* Dilation of Right Popliteal Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047M4D1" = "1" /* Dilation of Right Popliteal Artery with Intraluminal Device, using Drug-Coated Balloon, Percutaneous Endoscopic Approach */
"047M4D6" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047M4DZ" = "1" /* Dilation of Right Popliteal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047M4E6" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047M4EZ" = "1" /* Dilation of Right Popliteal Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047M4F6" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047M4FZ" = "1" /* Dilation of Right Popliteal Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047M4G6" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047M4GZ" = "1" /* Dilation of Right Popliteal Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047M4Z1" = "1" /* Dilation of Right Popliteal Artery using Drug-Coated Balloon, Percutaneous Endoscopic Approach */
"047M4Z6" = "1" /* Dilation of Right Popliteal Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047M4ZZ" = "1" /* Dilation of Right Popliteal Artery, Percutaneous Endoscopic Approach */
"047N041" = "1" /* Dilation of Left Popliteal Artery with Drug-eluting Intraluminal Device, using Drug-Coated Balloon, Open Approach */
"047N046" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047N04Z" = "1" /* Dilation of Left Popliteal Artery with Drug-eluting Intraluminal Device, Open Approach */
"047N056" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047N05Z" = "1" /* Dilation of Left Popliteal Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047N066" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047N06Z" = "1" /* Dilation of Left Popliteal Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047N076" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047N07Z" = "1" /* Dilation of Left Popliteal Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047N0D1" = "1" /* Dilation of Left Popliteal Artery with Intraluminal Device, using Drug-Coated Balloon, Open Approach */
"047N0D6" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047N0DZ" = "1" /* Dilation of Left Popliteal Artery with Intraluminal Device, Open Approach */
"047N0E6" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047N0EZ" = "1" /* Dilation of Left Popliteal Artery with Two Intraluminal Devices, Open Approach */
"047N0F6" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047N0FZ" = "1" /* Dilation of Left Popliteal Artery with Three Intraluminal Devices, Open Approach */
"047N0G6" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047N0GZ" = "1" /* Dilation of Left Popliteal Artery with Four or More Intraluminal Devices, Open Approach */
"047N0Z1" = "1" /* Dilation of Left Popliteal Artery using Drug-Coated Balloon, Open Approach */
"047N0Z6" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, Open Approach */
"047N0ZZ" = "1" /* Dilation of Left Popliteal Artery, Open Approach */
"047N341" = "1" /* Dilation of Left Popliteal Artery with Drug-eluting Intraluminal Device, using Drug-Coated Balloon, Percutaneous Approach */
"047N346" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047N34Z" = "1" /* Dilation of Left Popliteal Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047N356" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047N35Z" = "1" /* Dilation of Left Popliteal Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047N366" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047N36Z" = "1" /* Dilation of Left Popliteal Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047N376" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047N37Z" = "1" /* Dilation of Left Popliteal Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047N3D1" = "1" /* Dilation of Left Popliteal Artery with Intraluminal Device, using Drug-Coated Balloon, Percutaneous Approach */
"047N3D6" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"047N3DZ" = "1" /* Dilation of Left Popliteal Artery with Intraluminal Device, Percutaneous Approach */
"047N3E6" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"047N3EZ" = "1" /* Dilation of Left Popliteal Artery with Two Intraluminal Devices, Percutaneous Approach */
"047N3F6" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"047N3FZ" = "1" /* Dilation of Left Popliteal Artery with Three Intraluminal Devices, Percutaneous Approach */
"047N3G6" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"047N3GZ" = "1" /* Dilation of Left Popliteal Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"047N3Z1" = "1" /* Dilation of Left Popliteal Artery using Drug-Coated Balloon, Percutaneous Approach */
"047N3Z6" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, Percutaneous Approach */
"047N3ZZ" = "1" /* Dilation of Left Popliteal Artery, Percutaneous Approach */
"047N441" = "1" /* Dilation of Left Popliteal Artery with Drug-eluting Intraluminal Device, using Drug-Coated Balloon, Percutaneous Endoscopic Approach */
"047N446" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047N44Z" = "1" /* Dilation of Left Popliteal Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047N456" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047N45Z" = "1" /* Dilation of Left Popliteal Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047N466" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047N46Z" = "1" /* Dilation of Left Popliteal Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047N476" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047N47Z" = "1" /* Dilation of Left Popliteal Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047N4D1" = "1" /* Dilation of Left Popliteal Artery with Intraluminal Device, using Drug-Coated Balloon, Percutaneous Endoscopic Approach */
"047N4D6" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047N4DZ" = "1" /* Dilation of Left Popliteal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047N4E6" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047N4EZ" = "1" /* Dilation of Left Popliteal Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047N4F6" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047N4FZ" = "1" /* Dilation of Left Popliteal Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047N4G6" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047N4GZ" = "1" /* Dilation of Left Popliteal Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047N4Z1" = "1" /* Dilation of Left Popliteal Artery using Drug-Coated Balloon, Percutaneous Endoscopic Approach */
"047N4Z6" = "1" /* Dilation of Left Popliteal Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047N4ZZ" = "1" /* Dilation of Left Popliteal Artery, Percutaneous Endoscopic Approach */
"047P046" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047P04Z" = "1" /* Dilation of Right Anterior Tibial Artery with Drug-eluting Intraluminal Device, Open Approach */
"047P056" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047P05Z" = "1" /* Dilation of Right Anterior Tibial Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047P066" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047P06Z" = "1" /* Dilation of Right Anterior Tibial Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047P076" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047P07Z" = "1" /* Dilation of Right Anterior Tibial Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047P0D6" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047P0DZ" = "1" /* Dilation of Right Anterior Tibial Artery with Intraluminal Device, Open Approach */
"047P0E6" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047P0EZ" = "1" /* Dilation of Right Anterior Tibial Artery with Two Intraluminal Devices, Open Approach */
"047P0F6" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047P0FZ" = "1" /* Dilation of Right Anterior Tibial Artery with Three Intraluminal Devices, Open Approach */
"047P0G6" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047P0GZ" = "1" /* Dilation of Right Anterior Tibial Artery with Four or More Intraluminal Devices, Open Approach */
"047P0Z6" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, Open Approach */
"047P0ZZ" = "1" /* Dilation of Right Anterior Tibial Artery, Open Approach */
"047P346" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047P34Z" = "1" /* Dilation of Right Anterior Tibial Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047P356" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047P35Z" = "1" /* Dilation of Right Anterior Tibial Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047P366" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047P36Z" = "1" /* Dilation of Right Anterior Tibial Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047P376" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047P37Z" = "1" /* Dilation of Right Anterior Tibial Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047P3D6" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"047P3DZ" = "1" /* Dilation of Right Anterior Tibial Artery with Intraluminal Device, Percutaneous Approach */
"047P3E6" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"047P3EZ" = "1" /* Dilation of Right Anterior Tibial Artery with Two Intraluminal Devices, Percutaneous Approach */
"047P3F6" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"047P3FZ" = "1" /* Dilation of Right Anterior Tibial Artery with Three Intraluminal Devices, Percutaneous Approach */
"047P3G6" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"047P3GZ" = "1" /* Dilation of Right Anterior Tibial Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"047P3Z6" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, Percutaneous Approach */
"047P3ZZ" = "1" /* Dilation of Right Anterior Tibial Artery, Percutaneous Approach */
"047P446" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047P44Z" = "1" /* Dilation of Right Anterior Tibial Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047P456" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047P45Z" = "1" /* Dilation of Right Anterior Tibial Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047P466" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047P46Z" = "1" /* Dilation of Right Anterior Tibial Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047P476" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047P47Z" = "1" /* Dilation of Right Anterior Tibial Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047P4D6" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047P4DZ" = "1" /* Dilation of Right Anterior Tibial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047P4E6" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047P4EZ" = "1" /* Dilation of Right Anterior Tibial Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047P4F6" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047P4FZ" = "1" /* Dilation of Right Anterior Tibial Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047P4G6" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047P4GZ" = "1" /* Dilation of Right Anterior Tibial Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047P4Z6" = "1" /* Dilation of Right Anterior Tibial Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047P4ZZ" = "1" /* Dilation of Right Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"047Q046" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047Q04Z" = "1" /* Dilation of Left Anterior Tibial Artery with Drug-eluting Intraluminal Device, Open Approach */
"047Q056" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047Q05Z" = "1" /* Dilation of Left Anterior Tibial Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047Q066" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047Q06Z" = "1" /* Dilation of Left Anterior Tibial Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047Q076" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047Q07Z" = "1" /* Dilation of Left Anterior Tibial Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047Q0D6" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047Q0DZ" = "1" /* Dilation of Left Anterior Tibial Artery with Intraluminal Device, Open Approach */
"047Q0E6" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047Q0EZ" = "1" /* Dilation of Left Anterior Tibial Artery with Two Intraluminal Devices, Open Approach */
"047Q0F6" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047Q0FZ" = "1" /* Dilation of Left Anterior Tibial Artery with Three Intraluminal Devices, Open Approach */
"047Q0G6" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047Q0GZ" = "1" /* Dilation of Left Anterior Tibial Artery with Four or More Intraluminal Devices, Open Approach */
"047Q0Z6" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, Open Approach */
"047Q0ZZ" = "1" /* Dilation of Left Anterior Tibial Artery, Open Approach */
"047Q346" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047Q34Z" = "1" /* Dilation of Left Anterior Tibial Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047Q356" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047Q35Z" = "1" /* Dilation of Left Anterior Tibial Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047Q366" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047Q36Z" = "1" /* Dilation of Left Anterior Tibial Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047Q376" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047Q37Z" = "1" /* Dilation of Left Anterior Tibial Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047Q3D6" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"047Q3DZ" = "1" /* Dilation of Left Anterior Tibial Artery with Intraluminal Device, Percutaneous Approach */
"047Q3E6" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"047Q3EZ" = "1" /* Dilation of Left Anterior Tibial Artery with Two Intraluminal Devices, Percutaneous Approach */
"047Q3F6" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"047Q3FZ" = "1" /* Dilation of Left Anterior Tibial Artery with Three Intraluminal Devices, Percutaneous Approach */
"047Q3G6" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"047Q3GZ" = "1" /* Dilation of Left Anterior Tibial Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"047Q3Z6" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, Percutaneous Approach */
"047Q3ZZ" = "1" /* Dilation of Left Anterior Tibial Artery, Percutaneous Approach */
"047Q446" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047Q44Z" = "1" /* Dilation of Left Anterior Tibial Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047Q456" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Q45Z" = "1" /* Dilation of Left Anterior Tibial Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Q466" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Q46Z" = "1" /* Dilation of Left Anterior Tibial Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Q476" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Q47Z" = "1" /* Dilation of Left Anterior Tibial Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Q4D6" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047Q4DZ" = "1" /* Dilation of Left Anterior Tibial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047Q4E6" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Q4EZ" = "1" /* Dilation of Left Anterior Tibial Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Q4F6" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Q4FZ" = "1" /* Dilation of Left Anterior Tibial Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Q4G6" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Q4GZ" = "1" /* Dilation of Left Anterior Tibial Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Q4Z6" = "1" /* Dilation of Left Anterior Tibial Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047Q4ZZ" = "1" /* Dilation of Left Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"047R046" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047R04Z" = "1" /* Dilation of Right Posterior Tibial Artery with Drug-eluting Intraluminal Device, Open Approach */
"047R056" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047R05Z" = "1" /* Dilation of Right Posterior Tibial Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047R066" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047R06Z" = "1" /* Dilation of Right Posterior Tibial Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047R076" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047R07Z" = "1" /* Dilation of Right Posterior Tibial Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047R0D6" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047R0DZ" = "1" /* Dilation of Right Posterior Tibial Artery with Intraluminal Device, Open Approach */
"047R0E6" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047R0EZ" = "1" /* Dilation of Right Posterior Tibial Artery with Two Intraluminal Devices, Open Approach */
"047R0F6" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047R0FZ" = "1" /* Dilation of Right Posterior Tibial Artery with Three Intraluminal Devices, Open Approach */
"047R0G6" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047R0GZ" = "1" /* Dilation of Right Posterior Tibial Artery with Four or More Intraluminal Devices, Open Approach */
"047R0Z6" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, Open Approach */
"047R0ZZ" = "1" /* Dilation of Right Posterior Tibial Artery, Open Approach */
"047R346" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047R34Z" = "1" /* Dilation of Right Posterior Tibial Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047R356" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047R35Z" = "1" /* Dilation of Right Posterior Tibial Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047R366" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047R36Z" = "1" /* Dilation of Right Posterior Tibial Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047R376" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047R37Z" = "1" /* Dilation of Right Posterior Tibial Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047R3D6" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"047R3DZ" = "1" /* Dilation of Right Posterior Tibial Artery with Intraluminal Device, Percutaneous Approach */
"047R3E6" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"047R3EZ" = "1" /* Dilation of Right Posterior Tibial Artery with Two Intraluminal Devices, Percutaneous Approach */
"047R3F6" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"047R3FZ" = "1" /* Dilation of Right Posterior Tibial Artery with Three Intraluminal Devices, Percutaneous Approach */
"047R3G6" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"047R3GZ" = "1" /* Dilation of Right Posterior Tibial Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"047R3Z6" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, Percutaneous Approach */
"047R3ZZ" = "1" /* Dilation of Right Posterior Tibial Artery, Percutaneous Approach */
"047R446" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047R44Z" = "1" /* Dilation of Right Posterior Tibial Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047R456" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047R45Z" = "1" /* Dilation of Right Posterior Tibial Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047R466" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047R46Z" = "1" /* Dilation of Right Posterior Tibial Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047R476" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047R47Z" = "1" /* Dilation of Right Posterior Tibial Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047R4D6" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047R4DZ" = "1" /* Dilation of Right Posterior Tibial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047R4E6" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047R4EZ" = "1" /* Dilation of Right Posterior Tibial Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047R4F6" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047R4FZ" = "1" /* Dilation of Right Posterior Tibial Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047R4G6" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047R4GZ" = "1" /* Dilation of Right Posterior Tibial Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047R4Z6" = "1" /* Dilation of Right Posterior Tibial Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047R4ZZ" = "1" /* Dilation of Right Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"047S046" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047S04Z" = "1" /* Dilation of Left Posterior Tibial Artery with Drug-eluting Intraluminal Device, Open Approach */
"047S056" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047S05Z" = "1" /* Dilation of Left Posterior Tibial Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047S066" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047S06Z" = "1" /* Dilation of Left Posterior Tibial Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047S076" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047S07Z" = "1" /* Dilation of Left Posterior Tibial Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047S0D6" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047S0DZ" = "1" /* Dilation of Left Posterior Tibial Artery with Intraluminal Device, Open Approach */
"047S0E6" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047S0EZ" = "1" /* Dilation of Left Posterior Tibial Artery with Two Intraluminal Devices, Open Approach */
"047S0F6" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047S0FZ" = "1" /* Dilation of Left Posterior Tibial Artery with Three Intraluminal Devices, Open Approach */
"047S0G6" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047S0GZ" = "1" /* Dilation of Left Posterior Tibial Artery with Four or More Intraluminal Devices, Open Approach */
"047S0Z6" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, Open Approach */
"047S0ZZ" = "1" /* Dilation of Left Posterior Tibial Artery, Open Approach */
"047S346" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047S34Z" = "1" /* Dilation of Left Posterior Tibial Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047S356" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047S35Z" = "1" /* Dilation of Left Posterior Tibial Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047S366" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047S36Z" = "1" /* Dilation of Left Posterior Tibial Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047S376" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047S37Z" = "1" /* Dilation of Left Posterior Tibial Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047S3D6" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"047S3DZ" = "1" /* Dilation of Left Posterior Tibial Artery with Intraluminal Device, Percutaneous Approach */
"047S3E6" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"047S3EZ" = "1" /* Dilation of Left Posterior Tibial Artery with Two Intraluminal Devices, Percutaneous Approach */
"047S3F6" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"047S3FZ" = "1" /* Dilation of Left Posterior Tibial Artery with Three Intraluminal Devices, Percutaneous Approach */
"047S3G6" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"047S3GZ" = "1" /* Dilation of Left Posterior Tibial Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"047S3Z6" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, Percutaneous Approach */
"047S3ZZ" = "1" /* Dilation of Left Posterior Tibial Artery, Percutaneous Approach */
"047S446" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047S44Z" = "1" /* Dilation of Left Posterior Tibial Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047S456" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047S45Z" = "1" /* Dilation of Left Posterior Tibial Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047S466" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047S46Z" = "1" /* Dilation of Left Posterior Tibial Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047S476" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047S47Z" = "1" /* Dilation of Left Posterior Tibial Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047S4D6" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047S4DZ" = "1" /* Dilation of Left Posterior Tibial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047S4E6" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047S4EZ" = "1" /* Dilation of Left Posterior Tibial Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047S4F6" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047S4FZ" = "1" /* Dilation of Left Posterior Tibial Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047S4G6" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047S4GZ" = "1" /* Dilation of Left Posterior Tibial Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047S4Z6" = "1" /* Dilation of Left Posterior Tibial Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047S4ZZ" = "1" /* Dilation of Left Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"047T046" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047T04Z" = "1" /* Dilation of Right Peroneal Artery with Drug-eluting Intraluminal Device, Open Approach */
"047T056" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047T05Z" = "1" /* Dilation of Right Peroneal Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047T066" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047T06Z" = "1" /* Dilation of Right Peroneal Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047T076" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047T07Z" = "1" /* Dilation of Right Peroneal Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047T0D6" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047T0DZ" = "1" /* Dilation of Right Peroneal Artery with Intraluminal Device, Open Approach */
"047T0E6" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047T0EZ" = "1" /* Dilation of Right Peroneal Artery with Two Intraluminal Devices, Open Approach */
"047T0F6" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047T0FZ" = "1" /* Dilation of Right Peroneal Artery with Three Intraluminal Devices, Open Approach */
"047T0G6" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047T0GZ" = "1" /* Dilation of Right Peroneal Artery with Four or More Intraluminal Devices, Open Approach */
"047T0Z6" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, Open Approach */
"047T0ZZ" = "1" /* Dilation of Right Peroneal Artery, Open Approach */
"047T346" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047T34Z" = "1" /* Dilation of Right Peroneal Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047T356" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047T35Z" = "1" /* Dilation of Right Peroneal Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047T366" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047T36Z" = "1" /* Dilation of Right Peroneal Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047T376" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047T37Z" = "1" /* Dilation of Right Peroneal Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047T3D6" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"047T3DZ" = "1" /* Dilation of Right Peroneal Artery with Intraluminal Device, Percutaneous Approach */
"047T3E6" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"047T3EZ" = "1" /* Dilation of Right Peroneal Artery with Two Intraluminal Devices, Percutaneous Approach */
"047T3F6" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"047T3FZ" = "1" /* Dilation of Right Peroneal Artery with Three Intraluminal Devices, Percutaneous Approach */
"047T3G6" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"047T3GZ" = "1" /* Dilation of Right Peroneal Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"047T3Z6" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, Percutaneous Approach */
"047T3ZZ" = "1" /* Dilation of Right Peroneal Artery, Percutaneous Approach */
"047T446" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047T44Z" = "1" /* Dilation of Right Peroneal Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047T456" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047T45Z" = "1" /* Dilation of Right Peroneal Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047T466" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047T46Z" = "1" /* Dilation of Right Peroneal Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047T476" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047T47Z" = "1" /* Dilation of Right Peroneal Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047T4D6" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047T4DZ" = "1" /* Dilation of Right Peroneal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047T4E6" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047T4EZ" = "1" /* Dilation of Right Peroneal Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047T4F6" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047T4FZ" = "1" /* Dilation of Right Peroneal Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047T4G6" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047T4GZ" = "1" /* Dilation of Right Peroneal Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047T4Z6" = "1" /* Dilation of Right Peroneal Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047T4ZZ" = "1" /* Dilation of Right Peroneal Artery, Percutaneous Endoscopic Approach */
"047U046" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047U04Z" = "1" /* Dilation of Left Peroneal Artery with Drug-eluting Intraluminal Device, Open Approach */
"047U056" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047U05Z" = "1" /* Dilation of Left Peroneal Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047U066" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047U06Z" = "1" /* Dilation of Left Peroneal Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047U076" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047U07Z" = "1" /* Dilation of Left Peroneal Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047U0D6" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047U0DZ" = "1" /* Dilation of Left Peroneal Artery with Intraluminal Device, Open Approach */
"047U0E6" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047U0EZ" = "1" /* Dilation of Left Peroneal Artery with Two Intraluminal Devices, Open Approach */
"047U0F6" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047U0FZ" = "1" /* Dilation of Left Peroneal Artery with Three Intraluminal Devices, Open Approach */
"047U0G6" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047U0GZ" = "1" /* Dilation of Left Peroneal Artery with Four or More Intraluminal Devices, Open Approach */
"047U0Z6" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, Open Approach */
"047U0ZZ" = "1" /* Dilation of Left Peroneal Artery, Open Approach */
"047U346" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047U34Z" = "1" /* Dilation of Left Peroneal Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047U356" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047U35Z" = "1" /* Dilation of Left Peroneal Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047U366" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047U36Z" = "1" /* Dilation of Left Peroneal Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047U376" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047U37Z" = "1" /* Dilation of Left Peroneal Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047U3D6" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"047U3DZ" = "1" /* Dilation of Left Peroneal Artery with Intraluminal Device, Percutaneous Approach */
"047U3E6" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"047U3EZ" = "1" /* Dilation of Left Peroneal Artery with Two Intraluminal Devices, Percutaneous Approach */
"047U3F6" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"047U3FZ" = "1" /* Dilation of Left Peroneal Artery with Three Intraluminal Devices, Percutaneous Approach */
"047U3G6" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"047U3GZ" = "1" /* Dilation of Left Peroneal Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"047U3Z6" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, Percutaneous Approach */
"047U3ZZ" = "1" /* Dilation of Left Peroneal Artery, Percutaneous Approach */
"047U446" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047U44Z" = "1" /* Dilation of Left Peroneal Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047U456" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047U45Z" = "1" /* Dilation of Left Peroneal Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047U466" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047U46Z" = "1" /* Dilation of Left Peroneal Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047U476" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047U47Z" = "1" /* Dilation of Left Peroneal Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047U4D6" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047U4DZ" = "1" /* Dilation of Left Peroneal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047U4E6" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047U4EZ" = "1" /* Dilation of Left Peroneal Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047U4F6" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047U4FZ" = "1" /* Dilation of Left Peroneal Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047U4G6" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047U4GZ" = "1" /* Dilation of Left Peroneal Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047U4Z6" = "1" /* Dilation of Left Peroneal Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047U4ZZ" = "1" /* Dilation of Left Peroneal Artery, Percutaneous Endoscopic Approach */
"047V046" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047V04Z" = "1" /* Dilation of Right Foot Artery with Drug-eluting Intraluminal Device, Open Approach */
"047V056" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047V05Z" = "1" /* Dilation of Right Foot Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047V066" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047V06Z" = "1" /* Dilation of Right Foot Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047V076" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047V07Z" = "1" /* Dilation of Right Foot Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047V0D6" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047V0DZ" = "1" /* Dilation of Right Foot Artery with Intraluminal Device, Open Approach */
"047V0E6" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047V0EZ" = "1" /* Dilation of Right Foot Artery with Two Intraluminal Devices, Open Approach */
"047V0F6" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047V0FZ" = "1" /* Dilation of Right Foot Artery with Three Intraluminal Devices, Open Approach */
"047V0G6" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047V0GZ" = "1" /* Dilation of Right Foot Artery with Four or More Intraluminal Devices, Open Approach */
"047V0Z6" = "1" /* Dilation of Right Foot Artery, Bifurcation, Open Approach */
"047V0ZZ" = "1" /* Dilation of Right Foot Artery, Open Approach */
"047V346" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047V34Z" = "1" /* Dilation of Right Foot Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047V356" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047V35Z" = "1" /* Dilation of Right Foot Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047V366" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047V36Z" = "1" /* Dilation of Right Foot Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047V376" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047V37Z" = "1" /* Dilation of Right Foot Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047V3D6" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"047V3DZ" = "1" /* Dilation of Right Foot Artery with Intraluminal Device, Percutaneous Approach */
"047V3E6" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"047V3EZ" = "1" /* Dilation of Right Foot Artery with Two Intraluminal Devices, Percutaneous Approach */
"047V3F6" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"047V3FZ" = "1" /* Dilation of Right Foot Artery with Three Intraluminal Devices, Percutaneous Approach */
"047V3G6" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"047V3GZ" = "1" /* Dilation of Right Foot Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"047V3Z6" = "1" /* Dilation of Right Foot Artery, Bifurcation, Percutaneous Approach */
"047V3ZZ" = "1" /* Dilation of Right Foot Artery, Percutaneous Approach */
"047V446" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047V44Z" = "1" /* Dilation of Right Foot Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047V456" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047V45Z" = "1" /* Dilation of Right Foot Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047V466" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047V46Z" = "1" /* Dilation of Right Foot Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047V476" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047V47Z" = "1" /* Dilation of Right Foot Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047V4D6" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047V4DZ" = "1" /* Dilation of Right Foot Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047V4E6" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047V4EZ" = "1" /* Dilation of Right Foot Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047V4F6" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047V4FZ" = "1" /* Dilation of Right Foot Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047V4G6" = "1" /* Dilation of Right Foot Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047V4GZ" = "1" /* Dilation of Right Foot Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047V4Z6" = "1" /* Dilation of Right Foot Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047V4ZZ" = "1" /* Dilation of Right Foot Artery, Percutaneous Endoscopic Approach */
"047W046" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047W04Z" = "1" /* Dilation of Left Foot Artery with Drug-eluting Intraluminal Device, Open Approach */
"047W056" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047W05Z" = "1" /* Dilation of Left Foot Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047W066" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047W06Z" = "1" /* Dilation of Left Foot Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047W076" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047W07Z" = "1" /* Dilation of Left Foot Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047W0D6" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047W0DZ" = "1" /* Dilation of Left Foot Artery with Intraluminal Device, Open Approach */
"047W0E6" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047W0EZ" = "1" /* Dilation of Left Foot Artery with Two Intraluminal Devices, Open Approach */
"047W0F6" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047W0FZ" = "1" /* Dilation of Left Foot Artery with Three Intraluminal Devices, Open Approach */
"047W0G6" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047W0GZ" = "1" /* Dilation of Left Foot Artery with Four or More Intraluminal Devices, Open Approach */
"047W0Z6" = "1" /* Dilation of Left Foot Artery, Bifurcation, Open Approach */
"047W0ZZ" = "1" /* Dilation of Left Foot Artery, Open Approach */
"047W346" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047W34Z" = "1" /* Dilation of Left Foot Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047W356" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047W35Z" = "1" /* Dilation of Left Foot Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047W366" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047W36Z" = "1" /* Dilation of Left Foot Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047W376" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047W37Z" = "1" /* Dilation of Left Foot Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047W3D6" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"047W3DZ" = "1" /* Dilation of Left Foot Artery with Intraluminal Device, Percutaneous Approach */
"047W3E6" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"047W3EZ" = "1" /* Dilation of Left Foot Artery with Two Intraluminal Devices, Percutaneous Approach */
"047W3F6" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"047W3FZ" = "1" /* Dilation of Left Foot Artery with Three Intraluminal Devices, Percutaneous Approach */
"047W3G6" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"047W3GZ" = "1" /* Dilation of Left Foot Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"047W3Z6" = "1" /* Dilation of Left Foot Artery, Bifurcation, Percutaneous Approach */
"047W3ZZ" = "1" /* Dilation of Left Foot Artery, Percutaneous Approach */
"047W446" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047W44Z" = "1" /* Dilation of Left Foot Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047W456" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047W45Z" = "1" /* Dilation of Left Foot Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047W466" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047W46Z" = "1" /* Dilation of Left Foot Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047W476" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047W47Z" = "1" /* Dilation of Left Foot Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047W4D6" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047W4DZ" = "1" /* Dilation of Left Foot Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047W4E6" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047W4EZ" = "1" /* Dilation of Left Foot Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047W4F6" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047W4FZ" = "1" /* Dilation of Left Foot Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047W4G6" = "1" /* Dilation of Left Foot Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047W4GZ" = "1" /* Dilation of Left Foot Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047W4Z6" = "1" /* Dilation of Left Foot Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047W4ZZ" = "1" /* Dilation of Left Foot Artery, Percutaneous Endoscopic Approach */
"047Y046" = "1" /* Dilation of Lower Artery, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"047Y04Z" = "1" /* Dilation of Lower Artery with Drug-eluting Intraluminal Device, Open Approach */
"047Y056" = "1" /* Dilation of Lower Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"047Y05Z" = "1" /* Dilation of Lower Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"047Y066" = "1" /* Dilation of Lower Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"047Y06Z" = "1" /* Dilation of Lower Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"047Y076" = "1" /* Dilation of Lower Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047Y07Z" = "1" /* Dilation of Lower Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"047Y0D6" = "1" /* Dilation of Lower Artery, Bifurcation, with Intraluminal Device, Open Approach */
"047Y0DZ" = "1" /* Dilation of Lower Artery with Intraluminal Device, Open Approach */
"047Y0E6" = "1" /* Dilation of Lower Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"047Y0EZ" = "1" /* Dilation of Lower Artery with Two Intraluminal Devices, Open Approach */
"047Y0F6" = "1" /* Dilation of Lower Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"047Y0FZ" = "1" /* Dilation of Lower Artery with Three Intraluminal Devices, Open Approach */
"047Y0G6" = "1" /* Dilation of Lower Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"047Y0GZ" = "1" /* Dilation of Lower Artery with Four or More Intraluminal Devices, Open Approach */
"047Y0Z6" = "1" /* Dilation of Lower Artery, Bifurcation, Open Approach */
"047Y0ZZ" = "1" /* Dilation of Lower Artery, Open Approach */
"047Y346" = "1" /* Dilation of Lower Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047Y34Z" = "1" /* Dilation of Lower Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"047Y356" = "1" /* Dilation of Lower Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047Y35Z" = "1" /* Dilation of Lower Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047Y366" = "1" /* Dilation of Lower Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047Y36Z" = "1" /* Dilation of Lower Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047Y376" = "1" /* Dilation of Lower Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047Y37Z" = "1" /* Dilation of Lower Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"047Y3D6" = "1" /* Dilation of Lower Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"047Y3DZ" = "1" /* Dilation of Lower Artery with Intraluminal Device, Percutaneous Approach */
"047Y3E6" = "1" /* Dilation of Lower Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"047Y3EZ" = "1" /* Dilation of Lower Artery with Two Intraluminal Devices, Percutaneous Approach */
"047Y3F6" = "1" /* Dilation of Lower Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"047Y3FZ" = "1" /* Dilation of Lower Artery with Three Intraluminal Devices, Percutaneous Approach */
"047Y3G6" = "1" /* Dilation of Lower Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"047Y3GZ" = "1" /* Dilation of Lower Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"047Y3Z6" = "1" /* Dilation of Lower Artery, Bifurcation, Percutaneous Approach */
"047Y3ZZ" = "1" /* Dilation of Lower Artery, Percutaneous Approach */
"047Y446" = "1" /* Dilation of Lower Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047Y44Z" = "1" /* Dilation of Lower Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"047Y456" = "1" /* Dilation of Lower Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Y45Z" = "1" /* Dilation of Lower Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Y466" = "1" /* Dilation of Lower Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Y46Z" = "1" /* Dilation of Lower Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Y476" = "1" /* Dilation of Lower Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Y47Z" = "1" /* Dilation of Lower Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Y4D6" = "1" /* Dilation of Lower Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"047Y4DZ" = "1" /* Dilation of Lower Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"047Y4E6" = "1" /* Dilation of Lower Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Y4EZ" = "1" /* Dilation of Lower Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Y4F6" = "1" /* Dilation of Lower Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Y4FZ" = "1" /* Dilation of Lower Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Y4G6" = "1" /* Dilation of Lower Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Y4GZ" = "1" /* Dilation of Lower Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"047Y4Z6" = "1" /* Dilation of Lower Artery, Bifurcation, Percutaneous Endoscopic Approach */
"047Y4ZZ" = "1" /* Dilation of Lower Artery, Percutaneous Endoscopic Approach */
"04900ZX" = "1" /* Drainage of Abdominal Aorta, Open Approach, Diagnostic */
"04904ZX" = "1" /* Drainage of Abdominal Aorta, Percutaneous Endoscopic Approach, Diagnostic */
"04910ZX" = "1" /* Drainage of Celiac Artery, Open Approach, Diagnostic */
"04914ZX" = "1" /* Drainage of Celiac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04920ZX" = "1" /* Drainage of Gastric Artery, Open Approach, Diagnostic */
"04924ZX" = "1" /* Drainage of Gastric Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04930ZX" = "1" /* Drainage of Hepatic Artery, Open Approach, Diagnostic */
"04934ZX" = "1" /* Drainage of Hepatic Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04940ZX" = "1" /* Drainage of Splenic Artery, Open Approach, Diagnostic */
"04944ZX" = "1" /* Drainage of Splenic Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04950ZX" = "1" /* Drainage of Superior Mesenteric Artery, Open Approach, Diagnostic */
"04954ZX" = "1" /* Drainage of Superior Mesenteric Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04960ZX" = "1" /* Drainage of Right Colic Artery, Open Approach, Diagnostic */
"04964ZX" = "1" /* Drainage of Right Colic Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04970ZX" = "1" /* Drainage of Left Colic Artery, Open Approach, Diagnostic */
"04974ZX" = "1" /* Drainage of Left Colic Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04980ZX" = "1" /* Drainage of Middle Colic Artery, Open Approach, Diagnostic */
"04984ZX" = "1" /* Drainage of Middle Colic Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04990ZX" = "1" /* Drainage of Right Renal Artery, Open Approach, Diagnostic */
"04994ZX" = "1" /* Drainage of Right Renal Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049A0ZX" = "1" /* Drainage of Left Renal Artery, Open Approach, Diagnostic */
"049A4ZX" = "1" /* Drainage of Left Renal Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049B0ZX" = "1" /* Drainage of Inferior Mesenteric Artery, Open Approach, Diagnostic */
"049B4ZX" = "1" /* Drainage of Inferior Mesenteric Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049C0ZX" = "1" /* Drainage of Right Common Iliac Artery, Open Approach, Diagnostic */
"049C4ZX" = "1" /* Drainage of Right Common Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049D0ZX" = "1" /* Drainage of Left Common Iliac Artery, Open Approach, Diagnostic */
"049D4ZX" = "1" /* Drainage of Left Common Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049E0ZX" = "1" /* Drainage of Right Internal Iliac Artery, Open Approach, Diagnostic */
"049E4ZX" = "1" /* Drainage of Right Internal Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049F0ZX" = "1" /* Drainage of Left Internal Iliac Artery, Open Approach, Diagnostic */
"049F4ZX" = "1" /* Drainage of Left Internal Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049H0ZX" = "1" /* Drainage of Right External Iliac Artery, Open Approach, Diagnostic */
"049H4ZX" = "1" /* Drainage of Right External Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049J0ZX" = "1" /* Drainage of Left External Iliac Artery, Open Approach, Diagnostic */
"049J4ZX" = "1" /* Drainage of Left External Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049K0ZX" = "1" /* Drainage of Right Femoral Artery, Open Approach, Diagnostic */
"049K4ZX" = "1" /* Drainage of Right Femoral Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049L0ZX" = "1" /* Drainage of Left Femoral Artery, Open Approach, Diagnostic */
"049L4ZX" = "1" /* Drainage of Left Femoral Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049M0ZX" = "1" /* Drainage of Right Popliteal Artery, Open Approach, Diagnostic */
"049M4ZX" = "1" /* Drainage of Right Popliteal Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049N0ZX" = "1" /* Drainage of Left Popliteal Artery, Open Approach, Diagnostic */
"049N4ZX" = "1" /* Drainage of Left Popliteal Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049P0ZX" = "1" /* Drainage of Right Anterior Tibial Artery, Open Approach, Diagnostic */
"049P4ZX" = "1" /* Drainage of Right Anterior Tibial Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049Q0ZX" = "1" /* Drainage of Left Anterior Tibial Artery, Open Approach, Diagnostic */
"049Q4ZX" = "1" /* Drainage of Left Anterior Tibial Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049R0ZX" = "1" /* Drainage of Right Posterior Tibial Artery, Open Approach, Diagnostic */
"049R4ZX" = "1" /* Drainage of Right Posterior Tibial Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049S0ZX" = "1" /* Drainage of Left Posterior Tibial Artery, Open Approach, Diagnostic */
"049S4ZX" = "1" /* Drainage of Left Posterior Tibial Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049T0ZX" = "1" /* Drainage of Right Peroneal Artery, Open Approach, Diagnostic */
"049T4ZX" = "1" /* Drainage of Right Peroneal Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049U0ZX" = "1" /* Drainage of Left Peroneal Artery, Open Approach, Diagnostic */
"049U4ZX" = "1" /* Drainage of Left Peroneal Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049V0ZX" = "1" /* Drainage of Right Foot Artery, Open Approach, Diagnostic */
"049V4ZX" = "1" /* Drainage of Right Foot Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049W0ZX" = "1" /* Drainage of Left Foot Artery, Open Approach, Diagnostic */
"049W4ZX" = "1" /* Drainage of Left Foot Artery, Percutaneous Endoscopic Approach, Diagnostic */
"049Y0ZX" = "1" /* Drainage of Lower Artery, Open Approach, Diagnostic */
"049Y4ZX" = "1" /* Drainage of Lower Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04B00ZX" = "1" /* Excision of Abdominal Aorta, Open Approach, Diagnostic */
"04B00ZZ" = "1" /* Excision of Abdominal Aorta, Open Approach */
"04B03ZX" = "1" /* Excision of Abdominal Aorta, Percutaneous Approach, Diagnostic */
"04B03ZZ" = "1" /* Excision of Abdominal Aorta, Percutaneous Approach */
"04B04ZX" = "1" /* Excision of Abdominal Aorta, Percutaneous Endoscopic Approach, Diagnostic */
"04B04ZZ" = "1" /* Excision of Abdominal Aorta, Percutaneous Endoscopic Approach */
"04B10ZX" = "1" /* Excision of Celiac Artery, Open Approach, Diagnostic */
"04B10ZZ" = "1" /* Excision of Celiac Artery, Open Approach */
"04B13ZX" = "1" /* Excision of Celiac Artery, Percutaneous Approach, Diagnostic */
"04B13ZZ" = "1" /* Excision of Celiac Artery, Percutaneous Approach */
"04B14ZX" = "1" /* Excision of Celiac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04B14ZZ" = "1" /* Excision of Celiac Artery, Percutaneous Endoscopic Approach */
"04B20ZX" = "1" /* Excision of Gastric Artery, Open Approach, Diagnostic */
"04B20ZZ" = "1" /* Excision of Gastric Artery, Open Approach */
"04B23ZX" = "1" /* Excision of Gastric Artery, Percutaneous Approach, Diagnostic */
"04B23ZZ" = "1" /* Excision of Gastric Artery, Percutaneous Approach */
"04B24ZX" = "1" /* Excision of Gastric Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04B24ZZ" = "1" /* Excision of Gastric Artery, Percutaneous Endoscopic Approach */
"04B30ZX" = "1" /* Excision of Hepatic Artery, Open Approach, Diagnostic */
"04B30ZZ" = "1" /* Excision of Hepatic Artery, Open Approach */
"04B33ZX" = "1" /* Excision of Hepatic Artery, Percutaneous Approach, Diagnostic */
"04B33ZZ" = "1" /* Excision of Hepatic Artery, Percutaneous Approach */
"04B34ZX" = "1" /* Excision of Hepatic Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04B34ZZ" = "1" /* Excision of Hepatic Artery, Percutaneous Endoscopic Approach */
"04B40ZX" = "1" /* Excision of Splenic Artery, Open Approach, Diagnostic */
"04B40ZZ" = "1" /* Excision of Splenic Artery, Open Approach */
"04B43ZX" = "1" /* Excision of Splenic Artery, Percutaneous Approach, Diagnostic */
"04B43ZZ" = "1" /* Excision of Splenic Artery, Percutaneous Approach */
"04B44ZX" = "1" /* Excision of Splenic Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04B44ZZ" = "1" /* Excision of Splenic Artery, Percutaneous Endoscopic Approach */
"04B50ZX" = "1" /* Excision of Superior Mesenteric Artery, Open Approach, Diagnostic */
"04B50ZZ" = "1" /* Excision of Superior Mesenteric Artery, Open Approach */
"04B53ZX" = "1" /* Excision of Superior Mesenteric Artery, Percutaneous Approach, Diagnostic */
"04B53ZZ" = "1" /* Excision of Superior Mesenteric Artery, Percutaneous Approach */
"04B54ZX" = "1" /* Excision of Superior Mesenteric Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04B54ZZ" = "1" /* Excision of Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04B60ZX" = "1" /* Excision of Right Colic Artery, Open Approach, Diagnostic */
"04B60ZZ" = "1" /* Excision of Right Colic Artery, Open Approach */
"04B63ZX" = "1" /* Excision of Right Colic Artery, Percutaneous Approach, Diagnostic */
"04B63ZZ" = "1" /* Excision of Right Colic Artery, Percutaneous Approach */
"04B64ZX" = "1" /* Excision of Right Colic Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04B64ZZ" = "1" /* Excision of Right Colic Artery, Percutaneous Endoscopic Approach */
"04B70ZX" = "1" /* Excision of Left Colic Artery, Open Approach, Diagnostic */
"04B70ZZ" = "1" /* Excision of Left Colic Artery, Open Approach */
"04B73ZX" = "1" /* Excision of Left Colic Artery, Percutaneous Approach, Diagnostic */
"04B73ZZ" = "1" /* Excision of Left Colic Artery, Percutaneous Approach */
"04B74ZX" = "1" /* Excision of Left Colic Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04B74ZZ" = "1" /* Excision of Left Colic Artery, Percutaneous Endoscopic Approach */
"04B80ZX" = "1" /* Excision of Middle Colic Artery, Open Approach, Diagnostic */
"04B80ZZ" = "1" /* Excision of Middle Colic Artery, Open Approach */
"04B83ZX" = "1" /* Excision of Middle Colic Artery, Percutaneous Approach, Diagnostic */
"04B83ZZ" = "1" /* Excision of Middle Colic Artery, Percutaneous Approach */
"04B84ZX" = "1" /* Excision of Middle Colic Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04B84ZZ" = "1" /* Excision of Middle Colic Artery, Percutaneous Endoscopic Approach */
"04B90ZX" = "1" /* Excision of Right Renal Artery, Open Approach, Diagnostic */
"04B90ZZ" = "1" /* Excision of Right Renal Artery, Open Approach */
"04B93ZX" = "1" /* Excision of Right Renal Artery, Percutaneous Approach, Diagnostic */
"04B93ZZ" = "1" /* Excision of Right Renal Artery, Percutaneous Approach */
"04B94ZX" = "1" /* Excision of Right Renal Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04B94ZZ" = "1" /* Excision of Right Renal Artery, Percutaneous Endoscopic Approach */
"04BA0ZX" = "1" /* Excision of Left Renal Artery, Open Approach, Diagnostic */
"04BA0ZZ" = "1" /* Excision of Left Renal Artery, Open Approach */
"04BA3ZX" = "1" /* Excision of Left Renal Artery, Percutaneous Approach, Diagnostic */
"04BA3ZZ" = "1" /* Excision of Left Renal Artery, Percutaneous Approach */
"04BA4ZX" = "1" /* Excision of Left Renal Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BA4ZZ" = "1" /* Excision of Left Renal Artery, Percutaneous Endoscopic Approach */
"04BB0ZX" = "1" /* Excision of Inferior Mesenteric Artery, Open Approach, Diagnostic */
"04BB0ZZ" = "1" /* Excision of Inferior Mesenteric Artery, Open Approach */
"04BB3ZX" = "1" /* Excision of Inferior Mesenteric Artery, Percutaneous Approach, Diagnostic */
"04BB3ZZ" = "1" /* Excision of Inferior Mesenteric Artery, Percutaneous Approach */
"04BB4ZX" = "1" /* Excision of Inferior Mesenteric Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BB4ZZ" = "1" /* Excision of Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04BC0ZX" = "1" /* Excision of Right Common Iliac Artery, Open Approach, Diagnostic */
"04BC0ZZ" = "1" /* Excision of Right Common Iliac Artery, Open Approach */
"04BC3ZX" = "1" /* Excision of Right Common Iliac Artery, Percutaneous Approach, Diagnostic */
"04BC3ZZ" = "1" /* Excision of Right Common Iliac Artery, Percutaneous Approach */
"04BC4ZX" = "1" /* Excision of Right Common Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BC4ZZ" = "1" /* Excision of Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"04BD0ZX" = "1" /* Excision of Left Common Iliac Artery, Open Approach, Diagnostic */
"04BD0ZZ" = "1" /* Excision of Left Common Iliac Artery, Open Approach */
"04BD3ZX" = "1" /* Excision of Left Common Iliac Artery, Percutaneous Approach, Diagnostic */
"04BD3ZZ" = "1" /* Excision of Left Common Iliac Artery, Percutaneous Approach */
"04BD4ZX" = "1" /* Excision of Left Common Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BD4ZZ" = "1" /* Excision of Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"04BE0ZX" = "1" /* Excision of Right Internal Iliac Artery, Open Approach, Diagnostic */
"04BE0ZZ" = "1" /* Excision of Right Internal Iliac Artery, Open Approach */
"04BE3ZX" = "1" /* Excision of Right Internal Iliac Artery, Percutaneous Approach, Diagnostic */
"04BE3ZZ" = "1" /* Excision of Right Internal Iliac Artery, Percutaneous Approach */
"04BE4ZX" = "1" /* Excision of Right Internal Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BE4ZZ" = "1" /* Excision of Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04BF0ZX" = "1" /* Excision of Left Internal Iliac Artery, Open Approach, Diagnostic */
"04BF0ZZ" = "1" /* Excision of Left Internal Iliac Artery, Open Approach */
"04BF3ZX" = "1" /* Excision of Left Internal Iliac Artery, Percutaneous Approach, Diagnostic */
"04BF3ZZ" = "1" /* Excision of Left Internal Iliac Artery, Percutaneous Approach */
"04BF4ZX" = "1" /* Excision of Left Internal Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BF4ZZ" = "1" /* Excision of Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04BH0ZX" = "1" /* Excision of Right External Iliac Artery, Open Approach, Diagnostic */
"04BH0ZZ" = "1" /* Excision of Right External Iliac Artery, Open Approach */
"04BH3ZX" = "1" /* Excision of Right External Iliac Artery, Percutaneous Approach, Diagnostic */
"04BH3ZZ" = "1" /* Excision of Right External Iliac Artery, Percutaneous Approach */
"04BH4ZX" = "1" /* Excision of Right External Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BH4ZZ" = "1" /* Excision of Right External Iliac Artery, Percutaneous Endoscopic Approach */
"04BJ0ZX" = "1" /* Excision of Left External Iliac Artery, Open Approach, Diagnostic */
"04BJ0ZZ" = "1" /* Excision of Left External Iliac Artery, Open Approach */
"04BJ3ZX" = "1" /* Excision of Left External Iliac Artery, Percutaneous Approach, Diagnostic */
"04BJ3ZZ" = "1" /* Excision of Left External Iliac Artery, Percutaneous Approach */
"04BJ4ZX" = "1" /* Excision of Left External Iliac Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BJ4ZZ" = "1" /* Excision of Left External Iliac Artery, Percutaneous Endoscopic Approach */
"04BK0ZX" = "1" /* Excision of Right Femoral Artery, Open Approach, Diagnostic */
"04BK0ZZ" = "1" /* Excision of Right Femoral Artery, Open Approach */
"04BK3ZX" = "1" /* Excision of Right Femoral Artery, Percutaneous Approach, Diagnostic */
"04BK3ZZ" = "1" /* Excision of Right Femoral Artery, Percutaneous Approach */
"04BK4ZX" = "1" /* Excision of Right Femoral Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BK4ZZ" = "1" /* Excision of Right Femoral Artery, Percutaneous Endoscopic Approach */
"04BL0ZX" = "1" /* Excision of Left Femoral Artery, Open Approach, Diagnostic */
"04BL0ZZ" = "1" /* Excision of Left Femoral Artery, Open Approach */
"04BL3ZX" = "1" /* Excision of Left Femoral Artery, Percutaneous Approach, Diagnostic */
"04BL3ZZ" = "1" /* Excision of Left Femoral Artery, Percutaneous Approach */
"04BL4ZX" = "1" /* Excision of Left Femoral Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BL4ZZ" = "1" /* Excision of Left Femoral Artery, Percutaneous Endoscopic Approach */
"04BM0ZX" = "1" /* Excision of Right Popliteal Artery, Open Approach, Diagnostic */
"04BM0ZZ" = "1" /* Excision of Right Popliteal Artery, Open Approach */
"04BM3ZX" = "1" /* Excision of Right Popliteal Artery, Percutaneous Approach, Diagnostic */
"04BM3ZZ" = "1" /* Excision of Right Popliteal Artery, Percutaneous Approach */
"04BM4ZX" = "1" /* Excision of Right Popliteal Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BM4ZZ" = "1" /* Excision of Right Popliteal Artery, Percutaneous Endoscopic Approach */
"04BN0ZX" = "1" /* Excision of Left Popliteal Artery, Open Approach, Diagnostic */
"04BN0ZZ" = "1" /* Excision of Left Popliteal Artery, Open Approach */
"04BN3ZX" = "1" /* Excision of Left Popliteal Artery, Percutaneous Approach, Diagnostic */
"04BN3ZZ" = "1" /* Excision of Left Popliteal Artery, Percutaneous Approach */
"04BN4ZX" = "1" /* Excision of Left Popliteal Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BN4ZZ" = "1" /* Excision of Left Popliteal Artery, Percutaneous Endoscopic Approach */
"04BP0ZX" = "1" /* Excision of Right Anterior Tibial Artery, Open Approach, Diagnostic */
"04BP0ZZ" = "1" /* Excision of Right Anterior Tibial Artery, Open Approach */
"04BP3ZX" = "1" /* Excision of Right Anterior Tibial Artery, Percutaneous Approach, Diagnostic */
"04BP3ZZ" = "1" /* Excision of Right Anterior Tibial Artery, Percutaneous Approach */
"04BP4ZX" = "1" /* Excision of Right Anterior Tibial Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BP4ZZ" = "1" /* Excision of Right Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"04BQ0ZX" = "1" /* Excision of Left Anterior Tibial Artery, Open Approach, Diagnostic */
"04BQ0ZZ" = "1" /* Excision of Left Anterior Tibial Artery, Open Approach */
"04BQ3ZX" = "1" /* Excision of Left Anterior Tibial Artery, Percutaneous Approach, Diagnostic */
"04BQ3ZZ" = "1" /* Excision of Left Anterior Tibial Artery, Percutaneous Approach */
"04BQ4ZX" = "1" /* Excision of Left Anterior Tibial Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BQ4ZZ" = "1" /* Excision of Left Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"04BR0ZX" = "1" /* Excision of Right Posterior Tibial Artery, Open Approach, Diagnostic */
"04BR0ZZ" = "1" /* Excision of Right Posterior Tibial Artery, Open Approach */
"04BR3ZX" = "1" /* Excision of Right Posterior Tibial Artery, Percutaneous Approach, Diagnostic */
"04BR3ZZ" = "1" /* Excision of Right Posterior Tibial Artery, Percutaneous Approach */
"04BR4ZX" = "1" /* Excision of Right Posterior Tibial Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BR4ZZ" = "1" /* Excision of Right Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"04BS0ZX" = "1" /* Excision of Left Posterior Tibial Artery, Open Approach, Diagnostic */
"04BS0ZZ" = "1" /* Excision of Left Posterior Tibial Artery, Open Approach */
"04BS3ZX" = "1" /* Excision of Left Posterior Tibial Artery, Percutaneous Approach, Diagnostic */
"04BS3ZZ" = "1" /* Excision of Left Posterior Tibial Artery, Percutaneous Approach */
"04BS4ZX" = "1" /* Excision of Left Posterior Tibial Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BS4ZZ" = "1" /* Excision of Left Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"04BT0ZX" = "1" /* Excision of Right Peroneal Artery, Open Approach, Diagnostic */
"04BT0ZZ" = "1" /* Excision of Right Peroneal Artery, Open Approach */
"04BT3ZX" = "1" /* Excision of Right Peroneal Artery, Percutaneous Approach, Diagnostic */
"04BT3ZZ" = "1" /* Excision of Right Peroneal Artery, Percutaneous Approach */
"04BT4ZX" = "1" /* Excision of Right Peroneal Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BT4ZZ" = "1" /* Excision of Right Peroneal Artery, Percutaneous Endoscopic Approach */
"04BU0ZX" = "1" /* Excision of Left Peroneal Artery, Open Approach, Diagnostic */
"04BU0ZZ" = "1" /* Excision of Left Peroneal Artery, Open Approach */
"04BU3ZX" = "1" /* Excision of Left Peroneal Artery, Percutaneous Approach, Diagnostic */
"04BU3ZZ" = "1" /* Excision of Left Peroneal Artery, Percutaneous Approach */
"04BU4ZX" = "1" /* Excision of Left Peroneal Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BU4ZZ" = "1" /* Excision of Left Peroneal Artery, Percutaneous Endoscopic Approach */
"04BV0ZX" = "1" /* Excision of Right Foot Artery, Open Approach, Diagnostic */
"04BV0ZZ" = "1" /* Excision of Right Foot Artery, Open Approach */
"04BV3ZX" = "1" /* Excision of Right Foot Artery, Percutaneous Approach, Diagnostic */
"04BV3ZZ" = "1" /* Excision of Right Foot Artery, Percutaneous Approach */
"04BV4ZX" = "1" /* Excision of Right Foot Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BV4ZZ" = "1" /* Excision of Right Foot Artery, Percutaneous Endoscopic Approach */
"04BW0ZX" = "1" /* Excision of Left Foot Artery, Open Approach, Diagnostic */
"04BW0ZZ" = "1" /* Excision of Left Foot Artery, Open Approach */
"04BW3ZX" = "1" /* Excision of Left Foot Artery, Percutaneous Approach, Diagnostic */
"04BW3ZZ" = "1" /* Excision of Left Foot Artery, Percutaneous Approach */
"04BW4ZX" = "1" /* Excision of Left Foot Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BW4ZZ" = "1" /* Excision of Left Foot Artery, Percutaneous Endoscopic Approach */
"04BY0ZX" = "1" /* Excision of Lower Artery, Open Approach, Diagnostic */
"04BY0ZZ" = "1" /* Excision of Lower Artery, Open Approach */
"04BY3ZX" = "1" /* Excision of Lower Artery, Percutaneous Approach, Diagnostic */
"04BY3ZZ" = "1" /* Excision of Lower Artery, Percutaneous Approach */
"04BY4ZX" = "1" /* Excision of Lower Artery, Percutaneous Endoscopic Approach, Diagnostic */
"04BY4ZZ" = "1" /* Excision of Lower Artery, Percutaneous Endoscopic Approach */
"04C00Z6" = "1" /* Extirpation of Matter from Abdominal Aorta, Bifurcation, Open Approach */
"04C00ZZ" = "1" /* Extirpation of Matter from Abdominal Aorta, Open Approach */
"04C03Z6" = "1" /* Extirpation of Matter from Abdominal Aorta, Bifurcation, Percutaneous Approach */
"04C03ZZ" = "1" /* Extirpation of Matter from Abdominal Aorta, Percutaneous Approach */
"04C04Z6" = "1" /* Extirpation of Matter from Abdominal Aorta, Bifurcation, Percutaneous Endoscopic Approach */
"04C04ZZ" = "1" /* Extirpation of Matter from Abdominal Aorta, Percutaneous Endoscopic Approach */
"04C10Z6" = "1" /* Extirpation of Matter from Celiac Artery, Bifurcation, Open Approach */
"04C10ZZ" = "1" /* Extirpation of Matter from Celiac Artery, Open Approach */
"04C13Z6" = "1" /* Extirpation of Matter from Celiac Artery, Bifurcation, Percutaneous Approach */
"04C13ZZ" = "1" /* Extirpation of Matter from Celiac Artery, Percutaneous Approach */
"04C14Z6" = "1" /* Extirpation of Matter from Celiac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04C14ZZ" = "1" /* Extirpation of Matter from Celiac Artery, Percutaneous Endoscopic Approach */
"04C20Z6" = "1" /* Extirpation of Matter from Gastric Artery, Bifurcation, Open Approach */
"04C20ZZ" = "1" /* Extirpation of Matter from Gastric Artery, Open Approach */
"04C23Z6" = "1" /* Extirpation of Matter from Gastric Artery, Bifurcation, Percutaneous Approach */
"04C23ZZ" = "1" /* Extirpation of Matter from Gastric Artery, Percutaneous Approach */
"04C24Z6" = "1" /* Extirpation of Matter from Gastric Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04C24ZZ" = "1" /* Extirpation of Matter from Gastric Artery, Percutaneous Endoscopic Approach */
"04C30Z6" = "1" /* Extirpation of Matter from Hepatic Artery, Bifurcation, Open Approach */
"04C30ZZ" = "1" /* Extirpation of Matter from Hepatic Artery, Open Approach */
"04C33Z6" = "1" /* Extirpation of Matter from Hepatic Artery, Bifurcation, Percutaneous Approach */
"04C33ZZ" = "1" /* Extirpation of Matter from Hepatic Artery, Percutaneous Approach */
"04C34Z6" = "1" /* Extirpation of Matter from Hepatic Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04C34ZZ" = "1" /* Extirpation of Matter from Hepatic Artery, Percutaneous Endoscopic Approach */
"04C40Z6" = "1" /* Extirpation of Matter from Splenic Artery, Bifurcation, Open Approach */
"04C40ZZ" = "1" /* Extirpation of Matter from Splenic Artery, Open Approach */
"04C43Z6" = "1" /* Extirpation of Matter from Splenic Artery, Bifurcation, Percutaneous Approach */
"04C43ZZ" = "1" /* Extirpation of Matter from Splenic Artery, Percutaneous Approach */
"04C44Z6" = "1" /* Extirpation of Matter from Splenic Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04C44ZZ" = "1" /* Extirpation of Matter from Splenic Artery, Percutaneous Endoscopic Approach */
"04C50Z6" = "1" /* Extirpation of Matter from Superior Mesenteric Artery, Bifurcation, Open Approach */
"04C50ZZ" = "1" /* Extirpation of Matter from Superior Mesenteric Artery, Open Approach */
"04C53Z6" = "1" /* Extirpation of Matter from Superior Mesenteric Artery, Bifurcation, Percutaneous Approach */
"04C53ZZ" = "1" /* Extirpation of Matter from Superior Mesenteric Artery, Percutaneous Approach */
"04C54Z6" = "1" /* Extirpation of Matter from Superior Mesenteric Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04C54ZZ" = "1" /* Extirpation of Matter from Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04C60Z6" = "1" /* Extirpation of Matter from Right Colic Artery, Bifurcation, Open Approach */
"04C60ZZ" = "1" /* Extirpation of Matter from Right Colic Artery, Open Approach */
"04C63Z6" = "1" /* Extirpation of Matter from Right Colic Artery, Bifurcation, Percutaneous Approach */
"04C63ZZ" = "1" /* Extirpation of Matter from Right Colic Artery, Percutaneous Approach */
"04C64Z6" = "1" /* Extirpation of Matter from Right Colic Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04C64ZZ" = "1" /* Extirpation of Matter from Right Colic Artery, Percutaneous Endoscopic Approach */
"04C70Z6" = "1" /* Extirpation of Matter from Left Colic Artery, Bifurcation, Open Approach */
"04C70ZZ" = "1" /* Extirpation of Matter from Left Colic Artery, Open Approach */
"04C73Z6" = "1" /* Extirpation of Matter from Left Colic Artery, Bifurcation, Percutaneous Approach */
"04C73ZZ" = "1" /* Extirpation of Matter from Left Colic Artery, Percutaneous Approach */
"04C74Z6" = "1" /* Extirpation of Matter from Left Colic Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04C74ZZ" = "1" /* Extirpation of Matter from Left Colic Artery, Percutaneous Endoscopic Approach */
"04C80Z6" = "1" /* Extirpation of Matter from Middle Colic Artery, Bifurcation, Open Approach */
"04C80ZZ" = "1" /* Extirpation of Matter from Middle Colic Artery, Open Approach */
"04C83Z6" = "1" /* Extirpation of Matter from Middle Colic Artery, Bifurcation, Percutaneous Approach */
"04C83ZZ" = "1" /* Extirpation of Matter from Middle Colic Artery, Percutaneous Approach */
"04C84Z6" = "1" /* Extirpation of Matter from Middle Colic Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04C84ZZ" = "1" /* Extirpation of Matter from Middle Colic Artery, Percutaneous Endoscopic Approach */
"04C90Z6" = "1" /* Extirpation of Matter from Right Renal Artery, Bifurcation, Open Approach */
"04C90ZZ" = "1" /* Extirpation of Matter from Right Renal Artery, Open Approach */
"04C93Z6" = "1" /* Extirpation of Matter from Right Renal Artery, Bifurcation, Percutaneous Approach */
"04C93ZZ" = "1" /* Extirpation of Matter from Right Renal Artery, Percutaneous Approach */
"04C94Z6" = "1" /* Extirpation of Matter from Right Renal Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04C94ZZ" = "1" /* Extirpation of Matter from Right Renal Artery, Percutaneous Endoscopic Approach */
"04CA0Z6" = "1" /* Extirpation of Matter from Left Renal Artery, Bifurcation, Open Approach */
"04CA0ZZ" = "1" /* Extirpation of Matter from Left Renal Artery, Open Approach */
"04CA3Z6" = "1" /* Extirpation of Matter from Left Renal Artery, Bifurcation, Percutaneous Approach */
"04CA3ZZ" = "1" /* Extirpation of Matter from Left Renal Artery, Percutaneous Approach */
"04CA4Z6" = "1" /* Extirpation of Matter from Left Renal Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CA4ZZ" = "1" /* Extirpation of Matter from Left Renal Artery, Percutaneous Endoscopic Approach */
"04CB0Z6" = "1" /* Extirpation of Matter from Inferior Mesenteric Artery, Bifurcation, Open Approach */
"04CB0ZZ" = "1" /* Extirpation of Matter from Inferior Mesenteric Artery, Open Approach */
"04CB3Z6" = "1" /* Extirpation of Matter from Inferior Mesenteric Artery, Bifurcation, Percutaneous Approach */
"04CB3ZZ" = "1" /* Extirpation of Matter from Inferior Mesenteric Artery, Percutaneous Approach */
"04CB4Z6" = "1" /* Extirpation of Matter from Inferior Mesenteric Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CB4ZZ" = "1" /* Extirpation of Matter from Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04CC0Z6" = "1" /* Extirpation of Matter from Right Common Iliac Artery, Bifurcation, Open Approach */
"04CC0ZZ" = "1" /* Extirpation of Matter from Right Common Iliac Artery, Open Approach */
"04CC3Z6" = "1" /* Extirpation of Matter from Right Common Iliac Artery, Bifurcation, Percutaneous Approach */
"04CC3ZZ" = "1" /* Extirpation of Matter from Right Common Iliac Artery, Percutaneous Approach */
"04CC4Z6" = "1" /* Extirpation of Matter from Right Common Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CC4ZZ" = "1" /* Extirpation of Matter from Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"04CD0Z6" = "1" /* Extirpation of Matter from Left Common Iliac Artery, Bifurcation, Open Approach */
"04CD0ZZ" = "1" /* Extirpation of Matter from Left Common Iliac Artery, Open Approach */
"04CD3Z6" = "1" /* Extirpation of Matter from Left Common Iliac Artery, Bifurcation, Percutaneous Approach */
"04CD3ZZ" = "1" /* Extirpation of Matter from Left Common Iliac Artery, Percutaneous Approach */
"04CD4Z6" = "1" /* Extirpation of Matter from Left Common Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CD4ZZ" = "1" /* Extirpation of Matter from Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"04CE0Z6" = "1" /* Extirpation of Matter from Right Internal Iliac Artery, Bifurcation, Open Approach */
"04CE0ZZ" = "1" /* Extirpation of Matter from Right Internal Iliac Artery, Open Approach */
"04CE3Z6" = "1" /* Extirpation of Matter from Right Internal Iliac Artery, Bifurcation, Percutaneous Approach */
"04CE3ZZ" = "1" /* Extirpation of Matter from Right Internal Iliac Artery, Percutaneous Approach */
"04CE4Z6" = "1" /* Extirpation of Matter from Right Internal Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CE4ZZ" = "1" /* Extirpation of Matter from Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04CF0Z6" = "1" /* Extirpation of Matter from Left Internal Iliac Artery, Bifurcation, Open Approach */
"04CF0ZZ" = "1" /* Extirpation of Matter from Left Internal Iliac Artery, Open Approach */
"04CF3Z6" = "1" /* Extirpation of Matter from Left Internal Iliac Artery, Bifurcation, Percutaneous Approach */
"04CF3ZZ" = "1" /* Extirpation of Matter from Left Internal Iliac Artery, Percutaneous Approach */
"04CF4Z6" = "1" /* Extirpation of Matter from Left Internal Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CF4ZZ" = "1" /* Extirpation of Matter from Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04CH0Z6" = "1" /* Extirpation of Matter from Right External Iliac Artery, Bifurcation, Open Approach */
"04CH0ZZ" = "1" /* Extirpation of Matter from Right External Iliac Artery, Open Approach */
"04CH3Z6" = "1" /* Extirpation of Matter from Right External Iliac Artery, Bifurcation, Percutaneous Approach */
"04CH3ZZ" = "1" /* Extirpation of Matter from Right External Iliac Artery, Percutaneous Approach */
"04CH4Z6" = "1" /* Extirpation of Matter from Right External Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CH4ZZ" = "1" /* Extirpation of Matter from Right External Iliac Artery, Percutaneous Endoscopic Approach */
"04CJ0Z6" = "1" /* Extirpation of Matter from Left External Iliac Artery, Bifurcation, Open Approach */
"04CJ0ZZ" = "1" /* Extirpation of Matter from Left External Iliac Artery, Open Approach */
"04CJ3Z6" = "1" /* Extirpation of Matter from Left External Iliac Artery, Bifurcation, Percutaneous Approach */
"04CJ3ZZ" = "1" /* Extirpation of Matter from Left External Iliac Artery, Percutaneous Approach */
"04CJ4Z6" = "1" /* Extirpation of Matter from Left External Iliac Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CJ4ZZ" = "1" /* Extirpation of Matter from Left External Iliac Artery, Percutaneous Endoscopic Approach */
"04CK0Z6" = "1" /* Extirpation of Matter from Right Femoral Artery, Bifurcation, Open Approach */
"04CK0ZZ" = "1" /* Extirpation of Matter from Right Femoral Artery, Open Approach */
"04CK3Z6" = "1" /* Extirpation of Matter from Right Femoral Artery, Bifurcation, Percutaneous Approach */
"04CK3ZZ" = "1" /* Extirpation of Matter from Right Femoral Artery, Percutaneous Approach */
"04CK4Z6" = "1" /* Extirpation of Matter from Right Femoral Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CK4ZZ" = "1" /* Extirpation of Matter from Right Femoral Artery, Percutaneous Endoscopic Approach */
"04CL0Z6" = "1" /* Extirpation of Matter from Left Femoral Artery, Bifurcation, Open Approach */
"04CL0ZZ" = "1" /* Extirpation of Matter from Left Femoral Artery, Open Approach */
"04CL3Z6" = "1" /* Extirpation of Matter from Left Femoral Artery, Bifurcation, Percutaneous Approach */
"04CL3ZZ" = "1" /* Extirpation of Matter from Left Femoral Artery, Percutaneous Approach */
"04CL4Z6" = "1" /* Extirpation of Matter from Left Femoral Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CL4ZZ" = "1" /* Extirpation of Matter from Left Femoral Artery, Percutaneous Endoscopic Approach */
"04CM0Z6" = "1" /* Extirpation of Matter from Right Popliteal Artery, Bifurcation, Open Approach */
"04CM0ZZ" = "1" /* Extirpation of Matter from Right Popliteal Artery, Open Approach */
"04CM3Z6" = "1" /* Extirpation of Matter from Right Popliteal Artery, Bifurcation, Percutaneous Approach */
"04CM3ZZ" = "1" /* Extirpation of Matter from Right Popliteal Artery, Percutaneous Approach */
"04CM4Z6" = "1" /* Extirpation of Matter from Right Popliteal Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CM4ZZ" = "1" /* Extirpation of Matter from Right Popliteal Artery, Percutaneous Endoscopic Approach */
"04CN0Z6" = "1" /* Extirpation of Matter from Left Popliteal Artery, Bifurcation, Open Approach */
"04CN0ZZ" = "1" /* Extirpation of Matter from Left Popliteal Artery, Open Approach */
"04CN3Z6" = "1" /* Extirpation of Matter from Left Popliteal Artery, Bifurcation, Percutaneous Approach */
"04CN3ZZ" = "1" /* Extirpation of Matter from Left Popliteal Artery, Percutaneous Approach */
"04CN4Z6" = "1" /* Extirpation of Matter from Left Popliteal Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CN4ZZ" = "1" /* Extirpation of Matter from Left Popliteal Artery, Percutaneous Endoscopic Approach */
"04CP0Z6" = "1" /* Extirpation of Matter from Right Anterior Tibial Artery, Bifurcation, Open Approach */
"04CP0ZZ" = "1" /* Extirpation of Matter from Right Anterior Tibial Artery, Open Approach */
"04CP3Z6" = "1" /* Extirpation of Matter from Right Anterior Tibial Artery, Bifurcation, Percutaneous Approach */
"04CP3ZZ" = "1" /* Extirpation of Matter from Right Anterior Tibial Artery, Percutaneous Approach */
"04CP4Z6" = "1" /* Extirpation of Matter from Right Anterior Tibial Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CP4ZZ" = "1" /* Extirpation of Matter from Right Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"04CQ0Z6" = "1" /* Extirpation of Matter from Left Anterior Tibial Artery, Bifurcation, Open Approach */
"04CQ0ZZ" = "1" /* Extirpation of Matter from Left Anterior Tibial Artery, Open Approach */
"04CQ3Z6" = "1" /* Extirpation of Matter from Left Anterior Tibial Artery, Bifurcation, Percutaneous Approach */
"04CQ3ZZ" = "1" /* Extirpation of Matter from Left Anterior Tibial Artery, Percutaneous Approach */
"04CQ4Z6" = "1" /* Extirpation of Matter from Left Anterior Tibial Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CQ4ZZ" = "1" /* Extirpation of Matter from Left Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"04CR0Z6" = "1" /* Extirpation of Matter from Right Posterior Tibial Artery, Bifurcation, Open Approach */
"04CR0ZZ" = "1" /* Extirpation of Matter from Right Posterior Tibial Artery, Open Approach */
"04CR3Z6" = "1" /* Extirpation of Matter from Right Posterior Tibial Artery, Bifurcation, Percutaneous Approach */
"04CR3ZZ" = "1" /* Extirpation of Matter from Right Posterior Tibial Artery, Percutaneous Approach */
"04CR4Z6" = "1" /* Extirpation of Matter from Right Posterior Tibial Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CR4ZZ" = "1" /* Extirpation of Matter from Right Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"04CS0Z6" = "1" /* Extirpation of Matter from Left Posterior Tibial Artery, Bifurcation, Open Approach */
"04CS0ZZ" = "1" /* Extirpation of Matter from Left Posterior Tibial Artery, Open Approach */
"04CS3Z6" = "1" /* Extirpation of Matter from Left Posterior Tibial Artery, Bifurcation, Percutaneous Approach */
"04CS3ZZ" = "1" /* Extirpation of Matter from Left Posterior Tibial Artery, Percutaneous Approach */
"04CS4Z6" = "1" /* Extirpation of Matter from Left Posterior Tibial Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CS4ZZ" = "1" /* Extirpation of Matter from Left Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"04CT0Z6" = "1" /* Extirpation of Matter from Right Peroneal Artery, Bifurcation, Open Approach */
"04CT0ZZ" = "1" /* Extirpation of Matter from Right Peroneal Artery, Open Approach */
"04CT3Z6" = "1" /* Extirpation of Matter from Right Peroneal Artery, Bifurcation, Percutaneous Approach */
"04CT3ZZ" = "1" /* Extirpation of Matter from Right Peroneal Artery, Percutaneous Approach */
"04CT4Z6" = "1" /* Extirpation of Matter from Right Peroneal Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CT4ZZ" = "1" /* Extirpation of Matter from Right Peroneal Artery, Percutaneous Endoscopic Approach */
"04CU0Z6" = "1" /* Extirpation of Matter from Left Peroneal Artery, Bifurcation, Open Approach */
"04CU0ZZ" = "1" /* Extirpation of Matter from Left Peroneal Artery, Open Approach */
"04CU3Z6" = "1" /* Extirpation of Matter from Left Peroneal Artery, Bifurcation, Percutaneous Approach */
"04CU3ZZ" = "1" /* Extirpation of Matter from Left Peroneal Artery, Percutaneous Approach */
"04CU4Z6" = "1" /* Extirpation of Matter from Left Peroneal Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CU4ZZ" = "1" /* Extirpation of Matter from Left Peroneal Artery, Percutaneous Endoscopic Approach */
"04CV0Z6" = "1" /* Extirpation of Matter from Right Foot Artery, Bifurcation, Open Approach */
"04CV0ZZ" = "1" /* Extirpation of Matter from Right Foot Artery, Open Approach */
"04CV3Z6" = "1" /* Extirpation of Matter from Right Foot Artery, Bifurcation, Percutaneous Approach */
"04CV3ZZ" = "1" /* Extirpation of Matter from Right Foot Artery, Percutaneous Approach */
"04CV4Z6" = "1" /* Extirpation of Matter from Right Foot Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CV4ZZ" = "1" /* Extirpation of Matter from Right Foot Artery, Percutaneous Endoscopic Approach */
"04CW0Z6" = "1" /* Extirpation of Matter from Left Foot Artery, Bifurcation, Open Approach */
"04CW0ZZ" = "1" /* Extirpation of Matter from Left Foot Artery, Open Approach */
"04CW3Z6" = "1" /* Extirpation of Matter from Left Foot Artery, Bifurcation, Percutaneous Approach */
"04CW3ZZ" = "1" /* Extirpation of Matter from Left Foot Artery, Percutaneous Approach */
"04CW4Z6" = "1" /* Extirpation of Matter from Left Foot Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CW4ZZ" = "1" /* Extirpation of Matter from Left Foot Artery, Percutaneous Endoscopic Approach */
"04CY0Z6" = "1" /* Extirpation of Matter from Lower Artery, Bifurcation, Open Approach */
"04CY0ZZ" = "1" /* Extirpation of Matter from Lower Artery, Open Approach */
"04CY3Z6" = "1" /* Extirpation of Matter from Lower Artery, Bifurcation, Percutaneous Approach */
"04CY3ZZ" = "1" /* Extirpation of Matter from Lower Artery, Percutaneous Approach */
"04CY4Z6" = "1" /* Extirpation of Matter from Lower Artery, Bifurcation, Percutaneous Endoscopic Approach */
"04CY4ZZ" = "1" /* Extirpation of Matter from Lower Artery, Percutaneous Endoscopic Approach */
"04H00DZ" = "1" /* Insertion of Intraluminal Device into Abdominal Aorta, Open Approach */
"04H03DZ" = "1" /* Insertion of Intraluminal Device into Abdominal Aorta, Percutaneous Approach */
"04H04DZ" = "1" /* Insertion of Intraluminal Device into Abdominal Aorta, Percutaneous Endoscopic Approach */
"04H10DZ" = "1" /* Insertion of Intraluminal Device into Celiac Artery, Open Approach */
"04H13DZ" = "1" /* Insertion of Intraluminal Device into Celiac Artery, Percutaneous Approach */
"04H14DZ" = "1" /* Insertion of Intraluminal Device into Celiac Artery, Percutaneous Endoscopic Approach */
"04H20DZ" = "1" /* Insertion of Intraluminal Device into Gastric Artery, Open Approach */
"04H23DZ" = "1" /* Insertion of Intraluminal Device into Gastric Artery, Percutaneous Approach */
"04H24DZ" = "1" /* Insertion of Intraluminal Device into Gastric Artery, Percutaneous Endoscopic Approach */
"04H30DZ" = "1" /* Insertion of Intraluminal Device into Hepatic Artery, Open Approach */
"04H33DZ" = "1" /* Insertion of Intraluminal Device into Hepatic Artery, Percutaneous Approach */
"04H34DZ" = "1" /* Insertion of Intraluminal Device into Hepatic Artery, Percutaneous Endoscopic Approach */
"04H40DZ" = "1" /* Insertion of Intraluminal Device into Splenic Artery, Open Approach */
"04H43DZ" = "1" /* Insertion of Intraluminal Device into Splenic Artery, Percutaneous Approach */
"04H44DZ" = "1" /* Insertion of Intraluminal Device into Splenic Artery, Percutaneous Endoscopic Approach */
"04H50DZ" = "1" /* Insertion of Intraluminal Device into Superior Mesenteric Artery, Open Approach */
"04H53DZ" = "1" /* Insertion of Intraluminal Device into Superior Mesenteric Artery, Percutaneous Approach */
"04H54DZ" = "1" /* Insertion of Intraluminal Device into Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04H60DZ" = "1" /* Insertion of Intraluminal Device into Right Colic Artery, Open Approach */
"04H63DZ" = "1" /* Insertion of Intraluminal Device into Right Colic Artery, Percutaneous Approach */
"04H64DZ" = "1" /* Insertion of Intraluminal Device into Right Colic Artery, Percutaneous Endoscopic Approach */
"04H70DZ" = "1" /* Insertion of Intraluminal Device into Left Colic Artery, Open Approach */
"04H73DZ" = "1" /* Insertion of Intraluminal Device into Left Colic Artery, Percutaneous Approach */
"04H74DZ" = "1" /* Insertion of Intraluminal Device into Left Colic Artery, Percutaneous Endoscopic Approach */
"04H80DZ" = "1" /* Insertion of Intraluminal Device into Middle Colic Artery, Open Approach */
"04H83DZ" = "1" /* Insertion of Intraluminal Device into Middle Colic Artery, Percutaneous Approach */
"04H84DZ" = "1" /* Insertion of Intraluminal Device into Middle Colic Artery, Percutaneous Endoscopic Approach */
"04H90DZ" = "1" /* Insertion of Intraluminal Device into Right Renal Artery, Open Approach */
"04H93DZ" = "1" /* Insertion of Intraluminal Device into Right Renal Artery, Percutaneous Approach */
"04H94DZ" = "1" /* Insertion of Intraluminal Device into Right Renal Artery, Percutaneous Endoscopic Approach */
"04HA0DZ" = "1" /* Insertion of Intraluminal Device into Left Renal Artery, Open Approach */
"04HA3DZ" = "1" /* Insertion of Intraluminal Device into Left Renal Artery, Percutaneous Approach */
"04HA4DZ" = "1" /* Insertion of Intraluminal Device into Left Renal Artery, Percutaneous Endoscopic Approach */
"04HB0DZ" = "1" /* Insertion of Intraluminal Device into Inferior Mesenteric Artery, Open Approach */
"04HB3DZ" = "1" /* Insertion of Intraluminal Device into Inferior Mesenteric Artery, Percutaneous Approach */
"04HB4DZ" = "1" /* Insertion of Intraluminal Device into Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04HC0DZ" = "1" /* Insertion of Intraluminal Device into Right Common Iliac Artery, Open Approach */
"04HC3DZ" = "1" /* Insertion of Intraluminal Device into Right Common Iliac Artery, Percutaneous Approach */
"04HC4DZ" = "1" /* Insertion of Intraluminal Device into Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"04HD0DZ" = "1" /* Insertion of Intraluminal Device into Left Common Iliac Artery, Open Approach */
"04HD3DZ" = "1" /* Insertion of Intraluminal Device into Left Common Iliac Artery, Percutaneous Approach */
"04HD4DZ" = "1" /* Insertion of Intraluminal Device into Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"04HE0DZ" = "1" /* Insertion of Intraluminal Device into Right Internal Iliac Artery, Open Approach */
"04HE3DZ" = "1" /* Insertion of Intraluminal Device into Right Internal Iliac Artery, Percutaneous Approach */
"04HE4DZ" = "1" /* Insertion of Intraluminal Device into Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04HF0DZ" = "1" /* Insertion of Intraluminal Device into Left Internal Iliac Artery, Open Approach */
"04HF3DZ" = "1" /* Insertion of Intraluminal Device into Left Internal Iliac Artery, Percutaneous Approach */
"04HF4DZ" = "1" /* Insertion of Intraluminal Device into Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04HH0DZ" = "1" /* Insertion of Intraluminal Device into Right External Iliac Artery, Open Approach */
"04HH3DZ" = "1" /* Insertion of Intraluminal Device into Right External Iliac Artery, Percutaneous Approach */
"04HH4DZ" = "1" /* Insertion of Intraluminal Device into Right External Iliac Artery, Percutaneous Endoscopic Approach */
"04HJ0DZ" = "1" /* Insertion of Intraluminal Device into Left External Iliac Artery, Open Approach */
"04HJ3DZ" = "1" /* Insertion of Intraluminal Device into Left External Iliac Artery, Percutaneous Approach */
"04HJ4DZ" = "1" /* Insertion of Intraluminal Device into Left External Iliac Artery, Percutaneous Endoscopic Approach */
"04HK0DZ" = "1" /* Insertion of Intraluminal Device into Right Femoral Artery, Open Approach */
"04HK3DZ" = "1" /* Insertion of Intraluminal Device into Right Femoral Artery, Percutaneous Approach */
"04HK4DZ" = "1" /* Insertion of Intraluminal Device into Right Femoral Artery, Percutaneous Endoscopic Approach */
"04HL0DZ" = "1" /* Insertion of Intraluminal Device into Left Femoral Artery, Open Approach */
"04HL3DZ" = "1" /* Insertion of Intraluminal Device into Left Femoral Artery, Percutaneous Approach */
"04HL4DZ" = "1" /* Insertion of Intraluminal Device into Left Femoral Artery, Percutaneous Endoscopic Approach */
"04HM0DZ" = "1" /* Insertion of Intraluminal Device into Right Popliteal Artery, Open Approach */
"04HM3DZ" = "1" /* Insertion of Intraluminal Device into Right Popliteal Artery, Percutaneous Approach */
"04HM4DZ" = "1" /* Insertion of Intraluminal Device into Right Popliteal Artery, Percutaneous Endoscopic Approach */
"04HN0DZ" = "1" /* Insertion of Intraluminal Device into Left Popliteal Artery, Open Approach */
"04HN3DZ" = "1" /* Insertion of Intraluminal Device into Left Popliteal Artery, Percutaneous Approach */
"04HN4DZ" = "1" /* Insertion of Intraluminal Device into Left Popliteal Artery, Percutaneous Endoscopic Approach */
"04HP0DZ" = "1" /* Insertion of Intraluminal Device into Right Anterior Tibial Artery, Open Approach */
"04HP3DZ" = "1" /* Insertion of Intraluminal Device into Right Anterior Tibial Artery, Percutaneous Approach */
"04HP4DZ" = "1" /* Insertion of Intraluminal Device into Right Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"04HQ0DZ" = "1" /* Insertion of Intraluminal Device into Left Anterior Tibial Artery, Open Approach */
"04HQ3DZ" = "1" /* Insertion of Intraluminal Device into Left Anterior Tibial Artery, Percutaneous Approach */
"04HQ4DZ" = "1" /* Insertion of Intraluminal Device into Left Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"04HR0DZ" = "1" /* Insertion of Intraluminal Device into Right Posterior Tibial Artery, Open Approach */
"04HR3DZ" = "1" /* Insertion of Intraluminal Device into Right Posterior Tibial Artery, Percutaneous Approach */
"04HR4DZ" = "1" /* Insertion of Intraluminal Device into Right Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"04HS0DZ" = "1" /* Insertion of Intraluminal Device into Left Posterior Tibial Artery, Open Approach */
"04HS3DZ" = "1" /* Insertion of Intraluminal Device into Left Posterior Tibial Artery, Percutaneous Approach */
"04HS4DZ" = "1" /* Insertion of Intraluminal Device into Left Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"04HT0DZ" = "1" /* Insertion of Intraluminal Device into Right Peroneal Artery, Open Approach */
"04HT3DZ" = "1" /* Insertion of Intraluminal Device into Right Peroneal Artery, Percutaneous Approach */
"04HT4DZ" = "1" /* Insertion of Intraluminal Device into Right Peroneal Artery, Percutaneous Endoscopic Approach */
"04HU0DZ" = "1" /* Insertion of Intraluminal Device into Left Peroneal Artery, Open Approach */
"04HU3DZ" = "1" /* Insertion of Intraluminal Device into Left Peroneal Artery, Percutaneous Approach */
"04HU4DZ" = "1" /* Insertion of Intraluminal Device into Left Peroneal Artery, Percutaneous Endoscopic Approach */
"04HV0DZ" = "1" /* Insertion of Intraluminal Device into Right Foot Artery, Open Approach */
"04HV3DZ" = "1" /* Insertion of Intraluminal Device into Right Foot Artery, Percutaneous Approach */
"04HV4DZ" = "1" /* Insertion of Intraluminal Device into Right Foot Artery, Percutaneous Endoscopic Approach */
"04HW0DZ" = "1" /* Insertion of Intraluminal Device into Left Foot Artery, Open Approach */
"04HW3DZ" = "1" /* Insertion of Intraluminal Device into Left Foot Artery, Percutaneous Approach */
"04HW4DZ" = "1" /* Insertion of Intraluminal Device into Left Foot Artery, Percutaneous Endoscopic Approach */
"04HY02Z" = "1" /* Insertion of Monitoring Device into Lower Artery, Open Approach */
"04HY0DZ" = "1" /* Insertion of Intraluminal Device into Lower Artery, Open Approach */
"04HY3DZ" = "1" /* Insertion of Intraluminal Device into Lower Artery, Percutaneous Approach */
"04HY42Z" = "1" /* Insertion of Monitoring Device into Lower Artery, Percutaneous Endoscopic Approach */
"04HY4DZ" = "1" /* Insertion of Intraluminal Device into Lower Artery, Percutaneous Endoscopic Approach */
"04JY0ZZ" = "1" /* Inspection of Lower Artery, Open Approach */
"04L00CZ" = "1" /* Occlusion of Abdominal Aorta with Extraluminal Device, Open Approach */
"04L00DZ" = "1" /* Occlusion of Abdominal Aorta with Intraluminal Device, Open Approach */
"04L00ZZ" = "1" /* Occlusion of Abdominal Aorta, Open Approach */
"04L03CZ" = "1" /* Occlusion of Abdominal Aorta with Extraluminal Device, Percutaneous Approach */
"04L03DZ" = "1" /* Occlusion of Abdominal Aorta with Intraluminal Device, Percutaneous Approach */
"04L03ZZ" = "1" /* Occlusion of Abdominal Aorta, Percutaneous Approach */
"04L04CZ" = "1" /* Occlusion of Abdominal Aorta with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L04DZ" = "1" /* Occlusion of Abdominal Aorta with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L04ZZ" = "1" /* Occlusion of Abdominal Aorta, Percutaneous Endoscopic Approach */
"04L10CZ" = "1" /* Occlusion of Celiac Artery with Extraluminal Device, Open Approach */
"04L10DZ" = "1" /* Occlusion of Celiac Artery with Intraluminal Device, Open Approach */
"04L10ZZ" = "1" /* Occlusion of Celiac Artery, Open Approach */
"04L13CZ" = "1" /* Occlusion of Celiac Artery with Extraluminal Device, Percutaneous Approach */
"04L13DZ" = "1" /* Occlusion of Celiac Artery with Intraluminal Device, Percutaneous Approach */
"04L13ZZ" = "1" /* Occlusion of Celiac Artery, Percutaneous Approach */
"04L14CZ" = "1" /* Occlusion of Celiac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L14DZ" = "1" /* Occlusion of Celiac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L14ZZ" = "1" /* Occlusion of Celiac Artery, Percutaneous Endoscopic Approach */
"04L20CZ" = "1" /* Occlusion of Gastric Artery with Extraluminal Device, Open Approach */
"04L20DZ" = "1" /* Occlusion of Gastric Artery with Intraluminal Device, Open Approach */
"04L20ZZ" = "1" /* Occlusion of Gastric Artery, Open Approach */
"04L23CZ" = "1" /* Occlusion of Gastric Artery with Extraluminal Device, Percutaneous Approach */
"04L23ZZ" = "1" /* Occlusion of Gastric Artery, Percutaneous Approach */
"04L24CZ" = "1" /* Occlusion of Gastric Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L24DZ" = "1" /* Occlusion of Gastric Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L24ZZ" = "1" /* Occlusion of Gastric Artery, Percutaneous Endoscopic Approach */
"04L30CZ" = "1" /* Occlusion of Hepatic Artery with Extraluminal Device, Open Approach */
"04L30DZ" = "1" /* Occlusion of Hepatic Artery with Intraluminal Device, Open Approach */
"04L30ZZ" = "1" /* Occlusion of Hepatic Artery, Open Approach */
"04L33CZ" = "1" /* Occlusion of Hepatic Artery with Extraluminal Device, Percutaneous Approach */
"04L33DZ" = "1" /* Occlusion of Hepatic Artery with Intraluminal Device, Percutaneous Approach */
"04L33ZZ" = "1" /* Occlusion of Hepatic Artery, Percutaneous Approach */
"04L34CZ" = "1" /* Occlusion of Hepatic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L34DZ" = "1" /* Occlusion of Hepatic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L34ZZ" = "1" /* Occlusion of Hepatic Artery, Percutaneous Endoscopic Approach */
"04L40CZ" = "1" /* Occlusion of Splenic Artery with Extraluminal Device, Open Approach */
"04L40DZ" = "1" /* Occlusion of Splenic Artery with Intraluminal Device, Open Approach */
"04L40ZZ" = "1" /* Occlusion of Splenic Artery, Open Approach */
"04L43CZ" = "1" /* Occlusion of Splenic Artery with Extraluminal Device, Percutaneous Approach */
"04L43DZ" = "1" /* Occlusion of Splenic Artery with Intraluminal Device, Percutaneous Approach */
"04L43ZZ" = "1" /* Occlusion of Splenic Artery, Percutaneous Approach */
"04L44CZ" = "1" /* Occlusion of Splenic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L44DZ" = "1" /* Occlusion of Splenic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L44ZZ" = "1" /* Occlusion of Splenic Artery, Percutaneous Endoscopic Approach */
"04L50CZ" = "1" /* Occlusion of Superior Mesenteric Artery with Extraluminal Device, Open Approach */
"04L50DZ" = "1" /* Occlusion of Superior Mesenteric Artery with Intraluminal Device, Open Approach */
"04L50ZZ" = "1" /* Occlusion of Superior Mesenteric Artery, Open Approach */
"04L53CZ" = "1" /* Occlusion of Superior Mesenteric Artery with Extraluminal Device, Percutaneous Approach */
"04L53DZ" = "1" /* Occlusion of Superior Mesenteric Artery with Intraluminal Device, Percutaneous Approach */
"04L53ZZ" = "1" /* Occlusion of Superior Mesenteric Artery, Percutaneous Approach */
"04L54CZ" = "1" /* Occlusion of Superior Mesenteric Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L54DZ" = "1" /* Occlusion of Superior Mesenteric Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L54ZZ" = "1" /* Occlusion of Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04L60CZ" = "1" /* Occlusion of Right Colic Artery with Extraluminal Device, Open Approach */
"04L60DZ" = "1" /* Occlusion of Right Colic Artery with Intraluminal Device, Open Approach */
"04L60ZZ" = "1" /* Occlusion of Right Colic Artery, Open Approach */
"04L63CZ" = "1" /* Occlusion of Right Colic Artery with Extraluminal Device, Percutaneous Approach */
"04L63DZ" = "1" /* Occlusion of Right Colic Artery with Intraluminal Device, Percutaneous Approach */
"04L63ZZ" = "1" /* Occlusion of Right Colic Artery, Percutaneous Approach */
"04L64CZ" = "1" /* Occlusion of Right Colic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L64DZ" = "1" /* Occlusion of Right Colic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L64ZZ" = "1" /* Occlusion of Right Colic Artery, Percutaneous Endoscopic Approach */
"04L70CZ" = "1" /* Occlusion of Left Colic Artery with Extraluminal Device, Open Approach */
"04L70DZ" = "1" /* Occlusion of Left Colic Artery with Intraluminal Device, Open Approach */
"04L70ZZ" = "1" /* Occlusion of Left Colic Artery, Open Approach */
"04L73CZ" = "1" /* Occlusion of Left Colic Artery with Extraluminal Device, Percutaneous Approach */
"04L73DZ" = "1" /* Occlusion of Left Colic Artery with Intraluminal Device, Percutaneous Approach */
"04L73ZZ" = "1" /* Occlusion of Left Colic Artery, Percutaneous Approach */
"04L74CZ" = "1" /* Occlusion of Left Colic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L74DZ" = "1" /* Occlusion of Left Colic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L74ZZ" = "1" /* Occlusion of Left Colic Artery, Percutaneous Endoscopic Approach */
"04L80CZ" = "1" /* Occlusion of Middle Colic Artery with Extraluminal Device, Open Approach */
"04L80DZ" = "1" /* Occlusion of Middle Colic Artery with Intraluminal Device, Open Approach */
"04L80ZZ" = "1" /* Occlusion of Middle Colic Artery, Open Approach */
"04L83CZ" = "1" /* Occlusion of Middle Colic Artery with Extraluminal Device, Percutaneous Approach */
"04L83DZ" = "1" /* Occlusion of Middle Colic Artery with Intraluminal Device, Percutaneous Approach */
"04L83ZZ" = "1" /* Occlusion of Middle Colic Artery, Percutaneous Approach */
"04L84CZ" = "1" /* Occlusion of Middle Colic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L84DZ" = "1" /* Occlusion of Middle Colic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L84ZZ" = "1" /* Occlusion of Middle Colic Artery, Percutaneous Endoscopic Approach */
"04L90CZ" = "1" /* Occlusion of Right Renal Artery with Extraluminal Device, Open Approach */
"04L90DZ" = "1" /* Occlusion of Right Renal Artery with Intraluminal Device, Open Approach */
"04L90ZZ" = "1" /* Occlusion of Right Renal Artery, Open Approach */
"04L93CZ" = "1" /* Occlusion of Right Renal Artery with Extraluminal Device, Percutaneous Approach */
"04L93DZ" = "1" /* Occlusion of Right Renal Artery with Intraluminal Device, Percutaneous Approach */
"04L93ZZ" = "1" /* Occlusion of Right Renal Artery, Percutaneous Approach */
"04L94CZ" = "1" /* Occlusion of Right Renal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04L94DZ" = "1" /* Occlusion of Right Renal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L94ZZ" = "1" /* Occlusion of Right Renal Artery, Percutaneous Endoscopic Approach */
"04LA0CZ" = "1" /* Occlusion of Left Renal Artery with Extraluminal Device, Open Approach */
"04LA0DZ" = "1" /* Occlusion of Left Renal Artery with Intraluminal Device, Open Approach */
"04LA0ZZ" = "1" /* Occlusion of Left Renal Artery, Open Approach */
"04LA3CZ" = "1" /* Occlusion of Left Renal Artery with Extraluminal Device, Percutaneous Approach */
"04LA3DZ" = "1" /* Occlusion of Left Renal Artery with Intraluminal Device, Percutaneous Approach */
"04LA3ZZ" = "1" /* Occlusion of Left Renal Artery, Percutaneous Approach */
"04LA4CZ" = "1" /* Occlusion of Left Renal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LA4DZ" = "1" /* Occlusion of Left Renal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LA4ZZ" = "1" /* Occlusion of Left Renal Artery, Percutaneous Endoscopic Approach */
"04LB0CZ" = "1" /* Occlusion of Inferior Mesenteric Artery with Extraluminal Device, Open Approach */
"04LB0DZ" = "1" /* Occlusion of Inferior Mesenteric Artery with Intraluminal Device, Open Approach */
"04LB0ZZ" = "1" /* Occlusion of Inferior Mesenteric Artery, Open Approach */
"04LB3CZ" = "1" /* Occlusion of Inferior Mesenteric Artery with Extraluminal Device, Percutaneous Approach */
"04LB3DZ" = "1" /* Occlusion of Inferior Mesenteric Artery with Intraluminal Device, Percutaneous Approach */
"04LB3ZZ" = "1" /* Occlusion of Inferior Mesenteric Artery, Percutaneous Approach */
"04LB4CZ" = "1" /* Occlusion of Inferior Mesenteric Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LB4DZ" = "1" /* Occlusion of Inferior Mesenteric Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LB4ZZ" = "1" /* Occlusion of Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04LC0CZ" = "1" /* Occlusion of Right Common Iliac Artery with Extraluminal Device, Open Approach */
"04LC0DZ" = "1" /* Occlusion of Right Common Iliac Artery with Intraluminal Device, Open Approach */
"04LC0ZZ" = "1" /* Occlusion of Right Common Iliac Artery, Open Approach */
"04LC3CZ" = "1" /* Occlusion of Right Common Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04LC3DZ" = "1" /* Occlusion of Right Common Iliac Artery with Intraluminal Device, Percutaneous Approach */
"04LC3ZZ" = "1" /* Occlusion of Right Common Iliac Artery, Percutaneous Approach */
"04LC4CZ" = "1" /* Occlusion of Right Common Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LC4DZ" = "1" /* Occlusion of Right Common Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LC4ZZ" = "1" /* Occlusion of Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"04LD0CZ" = "1" /* Occlusion of Left Common Iliac Artery with Extraluminal Device, Open Approach */
"04LD0DZ" = "1" /* Occlusion of Left Common Iliac Artery with Intraluminal Device, Open Approach */
"04LD0ZZ" = "1" /* Occlusion of Left Common Iliac Artery, Open Approach */
"04LD3CZ" = "1" /* Occlusion of Left Common Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04LD3DZ" = "1" /* Occlusion of Left Common Iliac Artery with Intraluminal Device, Percutaneous Approach */
"04LD3ZZ" = "1" /* Occlusion of Left Common Iliac Artery, Percutaneous Approach */
"04LD4CZ" = "1" /* Occlusion of Left Common Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LD4DZ" = "1" /* Occlusion of Left Common Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LD4ZZ" = "1" /* Occlusion of Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"04LE0CT" = "1" /* Occlusion of Right Uterine Artery with Extraluminal Device, Open Approach */
"04LE0CZ" = "1" /* Occlusion of Right Internal Iliac Artery with Extraluminal Device, Open Approach */
"04LE0DT" = "1" /* Occlusion of Right Uterine Artery with Intraluminal Device, Open Approach */
"04LE0DZ" = "1" /* Occlusion of Right Internal Iliac Artery with Intraluminal Device, Open Approach */
"04LE0ZT" = "1" /* Occlusion of Right Uterine Artery, Open Approach */
"04LE0ZZ" = "1" /* Occlusion of Right Internal Iliac Artery, Open Approach */
"04LE3CT" = "1" /* Occlusion of Right Uterine Artery with Extraluminal Device, Percutaneous Approach */
"04LE3CZ" = "1" /* Occlusion of Right Internal Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04LE3DT" = "1" /* Occlusion of Right Uterine Artery with Intraluminal Device, Percutaneous Approach */
"04LE3DZ" = "1" /* Occlusion of Right Internal Iliac Artery with Intraluminal Device, Percutaneous Approach */
"04LE3ZT" = "1" /* Occlusion of Right Uterine Artery, Percutaneous Approach */
"04LE3ZZ" = "1" /* Occlusion of Right Internal Iliac Artery, Percutaneous Approach */
"04LE4CT" = "1" /* Occlusion of Right Uterine Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LE4CZ" = "1" /* Occlusion of Right Internal Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LE4DT" = "1" /* Occlusion of Right Uterine Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LE4DZ" = "1" /* Occlusion of Right Internal Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LE4ZT" = "1" /* Occlusion of Right Uterine Artery, Percutaneous Endoscopic Approach */
"04LE4ZZ" = "1" /* Occlusion of Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04LF0CU" = "1" /* Occlusion of Left Uterine Artery with Extraluminal Device, Open Approach */
"04LF0CZ" = "1" /* Occlusion of Left Internal Iliac Artery with Extraluminal Device, Open Approach */
"04LF0DU" = "1" /* Occlusion of Left Uterine Artery with Intraluminal Device, Open Approach */
"04LF0DZ" = "1" /* Occlusion of Left Internal Iliac Artery with Intraluminal Device, Open Approach */
"04LF0ZU" = "1" /* Occlusion of Left Uterine Artery, Open Approach */
"04LF0ZZ" = "1" /* Occlusion of Left Internal Iliac Artery, Open Approach */
"04LF3CU" = "1" /* Occlusion of Left Uterine Artery with Extraluminal Device, Percutaneous Approach */
"04LF3CZ" = "1" /* Occlusion of Left Internal Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04LF3DU" = "1" /* Occlusion of Left Uterine Artery with Intraluminal Device, Percutaneous Approach */
"04LF3DZ" = "1" /* Occlusion of Left Internal Iliac Artery with Intraluminal Device, Percutaneous Approach */
"04LF3ZU" = "1" /* Occlusion of Left Uterine Artery, Percutaneous Approach */
"04LF3ZZ" = "1" /* Occlusion of Left Internal Iliac Artery, Percutaneous Approach */
"04LF4CU" = "1" /* Occlusion of Left Uterine Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LF4CZ" = "1" /* Occlusion of Left Internal Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LF4DU" = "1" /* Occlusion of Left Uterine Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LF4DZ" = "1" /* Occlusion of Left Internal Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LF4ZU" = "1" /* Occlusion of Left Uterine Artery, Percutaneous Endoscopic Approach */
"04LF4ZZ" = "1" /* Occlusion of Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04LH0CZ" = "1" /* Occlusion of Right External Iliac Artery with Extraluminal Device, Open Approach */
"04LH0DZ" = "1" /* Occlusion of Right External Iliac Artery with Intraluminal Device, Open Approach */
"04LH0ZZ" = "1" /* Occlusion of Right External Iliac Artery, Open Approach */
"04LH3CZ" = "1" /* Occlusion of Right External Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04LH3DZ" = "1" /* Occlusion of Right External Iliac Artery with Intraluminal Device, Percutaneous Approach */
"04LH3ZZ" = "1" /* Occlusion of Right External Iliac Artery, Percutaneous Approach */
"04LH4CZ" = "1" /* Occlusion of Right External Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LH4DZ" = "1" /* Occlusion of Right External Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LH4ZZ" = "1" /* Occlusion of Right External Iliac Artery, Percutaneous Endoscopic Approach */
"04LJ0CZ" = "1" /* Occlusion of Left External Iliac Artery with Extraluminal Device, Open Approach */
"04LJ0DZ" = "1" /* Occlusion of Left External Iliac Artery with Intraluminal Device, Open Approach */
"04LJ0ZZ" = "1" /* Occlusion of Left External Iliac Artery, Open Approach */
"04LJ3CZ" = "1" /* Occlusion of Left External Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04LJ3DZ" = "1" /* Occlusion of Left External Iliac Artery with Intraluminal Device, Percutaneous Approach */
"04LJ3ZZ" = "1" /* Occlusion of Left External Iliac Artery, Percutaneous Approach */
"04LJ4CZ" = "1" /* Occlusion of Left External Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LJ4DZ" = "1" /* Occlusion of Left External Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LJ4ZZ" = "1" /* Occlusion of Left External Iliac Artery, Percutaneous Endoscopic Approach */
"04LK0CZ" = "1" /* Occlusion of Right Femoral Artery with Extraluminal Device, Open Approach */
"04LK0DZ" = "1" /* Occlusion of Right Femoral Artery with Intraluminal Device, Open Approach */
"04LK0ZZ" = "1" /* Occlusion of Right Femoral Artery, Open Approach */
"04LK3CZ" = "1" /* Occlusion of Right Femoral Artery with Extraluminal Device, Percutaneous Approach */
"04LK3DZ" = "1" /* Occlusion of Right Femoral Artery with Intraluminal Device, Percutaneous Approach */
"04LK3ZZ" = "1" /* Occlusion of Right Femoral Artery, Percutaneous Approach */
"04LK4CZ" = "1" /* Occlusion of Right Femoral Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LK4DZ" = "1" /* Occlusion of Right Femoral Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LK4ZZ" = "1" /* Occlusion of Right Femoral Artery, Percutaneous Endoscopic Approach */
"04LL0CZ" = "1" /* Occlusion of Left Femoral Artery with Extraluminal Device, Open Approach */
"04LL0DZ" = "1" /* Occlusion of Left Femoral Artery with Intraluminal Device, Open Approach */
"04LL0ZZ" = "1" /* Occlusion of Left Femoral Artery, Open Approach */
"04LL3CZ" = "1" /* Occlusion of Left Femoral Artery with Extraluminal Device, Percutaneous Approach */
"04LL3DZ" = "1" /* Occlusion of Left Femoral Artery with Intraluminal Device, Percutaneous Approach */
"04LL3ZZ" = "1" /* Occlusion of Left Femoral Artery, Percutaneous Approach */
"04LL4CZ" = "1" /* Occlusion of Left Femoral Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LL4DZ" = "1" /* Occlusion of Left Femoral Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LL4ZZ" = "1" /* Occlusion of Left Femoral Artery, Percutaneous Endoscopic Approach */
"04LM0CZ" = "1" /* Occlusion of Right Popliteal Artery with Extraluminal Device, Open Approach */
"04LM0DZ" = "1" /* Occlusion of Right Popliteal Artery with Intraluminal Device, Open Approach */
"04LM0ZZ" = "1" /* Occlusion of Right Popliteal Artery, Open Approach */
"04LM3CZ" = "1" /* Occlusion of Right Popliteal Artery with Extraluminal Device, Percutaneous Approach */
"04LM3DZ" = "1" /* Occlusion of Right Popliteal Artery with Intraluminal Device, Percutaneous Approach */
"04LM3ZZ" = "1" /* Occlusion of Right Popliteal Artery, Percutaneous Approach */
"04LM4CZ" = "1" /* Occlusion of Right Popliteal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LM4DZ" = "1" /* Occlusion of Right Popliteal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LM4ZZ" = "1" /* Occlusion of Right Popliteal Artery, Percutaneous Endoscopic Approach */
"04LN0CZ" = "1" /* Occlusion of Left Popliteal Artery with Extraluminal Device, Open Approach */
"04LN0DZ" = "1" /* Occlusion of Left Popliteal Artery with Intraluminal Device, Open Approach */
"04LN0ZZ" = "1" /* Occlusion of Left Popliteal Artery, Open Approach */
"04LN3CZ" = "1" /* Occlusion of Left Popliteal Artery with Extraluminal Device, Percutaneous Approach */
"04LN3DZ" = "1" /* Occlusion of Left Popliteal Artery with Intraluminal Device, Percutaneous Approach */
"04LN3ZZ" = "1" /* Occlusion of Left Popliteal Artery, Percutaneous Approach */
"04LN4CZ" = "1" /* Occlusion of Left Popliteal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LN4DZ" = "1" /* Occlusion of Left Popliteal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LN4ZZ" = "1" /* Occlusion of Left Popliteal Artery, Percutaneous Endoscopic Approach */
"04LP0CZ" = "1" /* Occlusion of Right Anterior Tibial Artery with Extraluminal Device, Open Approach */
"04LP0DZ" = "1" /* Occlusion of Right Anterior Tibial Artery with Intraluminal Device, Open Approach */
"04LP0ZZ" = "1" /* Occlusion of Right Anterior Tibial Artery, Open Approach */
"04LP3CZ" = "1" /* Occlusion of Right Anterior Tibial Artery with Extraluminal Device, Percutaneous Approach */
"04LP3DZ" = "1" /* Occlusion of Right Anterior Tibial Artery with Intraluminal Device, Percutaneous Approach */
"04LP3ZZ" = "1" /* Occlusion of Right Anterior Tibial Artery, Percutaneous Approach */
"04LP4CZ" = "1" /* Occlusion of Right Anterior Tibial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LP4DZ" = "1" /* Occlusion of Right Anterior Tibial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LP4ZZ" = "1" /* Occlusion of Right Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"04LQ0CZ" = "1" /* Occlusion of Left Anterior Tibial Artery with Extraluminal Device, Open Approach */
"04LQ0DZ" = "1" /* Occlusion of Left Anterior Tibial Artery with Intraluminal Device, Open Approach */
"04LQ0ZZ" = "1" /* Occlusion of Left Anterior Tibial Artery, Open Approach */
"04LQ3CZ" = "1" /* Occlusion of Left Anterior Tibial Artery with Extraluminal Device, Percutaneous Approach */
"04LQ3DZ" = "1" /* Occlusion of Left Anterior Tibial Artery with Intraluminal Device, Percutaneous Approach */
"04LQ3ZZ" = "1" /* Occlusion of Left Anterior Tibial Artery, Percutaneous Approach */
"04LQ4CZ" = "1" /* Occlusion of Left Anterior Tibial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LQ4DZ" = "1" /* Occlusion of Left Anterior Tibial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LQ4ZZ" = "1" /* Occlusion of Left Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"04LR0CZ" = "1" /* Occlusion of Right Posterior Tibial Artery with Extraluminal Device, Open Approach */
"04LR0DZ" = "1" /* Occlusion of Right Posterior Tibial Artery with Intraluminal Device, Open Approach */
"04LR0ZZ" = "1" /* Occlusion of Right Posterior Tibial Artery, Open Approach */
"04LR3CZ" = "1" /* Occlusion of Right Posterior Tibial Artery with Extraluminal Device, Percutaneous Approach */
"04LR3DZ" = "1" /* Occlusion of Right Posterior Tibial Artery with Intraluminal Device, Percutaneous Approach */
"04LR3ZZ" = "1" /* Occlusion of Right Posterior Tibial Artery, Percutaneous Approach */
"04LR4CZ" = "1" /* Occlusion of Right Posterior Tibial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LR4DZ" = "1" /* Occlusion of Right Posterior Tibial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LR4ZZ" = "1" /* Occlusion of Right Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"04LS0CZ" = "1" /* Occlusion of Left Posterior Tibial Artery with Extraluminal Device, Open Approach */
"04LS0DZ" = "1" /* Occlusion of Left Posterior Tibial Artery with Intraluminal Device, Open Approach */
"04LS0ZZ" = "1" /* Occlusion of Left Posterior Tibial Artery, Open Approach */
"04LS3CZ" = "1" /* Occlusion of Left Posterior Tibial Artery with Extraluminal Device, Percutaneous Approach */
"04LS3DZ" = "1" /* Occlusion of Left Posterior Tibial Artery with Intraluminal Device, Percutaneous Approach */
"04LS3ZZ" = "1" /* Occlusion of Left Posterior Tibial Artery, Percutaneous Approach */
"04LS4CZ" = "1" /* Occlusion of Left Posterior Tibial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LS4DZ" = "1" /* Occlusion of Left Posterior Tibial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LS4ZZ" = "1" /* Occlusion of Left Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"04LT0CZ" = "1" /* Occlusion of Right Peroneal Artery with Extraluminal Device, Open Approach */
"04LT0DZ" = "1" /* Occlusion of Right Peroneal Artery with Intraluminal Device, Open Approach */
"04LT0ZZ" = "1" /* Occlusion of Right Peroneal Artery, Open Approach */
"04LT3CZ" = "1" /* Occlusion of Right Peroneal Artery with Extraluminal Device, Percutaneous Approach */
"04LT3DZ" = "1" /* Occlusion of Right Peroneal Artery with Intraluminal Device, Percutaneous Approach */
"04LT3ZZ" = "1" /* Occlusion of Right Peroneal Artery, Percutaneous Approach */
"04LT4CZ" = "1" /* Occlusion of Right Peroneal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LT4DZ" = "1" /* Occlusion of Right Peroneal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LT4ZZ" = "1" /* Occlusion of Right Peroneal Artery, Percutaneous Endoscopic Approach */
"04LU0CZ" = "1" /* Occlusion of Left Peroneal Artery with Extraluminal Device, Open Approach */
"04LU0DZ" = "1" /* Occlusion of Left Peroneal Artery with Intraluminal Device, Open Approach */
"04LU0ZZ" = "1" /* Occlusion of Left Peroneal Artery, Open Approach */
"04LU3CZ" = "1" /* Occlusion of Left Peroneal Artery with Extraluminal Device, Percutaneous Approach */
"04LU3DZ" = "1" /* Occlusion of Left Peroneal Artery with Intraluminal Device, Percutaneous Approach */
"04LU3ZZ" = "1" /* Occlusion of Left Peroneal Artery, Percutaneous Approach */
"04LU4CZ" = "1" /* Occlusion of Left Peroneal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LU4DZ" = "1" /* Occlusion of Left Peroneal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LU4ZZ" = "1" /* Occlusion of Left Peroneal Artery, Percutaneous Endoscopic Approach */
"04LV0CZ" = "1" /* Occlusion of Right Foot Artery with Extraluminal Device, Open Approach */
"04LV0DZ" = "1" /* Occlusion of Right Foot Artery with Intraluminal Device, Open Approach */
"04LV0ZZ" = "1" /* Occlusion of Right Foot Artery, Open Approach */
"04LV3CZ" = "1" /* Occlusion of Right Foot Artery with Extraluminal Device, Percutaneous Approach */
"04LV3DZ" = "1" /* Occlusion of Right Foot Artery with Intraluminal Device, Percutaneous Approach */
"04LV3ZZ" = "1" /* Occlusion of Right Foot Artery, Percutaneous Approach */
"04LV4CZ" = "1" /* Occlusion of Right Foot Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LV4DZ" = "1" /* Occlusion of Right Foot Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LV4ZZ" = "1" /* Occlusion of Right Foot Artery, Percutaneous Endoscopic Approach */
"04LW0CZ" = "1" /* Occlusion of Left Foot Artery with Extraluminal Device, Open Approach */
"04LW0DZ" = "1" /* Occlusion of Left Foot Artery with Intraluminal Device, Open Approach */
"04LW0ZZ" = "1" /* Occlusion of Left Foot Artery, Open Approach */
"04LW3CZ" = "1" /* Occlusion of Left Foot Artery with Extraluminal Device, Percutaneous Approach */
"04LW3DZ" = "1" /* Occlusion of Left Foot Artery with Intraluminal Device, Percutaneous Approach */
"04LW3ZZ" = "1" /* Occlusion of Left Foot Artery, Percutaneous Approach */
"04LW4CZ" = "1" /* Occlusion of Left Foot Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LW4DZ" = "1" /* Occlusion of Left Foot Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LW4ZZ" = "1" /* Occlusion of Left Foot Artery, Percutaneous Endoscopic Approach */
"04LY0CZ" = "1" /* Occlusion of Lower Artery with Extraluminal Device, Open Approach */
"04LY0DZ" = "1" /* Occlusion of Lower Artery with Intraluminal Device, Open Approach */
"04LY0ZZ" = "1" /* Occlusion of Lower Artery, Open Approach */
"04LY3CZ" = "1" /* Occlusion of Lower Artery with Extraluminal Device, Percutaneous Approach */
"04LY3DZ" = "1" /* Occlusion of Lower Artery with Intraluminal Device, Percutaneous Approach */
"04LY3ZZ" = "1" /* Occlusion of Lower Artery, Percutaneous Approach */
"04LY4CZ" = "1" /* Occlusion of Lower Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04LY4DZ" = "1" /* Occlusion of Lower Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04LY4ZZ" = "1" /* Occlusion of Lower Artery, Percutaneous Endoscopic Approach */
"04N00ZZ" = "1" /* Release Abdominal Aorta, Open Approach */
"04N03ZZ" = "1" /* Release Abdominal Aorta, Percutaneous Approach */
"04N04ZZ" = "1" /* Release Abdominal Aorta, Percutaneous Endoscopic Approach */
"04N10ZZ" = "1" /* Release Celiac Artery, Open Approach */
"04N13ZZ" = "1" /* Release Celiac Artery, Percutaneous Approach */
"04N14ZZ" = "1" /* Release Celiac Artery, Percutaneous Endoscopic Approach */
"04N20ZZ" = "1" /* Release Gastric Artery, Open Approach */
"04N23ZZ" = "1" /* Release Gastric Artery, Percutaneous Approach */
"04N24ZZ" = "1" /* Release Gastric Artery, Percutaneous Endoscopic Approach */
"04N30ZZ" = "1" /* Release Hepatic Artery, Open Approach */
"04N33ZZ" = "1" /* Release Hepatic Artery, Percutaneous Approach */
"04N34ZZ" = "1" /* Release Hepatic Artery, Percutaneous Endoscopic Approach */
"04N40ZZ" = "1" /* Release Splenic Artery, Open Approach */
"04N43ZZ" = "1" /* Release Splenic Artery, Percutaneous Approach */
"04N44ZZ" = "1" /* Release Splenic Artery, Percutaneous Endoscopic Approach */
"04N50ZZ" = "1" /* Release Superior Mesenteric Artery, Open Approach */
"04N53ZZ" = "1" /* Release Superior Mesenteric Artery, Percutaneous Approach */
"04N54ZZ" = "1" /* Release Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04N60ZZ" = "1" /* Release Right Colic Artery, Open Approach */
"04N63ZZ" = "1" /* Release Right Colic Artery, Percutaneous Approach */
"04N64ZZ" = "1" /* Release Right Colic Artery, Percutaneous Endoscopic Approach */
"04N70ZZ" = "1" /* Release Left Colic Artery, Open Approach */
"04N73ZZ" = "1" /* Release Left Colic Artery, Percutaneous Approach */
"04N74ZZ" = "1" /* Release Left Colic Artery, Percutaneous Endoscopic Approach */
"04N80ZZ" = "1" /* Release Middle Colic Artery, Open Approach */
"04N83ZZ" = "1" /* Release Middle Colic Artery, Percutaneous Approach */
"04N84ZZ" = "1" /* Release Middle Colic Artery, Percutaneous Endoscopic Approach */
"04N90ZZ" = "1" /* Release Right Renal Artery, Open Approach */
"04N93ZZ" = "1" /* Release Right Renal Artery, Percutaneous Approach */
"04N94ZZ" = "1" /* Release Right Renal Artery, Percutaneous Endoscopic Approach */
"04NA0ZZ" = "1" /* Release Left Renal Artery, Open Approach */
"04NA3ZZ" = "1" /* Release Left Renal Artery, Percutaneous Approach */
"04NA4ZZ" = "1" /* Release Left Renal Artery, Percutaneous Endoscopic Approach */
"04NB0ZZ" = "1" /* Release Inferior Mesenteric Artery, Open Approach */
"04NB3ZZ" = "1" /* Release Inferior Mesenteric Artery, Percutaneous Approach */
"04NB4ZZ" = "1" /* Release Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04NC0ZZ" = "1" /* Release Right Common Iliac Artery, Open Approach */
"04NC3ZZ" = "1" /* Release Right Common Iliac Artery, Percutaneous Approach */
"04NC4ZZ" = "1" /* Release Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"04ND0ZZ" = "1" /* Release Left Common Iliac Artery, Open Approach */
"04ND3ZZ" = "1" /* Release Left Common Iliac Artery, Percutaneous Approach */
"04ND4ZZ" = "1" /* Release Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"04NE0ZZ" = "1" /* Release Right Internal Iliac Artery, Open Approach */
"04NE3ZZ" = "1" /* Release Right Internal Iliac Artery, Percutaneous Approach */
"04NE4ZZ" = "1" /* Release Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04NF0ZZ" = "1" /* Release Left Internal Iliac Artery, Open Approach */
"04NF3ZZ" = "1" /* Release Left Internal Iliac Artery, Percutaneous Approach */
"04NF4ZZ" = "1" /* Release Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04NH0ZZ" = "1" /* Release Right External Iliac Artery, Open Approach */
"04NH3ZZ" = "1" /* Release Right External Iliac Artery, Percutaneous Approach */
"04NH4ZZ" = "1" /* Release Right External Iliac Artery, Percutaneous Endoscopic Approach */
"04NJ0ZZ" = "1" /* Release Left External Iliac Artery, Open Approach */
"04NJ3ZZ" = "1" /* Release Left External Iliac Artery, Percutaneous Approach */
"04NJ4ZZ" = "1" /* Release Left External Iliac Artery, Percutaneous Endoscopic Approach */
"04NK0ZZ" = "1" /* Release Right Femoral Artery, Open Approach */
"04NK3ZZ" = "1" /* Release Right Femoral Artery, Percutaneous Approach */
"04NK4ZZ" = "1" /* Release Right Femoral Artery, Percutaneous Endoscopic Approach */
"04NL0ZZ" = "1" /* Release Left Femoral Artery, Open Approach */
"04NL3ZZ" = "1" /* Release Left Femoral Artery, Percutaneous Approach */
"04NL4ZZ" = "1" /* Release Left Femoral Artery, Percutaneous Endoscopic Approach */
"04NM0ZZ" = "1" /* Release Right Popliteal Artery, Open Approach */
"04NM3ZZ" = "1" /* Release Right Popliteal Artery, Percutaneous Approach */
"04NM4ZZ" = "1" /* Release Right Popliteal Artery, Percutaneous Endoscopic Approach */
"04NN0ZZ" = "1" /* Release Left Popliteal Artery, Open Approach */
"04NN3ZZ" = "1" /* Release Left Popliteal Artery, Percutaneous Approach */
"04NN4ZZ" = "1" /* Release Left Popliteal Artery, Percutaneous Endoscopic Approach */
"04NP0ZZ" = "1" /* Release Right Anterior Tibial Artery, Open Approach */
"04NP3ZZ" = "1" /* Release Right Anterior Tibial Artery, Percutaneous Approach */
"04NP4ZZ" = "1" /* Release Right Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"04NQ0ZZ" = "1" /* Release Left Anterior Tibial Artery, Open Approach */
"04NQ3ZZ" = "1" /* Release Left Anterior Tibial Artery, Percutaneous Approach */
"04NQ4ZZ" = "1" /* Release Left Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"04NR0ZZ" = "1" /* Release Right Posterior Tibial Artery, Open Approach */
"04NR3ZZ" = "1" /* Release Right Posterior Tibial Artery, Percutaneous Approach */
"04NR4ZZ" = "1" /* Release Right Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"04NS0ZZ" = "1" /* Release Left Posterior Tibial Artery, Open Approach */
"04NS3ZZ" = "1" /* Release Left Posterior Tibial Artery, Percutaneous Approach */
"04NS4ZZ" = "1" /* Release Left Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"04NT0ZZ" = "1" /* Release Right Peroneal Artery, Open Approach */
"04NT3ZZ" = "1" /* Release Right Peroneal Artery, Percutaneous Approach */
"04NT4ZZ" = "1" /* Release Right Peroneal Artery, Percutaneous Endoscopic Approach */
"04NU0ZZ" = "1" /* Release Left Peroneal Artery, Open Approach */
"04NU3ZZ" = "1" /* Release Left Peroneal Artery, Percutaneous Approach */
"04NU4ZZ" = "1" /* Release Left Peroneal Artery, Percutaneous Endoscopic Approach */
"04NV0ZZ" = "1" /* Release Right Foot Artery, Open Approach */
"04NV3ZZ" = "1" /* Release Right Foot Artery, Percutaneous Approach */
"04NV4ZZ" = "1" /* Release Right Foot Artery, Percutaneous Endoscopic Approach */
"04NW0ZZ" = "1" /* Release Left Foot Artery, Open Approach */
"04NW3ZZ" = "1" /* Release Left Foot Artery, Percutaneous Approach */
"04NW4ZZ" = "1" /* Release Left Foot Artery, Percutaneous Endoscopic Approach */
"04NY0ZZ" = "1" /* Release Lower Artery, Open Approach */
"04NY3ZZ" = "1" /* Release Lower Artery, Percutaneous Approach */
"04NY4ZZ" = "1" /* Release Lower Artery, Percutaneous Endoscopic Approach */
"04PY00Z" = "1" /* Removal of Drainage Device from Lower Artery, Open Approach */
"04PY02Z" = "1" /* Removal of Monitoring Device from Lower Artery, Open Approach */
"04PY03Z" = "1" /* Removal of Infusion Device from Lower Artery, Open Approach */
"04PY07Z" = "1" /* Removal of Autologous Tissue Substitute from Lower Artery, Open Approach */
"04PY0CZ" = "1" /* Removal of Extraluminal Device from Lower Artery, Open Approach */
"04PY0DZ" = "1" /* Removal of Intraluminal Device from Lower Artery, Open Approach */
"04PY0JZ" = "1" /* Removal of Synthetic Substitute from Lower Artery, Open Approach */
"04PY0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lower Artery, Open Approach */
"04PY37Z" = "1" /* Removal of Autologous Tissue Substitute from Lower Artery, Percutaneous Approach */
"04PY3CZ" = "1" /* Removal of Extraluminal Device from Lower Artery, Percutaneous Approach */
"04PY3JZ" = "1" /* Removal of Synthetic Substitute from Lower Artery, Percutaneous Approach */
"04PY3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lower Artery, Percutaneous Approach */
"04PY40Z" = "1" /* Removal of Drainage Device from Lower Artery, Percutaneous Endoscopic Approach */
"04PY42Z" = "1" /* Removal of Monitoring Device from Lower Artery, Percutaneous Endoscopic Approach */
"04PY43Z" = "1" /* Removal of Infusion Device from Lower Artery, Percutaneous Endoscopic Approach */
"04PY47Z" = "1" /* Removal of Autologous Tissue Substitute from Lower Artery, Percutaneous Endoscopic Approach */
"04PY4CZ" = "1" /* Removal of Extraluminal Device from Lower Artery, Percutaneous Endoscopic Approach */
"04PY4DZ" = "1" /* Removal of Intraluminal Device from Lower Artery, Percutaneous Endoscopic Approach */
"04PY4JZ" = "1" /* Removal of Synthetic Substitute from Lower Artery, Percutaneous Endoscopic Approach */
"04PY4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lower Artery, Percutaneous Endoscopic Approach */
"04Q00ZZ" = "1" /* Repair Abdominal Aorta, Open Approach */
"04Q03ZZ" = "1" /* Repair Abdominal Aorta, Percutaneous Approach */
"04Q04ZZ" = "1" /* Repair Abdominal Aorta, Percutaneous Endoscopic Approach */
"04Q10ZZ" = "1" /* Repair Celiac Artery, Open Approach */
"04Q13ZZ" = "1" /* Repair Celiac Artery, Percutaneous Approach */
"04Q14ZZ" = "1" /* Repair Celiac Artery, Percutaneous Endoscopic Approach */
"04Q20ZZ" = "1" /* Repair Gastric Artery, Open Approach */
"04Q23ZZ" = "1" /* Repair Gastric Artery, Percutaneous Approach */
"04Q24ZZ" = "1" /* Repair Gastric Artery, Percutaneous Endoscopic Approach */
"04Q30ZZ" = "1" /* Repair Hepatic Artery, Open Approach */
"04Q33ZZ" = "1" /* Repair Hepatic Artery, Percutaneous Approach */
"04Q34ZZ" = "1" /* Repair Hepatic Artery, Percutaneous Endoscopic Approach */
"04Q40ZZ" = "1" /* Repair Splenic Artery, Open Approach */
"04Q43ZZ" = "1" /* Repair Splenic Artery, Percutaneous Approach */
"04Q44ZZ" = "1" /* Repair Splenic Artery, Percutaneous Endoscopic Approach */
"04Q50ZZ" = "1" /* Repair Superior Mesenteric Artery, Open Approach */
"04Q53ZZ" = "1" /* Repair Superior Mesenteric Artery, Percutaneous Approach */
"04Q54ZZ" = "1" /* Repair Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04Q60ZZ" = "1" /* Repair Right Colic Artery, Open Approach */
"04Q63ZZ" = "1" /* Repair Right Colic Artery, Percutaneous Approach */
"04Q64ZZ" = "1" /* Repair Right Colic Artery, Percutaneous Endoscopic Approach */
"04Q70ZZ" = "1" /* Repair Left Colic Artery, Open Approach */
"04Q73ZZ" = "1" /* Repair Left Colic Artery, Percutaneous Approach */
"04Q74ZZ" = "1" /* Repair Left Colic Artery, Percutaneous Endoscopic Approach */
"04Q80ZZ" = "1" /* Repair Middle Colic Artery, Open Approach */
"04Q83ZZ" = "1" /* Repair Middle Colic Artery, Percutaneous Approach */
"04Q84ZZ" = "1" /* Repair Middle Colic Artery, Percutaneous Endoscopic Approach */
"04Q90ZZ" = "1" /* Repair Right Renal Artery, Open Approach */
"04Q93ZZ" = "1" /* Repair Right Renal Artery, Percutaneous Approach */
"04Q94ZZ" = "1" /* Repair Right Renal Artery, Percutaneous Endoscopic Approach */
"04QA0ZZ" = "1" /* Repair Left Renal Artery, Open Approach */
"04QA3ZZ" = "1" /* Repair Left Renal Artery, Percutaneous Approach */
"04QA4ZZ" = "1" /* Repair Left Renal Artery, Percutaneous Endoscopic Approach */
"04QB0ZZ" = "1" /* Repair Inferior Mesenteric Artery, Open Approach */
"04QB3ZZ" = "1" /* Repair Inferior Mesenteric Artery, Percutaneous Approach */
"04QB4ZZ" = "1" /* Repair Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04QC0ZZ" = "1" /* Repair Right Common Iliac Artery, Open Approach */
"04QC3ZZ" = "1" /* Repair Right Common Iliac Artery, Percutaneous Approach */
"04QC4ZZ" = "1" /* Repair Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"04QD0ZZ" = "1" /* Repair Left Common Iliac Artery, Open Approach */
"04QD3ZZ" = "1" /* Repair Left Common Iliac Artery, Percutaneous Approach */
"04QD4ZZ" = "1" /* Repair Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"04QE0ZZ" = "1" /* Repair Right Internal Iliac Artery, Open Approach */
"04QE3ZZ" = "1" /* Repair Right Internal Iliac Artery, Percutaneous Approach */
"04QE4ZZ" = "1" /* Repair Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04QF0ZZ" = "1" /* Repair Left Internal Iliac Artery, Open Approach */
"04QF3ZZ" = "1" /* Repair Left Internal Iliac Artery, Percutaneous Approach */
"04QF4ZZ" = "1" /* Repair Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04QH0ZZ" = "1" /* Repair Right External Iliac Artery, Open Approach */
"04QH3ZZ" = "1" /* Repair Right External Iliac Artery, Percutaneous Approach */
"04QH4ZZ" = "1" /* Repair Right External Iliac Artery, Percutaneous Endoscopic Approach */
"04QJ0ZZ" = "1" /* Repair Left External Iliac Artery, Open Approach */
"04QJ3ZZ" = "1" /* Repair Left External Iliac Artery, Percutaneous Approach */
"04QJ4ZZ" = "1" /* Repair Left External Iliac Artery, Percutaneous Endoscopic Approach */
"04QK0ZZ" = "1" /* Repair Right Femoral Artery, Open Approach */
"04QK3ZZ" = "1" /* Repair Right Femoral Artery, Percutaneous Approach */
"04QK4ZZ" = "1" /* Repair Right Femoral Artery, Percutaneous Endoscopic Approach */
"04QL0ZZ" = "1" /* Repair Left Femoral Artery, Open Approach */
"04QL3ZZ" = "1" /* Repair Left Femoral Artery, Percutaneous Approach */
"04QL4ZZ" = "1" /* Repair Left Femoral Artery, Percutaneous Endoscopic Approach */
"04QM0ZZ" = "1" /* Repair Right Popliteal Artery, Open Approach */
"04QM3ZZ" = "1" /* Repair Right Popliteal Artery, Percutaneous Approach */
"04QM4ZZ" = "1" /* Repair Right Popliteal Artery, Percutaneous Endoscopic Approach */
"04QN0ZZ" = "1" /* Repair Left Popliteal Artery, Open Approach */
"04QN3ZZ" = "1" /* Repair Left Popliteal Artery, Percutaneous Approach */
"04QN4ZZ" = "1" /* Repair Left Popliteal Artery, Percutaneous Endoscopic Approach */
"04QP0ZZ" = "1" /* Repair Right Anterior Tibial Artery, Open Approach */
"04QP3ZZ" = "1" /* Repair Right Anterior Tibial Artery, Percutaneous Approach */
"04QP4ZZ" = "1" /* Repair Right Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"04QQ0ZZ" = "1" /* Repair Left Anterior Tibial Artery, Open Approach */
"04QQ3ZZ" = "1" /* Repair Left Anterior Tibial Artery, Percutaneous Approach */
"04QQ4ZZ" = "1" /* Repair Left Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"04QR0ZZ" = "1" /* Repair Right Posterior Tibial Artery, Open Approach */
"04QR3ZZ" = "1" /* Repair Right Posterior Tibial Artery, Percutaneous Approach */
"04QR4ZZ" = "1" /* Repair Right Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"04QS0ZZ" = "1" /* Repair Left Posterior Tibial Artery, Open Approach */
"04QS3ZZ" = "1" /* Repair Left Posterior Tibial Artery, Percutaneous Approach */
"04QS4ZZ" = "1" /* Repair Left Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"04QT0ZZ" = "1" /* Repair Right Peroneal Artery, Open Approach */
"04QT3ZZ" = "1" /* Repair Right Peroneal Artery, Percutaneous Approach */
"04QT4ZZ" = "1" /* Repair Right Peroneal Artery, Percutaneous Endoscopic Approach */
"04QU0ZZ" = "1" /* Repair Left Peroneal Artery, Open Approach */
"04QU3ZZ" = "1" /* Repair Left Peroneal Artery, Percutaneous Approach */
"04QU4ZZ" = "1" /* Repair Left Peroneal Artery, Percutaneous Endoscopic Approach */
"04QV0ZZ" = "1" /* Repair Right Foot Artery, Open Approach */
"04QV3ZZ" = "1" /* Repair Right Foot Artery, Percutaneous Approach */
"04QV4ZZ" = "1" /* Repair Right Foot Artery, Percutaneous Endoscopic Approach */
"04QW0ZZ" = "1" /* Repair Left Foot Artery, Open Approach */
"04QW3ZZ" = "1" /* Repair Left Foot Artery, Percutaneous Approach */
"04QW4ZZ" = "1" /* Repair Left Foot Artery, Percutaneous Endoscopic Approach */
"04QY0ZZ" = "1" /* Repair Lower Artery, Open Approach */
"04QY3ZZ" = "1" /* Repair Lower Artery, Percutaneous Approach */
"04QY4ZZ" = "1" /* Repair Lower Artery, Percutaneous Endoscopic Approach */
"04R007Z" = "1" /* Replacement of Abdominal Aorta with Autologous Tissue Substitute, Open Approach */
"04R00JZ" = "1" /* Replacement of Abdominal Aorta with Synthetic Substitute, Open Approach */
"04R00KZ" = "1" /* Replacement of Abdominal Aorta with Nonautologous Tissue Substitute, Open Approach */
"04R047Z" = "1" /* Replacement of Abdominal Aorta with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R04JZ" = "1" /* Replacement of Abdominal Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04R04KZ" = "1" /* Replacement of Abdominal Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R107Z" = "1" /* Replacement of Celiac Artery with Autologous Tissue Substitute, Open Approach */
"04R10JZ" = "1" /* Replacement of Celiac Artery with Synthetic Substitute, Open Approach */
"04R10KZ" = "1" /* Replacement of Celiac Artery with Nonautologous Tissue Substitute, Open Approach */
"04R147Z" = "1" /* Replacement of Celiac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R14JZ" = "1" /* Replacement of Celiac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04R14KZ" = "1" /* Replacement of Celiac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R207Z" = "1" /* Replacement of Gastric Artery with Autologous Tissue Substitute, Open Approach */
"04R20JZ" = "1" /* Replacement of Gastric Artery with Synthetic Substitute, Open Approach */
"04R20KZ" = "1" /* Replacement of Gastric Artery with Nonautologous Tissue Substitute, Open Approach */
"04R247Z" = "1" /* Replacement of Gastric Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R24JZ" = "1" /* Replacement of Gastric Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04R24KZ" = "1" /* Replacement of Gastric Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R307Z" = "1" /* Replacement of Hepatic Artery with Autologous Tissue Substitute, Open Approach */
"04R30JZ" = "1" /* Replacement of Hepatic Artery with Synthetic Substitute, Open Approach */
"04R30KZ" = "1" /* Replacement of Hepatic Artery with Nonautologous Tissue Substitute, Open Approach */
"04R347Z" = "1" /* Replacement of Hepatic Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R34JZ" = "1" /* Replacement of Hepatic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04R34KZ" = "1" /* Replacement of Hepatic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R407Z" = "1" /* Replacement of Splenic Artery with Autologous Tissue Substitute, Open Approach */
"04R40JZ" = "1" /* Replacement of Splenic Artery with Synthetic Substitute, Open Approach */
"04R40KZ" = "1" /* Replacement of Splenic Artery with Nonautologous Tissue Substitute, Open Approach */
"04R447Z" = "1" /* Replacement of Splenic Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R44JZ" = "1" /* Replacement of Splenic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04R44KZ" = "1" /* Replacement of Splenic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R507Z" = "1" /* Replacement of Superior Mesenteric Artery with Autologous Tissue Substitute, Open Approach */
"04R50JZ" = "1" /* Replacement of Superior Mesenteric Artery with Synthetic Substitute, Open Approach */
"04R50KZ" = "1" /* Replacement of Superior Mesenteric Artery with Nonautologous Tissue Substitute, Open Approach */
"04R547Z" = "1" /* Replacement of Superior Mesenteric Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R54JZ" = "1" /* Replacement of Superior Mesenteric Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04R54KZ" = "1" /* Replacement of Superior Mesenteric Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R607Z" = "1" /* Replacement of Right Colic Artery with Autologous Tissue Substitute, Open Approach */
"04R60JZ" = "1" /* Replacement of Right Colic Artery with Synthetic Substitute, Open Approach */
"04R60KZ" = "1" /* Replacement of Right Colic Artery with Nonautologous Tissue Substitute, Open Approach */
"04R647Z" = "1" /* Replacement of Right Colic Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R64JZ" = "1" /* Replacement of Right Colic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04R64KZ" = "1" /* Replacement of Right Colic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R707Z" = "1" /* Replacement of Left Colic Artery with Autologous Tissue Substitute, Open Approach */
"04R70JZ" = "1" /* Replacement of Left Colic Artery with Synthetic Substitute, Open Approach */
"04R70KZ" = "1" /* Replacement of Left Colic Artery with Nonautologous Tissue Substitute, Open Approach */
"04R747Z" = "1" /* Replacement of Left Colic Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R74JZ" = "1" /* Replacement of Left Colic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04R74KZ" = "1" /* Replacement of Left Colic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R807Z" = "1" /* Replacement of Middle Colic Artery with Autologous Tissue Substitute, Open Approach */
"04R80JZ" = "1" /* Replacement of Middle Colic Artery with Synthetic Substitute, Open Approach */
"04R80KZ" = "1" /* Replacement of Middle Colic Artery with Nonautologous Tissue Substitute, Open Approach */
"04R847Z" = "1" /* Replacement of Middle Colic Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R84JZ" = "1" /* Replacement of Middle Colic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04R84KZ" = "1" /* Replacement of Middle Colic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R907Z" = "1" /* Replacement of Right Renal Artery with Autologous Tissue Substitute, Open Approach */
"04R90JZ" = "1" /* Replacement of Right Renal Artery with Synthetic Substitute, Open Approach */
"04R90KZ" = "1" /* Replacement of Right Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"04R947Z" = "1" /* Replacement of Right Renal Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R94JZ" = "1" /* Replacement of Right Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04R94KZ" = "1" /* Replacement of Right Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RA07Z" = "1" /* Replacement of Left Renal Artery with Autologous Tissue Substitute, Open Approach */
"04RA0JZ" = "1" /* Replacement of Left Renal Artery with Synthetic Substitute, Open Approach */
"04RA0KZ" = "1" /* Replacement of Left Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"04RA47Z" = "1" /* Replacement of Left Renal Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RA4JZ" = "1" /* Replacement of Left Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RA4KZ" = "1" /* Replacement of Left Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RB07Z" = "1" /* Replacement of Inferior Mesenteric Artery with Autologous Tissue Substitute, Open Approach */
"04RB0JZ" = "1" /* Replacement of Inferior Mesenteric Artery with Synthetic Substitute, Open Approach */
"04RB0KZ" = "1" /* Replacement of Inferior Mesenteric Artery with Nonautologous Tissue Substitute, Open Approach */
"04RB47Z" = "1" /* Replacement of Inferior Mesenteric Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RB4JZ" = "1" /* Replacement of Inferior Mesenteric Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RB4KZ" = "1" /* Replacement of Inferior Mesenteric Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RC07Z" = "1" /* Replacement of Right Common Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04RC0JZ" = "1" /* Replacement of Right Common Iliac Artery with Synthetic Substitute, Open Approach */
"04RC0KZ" = "1" /* Replacement of Right Common Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04RC47Z" = "1" /* Replacement of Right Common Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RC4JZ" = "1" /* Replacement of Right Common Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RC4KZ" = "1" /* Replacement of Right Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RD07Z" = "1" /* Replacement of Left Common Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04RD0JZ" = "1" /* Replacement of Left Common Iliac Artery with Synthetic Substitute, Open Approach */
"04RD0KZ" = "1" /* Replacement of Left Common Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04RD47Z" = "1" /* Replacement of Left Common Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RD4JZ" = "1" /* Replacement of Left Common Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RD4KZ" = "1" /* Replacement of Left Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RE07Z" = "1" /* Replacement of Right Internal Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04RE0JZ" = "1" /* Replacement of Right Internal Iliac Artery with Synthetic Substitute, Open Approach */
"04RE0KZ" = "1" /* Replacement of Right Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04RE47Z" = "1" /* Replacement of Right Internal Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RE4JZ" = "1" /* Replacement of Right Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RE4KZ" = "1" /* Replacement of Right Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RF07Z" = "1" /* Replacement of Left Internal Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04RF0JZ" = "1" /* Replacement of Left Internal Iliac Artery with Synthetic Substitute, Open Approach */
"04RF0KZ" = "1" /* Replacement of Left Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04RF47Z" = "1" /* Replacement of Left Internal Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RF4JZ" = "1" /* Replacement of Left Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RF4KZ" = "1" /* Replacement of Left Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RH07Z" = "1" /* Replacement of Right External Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04RH0JZ" = "1" /* Replacement of Right External Iliac Artery with Synthetic Substitute, Open Approach */
"04RH0KZ" = "1" /* Replacement of Right External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04RH47Z" = "1" /* Replacement of Right External Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RH4JZ" = "1" /* Replacement of Right External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RH4KZ" = "1" /* Replacement of Right External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RJ07Z" = "1" /* Replacement of Left External Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04RJ0JZ" = "1" /* Replacement of Left External Iliac Artery with Synthetic Substitute, Open Approach */
"04RJ0KZ" = "1" /* Replacement of Left External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04RJ47Z" = "1" /* Replacement of Left External Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RJ4JZ" = "1" /* Replacement of Left External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RJ4KZ" = "1" /* Replacement of Left External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RK07Z" = "1" /* Replacement of Right Femoral Artery with Autologous Tissue Substitute, Open Approach */
"04RK0JZ" = "1" /* Replacement of Right Femoral Artery with Synthetic Substitute, Open Approach */
"04RK0KZ" = "1" /* Replacement of Right Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"04RK47Z" = "1" /* Replacement of Right Femoral Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RK4JZ" = "1" /* Replacement of Right Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RK4KZ" = "1" /* Replacement of Right Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RL07Z" = "1" /* Replacement of Left Femoral Artery with Autologous Tissue Substitute, Open Approach */
"04RL0JZ" = "1" /* Replacement of Left Femoral Artery with Synthetic Substitute, Open Approach */
"04RL0KZ" = "1" /* Replacement of Left Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"04RL47Z" = "1" /* Replacement of Left Femoral Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RL4JZ" = "1" /* Replacement of Left Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RL4KZ" = "1" /* Replacement of Left Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RM07Z" = "1" /* Replacement of Right Popliteal Artery with Autologous Tissue Substitute, Open Approach */
"04RM0JZ" = "1" /* Replacement of Right Popliteal Artery with Synthetic Substitute, Open Approach */
"04RM0KZ" = "1" /* Replacement of Right Popliteal Artery with Nonautologous Tissue Substitute, Open Approach */
"04RM47Z" = "1" /* Replacement of Right Popliteal Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RM4JZ" = "1" /* Replacement of Right Popliteal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RM4KZ" = "1" /* Replacement of Right Popliteal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RN07Z" = "1" /* Replacement of Left Popliteal Artery with Autologous Tissue Substitute, Open Approach */
"04RN0JZ" = "1" /* Replacement of Left Popliteal Artery with Synthetic Substitute, Open Approach */
"04RN0KZ" = "1" /* Replacement of Left Popliteal Artery with Nonautologous Tissue Substitute, Open Approach */
"04RN47Z" = "1" /* Replacement of Left Popliteal Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RN4JZ" = "1" /* Replacement of Left Popliteal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RN4KZ" = "1" /* Replacement of Left Popliteal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RP07Z" = "1" /* Replacement of Right Anterior Tibial Artery with Autologous Tissue Substitute, Open Approach */
"04RP0JZ" = "1" /* Replacement of Right Anterior Tibial Artery with Synthetic Substitute, Open Approach */
"04RP0KZ" = "1" /* Replacement of Right Anterior Tibial Artery with Nonautologous Tissue Substitute, Open Approach */
"04RP47Z" = "1" /* Replacement of Right Anterior Tibial Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RP4JZ" = "1" /* Replacement of Right Anterior Tibial Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RP4KZ" = "1" /* Replacement of Right Anterior Tibial Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RQ07Z" = "1" /* Replacement of Left Anterior Tibial Artery with Autologous Tissue Substitute, Open Approach */
"04RQ0JZ" = "1" /* Replacement of Left Anterior Tibial Artery with Synthetic Substitute, Open Approach */
"04RQ0KZ" = "1" /* Replacement of Left Anterior Tibial Artery with Nonautologous Tissue Substitute, Open Approach */
"04RQ47Z" = "1" /* Replacement of Left Anterior Tibial Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RQ4JZ" = "1" /* Replacement of Left Anterior Tibial Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RQ4KZ" = "1" /* Replacement of Left Anterior Tibial Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RR07Z" = "1" /* Replacement of Right Posterior Tibial Artery with Autologous Tissue Substitute, Open Approach */
"04RR0JZ" = "1" /* Replacement of Right Posterior Tibial Artery with Synthetic Substitute, Open Approach */
"04RR0KZ" = "1" /* Replacement of Right Posterior Tibial Artery with Nonautologous Tissue Substitute, Open Approach */
"04RR47Z" = "1" /* Replacement of Right Posterior Tibial Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RR4JZ" = "1" /* Replacement of Right Posterior Tibial Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RR4KZ" = "1" /* Replacement of Right Posterior Tibial Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RS07Z" = "1" /* Replacement of Left Posterior Tibial Artery with Autologous Tissue Substitute, Open Approach */
"04RS0JZ" = "1" /* Replacement of Left Posterior Tibial Artery with Synthetic Substitute, Open Approach */
"04RS0KZ" = "1" /* Replacement of Left Posterior Tibial Artery with Nonautologous Tissue Substitute, Open Approach */
"04RS47Z" = "1" /* Replacement of Left Posterior Tibial Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RS4JZ" = "1" /* Replacement of Left Posterior Tibial Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RS4KZ" = "1" /* Replacement of Left Posterior Tibial Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RT07Z" = "1" /* Replacement of Right Peroneal Artery with Autologous Tissue Substitute, Open Approach */
"04RT0JZ" = "1" /* Replacement of Right Peroneal Artery with Synthetic Substitute, Open Approach */
"04RT0KZ" = "1" /* Replacement of Right Peroneal Artery with Nonautologous Tissue Substitute, Open Approach */
"04RT47Z" = "1" /* Replacement of Right Peroneal Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RT4JZ" = "1" /* Replacement of Right Peroneal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RT4KZ" = "1" /* Replacement of Right Peroneal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RU07Z" = "1" /* Replacement of Left Peroneal Artery with Autologous Tissue Substitute, Open Approach */
"04RU0JZ" = "1" /* Replacement of Left Peroneal Artery with Synthetic Substitute, Open Approach */
"04RU0KZ" = "1" /* Replacement of Left Peroneal Artery with Nonautologous Tissue Substitute, Open Approach */
"04RU47Z" = "1" /* Replacement of Left Peroneal Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RU4JZ" = "1" /* Replacement of Left Peroneal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RU4KZ" = "1" /* Replacement of Left Peroneal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RV07Z" = "1" /* Replacement of Right Foot Artery with Autologous Tissue Substitute, Open Approach */
"04RV0JZ" = "1" /* Replacement of Right Foot Artery with Synthetic Substitute, Open Approach */
"04RV0KZ" = "1" /* Replacement of Right Foot Artery with Nonautologous Tissue Substitute, Open Approach */
"04RV47Z" = "1" /* Replacement of Right Foot Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RV4JZ" = "1" /* Replacement of Right Foot Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RV4KZ" = "1" /* Replacement of Right Foot Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RW07Z" = "1" /* Replacement of Left Foot Artery with Autologous Tissue Substitute, Open Approach */
"04RW0JZ" = "1" /* Replacement of Left Foot Artery with Synthetic Substitute, Open Approach */
"04RW0KZ" = "1" /* Replacement of Left Foot Artery with Nonautologous Tissue Substitute, Open Approach */
"04RW47Z" = "1" /* Replacement of Left Foot Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RW4JZ" = "1" /* Replacement of Left Foot Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RW4KZ" = "1" /* Replacement of Left Foot Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RY07Z" = "1" /* Replacement of Lower Artery with Autologous Tissue Substitute, Open Approach */
"04RY0JZ" = "1" /* Replacement of Lower Artery with Synthetic Substitute, Open Approach */
"04RY0KZ" = "1" /* Replacement of Lower Artery with Nonautologous Tissue Substitute, Open Approach */
"04RY47Z" = "1" /* Replacement of Lower Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04RY4JZ" = "1" /* Replacement of Lower Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04RY4KZ" = "1" /* Replacement of Lower Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04S00ZZ" = "1" /* Reposition Abdominal Aorta, Open Approach */
"04S03ZZ" = "1" /* Reposition Abdominal Aorta, Percutaneous Approach */
"04S04ZZ" = "1" /* Reposition Abdominal Aorta, Percutaneous Endoscopic Approach */
"04S10ZZ" = "1" /* Reposition Celiac Artery, Open Approach */
"04S13ZZ" = "1" /* Reposition Celiac Artery, Percutaneous Approach */
"04S14ZZ" = "1" /* Reposition Celiac Artery, Percutaneous Endoscopic Approach */
"04S20ZZ" = "1" /* Reposition Gastric Artery, Open Approach */
"04S23ZZ" = "1" /* Reposition Gastric Artery, Percutaneous Approach */
"04S24ZZ" = "1" /* Reposition Gastric Artery, Percutaneous Endoscopic Approach */
"04S30ZZ" = "1" /* Reposition Hepatic Artery, Open Approach */
"04S33ZZ" = "1" /* Reposition Hepatic Artery, Percutaneous Approach */
"04S34ZZ" = "1" /* Reposition Hepatic Artery, Percutaneous Endoscopic Approach */
"04S40ZZ" = "1" /* Reposition Splenic Artery, Open Approach */
"04S43ZZ" = "1" /* Reposition Splenic Artery, Percutaneous Approach */
"04S44ZZ" = "1" /* Reposition Splenic Artery, Percutaneous Endoscopic Approach */
"04S50ZZ" = "1" /* Reposition Superior Mesenteric Artery, Open Approach */
"04S53ZZ" = "1" /* Reposition Superior Mesenteric Artery, Percutaneous Approach */
"04S54ZZ" = "1" /* Reposition Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04S60ZZ" = "1" /* Reposition Right Colic Artery, Open Approach */
"04S63ZZ" = "1" /* Reposition Right Colic Artery, Percutaneous Approach */
"04S64ZZ" = "1" /* Reposition Right Colic Artery, Percutaneous Endoscopic Approach */
"04S70ZZ" = "1" /* Reposition Left Colic Artery, Open Approach */
"04S73ZZ" = "1" /* Reposition Left Colic Artery, Percutaneous Approach */
"04S74ZZ" = "1" /* Reposition Left Colic Artery, Percutaneous Endoscopic Approach */
"04S80ZZ" = "1" /* Reposition Middle Colic Artery, Open Approach */
"04S83ZZ" = "1" /* Reposition Middle Colic Artery, Percutaneous Approach */
"04S84ZZ" = "1" /* Reposition Middle Colic Artery, Percutaneous Endoscopic Approach */
"04S90ZZ" = "1" /* Reposition Right Renal Artery, Open Approach */
"04S93ZZ" = "1" /* Reposition Right Renal Artery, Percutaneous Approach */
"04S94ZZ" = "1" /* Reposition Right Renal Artery, Percutaneous Endoscopic Approach */
"04SA0ZZ" = "1" /* Reposition Left Renal Artery, Open Approach */
"04SA3ZZ" = "1" /* Reposition Left Renal Artery, Percutaneous Approach */
"04SA4ZZ" = "1" /* Reposition Left Renal Artery, Percutaneous Endoscopic Approach */
"04SB0ZZ" = "1" /* Reposition Inferior Mesenteric Artery, Open Approach */
"04SB3ZZ" = "1" /* Reposition Inferior Mesenteric Artery, Percutaneous Approach */
"04SB4ZZ" = "1" /* Reposition Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04SC0ZZ" = "1" /* Reposition Right Common Iliac Artery, Open Approach */
"04SC3ZZ" = "1" /* Reposition Right Common Iliac Artery, Percutaneous Approach */
"04SC4ZZ" = "1" /* Reposition Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"04SD0ZZ" = "1" /* Reposition Left Common Iliac Artery, Open Approach */
"04SD3ZZ" = "1" /* Reposition Left Common Iliac Artery, Percutaneous Approach */
"04SD4ZZ" = "1" /* Reposition Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"04SE0ZZ" = "1" /* Reposition Right Internal Iliac Artery, Open Approach */
"04SE3ZZ" = "1" /* Reposition Right Internal Iliac Artery, Percutaneous Approach */
"04SE4ZZ" = "1" /* Reposition Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04SF0ZZ" = "1" /* Reposition Left Internal Iliac Artery, Open Approach */
"04SF3ZZ" = "1" /* Reposition Left Internal Iliac Artery, Percutaneous Approach */
"04SF4ZZ" = "1" /* Reposition Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04SH0ZZ" = "1" /* Reposition Right External Iliac Artery, Open Approach */
"04SH3ZZ" = "1" /* Reposition Right External Iliac Artery, Percutaneous Approach */
"04SH4ZZ" = "1" /* Reposition Right External Iliac Artery, Percutaneous Endoscopic Approach */
"04SJ0ZZ" = "1" /* Reposition Left External Iliac Artery, Open Approach */
"04SJ3ZZ" = "1" /* Reposition Left External Iliac Artery, Percutaneous Approach */
"04SJ4ZZ" = "1" /* Reposition Left External Iliac Artery, Percutaneous Endoscopic Approach */
"04SK0ZZ" = "1" /* Reposition Right Femoral Artery, Open Approach */
"04SK3ZZ" = "1" /* Reposition Right Femoral Artery, Percutaneous Approach */
"04SK4ZZ" = "1" /* Reposition Right Femoral Artery, Percutaneous Endoscopic Approach */
"04SL0ZZ" = "1" /* Reposition Left Femoral Artery, Open Approach */
"04SL3ZZ" = "1" /* Reposition Left Femoral Artery, Percutaneous Approach */
"04SL4ZZ" = "1" /* Reposition Left Femoral Artery, Percutaneous Endoscopic Approach */
"04SM0ZZ" = "1" /* Reposition Right Popliteal Artery, Open Approach */
"04SM3ZZ" = "1" /* Reposition Right Popliteal Artery, Percutaneous Approach */
"04SM4ZZ" = "1" /* Reposition Right Popliteal Artery, Percutaneous Endoscopic Approach */
"04SN0ZZ" = "1" /* Reposition Left Popliteal Artery, Open Approach */
"04SN3ZZ" = "1" /* Reposition Left Popliteal Artery, Percutaneous Approach */
"04SN4ZZ" = "1" /* Reposition Left Popliteal Artery, Percutaneous Endoscopic Approach */
"04SP0ZZ" = "1" /* Reposition Right Anterior Tibial Artery, Open Approach */
"04SP3ZZ" = "1" /* Reposition Right Anterior Tibial Artery, Percutaneous Approach */
"04SP4ZZ" = "1" /* Reposition Right Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"04SQ0ZZ" = "1" /* Reposition Left Anterior Tibial Artery, Open Approach */
"04SQ3ZZ" = "1" /* Reposition Left Anterior Tibial Artery, Percutaneous Approach */
"04SQ4ZZ" = "1" /* Reposition Left Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"04SR0ZZ" = "1" /* Reposition Right Posterior Tibial Artery, Open Approach */
"04SR3ZZ" = "1" /* Reposition Right Posterior Tibial Artery, Percutaneous Approach */
"04SR4ZZ" = "1" /* Reposition Right Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"04SS0ZZ" = "1" /* Reposition Left Posterior Tibial Artery, Open Approach */
"04SS3ZZ" = "1" /* Reposition Left Posterior Tibial Artery, Percutaneous Approach */
"04SS4ZZ" = "1" /* Reposition Left Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"04ST0ZZ" = "1" /* Reposition Right Peroneal Artery, Open Approach */
"04ST3ZZ" = "1" /* Reposition Right Peroneal Artery, Percutaneous Approach */
"04ST4ZZ" = "1" /* Reposition Right Peroneal Artery, Percutaneous Endoscopic Approach */
"04SU0ZZ" = "1" /* Reposition Left Peroneal Artery, Open Approach */
"04SU3ZZ" = "1" /* Reposition Left Peroneal Artery, Percutaneous Approach */
"04SU4ZZ" = "1" /* Reposition Left Peroneal Artery, Percutaneous Endoscopic Approach */
"04SV0ZZ" = "1" /* Reposition Right Foot Artery, Open Approach */
"04SV3ZZ" = "1" /* Reposition Right Foot Artery, Percutaneous Approach */
"04SV4ZZ" = "1" /* Reposition Right Foot Artery, Percutaneous Endoscopic Approach */
"04SW0ZZ" = "1" /* Reposition Left Foot Artery, Open Approach */
"04SW3ZZ" = "1" /* Reposition Left Foot Artery, Percutaneous Approach */
"04SW4ZZ" = "1" /* Reposition Left Foot Artery, Percutaneous Endoscopic Approach */
"04SY0ZZ" = "1" /* Reposition Lower Artery, Open Approach */
"04SY3ZZ" = "1" /* Reposition Lower Artery, Percutaneous Approach */
"04SY4ZZ" = "1" /* Reposition Lower Artery, Percutaneous Endoscopic Approach */
"04U007Z" = "1" /* Supplement Abdominal Aorta with Autologous Tissue Substitute, Open Approach */
"04U00JZ" = "1" /* Supplement Abdominal Aorta with Synthetic Substitute, Open Approach */
"04U00KZ" = "1" /* Supplement Abdominal Aorta with Nonautologous Tissue Substitute, Open Approach */
"04U037Z" = "1" /* Supplement Abdominal Aorta with Autologous Tissue Substitute, Percutaneous Approach */
"04U03JZ" = "1" /* Supplement Abdominal Aorta with Synthetic Substitute, Percutaneous Approach */
"04U03KZ" = "1" /* Supplement Abdominal Aorta with Nonautologous Tissue Substitute, Percutaneous Approach */
"04U047Z" = "1" /* Supplement Abdominal Aorta with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U04JZ" = "1" /* Supplement Abdominal Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04U04KZ" = "1" /* Supplement Abdominal Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U107Z" = "1" /* Supplement Celiac Artery with Autologous Tissue Substitute, Open Approach */
"04U10JZ" = "1" /* Supplement Celiac Artery with Synthetic Substitute, Open Approach */
"04U10KZ" = "1" /* Supplement Celiac Artery with Nonautologous Tissue Substitute, Open Approach */
"04U137Z" = "1" /* Supplement Celiac Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04U13JZ" = "1" /* Supplement Celiac Artery with Synthetic Substitute, Percutaneous Approach */
"04U13KZ" = "1" /* Supplement Celiac Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04U147Z" = "1" /* Supplement Celiac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U14JZ" = "1" /* Supplement Celiac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04U14KZ" = "1" /* Supplement Celiac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U207Z" = "1" /* Supplement Gastric Artery with Autologous Tissue Substitute, Open Approach */
"04U20JZ" = "1" /* Supplement Gastric Artery with Synthetic Substitute, Open Approach */
"04U20KZ" = "1" /* Supplement Gastric Artery with Nonautologous Tissue Substitute, Open Approach */
"04U237Z" = "1" /* Supplement Gastric Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04U23JZ" = "1" /* Supplement Gastric Artery with Synthetic Substitute, Percutaneous Approach */
"04U23KZ" = "1" /* Supplement Gastric Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04U247Z" = "1" /* Supplement Gastric Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U24JZ" = "1" /* Supplement Gastric Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04U24KZ" = "1" /* Supplement Gastric Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U307Z" = "1" /* Supplement Hepatic Artery with Autologous Tissue Substitute, Open Approach */
"04U30JZ" = "1" /* Supplement Hepatic Artery with Synthetic Substitute, Open Approach */
"04U30KZ" = "1" /* Supplement Hepatic Artery with Nonautologous Tissue Substitute, Open Approach */
"04U337Z" = "1" /* Supplement Hepatic Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04U33JZ" = "1" /* Supplement Hepatic Artery with Synthetic Substitute, Percutaneous Approach */
"04U33KZ" = "1" /* Supplement Hepatic Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04U347Z" = "1" /* Supplement Hepatic Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U34JZ" = "1" /* Supplement Hepatic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04U34KZ" = "1" /* Supplement Hepatic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U407Z" = "1" /* Supplement Splenic Artery with Autologous Tissue Substitute, Open Approach */
"04U40JZ" = "1" /* Supplement Splenic Artery with Synthetic Substitute, Open Approach */
"04U40KZ" = "1" /* Supplement Splenic Artery with Nonautologous Tissue Substitute, Open Approach */
"04U437Z" = "1" /* Supplement Splenic Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04U43JZ" = "1" /* Supplement Splenic Artery with Synthetic Substitute, Percutaneous Approach */
"04U43KZ" = "1" /* Supplement Splenic Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04U447Z" = "1" /* Supplement Splenic Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U44JZ" = "1" /* Supplement Splenic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04U44KZ" = "1" /* Supplement Splenic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U507Z" = "1" /* Supplement Superior Mesenteric Artery with Autologous Tissue Substitute, Open Approach */
"04U50JZ" = "1" /* Supplement Superior Mesenteric Artery with Synthetic Substitute, Open Approach */
"04U50KZ" = "1" /* Supplement Superior Mesenteric Artery with Nonautologous Tissue Substitute, Open Approach */
"04U537Z" = "1" /* Supplement Superior Mesenteric Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04U53JZ" = "1" /* Supplement Superior Mesenteric Artery with Synthetic Substitute, Percutaneous Approach */
"04U53KZ" = "1" /* Supplement Superior Mesenteric Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04U547Z" = "1" /* Supplement Superior Mesenteric Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U54JZ" = "1" /* Supplement Superior Mesenteric Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04U54KZ" = "1" /* Supplement Superior Mesenteric Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U607Z" = "1" /* Supplement Right Colic Artery with Autologous Tissue Substitute, Open Approach */
"04U60JZ" = "1" /* Supplement Right Colic Artery with Synthetic Substitute, Open Approach */
"04U60KZ" = "1" /* Supplement Right Colic Artery with Nonautologous Tissue Substitute, Open Approach */
"04U637Z" = "1" /* Supplement Right Colic Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04U63JZ" = "1" /* Supplement Right Colic Artery with Synthetic Substitute, Percutaneous Approach */
"04U63KZ" = "1" /* Supplement Right Colic Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04U647Z" = "1" /* Supplement Right Colic Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U64JZ" = "1" /* Supplement Right Colic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04U64KZ" = "1" /* Supplement Right Colic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U707Z" = "1" /* Supplement Left Colic Artery with Autologous Tissue Substitute, Open Approach */
"04U70JZ" = "1" /* Supplement Left Colic Artery with Synthetic Substitute, Open Approach */
"04U70KZ" = "1" /* Supplement Left Colic Artery with Nonautologous Tissue Substitute, Open Approach */
"04U737Z" = "1" /* Supplement Left Colic Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04U73JZ" = "1" /* Supplement Left Colic Artery with Synthetic Substitute, Percutaneous Approach */
"04U73KZ" = "1" /* Supplement Left Colic Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04U747Z" = "1" /* Supplement Left Colic Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U74JZ" = "1" /* Supplement Left Colic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04U74KZ" = "1" /* Supplement Left Colic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U807Z" = "1" /* Supplement Middle Colic Artery with Autologous Tissue Substitute, Open Approach */
"04U80JZ" = "1" /* Supplement Middle Colic Artery with Synthetic Substitute, Open Approach */
"04U80KZ" = "1" /* Supplement Middle Colic Artery with Nonautologous Tissue Substitute, Open Approach */
"04U837Z" = "1" /* Supplement Middle Colic Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04U83JZ" = "1" /* Supplement Middle Colic Artery with Synthetic Substitute, Percutaneous Approach */
"04U83KZ" = "1" /* Supplement Middle Colic Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04U847Z" = "1" /* Supplement Middle Colic Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U84JZ" = "1" /* Supplement Middle Colic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04U84KZ" = "1" /* Supplement Middle Colic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U907Z" = "1" /* Supplement Right Renal Artery with Autologous Tissue Substitute, Open Approach */
"04U90JZ" = "1" /* Supplement Right Renal Artery with Synthetic Substitute, Open Approach */
"04U90KZ" = "1" /* Supplement Right Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"04U937Z" = "1" /* Supplement Right Renal Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04U93JZ" = "1" /* Supplement Right Renal Artery with Synthetic Substitute, Percutaneous Approach */
"04U93KZ" = "1" /* Supplement Right Renal Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04U947Z" = "1" /* Supplement Right Renal Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U94JZ" = "1" /* Supplement Right Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04U94KZ" = "1" /* Supplement Right Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UA07Z" = "1" /* Supplement Left Renal Artery with Autologous Tissue Substitute, Open Approach */
"04UA0JZ" = "1" /* Supplement Left Renal Artery with Synthetic Substitute, Open Approach */
"04UA0KZ" = "1" /* Supplement Left Renal Artery with Nonautologous Tissue Substitute, Open Approach */
"04UA37Z" = "1" /* Supplement Left Renal Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UA3JZ" = "1" /* Supplement Left Renal Artery with Synthetic Substitute, Percutaneous Approach */
"04UA3KZ" = "1" /* Supplement Left Renal Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UA47Z" = "1" /* Supplement Left Renal Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UA4JZ" = "1" /* Supplement Left Renal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UA4KZ" = "1" /* Supplement Left Renal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UB07Z" = "1" /* Supplement Inferior Mesenteric Artery with Autologous Tissue Substitute, Open Approach */
"04UB0JZ" = "1" /* Supplement Inferior Mesenteric Artery with Synthetic Substitute, Open Approach */
"04UB0KZ" = "1" /* Supplement Inferior Mesenteric Artery with Nonautologous Tissue Substitute, Open Approach */
"04UB37Z" = "1" /* Supplement Inferior Mesenteric Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UB3JZ" = "1" /* Supplement Inferior Mesenteric Artery with Synthetic Substitute, Percutaneous Approach */
"04UB3KZ" = "1" /* Supplement Inferior Mesenteric Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UB47Z" = "1" /* Supplement Inferior Mesenteric Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UB4JZ" = "1" /* Supplement Inferior Mesenteric Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UB4KZ" = "1" /* Supplement Inferior Mesenteric Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UC07Z" = "1" /* Supplement Right Common Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04UC0JZ" = "1" /* Supplement Right Common Iliac Artery with Synthetic Substitute, Open Approach */
"04UC0KZ" = "1" /* Supplement Right Common Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04UC37Z" = "1" /* Supplement Right Common Iliac Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UC3JZ" = "1" /* Supplement Right Common Iliac Artery with Synthetic Substitute, Percutaneous Approach */
"04UC3KZ" = "1" /* Supplement Right Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UC47Z" = "1" /* Supplement Right Common Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UC4JZ" = "1" /* Supplement Right Common Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UC4KZ" = "1" /* Supplement Right Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UD07Z" = "1" /* Supplement Left Common Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04UD0JZ" = "1" /* Supplement Left Common Iliac Artery with Synthetic Substitute, Open Approach */
"04UD0KZ" = "1" /* Supplement Left Common Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04UD37Z" = "1" /* Supplement Left Common Iliac Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UD3JZ" = "1" /* Supplement Left Common Iliac Artery with Synthetic Substitute, Percutaneous Approach */
"04UD3KZ" = "1" /* Supplement Left Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UD47Z" = "1" /* Supplement Left Common Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UD4JZ" = "1" /* Supplement Left Common Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UD4KZ" = "1" /* Supplement Left Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UE07Z" = "1" /* Supplement Right Internal Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04UE0JZ" = "1" /* Supplement Right Internal Iliac Artery with Synthetic Substitute, Open Approach */
"04UE0KZ" = "1" /* Supplement Right Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04UE37Z" = "1" /* Supplement Right Internal Iliac Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UE3JZ" = "1" /* Supplement Right Internal Iliac Artery with Synthetic Substitute, Percutaneous Approach */
"04UE3KZ" = "1" /* Supplement Right Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UE47Z" = "1" /* Supplement Right Internal Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UE4JZ" = "1" /* Supplement Right Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UE4KZ" = "1" /* Supplement Right Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UF07Z" = "1" /* Supplement Left Internal Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04UF0JZ" = "1" /* Supplement Left Internal Iliac Artery with Synthetic Substitute, Open Approach */
"04UF0KZ" = "1" /* Supplement Left Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04UF37Z" = "1" /* Supplement Left Internal Iliac Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UF3JZ" = "1" /* Supplement Left Internal Iliac Artery with Synthetic Substitute, Percutaneous Approach */
"04UF3KZ" = "1" /* Supplement Left Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UF47Z" = "1" /* Supplement Left Internal Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UF4JZ" = "1" /* Supplement Left Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UF4KZ" = "1" /* Supplement Left Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UH07Z" = "1" /* Supplement Right External Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04UH0JZ" = "1" /* Supplement Right External Iliac Artery with Synthetic Substitute, Open Approach */
"04UH0KZ" = "1" /* Supplement Right External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04UH37Z" = "1" /* Supplement Right External Iliac Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UH3JZ" = "1" /* Supplement Right External Iliac Artery with Synthetic Substitute, Percutaneous Approach */
"04UH3KZ" = "1" /* Supplement Right External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UH47Z" = "1" /* Supplement Right External Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UH4JZ" = "1" /* Supplement Right External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UH4KZ" = "1" /* Supplement Right External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UJ07Z" = "1" /* Supplement Left External Iliac Artery with Autologous Tissue Substitute, Open Approach */
"04UJ0JZ" = "1" /* Supplement Left External Iliac Artery with Synthetic Substitute, Open Approach */
"04UJ0KZ" = "1" /* Supplement Left External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04UJ37Z" = "1" /* Supplement Left External Iliac Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UJ3JZ" = "1" /* Supplement Left External Iliac Artery with Synthetic Substitute, Percutaneous Approach */
"04UJ3KZ" = "1" /* Supplement Left External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UJ47Z" = "1" /* Supplement Left External Iliac Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UJ4JZ" = "1" /* Supplement Left External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UJ4KZ" = "1" /* Supplement Left External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UK07Z" = "1" /* Supplement Right Femoral Artery with Autologous Tissue Substitute, Open Approach */
"04UK0JZ" = "1" /* Supplement Right Femoral Artery with Synthetic Substitute, Open Approach */
"04UK0KZ" = "1" /* Supplement Right Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"04UK37Z" = "1" /* Supplement Right Femoral Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UK3JZ" = "1" /* Supplement Right Femoral Artery with Synthetic Substitute, Percutaneous Approach */
"04UK3KZ" = "1" /* Supplement Right Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UK47Z" = "1" /* Supplement Right Femoral Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UK4JZ" = "1" /* Supplement Right Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UK4KZ" = "1" /* Supplement Right Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UL07Z" = "1" /* Supplement Left Femoral Artery with Autologous Tissue Substitute, Open Approach */
"04UL0JZ" = "1" /* Supplement Left Femoral Artery with Synthetic Substitute, Open Approach */
"04UL0KZ" = "1" /* Supplement Left Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"04UL37Z" = "1" /* Supplement Left Femoral Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UL3JZ" = "1" /* Supplement Left Femoral Artery with Synthetic Substitute, Percutaneous Approach */
"04UL3KZ" = "1" /* Supplement Left Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UL47Z" = "1" /* Supplement Left Femoral Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UL4JZ" = "1" /* Supplement Left Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UL4KZ" = "1" /* Supplement Left Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UM07Z" = "1" /* Supplement Right Popliteal Artery with Autologous Tissue Substitute, Open Approach */
"04UM0JZ" = "1" /* Supplement Right Popliteal Artery with Synthetic Substitute, Open Approach */
"04UM0KZ" = "1" /* Supplement Right Popliteal Artery with Nonautologous Tissue Substitute, Open Approach */
"04UM37Z" = "1" /* Supplement Right Popliteal Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UM3JZ" = "1" /* Supplement Right Popliteal Artery with Synthetic Substitute, Percutaneous Approach */
"04UM3KZ" = "1" /* Supplement Right Popliteal Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UM47Z" = "1" /* Supplement Right Popliteal Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UM4JZ" = "1" /* Supplement Right Popliteal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UM4KZ" = "1" /* Supplement Right Popliteal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UN07Z" = "1" /* Supplement Left Popliteal Artery with Autologous Tissue Substitute, Open Approach */
"04UN0JZ" = "1" /* Supplement Left Popliteal Artery with Synthetic Substitute, Open Approach */
"04UN0KZ" = "1" /* Supplement Left Popliteal Artery with Nonautologous Tissue Substitute, Open Approach */
"04UN37Z" = "1" /* Supplement Left Popliteal Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UN3JZ" = "1" /* Supplement Left Popliteal Artery with Synthetic Substitute, Percutaneous Approach */
"04UN3KZ" = "1" /* Supplement Left Popliteal Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UN47Z" = "1" /* Supplement Left Popliteal Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UN4JZ" = "1" /* Supplement Left Popliteal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UN4KZ" = "1" /* Supplement Left Popliteal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UP07Z" = "1" /* Supplement Right Anterior Tibial Artery with Autologous Tissue Substitute, Open Approach */
"04UP0JZ" = "1" /* Supplement Right Anterior Tibial Artery with Synthetic Substitute, Open Approach */
"04UP0KZ" = "1" /* Supplement Right Anterior Tibial Artery with Nonautologous Tissue Substitute, Open Approach */
"04UP37Z" = "1" /* Supplement Right Anterior Tibial Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UP3JZ" = "1" /* Supplement Right Anterior Tibial Artery with Synthetic Substitute, Percutaneous Approach */
"04UP3KZ" = "1" /* Supplement Right Anterior Tibial Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UP47Z" = "1" /* Supplement Right Anterior Tibial Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UP4JZ" = "1" /* Supplement Right Anterior Tibial Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UP4KZ" = "1" /* Supplement Right Anterior Tibial Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UQ07Z" = "1" /* Supplement Left Anterior Tibial Artery with Autologous Tissue Substitute, Open Approach */
"04UQ0JZ" = "1" /* Supplement Left Anterior Tibial Artery with Synthetic Substitute, Open Approach */
"04UQ0KZ" = "1" /* Supplement Left Anterior Tibial Artery with Nonautologous Tissue Substitute, Open Approach */
"04UQ37Z" = "1" /* Supplement Left Anterior Tibial Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UQ3JZ" = "1" /* Supplement Left Anterior Tibial Artery with Synthetic Substitute, Percutaneous Approach */
"04UQ3KZ" = "1" /* Supplement Left Anterior Tibial Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UQ47Z" = "1" /* Supplement Left Anterior Tibial Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UQ4JZ" = "1" /* Supplement Left Anterior Tibial Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UQ4KZ" = "1" /* Supplement Left Anterior Tibial Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UR07Z" = "1" /* Supplement Right Posterior Tibial Artery with Autologous Tissue Substitute, Open Approach */
"04UR0JZ" = "1" /* Supplement Right Posterior Tibial Artery with Synthetic Substitute, Open Approach */
"04UR0KZ" = "1" /* Supplement Right Posterior Tibial Artery with Nonautologous Tissue Substitute, Open Approach */
"04UR37Z" = "1" /* Supplement Right Posterior Tibial Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UR3JZ" = "1" /* Supplement Right Posterior Tibial Artery with Synthetic Substitute, Percutaneous Approach */
"04UR3KZ" = "1" /* Supplement Right Posterior Tibial Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UR47Z" = "1" /* Supplement Right Posterior Tibial Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UR4JZ" = "1" /* Supplement Right Posterior Tibial Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UR4KZ" = "1" /* Supplement Right Posterior Tibial Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04US07Z" = "1" /* Supplement Left Posterior Tibial Artery with Autologous Tissue Substitute, Open Approach */
"04US0JZ" = "1" /* Supplement Left Posterior Tibial Artery with Synthetic Substitute, Open Approach */
"04US0KZ" = "1" /* Supplement Left Posterior Tibial Artery with Nonautologous Tissue Substitute, Open Approach */
"04US37Z" = "1" /* Supplement Left Posterior Tibial Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04US3JZ" = "1" /* Supplement Left Posterior Tibial Artery with Synthetic Substitute, Percutaneous Approach */
"04US3KZ" = "1" /* Supplement Left Posterior Tibial Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04US47Z" = "1" /* Supplement Left Posterior Tibial Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04US4JZ" = "1" /* Supplement Left Posterior Tibial Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04US4KZ" = "1" /* Supplement Left Posterior Tibial Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UT07Z" = "1" /* Supplement Right Peroneal Artery with Autologous Tissue Substitute, Open Approach */
"04UT0JZ" = "1" /* Supplement Right Peroneal Artery with Synthetic Substitute, Open Approach */
"04UT0KZ" = "1" /* Supplement Right Peroneal Artery with Nonautologous Tissue Substitute, Open Approach */
"04UT37Z" = "1" /* Supplement Right Peroneal Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UT3JZ" = "1" /* Supplement Right Peroneal Artery with Synthetic Substitute, Percutaneous Approach */
"04UT3KZ" = "1" /* Supplement Right Peroneal Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UT47Z" = "1" /* Supplement Right Peroneal Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UT4JZ" = "1" /* Supplement Right Peroneal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UT4KZ" = "1" /* Supplement Right Peroneal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UU07Z" = "1" /* Supplement Left Peroneal Artery with Autologous Tissue Substitute, Open Approach */
"04UU0JZ" = "1" /* Supplement Left Peroneal Artery with Synthetic Substitute, Open Approach */
"04UU0KZ" = "1" /* Supplement Left Peroneal Artery with Nonautologous Tissue Substitute, Open Approach */
"04UU37Z" = "1" /* Supplement Left Peroneal Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UU3JZ" = "1" /* Supplement Left Peroneal Artery with Synthetic Substitute, Percutaneous Approach */
"04UU3KZ" = "1" /* Supplement Left Peroneal Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UU47Z" = "1" /* Supplement Left Peroneal Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UU4JZ" = "1" /* Supplement Left Peroneal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UU4KZ" = "1" /* Supplement Left Peroneal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UV07Z" = "1" /* Supplement Right Foot Artery with Autologous Tissue Substitute, Open Approach */
"04UV0JZ" = "1" /* Supplement Right Foot Artery with Synthetic Substitute, Open Approach */
"04UV0KZ" = "1" /* Supplement Right Foot Artery with Nonautologous Tissue Substitute, Open Approach */
"04UV37Z" = "1" /* Supplement Right Foot Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UV3JZ" = "1" /* Supplement Right Foot Artery with Synthetic Substitute, Percutaneous Approach */
"04UV3KZ" = "1" /* Supplement Right Foot Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UV47Z" = "1" /* Supplement Right Foot Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UV4JZ" = "1" /* Supplement Right Foot Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UV4KZ" = "1" /* Supplement Right Foot Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UW07Z" = "1" /* Supplement Left Foot Artery with Autologous Tissue Substitute, Open Approach */
"04UW0JZ" = "1" /* Supplement Left Foot Artery with Synthetic Substitute, Open Approach */
"04UW0KZ" = "1" /* Supplement Left Foot Artery with Nonautologous Tissue Substitute, Open Approach */
"04UW37Z" = "1" /* Supplement Left Foot Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UW3JZ" = "1" /* Supplement Left Foot Artery with Synthetic Substitute, Percutaneous Approach */
"04UW3KZ" = "1" /* Supplement Left Foot Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UW47Z" = "1" /* Supplement Left Foot Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UW4JZ" = "1" /* Supplement Left Foot Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UW4KZ" = "1" /* Supplement Left Foot Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UY07Z" = "1" /* Supplement Lower Artery with Autologous Tissue Substitute, Open Approach */
"04UY0JZ" = "1" /* Supplement Lower Artery with Synthetic Substitute, Open Approach */
"04UY0KZ" = "1" /* Supplement Lower Artery with Nonautologous Tissue Substitute, Open Approach */
"04UY37Z" = "1" /* Supplement Lower Artery with Autologous Tissue Substitute, Percutaneous Approach */
"04UY3JZ" = "1" /* Supplement Lower Artery with Synthetic Substitute, Percutaneous Approach */
"04UY3KZ" = "1" /* Supplement Lower Artery with Nonautologous Tissue Substitute, Percutaneous Approach */
"04UY47Z" = "1" /* Supplement Lower Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04UY4JZ" = "1" /* Supplement Lower Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04UY4KZ" = "1" /* Supplement Lower Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04V00C6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, with Extraluminal Device, Open Approach */
"04V00CZ" = "1" /* Restriction of Abdominal Aorta with Extraluminal Device, Open Approach */
"04V00D6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, with Intraluminal Device, Open Approach */
"04V00DJ" = "1" /* Restriction of Abdominal Aorta with Intraluminal Device, Temp, Open Approach */
"04V00DZ" = "1" /* Restriction of Abdominal Aorta with Intraluminal Device, Open Approach */
"04V00E6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Open Approach */
"04V00EZ" = "1" /* Restriction of Abdominal Aorta with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Open Approach */
"04V00F6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Open Approach */
"04V00FZ" = "1" /* Restriction of Abdominal Aorta with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Open Approach */
"04V00Z6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, Open Approach */
"04V00ZZ" = "1" /* Restriction of Abdominal Aorta, Open Approach */
"04V03C6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, with Extraluminal Device, Percutaneous Approach */
"04V03CZ" = "1" /* Restriction of Abdominal Aorta with Extraluminal Device, Percutaneous Approach */
"04V03D6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"04V03DJ" = "1" /* Restriction of Abdominal Aorta with Intraluminal Device, Temporary, Percutaneous Approach */
"04V03DZ" = "1" /* Restriction of Abdominal Aorta with Intraluminal Device, Percutaneous Approach */
"04V03E6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Percutaneous Approach */
"04V03EZ" = "1" /* Restriction of Abdominal Aorta with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Percutaneous Approach */
"04V03F6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Percutaneous Approach */
"04V03FZ" = "1" /* Restriction of Abdominal Aorta with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Percutaneous Approach */
"04V03Z6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, Percutaneous Approach */
"04V03ZZ" = "1" /* Restriction of Abdominal Aorta, Percutaneous Approach */
"04V04C6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, with Extraluminal Device, Percutaneous Endoscopic Approach */
"04V04CZ" = "1" /* Restriction of Abdominal Aorta with Extraluminal Device, Percutaneous Endoscopic Approach */
"04V04D6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V04DJ" = "1" /* Restriction of Abdominal Aorta with Intraluminal Device, Temp, Percutaneous Endoscopic Approach */
"04V04DZ" = "1" /* Restriction of Abdominal Aorta with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V04E6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Percutaneous Endoscopic Approach */
"04V04EZ" = "1" /* Restriction of Abdominal Aorta with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Percutaneous Endoscopic Approach */
"04V04F6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Percutaneous Endoscopic Approach */
"04V04FZ" = "1" /* Restriction of Abdominal Aorta with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Percutaneous Endoscopic Approach */
"04V04Z6" = "1" /* Restriction of Abdominal Aorta, Bifurcation, Percutaneous Endoscopic Approach */
"04V04ZZ" = "1" /* Restriction of Abdominal Aorta, Percutaneous Endoscopic Approach */
"04V10CZ" = "1" /* Restriction of Celiac Artery with Extraluminal Device, Open Approach */
"04V10DZ" = "1" /* Restriction of Celiac Artery with Intraluminal Device, Open Approach */
"04V10ZZ" = "1" /* Restriction of Celiac Artery, Open Approach */
"04V13CZ" = "1" /* Restriction of Celiac Artery with Extraluminal Device, Percutaneous Approach */
"04V13DZ" = "1" /* Restriction of Celiac Artery with Intraluminal Device, Percutaneous Approach */
"04V13ZZ" = "1" /* Restriction of Celiac Artery, Percutaneous Approach */
"04V14CZ" = "1" /* Restriction of Celiac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04V14DZ" = "1" /* Restriction of Celiac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V14ZZ" = "1" /* Restriction of Celiac Artery, Percutaneous Endoscopic Approach */
"04V20CZ" = "1" /* Restriction of Gastric Artery with Extraluminal Device, Open Approach */
"04V20DZ" = "1" /* Restriction of Gastric Artery with Intraluminal Device, Open Approach */
"04V20ZZ" = "1" /* Restriction of Gastric Artery, Open Approach */
"04V23CZ" = "1" /* Restriction of Gastric Artery with Extraluminal Device, Percutaneous Approach */
"04V23DZ" = "1" /* Restriction of Gastric Artery with Intraluminal Device, Percutaneous Approach */
"04V23ZZ" = "1" /* Restriction of Gastric Artery, Percutaneous Approach */
"04V24CZ" = "1" /* Restriction of Gastric Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04V24DZ" = "1" /* Restriction of Gastric Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V24ZZ" = "1" /* Restriction of Gastric Artery, Percutaneous Endoscopic Approach */
"04V30CZ" = "1" /* Restriction of Hepatic Artery with Extraluminal Device, Open Approach */
"04V30DZ" = "1" /* Restriction of Hepatic Artery with Intraluminal Device, Open Approach */
"04V30ZZ" = "1" /* Restriction of Hepatic Artery, Open Approach */
"04V33CZ" = "1" /* Restriction of Hepatic Artery with Extraluminal Device, Percutaneous Approach */
"04V33DZ" = "1" /* Restriction of Hepatic Artery with Intraluminal Device, Percutaneous Approach */
"04V33ZZ" = "1" /* Restriction of Hepatic Artery, Percutaneous Approach */
"04V34CZ" = "1" /* Restriction of Hepatic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04V34DZ" = "1" /* Restriction of Hepatic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V34ZZ" = "1" /* Restriction of Hepatic Artery, Percutaneous Endoscopic Approach */
"04V40CZ" = "1" /* Restriction of Splenic Artery with Extraluminal Device, Open Approach */
"04V40DZ" = "1" /* Restriction of Splenic Artery with Intraluminal Device, Open Approach */
"04V40ZZ" = "1" /* Restriction of Splenic Artery, Open Approach */
"04V43CZ" = "1" /* Restriction of Splenic Artery with Extraluminal Device, Percutaneous Approach */
"04V43DZ" = "1" /* Restriction of Splenic Artery with Intraluminal Device, Percutaneous Approach */
"04V43ZZ" = "1" /* Restriction of Splenic Artery, Percutaneous Approach */
"04V44CZ" = "1" /* Restriction of Splenic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04V44DZ" = "1" /* Restriction of Splenic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V44ZZ" = "1" /* Restriction of Splenic Artery, Percutaneous Endoscopic Approach */
"04V50CZ" = "1" /* Restriction of Superior Mesenteric Artery with Extraluminal Device, Open Approach */
"04V50DZ" = "1" /* Restriction of Superior Mesenteric Artery with Intraluminal Device, Open Approach */
"04V50ZZ" = "1" /* Restriction of Superior Mesenteric Artery, Open Approach */
"04V53CZ" = "1" /* Restriction of Superior Mesenteric Artery with Extraluminal Device, Percutaneous Approach */
"04V53DZ" = "1" /* Restriction of Superior Mesenteric Artery with Intraluminal Device, Percutaneous Approach */
"04V53ZZ" = "1" /* Restriction of Superior Mesenteric Artery, Percutaneous Approach */
"04V54CZ" = "1" /* Restriction of Superior Mesenteric Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04V54DZ" = "1" /* Restriction of Superior Mesenteric Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V54ZZ" = "1" /* Restriction of Superior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04V60CZ" = "1" /* Restriction of Right Colic Artery with Extraluminal Device, Open Approach */
"04V60DZ" = "1" /* Restriction of Right Colic Artery with Intraluminal Device, Open Approach */
"04V60ZZ" = "1" /* Restriction of Right Colic Artery, Open Approach */
"04V63CZ" = "1" /* Restriction of Right Colic Artery with Extraluminal Device, Percutaneous Approach */
"04V63DZ" = "1" /* Restriction of Right Colic Artery with Intraluminal Device, Percutaneous Approach */
"04V63ZZ" = "1" /* Restriction of Right Colic Artery, Percutaneous Approach */
"04V64CZ" = "1" /* Restriction of Right Colic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04V64DZ" = "1" /* Restriction of Right Colic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V64ZZ" = "1" /* Restriction of Right Colic Artery, Percutaneous Endoscopic Approach */
"04V70CZ" = "1" /* Restriction of Left Colic Artery with Extraluminal Device, Open Approach */
"04V70DZ" = "1" /* Restriction of Left Colic Artery with Intraluminal Device, Open Approach */
"04V70ZZ" = "1" /* Restriction of Left Colic Artery, Open Approach */
"04V73CZ" = "1" /* Restriction of Left Colic Artery with Extraluminal Device, Percutaneous Approach */
"04V73DZ" = "1" /* Restriction of Left Colic Artery with Intraluminal Device, Percutaneous Approach */
"04V73ZZ" = "1" /* Restriction of Left Colic Artery, Percutaneous Approach */
"04V74CZ" = "1" /* Restriction of Left Colic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04V74DZ" = "1" /* Restriction of Left Colic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V74ZZ" = "1" /* Restriction of Left Colic Artery, Percutaneous Endoscopic Approach */
"04V80CZ" = "1" /* Restriction of Middle Colic Artery with Extraluminal Device, Open Approach */
"04V80DZ" = "1" /* Restriction of Middle Colic Artery with Intraluminal Device, Open Approach */
"04V80ZZ" = "1" /* Restriction of Middle Colic Artery, Open Approach */
"04V83CZ" = "1" /* Restriction of Middle Colic Artery with Extraluminal Device, Percutaneous Approach */
"04V83DZ" = "1" /* Restriction of Middle Colic Artery with Intraluminal Device, Percutaneous Approach */
"04V83ZZ" = "1" /* Restriction of Middle Colic Artery, Percutaneous Approach */
"04V84CZ" = "1" /* Restriction of Middle Colic Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04V84DZ" = "1" /* Restriction of Middle Colic Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V84ZZ" = "1" /* Restriction of Middle Colic Artery, Percutaneous Endoscopic Approach */
"04V90CZ" = "1" /* Restriction of Right Renal Artery with Extraluminal Device, Open Approach */
"04V90DZ" = "1" /* Restriction of Right Renal Artery with Intraluminal Device, Open Approach */
"04V90ZZ" = "1" /* Restriction of Right Renal Artery, Open Approach */
"04V93CZ" = "1" /* Restriction of Right Renal Artery with Extraluminal Device, Percutaneous Approach */
"04V93DZ" = "1" /* Restriction of Right Renal Artery with Intraluminal Device, Percutaneous Approach */
"04V93ZZ" = "1" /* Restriction of Right Renal Artery, Percutaneous Approach */
"04V94CZ" = "1" /* Restriction of Right Renal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04V94DZ" = "1" /* Restriction of Right Renal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V94ZZ" = "1" /* Restriction of Right Renal Artery, Percutaneous Endoscopic Approach */
"04VA0CZ" = "1" /* Restriction of Left Renal Artery with Extraluminal Device, Open Approach */
"04VA0DZ" = "1" /* Restriction of Left Renal Artery with Intraluminal Device, Open Approach */
"04VA0ZZ" = "1" /* Restriction of Left Renal Artery, Open Approach */
"04VA3CZ" = "1" /* Restriction of Left Renal Artery with Extraluminal Device, Percutaneous Approach */
"04VA3DZ" = "1" /* Restriction of Left Renal Artery with Intraluminal Device, Percutaneous Approach */
"04VA3ZZ" = "1" /* Restriction of Left Renal Artery, Percutaneous Approach */
"04VA4CZ" = "1" /* Restriction of Left Renal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VA4DZ" = "1" /* Restriction of Left Renal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VA4ZZ" = "1" /* Restriction of Left Renal Artery, Percutaneous Endoscopic Approach */
"04VB0CZ" = "1" /* Restriction of Inferior Mesenteric Artery with Extraluminal Device, Open Approach */
"04VB0DZ" = "1" /* Restriction of Inferior Mesenteric Artery with Intraluminal Device, Open Approach */
"04VB0ZZ" = "1" /* Restriction of Inferior Mesenteric Artery, Open Approach */
"04VB3CZ" = "1" /* Restriction of Inferior Mesenteric Artery with Extraluminal Device, Percutaneous Approach */
"04VB3DZ" = "1" /* Restriction of Inferior Mesenteric Artery with Intraluminal Device, Percutaneous Approach */
"04VB3ZZ" = "1" /* Restriction of Inferior Mesenteric Artery, Percutaneous Approach */
"04VB4CZ" = "1" /* Restriction of Inferior Mesenteric Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VB4DZ" = "1" /* Restriction of Inferior Mesenteric Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VB4ZZ" = "1" /* Restriction of Inferior Mesenteric Artery, Percutaneous Endoscopic Approach */
"04VC0CZ" = "1" /* Restriction of Right Common Iliac Artery with Extraluminal Device, Open Approach */
"04VC0DZ" = "1" /* Restriction of Right Common Iliac Artery with Intraluminal Device, Open Approach */
"04VC0EZ" = "1" /* Restriction of Right Common Iliac Artery with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Open Approach */
"04VC0FZ" = "1" /* Restriction of Right Common Iliac Artery with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Open Approach */
"04VC0ZZ" = "1" /* Restriction of Right Common Iliac Artery, Open Approach */
"04VC3CZ" = "1" /* Restriction of Right Common Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04VC3DZ" = "1" /* Restriction of Right Common Iliac Artery with Intraluminal Device, Percutaneous Approach */
"04VC3EZ" = "1" /* Restriction of Right Common Iliac Artery with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Percutaneous Approach */
"04VC3FZ" = "1" /* Restriction of Right Common Iliac Artery with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Percutaneous Approach */
"04VC3ZZ" = "1" /* Restriction of Right Common Iliac Artery, Percutaneous Approach */
"04VC4CZ" = "1" /* Restriction of Right Common Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VC4DZ" = "1" /* Restriction of Right Common Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VC4EZ" = "1" /* Restriction of Right Common Iliac Artery with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Percutaneous Endoscopic Approach */
"04VC4FZ" = "1" /* Restriction of Right Common Iliac Artery with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Percutaneous Endoscopic Approach */
"04VC4ZZ" = "1" /* Restriction of Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"04VD0CZ" = "1" /* Restriction of Left Common Iliac Artery with Extraluminal Device, Open Approach */
"04VD0DZ" = "1" /* Restriction of Left Common Iliac Artery with Intraluminal Device, Open Approach */
"04VD0EZ" = "1" /* Restriction of Left Common Iliac Artery with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Open Approach */
"04VD0FZ" = "1" /* Restriction of Left Common Iliac Artery with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Open Approach */
"04VD0ZZ" = "1" /* Restriction of Left Common Iliac Artery, Open Approach */
"04VD3CZ" = "1" /* Restriction of Left Common Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04VD3DZ" = "1" /* Restriction of Left Common Iliac Artery with Intraluminal Device, Percutaneous Approach */
"04VD3EZ" = "1" /* Restriction of Left Common Iliac Artery with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Percutaneous Approach */
"04VD3FZ" = "1" /* Restriction of Left Common Iliac Artery with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Percutaneous Approach */
"04VD3ZZ" = "1" /* Restriction of Left Common Iliac Artery, Percutaneous Approach */
"04VD4CZ" = "1" /* Restriction of Left Common Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VD4DZ" = "1" /* Restriction of Left Common Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VD4EZ" = "1" /* Restriction of Left Common Iliac Artery with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Percutaneous Endoscopic Approach */
"04VD4FZ" = "1" /* Restriction of Left Common Iliac Artery with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Percutaneous Endoscopic Approach */
"04VD4ZZ" = "1" /* Restriction of Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"04VE0CZ" = "1" /* Restriction of Right Internal Iliac Artery with Extraluminal Device, Open Approach */
"04VE0DZ" = "1" /* Restriction of Right Internal Iliac Artery with Intraluminal Device, Open Approach */
"04VE0ZZ" = "1" /* Restriction of Right Internal Iliac Artery, Open Approach */
"04VE3CZ" = "1" /* Restriction of Right Internal Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04VE3DZ" = "1" /* Restriction of Right Internal Iliac Artery with Intraluminal Device, Percutaneous Approach */
"04VE3ZZ" = "1" /* Restriction of Right Internal Iliac Artery, Percutaneous Approach */
"04VE4CZ" = "1" /* Restriction of Right Internal Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VE4DZ" = "1" /* Restriction of Right Internal Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VE4ZZ" = "1" /* Restriction of Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04VF0CZ" = "1" /* Restriction of Left Internal Iliac Artery with Extraluminal Device, Open Approach */
"04VF0DZ" = "1" /* Restriction of Left Internal Iliac Artery with Intraluminal Device, Open Approach */
"04VF0ZZ" = "1" /* Restriction of Left Internal Iliac Artery, Open Approach */
"04VF3CZ" = "1" /* Restriction of Left Internal Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04VF3DZ" = "1" /* Restriction of Left Internal Iliac Artery with Intraluminal Device, Percutaneous Approach */
"04VF3ZZ" = "1" /* Restriction of Left Internal Iliac Artery, Percutaneous Approach */
"04VF4CZ" = "1" /* Restriction of Left Internal Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VF4DZ" = "1" /* Restriction of Left Internal Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VF4ZZ" = "1" /* Restriction of Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04VH0CZ" = "1" /* Restriction of Right External Iliac Artery with Extraluminal Device, Open Approach */
"04VH0DZ" = "1" /* Restriction of Right External Iliac Artery with Intraluminal Device, Open Approach */
"04VH0ZZ" = "1" /* Restriction of Right External Iliac Artery, Open Approach */
"04VH3CZ" = "1" /* Restriction of Right External Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04VH3DZ" = "1" /* Restriction of Right External Iliac Artery with Intraluminal Device, Percutaneous Approach */
"04VH3ZZ" = "1" /* Restriction of Right External Iliac Artery, Percutaneous Approach */
"04VH4CZ" = "1" /* Restriction of Right External Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VH4DZ" = "1" /* Restriction of Right External Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VH4ZZ" = "1" /* Restriction of Right External Iliac Artery, Percutaneous Endoscopic Approach */
"04VJ0CZ" = "1" /* Restriction of Left External Iliac Artery with Extraluminal Device, Open Approach */
"04VJ0DZ" = "1" /* Restriction of Left External Iliac Artery with Intraluminal Device, Open Approach */
"04VJ0ZZ" = "1" /* Restriction of Left External Iliac Artery, Open Approach */
"04VJ3CZ" = "1" /* Restriction of Left External Iliac Artery with Extraluminal Device, Percutaneous Approach */
"04VJ3DZ" = "1" /* Restriction of Left External Iliac Artery with Intraluminal Device, Percutaneous Approach */
"04VJ3ZZ" = "1" /* Restriction of Left External Iliac Artery, Percutaneous Approach */
"04VJ4CZ" = "1" /* Restriction of Left External Iliac Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VJ4DZ" = "1" /* Restriction of Left External Iliac Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VJ4ZZ" = "1" /* Restriction of Left External Iliac Artery, Percutaneous Endoscopic Approach */
"04VK0CZ" = "1" /* Restriction of Right Femoral Artery with Extraluminal Device, Open Approach */
"04VK0DZ" = "1" /* Restriction of Right Femoral Artery with Intraluminal Device, Open Approach */
"04VK0ZZ" = "1" /* Restriction of Right Femoral Artery, Open Approach */
"04VK3CZ" = "1" /* Restriction of Right Femoral Artery with Extraluminal Device, Percutaneous Approach */
"04VK3DZ" = "1" /* Restriction of Right Femoral Artery with Intraluminal Device, Percutaneous Approach */
"04VK3ZZ" = "1" /* Restriction of Right Femoral Artery, Percutaneous Approach */
"04VK4CZ" = "1" /* Restriction of Right Femoral Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VK4DZ" = "1" /* Restriction of Right Femoral Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VK4ZZ" = "1" /* Restriction of Right Femoral Artery, Percutaneous Endoscopic Approach */
"04VL0CZ" = "1" /* Restriction of Left Femoral Artery with Extraluminal Device, Open Approach */
"04VL0DZ" = "1" /* Restriction of Left Femoral Artery with Intraluminal Device, Open Approach */
"04VL0ZZ" = "1" /* Restriction of Left Femoral Artery, Open Approach */
"04VL3CZ" = "1" /* Restriction of Left Femoral Artery with Extraluminal Device, Percutaneous Approach */
"04VL3DZ" = "1" /* Restriction of Left Femoral Artery with Intraluminal Device, Percutaneous Approach */
"04VL3ZZ" = "1" /* Restriction of Left Femoral Artery, Percutaneous Approach */
"04VL4CZ" = "1" /* Restriction of Left Femoral Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VL4DZ" = "1" /* Restriction of Left Femoral Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VL4ZZ" = "1" /* Restriction of Left Femoral Artery, Percutaneous Endoscopic Approach */
"04VM0CZ" = "1" /* Restriction of Right Popliteal Artery with Extraluminal Device, Open Approach */
"04VM0DZ" = "1" /* Restriction of Right Popliteal Artery with Intraluminal Device, Open Approach */
"04VM0ZZ" = "1" /* Restriction of Right Popliteal Artery, Open Approach */
"04VM3CZ" = "1" /* Restriction of Right Popliteal Artery with Extraluminal Device, Percutaneous Approach */
"04VM3DZ" = "1" /* Restriction of Right Popliteal Artery with Intraluminal Device, Percutaneous Approach */
"04VM3ZZ" = "1" /* Restriction of Right Popliteal Artery, Percutaneous Approach */
"04VM4CZ" = "1" /* Restriction of Right Popliteal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VM4DZ" = "1" /* Restriction of Right Popliteal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VM4ZZ" = "1" /* Restriction of Right Popliteal Artery, Percutaneous Endoscopic Approach */
"04VN0CZ" = "1" /* Restriction of Left Popliteal Artery with Extraluminal Device, Open Approach */
"04VN0DZ" = "1" /* Restriction of Left Popliteal Artery with Intraluminal Device, Open Approach */
"04VN0ZZ" = "1" /* Restriction of Left Popliteal Artery, Open Approach */
"04VN3CZ" = "1" /* Restriction of Left Popliteal Artery with Extraluminal Device, Percutaneous Approach */
"04VN3DZ" = "1" /* Restriction of Left Popliteal Artery with Intraluminal Device, Percutaneous Approach */
"04VN3ZZ" = "1" /* Restriction of Left Popliteal Artery, Percutaneous Approach */
"04VN4CZ" = "1" /* Restriction of Left Popliteal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VN4DZ" = "1" /* Restriction of Left Popliteal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VN4ZZ" = "1" /* Restriction of Left Popliteal Artery, Percutaneous Endoscopic Approach */
"04VP0CZ" = "1" /* Restriction of Right Anterior Tibial Artery with Extraluminal Device, Open Approach */
"04VP0DZ" = "1" /* Restriction of Right Anterior Tibial Artery with Intraluminal Device, Open Approach */
"04VP0ZZ" = "1" /* Restriction of Right Anterior Tibial Artery, Open Approach */
"04VP3CZ" = "1" /* Restriction of Right Anterior Tibial Artery with Extraluminal Device, Percutaneous Approach */
"04VP3DZ" = "1" /* Restriction of Right Anterior Tibial Artery with Intraluminal Device, Percutaneous Approach */
"04VP3ZZ" = "1" /* Restriction of Right Anterior Tibial Artery, Percutaneous Approach */
"04VP4CZ" = "1" /* Restriction of Right Anterior Tibial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VP4DZ" = "1" /* Restriction of Right Anterior Tibial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VP4ZZ" = "1" /* Restriction of Right Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"04VQ0CZ" = "1" /* Restriction of Left Anterior Tibial Artery with Extraluminal Device, Open Approach */
"04VQ0DZ" = "1" /* Restriction of Left Anterior Tibial Artery with Intraluminal Device, Open Approach */
"04VQ0ZZ" = "1" /* Restriction of Left Anterior Tibial Artery, Open Approach */
"04VQ3CZ" = "1" /* Restriction of Left Anterior Tibial Artery with Extraluminal Device, Percutaneous Approach */
"04VQ3DZ" = "1" /* Restriction of Left Anterior Tibial Artery with Intraluminal Device, Percutaneous Approach */
"04VQ3ZZ" = "1" /* Restriction of Left Anterior Tibial Artery, Percutaneous Approach */
"04VQ4CZ" = "1" /* Restriction of Left Anterior Tibial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VQ4DZ" = "1" /* Restriction of Left Anterior Tibial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VQ4ZZ" = "1" /* Restriction of Left Anterior Tibial Artery, Percutaneous Endoscopic Approach */
"04VR0CZ" = "1" /* Restriction of Right Posterior Tibial Artery with Extraluminal Device, Open Approach */
"04VR0DZ" = "1" /* Restriction of Right Posterior Tibial Artery with Intraluminal Device, Open Approach */
"04VR0ZZ" = "1" /* Restriction of Right Posterior Tibial Artery, Open Approach */
"04VR3CZ" = "1" /* Restriction of Right Posterior Tibial Artery with Extraluminal Device, Percutaneous Approach */
"04VR3DZ" = "1" /* Restriction of Right Posterior Tibial Artery with Intraluminal Device, Percutaneous Approach */
"04VR3ZZ" = "1" /* Restriction of Right Posterior Tibial Artery, Percutaneous Approach */
"04VR4CZ" = "1" /* Restriction of Right Posterior Tibial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VR4DZ" = "1" /* Restriction of Right Posterior Tibial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VR4ZZ" = "1" /* Restriction of Right Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"04VS0CZ" = "1" /* Restriction of Left Posterior Tibial Artery with Extraluminal Device, Open Approach */
"04VS0DZ" = "1" /* Restriction of Left Posterior Tibial Artery with Intraluminal Device, Open Approach */
"04VS0ZZ" = "1" /* Restriction of Left Posterior Tibial Artery, Open Approach */
"04VS3CZ" = "1" /* Restriction of Left Posterior Tibial Artery with Extraluminal Device, Percutaneous Approach */
"04VS3DZ" = "1" /* Restriction of Left Posterior Tibial Artery with Intraluminal Device, Percutaneous Approach */
"04VS3ZZ" = "1" /* Restriction of Left Posterior Tibial Artery, Percutaneous Approach */
"04VS4CZ" = "1" /* Restriction of Left Posterior Tibial Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VS4DZ" = "1" /* Restriction of Left Posterior Tibial Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VS4ZZ" = "1" /* Restriction of Left Posterior Tibial Artery, Percutaneous Endoscopic Approach */
"04VT0CZ" = "1" /* Restriction of Right Peroneal Artery with Extraluminal Device, Open Approach */
"04VT0DZ" = "1" /* Restriction of Right Peroneal Artery with Intraluminal Device, Open Approach */
"04VT0ZZ" = "1" /* Restriction of Right Peroneal Artery, Open Approach */
"04VT3CZ" = "1" /* Restriction of Right Peroneal Artery with Extraluminal Device, Percutaneous Approach */
"04VT3DZ" = "1" /* Restriction of Right Peroneal Artery with Intraluminal Device, Percutaneous Approach */
"04VT3ZZ" = "1" /* Restriction of Right Peroneal Artery, Percutaneous Approach */
"04VT4CZ" = "1" /* Restriction of Right Peroneal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VT4DZ" = "1" /* Restriction of Right Peroneal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VT4ZZ" = "1" /* Restriction of Right Peroneal Artery, Percutaneous Endoscopic Approach */
"04VU0CZ" = "1" /* Restriction of Left Peroneal Artery with Extraluminal Device, Open Approach */
"04VU0DZ" = "1" /* Restriction of Left Peroneal Artery with Intraluminal Device, Open Approach */
"04VU0ZZ" = "1" /* Restriction of Left Peroneal Artery, Open Approach */
"04VU3CZ" = "1" /* Restriction of Left Peroneal Artery with Extraluminal Device, Percutaneous Approach */
"04VU3DZ" = "1" /* Restriction of Left Peroneal Artery with Intraluminal Device, Percutaneous Approach */
"04VU3ZZ" = "1" /* Restriction of Left Peroneal Artery, Percutaneous Approach */
"04VU4CZ" = "1" /* Restriction of Left Peroneal Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VU4DZ" = "1" /* Restriction of Left Peroneal Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VU4ZZ" = "1" /* Restriction of Left Peroneal Artery, Percutaneous Endoscopic Approach */
"04VV0CZ" = "1" /* Restriction of Right Foot Artery with Extraluminal Device, Open Approach */
"04VV0DZ" = "1" /* Restriction of Right Foot Artery with Intraluminal Device, Open Approach */
"04VV0ZZ" = "1" /* Restriction of Right Foot Artery, Open Approach */
"04VV3CZ" = "1" /* Restriction of Right Foot Artery with Extraluminal Device, Percutaneous Approach */
"04VV3DZ" = "1" /* Restriction of Right Foot Artery with Intraluminal Device, Percutaneous Approach */
"04VV3ZZ" = "1" /* Restriction of Right Foot Artery, Percutaneous Approach */
"04VV4CZ" = "1" /* Restriction of Right Foot Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VV4DZ" = "1" /* Restriction of Right Foot Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VV4ZZ" = "1" /* Restriction of Right Foot Artery, Percutaneous Endoscopic Approach */
"04VW0CZ" = "1" /* Restriction of Left Foot Artery with Extraluminal Device, Open Approach */
"04VW0DZ" = "1" /* Restriction of Left Foot Artery with Intraluminal Device, Open Approach */
"04VW0ZZ" = "1" /* Restriction of Left Foot Artery, Open Approach */
"04VW3CZ" = "1" /* Restriction of Left Foot Artery with Extraluminal Device, Percutaneous Approach */
"04VW3DZ" = "1" /* Restriction of Left Foot Artery with Intraluminal Device, Percutaneous Approach */
"04VW3ZZ" = "1" /* Restriction of Left Foot Artery, Percutaneous Approach */
"04VW4CZ" = "1" /* Restriction of Left Foot Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VW4DZ" = "1" /* Restriction of Left Foot Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VW4ZZ" = "1" /* Restriction of Left Foot Artery, Percutaneous Endoscopic Approach */
"04VY0CZ" = "1" /* Restriction of Lower Artery with Extraluminal Device, Open Approach */
"04VY0DZ" = "1" /* Restriction of Lower Artery with Intraluminal Device, Open Approach */
"04VY0ZZ" = "1" /* Restriction of Lower Artery, Open Approach */
"04VY3CZ" = "1" /* Restriction of Lower Artery with Extraluminal Device, Percutaneous Approach */
"04VY3DZ" = "1" /* Restriction of Lower Artery with Intraluminal Device, Percutaneous Approach */
"04VY3ZZ" = "1" /* Restriction of Lower Artery, Percutaneous Approach */
"04VY4CZ" = "1" /* Restriction of Lower Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"04VY4DZ" = "1" /* Restriction of Lower Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"04VY4ZZ" = "1" /* Restriction of Lower Artery, Percutaneous Endoscopic Approach */
"04WY00Z" = "1" /* Revision of Drainage Device in Lower Artery, Open Approach */
"04WY02Z" = "1" /* Revision of Monitoring Device in Lower Artery, Open Approach */
"04WY03Z" = "1" /* Revision of Infusion Device in Lower Artery, Open Approach */
"04WY07Z" = "1" /* Revision of Autologous Tissue Substitute in Lower Artery, Open Approach */
"04WY0CZ" = "1" /* Revision of Extraluminal Device in Lower Artery, Open Approach */
"04WY0DZ" = "1" /* Revision of Intraluminal Device in Lower Artery, Open Approach */
"04WY0JZ" = "1" /* Revision of Synthetic Substitute in Lower Artery, Open Approach */
"04WY0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Artery, Open Approach */
"04WY37Z" = "1" /* Revision of Autologous Tissue Substitute in Lower Artery, Percutaneous Approach */
"04WY3CZ" = "1" /* Revision of Extraluminal Device in Lower Artery, Percutaneous Approach */
"04WY3JZ" = "1" /* Revision of Synthetic Substitute in Lower Artery, Percutaneous Approach */
"04WY3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Artery, Percutaneous Approach */
"04WY40Z" = "1" /* Revision of Drainage Device in Lower Artery, Percutaneous Endoscopic Approach */
"04WY42Z" = "1" /* Revision of Monitoring Device in Lower Artery, Percutaneous Endoscopic Approach */
"04WY43Z" = "1" /* Revision of Infusion Device in Lower Artery, Percutaneous Endoscopic Approach */
"04WY47Z" = "1" /* Revision of Autologous Tissue Substitute in Lower Artery, Percutaneous Endoscopic Approach */
"04WY4CZ" = "1" /* Revision of Extraluminal Device in Lower Artery, Percutaneous Endoscopic Approach */
"04WY4DZ" = "1" /* Revision of Intraluminal Device in Lower Artery, Percutaneous Endoscopic Approach */
"04WY4JZ" = "1" /* Revision of Synthetic Substitute in Lower Artery, Percutaneous Endoscopic Approach */
"04WY4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Artery, Percutaneous Endoscopic Approach */
"051007Y" = "1" /* Bypass Azygos Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051009Y" = "1" /* Bypass Azygos Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"05100AY" = "1" /* Bypass Azygos Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"05100JY" = "1" /* Bypass Azygos Vein to Upper Vein with Synthetic Substitute, Open Approach */
"05100KY" = "1" /* Bypass Azygos Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"05100ZY" = "1" /* Bypass Azygos Vein to Upper Vein, Open Approach */
"051047Y" = "1" /* Bypass Azygos Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051049Y" = "1" /* Bypass Azygos Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"05104AY" = "1" /* Bypass Azygos Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"05104JY" = "1" /* Bypass Azygos Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05104KY" = "1" /* Bypass Azygos Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05104ZY" = "1" /* Bypass Azygos Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051107Y" = "1" /* Bypass Hemiazygos Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051109Y" = "1" /* Bypass Hemiazygos Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"05110AY" = "1" /* Bypass Hemiazygos Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"05110JY" = "1" /* Bypass Hemiazygos Vein to Upper Vein with Synthetic Substitute, Open Approach */
"05110KY" = "1" /* Bypass Hemiazygos Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"05110ZY" = "1" /* Bypass Hemiazygos Vein to Upper Vein, Open Approach */
"051147Y" = "1" /* Bypass Hemiazygos Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051149Y" = "1" /* Bypass Hemiazygos Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"05114AY" = "1" /* Bypass Hemiazygos Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"05114JY" = "1" /* Bypass Hemiazygos Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05114KY" = "1" /* Bypass Hemiazygos Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05114ZY" = "1" /* Bypass Hemiazygos Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051307Y" = "1" /* Bypass Right Innominate Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051309Y" = "1" /* Bypass Right Innominate Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"05130AY" = "1" /* Bypass Right Innominate Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"05130JY" = "1" /* Bypass Right Innominate Vein to Upper Vein with Synthetic Substitute, Open Approach */
"05130KY" = "1" /* Bypass Right Innominate Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"05130ZY" = "1" /* Bypass Right Innominate Vein to Upper Vein, Open Approach */
"051347Y" = "1" /* Bypass Right Innominate Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051349Y" = "1" /* Bypass Right Innominate Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"05134AY" = "1" /* Bypass Right Innominate Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"05134JY" = "1" /* Bypass Right Innominate Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05134KY" = "1" /* Bypass Right Innominate Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05134ZY" = "1" /* Bypass Right Innominate Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051407Y" = "1" /* Bypass Left Innominate Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051409Y" = "1" /* Bypass Left Innominate Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"05140AY" = "1" /* Bypass Left Innominate Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"05140JY" = "1" /* Bypass Left Innominate Vein to Upper Vein with Synthetic Substitute, Open Approach */
"05140KY" = "1" /* Bypass Left Innominate Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"05140ZY" = "1" /* Bypass Left Innominate Vein to Upper Vein, Open Approach */
"051447Y" = "1" /* Bypass Left Innominate Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051449Y" = "1" /* Bypass Left Innominate Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"05144AY" = "1" /* Bypass Left Innominate Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"05144JY" = "1" /* Bypass Left Innominate Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05144KY" = "1" /* Bypass Left Innominate Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05144ZY" = "1" /* Bypass Left Innominate Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051507Y" = "1" /* Bypass Right Subclavian Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051509Y" = "1" /* Bypass Right Subclavian Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"05150AY" = "1" /* Bypass Right Subclavian Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"05150JY" = "1" /* Bypass Right Subclavian Vein to Upper Vein with Synthetic Substitute, Open Approach */
"05150KY" = "1" /* Bypass Right Subclavian Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"05150ZY" = "1" /* Bypass Right Subclavian Vein to Upper Vein, Open Approach */
"051547Y" = "1" /* Bypass Right Subclavian Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051549Y" = "1" /* Bypass Right Subclavian Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"05154AY" = "1" /* Bypass Right Subclavian Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"05154JY" = "1" /* Bypass Right Subclavian Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05154KY" = "1" /* Bypass Right Subclavian Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05154ZY" = "1" /* Bypass Right Subclavian Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051607Y" = "1" /* Bypass Left Subclavian Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051609Y" = "1" /* Bypass Left Subclavian Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"05160AY" = "1" /* Bypass Left Subclavian Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"05160JY" = "1" /* Bypass Left Subclavian Vein to Upper Vein with Synthetic Substitute, Open Approach */
"05160KY" = "1" /* Bypass Left Subclavian Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"05160ZY" = "1" /* Bypass Left Subclavian Vein to Upper Vein, Open Approach */
"051647Y" = "1" /* Bypass Left Subclavian Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051649Y" = "1" /* Bypass Left Subclavian Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"05164AY" = "1" /* Bypass Left Subclavian Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"05164JY" = "1" /* Bypass Left Subclavian Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05164KY" = "1" /* Bypass Left Subclavian Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05164ZY" = "1" /* Bypass Left Subclavian Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051707Y" = "1" /* Bypass Right Axillary Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051709Y" = "1" /* Bypass Right Axillary Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"05170AY" = "1" /* Bypass Right Axillary Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"05170JY" = "1" /* Bypass Right Axillary Vein to Upper Vein with Synthetic Substitute, Open Approach */
"05170KY" = "1" /* Bypass Right Axillary Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"05170ZY" = "1" /* Bypass Right Axillary Vein to Upper Vein, Open Approach */
"051747Y" = "1" /* Bypass Right Axillary Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051749Y" = "1" /* Bypass Right Axillary Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"05174AY" = "1" /* Bypass Right Axillary Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"05174JY" = "1" /* Bypass Right Axillary Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05174KY" = "1" /* Bypass Right Axillary Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05174ZY" = "1" /* Bypass Right Axillary Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051807Y" = "1" /* Bypass Left Axillary Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051809Y" = "1" /* Bypass Left Axillary Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"05180AY" = "1" /* Bypass Left Axillary Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"05180JY" = "1" /* Bypass Left Axillary Vein to Upper Vein with Synthetic Substitute, Open Approach */
"05180KY" = "1" /* Bypass Left Axillary Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"05180ZY" = "1" /* Bypass Left Axillary Vein to Upper Vein, Open Approach */
"051847Y" = "1" /* Bypass Left Axillary Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051849Y" = "1" /* Bypass Left Axillary Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"05184AY" = "1" /* Bypass Left Axillary Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"05184JY" = "1" /* Bypass Left Axillary Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05184KY" = "1" /* Bypass Left Axillary Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05184ZY" = "1" /* Bypass Left Axillary Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051907Y" = "1" /* Bypass Right Brachial Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051909Y" = "1" /* Bypass Right Brachial Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"05190AY" = "1" /* Bypass Right Brachial Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"05190JY" = "1" /* Bypass Right Brachial Vein to Upper Vein with Synthetic Substitute, Open Approach */
"05190KY" = "1" /* Bypass Right Brachial Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"05190ZY" = "1" /* Bypass Right Brachial Vein to Upper Vein, Open Approach */
"051947Y" = "1" /* Bypass Right Brachial Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051949Y" = "1" /* Bypass Right Brachial Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"05194AY" = "1" /* Bypass Right Brachial Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"05194JY" = "1" /* Bypass Right Brachial Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05194KY" = "1" /* Bypass Right Brachial Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05194ZY" = "1" /* Bypass Right Brachial Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051A07Y" = "1" /* Bypass Left Brachial Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051A09Y" = "1" /* Bypass Left Brachial Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"051A0AY" = "1" /* Bypass Left Brachial Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"051A0JY" = "1" /* Bypass Left Brachial Vein to Upper Vein with Synthetic Substitute, Open Approach */
"051A0KY" = "1" /* Bypass Left Brachial Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"051A0ZY" = "1" /* Bypass Left Brachial Vein to Upper Vein, Open Approach */
"051A47Y" = "1" /* Bypass Left Brachial Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051A49Y" = "1" /* Bypass Left Brachial Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"051A4AY" = "1" /* Bypass Left Brachial Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"051A4JY" = "1" /* Bypass Left Brachial Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"051A4KY" = "1" /* Bypass Left Brachial Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051A4ZY" = "1" /* Bypass Left Brachial Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051B07Y" = "1" /* Bypass Right Basilic Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051B09Y" = "1" /* Bypass Right Basilic Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"051B0AY" = "1" /* Bypass Right Basilic Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"051B0JY" = "1" /* Bypass Right Basilic Vein to Upper Vein with Synthetic Substitute, Open Approach */
"051B0KY" = "1" /* Bypass Right Basilic Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"051B0ZY" = "1" /* Bypass Right Basilic Vein to Upper Vein, Open Approach */
"051B47Y" = "1" /* Bypass Right Basilic Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051B49Y" = "1" /* Bypass Right Basilic Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"051B4AY" = "1" /* Bypass Right Basilic Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"051B4JY" = "1" /* Bypass Right Basilic Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"051B4KY" = "1" /* Bypass Right Basilic Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051B4ZY" = "1" /* Bypass Right Basilic Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051C07Y" = "1" /* Bypass Left Basilic Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051C09Y" = "1" /* Bypass Left Basilic Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"051C0AY" = "1" /* Bypass Left Basilic Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"051C0JY" = "1" /* Bypass Left Basilic Vein to Upper Vein with Synthetic Substitute, Open Approach */
"051C0KY" = "1" /* Bypass Left Basilic Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"051C0ZY" = "1" /* Bypass Left Basilic Vein to Upper Vein, Open Approach */
"051C47Y" = "1" /* Bypass Left Basilic Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051C49Y" = "1" /* Bypass Left Basilic Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"051C4AY" = "1" /* Bypass Left Basilic Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"051C4JY" = "1" /* Bypass Left Basilic Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"051C4KY" = "1" /* Bypass Left Basilic Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051C4ZY" = "1" /* Bypass Left Basilic Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051D07Y" = "1" /* Bypass Right Cephalic Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051D09Y" = "1" /* Bypass Right Cephalic Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"051D0AY" = "1" /* Bypass Right Cephalic Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"051D0JY" = "1" /* Bypass Right Cephalic Vein to Upper Vein with Synthetic Substitute, Open Approach */
"051D0KY" = "1" /* Bypass Right Cephalic Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"051D0ZY" = "1" /* Bypass Right Cephalic Vein to Upper Vein, Open Approach */
"051D47Y" = "1" /* Bypass Right Cephalic Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051D49Y" = "1" /* Bypass Right Cephalic Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"051D4AY" = "1" /* Bypass Right Cephalic Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"051D4JY" = "1" /* Bypass Right Cephalic Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"051D4KY" = "1" /* Bypass Right Cephalic Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051D4ZY" = "1" /* Bypass Right Cephalic Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051F07Y" = "1" /* Bypass Left Cephalic Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051F09Y" = "1" /* Bypass Left Cephalic Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"051F0AY" = "1" /* Bypass Left Cephalic Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"051F0JY" = "1" /* Bypass Left Cephalic Vein to Upper Vein with Synthetic Substitute, Open Approach */
"051F0KY" = "1" /* Bypass Left Cephalic Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"051F0ZY" = "1" /* Bypass Left Cephalic Vein to Upper Vein, Open Approach */
"051F47Y" = "1" /* Bypass Left Cephalic Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051F49Y" = "1" /* Bypass Left Cephalic Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"051F4AY" = "1" /* Bypass Left Cephalic Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"051F4JY" = "1" /* Bypass Left Cephalic Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"051F4KY" = "1" /* Bypass Left Cephalic Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051F4ZY" = "1" /* Bypass Left Cephalic Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051G07Y" = "1" /* Bypass Right Hand Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051G09Y" = "1" /* Bypass Right Hand Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"051G0AY" = "1" /* Bypass Right Hand Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"051G0JY" = "1" /* Bypass Right Hand Vein to Upper Vein with Synthetic Substitute, Open Approach */
"051G0KY" = "1" /* Bypass Right Hand Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"051G0ZY" = "1" /* Bypass Right Hand Vein to Upper Vein, Open Approach */
"051G47Y" = "1" /* Bypass Right Hand Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051G49Y" = "1" /* Bypass Right Hand Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"051G4AY" = "1" /* Bypass Right Hand Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"051G4JY" = "1" /* Bypass Right Hand Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"051G4KY" = "1" /* Bypass Right Hand Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051G4ZY" = "1" /* Bypass Right Hand Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051H07Y" = "1" /* Bypass Left Hand Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051H09Y" = "1" /* Bypass Left Hand Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"051H0AY" = "1" /* Bypass Left Hand Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"051H0JY" = "1" /* Bypass Left Hand Vein to Upper Vein with Synthetic Substitute, Open Approach */
"051H0KY" = "1" /* Bypass Left Hand Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"051H0ZY" = "1" /* Bypass Left Hand Vein to Upper Vein, Open Approach */
"051H47Y" = "1" /* Bypass Left Hand Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051H49Y" = "1" /* Bypass Left Hand Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"051H4AY" = "1" /* Bypass Left Hand Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"051H4JY" = "1" /* Bypass Left Hand Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"051H4KY" = "1" /* Bypass Left Hand Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051H4ZY" = "1" /* Bypass Left Hand Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051L07Y" = "1" /* Bypass Intracranial Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051L09Y" = "1" /* Bypass Intracranial Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"051L0AY" = "1" /* Bypass Intracranial Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"051L0JY" = "1" /* Bypass Intracranial Vein to Upper Vein with Synthetic Substitute, Open Approach */
"051L0KY" = "1" /* Bypass Intracranial Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"051L0ZY" = "1" /* Bypass Intracranial Vein to Upper Vein, Open Approach */
"051L47Y" = "1" /* Bypass Intracranial Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051L49Y" = "1" /* Bypass Intracranial Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"051L4AY" = "1" /* Bypass Intracranial Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"051L4JY" = "1" /* Bypass Intracranial Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"051L4KY" = "1" /* Bypass Intracranial Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051L4ZY" = "1" /* Bypass Intracranial Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051M07Y" = "1" /* Bypass Right Internal Jugular Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051M09Y" = "1" /* Bypass Right Internal Jugular Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"051M0AY" = "1" /* Bypass Right Internal Jugular Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"051M0JY" = "1" /* Bypass Right Internal Jugular Vein to Upper Vein with Synthetic Substitute, Open Approach */
"051M0KY" = "1" /* Bypass Right Internal Jugular Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"051M0ZY" = "1" /* Bypass Right Internal Jugular Vein to Upper Vein, Open Approach */
"051M47Y" = "1" /* Bypass Right Internal Jugular Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051M49Y" = "1" /* Bypass Right Internal Jugular Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"051M4AY" = "1" /* Bypass Right Internal Jugular Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"051M4JY" = "1" /* Bypass Right Internal Jugular Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"051M4KY" = "1" /* Bypass Right Internal Jugular Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051M4ZY" = "1" /* Bypass Right Internal Jugular Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051N07Y" = "1" /* Bypass Left Internal Jugular Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051N09Y" = "1" /* Bypass Left Internal Jugular Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"051N0AY" = "1" /* Bypass Left Internal Jugular Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"051N0JY" = "1" /* Bypass Left Internal Jugular Vein to Upper Vein with Synthetic Substitute, Open Approach */
"051N0KY" = "1" /* Bypass Left Internal Jugular Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"051N0ZY" = "1" /* Bypass Left Internal Jugular Vein to Upper Vein, Open Approach */
"051N47Y" = "1" /* Bypass Left Internal Jugular Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051N49Y" = "1" /* Bypass Left Internal Jugular Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"051N4AY" = "1" /* Bypass Left Internal Jugular Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"051N4JY" = "1" /* Bypass Left Internal Jugular Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"051N4KY" = "1" /* Bypass Left Internal Jugular Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051N4ZY" = "1" /* Bypass Left Internal Jugular Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051P07Y" = "1" /* Bypass Right External Jugular Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051P09Y" = "1" /* Bypass Right External Jugular Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"051P0AY" = "1" /* Bypass Right External Jugular Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"051P0JY" = "1" /* Bypass Right External Jugular Vein to Upper Vein with Synthetic Substitute, Open Approach */
"051P0KY" = "1" /* Bypass Right External Jugular Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"051P0ZY" = "1" /* Bypass Right External Jugular Vein to Upper Vein, Open Approach */
"051P47Y" = "1" /* Bypass Right External Jugular Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051P49Y" = "1" /* Bypass Right External Jugular Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"051P4AY" = "1" /* Bypass Right External Jugular Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"051P4JY" = "1" /* Bypass Right External Jugular Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"051P4KY" = "1" /* Bypass Right External Jugular Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051P4ZY" = "1" /* Bypass Right External Jugular Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051Q07Y" = "1" /* Bypass Left External Jugular Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051Q09Y" = "1" /* Bypass Left External Jugular Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"051Q0AY" = "1" /* Bypass Left External Jugular Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"051Q0JY" = "1" /* Bypass Left External Jugular Vein to Upper Vein with Synthetic Substitute, Open Approach */
"051Q0KY" = "1" /* Bypass Left External Jugular Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"051Q0ZY" = "1" /* Bypass Left External Jugular Vein to Upper Vein, Open Approach */
"051Q47Y" = "1" /* Bypass Left External Jugular Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051Q49Y" = "1" /* Bypass Left External Jugular Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"051Q4AY" = "1" /* Bypass Left External Jugular Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"051Q4JY" = "1" /* Bypass Left External Jugular Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"051Q4KY" = "1" /* Bypass Left External Jugular Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051Q4ZY" = "1" /* Bypass Left External Jugular Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051R07Y" = "1" /* Bypass Right Vertebral Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051R09Y" = "1" /* Bypass Right Vertebral Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"051R0AY" = "1" /* Bypass Right Vertebral Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"051R0JY" = "1" /* Bypass Right Vertebral Vein to Upper Vein with Synthetic Substitute, Open Approach */
"051R0KY" = "1" /* Bypass Right Vertebral Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"051R0ZY" = "1" /* Bypass Right Vertebral Vein to Upper Vein, Open Approach */
"051R47Y" = "1" /* Bypass Right Vertebral Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051R49Y" = "1" /* Bypass Right Vertebral Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"051R4AY" = "1" /* Bypass Right Vertebral Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"051R4JY" = "1" /* Bypass Right Vertebral Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"051R4KY" = "1" /* Bypass Right Vertebral Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051R4ZY" = "1" /* Bypass Right Vertebral Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051S07Y" = "1" /* Bypass Left Vertebral Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051S09Y" = "1" /* Bypass Left Vertebral Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"051S0AY" = "1" /* Bypass Left Vertebral Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"051S0JY" = "1" /* Bypass Left Vertebral Vein to Upper Vein with Synthetic Substitute, Open Approach */
"051S0KY" = "1" /* Bypass Left Vertebral Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"051S0ZY" = "1" /* Bypass Left Vertebral Vein to Upper Vein, Open Approach */
"051S47Y" = "1" /* Bypass Left Vertebral Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051S49Y" = "1" /* Bypass Left Vertebral Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"051S4AY" = "1" /* Bypass Left Vertebral Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"051S4JY" = "1" /* Bypass Left Vertebral Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"051S4KY" = "1" /* Bypass Left Vertebral Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051S4ZY" = "1" /* Bypass Left Vertebral Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051T07Y" = "1" /* Bypass Right Face Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051T09Y" = "1" /* Bypass Right Face Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"051T0AY" = "1" /* Bypass Right Face Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"051T0JY" = "1" /* Bypass Right Face Vein to Upper Vein with Synthetic Substitute, Open Approach */
"051T0KY" = "1" /* Bypass Right Face Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"051T0ZY" = "1" /* Bypass Right Face Vein to Upper Vein, Open Approach */
"051T47Y" = "1" /* Bypass Right Face Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051T49Y" = "1" /* Bypass Right Face Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"051T4AY" = "1" /* Bypass Right Face Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"051T4JY" = "1" /* Bypass Right Face Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"051T4KY" = "1" /* Bypass Right Face Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051T4ZY" = "1" /* Bypass Right Face Vein to Upper Vein, Percutaneous Endoscopic Approach */
"051V07Y" = "1" /* Bypass Left Face Vein to Upper Vein with Autologous Tissue Substitute, Open Approach */
"051V09Y" = "1" /* Bypass Left Face Vein to Upper Vein with Autologous Venous Tissue, Open Approach */
"051V0AY" = "1" /* Bypass Left Face Vein to Upper Vein with Autologous Arterial Tissue, Open Approach */
"051V0JY" = "1" /* Bypass Left Face Vein to Upper Vein with Synthetic Substitute, Open Approach */
"051V0KY" = "1" /* Bypass Left Face Vein to Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"051V0ZY" = "1" /* Bypass Left Face Vein to Upper Vein, Open Approach */
"051V47Y" = "1" /* Bypass Left Face Vein to Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051V49Y" = "1" /* Bypass Left Face Vein to Upper Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"051V4AY" = "1" /* Bypass Left Face Vein to Upper Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"051V4JY" = "1" /* Bypass Left Face Vein to Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"051V4KY" = "1" /* Bypass Left Face Vein to Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"051V4ZY" = "1" /* Bypass Left Face Vein to Upper Vein, Percutaneous Endoscopic Approach */
"05500ZZ" = "1" /* Destruction of Azygos Vein, Open Approach */
"05503ZZ" = "1" /* Destruction of Azygos Vein, Percutaneous Approach */
"05504ZZ" = "1" /* Destruction of Azygos Vein, Percutaneous Endoscopic Approach */
"05510ZZ" = "1" /* Destruction of Hemiazygos Vein, Open Approach */
"05513ZZ" = "1" /* Destruction of Hemiazygos Vein, Percutaneous Approach */
"05514ZZ" = "1" /* Destruction of Hemiazygos Vein, Percutaneous Endoscopic Approach */
"05530ZZ" = "1" /* Destruction of Right Innominate Vein, Open Approach */
"05533ZZ" = "1" /* Destruction of Right Innominate Vein, Percutaneous Approach */
"05534ZZ" = "1" /* Destruction of Right Innominate Vein, Percutaneous Endoscopic Approach */
"05540ZZ" = "1" /* Destruction of Left Innominate Vein, Open Approach */
"05543ZZ" = "1" /* Destruction of Left Innominate Vein, Percutaneous Approach */
"05544ZZ" = "1" /* Destruction of Left Innominate Vein, Percutaneous Endoscopic Approach */
"05550ZZ" = "1" /* Destruction of Right Subclavian Vein, Open Approach */
"05553ZZ" = "1" /* Destruction of Right Subclavian Vein, Percutaneous Approach */
"05554ZZ" = "1" /* Destruction of Right Subclavian Vein, Percutaneous Endoscopic Approach */
"05560ZZ" = "1" /* Destruction of Left Subclavian Vein, Open Approach */
"05563ZZ" = "1" /* Destruction of Left Subclavian Vein, Percutaneous Approach */
"05564ZZ" = "1" /* Destruction of Left Subclavian Vein, Percutaneous Endoscopic Approach */
"05570ZZ" = "1" /* Destruction of Right Axillary Vein, Open Approach */
"05573ZZ" = "1" /* Destruction of Right Axillary Vein, Percutaneous Approach */
"05574ZZ" = "1" /* Destruction of Right Axillary Vein, Percutaneous Endoscopic Approach */
"05580ZZ" = "1" /* Destruction of Left Axillary Vein, Open Approach */
"05583ZZ" = "1" /* Destruction of Left Axillary Vein, Percutaneous Approach */
"05584ZZ" = "1" /* Destruction of Left Axillary Vein, Percutaneous Endoscopic Approach */
"05590ZZ" = "1" /* Destruction of Right Brachial Vein, Open Approach */
"05593ZZ" = "1" /* Destruction of Right Brachial Vein, Percutaneous Approach */
"05594ZZ" = "1" /* Destruction of Right Brachial Vein, Percutaneous Endoscopic Approach */
"055A0ZZ" = "1" /* Destruction of Left Brachial Vein, Open Approach */
"055A3ZZ" = "1" /* Destruction of Left Brachial Vein, Percutaneous Approach */
"055A4ZZ" = "1" /* Destruction of Left Brachial Vein, Percutaneous Endoscopic Approach */
"055B0ZZ" = "1" /* Destruction of Right Basilic Vein, Open Approach */
"055B3ZZ" = "1" /* Destruction of Right Basilic Vein, Percutaneous Approach */
"055B4ZZ" = "1" /* Destruction of Right Basilic Vein, Percutaneous Endoscopic Approach */
"055C0ZZ" = "1" /* Destruction of Left Basilic Vein, Open Approach */
"055C3ZZ" = "1" /* Destruction of Left Basilic Vein, Percutaneous Approach */
"055C4ZZ" = "1" /* Destruction of Left Basilic Vein, Percutaneous Endoscopic Approach */
"055D0ZZ" = "1" /* Destruction of Right Cephalic Vein, Open Approach */
"055D3ZZ" = "1" /* Destruction of Right Cephalic Vein, Percutaneous Approach */
"055D4ZZ" = "1" /* Destruction of Right Cephalic Vein, Percutaneous Endoscopic Approach */
"055F0ZZ" = "1" /* Destruction of Left Cephalic Vein, Open Approach */
"055F3ZZ" = "1" /* Destruction of Left Cephalic Vein, Percutaneous Approach */
"055F4ZZ" = "1" /* Destruction of Left Cephalic Vein, Percutaneous Endoscopic Approach */
"055G0ZZ" = "1" /* Destruction of Right Hand Vein, Open Approach */
"055G3ZZ" = "1" /* Destruction of Right Hand Vein, Percutaneous Approach */
"055G4ZZ" = "1" /* Destruction of Right Hand Vein, Percutaneous Endoscopic Approach */
"055H0ZZ" = "1" /* Destruction of Left Hand Vein, Open Approach */
"055H3ZZ" = "1" /* Destruction of Left Hand Vein, Percutaneous Approach */
"055H4ZZ" = "1" /* Destruction of Left Hand Vein, Percutaneous Endoscopic Approach */
"055L0ZZ" = "1" /* Destruction of Intracranial Vein, Open Approach */
"055L3ZZ" = "1" /* Destruction of Intracranial Vein, Percutaneous Approach */
"055L4ZZ" = "1" /* Destruction of Intracranial Vein, Percutaneous Endoscopic Approach */
"055M0ZZ" = "1" /* Destruction of Right Internal Jugular Vein, Open Approach */
"055M3ZZ" = "1" /* Destruction of Right Internal Jugular Vein, Percutaneous Approach */
"055M4ZZ" = "1" /* Destruction of Right Internal Jugular Vein, Percutaneous Endoscopic Approach */
"055N0ZZ" = "1" /* Destruction of Left Internal Jugular Vein, Open Approach */
"055N3ZZ" = "1" /* Destruction of Left Internal Jugular Vein, Percutaneous Approach */
"055N4ZZ" = "1" /* Destruction of Left Internal Jugular Vein, Percutaneous Endoscopic Approach */
"055P0ZZ" = "1" /* Destruction of Right External Jugular Vein, Open Approach */
"055P3ZZ" = "1" /* Destruction of Right External Jugular Vein, Percutaneous Approach */
"055P4ZZ" = "1" /* Destruction of Right External Jugular Vein, Percutaneous Endoscopic Approach */
"055Q0ZZ" = "1" /* Destruction of Left External Jugular Vein, Open Approach */
"055Q3ZZ" = "1" /* Destruction of Left External Jugular Vein, Percutaneous Approach */
"055Q4ZZ" = "1" /* Destruction of Left External Jugular Vein, Percutaneous Endoscopic Approach */
"055R0ZZ" = "1" /* Destruction of Right Vertebral Vein, Open Approach */
"055R3ZZ" = "1" /* Destruction of Right Vertebral Vein, Percutaneous Approach */
"055R4ZZ" = "1" /* Destruction of Right Vertebral Vein, Percutaneous Endoscopic Approach */
"055S0ZZ" = "1" /* Destruction of Left Vertebral Vein, Open Approach */
"055S3ZZ" = "1" /* Destruction of Left Vertebral Vein, Percutaneous Approach */
"055S4ZZ" = "1" /* Destruction of Left Vertebral Vein, Percutaneous Endoscopic Approach */
"055T0ZZ" = "1" /* Destruction of Right Face Vein, Open Approach */
"055T3ZZ" = "1" /* Destruction of Right Face Vein, Percutaneous Approach */
"055T4ZZ" = "1" /* Destruction of Right Face Vein, Percutaneous Endoscopic Approach */
"055V0ZZ" = "1" /* Destruction of Left Face Vein, Open Approach */
"055V3ZZ" = "1" /* Destruction of Left Face Vein, Percutaneous Approach */
"055V4ZZ" = "1" /* Destruction of Left Face Vein, Percutaneous Endoscopic Approach */
"055Y0ZZ" = "1" /* Destruction of Upper Vein, Open Approach */
"055Y3ZZ" = "1" /* Destruction of Upper Vein, Percutaneous Approach */
"055Y4ZZ" = "1" /* Destruction of Upper Vein, Percutaneous Endoscopic Approach */
"05700DZ" = "1" /* Dilation of Azygos Vein with Intraluminal Device, Open Approach */
"05700ZZ" = "1" /* Dilation of Azygos Vein, Open Approach */
"05703DZ" = "1" /* Dilation of Azygos Vein with Intraluminal Device, Percutaneous Approach */
"05703ZZ" = "1" /* Dilation of Azygos Vein, Percutaneous Approach */
"05704DZ" = "1" /* Dilation of Azygos Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05704ZZ" = "1" /* Dilation of Azygos Vein, Percutaneous Endoscopic Approach */
"05710DZ" = "1" /* Dilation of Hemiazygos Vein with Intraluminal Device, Open Approach */
"05710ZZ" = "1" /* Dilation of Hemiazygos Vein, Open Approach */
"05713DZ" = "1" /* Dilation of Hemiazygos Vein with Intraluminal Device, Percutaneous Approach */
"05713ZZ" = "1" /* Dilation of Hemiazygos Vein, Percutaneous Approach */
"05714DZ" = "1" /* Dilation of Hemiazygos Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05714ZZ" = "1" /* Dilation of Hemiazygos Vein, Percutaneous Endoscopic Approach */
"05730DZ" = "1" /* Dilation of Right Innominate Vein with Intraluminal Device, Open Approach */
"05730ZZ" = "1" /* Dilation of Right Innominate Vein, Open Approach */
"05733DZ" = "1" /* Dilation of Right Innominate Vein with Intraluminal Device, Percutaneous Approach */
"05733ZZ" = "1" /* Dilation of Right Innominate Vein, Percutaneous Approach */
"05734DZ" = "1" /* Dilation of Right Innominate Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05734ZZ" = "1" /* Dilation of Right Innominate Vein, Percutaneous Endoscopic Approach */
"05740DZ" = "1" /* Dilation of Left Innominate Vein with Intraluminal Device, Open Approach */
"05740ZZ" = "1" /* Dilation of Left Innominate Vein, Open Approach */
"05743DZ" = "1" /* Dilation of Left Innominate Vein with Intraluminal Device, Percutaneous Approach */
"05743ZZ" = "1" /* Dilation of Left Innominate Vein, Percutaneous Approach */
"05744DZ" = "1" /* Dilation of Left Innominate Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05744ZZ" = "1" /* Dilation of Left Innominate Vein, Percutaneous Endoscopic Approach */
"05750DZ" = "1" /* Dilation of Right Subclavian Vein with Intraluminal Device, Open Approach */
"05750ZZ" = "1" /* Dilation of Right Subclavian Vein, Open Approach */
"05753DZ" = "1" /* Dilation of Right Subclavian Vein with Intraluminal Device, Percutaneous Approach */
"05753ZZ" = "1" /* Dilation of Right Subclavian Vein, Percutaneous Approach */
"05754DZ" = "1" /* Dilation of Right Subclavian Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05754ZZ" = "1" /* Dilation of Right Subclavian Vein, Percutaneous Endoscopic Approach */
"05760DZ" = "1" /* Dilation of Left Subclavian Vein with Intraluminal Device, Open Approach */
"05760ZZ" = "1" /* Dilation of Left Subclavian Vein, Open Approach */
"05763DZ" = "1" /* Dilation of Left Subclavian Vein with Intraluminal Device, Percutaneous Approach */
"05763ZZ" = "1" /* Dilation of Left Subclavian Vein, Percutaneous Approach */
"05764DZ" = "1" /* Dilation of Left Subclavian Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05764ZZ" = "1" /* Dilation of Left Subclavian Vein, Percutaneous Endoscopic Approach */
"05770DZ" = "1" /* Dilation of Right Axillary Vein with Intraluminal Device, Open Approach */
"05770ZZ" = "1" /* Dilation of Right Axillary Vein, Open Approach */
"05773DZ" = "1" /* Dilation of Right Axillary Vein with Intraluminal Device, Percutaneous Approach */
"05773ZZ" = "1" /* Dilation of Right Axillary Vein, Percutaneous Approach */
"05774DZ" = "1" /* Dilation of Right Axillary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05774ZZ" = "1" /* Dilation of Right Axillary Vein, Percutaneous Endoscopic Approach */
"05780DZ" = "1" /* Dilation of Left Axillary Vein with Intraluminal Device, Open Approach */
"05780ZZ" = "1" /* Dilation of Left Axillary Vein, Open Approach */
"05783DZ" = "1" /* Dilation of Left Axillary Vein with Intraluminal Device, Percutaneous Approach */
"05783ZZ" = "1" /* Dilation of Left Axillary Vein, Percutaneous Approach */
"05784DZ" = "1" /* Dilation of Left Axillary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05784ZZ" = "1" /* Dilation of Left Axillary Vein, Percutaneous Endoscopic Approach */
"05790DZ" = "1" /* Dilation of Right Brachial Vein with Intraluminal Device, Open Approach */
"05790ZZ" = "1" /* Dilation of Right Brachial Vein, Open Approach */
"05793DZ" = "1" /* Dilation of Right Brachial Vein with Intraluminal Device, Percutaneous Approach */
"05793ZZ" = "1" /* Dilation of Right Brachial Vein, Percutaneous Approach */
"05794DZ" = "1" /* Dilation of Right Brachial Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05794ZZ" = "1" /* Dilation of Right Brachial Vein, Percutaneous Endoscopic Approach */
"057A0DZ" = "1" /* Dilation of Left Brachial Vein with Intraluminal Device, Open Approach */
"057A0ZZ" = "1" /* Dilation of Left Brachial Vein, Open Approach */
"057A3DZ" = "1" /* Dilation of Left Brachial Vein with Intraluminal Device, Percutaneous Approach */
"057A3ZZ" = "1" /* Dilation of Left Brachial Vein, Percutaneous Approach */
"057A4DZ" = "1" /* Dilation of Left Brachial Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"057A4ZZ" = "1" /* Dilation of Left Brachial Vein, Percutaneous Endoscopic Approach */
"057B0DZ" = "1" /* Dilation of Right Basilic Vein with Intraluminal Device, Open Approach */
"057B0ZZ" = "1" /* Dilation of Right Basilic Vein, Open Approach */
"057B3DZ" = "1" /* Dilation of Right Basilic Vein with Intraluminal Device, Percutaneous Approach */
"057B3ZZ" = "1" /* Dilation of Right Basilic Vein, Percutaneous Approach */
"057B4DZ" = "1" /* Dilation of Right Basilic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"057B4ZZ" = "1" /* Dilation of Right Basilic Vein, Percutaneous Endoscopic Approach */
"057C0DZ" = "1" /* Dilation of Left Basilic Vein with Intraluminal Device, Open Approach */
"057C0ZZ" = "1" /* Dilation of Left Basilic Vein, Open Approach */
"057C3DZ" = "1" /* Dilation of Left Basilic Vein with Intraluminal Device, Percutaneous Approach */
"057C3ZZ" = "1" /* Dilation of Left Basilic Vein, Percutaneous Approach */
"057C4DZ" = "1" /* Dilation of Left Basilic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"057C4ZZ" = "1" /* Dilation of Left Basilic Vein, Percutaneous Endoscopic Approach */
"057D0DZ" = "1" /* Dilation of Right Cephalic Vein with Intraluminal Device, Open Approach */
"057D0ZZ" = "1" /* Dilation of Right Cephalic Vein, Open Approach */
"057D3DZ" = "1" /* Dilation of Right Cephalic Vein with Intraluminal Device, Percutaneous Approach */
"057D3ZZ" = "1" /* Dilation of Right Cephalic Vein, Percutaneous Approach */
"057D4DZ" = "1" /* Dilation of Right Cephalic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"057D4ZZ" = "1" /* Dilation of Right Cephalic Vein, Percutaneous Endoscopic Approach */
"057F0DZ" = "1" /* Dilation of Left Cephalic Vein with Intraluminal Device, Open Approach */
"057F0ZZ" = "1" /* Dilation of Left Cephalic Vein, Open Approach */
"057F3DZ" = "1" /* Dilation of Left Cephalic Vein with Intraluminal Device, Percutaneous Approach */
"057F3ZZ" = "1" /* Dilation of Left Cephalic Vein, Percutaneous Approach */
"057F4DZ" = "1" /* Dilation of Left Cephalic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"057F4ZZ" = "1" /* Dilation of Left Cephalic Vein, Percutaneous Endoscopic Approach */
"057G0DZ" = "1" /* Dilation of Right Hand Vein with Intraluminal Device, Open Approach */
"057G0ZZ" = "1" /* Dilation of Right Hand Vein, Open Approach */
"057G3DZ" = "1" /* Dilation of Right Hand Vein with Intraluminal Device, Percutaneous Approach */
"057G3ZZ" = "1" /* Dilation of Right Hand Vein, Percutaneous Approach */
"057G4DZ" = "1" /* Dilation of Right Hand Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"057G4ZZ" = "1" /* Dilation of Right Hand Vein, Percutaneous Endoscopic Approach */
"057H0DZ" = "1" /* Dilation of Left Hand Vein with Intraluminal Device, Open Approach */
"057H0ZZ" = "1" /* Dilation of Left Hand Vein, Open Approach */
"057H3DZ" = "1" /* Dilation of Left Hand Vein with Intraluminal Device, Percutaneous Approach */
"057H3ZZ" = "1" /* Dilation of Left Hand Vein, Percutaneous Approach */
"057H4DZ" = "1" /* Dilation of Left Hand Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"057H4ZZ" = "1" /* Dilation of Left Hand Vein, Percutaneous Endoscopic Approach */
"057L0DZ" = "1" /* Dilation of Intracranial Vein with Intraluminal Device, Open Approach */
"057L0ZZ" = "1" /* Dilation of Intracranial Vein, Open Approach */
"057L3DZ" = "1" /* Dilation of Intracranial Vein with Intraluminal Device, Percutaneous Approach */
"057L3ZZ" = "1" /* Dilation of Intracranial Vein, Percutaneous Approach */
"057L4DZ" = "1" /* Dilation of Intracranial Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"057L4ZZ" = "1" /* Dilation of Intracranial Vein, Percutaneous Endoscopic Approach */
"057M0DZ" = "1" /* Dilation of Right Internal Jugular Vein with Intraluminal Device, Open Approach */
"057M0ZZ" = "1" /* Dilation of Right Internal Jugular Vein, Open Approach */
"057M3DZ" = "1" /* Dilation of Right Internal Jugular Vein with Intraluminal Device, Percutaneous Approach */
"057M3ZZ" = "1" /* Dilation of Right Internal Jugular Vein, Percutaneous Approach */
"057M4DZ" = "1" /* Dilation of Right Internal Jugular Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"057M4ZZ" = "1" /* Dilation of Right Internal Jugular Vein, Percutaneous Endoscopic Approach */
"057N0DZ" = "1" /* Dilation of Left Internal Jugular Vein with Intraluminal Device, Open Approach */
"057N0ZZ" = "1" /* Dilation of Left Internal Jugular Vein, Open Approach */
"057N3DZ" = "1" /* Dilation of Left Internal Jugular Vein with Intraluminal Device, Percutaneous Approach */
"057N3ZZ" = "1" /* Dilation of Left Internal Jugular Vein, Percutaneous Approach */
"057N4DZ" = "1" /* Dilation of Left Internal Jugular Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"057N4ZZ" = "1" /* Dilation of Left Internal Jugular Vein, Percutaneous Endoscopic Approach */
"057P0DZ" = "1" /* Dilation of Right External Jugular Vein with Intraluminal Device, Open Approach */
"057P0ZZ" = "1" /* Dilation of Right External Jugular Vein, Open Approach */
"057P3DZ" = "1" /* Dilation of Right External Jugular Vein with Intraluminal Device, Percutaneous Approach */
"057P3ZZ" = "1" /* Dilation of Right External Jugular Vein, Percutaneous Approach */
"057P4DZ" = "1" /* Dilation of Right External Jugular Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"057P4ZZ" = "1" /* Dilation of Right External Jugular Vein, Percutaneous Endoscopic Approach */
"057Q0DZ" = "1" /* Dilation of Left External Jugular Vein with Intraluminal Device, Open Approach */
"057Q0ZZ" = "1" /* Dilation of Left External Jugular Vein, Open Approach */
"057Q3DZ" = "1" /* Dilation of Left External Jugular Vein with Intraluminal Device, Percutaneous Approach */
"057Q3ZZ" = "1" /* Dilation of Left External Jugular Vein, Percutaneous Approach */
"057Q4DZ" = "1" /* Dilation of Left External Jugular Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"057Q4ZZ" = "1" /* Dilation of Left External Jugular Vein, Percutaneous Endoscopic Approach */
"057R0DZ" = "1" /* Dilation of Right Vertebral Vein with Intraluminal Device, Open Approach */
"057R0ZZ" = "1" /* Dilation of Right Vertebral Vein, Open Approach */
"057R3DZ" = "1" /* Dilation of Right Vertebral Vein with Intraluminal Device, Percutaneous Approach */
"057R3ZZ" = "1" /* Dilation of Right Vertebral Vein, Percutaneous Approach */
"057R4DZ" = "1" /* Dilation of Right Vertebral Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"057R4ZZ" = "1" /* Dilation of Right Vertebral Vein, Percutaneous Endoscopic Approach */
"057S0DZ" = "1" /* Dilation of Left Vertebral Vein with Intraluminal Device, Open Approach */
"057S0ZZ" = "1" /* Dilation of Left Vertebral Vein, Open Approach */
"057S3DZ" = "1" /* Dilation of Left Vertebral Vein with Intraluminal Device, Percutaneous Approach */
"057S3ZZ" = "1" /* Dilation of Left Vertebral Vein, Percutaneous Approach */
"057S4DZ" = "1" /* Dilation of Left Vertebral Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"057S4ZZ" = "1" /* Dilation of Left Vertebral Vein, Percutaneous Endoscopic Approach */
"057T0DZ" = "1" /* Dilation of Right Face Vein with Intraluminal Device, Open Approach */
"057T0ZZ" = "1" /* Dilation of Right Face Vein, Open Approach */
"057T3DZ" = "1" /* Dilation of Right Face Vein with Intraluminal Device, Percutaneous Approach */
"057T3ZZ" = "1" /* Dilation of Right Face Vein, Percutaneous Approach */
"057T4DZ" = "1" /* Dilation of Right Face Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"057T4ZZ" = "1" /* Dilation of Right Face Vein, Percutaneous Endoscopic Approach */
"057V0DZ" = "1" /* Dilation of Left Face Vein with Intraluminal Device, Open Approach */
"057V0ZZ" = "1" /* Dilation of Left Face Vein, Open Approach */
"057V3DZ" = "1" /* Dilation of Left Face Vein with Intraluminal Device, Percutaneous Approach */
"057V3ZZ" = "1" /* Dilation of Left Face Vein, Percutaneous Approach */
"057V4DZ" = "1" /* Dilation of Left Face Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"057V4ZZ" = "1" /* Dilation of Left Face Vein, Percutaneous Endoscopic Approach */
"057Y0DZ" = "1" /* Dilation of Upper Vein with Intraluminal Device, Open Approach */
"057Y0ZZ" = "1" /* Dilation of Upper Vein, Open Approach */
"057Y3DZ" = "1" /* Dilation of Upper Vein with Intraluminal Device, Percutaneous Approach */
"057Y3ZZ" = "1" /* Dilation of Upper Vein, Percutaneous Approach */
"057Y4DZ" = "1" /* Dilation of Upper Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"057Y4ZZ" = "1" /* Dilation of Upper Vein, Percutaneous Endoscopic Approach */
"05900ZX" = "1" /* Drainage of Azygos Vein, Open Approach, Diagnostic */
"05904ZX" = "1" /* Drainage of Azygos Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05910ZX" = "1" /* Drainage of Hemiazygos Vein, Open Approach, Diagnostic */
"05914ZX" = "1" /* Drainage of Hemiazygos Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05930ZX" = "1" /* Drainage of Right Innominate Vein, Open Approach, Diagnostic */
"05934ZX" = "1" /* Drainage of Right Innominate Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05940ZX" = "1" /* Drainage of Left Innominate Vein, Open Approach, Diagnostic */
"05944ZX" = "1" /* Drainage of Left Innominate Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05950ZX" = "1" /* Drainage of Right Subclavian Vein, Open Approach, Diagnostic */
"05954ZX" = "1" /* Drainage of Right Subclavian Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05960ZX" = "1" /* Drainage of Left Subclavian Vein, Open Approach, Diagnostic */
"05964ZX" = "1" /* Drainage of Left Subclavian Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05970ZX" = "1" /* Drainage of Right Axillary Vein, Open Approach, Diagnostic */
"05974ZX" = "1" /* Drainage of Right Axillary Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05980ZX" = "1" /* Drainage of Left Axillary Vein, Open Approach, Diagnostic */
"05984ZX" = "1" /* Drainage of Left Axillary Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05990ZX" = "1" /* Drainage of Right Brachial Vein, Open Approach, Diagnostic */
"05994ZX" = "1" /* Drainage of Right Brachial Vein, Percutaneous Endoscopic Approach, Diagnostic */
"059A0ZX" = "1" /* Drainage of Left Brachial Vein, Open Approach, Diagnostic */
"059A4ZX" = "1" /* Drainage of Left Brachial Vein, Percutaneous Endoscopic Approach, Diagnostic */
"059B0ZX" = "1" /* Drainage of Right Basilic Vein, Open Approach, Diagnostic */
"059B4ZX" = "1" /* Drainage of Right Basilic Vein, Percutaneous Endoscopic Approach, Diagnostic */
"059C0ZX" = "1" /* Drainage of Left Basilic Vein, Open Approach, Diagnostic */
"059C4ZX" = "1" /* Drainage of Left Basilic Vein, Percutaneous Endoscopic Approach, Diagnostic */
"059D0ZX" = "1" /* Drainage of Right Cephalic Vein, Open Approach, Diagnostic */
"059D4ZX" = "1" /* Drainage of Right Cephalic Vein, Percutaneous Endoscopic Approach, Diagnostic */
"059F0ZX" = "1" /* Drainage of Left Cephalic Vein, Open Approach, Diagnostic */
"059F4ZX" = "1" /* Drainage of Left Cephalic Vein, Percutaneous Endoscopic Approach, Diagnostic */
"059G0ZX" = "1" /* Drainage of Right Hand Vein, Open Approach, Diagnostic */
"059G4ZX" = "1" /* Drainage of Right Hand Vein, Percutaneous Endoscopic Approach, Diagnostic */
"059H0ZX" = "1" /* Drainage of Left Hand Vein, Open Approach, Diagnostic */
"059H4ZX" = "1" /* Drainage of Left Hand Vein, Percutaneous Endoscopic Approach, Diagnostic */
"059L0ZX" = "1" /* Drainage of Intracranial Vein, Open Approach, Diagnostic */
"059L4ZX" = "1" /* Drainage of Intracranial Vein, Percutaneous Endoscopic Approach, Diagnostic */
"059M0ZX" = "1" /* Drainage of Right Internal Jugular Vein, Open Approach, Diagnostic */
"059M4ZX" = "1" /* Drainage of Right Internal Jugular Vein, Percutaneous Endoscopic Approach, Diagnostic */
"059N0ZX" = "1" /* Drainage of Left Internal Jugular Vein, Open Approach, Diagnostic */
"059N4ZX" = "1" /* Drainage of Left Internal Jugular Vein, Percutaneous Endoscopic Approach, Diagnostic */
"059P0ZX" = "1" /* Drainage of Right External Jugular Vein, Open Approach, Diagnostic */
"059P4ZX" = "1" /* Drainage of Right External Jugular Vein, Percutaneous Endoscopic Approach, Diagnostic */
"059Q0ZX" = "1" /* Drainage of Left External Jugular Vein, Open Approach, Diagnostic */
"059Q4ZX" = "1" /* Drainage of Left External Jugular Vein, Percutaneous Endoscopic Approach, Diagnostic */
"059R0ZX" = "1" /* Drainage of Right Vertebral Vein, Open Approach, Diagnostic */
"059R4ZX" = "1" /* Drainage of Right Vertebral Vein, Percutaneous Endoscopic Approach, Diagnostic */
"059S0ZX" = "1" /* Drainage of Left Vertebral Vein, Open Approach, Diagnostic */
"059S4ZX" = "1" /* Drainage of Left Vertebral Vein, Percutaneous Endoscopic Approach, Diagnostic */
"059T0ZX" = "1" /* Drainage of Right Face Vein, Open Approach, Diagnostic */
"059T4ZX" = "1" /* Drainage of Right Face Vein, Percutaneous Endoscopic Approach, Diagnostic */
"059V0ZX" = "1" /* Drainage of Left Face Vein, Open Approach, Diagnostic */
"059V4ZX" = "1" /* Drainage of Left Face Vein, Percutaneous Endoscopic Approach, Diagnostic */
"059Y0ZX" = "1" /* Drainage of Upper Vein, Open Approach, Diagnostic */
"059Y4ZX" = "1" /* Drainage of Upper Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05B00ZX" = "1" /* Excision of Azygos Vein, Open Approach, Diagnostic */
"05B00ZZ" = "1" /* Excision of Azygos Vein, Open Approach */
"05B03ZX" = "1" /* Excision of Azygos Vein, Percutaneous Approach, Diagnostic */
"05B03ZZ" = "1" /* Excision of Azygos Vein, Percutaneous Approach */
"05B04ZX" = "1" /* Excision of Azygos Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05B04ZZ" = "1" /* Excision of Azygos Vein, Percutaneous Endoscopic Approach */
"05B10ZX" = "1" /* Excision of Hemiazygos Vein, Open Approach, Diagnostic */
"05B10ZZ" = "1" /* Excision of Hemiazygos Vein, Open Approach */
"05B13ZX" = "1" /* Excision of Hemiazygos Vein, Percutaneous Approach, Diagnostic */
"05B13ZZ" = "1" /* Excision of Hemiazygos Vein, Percutaneous Approach */
"05B14ZX" = "1" /* Excision of Hemiazygos Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05B14ZZ" = "1" /* Excision of Hemiazygos Vein, Percutaneous Endoscopic Approach */
"05B30ZX" = "1" /* Excision of Right Innominate Vein, Open Approach, Diagnostic */
"05B30ZZ" = "1" /* Excision of Right Innominate Vein, Open Approach */
"05B33ZX" = "1" /* Excision of Right Innominate Vein, Percutaneous Approach, Diagnostic */
"05B33ZZ" = "1" /* Excision of Right Innominate Vein, Percutaneous Approach */
"05B34ZX" = "1" /* Excision of Right Innominate Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05B34ZZ" = "1" /* Excision of Right Innominate Vein, Percutaneous Endoscopic Approach */
"05B40ZX" = "1" /* Excision of Left Innominate Vein, Open Approach, Diagnostic */
"05B40ZZ" = "1" /* Excision of Left Innominate Vein, Open Approach */
"05B43ZX" = "1" /* Excision of Left Innominate Vein, Percutaneous Approach, Diagnostic */
"05B43ZZ" = "1" /* Excision of Left Innominate Vein, Percutaneous Approach */
"05B44ZX" = "1" /* Excision of Left Innominate Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05B44ZZ" = "1" /* Excision of Left Innominate Vein, Percutaneous Endoscopic Approach */
"05B50ZX" = "1" /* Excision of Right Subclavian Vein, Open Approach, Diagnostic */
"05B50ZZ" = "1" /* Excision of Right Subclavian Vein, Open Approach */
"05B53ZX" = "1" /* Excision of Right Subclavian Vein, Percutaneous Approach, Diagnostic */
"05B53ZZ" = "1" /* Excision of Right Subclavian Vein, Percutaneous Approach */
"05B54ZX" = "1" /* Excision of Right Subclavian Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05B54ZZ" = "1" /* Excision of Right Subclavian Vein, Percutaneous Endoscopic Approach */
"05B60ZX" = "1" /* Excision of Left Subclavian Vein, Open Approach, Diagnostic */
"05B60ZZ" = "1" /* Excision of Left Subclavian Vein, Open Approach */
"05B63ZX" = "1" /* Excision of Left Subclavian Vein, Percutaneous Approach, Diagnostic */
"05B63ZZ" = "1" /* Excision of Left Subclavian Vein, Percutaneous Approach */
"05B64ZX" = "1" /* Excision of Left Subclavian Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05B64ZZ" = "1" /* Excision of Left Subclavian Vein, Percutaneous Endoscopic Approach */
"05B70ZX" = "1" /* Excision of Right Axillary Vein, Open Approach, Diagnostic */
"05B70ZZ" = "1" /* Excision of Right Axillary Vein, Open Approach */
"05B73ZX" = "1" /* Excision of Right Axillary Vein, Percutaneous Approach, Diagnostic */
"05B73ZZ" = "1" /* Excision of Right Axillary Vein, Percutaneous Approach */
"05B74ZX" = "1" /* Excision of Right Axillary Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05B74ZZ" = "1" /* Excision of Right Axillary Vein, Percutaneous Endoscopic Approach */
"05B80ZX" = "1" /* Excision of Left Axillary Vein, Open Approach, Diagnostic */
"05B80ZZ" = "1" /* Excision of Left Axillary Vein, Open Approach */
"05B83ZX" = "1" /* Excision of Left Axillary Vein, Percutaneous Approach, Diagnostic */
"05B83ZZ" = "1" /* Excision of Left Axillary Vein, Percutaneous Approach */
"05B84ZX" = "1" /* Excision of Left Axillary Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05B84ZZ" = "1" /* Excision of Left Axillary Vein, Percutaneous Endoscopic Approach */
"05B90ZX" = "1" /* Excision of Right Brachial Vein, Open Approach, Diagnostic */
"05B90ZZ" = "1" /* Excision of Right Brachial Vein, Open Approach */
"05B93ZX" = "1" /* Excision of Right Brachial Vein, Percutaneous Approach, Diagnostic */
"05B93ZZ" = "1" /* Excision of Right Brachial Vein, Percutaneous Approach */
"05B94ZX" = "1" /* Excision of Right Brachial Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05B94ZZ" = "1" /* Excision of Right Brachial Vein, Percutaneous Endoscopic Approach */
"05BA0ZX" = "1" /* Excision of Left Brachial Vein, Open Approach, Diagnostic */
"05BA0ZZ" = "1" /* Excision of Left Brachial Vein, Open Approach */
"05BA3ZX" = "1" /* Excision of Left Brachial Vein, Percutaneous Approach, Diagnostic */
"05BA3ZZ" = "1" /* Excision of Left Brachial Vein, Percutaneous Approach */
"05BA4ZX" = "1" /* Excision of Left Brachial Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05BA4ZZ" = "1" /* Excision of Left Brachial Vein, Percutaneous Endoscopic Approach */
"05BB0ZX" = "1" /* Excision of Right Basilic Vein, Open Approach, Diagnostic */
"05BB0ZZ" = "1" /* Excision of Right Basilic Vein, Open Approach */
"05BB3ZX" = "1" /* Excision of Right Basilic Vein, Percutaneous Approach, Diagnostic */
"05BB3ZZ" = "1" /* Excision of Right Basilic Vein, Percutaneous Approach */
"05BB4ZX" = "1" /* Excision of Right Basilic Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05BB4ZZ" = "1" /* Excision of Right Basilic Vein, Percutaneous Endoscopic Approach */
"05BC0ZX" = "1" /* Excision of Left Basilic Vein, Open Approach, Diagnostic */
"05BC0ZZ" = "1" /* Excision of Left Basilic Vein, Open Approach */
"05BC3ZX" = "1" /* Excision of Left Basilic Vein, Percutaneous Approach, Diagnostic */
"05BC3ZZ" = "1" /* Excision of Left Basilic Vein, Percutaneous Approach */
"05BC4ZX" = "1" /* Excision of Left Basilic Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05BC4ZZ" = "1" /* Excision of Left Basilic Vein, Percutaneous Endoscopic Approach */
"05BD0ZX" = "1" /* Excision of Right Cephalic Vein, Open Approach, Diagnostic */
"05BD0ZZ" = "1" /* Excision of Right Cephalic Vein, Open Approach */
"05BD3ZX" = "1" /* Excision of Right Cephalic Vein, Percutaneous Approach, Diagnostic */
"05BD3ZZ" = "1" /* Excision of Right Cephalic Vein, Percutaneous Approach */
"05BD4ZX" = "1" /* Excision of Right Cephalic Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05BD4ZZ" = "1" /* Excision of Right Cephalic Vein, Percutaneous Endoscopic Approach */
"05BF0ZX" = "1" /* Excision of Left Cephalic Vein, Open Approach, Diagnostic */
"05BF0ZZ" = "1" /* Excision of Left Cephalic Vein, Open Approach */
"05BF3ZX" = "1" /* Excision of Left Cephalic Vein, Percutaneous Approach, Diagnostic */
"05BF3ZZ" = "1" /* Excision of Left Cephalic Vein, Percutaneous Approach */
"05BF4ZX" = "1" /* Excision of Left Cephalic Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05BF4ZZ" = "1" /* Excision of Left Cephalic Vein, Percutaneous Endoscopic Approach */
"05BG0ZX" = "1" /* Excision of Right Hand Vein, Open Approach, Diagnostic */
"05BG0ZZ" = "1" /* Excision of Right Hand Vein, Open Approach */
"05BG3ZX" = "1" /* Excision of Right Hand Vein, Percutaneous Approach, Diagnostic */
"05BG3ZZ" = "1" /* Excision of Right Hand Vein, Percutaneous Approach */
"05BG4ZX" = "1" /* Excision of Right Hand Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05BG4ZZ" = "1" /* Excision of Right Hand Vein, Percutaneous Endoscopic Approach */
"05BH0ZX" = "1" /* Excision of Left Hand Vein, Open Approach, Diagnostic */
"05BH0ZZ" = "1" /* Excision of Left Hand Vein, Open Approach */
"05BH3ZX" = "1" /* Excision of Left Hand Vein, Percutaneous Approach, Diagnostic */
"05BH3ZZ" = "1" /* Excision of Left Hand Vein, Percutaneous Approach */
"05BH4ZX" = "1" /* Excision of Left Hand Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05BH4ZZ" = "1" /* Excision of Left Hand Vein, Percutaneous Endoscopic Approach */
"05BL0ZX" = "1" /* Excision of Intracranial Vein, Open Approach, Diagnostic */
"05BL0ZZ" = "1" /* Excision of Intracranial Vein, Open Approach */
"05BL3ZX" = "1" /* Excision of Intracranial Vein, Percutaneous Approach, Diagnostic */
"05BL3ZZ" = "1" /* Excision of Intracranial Vein, Percutaneous Approach */
"05BL4ZX" = "1" /* Excision of Intracranial Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05BL4ZZ" = "1" /* Excision of Intracranial Vein, Percutaneous Endoscopic Approach */
"05BM0ZX" = "1" /* Excision of Right Internal Jugular Vein, Open Approach, Diagnostic */
"05BM0ZZ" = "1" /* Excision of Right Internal Jugular Vein, Open Approach */
"05BM3ZX" = "1" /* Excision of Right Internal Jugular Vein, Percutaneous Approach, Diagnostic */
"05BM3ZZ" = "1" /* Excision of Right Internal Jugular Vein, Percutaneous Approach */
"05BM4ZX" = "1" /* Excision of Right Internal Jugular Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05BM4ZZ" = "1" /* Excision of Right Internal Jugular Vein, Percutaneous Endoscopic Approach */
"05BN0ZX" = "1" /* Excision of Left Internal Jugular Vein, Open Approach, Diagnostic */
"05BN0ZZ" = "1" /* Excision of Left Internal Jugular Vein, Open Approach */
"05BN3ZX" = "1" /* Excision of Left Internal Jugular Vein, Percutaneous Approach, Diagnostic */
"05BN3ZZ" = "1" /* Excision of Left Internal Jugular Vein, Percutaneous Approach */
"05BN4ZX" = "1" /* Excision of Left Internal Jugular Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05BN4ZZ" = "1" /* Excision of Left Internal Jugular Vein, Percutaneous Endoscopic Approach */
"05BP0ZX" = "1" /* Excision of Right External Jugular Vein, Open Approach, Diagnostic */
"05BP0ZZ" = "1" /* Excision of Right External Jugular Vein, Open Approach */
"05BP3ZX" = "1" /* Excision of Right External Jugular Vein, Percutaneous Approach, Diagnostic */
"05BP3ZZ" = "1" /* Excision of Right External Jugular Vein, Percutaneous Approach */
"05BP4ZX" = "1" /* Excision of Right External Jugular Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05BP4ZZ" = "1" /* Excision of Right External Jugular Vein, Percutaneous Endoscopic Approach */
"05BQ0ZX" = "1" /* Excision of Left External Jugular Vein, Open Approach, Diagnostic */
"05BQ0ZZ" = "1" /* Excision of Left External Jugular Vein, Open Approach */
"05BQ3ZX" = "1" /* Excision of Left External Jugular Vein, Percutaneous Approach, Diagnostic */
"05BQ3ZZ" = "1" /* Excision of Left External Jugular Vein, Percutaneous Approach */
"05BQ4ZX" = "1" /* Excision of Left External Jugular Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05BQ4ZZ" = "1" /* Excision of Left External Jugular Vein, Percutaneous Endoscopic Approach */
"05BR0ZX" = "1" /* Excision of Right Vertebral Vein, Open Approach, Diagnostic */
"05BR0ZZ" = "1" /* Excision of Right Vertebral Vein, Open Approach */
"05BR3ZX" = "1" /* Excision of Right Vertebral Vein, Percutaneous Approach, Diagnostic */
"05BR3ZZ" = "1" /* Excision of Right Vertebral Vein, Percutaneous Approach */
"05BR4ZX" = "1" /* Excision of Right Vertebral Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05BR4ZZ" = "1" /* Excision of Right Vertebral Vein, Percutaneous Endoscopic Approach */
"05BS0ZX" = "1" /* Excision of Left Vertebral Vein, Open Approach, Diagnostic */
"05BS0ZZ" = "1" /* Excision of Left Vertebral Vein, Open Approach */
"05BS3ZX" = "1" /* Excision of Left Vertebral Vein, Percutaneous Approach, Diagnostic */
"05BS3ZZ" = "1" /* Excision of Left Vertebral Vein, Percutaneous Approach */
"05BS4ZX" = "1" /* Excision of Left Vertebral Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05BS4ZZ" = "1" /* Excision of Left Vertebral Vein, Percutaneous Endoscopic Approach */
"05BT0ZX" = "1" /* Excision of Right Face Vein, Open Approach, Diagnostic */
"05BT0ZZ" = "1" /* Excision of Right Face Vein, Open Approach */
"05BT3ZX" = "1" /* Excision of Right Face Vein, Percutaneous Approach, Diagnostic */
"05BT3ZZ" = "1" /* Excision of Right Face Vein, Percutaneous Approach */
"05BT4ZX" = "1" /* Excision of Right Face Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05BT4ZZ" = "1" /* Excision of Right Face Vein, Percutaneous Endoscopic Approach */
"05BV0ZX" = "1" /* Excision of Left Face Vein, Open Approach, Diagnostic */
"05BV0ZZ" = "1" /* Excision of Left Face Vein, Open Approach */
"05BV3ZX" = "1" /* Excision of Left Face Vein, Percutaneous Approach, Diagnostic */
"05BV3ZZ" = "1" /* Excision of Left Face Vein, Percutaneous Approach */
"05BV4ZX" = "1" /* Excision of Left Face Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05BV4ZZ" = "1" /* Excision of Left Face Vein, Percutaneous Endoscopic Approach */
"05BY0ZX" = "1" /* Excision of Upper Vein, Open Approach, Diagnostic */
"05BY0ZZ" = "1" /* Excision of Upper Vein, Open Approach */
"05BY3ZX" = "1" /* Excision of Upper Vein, Percutaneous Approach, Diagnostic */
"05BY3ZZ" = "1" /* Excision of Upper Vein, Percutaneous Approach */
"05BY4ZX" = "1" /* Excision of Upper Vein, Percutaneous Endoscopic Approach, Diagnostic */
"05BY4ZZ" = "1" /* Excision of Upper Vein, Percutaneous Endoscopic Approach */
"05C00ZZ" = "1" /* Extirpation of Matter from Azygos Vein, Open Approach */
"05C03ZZ" = "1" /* Extirpation of Matter from Azygos Vein, Percutaneous Approach */
"05C04ZZ" = "1" /* Extirpation of Matter from Azygos Vein, Percutaneous Endoscopic Approach */
"05C10ZZ" = "1" /* Extirpation of Matter from Hemiazygos Vein, Open Approach */
"05C13ZZ" = "1" /* Extirpation of Matter from Hemiazygos Vein, Percutaneous Approach */
"05C14ZZ" = "1" /* Extirpation of Matter from Hemiazygos Vein, Percutaneous Endoscopic Approach */
"05C30ZZ" = "1" /* Extirpation of Matter from Right Innominate Vein, Open Approach */
"05C33ZZ" = "1" /* Extirpation of Matter from Right Innominate Vein, Percutaneous Approach */
"05C34ZZ" = "1" /* Extirpation of Matter from Right Innominate Vein, Percutaneous Endoscopic Approach */
"05C40ZZ" = "1" /* Extirpation of Matter from Left Innominate Vein, Open Approach */
"05C43ZZ" = "1" /* Extirpation of Matter from Left Innominate Vein, Percutaneous Approach */
"05C44ZZ" = "1" /* Extirpation of Matter from Left Innominate Vein, Percutaneous Endoscopic Approach */
"05C50ZZ" = "1" /* Extirpation of Matter from Right Subclavian Vein, Open Approach */
"05C53ZZ" = "1" /* Extirpation of Matter from Right Subclavian Vein, Percutaneous Approach */
"05C54ZZ" = "1" /* Extirpation of Matter from Right Subclavian Vein, Percutaneous Endoscopic Approach */
"05C60ZZ" = "1" /* Extirpation of Matter from Left Subclavian Vein, Open Approach */
"05C63ZZ" = "1" /* Extirpation of Matter from Left Subclavian Vein, Percutaneous Approach */
"05C64ZZ" = "1" /* Extirpation of Matter from Left Subclavian Vein, Percutaneous Endoscopic Approach */
"05C70ZZ" = "1" /* Extirpation of Matter from Right Axillary Vein, Open Approach */
"05C73ZZ" = "1" /* Extirpation of Matter from Right Axillary Vein, Percutaneous Approach */
"05C74ZZ" = "1" /* Extirpation of Matter from Right Axillary Vein, Percutaneous Endoscopic Approach */
"05C80ZZ" = "1" /* Extirpation of Matter from Left Axillary Vein, Open Approach */
"05C83ZZ" = "1" /* Extirpation of Matter from Left Axillary Vein, Percutaneous Approach */
"05C84ZZ" = "1" /* Extirpation of Matter from Left Axillary Vein, Percutaneous Endoscopic Approach */
"05C90ZZ" = "1" /* Extirpation of Matter from Right Brachial Vein, Open Approach */
"05C93ZZ" = "1" /* Extirpation of Matter from Right Brachial Vein, Percutaneous Approach */
"05C94ZZ" = "1" /* Extirpation of Matter from Right Brachial Vein, Percutaneous Endoscopic Approach */
"05CA0ZZ" = "1" /* Extirpation of Matter from Left Brachial Vein, Open Approach */
"05CA3ZZ" = "1" /* Extirpation of Matter from Left Brachial Vein, Percutaneous Approach */
"05CA4ZZ" = "1" /* Extirpation of Matter from Left Brachial Vein, Percutaneous Endoscopic Approach */
"05CB0ZZ" = "1" /* Extirpation of Matter from Right Basilic Vein, Open Approach */
"05CB3ZZ" = "1" /* Extirpation of Matter from Right Basilic Vein, Percutaneous Approach */
"05CB4ZZ" = "1" /* Extirpation of Matter from Right Basilic Vein, Percutaneous Endoscopic Approach */
"05CC0ZZ" = "1" /* Extirpation of Matter from Left Basilic Vein, Open Approach */
"05CC3ZZ" = "1" /* Extirpation of Matter from Left Basilic Vein, Percutaneous Approach */
"05CC4ZZ" = "1" /* Extirpation of Matter from Left Basilic Vein, Percutaneous Endoscopic Approach */
"05CD0ZZ" = "1" /* Extirpation of Matter from Right Cephalic Vein, Open Approach */
"05CD3ZZ" = "1" /* Extirpation of Matter from Right Cephalic Vein, Percutaneous Approach */
"05CD4ZZ" = "1" /* Extirpation of Matter from Right Cephalic Vein, Percutaneous Endoscopic Approach */
"05CF0ZZ" = "1" /* Extirpation of Matter from Left Cephalic Vein, Open Approach */
"05CF3ZZ" = "1" /* Extirpation of Matter from Left Cephalic Vein, Percutaneous Approach */
"05CF4ZZ" = "1" /* Extirpation of Matter from Left Cephalic Vein, Percutaneous Endoscopic Approach */
"05CG0ZZ" = "1" /* Extirpation of Matter from Right Hand Vein, Open Approach */
"05CG3ZZ" = "1" /* Extirpation of Matter from Right Hand Vein, Percutaneous Approach */
"05CG4ZZ" = "1" /* Extirpation of Matter from Right Hand Vein, Percutaneous Endoscopic Approach */
"05CH0ZZ" = "1" /* Extirpation of Matter from Left Hand Vein, Open Approach */
"05CH3ZZ" = "1" /* Extirpation of Matter from Left Hand Vein, Percutaneous Approach */
"05CH4ZZ" = "1" /* Extirpation of Matter from Left Hand Vein, Percutaneous Endoscopic Approach */
"05CL0ZZ" = "1" /* Extirpation of Matter from Intracranial Vein, Open Approach */
"05CL3ZZ" = "1" /* Extirpation of Matter from Intracranial Vein, Percutaneous Approach */
"05CL4ZZ" = "1" /* Extirpation of Matter from Intracranial Vein, Percutaneous Endoscopic Approach */
"05CM0ZZ" = "1" /* Extirpation of Matter from Right Internal Jugular Vein, Open Approach */
"05CM3ZZ" = "1" /* Extirpation of Matter from Right Internal Jugular Vein, Percutaneous Approach */
"05CM4ZZ" = "1" /* Extirpation of Matter from Right Internal Jugular Vein, Percutaneous Endoscopic Approach */
"05CN0ZZ" = "1" /* Extirpation of Matter from Left Internal Jugular Vein, Open Approach */
"05CN3ZZ" = "1" /* Extirpation of Matter from Left Internal Jugular Vein, Percutaneous Approach */
"05CN4ZZ" = "1" /* Extirpation of Matter from Left Internal Jugular Vein, Percutaneous Endoscopic Approach */
"05CP0ZZ" = "1" /* Extirpation of Matter from Right External Jugular Vein, Open Approach */
"05CP3ZZ" = "1" /* Extirpation of Matter from Right External Jugular Vein, Percutaneous Approach */
"05CP4ZZ" = "1" /* Extirpation of Matter from Right External Jugular Vein, Percutaneous Endoscopic Approach */
"05CQ0ZZ" = "1" /* Extirpation of Matter from Left External Jugular Vein, Open Approach */
"05CQ3ZZ" = "1" /* Extirpation of Matter from Left External Jugular Vein, Percutaneous Approach */
"05CQ4ZZ" = "1" /* Extirpation of Matter from Left External Jugular Vein, Percutaneous Endoscopic Approach */
"05CR0ZZ" = "1" /* Extirpation of Matter from Right Vertebral Vein, Open Approach */
"05CR3ZZ" = "1" /* Extirpation of Matter from Right Vertebral Vein, Percutaneous Approach */
"05CR4ZZ" = "1" /* Extirpation of Matter from Right Vertebral Vein, Percutaneous Endoscopic Approach */
"05CS0ZZ" = "1" /* Extirpation of Matter from Left Vertebral Vein, Open Approach */
"05CS3ZZ" = "1" /* Extirpation of Matter from Left Vertebral Vein, Percutaneous Approach */
"05CS4ZZ" = "1" /* Extirpation of Matter from Left Vertebral Vein, Percutaneous Endoscopic Approach */
"05CT0ZZ" = "1" /* Extirpation of Matter from Right Face Vein, Open Approach */
"05CT3ZZ" = "1" /* Extirpation of Matter from Right Face Vein, Percutaneous Approach */
"05CT4ZZ" = "1" /* Extirpation of Matter from Right Face Vein, Percutaneous Endoscopic Approach */
"05CV0ZZ" = "1" /* Extirpation of Matter from Left Face Vein, Open Approach */
"05CV3ZZ" = "1" /* Extirpation of Matter from Left Face Vein, Percutaneous Approach */
"05CV4ZZ" = "1" /* Extirpation of Matter from Left Face Vein, Percutaneous Endoscopic Approach */
"05CY0ZZ" = "1" /* Extirpation of Matter from Upper Vein, Open Approach */
"05CY3ZZ" = "1" /* Extirpation of Matter from Upper Vein, Percutaneous Approach */
"05CY4ZZ" = "1" /* Extirpation of Matter from Upper Vein, Percutaneous Endoscopic Approach */
"05D90ZZ" = "1" /* Extraction of Right Brachial Vein, Open Approach */
"05D93ZZ" = "1" /* Extraction of Right Brachial Vein, Percutaneous Approach */
"05DA0ZZ" = "1" /* Extraction of Left Brachial Vein, Open Approach */
"05DA3ZZ" = "1" /* Extraction of Left Brachial Vein, Percutaneous Approach */
"05DB0ZZ" = "1" /* Extraction of Right Basilic Vein, Open Approach */
"05DB3ZZ" = "1" /* Extraction of Right Basilic Vein, Percutaneous Approach */
"05DC0ZZ" = "1" /* Extraction of Left Basilic Vein, Open Approach */
"05DC3ZZ" = "1" /* Extraction of Left Basilic Vein, Percutaneous Approach */
"05DD0ZZ" = "1" /* Extraction of Right Cephalic Vein, Open Approach */
"05DD3ZZ" = "1" /* Extraction of Right Cephalic Vein, Percutaneous Approach */
"05DF0ZZ" = "1" /* Extraction of Left Cephalic Vein, Open Approach */
"05DF3ZZ" = "1" /* Extraction of Left Cephalic Vein, Percutaneous Approach */
"05DG0ZZ" = "1" /* Extraction of Right Hand Vein, Open Approach */
"05DG3ZZ" = "1" /* Extraction of Right Hand Vein, Percutaneous Approach */
"05DH0ZZ" = "1" /* Extraction of Left Hand Vein, Open Approach */
"05DH3ZZ" = "1" /* Extraction of Left Hand Vein, Percutaneous Approach */
"05DY0ZZ" = "1" /* Extraction of Upper Vein, Open Approach */
"05DY3ZZ" = "1" /* Extraction of Upper Vein, Percutaneous Approach */
"05H002Z" = "1" /* Insertion of Monitoring Device into Azygos Vein, Open Approach */
"05H00DZ" = "1" /* Insertion of Intraluminal Device into Azygos Vein, Open Approach */
"05H00MZ" = "1" /* Insertion of Neurostimulator Lead into Azygos Vein, Open Approach */
"05H03DZ" = "1" /* Insertion of Intraluminal Device into Azygos Vein, Percutaneous Approach */
"05H042Z" = "1" /* Insertion of Monitoring Device into Azygos Vein, Percutaneous Endoscopic Approach */
"05H04DZ" = "1" /* Insertion of Intraluminal Device into Azygos Vein, Percutaneous Endoscopic Approach */
"05H04MZ" = "1" /* Insertion of Neurostimulator Lead into Azygos Vein, Percutaneous Endoscopic Approach */
"05H10DZ" = "1" /* Insertion of Intraluminal Device into Hemiazygos Vein, Open Approach */
"05H13DZ" = "1" /* Insertion of Intraluminal Device into Hemiazygos Vein, Percutaneous Approach */
"05H14DZ" = "1" /* Insertion of Intraluminal Device into Hemiazygos Vein, Percutaneous Endoscopic Approach */
"05H30DZ" = "1" /* Insertion of Intraluminal Device into Right Innominate Vein, Open Approach */
"05H30MZ" = "1" /* Insertion of Neurostimulator Lead into Right Innominate Vein, Open Approach */
"05H33DZ" = "1" /* Insertion of Intraluminal Device into Right Innominate Vein, Percutaneous Approach */
"05H34DZ" = "1" /* Insertion of Intraluminal Device into Right Innominate Vein, Percutaneous Endoscopic Approach */
"05H34MZ" = "1" /* Insertion of Neurostimulator Lead into Right Innominate Vein, Percutaneous Endoscopic Approach */
"05H40DZ" = "1" /* Insertion of Intraluminal Device into Left Innominate Vein, Open Approach */
"05H40MZ" = "1" /* Insertion of Neurostimulator Lead into Left Innominate Vein, Open Approach */
"05H43DZ" = "1" /* Insertion of Intraluminal Device into Left Innominate Vein, Percutaneous Approach */
"05H44DZ" = "1" /* Insertion of Intraluminal Device into Left Innominate Vein, Percutaneous Endoscopic Approach */
"05H44MZ" = "1" /* Insertion of Neurostimulator Lead into Left Innominate Vein, Percutaneous Endoscopic Approach */
"05H50DZ" = "1" /* Insertion of Intraluminal Device into Right Subclavian Vein, Open Approach */
"05H53DZ" = "1" /* Insertion of Intraluminal Device into Right Subclavian Vein, Percutaneous Approach */
"05H54DZ" = "1" /* Insertion of Intraluminal Device into Right Subclavian Vein, Percutaneous Endoscopic Approach */
"05H60DZ" = "1" /* Insertion of Intraluminal Device into Left Subclavian Vein, Open Approach */
"05H63DZ" = "1" /* Insertion of Intraluminal Device into Left Subclavian Vein, Percutaneous Approach */
"05H64DZ" = "1" /* Insertion of Intraluminal Device into Left Subclavian Vein, Percutaneous Endoscopic Approach */
"05H70DZ" = "1" /* Insertion of Intraluminal Device into Right Axillary Vein, Open Approach */
"05H73DZ" = "1" /* Insertion of Intraluminal Device into Right Axillary Vein, Percutaneous Approach */
"05H74DZ" = "1" /* Insertion of Intraluminal Device into Right Axillary Vein, Percutaneous Endoscopic Approach */
"05H80DZ" = "1" /* Insertion of Intraluminal Device into Left Axillary Vein, Open Approach */
"05H83DZ" = "1" /* Insertion of Intraluminal Device into Left Axillary Vein, Percutaneous Approach */
"05H84DZ" = "1" /* Insertion of Intraluminal Device into Left Axillary Vein, Percutaneous Endoscopic Approach */
"05H90DZ" = "1" /* Insertion of Intraluminal Device into Right Brachial Vein, Open Approach */
"05H93DZ" = "1" /* Insertion of Intraluminal Device into Right Brachial Vein, Percutaneous Approach */
"05H94DZ" = "1" /* Insertion of Intraluminal Device into Right Brachial Vein, Percutaneous Endoscopic Approach */
"05HA0DZ" = "1" /* Insertion of Intraluminal Device into Left Brachial Vein, Open Approach */
"05HA3DZ" = "1" /* Insertion of Intraluminal Device into Left Brachial Vein, Percutaneous Approach */
"05HA4DZ" = "1" /* Insertion of Intraluminal Device into Left Brachial Vein, Percutaneous Endoscopic Approach */
"05HB0DZ" = "1" /* Insertion of Intraluminal Device into Right Basilic Vein, Open Approach */
"05HB3DZ" = "1" /* Insertion of Intraluminal Device into Right Basilic Vein, Percutaneous Approach */
"05HB4DZ" = "1" /* Insertion of Intraluminal Device into Right Basilic Vein, Percutaneous Endoscopic Approach */
"05HC0DZ" = "1" /* Insertion of Intraluminal Device into Left Basilic Vein, Open Approach */
"05HC3DZ" = "1" /* Insertion of Intraluminal Device into Left Basilic Vein, Percutaneous Approach */
"05HC4DZ" = "1" /* Insertion of Intraluminal Device into Left Basilic Vein, Percutaneous Endoscopic Approach */
"05HD0DZ" = "1" /* Insertion of Intraluminal Device into Right Cephalic Vein, Open Approach */
"05HD3DZ" = "1" /* Insertion of Intraluminal Device into Right Cephalic Vein, Percutaneous Approach */
"05HD4DZ" = "1" /* Insertion of Intraluminal Device into Right Cephalic Vein, Percutaneous Endoscopic Approach */
"05HF0DZ" = "1" /* Insertion of Intraluminal Device into Left Cephalic Vein, Open Approach */
"05HF3DZ" = "1" /* Insertion of Intraluminal Device into Left Cephalic Vein, Percutaneous Approach */
"05HF4DZ" = "1" /* Insertion of Intraluminal Device into Left Cephalic Vein, Percutaneous Endoscopic Approach */
"05HG0DZ" = "1" /* Insertion of Intraluminal Device into Right Hand Vein, Open Approach */
"05HG3DZ" = "1" /* Insertion of Intraluminal Device into Right Hand Vein, Percutaneous Approach */
"05HG4DZ" = "1" /* Insertion of Intraluminal Device into Right Hand Vein, Percutaneous Endoscopic Approach */
"05HH0DZ" = "1" /* Insertion of Intraluminal Device into Left Hand Vein, Open Approach */
"05HH3DZ" = "1" /* Insertion of Intraluminal Device into Left Hand Vein, Percutaneous Approach */
"05HH4DZ" = "1" /* Insertion of Intraluminal Device into Left Hand Vein, Percutaneous Endoscopic Approach */
"05HL0DZ" = "1" /* Insertion of Intraluminal Device into Intracranial Vein, Open Approach */
"05HL3DZ" = "1" /* Insertion of Intraluminal Device into Intracranial Vein, Percutaneous Approach */
"05HL4DZ" = "1" /* Insertion of Intraluminal Device into Intracranial Vein, Percutaneous Endoscopic Approach */
"05HM0DZ" = "1" /* Insertion of Intraluminal Device into Right Internal Jugular Vein, Open Approach */
"05HM3DZ" = "1" /* Insertion of Intraluminal Device into Right Internal Jugular Vein, Percutaneous Approach */
"05HM4DZ" = "1" /* Insertion of Intraluminal Device into Right Internal Jugular Vein, Percutaneous Endoscopic Approach */
"05HN0DZ" = "1" /* Insertion of Intraluminal Device into Left Internal Jugular Vein, Open Approach */
"05HN3DZ" = "1" /* Insertion of Intraluminal Device into Left Internal Jugular Vein, Percutaneous Approach */
"05HN4DZ" = "1" /* Insertion of Intraluminal Device into Left Internal Jugular Vein, Percutaneous Endoscopic Approach */
"05HP0DZ" = "1" /* Insertion of Intraluminal Device into Right External Jugular Vein, Open Approach */
"05HP3DZ" = "1" /* Insertion of Intraluminal Device into Right External Jugular Vein, Percutaneous Approach */
"05HP4DZ" = "1" /* Insertion of Intraluminal Device into Right External Jugular Vein, Percutaneous Endoscopic Approach */
"05HQ0DZ" = "1" /* Insertion of Intraluminal Device into Left External Jugular Vein, Open Approach */
"05HQ3DZ" = "1" /* Insertion of Intraluminal Device into Left External Jugular Vein, Percutaneous Approach */
"05HQ4DZ" = "1" /* Insertion of Intraluminal Device into Left External Jugular Vein, Percutaneous Endoscopic Approach */
"05HR0DZ" = "1" /* Insertion of Intraluminal Device into Right Vertebral Vein, Open Approach */
"05HR3DZ" = "1" /* Insertion of Intraluminal Device into Right Vertebral Vein, Percutaneous Approach */
"05HR4DZ" = "1" /* Insertion of Intraluminal Device into Right Vertebral Vein, Percutaneous Endoscopic Approach */
"05HS0DZ" = "1" /* Insertion of Intraluminal Device into Left Vertebral Vein, Open Approach */
"05HS3DZ" = "1" /* Insertion of Intraluminal Device into Left Vertebral Vein, Percutaneous Approach */
"05HS4DZ" = "1" /* Insertion of Intraluminal Device into Left Vertebral Vein, Percutaneous Endoscopic Approach */
"05HT0DZ" = "1" /* Insertion of Intraluminal Device into Right Face Vein, Open Approach */
"05HT3DZ" = "1" /* Insertion of Intraluminal Device into Right Face Vein, Percutaneous Approach */
"05HT4DZ" = "1" /* Insertion of Intraluminal Device into Right Face Vein, Percutaneous Endoscopic Approach */
"05HV0DZ" = "1" /* Insertion of Intraluminal Device into Left Face Vein, Open Approach */
"05HV3DZ" = "1" /* Insertion of Intraluminal Device into Left Face Vein, Percutaneous Approach */
"05HV4DZ" = "1" /* Insertion of Intraluminal Device into Left Face Vein, Percutaneous Endoscopic Approach */
"05HY02Z" = "1" /* Insertion of Monitoring Device into Upper Vein, Open Approach */
"05HY0DZ" = "1" /* Insertion of Intraluminal Device into Upper Vein, Open Approach */
"05HY3DZ" = "1" /* Insertion of Intraluminal Device into Upper Vein, Percutaneous Approach */
"05HY42Z" = "1" /* Insertion of Monitoring Device into Upper Vein, Percutaneous Endoscopic Approach */
"05HY4DZ" = "1" /* Insertion of Intraluminal Device into Upper Vein, Percutaneous Endoscopic Approach */
"05JY0ZZ" = "1" /* Inspection of Upper Vein, Open Approach */
"05JY4ZZ" = "1" /* Inspection of Upper Vein, Percutaneous Endoscopic Approach */
"05L00CZ" = "1" /* Occlusion of Azygos Vein with Extraluminal Device, Open Approach */
"05L00DZ" = "1" /* Occlusion of Azygos Vein with Intraluminal Device, Open Approach */
"05L00ZZ" = "1" /* Occlusion of Azygos Vein, Open Approach */
"05L03CZ" = "1" /* Occlusion of Azygos Vein with Extraluminal Device, Percutaneous Approach */
"05L03DZ" = "1" /* Occlusion of Azygos Vein with Intraluminal Device, Percutaneous Approach */
"05L03ZZ" = "1" /* Occlusion of Azygos Vein, Percutaneous Approach */
"05L04CZ" = "1" /* Occlusion of Azygos Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L04DZ" = "1" /* Occlusion of Azygos Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L04ZZ" = "1" /* Occlusion of Azygos Vein, Percutaneous Endoscopic Approach */
"05L10CZ" = "1" /* Occlusion of Hemiazygos Vein with Extraluminal Device, Open Approach */
"05L10DZ" = "1" /* Occlusion of Hemiazygos Vein with Intraluminal Device, Open Approach */
"05L10ZZ" = "1" /* Occlusion of Hemiazygos Vein, Open Approach */
"05L13CZ" = "1" /* Occlusion of Hemiazygos Vein with Extraluminal Device, Percutaneous Approach */
"05L13DZ" = "1" /* Occlusion of Hemiazygos Vein with Intraluminal Device, Percutaneous Approach */
"05L13ZZ" = "1" /* Occlusion of Hemiazygos Vein, Percutaneous Approach */
"05L14CZ" = "1" /* Occlusion of Hemiazygos Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L14DZ" = "1" /* Occlusion of Hemiazygos Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L14ZZ" = "1" /* Occlusion of Hemiazygos Vein, Percutaneous Endoscopic Approach */
"05L30CZ" = "1" /* Occlusion of Right Innominate Vein with Extraluminal Device, Open Approach */
"05L30DZ" = "1" /* Occlusion of Right Innominate Vein with Intraluminal Device, Open Approach */
"05L30ZZ" = "1" /* Occlusion of Right Innominate Vein, Open Approach */
"05L33CZ" = "1" /* Occlusion of Right Innominate Vein with Extraluminal Device, Percutaneous Approach */
"05L33DZ" = "1" /* Occlusion of Right Innominate Vein with Intraluminal Device, Percutaneous Approach */
"05L33ZZ" = "1" /* Occlusion of Right Innominate Vein, Percutaneous Approach */
"05L34CZ" = "1" /* Occlusion of Right Innominate Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L34DZ" = "1" /* Occlusion of Right Innominate Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L34ZZ" = "1" /* Occlusion of Right Innominate Vein, Percutaneous Endoscopic Approach */
"05L40CZ" = "1" /* Occlusion of Left Innominate Vein with Extraluminal Device, Open Approach */
"05L40DZ" = "1" /* Occlusion of Left Innominate Vein with Intraluminal Device, Open Approach */
"05L40ZZ" = "1" /* Occlusion of Left Innominate Vein, Open Approach */
"05L43CZ" = "1" /* Occlusion of Left Innominate Vein with Extraluminal Device, Percutaneous Approach */
"05L43DZ" = "1" /* Occlusion of Left Innominate Vein with Intraluminal Device, Percutaneous Approach */
"05L43ZZ" = "1" /* Occlusion of Left Innominate Vein, Percutaneous Approach */
"05L44CZ" = "1" /* Occlusion of Left Innominate Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L44DZ" = "1" /* Occlusion of Left Innominate Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L44ZZ" = "1" /* Occlusion of Left Innominate Vein, Percutaneous Endoscopic Approach */
"05L50CZ" = "1" /* Occlusion of Right Subclavian Vein with Extraluminal Device, Open Approach */
"05L50DZ" = "1" /* Occlusion of Right Subclavian Vein with Intraluminal Device, Open Approach */
"05L50ZZ" = "1" /* Occlusion of Right Subclavian Vein, Open Approach */
"05L53CZ" = "1" /* Occlusion of Right Subclavian Vein with Extraluminal Device, Percutaneous Approach */
"05L53DZ" = "1" /* Occlusion of Right Subclavian Vein with Intraluminal Device, Percutaneous Approach */
"05L53ZZ" = "1" /* Occlusion of Right Subclavian Vein, Percutaneous Approach */
"05L54CZ" = "1" /* Occlusion of Right Subclavian Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L54DZ" = "1" /* Occlusion of Right Subclavian Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L54ZZ" = "1" /* Occlusion of Right Subclavian Vein, Percutaneous Endoscopic Approach */
"05L60CZ" = "1" /* Occlusion of Left Subclavian Vein with Extraluminal Device, Open Approach */
"05L60DZ" = "1" /* Occlusion of Left Subclavian Vein with Intraluminal Device, Open Approach */
"05L60ZZ" = "1" /* Occlusion of Left Subclavian Vein, Open Approach */
"05L63CZ" = "1" /* Occlusion of Left Subclavian Vein with Extraluminal Device, Percutaneous Approach */
"05L63DZ" = "1" /* Occlusion of Left Subclavian Vein with Intraluminal Device, Percutaneous Approach */
"05L63ZZ" = "1" /* Occlusion of Left Subclavian Vein, Percutaneous Approach */
"05L64CZ" = "1" /* Occlusion of Left Subclavian Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L64DZ" = "1" /* Occlusion of Left Subclavian Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L64ZZ" = "1" /* Occlusion of Left Subclavian Vein, Percutaneous Endoscopic Approach */
"05L70CZ" = "1" /* Occlusion of Right Axillary Vein with Extraluminal Device, Open Approach */
"05L70DZ" = "1" /* Occlusion of Right Axillary Vein with Intraluminal Device, Open Approach */
"05L70ZZ" = "1" /* Occlusion of Right Axillary Vein, Open Approach */
"05L73CZ" = "1" /* Occlusion of Right Axillary Vein with Extraluminal Device, Percutaneous Approach */
"05L73DZ" = "1" /* Occlusion of Right Axillary Vein with Intraluminal Device, Percutaneous Approach */
"05L73ZZ" = "1" /* Occlusion of Right Axillary Vein, Percutaneous Approach */
"05L74CZ" = "1" /* Occlusion of Right Axillary Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L74DZ" = "1" /* Occlusion of Right Axillary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L74ZZ" = "1" /* Occlusion of Right Axillary Vein, Percutaneous Endoscopic Approach */
"05L80CZ" = "1" /* Occlusion of Left Axillary Vein with Extraluminal Device, Open Approach */
"05L80DZ" = "1" /* Occlusion of Left Axillary Vein with Intraluminal Device, Open Approach */
"05L80ZZ" = "1" /* Occlusion of Left Axillary Vein, Open Approach */
"05L83CZ" = "1" /* Occlusion of Left Axillary Vein with Extraluminal Device, Percutaneous Approach */
"05L83DZ" = "1" /* Occlusion of Left Axillary Vein with Intraluminal Device, Percutaneous Approach */
"05L83ZZ" = "1" /* Occlusion of Left Axillary Vein, Percutaneous Approach */
"05L84CZ" = "1" /* Occlusion of Left Axillary Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L84DZ" = "1" /* Occlusion of Left Axillary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L84ZZ" = "1" /* Occlusion of Left Axillary Vein, Percutaneous Endoscopic Approach */
"05L90CZ" = "1" /* Occlusion of Right Brachial Vein with Extraluminal Device, Open Approach */
"05L90DZ" = "1" /* Occlusion of Right Brachial Vein with Intraluminal Device, Open Approach */
"05L90ZZ" = "1" /* Occlusion of Right Brachial Vein, Open Approach */
"05L93CZ" = "1" /* Occlusion of Right Brachial Vein with Extraluminal Device, Percutaneous Approach */
"05L93DZ" = "1" /* Occlusion of Right Brachial Vein with Intraluminal Device, Percutaneous Approach */
"05L93ZZ" = "1" /* Occlusion of Right Brachial Vein, Percutaneous Approach */
"05L94CZ" = "1" /* Occlusion of Right Brachial Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05L94DZ" = "1" /* Occlusion of Right Brachial Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05L94ZZ" = "1" /* Occlusion of Right Brachial Vein, Percutaneous Endoscopic Approach */
"05LA0CZ" = "1" /* Occlusion of Left Brachial Vein with Extraluminal Device, Open Approach */
"05LA0DZ" = "1" /* Occlusion of Left Brachial Vein with Intraluminal Device, Open Approach */
"05LA0ZZ" = "1" /* Occlusion of Left Brachial Vein, Open Approach */
"05LA3CZ" = "1" /* Occlusion of Left Brachial Vein with Extraluminal Device, Percutaneous Approach */
"05LA3DZ" = "1" /* Occlusion of Left Brachial Vein with Intraluminal Device, Percutaneous Approach */
"05LA3ZZ" = "1" /* Occlusion of Left Brachial Vein, Percutaneous Approach */
"05LA4CZ" = "1" /* Occlusion of Left Brachial Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LA4DZ" = "1" /* Occlusion of Left Brachial Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LA4ZZ" = "1" /* Occlusion of Left Brachial Vein, Percutaneous Endoscopic Approach */
"05LB0CZ" = "1" /* Occlusion of Right Basilic Vein with Extraluminal Device, Open Approach */
"05LB0DZ" = "1" /* Occlusion of Right Basilic Vein with Intraluminal Device, Open Approach */
"05LB0ZZ" = "1" /* Occlusion of Right Basilic Vein, Open Approach */
"05LB3CZ" = "1" /* Occlusion of Right Basilic Vein with Extraluminal Device, Percutaneous Approach */
"05LB3DZ" = "1" /* Occlusion of Right Basilic Vein with Intraluminal Device, Percutaneous Approach */
"05LB3ZZ" = "1" /* Occlusion of Right Basilic Vein, Percutaneous Approach */
"05LB4CZ" = "1" /* Occlusion of Right Basilic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LB4DZ" = "1" /* Occlusion of Right Basilic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LB4ZZ" = "1" /* Occlusion of Right Basilic Vein, Percutaneous Endoscopic Approach */
"05LC0CZ" = "1" /* Occlusion of Left Basilic Vein with Extraluminal Device, Open Approach */
"05LC0DZ" = "1" /* Occlusion of Left Basilic Vein with Intraluminal Device, Open Approach */
"05LC0ZZ" = "1" /* Occlusion of Left Basilic Vein, Open Approach */
"05LC3CZ" = "1" /* Occlusion of Left Basilic Vein with Extraluminal Device, Percutaneous Approach */
"05LC3DZ" = "1" /* Occlusion of Left Basilic Vein with Intraluminal Device, Percutaneous Approach */
"05LC3ZZ" = "1" /* Occlusion of Left Basilic Vein, Percutaneous Approach */
"05LC4CZ" = "1" /* Occlusion of Left Basilic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LC4DZ" = "1" /* Occlusion of Left Basilic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LC4ZZ" = "1" /* Occlusion of Left Basilic Vein, Percutaneous Endoscopic Approach */
"05LD0CZ" = "1" /* Occlusion of Right Cephalic Vein with Extraluminal Device, Open Approach */
"05LD0DZ" = "1" /* Occlusion of Right Cephalic Vein with Intraluminal Device, Open Approach */
"05LD0ZZ" = "1" /* Occlusion of Right Cephalic Vein, Open Approach */
"05LD3CZ" = "1" /* Occlusion of Right Cephalic Vein with Extraluminal Device, Percutaneous Approach */
"05LD3DZ" = "1" /* Occlusion of Right Cephalic Vein with Intraluminal Device, Percutaneous Approach */
"05LD3ZZ" = "1" /* Occlusion of Right Cephalic Vein, Percutaneous Approach */
"05LD4CZ" = "1" /* Occlusion of Right Cephalic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LD4DZ" = "1" /* Occlusion of Right Cephalic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LD4ZZ" = "1" /* Occlusion of Right Cephalic Vein, Percutaneous Endoscopic Approach */
"05LF0CZ" = "1" /* Occlusion of Left Cephalic Vein with Extraluminal Device, Open Approach */
"05LF0DZ" = "1" /* Occlusion of Left Cephalic Vein with Intraluminal Device, Open Approach */
"05LF0ZZ" = "1" /* Occlusion of Left Cephalic Vein, Open Approach */
"05LF3CZ" = "1" /* Occlusion of Left Cephalic Vein with Extraluminal Device, Percutaneous Approach */
"05LF3DZ" = "1" /* Occlusion of Left Cephalic Vein with Intraluminal Device, Percutaneous Approach */
"05LF3ZZ" = "1" /* Occlusion of Left Cephalic Vein, Percutaneous Approach */
"05LF4CZ" = "1" /* Occlusion of Left Cephalic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LF4DZ" = "1" /* Occlusion of Left Cephalic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LF4ZZ" = "1" /* Occlusion of Left Cephalic Vein, Percutaneous Endoscopic Approach */
"05LG0CZ" = "1" /* Occlusion of Right Hand Vein with Extraluminal Device, Open Approach */
"05LG0DZ" = "1" /* Occlusion of Right Hand Vein with Intraluminal Device, Open Approach */
"05LG0ZZ" = "1" /* Occlusion of Right Hand Vein, Open Approach */
"05LG3CZ" = "1" /* Occlusion of Right Hand Vein with Extraluminal Device, Percutaneous Approach */
"05LG3DZ" = "1" /* Occlusion of Right Hand Vein with Intraluminal Device, Percutaneous Approach */
"05LG3ZZ" = "1" /* Occlusion of Right Hand Vein, Percutaneous Approach */
"05LG4CZ" = "1" /* Occlusion of Right Hand Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LG4DZ" = "1" /* Occlusion of Right Hand Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LG4ZZ" = "1" /* Occlusion of Right Hand Vein, Percutaneous Endoscopic Approach */
"05LH0CZ" = "1" /* Occlusion of Left Hand Vein with Extraluminal Device, Open Approach */
"05LH0DZ" = "1" /* Occlusion of Left Hand Vein with Intraluminal Device, Open Approach */
"05LH0ZZ" = "1" /* Occlusion of Left Hand Vein, Open Approach */
"05LH3CZ" = "1" /* Occlusion of Left Hand Vein with Extraluminal Device, Percutaneous Approach */
"05LH3DZ" = "1" /* Occlusion of Left Hand Vein with Intraluminal Device, Percutaneous Approach */
"05LH3ZZ" = "1" /* Occlusion of Left Hand Vein, Percutaneous Approach */
"05LH4CZ" = "1" /* Occlusion of Left Hand Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LH4DZ" = "1" /* Occlusion of Left Hand Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LH4ZZ" = "1" /* Occlusion of Left Hand Vein, Percutaneous Endoscopic Approach */
"05LL0CZ" = "1" /* Occlusion of Intracranial Vein with Extraluminal Device, Open Approach */
"05LL0DZ" = "1" /* Occlusion of Intracranial Vein with Intraluminal Device, Open Approach */
"05LL0ZZ" = "1" /* Occlusion of Intracranial Vein, Open Approach */
"05LL3CZ" = "1" /* Occlusion of Intracranial Vein with Extraluminal Device, Percutaneous Approach */
"05LL3DZ" = "1" /* Occlusion of Intracranial Vein with Intraluminal Device, Percutaneous Approach */
"05LL3ZZ" = "1" /* Occlusion of Intracranial Vein, Percutaneous Approach */
"05LL4CZ" = "1" /* Occlusion of Intracranial Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LL4DZ" = "1" /* Occlusion of Intracranial Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LL4ZZ" = "1" /* Occlusion of Intracranial Vein, Percutaneous Endoscopic Approach */
"05LM0CZ" = "1" /* Occlusion of Right Internal Jugular Vein with Extraluminal Device, Open Approach */
"05LM0DZ" = "1" /* Occlusion of Right Internal Jugular Vein with Intraluminal Device, Open Approach */
"05LM0ZZ" = "1" /* Occlusion of Right Internal Jugular Vein, Open Approach */
"05LM3CZ" = "1" /* Occlusion of Right Internal Jugular Vein with Extraluminal Device, Percutaneous Approach */
"05LM3DZ" = "1" /* Occlusion of Right Internal Jugular Vein with Intraluminal Device, Percutaneous Approach */
"05LM3ZZ" = "1" /* Occlusion of Right Internal Jugular Vein, Percutaneous Approach */
"05LM4CZ" = "1" /* Occlusion of Right Internal Jugular Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LM4DZ" = "1" /* Occlusion of Right Internal Jugular Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LM4ZZ" = "1" /* Occlusion of Right Internal Jugular Vein, Percutaneous Endoscopic Approach */
"05LN0CZ" = "1" /* Occlusion of Left Internal Jugular Vein with Extraluminal Device, Open Approach */
"05LN0DZ" = "1" /* Occlusion of Left Internal Jugular Vein with Intraluminal Device, Open Approach */
"05LN0ZZ" = "1" /* Occlusion of Left Internal Jugular Vein, Open Approach */
"05LN3CZ" = "1" /* Occlusion of Left Internal Jugular Vein with Extraluminal Device, Percutaneous Approach */
"05LN3DZ" = "1" /* Occlusion of Left Internal Jugular Vein with Intraluminal Device, Percutaneous Approach */
"05LN3ZZ" = "1" /* Occlusion of Left Internal Jugular Vein, Percutaneous Approach */
"05LN4CZ" = "1" /* Occlusion of Left Internal Jugular Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LN4DZ" = "1" /* Occlusion of Left Internal Jugular Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LN4ZZ" = "1" /* Occlusion of Left Internal Jugular Vein, Percutaneous Endoscopic Approach */
"05LP0CZ" = "1" /* Occlusion of Right External Jugular Vein with Extraluminal Device, Open Approach */
"05LP0DZ" = "1" /* Occlusion of Right External Jugular Vein with Intraluminal Device, Open Approach */
"05LP0ZZ" = "1" /* Occlusion of Right External Jugular Vein, Open Approach */
"05LP3CZ" = "1" /* Occlusion of Right External Jugular Vein with Extraluminal Device, Percutaneous Approach */
"05LP3DZ" = "1" /* Occlusion of Right External Jugular Vein with Intraluminal Device, Percutaneous Approach */
"05LP3ZZ" = "1" /* Occlusion of Right External Jugular Vein, Percutaneous Approach */
"05LP4CZ" = "1" /* Occlusion of Right External Jugular Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LP4DZ" = "1" /* Occlusion of Right External Jugular Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LP4ZZ" = "1" /* Occlusion of Right External Jugular Vein, Percutaneous Endoscopic Approach */
"05LQ0CZ" = "1" /* Occlusion of Left External Jugular Vein with Extraluminal Device, Open Approach */
"05LQ0DZ" = "1" /* Occlusion of Left External Jugular Vein with Intraluminal Device, Open Approach */
"05LQ0ZZ" = "1" /* Occlusion of Left External Jugular Vein, Open Approach */
"05LQ3CZ" = "1" /* Occlusion of Left External Jugular Vein with Extraluminal Device, Percutaneous Approach */
"05LQ3DZ" = "1" /* Occlusion of Left External Jugular Vein with Intraluminal Device, Percutaneous Approach */
"05LQ3ZZ" = "1" /* Occlusion of Left External Jugular Vein, Percutaneous Approach */
"05LQ4CZ" = "1" /* Occlusion of Left External Jugular Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LQ4DZ" = "1" /* Occlusion of Left External Jugular Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LQ4ZZ" = "1" /* Occlusion of Left External Jugular Vein, Percutaneous Endoscopic Approach */
"05LR0CZ" = "1" /* Occlusion of Right Vertebral Vein with Extraluminal Device, Open Approach */
"05LR0DZ" = "1" /* Occlusion of Right Vertebral Vein with Intraluminal Device, Open Approach */
"05LR0ZZ" = "1" /* Occlusion of Right Vertebral Vein, Open Approach */
"05LR3CZ" = "1" /* Occlusion of Right Vertebral Vein with Extraluminal Device, Percutaneous Approach */
"05LR3DZ" = "1" /* Occlusion of Right Vertebral Vein with Intraluminal Device, Percutaneous Approach */
"05LR3ZZ" = "1" /* Occlusion of Right Vertebral Vein, Percutaneous Approach */
"05LR4CZ" = "1" /* Occlusion of Right Vertebral Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LR4DZ" = "1" /* Occlusion of Right Vertebral Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LR4ZZ" = "1" /* Occlusion of Right Vertebral Vein, Percutaneous Endoscopic Approach */
"05LS0CZ" = "1" /* Occlusion of Left Vertebral Vein with Extraluminal Device, Open Approach */
"05LS0DZ" = "1" /* Occlusion of Left Vertebral Vein with Intraluminal Device, Open Approach */
"05LS0ZZ" = "1" /* Occlusion of Left Vertebral Vein, Open Approach */
"05LS3CZ" = "1" /* Occlusion of Left Vertebral Vein with Extraluminal Device, Percutaneous Approach */
"05LS3DZ" = "1" /* Occlusion of Left Vertebral Vein with Intraluminal Device, Percutaneous Approach */
"05LS3ZZ" = "1" /* Occlusion of Left Vertebral Vein, Percutaneous Approach */
"05LS4CZ" = "1" /* Occlusion of Left Vertebral Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LS4DZ" = "1" /* Occlusion of Left Vertebral Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LS4ZZ" = "1" /* Occlusion of Left Vertebral Vein, Percutaneous Endoscopic Approach */
"05LT0CZ" = "1" /* Occlusion of Right Face Vein with Extraluminal Device, Open Approach */
"05LT0DZ" = "1" /* Occlusion of Right Face Vein with Intraluminal Device, Open Approach */
"05LT0ZZ" = "1" /* Occlusion of Right Face Vein, Open Approach */
"05LT3CZ" = "1" /* Occlusion of Right Face Vein with Extraluminal Device, Percutaneous Approach */
"05LT3DZ" = "1" /* Occlusion of Right Face Vein with Intraluminal Device, Percutaneous Approach */
"05LT3ZZ" = "1" /* Occlusion of Right Face Vein, Percutaneous Approach */
"05LT4CZ" = "1" /* Occlusion of Right Face Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LT4DZ" = "1" /* Occlusion of Right Face Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LT4ZZ" = "1" /* Occlusion of Right Face Vein, Percutaneous Endoscopic Approach */
"05LV0CZ" = "1" /* Occlusion of Left Face Vein with Extraluminal Device, Open Approach */
"05LV0DZ" = "1" /* Occlusion of Left Face Vein with Intraluminal Device, Open Approach */
"05LV0ZZ" = "1" /* Occlusion of Left Face Vein, Open Approach */
"05LV3CZ" = "1" /* Occlusion of Left Face Vein with Extraluminal Device, Percutaneous Approach */
"05LV3DZ" = "1" /* Occlusion of Left Face Vein with Intraluminal Device, Percutaneous Approach */
"05LV3ZZ" = "1" /* Occlusion of Left Face Vein, Percutaneous Approach */
"05LV4CZ" = "1" /* Occlusion of Left Face Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LV4DZ" = "1" /* Occlusion of Left Face Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LV4ZZ" = "1" /* Occlusion of Left Face Vein, Percutaneous Endoscopic Approach */
"05LY0CZ" = "1" /* Occlusion of Upper Vein with Extraluminal Device, Open Approach */
"05LY0DZ" = "1" /* Occlusion of Upper Vein with Intraluminal Device, Open Approach */
"05LY0ZZ" = "1" /* Occlusion of Upper Vein, Open Approach */
"05LY3CZ" = "1" /* Occlusion of Upper Vein with Extraluminal Device, Percutaneous Approach */
"05LY3DZ" = "1" /* Occlusion of Upper Vein with Intraluminal Device, Percutaneous Approach */
"05LY3ZZ" = "1" /* Occlusion of Upper Vein, Percutaneous Approach */
"05LY4CZ" = "1" /* Occlusion of Upper Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05LY4DZ" = "1" /* Occlusion of Upper Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05LY4ZZ" = "1" /* Occlusion of Upper Vein, Percutaneous Endoscopic Approach */
"05N00ZZ" = "1" /* Release Azygos Vein, Open Approach */
"05N03ZZ" = "1" /* Release Azygos Vein, Percutaneous Approach */
"05N04ZZ" = "1" /* Release Azygos Vein, Percutaneous Endoscopic Approach */
"05N10ZZ" = "1" /* Release Hemiazygos Vein, Open Approach */
"05N13ZZ" = "1" /* Release Hemiazygos Vein, Percutaneous Approach */
"05N14ZZ" = "1" /* Release Hemiazygos Vein, Percutaneous Endoscopic Approach */
"05N30ZZ" = "1" /* Release Right Innominate Vein, Open Approach */
"05N33ZZ" = "1" /* Release Right Innominate Vein, Percutaneous Approach */
"05N34ZZ" = "1" /* Release Right Innominate Vein, Percutaneous Endoscopic Approach */
"05N40ZZ" = "1" /* Release Left Innominate Vein, Open Approach */
"05N43ZZ" = "1" /* Release Left Innominate Vein, Percutaneous Approach */
"05N44ZZ" = "1" /* Release Left Innominate Vein, Percutaneous Endoscopic Approach */
"05N50ZZ" = "1" /* Release Right Subclavian Vein, Open Approach */
"05N53ZZ" = "1" /* Release Right Subclavian Vein, Percutaneous Approach */
"05N54ZZ" = "1" /* Release Right Subclavian Vein, Percutaneous Endoscopic Approach */
"05N60ZZ" = "1" /* Release Left Subclavian Vein, Open Approach */
"05N63ZZ" = "1" /* Release Left Subclavian Vein, Percutaneous Approach */
"05N64ZZ" = "1" /* Release Left Subclavian Vein, Percutaneous Endoscopic Approach */
"05N70ZZ" = "1" /* Release Right Axillary Vein, Open Approach */
"05N73ZZ" = "1" /* Release Right Axillary Vein, Percutaneous Approach */
"05N74ZZ" = "1" /* Release Right Axillary Vein, Percutaneous Endoscopic Approach */
"05N80ZZ" = "1" /* Release Left Axillary Vein, Open Approach */
"05N83ZZ" = "1" /* Release Left Axillary Vein, Percutaneous Approach */
"05N84ZZ" = "1" /* Release Left Axillary Vein, Percutaneous Endoscopic Approach */
"05N90ZZ" = "1" /* Release Right Brachial Vein, Open Approach */
"05N93ZZ" = "1" /* Release Right Brachial Vein, Percutaneous Approach */
"05N94ZZ" = "1" /* Release Right Brachial Vein, Percutaneous Endoscopic Approach */
"05NA0ZZ" = "1" /* Release Left Brachial Vein, Open Approach */
"05NA3ZZ" = "1" /* Release Left Brachial Vein, Percutaneous Approach */
"05NA4ZZ" = "1" /* Release Left Brachial Vein, Percutaneous Endoscopic Approach */
"05NB0ZZ" = "1" /* Release Right Basilic Vein, Open Approach */
"05NB3ZZ" = "1" /* Release Right Basilic Vein, Percutaneous Approach */
"05NB4ZZ" = "1" /* Release Right Basilic Vein, Percutaneous Endoscopic Approach */
"05NC0ZZ" = "1" /* Release Left Basilic Vein, Open Approach */
"05NC3ZZ" = "1" /* Release Left Basilic Vein, Percutaneous Approach */
"05NC4ZZ" = "1" /* Release Left Basilic Vein, Percutaneous Endoscopic Approach */
"05ND0ZZ" = "1" /* Release Right Cephalic Vein, Open Approach */
"05ND3ZZ" = "1" /* Release Right Cephalic Vein, Percutaneous Approach */
"05ND4ZZ" = "1" /* Release Right Cephalic Vein, Percutaneous Endoscopic Approach */
"05NF0ZZ" = "1" /* Release Left Cephalic Vein, Open Approach */
"05NF3ZZ" = "1" /* Release Left Cephalic Vein, Percutaneous Approach */
"05NF4ZZ" = "1" /* Release Left Cephalic Vein, Percutaneous Endoscopic Approach */
"05NG0ZZ" = "1" /* Release Right Hand Vein, Open Approach */
"05NG3ZZ" = "1" /* Release Right Hand Vein, Percutaneous Approach */
"05NG4ZZ" = "1" /* Release Right Hand Vein, Percutaneous Endoscopic Approach */
"05NH0ZZ" = "1" /* Release Left Hand Vein, Open Approach */
"05NH3ZZ" = "1" /* Release Left Hand Vein, Percutaneous Approach */
"05NH4ZZ" = "1" /* Release Left Hand Vein, Percutaneous Endoscopic Approach */
"05NL0ZZ" = "1" /* Release Intracranial Vein, Open Approach */
"05NL3ZZ" = "1" /* Release Intracranial Vein, Percutaneous Approach */
"05NL4ZZ" = "1" /* Release Intracranial Vein, Percutaneous Endoscopic Approach */
"05NM0ZZ" = "1" /* Release Right Internal Jugular Vein, Open Approach */
"05NM3ZZ" = "1" /* Release Right Internal Jugular Vein, Percutaneous Approach */
"05NM4ZZ" = "1" /* Release Right Internal Jugular Vein, Percutaneous Endoscopic Approach */
"05NN0ZZ" = "1" /* Release Left Internal Jugular Vein, Open Approach */
"05NN3ZZ" = "1" /* Release Left Internal Jugular Vein, Percutaneous Approach */
"05NN4ZZ" = "1" /* Release Left Internal Jugular Vein, Percutaneous Endoscopic Approach */
"05NP0ZZ" = "1" /* Release Right External Jugular Vein, Open Approach */
"05NP3ZZ" = "1" /* Release Right External Jugular Vein, Percutaneous Approach */
"05NP4ZZ" = "1" /* Release Right External Jugular Vein, Percutaneous Endoscopic Approach */
"05NQ0ZZ" = "1" /* Release Left External Jugular Vein, Open Approach */
"05NQ3ZZ" = "1" /* Release Left External Jugular Vein, Percutaneous Approach */
"05NQ4ZZ" = "1" /* Release Left External Jugular Vein, Percutaneous Endoscopic Approach */
"05NR0ZZ" = "1" /* Release Right Vertebral Vein, Open Approach */
"05NR3ZZ" = "1" /* Release Right Vertebral Vein, Percutaneous Approach */
"05NR4ZZ" = "1" /* Release Right Vertebral Vein, Percutaneous Endoscopic Approach */
"05NS0ZZ" = "1" /* Release Left Vertebral Vein, Open Approach */
"05NS3ZZ" = "1" /* Release Left Vertebral Vein, Percutaneous Approach */
"05NS4ZZ" = "1" /* Release Left Vertebral Vein, Percutaneous Endoscopic Approach */
"05NT0ZZ" = "1" /* Release Right Face Vein, Open Approach */
"05NT3ZZ" = "1" /* Release Right Face Vein, Percutaneous Approach */
"05NT4ZZ" = "1" /* Release Right Face Vein, Percutaneous Endoscopic Approach */
"05NV0ZZ" = "1" /* Release Left Face Vein, Open Approach */
"05NV3ZZ" = "1" /* Release Left Face Vein, Percutaneous Approach */
"05NV4ZZ" = "1" /* Release Left Face Vein, Percutaneous Endoscopic Approach */
"05NY0ZZ" = "1" /* Release Upper Vein, Open Approach */
"05NY3ZZ" = "1" /* Release Upper Vein, Percutaneous Approach */
"05NY4ZZ" = "1" /* Release Upper Vein, Percutaneous Endoscopic Approach */
"05P002Z" = "1" /* Removal of Monitoring Device from Azygos Vein, Open Approach */
"05P00MZ" = "1" /* Removal of Neurostimulator Lead from Azygos Vein, Open Approach */
"05P042Z" = "1" /* Removal of Monitoring Device from Azygos Vein, Percutaneous Endoscopic Approach */
"05P04MZ" = "1" /* Removal of Neurostimulator Lead from Azygos Vein, Percutaneous Endoscopic Approach */
"05P30MZ" = "1" /* Removal of Neurostimulator Lead from Right Innominate Vein, Open Approach */
"05P34MZ" = "1" /* Removal of Neurostimulator Lead from Right Innominate Vein, Percutaneous Endoscopic Approach */
"05P40MZ" = "1" /* Removal of Neurostimulator Lead from Left Innominate Vein, Open Approach */
"05P44MZ" = "1" /* Removal of Neurostimulator Lead from Left Innominate Vein, Percutaneous Endoscopic Approach */
"05PY00Z" = "1" /* Removal of Drainage Device from Upper Vein, Open Approach */
"05PY02Z" = "1" /* Removal of Monitoring Device from Upper Vein, Open Approach */
"05PY03Z" = "1" /* Removal of Infusion Device from Upper Vein, Open Approach */
"05PY07Z" = "1" /* Removal of Autologous Tissue Substitute from Upper Vein, Open Approach */
"05PY0CZ" = "1" /* Removal of Extraluminal Device from Upper Vein, Open Approach */
"05PY0DZ" = "1" /* Removal of Intraluminal Device from Upper Vein, Open Approach */
"05PY0JZ" = "1" /* Removal of Synthetic Substitute from Upper Vein, Open Approach */
"05PY0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Upper Vein, Open Approach */
"05PY37Z" = "1" /* Removal of Autologous Tissue Substitute from Upper Vein, Percutaneous Approach */
"05PY3CZ" = "1" /* Removal of Extraluminal Device from Upper Vein, Percutaneous Approach */
"05PY3JZ" = "1" /* Removal of Synthetic Substitute from Upper Vein, Percutaneous Approach */
"05PY3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Upper Vein, Percutaneous Approach */
"05PY40Z" = "1" /* Removal of Drainage Device from Upper Vein, Percutaneous Endoscopic Approach */
"05PY42Z" = "1" /* Removal of Monitoring Device from Upper Vein, Percutaneous Endoscopic Approach */
"05PY43Z" = "1" /* Removal of Infusion Device from Upper Vein, Percutaneous Endoscopic Approach */
"05PY47Z" = "1" /* Removal of Autologous Tissue Substitute from Upper Vein, Percutaneous Endoscopic Approach */
"05PY4CZ" = "1" /* Removal of Extraluminal Device from Upper Vein, Percutaneous Endoscopic Approach */
"05PY4DZ" = "1" /* Removal of Intraluminal Device from Upper Vein, Percutaneous Endoscopic Approach */
"05PY4JZ" = "1" /* Removal of Synthetic Substitute from Upper Vein, Percutaneous Endoscopic Approach */
"05PY4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Upper Vein, Percutaneous Endoscopic Approach */
"05Q00ZZ" = "1" /* Repair Azygos Vein, Open Approach */
"05Q03ZZ" = "1" /* Repair Azygos Vein, Percutaneous Approach */
"05Q04ZZ" = "1" /* Repair Azygos Vein, Percutaneous Endoscopic Approach */
"05Q10ZZ" = "1" /* Repair Hemiazygos Vein, Open Approach */
"05Q13ZZ" = "1" /* Repair Hemiazygos Vein, Percutaneous Approach */
"05Q14ZZ" = "1" /* Repair Hemiazygos Vein, Percutaneous Endoscopic Approach */
"05Q30ZZ" = "1" /* Repair Right Innominate Vein, Open Approach */
"05Q33ZZ" = "1" /* Repair Right Innominate Vein, Percutaneous Approach */
"05Q34ZZ" = "1" /* Repair Right Innominate Vein, Percutaneous Endoscopic Approach */
"05Q40ZZ" = "1" /* Repair Left Innominate Vein, Open Approach */
"05Q43ZZ" = "1" /* Repair Left Innominate Vein, Percutaneous Approach */
"05Q44ZZ" = "1" /* Repair Left Innominate Vein, Percutaneous Endoscopic Approach */
"05Q50ZZ" = "1" /* Repair Right Subclavian Vein, Open Approach */
"05Q53ZZ" = "1" /* Repair Right Subclavian Vein, Percutaneous Approach */
"05Q54ZZ" = "1" /* Repair Right Subclavian Vein, Percutaneous Endoscopic Approach */
"05Q60ZZ" = "1" /* Repair Left Subclavian Vein, Open Approach */
"05Q63ZZ" = "1" /* Repair Left Subclavian Vein, Percutaneous Approach */
"05Q64ZZ" = "1" /* Repair Left Subclavian Vein, Percutaneous Endoscopic Approach */
"05Q70ZZ" = "1" /* Repair Right Axillary Vein, Open Approach */
"05Q73ZZ" = "1" /* Repair Right Axillary Vein, Percutaneous Approach */
"05Q74ZZ" = "1" /* Repair Right Axillary Vein, Percutaneous Endoscopic Approach */
"05Q80ZZ" = "1" /* Repair Left Axillary Vein, Open Approach */
"05Q83ZZ" = "1" /* Repair Left Axillary Vein, Percutaneous Approach */
"05Q84ZZ" = "1" /* Repair Left Axillary Vein, Percutaneous Endoscopic Approach */
"05Q90ZZ" = "1" /* Repair Right Brachial Vein, Open Approach */
"05Q93ZZ" = "1" /* Repair Right Brachial Vein, Percutaneous Approach */
"05Q94ZZ" = "1" /* Repair Right Brachial Vein, Percutaneous Endoscopic Approach */
"05QA0ZZ" = "1" /* Repair Left Brachial Vein, Open Approach */
"05QA3ZZ" = "1" /* Repair Left Brachial Vein, Percutaneous Approach */
"05QA4ZZ" = "1" /* Repair Left Brachial Vein, Percutaneous Endoscopic Approach */
"05QB0ZZ" = "1" /* Repair Right Basilic Vein, Open Approach */
"05QB3ZZ" = "1" /* Repair Right Basilic Vein, Percutaneous Approach */
"05QB4ZZ" = "1" /* Repair Right Basilic Vein, Percutaneous Endoscopic Approach */
"05QC0ZZ" = "1" /* Repair Left Basilic Vein, Open Approach */
"05QC3ZZ" = "1" /* Repair Left Basilic Vein, Percutaneous Approach */
"05QC4ZZ" = "1" /* Repair Left Basilic Vein, Percutaneous Endoscopic Approach */
"05QD0ZZ" = "1" /* Repair Right Cephalic Vein, Open Approach */
"05QD3ZZ" = "1" /* Repair Right Cephalic Vein, Percutaneous Approach */
"05QD4ZZ" = "1" /* Repair Right Cephalic Vein, Percutaneous Endoscopic Approach */
"05QF0ZZ" = "1" /* Repair Left Cephalic Vein, Open Approach */
"05QF3ZZ" = "1" /* Repair Left Cephalic Vein, Percutaneous Approach */
"05QF4ZZ" = "1" /* Repair Left Cephalic Vein, Percutaneous Endoscopic Approach */
"05QG0ZZ" = "1" /* Repair Right Hand Vein, Open Approach */
"05QG3ZZ" = "1" /* Repair Right Hand Vein, Percutaneous Approach */
"05QG4ZZ" = "1" /* Repair Right Hand Vein, Percutaneous Endoscopic Approach */
"05QH0ZZ" = "1" /* Repair Left Hand Vein, Open Approach */
"05QH3ZZ" = "1" /* Repair Left Hand Vein, Percutaneous Approach */
"05QH4ZZ" = "1" /* Repair Left Hand Vein, Percutaneous Endoscopic Approach */
"05QL0ZZ" = "1" /* Repair Intracranial Vein, Open Approach */
"05QL3ZZ" = "1" /* Repair Intracranial Vein, Percutaneous Approach */
"05QL4ZZ" = "1" /* Repair Intracranial Vein, Percutaneous Endoscopic Approach */
"05QM0ZZ" = "1" /* Repair Right Internal Jugular Vein, Open Approach */
"05QM3ZZ" = "1" /* Repair Right Internal Jugular Vein, Percutaneous Approach */
"05QM4ZZ" = "1" /* Repair Right Internal Jugular Vein, Percutaneous Endoscopic Approach */
"05QN0ZZ" = "1" /* Repair Left Internal Jugular Vein, Open Approach */
"05QN3ZZ" = "1" /* Repair Left Internal Jugular Vein, Percutaneous Approach */
"05QN4ZZ" = "1" /* Repair Left Internal Jugular Vein, Percutaneous Endoscopic Approach */
"05QP0ZZ" = "1" /* Repair Right External Jugular Vein, Open Approach */
"05QP3ZZ" = "1" /* Repair Right External Jugular Vein, Percutaneous Approach */
"05QP4ZZ" = "1" /* Repair Right External Jugular Vein, Percutaneous Endoscopic Approach */
"05QQ0ZZ" = "1" /* Repair Left External Jugular Vein, Open Approach */
"05QQ3ZZ" = "1" /* Repair Left External Jugular Vein, Percutaneous Approach */
"05QQ4ZZ" = "1" /* Repair Left External Jugular Vein, Percutaneous Endoscopic Approach */
"05QR0ZZ" = "1" /* Repair Right Vertebral Vein, Open Approach */
"05QR3ZZ" = "1" /* Repair Right Vertebral Vein, Percutaneous Approach */
"05QR4ZZ" = "1" /* Repair Right Vertebral Vein, Percutaneous Endoscopic Approach */
"05QS0ZZ" = "1" /* Repair Left Vertebral Vein, Open Approach */
"05QS3ZZ" = "1" /* Repair Left Vertebral Vein, Percutaneous Approach */
"05QS4ZZ" = "1" /* Repair Left Vertebral Vein, Percutaneous Endoscopic Approach */
"05QT0ZZ" = "1" /* Repair Right Face Vein, Open Approach */
"05QT3ZZ" = "1" /* Repair Right Face Vein, Percutaneous Approach */
"05QT4ZZ" = "1" /* Repair Right Face Vein, Percutaneous Endoscopic Approach */
"05QV0ZZ" = "1" /* Repair Left Face Vein, Open Approach */
"05QV3ZZ" = "1" /* Repair Left Face Vein, Percutaneous Approach */
"05QV4ZZ" = "1" /* Repair Left Face Vein, Percutaneous Endoscopic Approach */
"05QY0ZZ" = "1" /* Repair Upper Vein, Open Approach */
"05QY3ZZ" = "1" /* Repair Upper Vein, Percutaneous Approach */
"05QY4ZZ" = "1" /* Repair Upper Vein, Percutaneous Endoscopic Approach */
"05R007Z" = "1" /* Replacement of Azygos Vein with Autologous Tissue Substitute, Open Approach */
"05R00JZ" = "1" /* Replacement of Azygos Vein with Synthetic Substitute, Open Approach */
"05R00KZ" = "1" /* Replacement of Azygos Vein with Nonautologous Tissue Substitute, Open Approach */
"05R047Z" = "1" /* Replacement of Azygos Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R04JZ" = "1" /* Replacement of Azygos Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05R04KZ" = "1" /* Replacement of Azygos Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R107Z" = "1" /* Replacement of Hemiazygos Vein with Autologous Tissue Substitute, Open Approach */
"05R10JZ" = "1" /* Replacement of Hemiazygos Vein with Synthetic Substitute, Open Approach */
"05R10KZ" = "1" /* Replacement of Hemiazygos Vein with Nonautologous Tissue Substitute, Open Approach */
"05R147Z" = "1" /* Replacement of Hemiazygos Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R14JZ" = "1" /* Replacement of Hemiazygos Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05R14KZ" = "1" /* Replacement of Hemiazygos Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R307Z" = "1" /* Replacement of Right Innominate Vein with Autologous Tissue Substitute, Open Approach */
"05R30JZ" = "1" /* Replacement of Right Innominate Vein with Synthetic Substitute, Open Approach */
"05R30KZ" = "1" /* Replacement of Right Innominate Vein with Nonautologous Tissue Substitute, Open Approach */
"05R347Z" = "1" /* Replacement of Right Innominate Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R34JZ" = "1" /* Replacement of Right Innominate Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05R34KZ" = "1" /* Replacement of Right Innominate Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R407Z" = "1" /* Replacement of Left Innominate Vein with Autologous Tissue Substitute, Open Approach */
"05R40JZ" = "1" /* Replacement of Left Innominate Vein with Synthetic Substitute, Open Approach */
"05R40KZ" = "1" /* Replacement of Left Innominate Vein with Nonautologous Tissue Substitute, Open Approach */
"05R447Z" = "1" /* Replacement of Left Innominate Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R44JZ" = "1" /* Replacement of Left Innominate Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05R44KZ" = "1" /* Replacement of Left Innominate Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R507Z" = "1" /* Replacement of Right Subclavian Vein with Autologous Tissue Substitute, Open Approach */
"05R50JZ" = "1" /* Replacement of Right Subclavian Vein with Synthetic Substitute, Open Approach */
"05R50KZ" = "1" /* Replacement of Right Subclavian Vein with Nonautologous Tissue Substitute, Open Approach */
"05R547Z" = "1" /* Replacement of Right Subclavian Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R54JZ" = "1" /* Replacement of Right Subclavian Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05R54KZ" = "1" /* Replacement of Right Subclavian Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R607Z" = "1" /* Replacement of Left Subclavian Vein with Autologous Tissue Substitute, Open Approach */
"05R60JZ" = "1" /* Replacement of Left Subclavian Vein with Synthetic Substitute, Open Approach */
"05R60KZ" = "1" /* Replacement of Left Subclavian Vein with Nonautologous Tissue Substitute, Open Approach */
"05R647Z" = "1" /* Replacement of Left Subclavian Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R64JZ" = "1" /* Replacement of Left Subclavian Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05R64KZ" = "1" /* Replacement of Left Subclavian Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R707Z" = "1" /* Replacement of Right Axillary Vein with Autologous Tissue Substitute, Open Approach */
"05R70JZ" = "1" /* Replacement of Right Axillary Vein with Synthetic Substitute, Open Approach */
"05R70KZ" = "1" /* Replacement of Right Axillary Vein with Nonautologous Tissue Substitute, Open Approach */
"05R747Z" = "1" /* Replacement of Right Axillary Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R74JZ" = "1" /* Replacement of Right Axillary Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05R74KZ" = "1" /* Replacement of Right Axillary Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R807Z" = "1" /* Replacement of Left Axillary Vein with Autologous Tissue Substitute, Open Approach */
"05R80JZ" = "1" /* Replacement of Left Axillary Vein with Synthetic Substitute, Open Approach */
"05R80KZ" = "1" /* Replacement of Left Axillary Vein with Nonautologous Tissue Substitute, Open Approach */
"05R847Z" = "1" /* Replacement of Left Axillary Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R84JZ" = "1" /* Replacement of Left Axillary Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05R84KZ" = "1" /* Replacement of Left Axillary Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R907Z" = "1" /* Replacement of Right Brachial Vein with Autologous Tissue Substitute, Open Approach */
"05R90JZ" = "1" /* Replacement of Right Brachial Vein with Synthetic Substitute, Open Approach */
"05R90KZ" = "1" /* Replacement of Right Brachial Vein with Nonautologous Tissue Substitute, Open Approach */
"05R947Z" = "1" /* Replacement of Right Brachial Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05R94JZ" = "1" /* Replacement of Right Brachial Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05R94KZ" = "1" /* Replacement of Right Brachial Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RA07Z" = "1" /* Replacement of Left Brachial Vein with Autologous Tissue Substitute, Open Approach */
"05RA0JZ" = "1" /* Replacement of Left Brachial Vein with Synthetic Substitute, Open Approach */
"05RA0KZ" = "1" /* Replacement of Left Brachial Vein with Nonautologous Tissue Substitute, Open Approach */
"05RA47Z" = "1" /* Replacement of Left Brachial Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RA4JZ" = "1" /* Replacement of Left Brachial Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05RA4KZ" = "1" /* Replacement of Left Brachial Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RB07Z" = "1" /* Replacement of Right Basilic Vein with Autologous Tissue Substitute, Open Approach */
"05RB0JZ" = "1" /* Replacement of Right Basilic Vein with Synthetic Substitute, Open Approach */
"05RB0KZ" = "1" /* Replacement of Right Basilic Vein with Nonautologous Tissue Substitute, Open Approach */
"05RB47Z" = "1" /* Replacement of Right Basilic Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RB4JZ" = "1" /* Replacement of Right Basilic Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05RB4KZ" = "1" /* Replacement of Right Basilic Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RC07Z" = "1" /* Replacement of Left Basilic Vein with Autologous Tissue Substitute, Open Approach */
"05RC0JZ" = "1" /* Replacement of Left Basilic Vein with Synthetic Substitute, Open Approach */
"05RC0KZ" = "1" /* Replacement of Left Basilic Vein with Nonautologous Tissue Substitute, Open Approach */
"05RC47Z" = "1" /* Replacement of Left Basilic Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RC4JZ" = "1" /* Replacement of Left Basilic Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05RC4KZ" = "1" /* Replacement of Left Basilic Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RD07Z" = "1" /* Replacement of Right Cephalic Vein with Autologous Tissue Substitute, Open Approach */
"05RD0JZ" = "1" /* Replacement of Right Cephalic Vein with Synthetic Substitute, Open Approach */
"05RD0KZ" = "1" /* Replacement of Right Cephalic Vein with Nonautologous Tissue Substitute, Open Approach */
"05RD47Z" = "1" /* Replacement of Right Cephalic Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RD4JZ" = "1" /* Replacement of Right Cephalic Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05RD4KZ" = "1" /* Replacement of Right Cephalic Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RF07Z" = "1" /* Replacement of Left Cephalic Vein with Autologous Tissue Substitute, Open Approach */
"05RF0JZ" = "1" /* Replacement of Left Cephalic Vein with Synthetic Substitute, Open Approach */
"05RF0KZ" = "1" /* Replacement of Left Cephalic Vein with Nonautologous Tissue Substitute, Open Approach */
"05RF47Z" = "1" /* Replacement of Left Cephalic Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RF4JZ" = "1" /* Replacement of Left Cephalic Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05RF4KZ" = "1" /* Replacement of Left Cephalic Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RG07Z" = "1" /* Replacement of Right Hand Vein with Autologous Tissue Substitute, Open Approach */
"05RG0JZ" = "1" /* Replacement of Right Hand Vein with Synthetic Substitute, Open Approach */
"05RG0KZ" = "1" /* Replacement of Right Hand Vein with Nonautologous Tissue Substitute, Open Approach */
"05RG47Z" = "1" /* Replacement of Right Hand Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RG4JZ" = "1" /* Replacement of Right Hand Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05RG4KZ" = "1" /* Replacement of Right Hand Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RH07Z" = "1" /* Replacement of Left Hand Vein with Autologous Tissue Substitute, Open Approach */
"05RH0JZ" = "1" /* Replacement of Left Hand Vein with Synthetic Substitute, Open Approach */
"05RH0KZ" = "1" /* Replacement of Left Hand Vein with Nonautologous Tissue Substitute, Open Approach */
"05RH47Z" = "1" /* Replacement of Left Hand Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RH4JZ" = "1" /* Replacement of Left Hand Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05RH4KZ" = "1" /* Replacement of Left Hand Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RL07Z" = "1" /* Replacement of Intracranial Vein with Autologous Tissue Substitute, Open Approach */
"05RL0JZ" = "1" /* Replacement of Intracranial Vein with Synthetic Substitute, Open Approach */
"05RL0KZ" = "1" /* Replacement of Intracranial Vein with Nonautologous Tissue Substitute, Open Approach */
"05RL47Z" = "1" /* Replacement of Intracranial Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RL4JZ" = "1" /* Replacement of Intracranial Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05RL4KZ" = "1" /* Replacement of Intracranial Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RM07Z" = "1" /* Replacement of Right Internal Jugular Vein with Autologous Tissue Substitute, Open Approach */
"05RM0JZ" = "1" /* Replacement of Right Internal Jugular Vein with Synthetic Substitute, Open Approach */
"05RM0KZ" = "1" /* Replacement of Right Internal Jugular Vein with Nonautologous Tissue Substitute, Open Approach */
"05RM47Z" = "1" /* Replacement of Right Internal Jugular Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RM4JZ" = "1" /* Replacement of Right Internal Jugular Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05RM4KZ" = "1" /* Replacement of Right Internal Jugular Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RN07Z" = "1" /* Replacement of Left Internal Jugular Vein with Autologous Tissue Substitute, Open Approach */
"05RN0JZ" = "1" /* Replacement of Left Internal Jugular Vein with Synthetic Substitute, Open Approach */
"05RN0KZ" = "1" /* Replacement of Left Internal Jugular Vein with Nonautologous Tissue Substitute, Open Approach */
"05RN47Z" = "1" /* Replacement of Left Internal Jugular Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RN4JZ" = "1" /* Replacement of Left Internal Jugular Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05RN4KZ" = "1" /* Replacement of Left Internal Jugular Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RP07Z" = "1" /* Replacement of Right External Jugular Vein with Autologous Tissue Substitute, Open Approach */
"05RP0JZ" = "1" /* Replacement of Right External Jugular Vein with Synthetic Substitute, Open Approach */
"05RP0KZ" = "1" /* Replacement of Right External Jugular Vein with Nonautologous Tissue Substitute, Open Approach */
"05RP47Z" = "1" /* Replacement of Right External Jugular Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RP4JZ" = "1" /* Replacement of Right External Jugular Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05RP4KZ" = "1" /* Replacement of Right External Jugular Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RQ07Z" = "1" /* Replacement of Left External Jugular Vein with Autologous Tissue Substitute, Open Approach */
"05RQ0JZ" = "1" /* Replacement of Left External Jugular Vein with Synthetic Substitute, Open Approach */
"05RQ0KZ" = "1" /* Replacement of Left External Jugular Vein with Nonautologous Tissue Substitute, Open Approach */
"05RQ47Z" = "1" /* Replacement of Left External Jugular Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RQ4JZ" = "1" /* Replacement of Left External Jugular Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05RQ4KZ" = "1" /* Replacement of Left External Jugular Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RR07Z" = "1" /* Replacement of Right Vertebral Vein with Autologous Tissue Substitute, Open Approach */
"05RR0JZ" = "1" /* Replacement of Right Vertebral Vein with Synthetic Substitute, Open Approach */
"05RR0KZ" = "1" /* Replacement of Right Vertebral Vein with Nonautologous Tissue Substitute, Open Approach */
"05RR47Z" = "1" /* Replacement of Right Vertebral Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RR4JZ" = "1" /* Replacement of Right Vertebral Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05RR4KZ" = "1" /* Replacement of Right Vertebral Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RS07Z" = "1" /* Replacement of Left Vertebral Vein with Autologous Tissue Substitute, Open Approach */
"05RS0JZ" = "1" /* Replacement of Left Vertebral Vein with Synthetic Substitute, Open Approach */
"05RS0KZ" = "1" /* Replacement of Left Vertebral Vein with Nonautologous Tissue Substitute, Open Approach */
"05RS47Z" = "1" /* Replacement of Left Vertebral Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RS4JZ" = "1" /* Replacement of Left Vertebral Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05RS4KZ" = "1" /* Replacement of Left Vertebral Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RT07Z" = "1" /* Replacement of Right Face Vein with Autologous Tissue Substitute, Open Approach */
"05RT0JZ" = "1" /* Replacement of Right Face Vein with Synthetic Substitute, Open Approach */
"05RT0KZ" = "1" /* Replacement of Right Face Vein with Nonautologous Tissue Substitute, Open Approach */
"05RT47Z" = "1" /* Replacement of Right Face Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RT4JZ" = "1" /* Replacement of Right Face Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05RT4KZ" = "1" /* Replacement of Right Face Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RV07Z" = "1" /* Replacement of Left Face Vein with Autologous Tissue Substitute, Open Approach */
"05RV0JZ" = "1" /* Replacement of Left Face Vein with Synthetic Substitute, Open Approach */
"05RV0KZ" = "1" /* Replacement of Left Face Vein with Nonautologous Tissue Substitute, Open Approach */
"05RV47Z" = "1" /* Replacement of Left Face Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RV4JZ" = "1" /* Replacement of Left Face Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05RV4KZ" = "1" /* Replacement of Left Face Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RY07Z" = "1" /* Replacement of Upper Vein with Autologous Tissue Substitute, Open Approach */
"05RY0JZ" = "1" /* Replacement of Upper Vein with Synthetic Substitute, Open Approach */
"05RY0KZ" = "1" /* Replacement of Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"05RY47Z" = "1" /* Replacement of Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05RY4JZ" = "1" /* Replacement of Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05RY4KZ" = "1" /* Replacement of Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05S00ZZ" = "1" /* Reposition Azygos Vein, Open Approach */
"05S03ZZ" = "1" /* Reposition Azygos Vein, Percutaneous Approach */
"05S04ZZ" = "1" /* Reposition Azygos Vein, Percutaneous Endoscopic Approach */
"05S10ZZ" = "1" /* Reposition Hemiazygos Vein, Open Approach */
"05S13ZZ" = "1" /* Reposition Hemiazygos Vein, Percutaneous Approach */
"05S14ZZ" = "1" /* Reposition Hemiazygos Vein, Percutaneous Endoscopic Approach */
"05S30ZZ" = "1" /* Reposition Right Innominate Vein, Open Approach */
"05S33ZZ" = "1" /* Reposition Right Innominate Vein, Percutaneous Approach */
"05S34ZZ" = "1" /* Reposition Right Innominate Vein, Percutaneous Endoscopic Approach */
"05S40ZZ" = "1" /* Reposition Left Innominate Vein, Open Approach */
"05S43ZZ" = "1" /* Reposition Left Innominate Vein, Percutaneous Approach */
"05S44ZZ" = "1" /* Reposition Left Innominate Vein, Percutaneous Endoscopic Approach */
"05S50ZZ" = "1" /* Reposition Right Subclavian Vein, Open Approach */
"05S53ZZ" = "1" /* Reposition Right Subclavian Vein, Percutaneous Approach */
"05S54ZZ" = "1" /* Reposition Right Subclavian Vein, Percutaneous Endoscopic Approach */
"05S60ZZ" = "1" /* Reposition Left Subclavian Vein, Open Approach */
"05S63ZZ" = "1" /* Reposition Left Subclavian Vein, Percutaneous Approach */
"05S64ZZ" = "1" /* Reposition Left Subclavian Vein, Percutaneous Endoscopic Approach */
"05S70ZZ" = "1" /* Reposition Right Axillary Vein, Open Approach */
"05S73ZZ" = "1" /* Reposition Right Axillary Vein, Percutaneous Approach */
"05S74ZZ" = "1" /* Reposition Right Axillary Vein, Percutaneous Endoscopic Approach */
"05S80ZZ" = "1" /* Reposition Left Axillary Vein, Open Approach */
"05S83ZZ" = "1" /* Reposition Left Axillary Vein, Percutaneous Approach */
"05S84ZZ" = "1" /* Reposition Left Axillary Vein, Percutaneous Endoscopic Approach */
"05S90ZZ" = "1" /* Reposition Right Brachial Vein, Open Approach */
"05S93ZZ" = "1" /* Reposition Right Brachial Vein, Percutaneous Approach */
"05S94ZZ" = "1" /* Reposition Right Brachial Vein, Percutaneous Endoscopic Approach */
"05SA0ZZ" = "1" /* Reposition Left Brachial Vein, Open Approach */
"05SA3ZZ" = "1" /* Reposition Left Brachial Vein, Percutaneous Approach */
"05SA4ZZ" = "1" /* Reposition Left Brachial Vein, Percutaneous Endoscopic Approach */
"05SB0ZZ" = "1" /* Reposition Right Basilic Vein, Open Approach */
"05SB3ZZ" = "1" /* Reposition Right Basilic Vein, Percutaneous Approach */
"05SB4ZZ" = "1" /* Reposition Right Basilic Vein, Percutaneous Endoscopic Approach */
"05SC0ZZ" = "1" /* Reposition Left Basilic Vein, Open Approach */
"05SC3ZZ" = "1" /* Reposition Left Basilic Vein, Percutaneous Approach */
"05SC4ZZ" = "1" /* Reposition Left Basilic Vein, Percutaneous Endoscopic Approach */
"05SD0ZZ" = "1" /* Reposition Right Cephalic Vein, Open Approach */
"05SD3ZZ" = "1" /* Reposition Right Cephalic Vein, Percutaneous Approach */
"05SD4ZZ" = "1" /* Reposition Right Cephalic Vein, Percutaneous Endoscopic Approach */
"05SF0ZZ" = "1" /* Reposition Left Cephalic Vein, Open Approach */
"05SF3ZZ" = "1" /* Reposition Left Cephalic Vein, Percutaneous Approach */
"05SF4ZZ" = "1" /* Reposition Left Cephalic Vein, Percutaneous Endoscopic Approach */
"05SG0ZZ" = "1" /* Reposition Right Hand Vein, Open Approach */
"05SG3ZZ" = "1" /* Reposition Right Hand Vein, Percutaneous Approach */
"05SG4ZZ" = "1" /* Reposition Right Hand Vein, Percutaneous Endoscopic Approach */
"05SH0ZZ" = "1" /* Reposition Left Hand Vein, Open Approach */
"05SH3ZZ" = "1" /* Reposition Left Hand Vein, Percutaneous Approach */
"05SH4ZZ" = "1" /* Reposition Left Hand Vein, Percutaneous Endoscopic Approach */
"05SL0ZZ" = "1" /* Reposition Intracranial Vein, Open Approach */
"05SL3ZZ" = "1" /* Reposition Intracranial Vein, Percutaneous Approach */
"05SL4ZZ" = "1" /* Reposition Intracranial Vein, Percutaneous Endoscopic Approach */
"05SM0ZZ" = "1" /* Reposition Right Internal Jugular Vein, Open Approach */
"05SM3ZZ" = "1" /* Reposition Right Internal Jugular Vein, Percutaneous Approach */
"05SM4ZZ" = "1" /* Reposition Right Internal Jugular Vein, Percutaneous Endoscopic Approach */
"05SN0ZZ" = "1" /* Reposition Left Internal Jugular Vein, Open Approach */
"05SN3ZZ" = "1" /* Reposition Left Internal Jugular Vein, Percutaneous Approach */
"05SN4ZZ" = "1" /* Reposition Left Internal Jugular Vein, Percutaneous Endoscopic Approach */
"05SP0ZZ" = "1" /* Reposition Right External Jugular Vein, Open Approach */
"05SP3ZZ" = "1" /* Reposition Right External Jugular Vein, Percutaneous Approach */
"05SP4ZZ" = "1" /* Reposition Right External Jugular Vein, Percutaneous Endoscopic Approach */
"05SQ0ZZ" = "1" /* Reposition Left External Jugular Vein, Open Approach */
"05SQ3ZZ" = "1" /* Reposition Left External Jugular Vein, Percutaneous Approach */
"05SQ4ZZ" = "1" /* Reposition Left External Jugular Vein, Percutaneous Endoscopic Approach */
"05SR0ZZ" = "1" /* Reposition Right Vertebral Vein, Open Approach */
"05SR3ZZ" = "1" /* Reposition Right Vertebral Vein, Percutaneous Approach */
"05SR4ZZ" = "1" /* Reposition Right Vertebral Vein, Percutaneous Endoscopic Approach */
"05SS0ZZ" = "1" /* Reposition Left Vertebral Vein, Open Approach */
"05SS3ZZ" = "1" /* Reposition Left Vertebral Vein, Percutaneous Approach */
"05SS4ZZ" = "1" /* Reposition Left Vertebral Vein, Percutaneous Endoscopic Approach */
"05ST0ZZ" = "1" /* Reposition Right Face Vein, Open Approach */
"05ST3ZZ" = "1" /* Reposition Right Face Vein, Percutaneous Approach */
"05ST4ZZ" = "1" /* Reposition Right Face Vein, Percutaneous Endoscopic Approach */
"05SV0ZZ" = "1" /* Reposition Left Face Vein, Open Approach */
"05SV3ZZ" = "1" /* Reposition Left Face Vein, Percutaneous Approach */
"05SV4ZZ" = "1" /* Reposition Left Face Vein, Percutaneous Endoscopic Approach */
"05SY0ZZ" = "1" /* Reposition Upper Vein, Open Approach */
"05SY3ZZ" = "1" /* Reposition Upper Vein, Percutaneous Approach */
"05SY4ZZ" = "1" /* Reposition Upper Vein, Percutaneous Endoscopic Approach */
"05U007Z" = "1" /* Supplement Azygos Vein with Autologous Tissue Substitute, Open Approach */
"05U00JZ" = "1" /* Supplement Azygos Vein with Synthetic Substitute, Open Approach */
"05U00KZ" = "1" /* Supplement Azygos Vein with Nonautologous Tissue Substitute, Open Approach */
"05U037Z" = "1" /* Supplement Azygos Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05U03JZ" = "1" /* Supplement Azygos Vein with Synthetic Substitute, Percutaneous Approach */
"05U03KZ" = "1" /* Supplement Azygos Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05U047Z" = "1" /* Supplement Azygos Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05U04JZ" = "1" /* Supplement Azygos Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05U04KZ" = "1" /* Supplement Azygos Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05U107Z" = "1" /* Supplement Hemiazygos Vein with Autologous Tissue Substitute, Open Approach */
"05U10JZ" = "1" /* Supplement Hemiazygos Vein with Synthetic Substitute, Open Approach */
"05U10KZ" = "1" /* Supplement Hemiazygos Vein with Nonautologous Tissue Substitute, Open Approach */
"05U137Z" = "1" /* Supplement Hemiazygos Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05U13JZ" = "1" /* Supplement Hemiazygos Vein with Synthetic Substitute, Percutaneous Approach */
"05U13KZ" = "1" /* Supplement Hemiazygos Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05U147Z" = "1" /* Supplement Hemiazygos Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05U14JZ" = "1" /* Supplement Hemiazygos Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05U14KZ" = "1" /* Supplement Hemiazygos Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05U307Z" = "1" /* Supplement Right Innominate Vein with Autologous Tissue Substitute, Open Approach */
"05U30JZ" = "1" /* Supplement Right Innominate Vein with Synthetic Substitute, Open Approach */
"05U30KZ" = "1" /* Supplement Right Innominate Vein with Nonautologous Tissue Substitute, Open Approach */
"05U337Z" = "1" /* Supplement Right Innominate Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05U33JZ" = "1" /* Supplement Right Innominate Vein with Synthetic Substitute, Percutaneous Approach */
"05U33KZ" = "1" /* Supplement Right Innominate Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05U347Z" = "1" /* Supplement Right Innominate Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05U34JZ" = "1" /* Supplement Right Innominate Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05U34KZ" = "1" /* Supplement Right Innominate Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05U407Z" = "1" /* Supplement Left Innominate Vein with Autologous Tissue Substitute, Open Approach */
"05U40JZ" = "1" /* Supplement Left Innominate Vein with Synthetic Substitute, Open Approach */
"05U40KZ" = "1" /* Supplement Left Innominate Vein with Nonautologous Tissue Substitute, Open Approach */
"05U437Z" = "1" /* Supplement Left Innominate Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05U43JZ" = "1" /* Supplement Left Innominate Vein with Synthetic Substitute, Percutaneous Approach */
"05U43KZ" = "1" /* Supplement Left Innominate Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05U447Z" = "1" /* Supplement Left Innominate Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05U44JZ" = "1" /* Supplement Left Innominate Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05U44KZ" = "1" /* Supplement Left Innominate Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05U507Z" = "1" /* Supplement Right Subclavian Vein with Autologous Tissue Substitute, Open Approach */
"05U50JZ" = "1" /* Supplement Right Subclavian Vein with Synthetic Substitute, Open Approach */
"05U50KZ" = "1" /* Supplement Right Subclavian Vein with Nonautologous Tissue Substitute, Open Approach */
"05U537Z" = "1" /* Supplement Right Subclavian Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05U53JZ" = "1" /* Supplement Right Subclavian Vein with Synthetic Substitute, Percutaneous Approach */
"05U53KZ" = "1" /* Supplement Right Subclavian Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05U547Z" = "1" /* Supplement Right Subclavian Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05U54JZ" = "1" /* Supplement Right Subclavian Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05U54KZ" = "1" /* Supplement Right Subclavian Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05U607Z" = "1" /* Supplement Left Subclavian Vein with Autologous Tissue Substitute, Open Approach */
"05U60JZ" = "1" /* Supplement Left Subclavian Vein with Synthetic Substitute, Open Approach */
"05U60KZ" = "1" /* Supplement Left Subclavian Vein with Nonautologous Tissue Substitute, Open Approach */
"05U637Z" = "1" /* Supplement Left Subclavian Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05U63JZ" = "1" /* Supplement Left Subclavian Vein with Synthetic Substitute, Percutaneous Approach */
"05U63KZ" = "1" /* Supplement Left Subclavian Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05U647Z" = "1" /* Supplement Left Subclavian Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05U64JZ" = "1" /* Supplement Left Subclavian Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05U64KZ" = "1" /* Supplement Left Subclavian Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05U707Z" = "1" /* Supplement Right Axillary Vein with Autologous Tissue Substitute, Open Approach */
"05U70JZ" = "1" /* Supplement Right Axillary Vein with Synthetic Substitute, Open Approach */
"05U70KZ" = "1" /* Supplement Right Axillary Vein with Nonautologous Tissue Substitute, Open Approach */
"05U737Z" = "1" /* Supplement Right Axillary Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05U73JZ" = "1" /* Supplement Right Axillary Vein with Synthetic Substitute, Percutaneous Approach */
"05U73KZ" = "1" /* Supplement Right Axillary Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05U747Z" = "1" /* Supplement Right Axillary Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05U74JZ" = "1" /* Supplement Right Axillary Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05U74KZ" = "1" /* Supplement Right Axillary Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05U807Z" = "1" /* Supplement Left Axillary Vein with Autologous Tissue Substitute, Open Approach */
"05U80JZ" = "1" /* Supplement Left Axillary Vein with Synthetic Substitute, Open Approach */
"05U80KZ" = "1" /* Supplement Left Axillary Vein with Nonautologous Tissue Substitute, Open Approach */
"05U837Z" = "1" /* Supplement Left Axillary Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05U83JZ" = "1" /* Supplement Left Axillary Vein with Synthetic Substitute, Percutaneous Approach */
"05U83KZ" = "1" /* Supplement Left Axillary Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05U847Z" = "1" /* Supplement Left Axillary Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05U84JZ" = "1" /* Supplement Left Axillary Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05U84KZ" = "1" /* Supplement Left Axillary Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05U907Z" = "1" /* Supplement Right Brachial Vein with Autologous Tissue Substitute, Open Approach */
"05U90JZ" = "1" /* Supplement Right Brachial Vein with Synthetic Substitute, Open Approach */
"05U90KZ" = "1" /* Supplement Right Brachial Vein with Nonautologous Tissue Substitute, Open Approach */
"05U937Z" = "1" /* Supplement Right Brachial Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05U93JZ" = "1" /* Supplement Right Brachial Vein with Synthetic Substitute, Percutaneous Approach */
"05U93KZ" = "1" /* Supplement Right Brachial Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05U947Z" = "1" /* Supplement Right Brachial Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05U94JZ" = "1" /* Supplement Right Brachial Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05U94KZ" = "1" /* Supplement Right Brachial Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UA07Z" = "1" /* Supplement Left Brachial Vein with Autologous Tissue Substitute, Open Approach */
"05UA0JZ" = "1" /* Supplement Left Brachial Vein with Synthetic Substitute, Open Approach */
"05UA0KZ" = "1" /* Supplement Left Brachial Vein with Nonautologous Tissue Substitute, Open Approach */
"05UA37Z" = "1" /* Supplement Left Brachial Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05UA3JZ" = "1" /* Supplement Left Brachial Vein with Synthetic Substitute, Percutaneous Approach */
"05UA3KZ" = "1" /* Supplement Left Brachial Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05UA47Z" = "1" /* Supplement Left Brachial Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UA4JZ" = "1" /* Supplement Left Brachial Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05UA4KZ" = "1" /* Supplement Left Brachial Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UB07Z" = "1" /* Supplement Right Basilic Vein with Autologous Tissue Substitute, Open Approach */
"05UB0JZ" = "1" /* Supplement Right Basilic Vein with Synthetic Substitute, Open Approach */
"05UB0KZ" = "1" /* Supplement Right Basilic Vein with Nonautologous Tissue Substitute, Open Approach */
"05UB37Z" = "1" /* Supplement Right Basilic Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05UB3JZ" = "1" /* Supplement Right Basilic Vein with Synthetic Substitute, Percutaneous Approach */
"05UB3KZ" = "1" /* Supplement Right Basilic Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05UB47Z" = "1" /* Supplement Right Basilic Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UB4JZ" = "1" /* Supplement Right Basilic Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05UB4KZ" = "1" /* Supplement Right Basilic Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UC07Z" = "1" /* Supplement Left Basilic Vein with Autologous Tissue Substitute, Open Approach */
"05UC0JZ" = "1" /* Supplement Left Basilic Vein with Synthetic Substitute, Open Approach */
"05UC0KZ" = "1" /* Supplement Left Basilic Vein with Nonautologous Tissue Substitute, Open Approach */
"05UC37Z" = "1" /* Supplement Left Basilic Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05UC3JZ" = "1" /* Supplement Left Basilic Vein with Synthetic Substitute, Percutaneous Approach */
"05UC3KZ" = "1" /* Supplement Left Basilic Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05UC47Z" = "1" /* Supplement Left Basilic Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UC4JZ" = "1" /* Supplement Left Basilic Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05UC4KZ" = "1" /* Supplement Left Basilic Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UD07Z" = "1" /* Supplement Right Cephalic Vein with Autologous Tissue Substitute, Open Approach */
"05UD0JZ" = "1" /* Supplement Right Cephalic Vein with Synthetic Substitute, Open Approach */
"05UD0KZ" = "1" /* Supplement Right Cephalic Vein with Nonautologous Tissue Substitute, Open Approach */
"05UD37Z" = "1" /* Supplement Right Cephalic Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05UD3JZ" = "1" /* Supplement Right Cephalic Vein with Synthetic Substitute, Percutaneous Approach */
"05UD3KZ" = "1" /* Supplement Right Cephalic Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05UD47Z" = "1" /* Supplement Right Cephalic Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UD4JZ" = "1" /* Supplement Right Cephalic Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05UD4KZ" = "1" /* Supplement Right Cephalic Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UF07Z" = "1" /* Supplement Left Cephalic Vein with Autologous Tissue Substitute, Open Approach */
"05UF0JZ" = "1" /* Supplement Left Cephalic Vein with Synthetic Substitute, Open Approach */
"05UF0KZ" = "1" /* Supplement Left Cephalic Vein with Nonautologous Tissue Substitute, Open Approach */
"05UF37Z" = "1" /* Supplement Left Cephalic Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05UF3JZ" = "1" /* Supplement Left Cephalic Vein with Synthetic Substitute, Percutaneous Approach */
"05UF3KZ" = "1" /* Supplement Left Cephalic Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05UF47Z" = "1" /* Supplement Left Cephalic Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UF4JZ" = "1" /* Supplement Left Cephalic Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05UF4KZ" = "1" /* Supplement Left Cephalic Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UG07Z" = "1" /* Supplement Right Hand Vein with Autologous Tissue Substitute, Open Approach */
"05UG0JZ" = "1" /* Supplement Right Hand Vein with Synthetic Substitute, Open Approach */
"05UG0KZ" = "1" /* Supplement Right Hand Vein with Nonautologous Tissue Substitute, Open Approach */
"05UG37Z" = "1" /* Supplement Right Hand Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05UG3JZ" = "1" /* Supplement Right Hand Vein with Synthetic Substitute, Percutaneous Approach */
"05UG3KZ" = "1" /* Supplement Right Hand Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05UG47Z" = "1" /* Supplement Right Hand Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UG4JZ" = "1" /* Supplement Right Hand Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05UG4KZ" = "1" /* Supplement Right Hand Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UH07Z" = "1" /* Supplement Left Hand Vein with Autologous Tissue Substitute, Open Approach */
"05UH0JZ" = "1" /* Supplement Left Hand Vein with Synthetic Substitute, Open Approach */
"05UH0KZ" = "1" /* Supplement Left Hand Vein with Nonautologous Tissue Substitute, Open Approach */
"05UH37Z" = "1" /* Supplement Left Hand Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05UH3JZ" = "1" /* Supplement Left Hand Vein with Synthetic Substitute, Percutaneous Approach */
"05UH3KZ" = "1" /* Supplement Left Hand Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05UH47Z" = "1" /* Supplement Left Hand Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UH4JZ" = "1" /* Supplement Left Hand Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05UH4KZ" = "1" /* Supplement Left Hand Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UL07Z" = "1" /* Supplement Intracranial Vein with Autologous Tissue Substitute, Open Approach */
"05UL0JZ" = "1" /* Supplement Intracranial Vein with Synthetic Substitute, Open Approach */
"05UL0KZ" = "1" /* Supplement Intracranial Vein with Nonautologous Tissue Substitute, Open Approach */
"05UL37Z" = "1" /* Supplement Intracranial Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05UL3JZ" = "1" /* Supplement Intracranial Vein with Synthetic Substitute, Percutaneous Approach */
"05UL3KZ" = "1" /* Supplement Intracranial Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05UL47Z" = "1" /* Supplement Intracranial Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UL4JZ" = "1" /* Supplement Intracranial Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05UL4KZ" = "1" /* Supplement Intracranial Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UM07Z" = "1" /* Supplement Right Internal Jugular Vein with Autologous Tissue Substitute, Open Approach */
"05UM0JZ" = "1" /* Supplement Right Internal Jugular Vein with Synthetic Substitute, Open Approach */
"05UM0KZ" = "1" /* Supplement Right Internal Jugular Vein with Nonautologous Tissue Substitute, Open Approach */
"05UM37Z" = "1" /* Supplement Right Internal Jugular Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05UM3JZ" = "1" /* Supplement Right Internal Jugular Vein with Synthetic Substitute, Percutaneous Approach */
"05UM3KZ" = "1" /* Supplement Right Internal Jugular Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05UM47Z" = "1" /* Supplement Right Internal Jugular Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UM4JZ" = "1" /* Supplement Right Internal Jugular Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05UM4KZ" = "1" /* Supplement Right Internal Jugular Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UN07Z" = "1" /* Supplement Left Internal Jugular Vein with Autologous Tissue Substitute, Open Approach */
"05UN0JZ" = "1" /* Supplement Left Internal Jugular Vein with Synthetic Substitute, Open Approach */
"05UN0KZ" = "1" /* Supplement Left Internal Jugular Vein with Nonautologous Tissue Substitute, Open Approach */
"05UN37Z" = "1" /* Supplement Left Internal Jugular Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05UN3JZ" = "1" /* Supplement Left Internal Jugular Vein with Synthetic Substitute, Percutaneous Approach */
"05UN3KZ" = "1" /* Supplement Left Internal Jugular Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05UN47Z" = "1" /* Supplement Left Internal Jugular Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UN4JZ" = "1" /* Supplement Left Internal Jugular Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05UN4KZ" = "1" /* Supplement Left Internal Jugular Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UP07Z" = "1" /* Supplement Right External Jugular Vein with Autologous Tissue Substitute, Open Approach */
"05UP0JZ" = "1" /* Supplement Right External Jugular Vein with Synthetic Substitute, Open Approach */
"05UP0KZ" = "1" /* Supplement Right External Jugular Vein with Nonautologous Tissue Substitute, Open Approach */
"05UP37Z" = "1" /* Supplement Right External Jugular Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05UP3JZ" = "1" /* Supplement Right External Jugular Vein with Synthetic Substitute, Percutaneous Approach */
"05UP3KZ" = "1" /* Supplement Right External Jugular Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05UP47Z" = "1" /* Supplement Right External Jugular Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UP4JZ" = "1" /* Supplement Right External Jugular Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05UP4KZ" = "1" /* Supplement Right External Jugular Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UQ07Z" = "1" /* Supplement Left External Jugular Vein with Autologous Tissue Substitute, Open Approach */
"05UQ0JZ" = "1" /* Supplement Left External Jugular Vein with Synthetic Substitute, Open Approach */
"05UQ0KZ" = "1" /* Supplement Left External Jugular Vein with Nonautologous Tissue Substitute, Open Approach */
"05UQ37Z" = "1" /* Supplement Left External Jugular Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05UQ3JZ" = "1" /* Supplement Left External Jugular Vein with Synthetic Substitute, Percutaneous Approach */
"05UQ3KZ" = "1" /* Supplement Left External Jugular Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05UQ47Z" = "1" /* Supplement Left External Jugular Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UQ4JZ" = "1" /* Supplement Left External Jugular Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05UQ4KZ" = "1" /* Supplement Left External Jugular Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UR07Z" = "1" /* Supplement Right Vertebral Vein with Autologous Tissue Substitute, Open Approach */
"05UR0JZ" = "1" /* Supplement Right Vertebral Vein with Synthetic Substitute, Open Approach */
"05UR0KZ" = "1" /* Supplement Right Vertebral Vein with Nonautologous Tissue Substitute, Open Approach */
"05UR37Z" = "1" /* Supplement Right Vertebral Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05UR3JZ" = "1" /* Supplement Right Vertebral Vein with Synthetic Substitute, Percutaneous Approach */
"05UR3KZ" = "1" /* Supplement Right Vertebral Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05UR47Z" = "1" /* Supplement Right Vertebral Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UR4JZ" = "1" /* Supplement Right Vertebral Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05UR4KZ" = "1" /* Supplement Right Vertebral Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05US07Z" = "1" /* Supplement Left Vertebral Vein with Autologous Tissue Substitute, Open Approach */
"05US0JZ" = "1" /* Supplement Left Vertebral Vein with Synthetic Substitute, Open Approach */
"05US0KZ" = "1" /* Supplement Left Vertebral Vein with Nonautologous Tissue Substitute, Open Approach */
"05US37Z" = "1" /* Supplement Left Vertebral Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05US3JZ" = "1" /* Supplement Left Vertebral Vein with Synthetic Substitute, Percutaneous Approach */
"05US3KZ" = "1" /* Supplement Left Vertebral Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05US47Z" = "1" /* Supplement Left Vertebral Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05US4JZ" = "1" /* Supplement Left Vertebral Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05US4KZ" = "1" /* Supplement Left Vertebral Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UT07Z" = "1" /* Supplement Right Face Vein with Autologous Tissue Substitute, Open Approach */
"05UT0JZ" = "1" /* Supplement Right Face Vein with Synthetic Substitute, Open Approach */
"05UT0KZ" = "1" /* Supplement Right Face Vein with Nonautologous Tissue Substitute, Open Approach */
"05UT37Z" = "1" /* Supplement Right Face Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05UT3JZ" = "1" /* Supplement Right Face Vein with Synthetic Substitute, Percutaneous Approach */
"05UT3KZ" = "1" /* Supplement Right Face Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05UT47Z" = "1" /* Supplement Right Face Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UT4JZ" = "1" /* Supplement Right Face Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05UT4KZ" = "1" /* Supplement Right Face Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UV07Z" = "1" /* Supplement Left Face Vein with Autologous Tissue Substitute, Open Approach */
"05UV0JZ" = "1" /* Supplement Left Face Vein with Synthetic Substitute, Open Approach */
"05UV0KZ" = "1" /* Supplement Left Face Vein with Nonautologous Tissue Substitute, Open Approach */
"05UV37Z" = "1" /* Supplement Left Face Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05UV3JZ" = "1" /* Supplement Left Face Vein with Synthetic Substitute, Percutaneous Approach */
"05UV3KZ" = "1" /* Supplement Left Face Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05UV47Z" = "1" /* Supplement Left Face Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UV4JZ" = "1" /* Supplement Left Face Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05UV4KZ" = "1" /* Supplement Left Face Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UY07Z" = "1" /* Supplement Upper Vein with Autologous Tissue Substitute, Open Approach */
"05UY0JZ" = "1" /* Supplement Upper Vein with Synthetic Substitute, Open Approach */
"05UY0KZ" = "1" /* Supplement Upper Vein with Nonautologous Tissue Substitute, Open Approach */
"05UY37Z" = "1" /* Supplement Upper Vein with Autologous Tissue Substitute, Percutaneous Approach */
"05UY3JZ" = "1" /* Supplement Upper Vein with Synthetic Substitute, Percutaneous Approach */
"05UY3KZ" = "1" /* Supplement Upper Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"05UY47Z" = "1" /* Supplement Upper Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05UY4JZ" = "1" /* Supplement Upper Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"05UY4KZ" = "1" /* Supplement Upper Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"05V00CZ" = "1" /* Restriction of Azygos Vein with Extraluminal Device, Open Approach */
"05V00DZ" = "1" /* Restriction of Azygos Vein with Intraluminal Device, Open Approach */
"05V00ZZ" = "1" /* Restriction of Azygos Vein, Open Approach */
"05V03CZ" = "1" /* Restriction of Azygos Vein with Extraluminal Device, Percutaneous Approach */
"05V03DZ" = "1" /* Restriction of Azygos Vein with Intraluminal Device, Percutaneous Approach */
"05V03ZZ" = "1" /* Restriction of Azygos Vein, Percutaneous Approach */
"05V04CZ" = "1" /* Restriction of Azygos Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05V04DZ" = "1" /* Restriction of Azygos Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05V04ZZ" = "1" /* Restriction of Azygos Vein, Percutaneous Endoscopic Approach */
"05V10CZ" = "1" /* Restriction of Hemiazygos Vein with Extraluminal Device, Open Approach */
"05V10DZ" = "1" /* Restriction of Hemiazygos Vein with Intraluminal Device, Open Approach */
"05V10ZZ" = "1" /* Restriction of Hemiazygos Vein, Open Approach */
"05V13CZ" = "1" /* Restriction of Hemiazygos Vein with Extraluminal Device, Percutaneous Approach */
"05V13DZ" = "1" /* Restriction of Hemiazygos Vein with Intraluminal Device, Percutaneous Approach */
"05V13ZZ" = "1" /* Restriction of Hemiazygos Vein, Percutaneous Approach */
"05V14CZ" = "1" /* Restriction of Hemiazygos Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05V14DZ" = "1" /* Restriction of Hemiazygos Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05V14ZZ" = "1" /* Restriction of Hemiazygos Vein, Percutaneous Endoscopic Approach */
"05V30CZ" = "1" /* Restriction of Right Innominate Vein with Extraluminal Device, Open Approach */
"05V30DZ" = "1" /* Restriction of Right Innominate Vein with Intraluminal Device, Open Approach */
"05V30ZZ" = "1" /* Restriction of Right Innominate Vein, Open Approach */
"05V33CZ" = "1" /* Restriction of Right Innominate Vein with Extraluminal Device, Percutaneous Approach */
"05V33DZ" = "1" /* Restriction of Right Innominate Vein with Intraluminal Device, Percutaneous Approach */
"05V33ZZ" = "1" /* Restriction of Right Innominate Vein, Percutaneous Approach */
"05V34CZ" = "1" /* Restriction of Right Innominate Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05V34DZ" = "1" /* Restriction of Right Innominate Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05V34ZZ" = "1" /* Restriction of Right Innominate Vein, Percutaneous Endoscopic Approach */
"05V40CZ" = "1" /* Restriction of Left Innominate Vein with Extraluminal Device, Open Approach */
"05V40DZ" = "1" /* Restriction of Left Innominate Vein with Intraluminal Device, Open Approach */
"05V40ZZ" = "1" /* Restriction of Left Innominate Vein, Open Approach */
"05V43CZ" = "1" /* Restriction of Left Innominate Vein with Extraluminal Device, Percutaneous Approach */
"05V43DZ" = "1" /* Restriction of Left Innominate Vein with Intraluminal Device, Percutaneous Approach */
"05V43ZZ" = "1" /* Restriction of Left Innominate Vein, Percutaneous Approach */
"05V44CZ" = "1" /* Restriction of Left Innominate Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05V44DZ" = "1" /* Restriction of Left Innominate Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05V44ZZ" = "1" /* Restriction of Left Innominate Vein, Percutaneous Endoscopic Approach */
"05V50CZ" = "1" /* Restriction of Right Subclavian Vein with Extraluminal Device, Open Approach */
"05V50DZ" = "1" /* Restriction of Right Subclavian Vein with Intraluminal Device, Open Approach */
"05V50ZZ" = "1" /* Restriction of Right Subclavian Vein, Open Approach */
"05V53CZ" = "1" /* Restriction of Right Subclavian Vein with Extraluminal Device, Percutaneous Approach */
"05V53DZ" = "1" /* Restriction of Right Subclavian Vein with Intraluminal Device, Percutaneous Approach */
"05V53ZZ" = "1" /* Restriction of Right Subclavian Vein, Percutaneous Approach */
"05V54CZ" = "1" /* Restriction of Right Subclavian Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05V54DZ" = "1" /* Restriction of Right Subclavian Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05V54ZZ" = "1" /* Restriction of Right Subclavian Vein, Percutaneous Endoscopic Approach */
"05V60CZ" = "1" /* Restriction of Left Subclavian Vein with Extraluminal Device, Open Approach */
"05V60DZ" = "1" /* Restriction of Left Subclavian Vein with Intraluminal Device, Open Approach */
"05V60ZZ" = "1" /* Restriction of Left Subclavian Vein, Open Approach */
"05V63CZ" = "1" /* Restriction of Left Subclavian Vein with Extraluminal Device, Percutaneous Approach */
"05V63DZ" = "1" /* Restriction of Left Subclavian Vein with Intraluminal Device, Percutaneous Approach */
"05V63ZZ" = "1" /* Restriction of Left Subclavian Vein, Percutaneous Approach */
"05V64CZ" = "1" /* Restriction of Left Subclavian Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05V64DZ" = "1" /* Restriction of Left Subclavian Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05V64ZZ" = "1" /* Restriction of Left Subclavian Vein, Percutaneous Endoscopic Approach */
"05V70CZ" = "1" /* Restriction of Right Axillary Vein with Extraluminal Device, Open Approach */
"05V70DZ" = "1" /* Restriction of Right Axillary Vein with Intraluminal Device, Open Approach */
"05V70ZZ" = "1" /* Restriction of Right Axillary Vein, Open Approach */
"05V73CZ" = "1" /* Restriction of Right Axillary Vein with Extraluminal Device, Percutaneous Approach */
"05V73DZ" = "1" /* Restriction of Right Axillary Vein with Intraluminal Device, Percutaneous Approach */
"05V73ZZ" = "1" /* Restriction of Right Axillary Vein, Percutaneous Approach */
"05V74CZ" = "1" /* Restriction of Right Axillary Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05V74DZ" = "1" /* Restriction of Right Axillary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05V74ZZ" = "1" /* Restriction of Right Axillary Vein, Percutaneous Endoscopic Approach */
"05V80CZ" = "1" /* Restriction of Left Axillary Vein with Extraluminal Device, Open Approach */
"05V80DZ" = "1" /* Restriction of Left Axillary Vein with Intraluminal Device, Open Approach */
"05V80ZZ" = "1" /* Restriction of Left Axillary Vein, Open Approach */
"05V83CZ" = "1" /* Restriction of Left Axillary Vein with Extraluminal Device, Percutaneous Approach */
"05V83DZ" = "1" /* Restriction of Left Axillary Vein with Intraluminal Device, Percutaneous Approach */
"05V83ZZ" = "1" /* Restriction of Left Axillary Vein, Percutaneous Approach */
"05V84CZ" = "1" /* Restriction of Left Axillary Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05V84DZ" = "1" /* Restriction of Left Axillary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05V84ZZ" = "1" /* Restriction of Left Axillary Vein, Percutaneous Endoscopic Approach */
"05V90CZ" = "1" /* Restriction of Right Brachial Vein with Extraluminal Device, Open Approach */
"05V90DZ" = "1" /* Restriction of Right Brachial Vein with Intraluminal Device, Open Approach */
"05V90ZZ" = "1" /* Restriction of Right Brachial Vein, Open Approach */
"05V93CZ" = "1" /* Restriction of Right Brachial Vein with Extraluminal Device, Percutaneous Approach */
"05V93DZ" = "1" /* Restriction of Right Brachial Vein with Intraluminal Device, Percutaneous Approach */
"05V93ZZ" = "1" /* Restriction of Right Brachial Vein, Percutaneous Approach */
"05V94CZ" = "1" /* Restriction of Right Brachial Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05V94DZ" = "1" /* Restriction of Right Brachial Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05V94ZZ" = "1" /* Restriction of Right Brachial Vein, Percutaneous Endoscopic Approach */
"05VA0CZ" = "1" /* Restriction of Left Brachial Vein with Extraluminal Device, Open Approach */
"05VA0DZ" = "1" /* Restriction of Left Brachial Vein with Intraluminal Device, Open Approach */
"05VA0ZZ" = "1" /* Restriction of Left Brachial Vein, Open Approach */
"05VA3CZ" = "1" /* Restriction of Left Brachial Vein with Extraluminal Device, Percutaneous Approach */
"05VA3DZ" = "1" /* Restriction of Left Brachial Vein with Intraluminal Device, Percutaneous Approach */
"05VA3ZZ" = "1" /* Restriction of Left Brachial Vein, Percutaneous Approach */
"05VA4CZ" = "1" /* Restriction of Left Brachial Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05VA4DZ" = "1" /* Restriction of Left Brachial Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05VA4ZZ" = "1" /* Restriction of Left Brachial Vein, Percutaneous Endoscopic Approach */
"05VB0CZ" = "1" /* Restriction of Right Basilic Vein with Extraluminal Device, Open Approach */
"05VB0DZ" = "1" /* Restriction of Right Basilic Vein with Intraluminal Device, Open Approach */
"05VB0ZZ" = "1" /* Restriction of Right Basilic Vein, Open Approach */
"05VB3CZ" = "1" /* Restriction of Right Basilic Vein with Extraluminal Device, Percutaneous Approach */
"05VB3DZ" = "1" /* Restriction of Right Basilic Vein with Intraluminal Device, Percutaneous Approach */
"05VB3ZZ" = "1" /* Restriction of Right Basilic Vein, Percutaneous Approach */
"05VB4CZ" = "1" /* Restriction of Right Basilic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05VB4DZ" = "1" /* Restriction of Right Basilic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05VB4ZZ" = "1" /* Restriction of Right Basilic Vein, Percutaneous Endoscopic Approach */
"05VC0CZ" = "1" /* Restriction of Left Basilic Vein with Extraluminal Device, Open Approach */
"05VC0DZ" = "1" /* Restriction of Left Basilic Vein with Intraluminal Device, Open Approach */
"05VC0ZZ" = "1" /* Restriction of Left Basilic Vein, Open Approach */
"05VC3CZ" = "1" /* Restriction of Left Basilic Vein with Extraluminal Device, Percutaneous Approach */
"05VC3DZ" = "1" /* Restriction of Left Basilic Vein with Intraluminal Device, Percutaneous Approach */
"05VC3ZZ" = "1" /* Restriction of Left Basilic Vein, Percutaneous Approach */
"05VC4CZ" = "1" /* Restriction of Left Basilic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05VC4DZ" = "1" /* Restriction of Left Basilic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05VC4ZZ" = "1" /* Restriction of Left Basilic Vein, Percutaneous Endoscopic Approach */
"05VD0CZ" = "1" /* Restriction of Right Cephalic Vein with Extraluminal Device, Open Approach */
"05VD0DZ" = "1" /* Restriction of Right Cephalic Vein with Intraluminal Device, Open Approach */
"05VD0ZZ" = "1" /* Restriction of Right Cephalic Vein, Open Approach */
"05VD3CZ" = "1" /* Restriction of Right Cephalic Vein with Extraluminal Device, Percutaneous Approach */
"05VD3DZ" = "1" /* Restriction of Right Cephalic Vein with Intraluminal Device, Percutaneous Approach */
"05VD3ZZ" = "1" /* Restriction of Right Cephalic Vein, Percutaneous Approach */
"05VD4CZ" = "1" /* Restriction of Right Cephalic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05VD4DZ" = "1" /* Restriction of Right Cephalic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05VD4ZZ" = "1" /* Restriction of Right Cephalic Vein, Percutaneous Endoscopic Approach */
"05VF0CZ" = "1" /* Restriction of Left Cephalic Vein with Extraluminal Device, Open Approach */
"05VF0DZ" = "1" /* Restriction of Left Cephalic Vein with Intraluminal Device, Open Approach */
"05VF0ZZ" = "1" /* Restriction of Left Cephalic Vein, Open Approach */
"05VF3CZ" = "1" /* Restriction of Left Cephalic Vein with Extraluminal Device, Percutaneous Approach */
"05VF3DZ" = "1" /* Restriction of Left Cephalic Vein with Intraluminal Device, Percutaneous Approach */
"05VF3ZZ" = "1" /* Restriction of Left Cephalic Vein, Percutaneous Approach */
"05VF4CZ" = "1" /* Restriction of Left Cephalic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05VF4DZ" = "1" /* Restriction of Left Cephalic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05VF4ZZ" = "1" /* Restriction of Left Cephalic Vein, Percutaneous Endoscopic Approach */
"05VG0CZ" = "1" /* Restriction of Right Hand Vein with Extraluminal Device, Open Approach */
"05VG0DZ" = "1" /* Restriction of Right Hand Vein with Intraluminal Device, Open Approach */
"05VG0ZZ" = "1" /* Restriction of Right Hand Vein, Open Approach */
"05VG3CZ" = "1" /* Restriction of Right Hand Vein with Extraluminal Device, Percutaneous Approach */
"05VG3DZ" = "1" /* Restriction of Right Hand Vein with Intraluminal Device, Percutaneous Approach */
"05VG3ZZ" = "1" /* Restriction of Right Hand Vein, Percutaneous Approach */
"05VG4CZ" = "1" /* Restriction of Right Hand Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05VG4DZ" = "1" /* Restriction of Right Hand Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05VG4ZZ" = "1" /* Restriction of Right Hand Vein, Percutaneous Endoscopic Approach */
"05VH0CZ" = "1" /* Restriction of Left Hand Vein with Extraluminal Device, Open Approach */
"05VH0DZ" = "1" /* Restriction of Left Hand Vein with Intraluminal Device, Open Approach */
"05VH0ZZ" = "1" /* Restriction of Left Hand Vein, Open Approach */
"05VH3CZ" = "1" /* Restriction of Left Hand Vein with Extraluminal Device, Percutaneous Approach */
"05VH3DZ" = "1" /* Restriction of Left Hand Vein with Intraluminal Device, Percutaneous Approach */
"05VH3ZZ" = "1" /* Restriction of Left Hand Vein, Percutaneous Approach */
"05VH4CZ" = "1" /* Restriction of Left Hand Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05VH4DZ" = "1" /* Restriction of Left Hand Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05VH4ZZ" = "1" /* Restriction of Left Hand Vein, Percutaneous Endoscopic Approach */
"05VL0CZ" = "1" /* Restriction of Intracranial Vein with Extraluminal Device, Open Approach */
"05VL0DZ" = "1" /* Restriction of Intracranial Vein with Intraluminal Device, Open Approach */
"05VL0ZZ" = "1" /* Restriction of Intracranial Vein, Open Approach */
"05VL3CZ" = "1" /* Restriction of Intracranial Vein with Extraluminal Device, Percutaneous Approach */
"05VL3DZ" = "1" /* Restriction of Intracranial Vein with Intraluminal Device, Percutaneous Approach */
"05VL3ZZ" = "1" /* Restriction of Intracranial Vein, Percutaneous Approach */
"05VL4CZ" = "1" /* Restriction of Intracranial Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05VL4DZ" = "1" /* Restriction of Intracranial Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05VL4ZZ" = "1" /* Restriction of Intracranial Vein, Percutaneous Endoscopic Approach */
"05VM0CZ" = "1" /* Restriction of Right Internal Jugular Vein with Extraluminal Device, Open Approach */
"05VM0DZ" = "1" /* Restriction of Right Internal Jugular Vein with Intraluminal Device, Open Approach */
"05VM0ZZ" = "1" /* Restriction of Right Internal Jugular Vein, Open Approach */
"05VM3CZ" = "1" /* Restriction of Right Internal Jugular Vein with Extraluminal Device, Percutaneous Approach */
"05VM3DZ" = "1" /* Restriction of Right Internal Jugular Vein with Intraluminal Device, Percutaneous Approach */
"05VM3ZZ" = "1" /* Restriction of Right Internal Jugular Vein, Percutaneous Approach */
"05VM4CZ" = "1" /* Restriction of Right Internal Jugular Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05VM4DZ" = "1" /* Restriction of Right Internal Jugular Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05VM4ZZ" = "1" /* Restriction of Right Internal Jugular Vein, Percutaneous Endoscopic Approach */
"05VN0CZ" = "1" /* Restriction of Left Internal Jugular Vein with Extraluminal Device, Open Approach */
"05VN0DZ" = "1" /* Restriction of Left Internal Jugular Vein with Intraluminal Device, Open Approach */
"05VN0ZZ" = "1" /* Restriction of Left Internal Jugular Vein, Open Approach */
"05VN3CZ" = "1" /* Restriction of Left Internal Jugular Vein with Extraluminal Device, Percutaneous Approach */
"05VN3DZ" = "1" /* Restriction of Left Internal Jugular Vein with Intraluminal Device, Percutaneous Approach */
"05VN3ZZ" = "1" /* Restriction of Left Internal Jugular Vein, Percutaneous Approach */
"05VN4CZ" = "1" /* Restriction of Left Internal Jugular Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05VN4DZ" = "1" /* Restriction of Left Internal Jugular Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05VN4ZZ" = "1" /* Restriction of Left Internal Jugular Vein, Percutaneous Endoscopic Approach */
"05VP0CZ" = "1" /* Restriction of Right External Jugular Vein with Extraluminal Device, Open Approach */
"05VP0DZ" = "1" /* Restriction of Right External Jugular Vein with Intraluminal Device, Open Approach */
"05VP0ZZ" = "1" /* Restriction of Right External Jugular Vein, Open Approach */
"05VP3CZ" = "1" /* Restriction of Right External Jugular Vein with Extraluminal Device, Percutaneous Approach */
"05VP3DZ" = "1" /* Restriction of Right External Jugular Vein with Intraluminal Device, Percutaneous Approach */
"05VP3ZZ" = "1" /* Restriction of Right External Jugular Vein, Percutaneous Approach */
"05VP4CZ" = "1" /* Restriction of Right External Jugular Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05VP4DZ" = "1" /* Restriction of Right External Jugular Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05VP4ZZ" = "1" /* Restriction of Right External Jugular Vein, Percutaneous Endoscopic Approach */
"05VQ0CZ" = "1" /* Restriction of Left External Jugular Vein with Extraluminal Device, Open Approach */
"05VQ0DZ" = "1" /* Restriction of Left External Jugular Vein with Intraluminal Device, Open Approach */
"05VQ0ZZ" = "1" /* Restriction of Left External Jugular Vein, Open Approach */
"05VQ3CZ" = "1" /* Restriction of Left External Jugular Vein with Extraluminal Device, Percutaneous Approach */
"05VQ3DZ" = "1" /* Restriction of Left External Jugular Vein with Intraluminal Device, Percutaneous Approach */
"05VQ3ZZ" = "1" /* Restriction of Left External Jugular Vein, Percutaneous Approach */
"05VQ4CZ" = "1" /* Restriction of Left External Jugular Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05VQ4DZ" = "1" /* Restriction of Left External Jugular Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05VQ4ZZ" = "1" /* Restriction of Left External Jugular Vein, Percutaneous Endoscopic Approach */
"05VR0CZ" = "1" /* Restriction of Right Vertebral Vein with Extraluminal Device, Open Approach */
"05VR0DZ" = "1" /* Restriction of Right Vertebral Vein with Intraluminal Device, Open Approach */
"05VR0ZZ" = "1" /* Restriction of Right Vertebral Vein, Open Approach */
"05VR3CZ" = "1" /* Restriction of Right Vertebral Vein with Extraluminal Device, Percutaneous Approach */
"05VR3DZ" = "1" /* Restriction of Right Vertebral Vein with Intraluminal Device, Percutaneous Approach */
"05VR3ZZ" = "1" /* Restriction of Right Vertebral Vein, Percutaneous Approach */
"05VR4CZ" = "1" /* Restriction of Right Vertebral Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05VR4DZ" = "1" /* Restriction of Right Vertebral Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05VR4ZZ" = "1" /* Restriction of Right Vertebral Vein, Percutaneous Endoscopic Approach */
"05VS0CZ" = "1" /* Restriction of Left Vertebral Vein with Extraluminal Device, Open Approach */
"05VS0DZ" = "1" /* Restriction of Left Vertebral Vein with Intraluminal Device, Open Approach */
"05VS0ZZ" = "1" /* Restriction of Left Vertebral Vein, Open Approach */
"05VS3CZ" = "1" /* Restriction of Left Vertebral Vein with Extraluminal Device, Percutaneous Approach */
"05VS3DZ" = "1" /* Restriction of Left Vertebral Vein with Intraluminal Device, Percutaneous Approach */
"05VS3ZZ" = "1" /* Restriction of Left Vertebral Vein, Percutaneous Approach */
"05VS4CZ" = "1" /* Restriction of Left Vertebral Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05VS4DZ" = "1" /* Restriction of Left Vertebral Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05VS4ZZ" = "1" /* Restriction of Left Vertebral Vein, Percutaneous Endoscopic Approach */
"05VT0CZ" = "1" /* Restriction of Right Face Vein with Extraluminal Device, Open Approach */
"05VT0DZ" = "1" /* Restriction of Right Face Vein with Intraluminal Device, Open Approach */
"05VT0ZZ" = "1" /* Restriction of Right Face Vein, Open Approach */
"05VT3CZ" = "1" /* Restriction of Right Face Vein with Extraluminal Device, Percutaneous Approach */
"05VT3DZ" = "1" /* Restriction of Right Face Vein with Intraluminal Device, Percutaneous Approach */
"05VT3ZZ" = "1" /* Restriction of Right Face Vein, Percutaneous Approach */
"05VT4CZ" = "1" /* Restriction of Right Face Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05VT4DZ" = "1" /* Restriction of Right Face Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05VT4ZZ" = "1" /* Restriction of Right Face Vein, Percutaneous Endoscopic Approach */
"05VV0CZ" = "1" /* Restriction of Left Face Vein with Extraluminal Device, Open Approach */
"05VV0DZ" = "1" /* Restriction of Left Face Vein with Intraluminal Device, Open Approach */
"05VV0ZZ" = "1" /* Restriction of Left Face Vein, Open Approach */
"05VV3CZ" = "1" /* Restriction of Left Face Vein with Extraluminal Device, Percutaneous Approach */
"05VV3DZ" = "1" /* Restriction of Left Face Vein with Intraluminal Device, Percutaneous Approach */
"05VV3ZZ" = "1" /* Restriction of Left Face Vein, Percutaneous Approach */
"05VV4CZ" = "1" /* Restriction of Left Face Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05VV4DZ" = "1" /* Restriction of Left Face Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05VV4ZZ" = "1" /* Restriction of Left Face Vein, Percutaneous Endoscopic Approach */
"05VY0CZ" = "1" /* Restriction of Upper Vein with Extraluminal Device, Open Approach */
"05VY0DZ" = "1" /* Restriction of Upper Vein with Intraluminal Device, Open Approach */
"05VY0ZZ" = "1" /* Restriction of Upper Vein, Open Approach */
"05VY3CZ" = "1" /* Restriction of Upper Vein with Extraluminal Device, Percutaneous Approach */
"05VY3DZ" = "1" /* Restriction of Upper Vein with Intraluminal Device, Percutaneous Approach */
"05VY3ZZ" = "1" /* Restriction of Upper Vein, Percutaneous Approach */
"05VY4CZ" = "1" /* Restriction of Upper Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"05VY4DZ" = "1" /* Restriction of Upper Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"05VY4ZZ" = "1" /* Restriction of Upper Vein, Percutaneous Endoscopic Approach */
"05W002Z" = "1" /* Revision of Monitoring Device in Azygos Vein, Open Approach */
"05W00MZ" = "1" /* Revision of Neurostimulator Lead in Azygos Vein, Open Approach */
"05W042Z" = "1" /* Revision of Monitoring Device in Azygos Vein, Percutaneous Endoscopic Approach */
"05W04MZ" = "1" /* Revision of Neurostimulator Lead in Azygos Vein, Percutaneous Endoscopic Approach */
"05W30MZ" = "1" /* Revision of Neurostimulator Lead in Right Innominate Vein, Open Approach */
"05W34MZ" = "1" /* Revision of Neurostimulator Lead in Right Innominate Vein, Percutaneous Endoscopic Approach */
"05W40MZ" = "1" /* Revision of Neurostimulator Lead in Left Innominate Vein, Open Approach */
"05W44MZ" = "1" /* Revision of Neurostimulator Lead in Left Innominate Vein, Percutaneous Endoscopic Approach */
"05WY00Z" = "1" /* Revision of Drainage Device in Upper Vein, Open Approach */
"05WY02Z" = "1" /* Revision of Monitoring Device in Upper Vein, Open Approach */
"05WY03Z" = "1" /* Revision of Infusion Device in Upper Vein, Open Approach */
"05WY07Z" = "1" /* Revision of Autologous Tissue Substitute in Upper Vein, Open Approach */
"05WY0CZ" = "1" /* Revision of Extraluminal Device in Upper Vein, Open Approach */
"05WY0DZ" = "1" /* Revision of Intraluminal Device in Upper Vein, Open Approach */
"05WY0JZ" = "1" /* Revision of Synthetic Substitute in Upper Vein, Open Approach */
"05WY0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Vein, Open Approach */
"05WY37Z" = "1" /* Revision of Autologous Tissue Substitute in Upper Vein, Percutaneous Approach */
"05WY3CZ" = "1" /* Revision of Extraluminal Device in Upper Vein, Percutaneous Approach */
"05WY3JZ" = "1" /* Revision of Synthetic Substitute in Upper Vein, Percutaneous Approach */
"05WY3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Vein, Percutaneous Approach */
"05WY40Z" = "1" /* Revision of Drainage Device in Upper Vein, Percutaneous Endoscopic Approach */
"05WY42Z" = "1" /* Revision of Monitoring Device in Upper Vein, Percutaneous Endoscopic Approach */
"05WY43Z" = "1" /* Revision of Infusion Device in Upper Vein, Percutaneous Endoscopic Approach */
"05WY47Z" = "1" /* Revision of Autologous Tissue Substitute in Upper Vein, Percutaneous Endoscopic Approach */
"05WY4CZ" = "1" /* Revision of Extraluminal Device in Upper Vein, Percutaneous Endoscopic Approach */
"05WY4DZ" = "1" /* Revision of Intraluminal Device in Upper Vein, Percutaneous Endoscopic Approach */
"05WY4JZ" = "1" /* Revision of Synthetic Substitute in Upper Vein, Percutaneous Endoscopic Approach */
"05WY4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Vein, Percutaneous Endoscopic Approach */
"0610075" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein with Autologous Tissue Substitute, Open Approach */
"0610076" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein with Autologous Tissue Substitute, Open Approach */
"061007Y" = "1" /* Bypass Inferior Vena Cava to Lower Vein with Autologous Tissue Substitute, Open Approach */
"0610095" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein with Autologous Venous Tissue, Open Approach */
"0610096" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein with Autologous Venous Tissue, Open Approach */
"061009Y" = "1" /* Bypass Inferior Vena Cava to Lower Vein with Autologous Venous Tissue, Open Approach */
"06100A5" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein with Autologous Arterial Tissue, Open Approach */
"06100A6" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein with Autologous Arterial Tissue, Open Approach */
"06100AY" = "1" /* Bypass Inferior Vena Cava to Lower Vein with Autologous Arterial Tissue, Open Approach */
"06100J5" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein with Synthetic Substitute, Open Approach */
"06100J6" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein with Synthetic Substitute, Open Approach */
"06100JY" = "1" /* Bypass Inferior Vena Cava to Lower Vein with Synthetic Substitute, Open Approach */
"06100K5" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein with Nonautologous Tissue Substitute, Open Approach */
"06100K6" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein with Nonautologous Tissue Substitute, Open Approach */
"06100KY" = "1" /* Bypass Inferior Vena Cava to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"06100Z5" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein, Open Approach */
"06100Z6" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein, Open Approach */
"06100ZY" = "1" /* Bypass Inferior Vena Cava to Lower Vein, Open Approach */
"0610475" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0610476" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061047Y" = "1" /* Bypass Inferior Vena Cava to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0610495" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0610496" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061049Y" = "1" /* Bypass Inferior Vena Cava to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"06104A5" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06104A6" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06104AY" = "1" /* Bypass Inferior Vena Cava to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06104J5" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06104J6" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06104JY" = "1" /* Bypass Inferior Vena Cava to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06104K5" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06104K6" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06104KY" = "1" /* Bypass Inferior Vena Cava to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06104Z5" = "1" /* Bypass Inferior Vena Cava to Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06104Z6" = "1" /* Bypass Inferior Vena Cava to Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06104ZY" = "1" /* Bypass Inferior Vena Cava to Lower Vein, Percutaneous Endoscopic Approach */
"0611079" = "1" /* Bypass Splenic Vein to Right Renal Vein with Autologous Tissue Substitute, Open Approach */
"061107B" = "1" /* Bypass Splenic Vein to Left Renal Vein with Autologous Tissue Substitute, Open Approach */
"061107Y" = "1" /* Bypass Splenic Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"0611099" = "1" /* Bypass Splenic Vein to Right Renal Vein with Autologous Venous Tissue, Open Approach */
"061109B" = "1" /* Bypass Splenic Vein to Left Renal Vein with Autologous Venous Tissue, Open Approach */
"061109Y" = "1" /* Bypass Splenic Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"06110A9" = "1" /* Bypass Splenic Vein to Right Renal Vein with Autologous Arterial Tissue, Open Approach */
"06110AB" = "1" /* Bypass Splenic Vein to Left Renal Vein with Autologous Arterial Tissue, Open Approach */
"06110AY" = "1" /* Bypass Splenic Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"06110J9" = "1" /* Bypass Splenic Vein to Right Renal Vein with Synthetic Substitute, Open Approach */
"06110JB" = "1" /* Bypass Splenic Vein to Left Renal Vein with Synthetic Substitute, Open Approach */
"06110JY" = "1" /* Bypass Splenic Vein to Lower Vein with Synthetic Substitute, Open Approach */
"06110K9" = "1" /* Bypass Splenic Vein to Right Renal Vein with Nonautologous Tissue Substitute, Open Approach */
"06110KB" = "1" /* Bypass Splenic Vein to Left Renal Vein with Nonautologous Tissue Substitute, Open Approach */
"06110KY" = "1" /* Bypass Splenic Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"06110Z9" = "1" /* Bypass Splenic Vein to Right Renal Vein, Open Approach */
"06110ZB" = "1" /* Bypass Splenic Vein to Left Renal Vein, Open Approach */
"06110ZY" = "1" /* Bypass Splenic Vein to Lower Vein, Open Approach */
"0611479" = "1" /* Bypass Splenic Vein to Right Renal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061147B" = "1" /* Bypass Splenic Vein to Left Renal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061147Y" = "1" /* Bypass Splenic Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0611499" = "1" /* Bypass Splenic Vein to Right Renal Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061149B" = "1" /* Bypass Splenic Vein to Left Renal Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061149Y" = "1" /* Bypass Splenic Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"06114A9" = "1" /* Bypass Splenic Vein to Right Renal Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06114AB" = "1" /* Bypass Splenic Vein to Left Renal Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06114AY" = "1" /* Bypass Splenic Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06114J9" = "1" /* Bypass Splenic Vein to Right Renal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06114JB" = "1" /* Bypass Splenic Vein to Left Renal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06114JY" = "1" /* Bypass Splenic Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06114K9" = "1" /* Bypass Splenic Vein to Right Renal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06114KB" = "1" /* Bypass Splenic Vein to Left Renal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06114KY" = "1" /* Bypass Splenic Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06114Z9" = "1" /* Bypass Splenic Vein to Right Renal Vein, Percutaneous Endoscopic Approach */
"06114ZB" = "1" /* Bypass Splenic Vein to Left Renal Vein, Percutaneous Endoscopic Approach */
"06114ZY" = "1" /* Bypass Splenic Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061207Y" = "1" /* Bypass Gastric Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061209Y" = "1" /* Bypass Gastric Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"06120AY" = "1" /* Bypass Gastric Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"06120JY" = "1" /* Bypass Gastric Vein to Lower Vein with Synthetic Substitute, Open Approach */
"06120KY" = "1" /* Bypass Gastric Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"06120ZY" = "1" /* Bypass Gastric Vein to Lower Vein, Open Approach */
"061247Y" = "1" /* Bypass Gastric Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061249Y" = "1" /* Bypass Gastric Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"06124AY" = "1" /* Bypass Gastric Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06124JY" = "1" /* Bypass Gastric Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06124KY" = "1" /* Bypass Gastric Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06124ZY" = "1" /* Bypass Gastric Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061307Y" = "1" /* Bypass Esophageal Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061309Y" = "1" /* Bypass Esophageal Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"06130AY" = "1" /* Bypass Esophageal Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"06130JY" = "1" /* Bypass Esophageal Vein to Lower Vein with Synthetic Substitute, Open Approach */
"06130KY" = "1" /* Bypass Esophageal Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"06130ZY" = "1" /* Bypass Esophageal Vein to Lower Vein, Open Approach */
"061347Y" = "1" /* Bypass Esophageal Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061349Y" = "1" /* Bypass Esophageal Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"06134AY" = "1" /* Bypass Esophageal Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06134JY" = "1" /* Bypass Esophageal Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06134KY" = "1" /* Bypass Esophageal Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06134ZY" = "1" /* Bypass Esophageal Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061407Y" = "1" /* Bypass Hepatic Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061409Y" = "1" /* Bypass Hepatic Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"06140AY" = "1" /* Bypass Hepatic Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"06140JY" = "1" /* Bypass Hepatic Vein to Lower Vein with Synthetic Substitute, Open Approach */
"06140KY" = "1" /* Bypass Hepatic Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"06140ZY" = "1" /* Bypass Hepatic Vein to Lower Vein, Open Approach */
"061447Y" = "1" /* Bypass Hepatic Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061449Y" = "1" /* Bypass Hepatic Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"06144AY" = "1" /* Bypass Hepatic Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06144JY" = "1" /* Bypass Hepatic Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06144KY" = "1" /* Bypass Hepatic Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06144ZY" = "1" /* Bypass Hepatic Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061507Y" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061509Y" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"06150AY" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"06150JY" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein with Synthetic Substitute, Open Approach */
"06150KY" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"06150ZY" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein, Open Approach */
"061547Y" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061549Y" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"06154AY" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06154JY" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06154KY" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06154ZY" = "1" /* Bypass Superior Mesenteric Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061607Y" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061609Y" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"06160AY" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"06160JY" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein with Synthetic Substitute, Open Approach */
"06160KY" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"06160ZY" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein, Open Approach */
"061647Y" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061649Y" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"06164AY" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06164JY" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06164KY" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06164ZY" = "1" /* Bypass Inferior Mesenteric Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061707Y" = "1" /* Bypass Colic Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061709Y" = "1" /* Bypass Colic Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"06170AY" = "1" /* Bypass Colic Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"06170JY" = "1" /* Bypass Colic Vein to Lower Vein with Synthetic Substitute, Open Approach */
"06170KY" = "1" /* Bypass Colic Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"06170ZY" = "1" /* Bypass Colic Vein to Lower Vein, Open Approach */
"061747Y" = "1" /* Bypass Colic Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061749Y" = "1" /* Bypass Colic Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"06174AY" = "1" /* Bypass Colic Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06174JY" = "1" /* Bypass Colic Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06174KY" = "1" /* Bypass Colic Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06174ZY" = "1" /* Bypass Colic Vein to Lower Vein, Percutaneous Endoscopic Approach */
"0618079" = "1" /* Bypass Portal Vein to Right Renal Vein with Autologous Tissue Substitute, Open Approach */
"061807B" = "1" /* Bypass Portal Vein to Left Renal Vein with Autologous Tissue Substitute, Open Approach */
"061807Y" = "1" /* Bypass Portal Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"0618099" = "1" /* Bypass Portal Vein to Right Renal Vein with Autologous Venous Tissue, Open Approach */
"061809B" = "1" /* Bypass Portal Vein to Left Renal Vein with Autologous Venous Tissue, Open Approach */
"061809Y" = "1" /* Bypass Portal Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"06180A9" = "1" /* Bypass Portal Vein to Right Renal Vein with Autologous Arterial Tissue, Open Approach */
"06180AB" = "1" /* Bypass Portal Vein to Left Renal Vein with Autologous Arterial Tissue, Open Approach */
"06180AY" = "1" /* Bypass Portal Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"06180J9" = "1" /* Bypass Portal Vein to Right Renal Vein with Synthetic Substitute, Open Approach */
"06180JB" = "1" /* Bypass Portal Vein to Left Renal Vein with Synthetic Substitute, Open Approach */
"06180JY" = "1" /* Bypass Portal Vein to Lower Vein with Synthetic Substitute, Open Approach */
"06180K9" = "1" /* Bypass Portal Vein to Right Renal Vein with Nonautologous Tissue Substitute, Open Approach */
"06180KB" = "1" /* Bypass Portal Vein to Left Renal Vein with Nonautologous Tissue Substitute, Open Approach */
"06180KY" = "1" /* Bypass Portal Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"06180Z9" = "1" /* Bypass Portal Vein to Right Renal Vein, Open Approach */
"06180ZB" = "1" /* Bypass Portal Vein to Left Renal Vein, Open Approach */
"06180ZY" = "1" /* Bypass Portal Vein to Lower Vein, Open Approach */
"06183DY" = "1" /* Bypass Portal Vein to Lower Vein with Intraluminal Device, Percutaneous Approach */
"0618479" = "1" /* Bypass Portal Vein to Right Renal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061847B" = "1" /* Bypass Portal Vein to Left Renal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061847Y" = "1" /* Bypass Portal Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0618499" = "1" /* Bypass Portal Vein to Right Renal Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061849B" = "1" /* Bypass Portal Vein to Left Renal Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061849Y" = "1" /* Bypass Portal Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"06184A9" = "1" /* Bypass Portal Vein to Right Renal Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06184AB" = "1" /* Bypass Portal Vein to Left Renal Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06184AY" = "1" /* Bypass Portal Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06184DY" = "1" /* Bypass Portal Vein to Lower Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06184J9" = "1" /* Bypass Portal Vein to Right Renal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06184JB" = "1" /* Bypass Portal Vein to Left Renal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06184JY" = "1" /* Bypass Portal Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06184K9" = "1" /* Bypass Portal Vein to Right Renal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06184KB" = "1" /* Bypass Portal Vein to Left Renal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06184KY" = "1" /* Bypass Portal Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06184Z9" = "1" /* Bypass Portal Vein to Right Renal Vein, Percutaneous Endoscopic Approach */
"06184ZB" = "1" /* Bypass Portal Vein to Left Renal Vein, Percutaneous Endoscopic Approach */
"06184ZY" = "1" /* Bypass Portal Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061907Y" = "1" /* Bypass Right Renal Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061909Y" = "1" /* Bypass Right Renal Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"06190AY" = "1" /* Bypass Right Renal Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"06190JY" = "1" /* Bypass Right Renal Vein to Lower Vein with Synthetic Substitute, Open Approach */
"06190KY" = "1" /* Bypass Right Renal Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"06190ZY" = "1" /* Bypass Right Renal Vein to Lower Vein, Open Approach */
"061947Y" = "1" /* Bypass Right Renal Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061949Y" = "1" /* Bypass Right Renal Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"06194AY" = "1" /* Bypass Right Renal Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06194JY" = "1" /* Bypass Right Renal Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06194KY" = "1" /* Bypass Right Renal Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06194ZY" = "1" /* Bypass Right Renal Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061B07Y" = "1" /* Bypass Left Renal Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061B09Y" = "1" /* Bypass Left Renal Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"061B0AY" = "1" /* Bypass Left Renal Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"061B0JY" = "1" /* Bypass Left Renal Vein to Lower Vein with Synthetic Substitute, Open Approach */
"061B0KY" = "1" /* Bypass Left Renal Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"061B0ZY" = "1" /* Bypass Left Renal Vein to Lower Vein, Open Approach */
"061B47Y" = "1" /* Bypass Left Renal Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061B49Y" = "1" /* Bypass Left Renal Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061B4AY" = "1" /* Bypass Left Renal Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"061B4JY" = "1" /* Bypass Left Renal Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"061B4KY" = "1" /* Bypass Left Renal Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061B4ZY" = "1" /* Bypass Left Renal Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061C07Y" = "1" /* Bypass Right Common Iliac Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061C09Y" = "1" /* Bypass Right Common Iliac Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"061C0AY" = "1" /* Bypass Right Common Iliac Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"061C0JY" = "1" /* Bypass Right Common Iliac Vein to Lower Vein with Synthetic Substitute, Open Approach */
"061C0KY" = "1" /* Bypass Right Common Iliac Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"061C0ZY" = "1" /* Bypass Right Common Iliac Vein to Lower Vein, Open Approach */
"061C47Y" = "1" /* Bypass Right Common Iliac Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061C49Y" = "1" /* Bypass Right Common Iliac Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061C4AY" = "1" /* Bypass Right Common Iliac Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"061C4JY" = "1" /* Bypass Right Common Iliac Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"061C4KY" = "1" /* Bypass Right Common Iliac Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061C4ZY" = "1" /* Bypass Right Common Iliac Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061D07Y" = "1" /* Bypass Left Common Iliac Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061D09Y" = "1" /* Bypass Left Common Iliac Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"061D0AY" = "1" /* Bypass Left Common Iliac Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"061D0JY" = "1" /* Bypass Left Common Iliac Vein to Lower Vein with Synthetic Substitute, Open Approach */
"061D0KY" = "1" /* Bypass Left Common Iliac Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"061D0ZY" = "1" /* Bypass Left Common Iliac Vein to Lower Vein, Open Approach */
"061D47Y" = "1" /* Bypass Left Common Iliac Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061D49Y" = "1" /* Bypass Left Common Iliac Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061D4AY" = "1" /* Bypass Left Common Iliac Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"061D4JY" = "1" /* Bypass Left Common Iliac Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"061D4KY" = "1" /* Bypass Left Common Iliac Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061D4ZY" = "1" /* Bypass Left Common Iliac Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061F07Y" = "1" /* Bypass Right External Iliac Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061F09Y" = "1" /* Bypass Right External Iliac Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"061F0AY" = "1" /* Bypass Right External Iliac Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"061F0JY" = "1" /* Bypass Right External Iliac Vein to Lower Vein with Synthetic Substitute, Open Approach */
"061F0KY" = "1" /* Bypass Right External Iliac Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"061F0ZY" = "1" /* Bypass Right External Iliac Vein to Lower Vein, Open Approach */
"061F47Y" = "1" /* Bypass Right External Iliac Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061F49Y" = "1" /* Bypass Right External Iliac Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061F4AY" = "1" /* Bypass Right External Iliac Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"061F4JY" = "1" /* Bypass Right External Iliac Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"061F4KY" = "1" /* Bypass Right External Iliac Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061F4ZY" = "1" /* Bypass Right External Iliac Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061G07Y" = "1" /* Bypass Left External Iliac Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061G09Y" = "1" /* Bypass Left External Iliac Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"061G0AY" = "1" /* Bypass Left External Iliac Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"061G0JY" = "1" /* Bypass Left External Iliac Vein to Lower Vein with Synthetic Substitute, Open Approach */
"061G0KY" = "1" /* Bypass Left External Iliac Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"061G0ZY" = "1" /* Bypass Left External Iliac Vein to Lower Vein, Open Approach */
"061G47Y" = "1" /* Bypass Left External Iliac Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061G49Y" = "1" /* Bypass Left External Iliac Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061G4AY" = "1" /* Bypass Left External Iliac Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"061G4JY" = "1" /* Bypass Left External Iliac Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"061G4KY" = "1" /* Bypass Left External Iliac Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061G4ZY" = "1" /* Bypass Left External Iliac Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061H07Y" = "1" /* Bypass Right Hypogastric Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061H09Y" = "1" /* Bypass Right Hypogastric Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"061H0AY" = "1" /* Bypass Right Hypogastric Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"061H0JY" = "1" /* Bypass Right Hypogastric Vein to Lower Vein with Synthetic Substitute, Open Approach */
"061H0KY" = "1" /* Bypass Right Hypogastric Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"061H0ZY" = "1" /* Bypass Right Hypogastric Vein to Lower Vein, Open Approach */
"061H47Y" = "1" /* Bypass Right Hypogastric Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061H49Y" = "1" /* Bypass Right Hypogastric Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061H4AY" = "1" /* Bypass Right Hypogastric Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"061H4JY" = "1" /* Bypass Right Hypogastric Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"061H4KY" = "1" /* Bypass Right Hypogastric Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061H4ZY" = "1" /* Bypass Right Hypogastric Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061J07Y" = "1" /* Bypass Left Hypogastric Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061J09Y" = "1" /* Bypass Left Hypogastric Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"061J0AY" = "1" /* Bypass Left Hypogastric Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"061J0JY" = "1" /* Bypass Left Hypogastric Vein to Lower Vein with Synthetic Substitute, Open Approach */
"061J0KY" = "1" /* Bypass Left Hypogastric Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"061J0ZY" = "1" /* Bypass Left Hypogastric Vein to Lower Vein, Open Approach */
"061J47Y" = "1" /* Bypass Left Hypogastric Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061J49Y" = "1" /* Bypass Left Hypogastric Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061J4AY" = "1" /* Bypass Left Hypogastric Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"061J4JY" = "1" /* Bypass Left Hypogastric Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"061J4KY" = "1" /* Bypass Left Hypogastric Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061J4ZY" = "1" /* Bypass Left Hypogastric Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061M07Y" = "1" /* Bypass Right Femoral Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061M09Y" = "1" /* Bypass Right Femoral Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"061M0AY" = "1" /* Bypass Right Femoral Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"061M0JY" = "1" /* Bypass Right Femoral Vein to Lower Vein with Synthetic Substitute, Open Approach */
"061M0KY" = "1" /* Bypass Right Femoral Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"061M0ZY" = "1" /* Bypass Right Femoral Vein to Lower Vein, Open Approach */
"061M47Y" = "1" /* Bypass Right Femoral Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061M49Y" = "1" /* Bypass Right Femoral Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061M4AY" = "1" /* Bypass Right Femoral Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"061M4JY" = "1" /* Bypass Right Femoral Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"061M4KY" = "1" /* Bypass Right Femoral Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061M4ZY" = "1" /* Bypass Right Femoral Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061N07Y" = "1" /* Bypass Left Femoral Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061N09Y" = "1" /* Bypass Left Femoral Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"061N0AY" = "1" /* Bypass Left Femoral Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"061N0JY" = "1" /* Bypass Left Femoral Vein to Lower Vein with Synthetic Substitute, Open Approach */
"061N0KY" = "1" /* Bypass Left Femoral Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"061N0ZY" = "1" /* Bypass Left Femoral Vein to Lower Vein, Open Approach */
"061N47Y" = "1" /* Bypass Left Femoral Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061N49Y" = "1" /* Bypass Left Femoral Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061N4AY" = "1" /* Bypass Left Femoral Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"061N4JY" = "1" /* Bypass Left Femoral Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"061N4KY" = "1" /* Bypass Left Femoral Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061N4ZY" = "1" /* Bypass Left Femoral Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061P07Y" = "1" /* Bypass Right Greater Saphenous Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061P09Y" = "1" /* Bypass Right Greater Saphenous Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"061P0AY" = "1" /* Bypass Right Greater Saphenous Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"061P0JY" = "1" /* Bypass Right Greater Saphenous Vein to Lower Vein with Synthetic Substitute, Open Approach */
"061P0KY" = "1" /* Bypass Right Greater Saphenous Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"061P0ZY" = "1" /* Bypass Right Greater Saphenous Vein to Lower Vein, Open Approach */
"061P47Y" = "1" /* Bypass Right Greater Saphenous Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061P49Y" = "1" /* Bypass Right Greater Saphenous Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061P4AY" = "1" /* Bypass Right Greater Saphenous Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"061P4JY" = "1" /* Bypass Right Greater Saphenous Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"061P4KY" = "1" /* Bypass Right Greater Saphenous Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061P4ZY" = "1" /* Bypass Right Greater Saphenous Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061Q07Y" = "1" /* Bypass Left Greater Saphenous Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061Q09Y" = "1" /* Bypass Left Greater Saphenous Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"061Q0AY" = "1" /* Bypass Left Greater Saphenous Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"061Q0JY" = "1" /* Bypass Left Greater Saphenous Vein to Lower Vein with Synthetic Substitute, Open Approach */
"061Q0KY" = "1" /* Bypass Left Greater Saphenous Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"061Q0ZY" = "1" /* Bypass Left Greater Saphenous Vein to Lower Vein, Open Approach */
"061Q47Y" = "1" /* Bypass Left Greater Saphenous Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061Q49Y" = "1" /* Bypass Left Greater Saphenous Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061Q4AY" = "1" /* Bypass Left Greater Saphenous Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"061Q4JY" = "1" /* Bypass Left Greater Saphenous Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"061Q4KY" = "1" /* Bypass Left Greater Saphenous Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061Q4ZY" = "1" /* Bypass Left Greater Saphenous Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061R07Y" = "1" /* Bypass Right Lesser Saphenous Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061R09Y" = "1" /* Bypass Right Lesser Saphenous Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"061R0AY" = "1" /* Bypass Right Lesser Saphenous Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"061R0JY" = "1" /* Bypass Right Lesser Saphenous Vein to Lower Vein with Synthetic Substitute, Open Approach */
"061R0KY" = "1" /* Bypass Right Lesser Saphenous Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"061R0ZY" = "1" /* Bypass Right Lesser Saphenous Vein to Lower Vein, Open Approach */
"061R47Y" = "1" /* Bypass Right Lesser Saphenous Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061R49Y" = "1" /* Bypass Right Lesser Saphenous Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061R4AY" = "1" /* Bypass Right Lesser Saphenous Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"061R4JY" = "1" /* Bypass Right Lesser Saphenous Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"061R4KY" = "1" /* Bypass Right Lesser Saphenous Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061R4ZY" = "1" /* Bypass Right Lesser Saphenous Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061S07Y" = "1" /* Bypass Left Lesser Saphenous Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061S09Y" = "1" /* Bypass Left Lesser Saphenous Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"061S0AY" = "1" /* Bypass Left Lesser Saphenous Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"061S0JY" = "1" /* Bypass Left Lesser Saphenous Vein to Lower Vein with Synthetic Substitute, Open Approach */
"061S0KY" = "1" /* Bypass Left Lesser Saphenous Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"061S0ZY" = "1" /* Bypass Left Lesser Saphenous Vein to Lower Vein, Open Approach */
"061S47Y" = "1" /* Bypass Left Lesser Saphenous Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061S49Y" = "1" /* Bypass Left Lesser Saphenous Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061S4AY" = "1" /* Bypass Left Lesser Saphenous Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"061S4JY" = "1" /* Bypass Left Lesser Saphenous Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"061S4KY" = "1" /* Bypass Left Lesser Saphenous Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061S4ZY" = "1" /* Bypass Left Lesser Saphenous Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061T07Y" = "1" /* Bypass Right Foot Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061T09Y" = "1" /* Bypass Right Foot Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"061T0AY" = "1" /* Bypass Right Foot Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"061T0JY" = "1" /* Bypass Right Foot Vein to Lower Vein with Synthetic Substitute, Open Approach */
"061T0KY" = "1" /* Bypass Right Foot Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"061T0ZY" = "1" /* Bypass Right Foot Vein to Lower Vein, Open Approach */
"061T47Y" = "1" /* Bypass Right Foot Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061T49Y" = "1" /* Bypass Right Foot Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061T4AY" = "1" /* Bypass Right Foot Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"061T4JY" = "1" /* Bypass Right Foot Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"061T4KY" = "1" /* Bypass Right Foot Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061T4ZY" = "1" /* Bypass Right Foot Vein to Lower Vein, Percutaneous Endoscopic Approach */
"061V07Y" = "1" /* Bypass Left Foot Vein to Lower Vein with Autologous Tissue Substitute, Open Approach */
"061V09Y" = "1" /* Bypass Left Foot Vein to Lower Vein with Autologous Venous Tissue, Open Approach */
"061V0AY" = "1" /* Bypass Left Foot Vein to Lower Vein with Autologous Arterial Tissue, Open Approach */
"061V0JY" = "1" /* Bypass Left Foot Vein to Lower Vein with Synthetic Substitute, Open Approach */
"061V0KY" = "1" /* Bypass Left Foot Vein to Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"061V0ZY" = "1" /* Bypass Left Foot Vein to Lower Vein, Open Approach */
"061V47Y" = "1" /* Bypass Left Foot Vein to Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061V49Y" = "1" /* Bypass Left Foot Vein to Lower Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061V4AY" = "1" /* Bypass Left Foot Vein to Lower Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"061V4JY" = "1" /* Bypass Left Foot Vein to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"061V4KY" = "1" /* Bypass Left Foot Vein to Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061V4ZY" = "1" /* Bypass Left Foot Vein to Lower Vein, Percutaneous Endoscopic Approach */
"06500ZZ" = "1" /* Destruction of Inferior Vena Cava, Open Approach */
"06503ZZ" = "1" /* Destruction of Inferior Vena Cava, Percutaneous Approach */
"06504ZZ" = "1" /* Destruction of Inferior Vena Cava, Percutaneous Endoscopic Approach */
"06510ZZ" = "1" /* Destruction of Splenic Vein, Open Approach */
"06513ZZ" = "1" /* Destruction of Splenic Vein, Percutaneous Approach */
"06514ZZ" = "1" /* Destruction of Splenic Vein, Percutaneous Endoscopic Approach */
"06520ZZ" = "1" /* Destruction of Gastric Vein, Open Approach */
"06523ZZ" = "1" /* Destruction of Gastric Vein, Percutaneous Approach */
"06524ZZ" = "1" /* Destruction of Gastric Vein, Percutaneous Endoscopic Approach */
"06530ZZ" = "1" /* Destruction of Esophageal Vein, Open Approach */
"06533ZZ" = "1" /* Destruction of Esophageal Vein, Percutaneous Approach */
"06534ZZ" = "1" /* Destruction of Esophageal Vein, Percutaneous Endoscopic Approach */
"06540ZZ" = "1" /* Destruction of Hepatic Vein, Open Approach */
"06543ZZ" = "1" /* Destruction of Hepatic Vein, Percutaneous Approach */
"06544ZZ" = "1" /* Destruction of Hepatic Vein, Percutaneous Endoscopic Approach */
"06550ZZ" = "1" /* Destruction of Superior Mesenteric Vein, Open Approach */
"06553ZZ" = "1" /* Destruction of Superior Mesenteric Vein, Percutaneous Approach */
"06554ZZ" = "1" /* Destruction of Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06560ZZ" = "1" /* Destruction of Inferior Mesenteric Vein, Open Approach */
"06563ZZ" = "1" /* Destruction of Inferior Mesenteric Vein, Percutaneous Approach */
"06564ZZ" = "1" /* Destruction of Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06570ZZ" = "1" /* Destruction of Colic Vein, Open Approach */
"06573ZZ" = "1" /* Destruction of Colic Vein, Percutaneous Approach */
"06574ZZ" = "1" /* Destruction of Colic Vein, Percutaneous Endoscopic Approach */
"06580ZZ" = "1" /* Destruction of Portal Vein, Open Approach */
"06583ZZ" = "1" /* Destruction of Portal Vein, Percutaneous Approach */
"06584ZZ" = "1" /* Destruction of Portal Vein, Percutaneous Endoscopic Approach */
"06590ZZ" = "1" /* Destruction of Right Renal Vein, Open Approach */
"06593ZZ" = "1" /* Destruction of Right Renal Vein, Percutaneous Approach */
"06594ZZ" = "1" /* Destruction of Right Renal Vein, Percutaneous Endoscopic Approach */
"065B0ZZ" = "1" /* Destruction of Left Renal Vein, Open Approach */
"065B3ZZ" = "1" /* Destruction of Left Renal Vein, Percutaneous Approach */
"065B4ZZ" = "1" /* Destruction of Left Renal Vein, Percutaneous Endoscopic Approach */
"065C0ZZ" = "1" /* Destruction of Right Common Iliac Vein, Open Approach */
"065C3ZZ" = "1" /* Destruction of Right Common Iliac Vein, Percutaneous Approach */
"065C4ZZ" = "1" /* Destruction of Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"065D0ZZ" = "1" /* Destruction of Left Common Iliac Vein, Open Approach */
"065D3ZZ" = "1" /* Destruction of Left Common Iliac Vein, Percutaneous Approach */
"065D4ZZ" = "1" /* Destruction of Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"065F0ZZ" = "1" /* Destruction of Right External Iliac Vein, Open Approach */
"065F3ZZ" = "1" /* Destruction of Right External Iliac Vein, Percutaneous Approach */
"065F4ZZ" = "1" /* Destruction of Right External Iliac Vein, Percutaneous Endoscopic Approach */
"065G0ZZ" = "1" /* Destruction of Left External Iliac Vein, Open Approach */
"065G3ZZ" = "1" /* Destruction of Left External Iliac Vein, Percutaneous Approach */
"065G4ZZ" = "1" /* Destruction of Left External Iliac Vein, Percutaneous Endoscopic Approach */
"065H0ZZ" = "1" /* Destruction of Right Hypogastric Vein, Open Approach */
"065H3ZZ" = "1" /* Destruction of Right Hypogastric Vein, Percutaneous Approach */
"065H4ZZ" = "1" /* Destruction of Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"065J0ZZ" = "1" /* Destruction of Left Hypogastric Vein, Open Approach */
"065J3ZZ" = "1" /* Destruction of Left Hypogastric Vein, Percutaneous Approach */
"065J4ZZ" = "1" /* Destruction of Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"065M0ZZ" = "1" /* Destruction of Right Femoral Vein, Open Approach */
"065M3ZZ" = "1" /* Destruction of Right Femoral Vein, Percutaneous Approach */
"065M4ZZ" = "1" /* Destruction of Right Femoral Vein, Percutaneous Endoscopic Approach */
"065N0ZZ" = "1" /* Destruction of Left Femoral Vein, Open Approach */
"065N3ZZ" = "1" /* Destruction of Left Femoral Vein, Percutaneous Approach */
"065N4ZZ" = "1" /* Destruction of Left Femoral Vein, Percutaneous Endoscopic Approach */
"065P0ZZ" = "1" /* Destruction of Right Greater Saphenous Vein, Open Approach */
"065P3ZZ" = "1" /* Destruction of Right Greater Saphenous Vein, Percutaneous Approach */
"065P4ZZ" = "1" /* Destruction of Right Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"065Q0ZZ" = "1" /* Destruction of Left Greater Saphenous Vein, Open Approach */
"065Q3ZZ" = "1" /* Destruction of Left Greater Saphenous Vein, Percutaneous Approach */
"065Q4ZZ" = "1" /* Destruction of Left Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"065R0ZZ" = "1" /* Destruction of Right Lesser Saphenous Vein, Open Approach */
"065R3ZZ" = "1" /* Destruction of Right Lesser Saphenous Vein, Percutaneous Approach */
"065R4ZZ" = "1" /* Destruction of Right Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"065S0ZZ" = "1" /* Destruction of Left Lesser Saphenous Vein, Open Approach */
"065S3ZZ" = "1" /* Destruction of Left Lesser Saphenous Vein, Percutaneous Approach */
"065S4ZZ" = "1" /* Destruction of Left Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"065T0ZZ" = "1" /* Destruction of Right Foot Vein, Open Approach */
"065T3ZZ" = "1" /* Destruction of Right Foot Vein, Percutaneous Approach */
"065T4ZZ" = "1" /* Destruction of Right Foot Vein, Percutaneous Endoscopic Approach */
"065V0ZZ" = "1" /* Destruction of Left Foot Vein, Open Approach */
"065V3ZZ" = "1" /* Destruction of Left Foot Vein, Percutaneous Approach */
"065V4ZZ" = "1" /* Destruction of Left Foot Vein, Percutaneous Endoscopic Approach */
"065Y0ZC" = "1" /* Destruction of Hemorrhoidal Plexus, Open Approach */
"065Y0ZZ" = "1" /* Destruction of Lower Vein, Open Approach */
"065Y3ZC" = "1" /* Destruction of Hemorrhoidal Plexus, Percutaneous Approach */
"065Y3ZZ" = "1" /* Destruction of Lower Vein, Percutaneous Approach */
"065Y4ZC" = "1" /* Destruction of Hemorrhoidal Plexus, Percutaneous Endoscopic Approach */
"065Y4ZZ" = "1" /* Destruction of Lower Vein, Percutaneous Endoscopic Approach */
"06700DZ" = "1" /* Dilation of Inferior Vena Cava with Intraluminal Device, Open Approach */
"06700ZZ" = "1" /* Dilation of Inferior Vena Cava, Open Approach */
"06703DZ" = "1" /* Dilation of Inferior Vena Cava with Intraluminal Device, Percutaneous Approach */
"06703ZZ" = "1" /* Dilation of Inferior Vena Cava, Percutaneous Approach */
"06704DZ" = "1" /* Dilation of Inferior Vena Cava with Intraluminal Device, Percutaneous Endoscopic Approach */
"06704ZZ" = "1" /* Dilation of Inferior Vena Cava, Percutaneous Endoscopic Approach */
"06710DZ" = "1" /* Dilation of Splenic Vein with Intraluminal Device, Open Approach */
"06710ZZ" = "1" /* Dilation of Splenic Vein, Open Approach */
"06713DZ" = "1" /* Dilation of Splenic Vein with Intraluminal Device, Percutaneous Approach */
"06713ZZ" = "1" /* Dilation of Splenic Vein, Percutaneous Approach */
"06714DZ" = "1" /* Dilation of Splenic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06714ZZ" = "1" /* Dilation of Splenic Vein, Percutaneous Endoscopic Approach */
"06720DZ" = "1" /* Dilation of Gastric Vein with Intraluminal Device, Open Approach */
"06720ZZ" = "1" /* Dilation of Gastric Vein, Open Approach */
"06723DZ" = "1" /* Dilation of Gastric Vein with Intraluminal Device, Percutaneous Approach */
"06723ZZ" = "1" /* Dilation of Gastric Vein, Percutaneous Approach */
"06724DZ" = "1" /* Dilation of Gastric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06724ZZ" = "1" /* Dilation of Gastric Vein, Percutaneous Endoscopic Approach */
"06730DZ" = "1" /* Dilation of Esophageal Vein with Intraluminal Device, Open Approach */
"06730ZZ" = "1" /* Dilation of Esophageal Vein, Open Approach */
"06733DZ" = "1" /* Dilation of Esophageal Vein with Intraluminal Device, Percutaneous Approach */
"06733ZZ" = "1" /* Dilation of Esophageal Vein, Percutaneous Approach */
"06734DZ" = "1" /* Dilation of Esophageal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06734ZZ" = "1" /* Dilation of Esophageal Vein, Percutaneous Endoscopic Approach */
"06740DZ" = "1" /* Dilation of Hepatic Vein with Intraluminal Device, Open Approach */
"06740ZZ" = "1" /* Dilation of Hepatic Vein, Open Approach */
"06743DZ" = "1" /* Dilation of Hepatic Vein with Intraluminal Device, Percutaneous Approach */
"06743ZZ" = "1" /* Dilation of Hepatic Vein, Percutaneous Approach */
"06744DZ" = "1" /* Dilation of Hepatic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06744ZZ" = "1" /* Dilation of Hepatic Vein, Percutaneous Endoscopic Approach */
"06750DZ" = "1" /* Dilation of Superior Mesenteric Vein with Intraluminal Device, Open Approach */
"06750ZZ" = "1" /* Dilation of Superior Mesenteric Vein, Open Approach */
"06753DZ" = "1" /* Dilation of Superior Mesenteric Vein with Intraluminal Device, Percutaneous Approach */
"06753ZZ" = "1" /* Dilation of Superior Mesenteric Vein, Percutaneous Approach */
"06754DZ" = "1" /* Dilation of Superior Mesenteric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06754ZZ" = "1" /* Dilation of Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06760DZ" = "1" /* Dilation of Inferior Mesenteric Vein with Intraluminal Device, Open Approach */
"06760ZZ" = "1" /* Dilation of Inferior Mesenteric Vein, Open Approach */
"06763DZ" = "1" /* Dilation of Inferior Mesenteric Vein with Intraluminal Device, Percutaneous Approach */
"06763ZZ" = "1" /* Dilation of Inferior Mesenteric Vein, Percutaneous Approach */
"06764DZ" = "1" /* Dilation of Inferior Mesenteric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06764ZZ" = "1" /* Dilation of Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06770DZ" = "1" /* Dilation of Colic Vein with Intraluminal Device, Open Approach */
"06770ZZ" = "1" /* Dilation of Colic Vein, Open Approach */
"06773DZ" = "1" /* Dilation of Colic Vein with Intraluminal Device, Percutaneous Approach */
"06773ZZ" = "1" /* Dilation of Colic Vein, Percutaneous Approach */
"06774DZ" = "1" /* Dilation of Colic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06774ZZ" = "1" /* Dilation of Colic Vein, Percutaneous Endoscopic Approach */
"06780DZ" = "1" /* Dilation of Portal Vein with Intraluminal Device, Open Approach */
"06780ZZ" = "1" /* Dilation of Portal Vein, Open Approach */
"06783DZ" = "1" /* Dilation of Portal Vein with Intraluminal Device, Percutaneous Approach */
"06783ZZ" = "1" /* Dilation of Portal Vein, Percutaneous Approach */
"06784DZ" = "1" /* Dilation of Portal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06784ZZ" = "1" /* Dilation of Portal Vein, Percutaneous Endoscopic Approach */
"06790DZ" = "1" /* Dilation of Right Renal Vein with Intraluminal Device, Open Approach */
"06790ZZ" = "1" /* Dilation of Right Renal Vein, Open Approach */
"06793DZ" = "1" /* Dilation of Right Renal Vein with Intraluminal Device, Percutaneous Approach */
"06793ZZ" = "1" /* Dilation of Right Renal Vein, Percutaneous Approach */
"06794DZ" = "1" /* Dilation of Right Renal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06794ZZ" = "1" /* Dilation of Right Renal Vein, Percutaneous Endoscopic Approach */
"067B0DZ" = "1" /* Dilation of Left Renal Vein with Intraluminal Device, Open Approach */
"067B0ZZ" = "1" /* Dilation of Left Renal Vein, Open Approach */
"067B3DZ" = "1" /* Dilation of Left Renal Vein with Intraluminal Device, Percutaneous Approach */
"067B3ZZ" = "1" /* Dilation of Left Renal Vein, Percutaneous Approach */
"067B4DZ" = "1" /* Dilation of Left Renal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"067B4ZZ" = "1" /* Dilation of Left Renal Vein, Percutaneous Endoscopic Approach */
"067C0DZ" = "1" /* Dilation of Right Common Iliac Vein with Intraluminal Device, Open Approach */
"067C0ZZ" = "1" /* Dilation of Right Common Iliac Vein, Open Approach */
"067C3DZ" = "1" /* Dilation of Right Common Iliac Vein with Intraluminal Device, Percutaneous Approach */
"067C3ZZ" = "1" /* Dilation of Right Common Iliac Vein, Percutaneous Approach */
"067C4DZ" = "1" /* Dilation of Right Common Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"067C4ZZ" = "1" /* Dilation of Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"067D0DZ" = "1" /* Dilation of Left Common Iliac Vein with Intraluminal Device, Open Approach */
"067D0ZZ" = "1" /* Dilation of Left Common Iliac Vein, Open Approach */
"067D3DZ" = "1" /* Dilation of Left Common Iliac Vein with Intraluminal Device, Percutaneous Approach */
"067D3ZZ" = "1" /* Dilation of Left Common Iliac Vein, Percutaneous Approach */
"067D4DZ" = "1" /* Dilation of Left Common Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"067D4ZZ" = "1" /* Dilation of Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"067F0DZ" = "1" /* Dilation of Right External Iliac Vein with Intraluminal Device, Open Approach */
"067F0ZZ" = "1" /* Dilation of Right External Iliac Vein, Open Approach */
"067F3DZ" = "1" /* Dilation of Right External Iliac Vein with Intraluminal Device, Percutaneous Approach */
"067F3ZZ" = "1" /* Dilation of Right External Iliac Vein, Percutaneous Approach */
"067F4DZ" = "1" /* Dilation of Right External Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"067F4ZZ" = "1" /* Dilation of Right External Iliac Vein, Percutaneous Endoscopic Approach */
"067G0DZ" = "1" /* Dilation of Left External Iliac Vein with Intraluminal Device, Open Approach */
"067G0ZZ" = "1" /* Dilation of Left External Iliac Vein, Open Approach */
"067G3DZ" = "1" /* Dilation of Left External Iliac Vein with Intraluminal Device, Percutaneous Approach */
"067G3ZZ" = "1" /* Dilation of Left External Iliac Vein, Percutaneous Approach */
"067G4DZ" = "1" /* Dilation of Left External Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"067G4ZZ" = "1" /* Dilation of Left External Iliac Vein, Percutaneous Endoscopic Approach */
"067H0DZ" = "1" /* Dilation of Right Hypogastric Vein with Intraluminal Device, Open Approach */
"067H0ZZ" = "1" /* Dilation of Right Hypogastric Vein, Open Approach */
"067H3DZ" = "1" /* Dilation of Right Hypogastric Vein with Intraluminal Device, Percutaneous Approach */
"067H3ZZ" = "1" /* Dilation of Right Hypogastric Vein, Percutaneous Approach */
"067H4DZ" = "1" /* Dilation of Right Hypogastric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"067H4ZZ" = "1" /* Dilation of Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"067J0DZ" = "1" /* Dilation of Left Hypogastric Vein with Intraluminal Device, Open Approach */
"067J0ZZ" = "1" /* Dilation of Left Hypogastric Vein, Open Approach */
"067J3DZ" = "1" /* Dilation of Left Hypogastric Vein with Intraluminal Device, Percutaneous Approach */
"067J3ZZ" = "1" /* Dilation of Left Hypogastric Vein, Percutaneous Approach */
"067J4DZ" = "1" /* Dilation of Left Hypogastric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"067J4ZZ" = "1" /* Dilation of Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"067M0DZ" = "1" /* Dilation of Right Femoral Vein with Intraluminal Device, Open Approach */
"067M0ZZ" = "1" /* Dilation of Right Femoral Vein, Open Approach */
"067M3DZ" = "1" /* Dilation of Right Femoral Vein with Intraluminal Device, Percutaneous Approach */
"067M3ZZ" = "1" /* Dilation of Right Femoral Vein, Percutaneous Approach */
"067M4DZ" = "1" /* Dilation of Right Femoral Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"067M4ZZ" = "1" /* Dilation of Right Femoral Vein, Percutaneous Endoscopic Approach */
"067N0DZ" = "1" /* Dilation of Left Femoral Vein with Intraluminal Device, Open Approach */
"067N0ZZ" = "1" /* Dilation of Left Femoral Vein, Open Approach */
"067N3DZ" = "1" /* Dilation of Left Femoral Vein with Intraluminal Device, Percutaneous Approach */
"067N3ZZ" = "1" /* Dilation of Left Femoral Vein, Percutaneous Approach */
"067N4DZ" = "1" /* Dilation of Left Femoral Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"067N4ZZ" = "1" /* Dilation of Left Femoral Vein, Percutaneous Endoscopic Approach */
"067P0DZ" = "1" /* Dilation of Right Greater Saphenous Vein with Intraluminal Device, Open Approach */
"067P0ZZ" = "1" /* Dilation of Right Greater Saphenous Vein, Open Approach */
"067P3DZ" = "1" /* Dilation of Right Greater Saphenous Vein with Intraluminal Device, Percutaneous Approach */
"067P3ZZ" = "1" /* Dilation of Right Greater Saphenous Vein, Percutaneous Approach */
"067P4DZ" = "1" /* Dilation of Right Greater Saphenous Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"067P4ZZ" = "1" /* Dilation of Right Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"067Q0DZ" = "1" /* Dilation of Left Greater Saphenous Vein with Intraluminal Device, Open Approach */
"067Q0ZZ" = "1" /* Dilation of Left Greater Saphenous Vein, Open Approach */
"067Q3DZ" = "1" /* Dilation of Left Greater Saphenous Vein with Intraluminal Device, Percutaneous Approach */
"067Q3ZZ" = "1" /* Dilation of Left Greater Saphenous Vein, Percutaneous Approach */
"067Q4DZ" = "1" /* Dilation of Left Greater Saphenous Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"067Q4ZZ" = "1" /* Dilation of Left Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"067R0DZ" = "1" /* Dilation of Right Lesser Saphenous Vein with Intraluminal Device, Open Approach */
"067R0ZZ" = "1" /* Dilation of Right Lesser Saphenous Vein, Open Approach */
"067R3DZ" = "1" /* Dilation of Right Lesser Saphenous Vein with Intraluminal Device, Percutaneous Approach */
"067R3ZZ" = "1" /* Dilation of Right Lesser Saphenous Vein, Percutaneous Approach */
"067R4DZ" = "1" /* Dilation of Right Lesser Saphenous Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"067R4ZZ" = "1" /* Dilation of Right Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"067S0DZ" = "1" /* Dilation of Left Lesser Saphenous Vein with Intraluminal Device, Open Approach */
"067S0ZZ" = "1" /* Dilation of Left Lesser Saphenous Vein, Open Approach */
"067S3DZ" = "1" /* Dilation of Left Lesser Saphenous Vein with Intraluminal Device, Percutaneous Approach */
"067S3ZZ" = "1" /* Dilation of Left Lesser Saphenous Vein, Percutaneous Approach */
"067S4DZ" = "1" /* Dilation of Left Lesser Saphenous Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"067S4ZZ" = "1" /* Dilation of Left Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"067T0DZ" = "1" /* Dilation of Right Foot Vein with Intraluminal Device, Open Approach */
"067T0ZZ" = "1" /* Dilation of Right Foot Vein, Open Approach */
"067T3DZ" = "1" /* Dilation of Right Foot Vein with Intraluminal Device, Percutaneous Approach */
"067T3ZZ" = "1" /* Dilation of Right Foot Vein, Percutaneous Approach */
"067T4DZ" = "1" /* Dilation of Right Foot Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"067T4ZZ" = "1" /* Dilation of Right Foot Vein, Percutaneous Endoscopic Approach */
"067V0DZ" = "1" /* Dilation of Left Foot Vein with Intraluminal Device, Open Approach */
"067V0ZZ" = "1" /* Dilation of Left Foot Vein, Open Approach */
"067V3DZ" = "1" /* Dilation of Left Foot Vein with Intraluminal Device, Percutaneous Approach */
"067V3ZZ" = "1" /* Dilation of Left Foot Vein, Percutaneous Approach */
"067V4DZ" = "1" /* Dilation of Left Foot Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"067V4ZZ" = "1" /* Dilation of Left Foot Vein, Percutaneous Endoscopic Approach */
"067Y0DZ" = "1" /* Dilation of Lower Vein with Intraluminal Device, Open Approach */
"067Y0ZZ" = "1" /* Dilation of Lower Vein, Open Approach */
"067Y3DZ" = "1" /* Dilation of Lower Vein with Intraluminal Device, Percutaneous Approach */
"067Y3ZZ" = "1" /* Dilation of Lower Vein, Percutaneous Approach */
"067Y4DZ" = "1" /* Dilation of Lower Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"067Y4ZZ" = "1" /* Dilation of Lower Vein, Percutaneous Endoscopic Approach */
"06900ZX" = "1" /* Drainage of Inferior Vena Cava, Open Approach, Diagnostic */
"06904ZX" = "1" /* Drainage of Inferior Vena Cava, Percutaneous Endoscopic Approach, Diagnostic */
"06910ZX" = "1" /* Drainage of Splenic Vein, Open Approach, Diagnostic */
"06914ZX" = "1" /* Drainage of Splenic Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06920ZX" = "1" /* Drainage of Gastric Vein, Open Approach, Diagnostic */
"06924ZX" = "1" /* Drainage of Gastric Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069300Z" = "1" /* Drainage of Esophageal Vein with Drainage Device, Open Approach */
"06930ZX" = "1" /* Drainage of Esophageal Vein, Open Approach, Diagnostic */
"06930ZZ" = "1" /* Drainage of Esophageal Vein, Open Approach */
"069340Z" = "1" /* Drainage of Esophageal Vein with Drainage Device, Percutaneous Endoscopic Approach */
"06934ZX" = "1" /* Drainage of Esophageal Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06934ZZ" = "1" /* Drainage of Esophageal Vein, Percutaneous Endoscopic Approach */
"06940ZX" = "1" /* Drainage of Hepatic Vein, Open Approach, Diagnostic */
"06944ZX" = "1" /* Drainage of Hepatic Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06950ZX" = "1" /* Drainage of Superior Mesenteric Vein, Open Approach, Diagnostic */
"06954ZX" = "1" /* Drainage of Superior Mesenteric Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06960ZX" = "1" /* Drainage of Inferior Mesenteric Vein, Open Approach, Diagnostic */
"06964ZX" = "1" /* Drainage of Inferior Mesenteric Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06970ZX" = "1" /* Drainage of Colic Vein, Open Approach, Diagnostic */
"06974ZX" = "1" /* Drainage of Colic Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06980ZX" = "1" /* Drainage of Portal Vein, Open Approach, Diagnostic */
"06984ZX" = "1" /* Drainage of Portal Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06990ZX" = "1" /* Drainage of Right Renal Vein, Open Approach, Diagnostic */
"06994ZX" = "1" /* Drainage of Right Renal Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069B0ZX" = "1" /* Drainage of Left Renal Vein, Open Approach, Diagnostic */
"069B4ZX" = "1" /* Drainage of Left Renal Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069C0ZX" = "1" /* Drainage of Right Common Iliac Vein, Open Approach, Diagnostic */
"069C4ZX" = "1" /* Drainage of Right Common Iliac Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069D0ZX" = "1" /* Drainage of Left Common Iliac Vein, Open Approach, Diagnostic */
"069D4ZX" = "1" /* Drainage of Left Common Iliac Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069F0ZX" = "1" /* Drainage of Right External Iliac Vein, Open Approach, Diagnostic */
"069F4ZX" = "1" /* Drainage of Right External Iliac Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069G0ZX" = "1" /* Drainage of Left External Iliac Vein, Open Approach, Diagnostic */
"069G4ZX" = "1" /* Drainage of Left External Iliac Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069H0ZX" = "1" /* Drainage of Right Hypogastric Vein, Open Approach, Diagnostic */
"069H4ZX" = "1" /* Drainage of Right Hypogastric Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069J0ZX" = "1" /* Drainage of Left Hypogastric Vein, Open Approach, Diagnostic */
"069J4ZX" = "1" /* Drainage of Left Hypogastric Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069M0ZX" = "1" /* Drainage of Right Femoral Vein, Open Approach, Diagnostic */
"069M4ZX" = "1" /* Drainage of Right Femoral Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069N0ZX" = "1" /* Drainage of Left Femoral Vein, Open Approach, Diagnostic */
"069N4ZX" = "1" /* Drainage of Left Femoral Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069P0ZX" = "1" /* Drainage of Right Greater Saphenous Vein, Open Approach, Diagnostic */
"069P4ZX" = "1" /* Drainage of Right Greater Saphenous Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069Q0ZX" = "1" /* Drainage of Left Greater Saphenous Vein, Open Approach, Diagnostic */
"069Q4ZX" = "1" /* Drainage of Left Greater Saphenous Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069R0ZX" = "1" /* Drainage of Right Lesser Saphenous Vein, Open Approach, Diagnostic */
"069R4ZX" = "1" /* Drainage of Right Lesser Saphenous Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069S0ZX" = "1" /* Drainage of Left Lesser Saphenous Vein, Open Approach, Diagnostic */
"069S4ZX" = "1" /* Drainage of Left Lesser Saphenous Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069T0ZX" = "1" /* Drainage of Right Foot Vein, Open Approach, Diagnostic */
"069T4ZX" = "1" /* Drainage of Right Foot Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069V0ZX" = "1" /* Drainage of Left Foot Vein, Open Approach, Diagnostic */
"069V4ZX" = "1" /* Drainage of Left Foot Vein, Percutaneous Endoscopic Approach, Diagnostic */
"069Y0ZX" = "1" /* Drainage of Lower Vein, Open Approach, Diagnostic */
"069Y4ZX" = "1" /* Drainage of Lower Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06B00ZX" = "1" /* Excision of Inferior Vena Cava, Open Approach, Diagnostic */
"06B00ZZ" = "1" /* Excision of Inferior Vena Cava, Open Approach */
"06B03ZX" = "1" /* Excision of Inferior Vena Cava, Percutaneous Approach, Diagnostic */
"06B03ZZ" = "1" /* Excision of Inferior Vena Cava, Percutaneous Approach */
"06B04ZX" = "1" /* Excision of Inferior Vena Cava, Percutaneous Endoscopic Approach, Diagnostic */
"06B04ZZ" = "1" /* Excision of Inferior Vena Cava, Percutaneous Endoscopic Approach */
"06B10ZX" = "1" /* Excision of Splenic Vein, Open Approach, Diagnostic */
"06B10ZZ" = "1" /* Excision of Splenic Vein, Open Approach */
"06B13ZX" = "1" /* Excision of Splenic Vein, Percutaneous Approach, Diagnostic */
"06B13ZZ" = "1" /* Excision of Splenic Vein, Percutaneous Approach */
"06B14ZX" = "1" /* Excision of Splenic Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06B14ZZ" = "1" /* Excision of Splenic Vein, Percutaneous Endoscopic Approach */
"06B20ZX" = "1" /* Excision of Gastric Vein, Open Approach, Diagnostic */
"06B20ZZ" = "1" /* Excision of Gastric Vein, Open Approach */
"06B23ZX" = "1" /* Excision of Gastric Vein, Percutaneous Approach, Diagnostic */
"06B23ZZ" = "1" /* Excision of Gastric Vein, Percutaneous Approach */
"06B24ZX" = "1" /* Excision of Gastric Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06B24ZZ" = "1" /* Excision of Gastric Vein, Percutaneous Endoscopic Approach */
"06B30ZX" = "1" /* Excision of Esophageal Vein, Open Approach, Diagnostic */
"06B30ZZ" = "1" /* Excision of Esophageal Vein, Open Approach */
"06B33ZX" = "1" /* Excision of Esophageal Vein, Percutaneous Approach, Diagnostic */
"06B33ZZ" = "1" /* Excision of Esophageal Vein, Percutaneous Approach */
"06B34ZX" = "1" /* Excision of Esophageal Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06B34ZZ" = "1" /* Excision of Esophageal Vein, Percutaneous Endoscopic Approach */
"06B40ZX" = "1" /* Excision of Hepatic Vein, Open Approach, Diagnostic */
"06B40ZZ" = "1" /* Excision of Hepatic Vein, Open Approach */
"06B43ZX" = "1" /* Excision of Hepatic Vein, Percutaneous Approach, Diagnostic */
"06B43ZZ" = "1" /* Excision of Hepatic Vein, Percutaneous Approach */
"06B44ZX" = "1" /* Excision of Hepatic Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06B44ZZ" = "1" /* Excision of Hepatic Vein, Percutaneous Endoscopic Approach */
"06B50ZX" = "1" /* Excision of Superior Mesenteric Vein, Open Approach, Diagnostic */
"06B50ZZ" = "1" /* Excision of Superior Mesenteric Vein, Open Approach */
"06B53ZX" = "1" /* Excision of Superior Mesenteric Vein, Percutaneous Approach, Diagnostic */
"06B53ZZ" = "1" /* Excision of Superior Mesenteric Vein, Percutaneous Approach */
"06B54ZX" = "1" /* Excision of Superior Mesenteric Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06B54ZZ" = "1" /* Excision of Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06B60ZX" = "1" /* Excision of Inferior Mesenteric Vein, Open Approach, Diagnostic */
"06B60ZZ" = "1" /* Excision of Inferior Mesenteric Vein, Open Approach */
"06B63ZX" = "1" /* Excision of Inferior Mesenteric Vein, Percutaneous Approach, Diagnostic */
"06B63ZZ" = "1" /* Excision of Inferior Mesenteric Vein, Percutaneous Approach */
"06B64ZX" = "1" /* Excision of Inferior Mesenteric Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06B64ZZ" = "1" /* Excision of Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06B70ZX" = "1" /* Excision of Colic Vein, Open Approach, Diagnostic */
"06B70ZZ" = "1" /* Excision of Colic Vein, Open Approach */
"06B73ZX" = "1" /* Excision of Colic Vein, Percutaneous Approach, Diagnostic */
"06B73ZZ" = "1" /* Excision of Colic Vein, Percutaneous Approach */
"06B74ZX" = "1" /* Excision of Colic Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06B74ZZ" = "1" /* Excision of Colic Vein, Percutaneous Endoscopic Approach */
"06B80ZX" = "1" /* Excision of Portal Vein, Open Approach, Diagnostic */
"06B80ZZ" = "1" /* Excision of Portal Vein, Open Approach */
"06B83ZX" = "1" /* Excision of Portal Vein, Percutaneous Approach, Diagnostic */
"06B83ZZ" = "1" /* Excision of Portal Vein, Percutaneous Approach */
"06B84ZX" = "1" /* Excision of Portal Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06B84ZZ" = "1" /* Excision of Portal Vein, Percutaneous Endoscopic Approach */
"06B90ZX" = "1" /* Excision of Right Renal Vein, Open Approach, Diagnostic */
"06B90ZZ" = "1" /* Excision of Right Renal Vein, Open Approach */
"06B93ZX" = "1" /* Excision of Right Renal Vein, Percutaneous Approach, Diagnostic */
"06B93ZZ" = "1" /* Excision of Right Renal Vein, Percutaneous Approach */
"06B94ZX" = "1" /* Excision of Right Renal Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06B94ZZ" = "1" /* Excision of Right Renal Vein, Percutaneous Endoscopic Approach */
"06BB0ZX" = "1" /* Excision of Left Renal Vein, Open Approach, Diagnostic */
"06BB0ZZ" = "1" /* Excision of Left Renal Vein, Open Approach */
"06BB3ZX" = "1" /* Excision of Left Renal Vein, Percutaneous Approach, Diagnostic */
"06BB3ZZ" = "1" /* Excision of Left Renal Vein, Percutaneous Approach */
"06BB4ZX" = "1" /* Excision of Left Renal Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06BB4ZZ" = "1" /* Excision of Left Renal Vein, Percutaneous Endoscopic Approach */
"06BC0ZX" = "1" /* Excision of Right Common Iliac Vein, Open Approach, Diagnostic */
"06BC0ZZ" = "1" /* Excision of Right Common Iliac Vein, Open Approach */
"06BC3ZX" = "1" /* Excision of Right Common Iliac Vein, Percutaneous Approach, Diagnostic */
"06BC3ZZ" = "1" /* Excision of Right Common Iliac Vein, Percutaneous Approach */
"06BC4ZX" = "1" /* Excision of Right Common Iliac Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06BC4ZZ" = "1" /* Excision of Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"06BD0ZX" = "1" /* Excision of Left Common Iliac Vein, Open Approach, Diagnostic */
"06BD0ZZ" = "1" /* Excision of Left Common Iliac Vein, Open Approach */
"06BD3ZX" = "1" /* Excision of Left Common Iliac Vein, Percutaneous Approach, Diagnostic */
"06BD3ZZ" = "1" /* Excision of Left Common Iliac Vein, Percutaneous Approach */
"06BD4ZX" = "1" /* Excision of Left Common Iliac Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06BD4ZZ" = "1" /* Excision of Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"06BF0ZX" = "1" /* Excision of Right External Iliac Vein, Open Approach, Diagnostic */
"06BF0ZZ" = "1" /* Excision of Right External Iliac Vein, Open Approach */
"06BF3ZX" = "1" /* Excision of Right External Iliac Vein, Percutaneous Approach, Diagnostic */
"06BF3ZZ" = "1" /* Excision of Right External Iliac Vein, Percutaneous Approach */
"06BF4ZX" = "1" /* Excision of Right External Iliac Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06BF4ZZ" = "1" /* Excision of Right External Iliac Vein, Percutaneous Endoscopic Approach */
"06BG0ZX" = "1" /* Excision of Left External Iliac Vein, Open Approach, Diagnostic */
"06BG0ZZ" = "1" /* Excision of Left External Iliac Vein, Open Approach */
"06BG3ZX" = "1" /* Excision of Left External Iliac Vein, Percutaneous Approach, Diagnostic */
"06BG3ZZ" = "1" /* Excision of Left External Iliac Vein, Percutaneous Approach */
"06BG4ZX" = "1" /* Excision of Left External Iliac Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06BG4ZZ" = "1" /* Excision of Left External Iliac Vein, Percutaneous Endoscopic Approach */
"06BH0ZX" = "1" /* Excision of Right Hypogastric Vein, Open Approach, Diagnostic */
"06BH0ZZ" = "1" /* Excision of Right Hypogastric Vein, Open Approach */
"06BH3ZX" = "1" /* Excision of Right Hypogastric Vein, Percutaneous Approach, Diagnostic */
"06BH3ZZ" = "1" /* Excision of Right Hypogastric Vein, Percutaneous Approach */
"06BH4ZX" = "1" /* Excision of Right Hypogastric Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06BH4ZZ" = "1" /* Excision of Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"06BJ0ZX" = "1" /* Excision of Left Hypogastric Vein, Open Approach, Diagnostic */
"06BJ0ZZ" = "1" /* Excision of Left Hypogastric Vein, Open Approach */
"06BJ3ZX" = "1" /* Excision of Left Hypogastric Vein, Percutaneous Approach, Diagnostic */
"06BJ3ZZ" = "1" /* Excision of Left Hypogastric Vein, Percutaneous Approach */
"06BJ4ZX" = "1" /* Excision of Left Hypogastric Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06BJ4ZZ" = "1" /* Excision of Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"06BM0ZX" = "1" /* Excision of Right Femoral Vein, Open Approach, Diagnostic */
"06BM0ZZ" = "1" /* Excision of Right Femoral Vein, Open Approach */
"06BM3ZX" = "1" /* Excision of Right Femoral Vein, Percutaneous Approach, Diagnostic */
"06BM3ZZ" = "1" /* Excision of Right Femoral Vein, Percutaneous Approach */
"06BM4ZX" = "1" /* Excision of Right Femoral Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06BM4ZZ" = "1" /* Excision of Right Femoral Vein, Percutaneous Endoscopic Approach */
"06BN0ZX" = "1" /* Excision of Left Femoral Vein, Open Approach, Diagnostic */
"06BN0ZZ" = "1" /* Excision of Left Femoral Vein, Open Approach */
"06BN3ZX" = "1" /* Excision of Left Femoral Vein, Percutaneous Approach, Diagnostic */
"06BN3ZZ" = "1" /* Excision of Left Femoral Vein, Percutaneous Approach */
"06BN4ZX" = "1" /* Excision of Left Femoral Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06BN4ZZ" = "1" /* Excision of Left Femoral Vein, Percutaneous Endoscopic Approach */
"06BP0ZX" = "1" /* Excision of Right Greater Saphenous Vein, Open Approach, Diagnostic */
"06BP0ZZ" = "1" /* Excision of Right Greater Saphenous Vein, Open Approach */
"06BP3ZX" = "1" /* Excision of Right Greater Saphenous Vein, Percutaneous Approach, Diagnostic */
"06BP3ZZ" = "1" /* Excision of Right Greater Saphenous Vein, Percutaneous Approach */
"06BP4ZX" = "1" /* Excision of Right Greater Saphenous Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06BP4ZZ" = "1" /* Excision of Right Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"06BQ0ZX" = "1" /* Excision of Left Greater Saphenous Vein, Open Approach, Diagnostic */
"06BQ0ZZ" = "1" /* Excision of Left Greater Saphenous Vein, Open Approach */
"06BQ3ZX" = "1" /* Excision of Left Greater Saphenous Vein, Percutaneous Approach, Diagnostic */
"06BQ3ZZ" = "1" /* Excision of Left Greater Saphenous Vein, Percutaneous Approach */
"06BQ4ZX" = "1" /* Excision of Left Greater Saphenous Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06BQ4ZZ" = "1" /* Excision of Left Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"06BR0ZX" = "1" /* Excision of Right Lesser Saphenous Vein, Open Approach, Diagnostic */
"06BR0ZZ" = "1" /* Excision of Right Lesser Saphenous Vein, Open Approach */
"06BR3ZX" = "1" /* Excision of Right Lesser Saphenous Vein, Percutaneous Approach, Diagnostic */
"06BR3ZZ" = "1" /* Excision of Right Lesser Saphenous Vein, Percutaneous Approach */
"06BR4ZX" = "1" /* Excision of Right Lesser Saphenous Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06BR4ZZ" = "1" /* Excision of Right Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"06BS0ZX" = "1" /* Excision of Left Lesser Saphenous Vein, Open Approach, Diagnostic */
"06BS0ZZ" = "1" /* Excision of Left Lesser Saphenous Vein, Open Approach */
"06BS3ZX" = "1" /* Excision of Left Lesser Saphenous Vein, Percutaneous Approach, Diagnostic */
"06BS3ZZ" = "1" /* Excision of Left Lesser Saphenous Vein, Percutaneous Approach */
"06BS4ZX" = "1" /* Excision of Left Lesser Saphenous Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06BS4ZZ" = "1" /* Excision of Left Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"06BT0ZX" = "1" /* Excision of Right Foot Vein, Open Approach, Diagnostic */
"06BT0ZZ" = "1" /* Excision of Right Foot Vein, Open Approach */
"06BT3ZX" = "1" /* Excision of Right Foot Vein, Percutaneous Approach, Diagnostic */
"06BT3ZZ" = "1" /* Excision of Right Foot Vein, Percutaneous Approach */
"06BT4ZX" = "1" /* Excision of Right Foot Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06BT4ZZ" = "1" /* Excision of Right Foot Vein, Percutaneous Endoscopic Approach */
"06BV0ZX" = "1" /* Excision of Left Foot Vein, Open Approach, Diagnostic */
"06BV0ZZ" = "1" /* Excision of Left Foot Vein, Open Approach */
"06BV3ZX" = "1" /* Excision of Left Foot Vein, Percutaneous Approach, Diagnostic */
"06BV3ZZ" = "1" /* Excision of Left Foot Vein, Percutaneous Approach */
"06BV4ZX" = "1" /* Excision of Left Foot Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06BV4ZZ" = "1" /* Excision of Left Foot Vein, Percutaneous Endoscopic Approach */
"06BY0ZC" = "1" /* Excision of Hemorrhoidal Plexus, Open Approach */
"06BY0ZX" = "1" /* Excision of Lower Vein, Open Approach, Diagnostic */
"06BY0ZZ" = "1" /* Excision of Lower Vein, Open Approach */
"06BY3ZC" = "1" /* Excision of Hemorrhoidal Plexus, Percutaneous Approach */
"06BY3ZX" = "1" /* Excision of Lower Vein, Percutaneous Approach, Diagnostic */
"06BY3ZZ" = "1" /* Excision of Lower Vein, Percutaneous Approach */
"06BY4ZC" = "1" /* Excision of Hemorrhoidal Plexus, Percutaneous Endoscopic Approach */
"06BY4ZX" = "1" /* Excision of Lower Vein, Percutaneous Endoscopic Approach, Diagnostic */
"06BY4ZZ" = "1" /* Excision of Lower Vein, Percutaneous Endoscopic Approach */
"06C00ZZ" = "1" /* Extirpation of Matter from Inferior Vena Cava, Open Approach */
"06C03ZZ" = "1" /* Extirpation of Matter from Inferior Vena Cava, Percutaneous Approach */
"06C04ZZ" = "1" /* Extirpation of Matter from Inferior Vena Cava, Percutaneous Endoscopic Approach */
"06C10ZZ" = "1" /* Extirpation of Matter from Splenic Vein, Open Approach */
"06C13ZZ" = "1" /* Extirpation of Matter from Splenic Vein, Percutaneous Approach */
"06C14ZZ" = "1" /* Extirpation of Matter from Splenic Vein, Percutaneous Endoscopic Approach */
"06C20ZZ" = "1" /* Extirpation of Matter from Gastric Vein, Open Approach */
"06C23ZZ" = "1" /* Extirpation of Matter from Gastric Vein, Percutaneous Approach */
"06C24ZZ" = "1" /* Extirpation of Matter from Gastric Vein, Percutaneous Endoscopic Approach */
"06C30ZZ" = "1" /* Extirpation of Matter from Esophageal Vein, Open Approach */
"06C33ZZ" = "1" /* Extirpation of Matter from Esophageal Vein, Percutaneous Approach */
"06C34ZZ" = "1" /* Extirpation of Matter from Esophageal Vein, Percutaneous Endoscopic Approach */
"06C40ZZ" = "1" /* Extirpation of Matter from Hepatic Vein, Open Approach */
"06C43ZZ" = "1" /* Extirpation of Matter from Hepatic Vein, Percutaneous Approach */
"06C44ZZ" = "1" /* Extirpation of Matter from Hepatic Vein, Percutaneous Endoscopic Approach */
"06C50ZZ" = "1" /* Extirpation of Matter from Superior Mesenteric Vein, Open Approach */
"06C53ZZ" = "1" /* Extirpation of Matter from Superior Mesenteric Vein, Percutaneous Approach */
"06C54ZZ" = "1" /* Extirpation of Matter from Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06C60ZZ" = "1" /* Extirpation of Matter from Inferior Mesenteric Vein, Open Approach */
"06C63ZZ" = "1" /* Extirpation of Matter from Inferior Mesenteric Vein, Percutaneous Approach */
"06C64ZZ" = "1" /* Extirpation of Matter from Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06C70ZZ" = "1" /* Extirpation of Matter from Colic Vein, Open Approach */
"06C73ZZ" = "1" /* Extirpation of Matter from Colic Vein, Percutaneous Approach */
"06C74ZZ" = "1" /* Extirpation of Matter from Colic Vein, Percutaneous Endoscopic Approach */
"06C80ZZ" = "1" /* Extirpation of Matter from Portal Vein, Open Approach */
"06C83ZZ" = "1" /* Extirpation of Matter from Portal Vein, Percutaneous Approach */
"06C84ZZ" = "1" /* Extirpation of Matter from Portal Vein, Percutaneous Endoscopic Approach */
"06C90ZZ" = "1" /* Extirpation of Matter from Right Renal Vein, Open Approach */
"06C93ZZ" = "1" /* Extirpation of Matter from Right Renal Vein, Percutaneous Approach */
"06C94ZZ" = "1" /* Extirpation of Matter from Right Renal Vein, Percutaneous Endoscopic Approach */
"06CB0ZZ" = "1" /* Extirpation of Matter from Left Renal Vein, Open Approach */
"06CB3ZZ" = "1" /* Extirpation of Matter from Left Renal Vein, Percutaneous Approach */
"06CB4ZZ" = "1" /* Extirpation of Matter from Left Renal Vein, Percutaneous Endoscopic Approach */
"06CC0ZZ" = "1" /* Extirpation of Matter from Right Common Iliac Vein, Open Approach */
"06CC3ZZ" = "1" /* Extirpation of Matter from Right Common Iliac Vein, Percutaneous Approach */
"06CC4ZZ" = "1" /* Extirpation of Matter from Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"06CD0ZZ" = "1" /* Extirpation of Matter from Left Common Iliac Vein, Open Approach */
"06CD3ZZ" = "1" /* Extirpation of Matter from Left Common Iliac Vein, Percutaneous Approach */
"06CD4ZZ" = "1" /* Extirpation of Matter from Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"06CF0ZZ" = "1" /* Extirpation of Matter from Right External Iliac Vein, Open Approach */
"06CF3ZZ" = "1" /* Extirpation of Matter from Right External Iliac Vein, Percutaneous Approach */
"06CF4ZZ" = "1" /* Extirpation of Matter from Right External Iliac Vein, Percutaneous Endoscopic Approach */
"06CG0ZZ" = "1" /* Extirpation of Matter from Left External Iliac Vein, Open Approach */
"06CG3ZZ" = "1" /* Extirpation of Matter from Left External Iliac Vein, Percutaneous Approach */
"06CG4ZZ" = "1" /* Extirpation of Matter from Left External Iliac Vein, Percutaneous Endoscopic Approach */
"06CH0ZZ" = "1" /* Extirpation of Matter from Right Hypogastric Vein, Open Approach */
"06CH3ZZ" = "1" /* Extirpation of Matter from Right Hypogastric Vein, Percutaneous Approach */
"06CH4ZZ" = "1" /* Extirpation of Matter from Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"06CJ0ZZ" = "1" /* Extirpation of Matter from Left Hypogastric Vein, Open Approach */
"06CJ3ZZ" = "1" /* Extirpation of Matter from Left Hypogastric Vein, Percutaneous Approach */
"06CJ4ZZ" = "1" /* Extirpation of Matter from Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"06CM0ZZ" = "1" /* Extirpation of Matter from Right Femoral Vein, Open Approach */
"06CM3ZZ" = "1" /* Extirpation of Matter from Right Femoral Vein, Percutaneous Approach */
"06CM4ZZ" = "1" /* Extirpation of Matter from Right Femoral Vein, Percutaneous Endoscopic Approach */
"06CN0ZZ" = "1" /* Extirpation of Matter from Left Femoral Vein, Open Approach */
"06CN3ZZ" = "1" /* Extirpation of Matter from Left Femoral Vein, Percutaneous Approach */
"06CN4ZZ" = "1" /* Extirpation of Matter from Left Femoral Vein, Percutaneous Endoscopic Approach */
"06CP0ZZ" = "1" /* Extirpation of Matter from Right Greater Saphenous Vein, Open Approach */
"06CP3ZZ" = "1" /* Extirpation of Matter from Right Greater Saphenous Vein, Percutaneous Approach */
"06CP4ZZ" = "1" /* Extirpation of Matter from Right Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"06CQ0ZZ" = "1" /* Extirpation of Matter from Left Greater Saphenous Vein, Open Approach */
"06CQ3ZZ" = "1" /* Extirpation of Matter from Left Greater Saphenous Vein, Percutaneous Approach */
"06CQ4ZZ" = "1" /* Extirpation of Matter from Left Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"06CR0ZZ" = "1" /* Extirpation of Matter from Right Lesser Saphenous Vein, Open Approach */
"06CR3ZZ" = "1" /* Extirpation of Matter from Right Lesser Saphenous Vein, Percutaneous Approach */
"06CR4ZZ" = "1" /* Extirpation of Matter from Right Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"06CS0ZZ" = "1" /* Extirpation of Matter from Left Lesser Saphenous Vein, Open Approach */
"06CS3ZZ" = "1" /* Extirpation of Matter from Left Lesser Saphenous Vein, Percutaneous Approach */
"06CS4ZZ" = "1" /* Extirpation of Matter from Left Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"06CT0ZZ" = "1" /* Extirpation of Matter from Right Foot Vein, Open Approach */
"06CT3ZZ" = "1" /* Extirpation of Matter from Right Foot Vein, Percutaneous Approach */
"06CT4ZZ" = "1" /* Extirpation of Matter from Right Foot Vein, Percutaneous Endoscopic Approach */
"06CV0ZZ" = "1" /* Extirpation of Matter from Left Foot Vein, Open Approach */
"06CV3ZZ" = "1" /* Extirpation of Matter from Left Foot Vein, Percutaneous Approach */
"06CV4ZZ" = "1" /* Extirpation of Matter from Left Foot Vein, Percutaneous Endoscopic Approach */
"06CY0ZZ" = "1" /* Extirpation of Matter from Lower Vein, Open Approach */
"06CY3ZZ" = "1" /* Extirpation of Matter from Lower Vein, Percutaneous Approach */
"06CY4ZZ" = "1" /* Extirpation of Matter from Lower Vein, Percutaneous Endoscopic Approach */
"06DM0ZZ" = "1" /* Extraction of Right Femoral Vein, Open Approach */
"06DM3ZZ" = "1" /* Extraction of Right Femoral Vein, Percutaneous Approach */
"06DM4ZZ" = "1" /* Extraction of Right Femoral Vein, Percutaneous Endoscopic Approach */
"06DN0ZZ" = "1" /* Extraction of Left Femoral Vein, Open Approach */
"06DN3ZZ" = "1" /* Extraction of Left Femoral Vein, Percutaneous Approach */
"06DN4ZZ" = "1" /* Extraction of Left Femoral Vein, Percutaneous Endoscopic Approach */
"06DP0ZZ" = "1" /* Extraction of Right Greater Saphenous Vein, Open Approach */
"06DP3ZZ" = "1" /* Extraction of Right Greater Saphenous Vein, Percutaneous Approach */
"06DP4ZZ" = "1" /* Extraction of Right Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"06DQ0ZZ" = "1" /* Extraction of Left Greater Saphenous Vein, Open Approach */
"06DQ3ZZ" = "1" /* Extraction of Left Greater Saphenous Vein, Percutaneous Approach */
"06DQ4ZZ" = "1" /* Extraction of Left Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"06DR0ZZ" = "1" /* Extraction of Right Lesser Saphenous Vein, Open Approach */
"06DR3ZZ" = "1" /* Extraction of Right Lesser Saphenous Vein, Percutaneous Approach */
"06DR4ZZ" = "1" /* Extraction of Right Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"06DS0ZZ" = "1" /* Extraction of Left Lesser Saphenous Vein, Open Approach */
"06DS3ZZ" = "1" /* Extraction of Left Lesser Saphenous Vein, Percutaneous Approach */
"06DS4ZZ" = "1" /* Extraction of Left Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"06DT0ZZ" = "1" /* Extraction of Right Foot Vein, Open Approach */
"06DT3ZZ" = "1" /* Extraction of Right Foot Vein, Percutaneous Approach */
"06DT4ZZ" = "1" /* Extraction of Right Foot Vein, Percutaneous Endoscopic Approach */
"06DV0ZZ" = "1" /* Extraction of Left Foot Vein, Open Approach */
"06DV3ZZ" = "1" /* Extraction of Left Foot Vein, Percutaneous Approach */
"06DV4ZZ" = "1" /* Extraction of Left Foot Vein, Percutaneous Endoscopic Approach */
"06DY0ZZ" = "1" /* Extraction of Lower Vein, Open Approach */
"06DY3ZZ" = "1" /* Extraction of Lower Vein, Percutaneous Approach */
"06DY4ZZ" = "1" /* Extraction of Lower Vein, Percutaneous Endoscopic Approach */
"06H00DZ" = "1" /* Insertion of Intraluminal Device into Inferior Vena Cava, Open Approach */
"06H04DZ" = "1" /* Insertion of Intraluminal Device into Inferior Vena Cava, Percutaneous Endoscopic Approach */
"06H10DZ" = "1" /* Insertion of Intraluminal Device into Splenic Vein, Open Approach */
"06H13DZ" = "1" /* Insertion of Intraluminal Device into Splenic Vein, Percutaneous Approach */
"06H14DZ" = "1" /* Insertion of Intraluminal Device into Splenic Vein, Percutaneous Endoscopic Approach */
"06H20DZ" = "1" /* Insertion of Intraluminal Device into Gastric Vein, Open Approach */
"06H23DZ" = "1" /* Insertion of Intraluminal Device into Gastric Vein, Percutaneous Approach */
"06H24DZ" = "1" /* Insertion of Intraluminal Device into Gastric Vein, Percutaneous Endoscopic Approach */
"06H30DZ" = "1" /* Insertion of Intraluminal Device into Esophageal Vein, Open Approach */
"06H33DZ" = "1" /* Insertion of Intraluminal Device into Esophageal Vein, Percutaneous Approach */
"06H34DZ" = "1" /* Insertion of Intraluminal Device into Esophageal Vein, Percutaneous Endoscopic Approach */
"06H40DZ" = "1" /* Insertion of Intraluminal Device into Hepatic Vein, Open Approach */
"06H43DZ" = "1" /* Insertion of Intraluminal Device into Hepatic Vein, Percutaneous Approach */
"06H44DZ" = "1" /* Insertion of Intraluminal Device into Hepatic Vein, Percutaneous Endoscopic Approach */
"06H50DZ" = "1" /* Insertion of Intraluminal Device into Superior Mesenteric Vein, Open Approach */
"06H53DZ" = "1" /* Insertion of Intraluminal Device into Superior Mesenteric Vein, Percutaneous Approach */
"06H54DZ" = "1" /* Insertion of Intraluminal Device into Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06H60DZ" = "1" /* Insertion of Intraluminal Device into Inferior Mesenteric Vein, Open Approach */
"06H63DZ" = "1" /* Insertion of Intraluminal Device into Inferior Mesenteric Vein, Percutaneous Approach */
"06H64DZ" = "1" /* Insertion of Intraluminal Device into Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06H70DZ" = "1" /* Insertion of Intraluminal Device into Colic Vein, Open Approach */
"06H73DZ" = "1" /* Insertion of Intraluminal Device into Colic Vein, Percutaneous Approach */
"06H74DZ" = "1" /* Insertion of Intraluminal Device into Colic Vein, Percutaneous Endoscopic Approach */
"06H80DZ" = "1" /* Insertion of Intraluminal Device into Portal Vein, Open Approach */
"06H83DZ" = "1" /* Insertion of Intraluminal Device into Portal Vein, Percutaneous Approach */
"06H84DZ" = "1" /* Insertion of Intraluminal Device into Portal Vein, Percutaneous Endoscopic Approach */
"06H90DZ" = "1" /* Insertion of Intraluminal Device into Right Renal Vein, Open Approach */
"06H93DZ" = "1" /* Insertion of Intraluminal Device into Right Renal Vein, Percutaneous Approach */
"06H94DZ" = "1" /* Insertion of Intraluminal Device into Right Renal Vein, Percutaneous Endoscopic Approach */
"06HB0DZ" = "1" /* Insertion of Intraluminal Device into Left Renal Vein, Open Approach */
"06HB3DZ" = "1" /* Insertion of Intraluminal Device into Left Renal Vein, Percutaneous Approach */
"06HB4DZ" = "1" /* Insertion of Intraluminal Device into Left Renal Vein, Percutaneous Endoscopic Approach */
"06HC0DZ" = "1" /* Insertion of Intraluminal Device into Right Common Iliac Vein, Open Approach */
"06HC3DZ" = "1" /* Insertion of Intraluminal Device into Right Common Iliac Vein, Percutaneous Approach */
"06HC4DZ" = "1" /* Insertion of Intraluminal Device into Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"06HD0DZ" = "1" /* Insertion of Intraluminal Device into Left Common Iliac Vein, Open Approach */
"06HD3DZ" = "1" /* Insertion of Intraluminal Device into Left Common Iliac Vein, Percutaneous Approach */
"06HD4DZ" = "1" /* Insertion of Intraluminal Device into Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"06HF0DZ" = "1" /* Insertion of Intraluminal Device into Right External Iliac Vein, Open Approach */
"06HF3DZ" = "1" /* Insertion of Intraluminal Device into Right External Iliac Vein, Percutaneous Approach */
"06HF4DZ" = "1" /* Insertion of Intraluminal Device into Right External Iliac Vein, Percutaneous Endoscopic Approach */
"06HG0DZ" = "1" /* Insertion of Intraluminal Device into Left External Iliac Vein, Open Approach */
"06HG3DZ" = "1" /* Insertion of Intraluminal Device into Left External Iliac Vein, Percutaneous Approach */
"06HG4DZ" = "1" /* Insertion of Intraluminal Device into Left External Iliac Vein, Percutaneous Endoscopic Approach */
"06HH0DZ" = "1" /* Insertion of Intraluminal Device into Right Hypogastric Vein, Open Approach */
"06HH3DZ" = "1" /* Insertion of Intraluminal Device into Right Hypogastric Vein, Percutaneous Approach */
"06HH4DZ" = "1" /* Insertion of Intraluminal Device into Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"06HJ0DZ" = "1" /* Insertion of Intraluminal Device into Left Hypogastric Vein, Open Approach */
"06HJ3DZ" = "1" /* Insertion of Intraluminal Device into Left Hypogastric Vein, Percutaneous Approach */
"06HJ4DZ" = "1" /* Insertion of Intraluminal Device into Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"06HM0DZ" = "1" /* Insertion of Intraluminal Device into Right Femoral Vein, Open Approach */
"06HM3DZ" = "1" /* Insertion of Intraluminal Device into Right Femoral Vein, Percutaneous Approach */
"06HM4DZ" = "1" /* Insertion of Intraluminal Device into Right Femoral Vein, Percutaneous Endoscopic Approach */
"06HN0DZ" = "1" /* Insertion of Intraluminal Device into Left Femoral Vein, Open Approach */
"06HN3DZ" = "1" /* Insertion of Intraluminal Device into Left Femoral Vein, Percutaneous Approach */
"06HN4DZ" = "1" /* Insertion of Intraluminal Device into Left Femoral Vein, Percutaneous Endoscopic Approach */
"06HP0DZ" = "1" /* Insertion of Intraluminal Device into Right Greater Saphenous Vein, Open Approach */
"06HP3DZ" = "1" /* Insertion of Intraluminal Device into Right Greater Saphenous Vein, Percutaneous Approach */
"06HP4DZ" = "1" /* Insertion of Intraluminal Device into Right Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"06HQ0DZ" = "1" /* Insertion of Intraluminal Device into Left Greater Saphenous Vein, Open Approach */
"06HQ3DZ" = "1" /* Insertion of Intraluminal Device into Left Greater Saphenous Vein, Percutaneous Approach */
"06HQ4DZ" = "1" /* Insertion of Intraluminal Device into Left Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"06HR0DZ" = "1" /* Insertion of Intraluminal Device into Right Lesser Saphenous Vein, Open Approach */
"06HR3DZ" = "1" /* Insertion of Intraluminal Device into Right Lesser Saphenous Vein, Percutaneous Approach */
"06HR4DZ" = "1" /* Insertion of Intraluminal Device into Right Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"06HS0DZ" = "1" /* Insertion of Intraluminal Device into Left Lesser Saphenous Vein, Open Approach */
"06HS3DZ" = "1" /* Insertion of Intraluminal Device into Left Lesser Saphenous Vein, Percutaneous Approach */
"06HS4DZ" = "1" /* Insertion of Intraluminal Device into Left Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"06HT0DZ" = "1" /* Insertion of Intraluminal Device into Right Foot Vein, Open Approach */
"06HT3DZ" = "1" /* Insertion of Intraluminal Device into Right Foot Vein, Percutaneous Approach */
"06HT4DZ" = "1" /* Insertion of Intraluminal Device into Right Foot Vein, Percutaneous Endoscopic Approach */
"06HV0DZ" = "1" /* Insertion of Intraluminal Device into Left Foot Vein, Open Approach */
"06HV3DZ" = "1" /* Insertion of Intraluminal Device into Left Foot Vein, Percutaneous Approach */
"06HV4DZ" = "1" /* Insertion of Intraluminal Device into Left Foot Vein, Percutaneous Endoscopic Approach */
"06HY02Z" = "1" /* Insertion of Monitoring Device into Lower Vein, Open Approach */
"06HY0DZ" = "1" /* Insertion of Intraluminal Device into Lower Vein, Open Approach */
"06HY3DZ" = "1" /* Insertion of Intraluminal Device into Lower Vein, Percutaneous Approach */
"06HY42Z" = "1" /* Insertion of Monitoring Device into Lower Vein, Percutaneous Endoscopic Approach */
"06HY4DZ" = "1" /* Insertion of Intraluminal Device into Lower Vein, Percutaneous Endoscopic Approach */
"06JY0ZZ" = "1" /* Inspection of Lower Vein, Open Approach */
"06JY4ZZ" = "1" /* Inspection of Lower Vein, Percutaneous Endoscopic Approach */
"06L00CZ" = "1" /* Occlusion of Inferior Vena Cava with Extraluminal Device, Open Approach */
"06L00DZ" = "1" /* Occlusion of Inferior Vena Cava with Intraluminal Device, Open Approach */
"06L00ZZ" = "1" /* Occlusion of Inferior Vena Cava, Open Approach */
"06L03CZ" = "1" /* Occlusion of Inferior Vena Cava with Extraluminal Device, Percutaneous Approach */
"06L03DZ" = "1" /* Occlusion of Inferior Vena Cava with Intraluminal Device, Percutaneous Approach */
"06L03ZZ" = "1" /* Occlusion of Inferior Vena Cava, Percutaneous Approach */
"06L04CZ" = "1" /* Occlusion of Inferior Vena Cava with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L04DZ" = "1" /* Occlusion of Inferior Vena Cava with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L04ZZ" = "1" /* Occlusion of Inferior Vena Cava, Percutaneous Endoscopic Approach */
"06L10CZ" = "1" /* Occlusion of Splenic Vein with Extraluminal Device, Open Approach */
"06L10DZ" = "1" /* Occlusion of Splenic Vein with Intraluminal Device, Open Approach */
"06L10ZZ" = "1" /* Occlusion of Splenic Vein, Open Approach */
"06L13CZ" = "1" /* Occlusion of Splenic Vein with Extraluminal Device, Percutaneous Approach */
"06L13DZ" = "1" /* Occlusion of Splenic Vein with Intraluminal Device, Percutaneous Approach */
"06L13ZZ" = "1" /* Occlusion of Splenic Vein, Percutaneous Approach */
"06L14CZ" = "1" /* Occlusion of Splenic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L14DZ" = "1" /* Occlusion of Splenic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L14ZZ" = "1" /* Occlusion of Splenic Vein, Percutaneous Endoscopic Approach */
"06L20CZ" = "1" /* Occlusion of Gastric Vein with Extraluminal Device, Open Approach */
"06L20DZ" = "1" /* Occlusion of Gastric Vein with Intraluminal Device, Open Approach */
"06L20ZZ" = "1" /* Occlusion of Gastric Vein, Open Approach */
"06L23CZ" = "1" /* Occlusion of Gastric Vein with Extraluminal Device, Percutaneous Approach */
"06L23DZ" = "1" /* Occlusion of Gastric Vein with Intraluminal Device, Percutaneous Approach */
"06L23ZZ" = "1" /* Occlusion of Gastric Vein, Percutaneous Approach */
"06L24CZ" = "1" /* Occlusion of Gastric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L24DZ" = "1" /* Occlusion of Gastric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L24ZZ" = "1" /* Occlusion of Gastric Vein, Percutaneous Endoscopic Approach */
"06L30CZ" = "1" /* Occlusion of Esophageal Vein with Extraluminal Device, Open Approach */
"06L30DZ" = "1" /* Occlusion of Esophageal Vein with Intraluminal Device, Open Approach */
"06L30ZZ" = "1" /* Occlusion of Esophageal Vein, Open Approach */
"06L33CZ" = "1" /* Occlusion of Esophageal Vein with Extraluminal Device, Percutaneous Approach */
"06L33DZ" = "1" /* Occlusion of Esophageal Vein with Intraluminal Device, Percutaneous Approach */
"06L33ZZ" = "1" /* Occlusion of Esophageal Vein, Percutaneous Approach */
"06L34CZ" = "1" /* Occlusion of Esophageal Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L34DZ" = "1" /* Occlusion of Esophageal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L34ZZ" = "1" /* Occlusion of Esophageal Vein, Percutaneous Endoscopic Approach */
"06L40CZ" = "1" /* Occlusion of Hepatic Vein with Extraluminal Device, Open Approach */
"06L40DZ" = "1" /* Occlusion of Hepatic Vein with Intraluminal Device, Open Approach */
"06L40ZZ" = "1" /* Occlusion of Hepatic Vein, Open Approach */
"06L43CZ" = "1" /* Occlusion of Hepatic Vein with Extraluminal Device, Percutaneous Approach */
"06L43DZ" = "1" /* Occlusion of Hepatic Vein with Intraluminal Device, Percutaneous Approach */
"06L43ZZ" = "1" /* Occlusion of Hepatic Vein, Percutaneous Approach */
"06L44CZ" = "1" /* Occlusion of Hepatic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L44DZ" = "1" /* Occlusion of Hepatic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L44ZZ" = "1" /* Occlusion of Hepatic Vein, Percutaneous Endoscopic Approach */
"06L50CZ" = "1" /* Occlusion of Superior Mesenteric Vein with Extraluminal Device, Open Approach */
"06L50DZ" = "1" /* Occlusion of Superior Mesenteric Vein with Intraluminal Device, Open Approach */
"06L50ZZ" = "1" /* Occlusion of Superior Mesenteric Vein, Open Approach */
"06L53CZ" = "1" /* Occlusion of Superior Mesenteric Vein with Extraluminal Device, Percutaneous Approach */
"06L53DZ" = "1" /* Occlusion of Superior Mesenteric Vein with Intraluminal Device, Percutaneous Approach */
"06L53ZZ" = "1" /* Occlusion of Superior Mesenteric Vein, Percutaneous Approach */
"06L54CZ" = "1" /* Occlusion of Superior Mesenteric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L54DZ" = "1" /* Occlusion of Superior Mesenteric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L54ZZ" = "1" /* Occlusion of Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06L60CZ" = "1" /* Occlusion of Inferior Mesenteric Vein with Extraluminal Device, Open Approach */
"06L60DZ" = "1" /* Occlusion of Inferior Mesenteric Vein with Intraluminal Device, Open Approach */
"06L60ZZ" = "1" /* Occlusion of Inferior Mesenteric Vein, Open Approach */
"06L63CZ" = "1" /* Occlusion of Inferior Mesenteric Vein with Extraluminal Device, Percutaneous Approach */
"06L63DZ" = "1" /* Occlusion of Inferior Mesenteric Vein with Intraluminal Device, Percutaneous Approach */
"06L63ZZ" = "1" /* Occlusion of Inferior Mesenteric Vein, Percutaneous Approach */
"06L64CZ" = "1" /* Occlusion of Inferior Mesenteric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L64DZ" = "1" /* Occlusion of Inferior Mesenteric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L64ZZ" = "1" /* Occlusion of Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06L70CZ" = "1" /* Occlusion of Colic Vein with Extraluminal Device, Open Approach */
"06L70DZ" = "1" /* Occlusion of Colic Vein with Intraluminal Device, Open Approach */
"06L70ZZ" = "1" /* Occlusion of Colic Vein, Open Approach */
"06L73CZ" = "1" /* Occlusion of Colic Vein with Extraluminal Device, Percutaneous Approach */
"06L73DZ" = "1" /* Occlusion of Colic Vein with Intraluminal Device, Percutaneous Approach */
"06L73ZZ" = "1" /* Occlusion of Colic Vein, Percutaneous Approach */
"06L74CZ" = "1" /* Occlusion of Colic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L74DZ" = "1" /* Occlusion of Colic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L74ZZ" = "1" /* Occlusion of Colic Vein, Percutaneous Endoscopic Approach */
"06L80CZ" = "1" /* Occlusion of Portal Vein with Extraluminal Device, Open Approach */
"06L80DZ" = "1" /* Occlusion of Portal Vein with Intraluminal Device, Open Approach */
"06L80ZZ" = "1" /* Occlusion of Portal Vein, Open Approach */
"06L83CZ" = "1" /* Occlusion of Portal Vein with Extraluminal Device, Percutaneous Approach */
"06L83DZ" = "1" /* Occlusion of Portal Vein with Intraluminal Device, Percutaneous Approach */
"06L83ZZ" = "1" /* Occlusion of Portal Vein, Percutaneous Approach */
"06L84CZ" = "1" /* Occlusion of Portal Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L84DZ" = "1" /* Occlusion of Portal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L84ZZ" = "1" /* Occlusion of Portal Vein, Percutaneous Endoscopic Approach */
"06L90CZ" = "1" /* Occlusion of Right Renal Vein with Extraluminal Device, Open Approach */
"06L90DZ" = "1" /* Occlusion of Right Renal Vein with Intraluminal Device, Open Approach */
"06L90ZZ" = "1" /* Occlusion of Right Renal Vein, Open Approach */
"06L93CZ" = "1" /* Occlusion of Right Renal Vein with Extraluminal Device, Percutaneous Approach */
"06L93DZ" = "1" /* Occlusion of Right Renal Vein with Intraluminal Device, Percutaneous Approach */
"06L93ZZ" = "1" /* Occlusion of Right Renal Vein, Percutaneous Approach */
"06L94CZ" = "1" /* Occlusion of Right Renal Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06L94DZ" = "1" /* Occlusion of Right Renal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06L94ZZ" = "1" /* Occlusion of Right Renal Vein, Percutaneous Endoscopic Approach */
"06LB0CZ" = "1" /* Occlusion of Left Renal Vein with Extraluminal Device, Open Approach */
"06LB0DZ" = "1" /* Occlusion of Left Renal Vein with Intraluminal Device, Open Approach */
"06LB0ZZ" = "1" /* Occlusion of Left Renal Vein, Open Approach */
"06LB3CZ" = "1" /* Occlusion of Left Renal Vein with Extraluminal Device, Percutaneous Approach */
"06LB3DZ" = "1" /* Occlusion of Left Renal Vein with Intraluminal Device, Percutaneous Approach */
"06LB3ZZ" = "1" /* Occlusion of Left Renal Vein, Percutaneous Approach */
"06LB4CZ" = "1" /* Occlusion of Left Renal Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LB4DZ" = "1" /* Occlusion of Left Renal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LB4ZZ" = "1" /* Occlusion of Left Renal Vein, Percutaneous Endoscopic Approach */
"06LC0CZ" = "1" /* Occlusion of Right Common Iliac Vein with Extraluminal Device, Open Approach */
"06LC0DZ" = "1" /* Occlusion of Right Common Iliac Vein with Intraluminal Device, Open Approach */
"06LC0ZZ" = "1" /* Occlusion of Right Common Iliac Vein, Open Approach */
"06LC3CZ" = "1" /* Occlusion of Right Common Iliac Vein with Extraluminal Device, Percutaneous Approach */
"06LC3DZ" = "1" /* Occlusion of Right Common Iliac Vein with Intraluminal Device, Percutaneous Approach */
"06LC3ZZ" = "1" /* Occlusion of Right Common Iliac Vein, Percutaneous Approach */
"06LC4CZ" = "1" /* Occlusion of Right Common Iliac Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LC4DZ" = "1" /* Occlusion of Right Common Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LC4ZZ" = "1" /* Occlusion of Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"06LD0CZ" = "1" /* Occlusion of Left Common Iliac Vein with Extraluminal Device, Open Approach */
"06LD0DZ" = "1" /* Occlusion of Left Common Iliac Vein with Intraluminal Device, Open Approach */
"06LD0ZZ" = "1" /* Occlusion of Left Common Iliac Vein, Open Approach */
"06LD3CZ" = "1" /* Occlusion of Left Common Iliac Vein with Extraluminal Device, Percutaneous Approach */
"06LD3DZ" = "1" /* Occlusion of Left Common Iliac Vein with Intraluminal Device, Percutaneous Approach */
"06LD3ZZ" = "1" /* Occlusion of Left Common Iliac Vein, Percutaneous Approach */
"06LD4CZ" = "1" /* Occlusion of Left Common Iliac Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LD4DZ" = "1" /* Occlusion of Left Common Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LD4ZZ" = "1" /* Occlusion of Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"06LF0CZ" = "1" /* Occlusion of Right External Iliac Vein with Extraluminal Device, Open Approach */
"06LF0DZ" = "1" /* Occlusion of Right External Iliac Vein with Intraluminal Device, Open Approach */
"06LF0ZZ" = "1" /* Occlusion of Right External Iliac Vein, Open Approach */
"06LF3CZ" = "1" /* Occlusion of Right External Iliac Vein with Extraluminal Device, Percutaneous Approach */
"06LF3DZ" = "1" /* Occlusion of Right External Iliac Vein with Intraluminal Device, Percutaneous Approach */
"06LF3ZZ" = "1" /* Occlusion of Right External Iliac Vein, Percutaneous Approach */
"06LF4CZ" = "1" /* Occlusion of Right External Iliac Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LF4DZ" = "1" /* Occlusion of Right External Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LF4ZZ" = "1" /* Occlusion of Right External Iliac Vein, Percutaneous Endoscopic Approach */
"06LG0CZ" = "1" /* Occlusion of Left External Iliac Vein with Extraluminal Device, Open Approach */
"06LG0DZ" = "1" /* Occlusion of Left External Iliac Vein with Intraluminal Device, Open Approach */
"06LG0ZZ" = "1" /* Occlusion of Left External Iliac Vein, Open Approach */
"06LG3CZ" = "1" /* Occlusion of Left External Iliac Vein with Extraluminal Device, Percutaneous Approach */
"06LG3DZ" = "1" /* Occlusion of Left External Iliac Vein with Intraluminal Device, Percutaneous Approach */
"06LG3ZZ" = "1" /* Occlusion of Left External Iliac Vein, Percutaneous Approach */
"06LG4CZ" = "1" /* Occlusion of Left External Iliac Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LG4DZ" = "1" /* Occlusion of Left External Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LG4ZZ" = "1" /* Occlusion of Left External Iliac Vein, Percutaneous Endoscopic Approach */
"06LH0CZ" = "1" /* Occlusion of Right Hypogastric Vein with Extraluminal Device, Open Approach */
"06LH0DZ" = "1" /* Occlusion of Right Hypogastric Vein with Intraluminal Device, Open Approach */
"06LH0ZZ" = "1" /* Occlusion of Right Hypogastric Vein, Open Approach */
"06LH3CZ" = "1" /* Occlusion of Right Hypogastric Vein with Extraluminal Device, Percutaneous Approach */
"06LH3DZ" = "1" /* Occlusion of Right Hypogastric Vein with Intraluminal Device, Percutaneous Approach */
"06LH3ZZ" = "1" /* Occlusion of Right Hypogastric Vein, Percutaneous Approach */
"06LH4CZ" = "1" /* Occlusion of Right Hypogastric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LH4DZ" = "1" /* Occlusion of Right Hypogastric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LH4ZZ" = "1" /* Occlusion of Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"06LJ0CZ" = "1" /* Occlusion of Left Hypogastric Vein with Extraluminal Device, Open Approach */
"06LJ0DZ" = "1" /* Occlusion of Left Hypogastric Vein with Intraluminal Device, Open Approach */
"06LJ0ZZ" = "1" /* Occlusion of Left Hypogastric Vein, Open Approach */
"06LJ3CZ" = "1" /* Occlusion of Left Hypogastric Vein with Extraluminal Device, Percutaneous Approach */
"06LJ3DZ" = "1" /* Occlusion of Left Hypogastric Vein with Intraluminal Device, Percutaneous Approach */
"06LJ3ZZ" = "1" /* Occlusion of Left Hypogastric Vein, Percutaneous Approach */
"06LJ4CZ" = "1" /* Occlusion of Left Hypogastric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LJ4DZ" = "1" /* Occlusion of Left Hypogastric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LJ4ZZ" = "1" /* Occlusion of Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"06LM0CZ" = "1" /* Occlusion of Right Femoral Vein with Extraluminal Device, Open Approach */
"06LM0DZ" = "1" /* Occlusion of Right Femoral Vein with Intraluminal Device, Open Approach */
"06LM0ZZ" = "1" /* Occlusion of Right Femoral Vein, Open Approach */
"06LM3CZ" = "1" /* Occlusion of Right Femoral Vein with Extraluminal Device, Percutaneous Approach */
"06LM3DZ" = "1" /* Occlusion of Right Femoral Vein with Intraluminal Device, Percutaneous Approach */
"06LM3ZZ" = "1" /* Occlusion of Right Femoral Vein, Percutaneous Approach */
"06LM4CZ" = "1" /* Occlusion of Right Femoral Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LM4DZ" = "1" /* Occlusion of Right Femoral Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LM4ZZ" = "1" /* Occlusion of Right Femoral Vein, Percutaneous Endoscopic Approach */
"06LN0CZ" = "1" /* Occlusion of Left Femoral Vein with Extraluminal Device, Open Approach */
"06LN0DZ" = "1" /* Occlusion of Left Femoral Vein with Intraluminal Device, Open Approach */
"06LN0ZZ" = "1" /* Occlusion of Left Femoral Vein, Open Approach */
"06LN3CZ" = "1" /* Occlusion of Left Femoral Vein with Extraluminal Device, Percutaneous Approach */
"06LN3DZ" = "1" /* Occlusion of Left Femoral Vein with Intraluminal Device, Percutaneous Approach */
"06LN3ZZ" = "1" /* Occlusion of Left Femoral Vein, Percutaneous Approach */
"06LN4CZ" = "1" /* Occlusion of Left Femoral Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LN4DZ" = "1" /* Occlusion of Left Femoral Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LN4ZZ" = "1" /* Occlusion of Left Femoral Vein, Percutaneous Endoscopic Approach */
"06LP0CZ" = "1" /* Occlusion of Right Greater Saphenous Vein with Extraluminal Device, Open Approach */
"06LP0DZ" = "1" /* Occlusion of Right Greater Saphenous Vein with Intraluminal Device, Open Approach */
"06LP0ZZ" = "1" /* Occlusion of Right Greater Saphenous Vein, Open Approach */
"06LP3CZ" = "1" /* Occlusion of Right Greater Saphenous Vein with Extraluminal Device, Percutaneous Approach */
"06LP3DZ" = "1" /* Occlusion of Right Greater Saphenous Vein with Intraluminal Device, Percutaneous Approach */
"06LP3ZZ" = "1" /* Occlusion of Right Greater Saphenous Vein, Percutaneous Approach */
"06LP4CZ" = "1" /* Occlusion of Right Greater Saphenous Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LP4DZ" = "1" /* Occlusion of Right Greater Saphenous Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LP4ZZ" = "1" /* Occlusion of Right Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"06LQ0CZ" = "1" /* Occlusion of Left Greater Saphenous Vein with Extraluminal Device, Open Approach */
"06LQ0DZ" = "1" /* Occlusion of Left Greater Saphenous Vein with Intraluminal Device, Open Approach */
"06LQ0ZZ" = "1" /* Occlusion of Left Greater Saphenous Vein, Open Approach */
"06LQ3CZ" = "1" /* Occlusion of Left Greater Saphenous Vein with Extraluminal Device, Percutaneous Approach */
"06LQ3DZ" = "1" /* Occlusion of Left Greater Saphenous Vein with Intraluminal Device, Percutaneous Approach */
"06LQ3ZZ" = "1" /* Occlusion of Left Greater Saphenous Vein, Percutaneous Approach */
"06LQ4CZ" = "1" /* Occlusion of Left Greater Saphenous Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LQ4DZ" = "1" /* Occlusion of Left Greater Saphenous Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LQ4ZZ" = "1" /* Occlusion of Left Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"06LR0CZ" = "1" /* Occlusion of Right Lesser Saphenous Vein with Extraluminal Device, Open Approach */
"06LR0DZ" = "1" /* Occlusion of Right Lesser Saphenous Vein with Intraluminal Device, Open Approach */
"06LR0ZZ" = "1" /* Occlusion of Right Lesser Saphenous Vein, Open Approach */
"06LR3CZ" = "1" /* Occlusion of Right Lesser Saphenous Vein with Extraluminal Device, Percutaneous Approach */
"06LR3DZ" = "1" /* Occlusion of Right Lesser Saphenous Vein with Intraluminal Device, Percutaneous Approach */
"06LR3ZZ" = "1" /* Occlusion of Right Lesser Saphenous Vein, Percutaneous Approach */
"06LR4CZ" = "1" /* Occlusion of Right Lesser Saphenous Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LR4DZ" = "1" /* Occlusion of Right Lesser Saphenous Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LR4ZZ" = "1" /* Occlusion of Right Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"06LS0CZ" = "1" /* Occlusion of Left Lesser Saphenous Vein with Extraluminal Device, Open Approach */
"06LS0DZ" = "1" /* Occlusion of Left Lesser Saphenous Vein with Intraluminal Device, Open Approach */
"06LS0ZZ" = "1" /* Occlusion of Left Lesser Saphenous Vein, Open Approach */
"06LS3CZ" = "1" /* Occlusion of Left Lesser Saphenous Vein with Extraluminal Device, Percutaneous Approach */
"06LS3DZ" = "1" /* Occlusion of Left Lesser Saphenous Vein with Intraluminal Device, Percutaneous Approach */
"06LS3ZZ" = "1" /* Occlusion of Left Lesser Saphenous Vein, Percutaneous Approach */
"06LS4CZ" = "1" /* Occlusion of Left Lesser Saphenous Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LS4DZ" = "1" /* Occlusion of Left Lesser Saphenous Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LS4ZZ" = "1" /* Occlusion of Left Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"06LT0CZ" = "1" /* Occlusion of Right Foot Vein with Extraluminal Device, Open Approach */
"06LT0DZ" = "1" /* Occlusion of Right Foot Vein with Intraluminal Device, Open Approach */
"06LT0ZZ" = "1" /* Occlusion of Right Foot Vein, Open Approach */
"06LT3CZ" = "1" /* Occlusion of Right Foot Vein with Extraluminal Device, Percutaneous Approach */
"06LT3DZ" = "1" /* Occlusion of Right Foot Vein with Intraluminal Device, Percutaneous Approach */
"06LT3ZZ" = "1" /* Occlusion of Right Foot Vein, Percutaneous Approach */
"06LT4CZ" = "1" /* Occlusion of Right Foot Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LT4DZ" = "1" /* Occlusion of Right Foot Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LT4ZZ" = "1" /* Occlusion of Right Foot Vein, Percutaneous Endoscopic Approach */
"06LV0CZ" = "1" /* Occlusion of Left Foot Vein with Extraluminal Device, Open Approach */
"06LV0DZ" = "1" /* Occlusion of Left Foot Vein with Intraluminal Device, Open Approach */
"06LV0ZZ" = "1" /* Occlusion of Left Foot Vein, Open Approach */
"06LV3CZ" = "1" /* Occlusion of Left Foot Vein with Extraluminal Device, Percutaneous Approach */
"06LV3DZ" = "1" /* Occlusion of Left Foot Vein with Intraluminal Device, Percutaneous Approach */
"06LV3ZZ" = "1" /* Occlusion of Left Foot Vein, Percutaneous Approach */
"06LV4CZ" = "1" /* Occlusion of Left Foot Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LV4DZ" = "1" /* Occlusion of Left Foot Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LV4ZZ" = "1" /* Occlusion of Left Foot Vein, Percutaneous Endoscopic Approach */
"06LY0CC" = "1" /* Occlusion of Hemorrhoidal Plexus with Extraluminal Device, Open Approach */
"06LY0CZ" = "1" /* Occlusion of Lower Vein with Extraluminal Device, Open Approach */
"06LY0DC" = "1" /* Occlusion of Hemorrhoidal Plexus with Intraluminal Device, Open Approach */
"06LY0DZ" = "1" /* Occlusion of Lower Vein with Intraluminal Device, Open Approach */
"06LY0ZC" = "1" /* Occlusion of Hemorrhoidal Plexus, Open Approach */
"06LY0ZZ" = "1" /* Occlusion of Lower Vein, Open Approach */
"06LY3CC" = "1" /* Occlusion of Hemorrhoidal Plexus with Extraluminal Device, Percutaneous Approach */
"06LY3CZ" = "1" /* Occlusion of Lower Vein with Extraluminal Device, Percutaneous Approach */
"06LY3DC" = "1" /* Occlusion of Hemorrhoidal Plexus with Intraluminal Device, Percutaneous Approach */
"06LY3DZ" = "1" /* Occlusion of Lower Vein with Intraluminal Device, Percutaneous Approach */
"06LY3ZC" = "1" /* Occlusion of Hemorrhoidal Plexus, Percutaneous Approach */
"06LY3ZZ" = "1" /* Occlusion of Lower Vein, Percutaneous Approach */
"06LY4CC" = "1" /* Occlusion of Hemorrhoidal Plexus with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LY4CZ" = "1" /* Occlusion of Lower Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06LY4DC" = "1" /* Occlusion of Hemorrhoidal Plexus with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LY4DZ" = "1" /* Occlusion of Lower Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06LY4ZC" = "1" /* Occlusion of Hemorrhoidal Plexus, Percutaneous Endoscopic Approach */
"06LY4ZZ" = "1" /* Occlusion of Lower Vein, Percutaneous Endoscopic Approach */
"06N00ZZ" = "1" /* Release Inferior Vena Cava, Open Approach */
"06N03ZZ" = "1" /* Release Inferior Vena Cava, Percutaneous Approach */
"06N04ZZ" = "1" /* Release Inferior Vena Cava, Percutaneous Endoscopic Approach */
"06N10ZZ" = "1" /* Release Splenic Vein, Open Approach */
"06N13ZZ" = "1" /* Release Splenic Vein, Percutaneous Approach */
"06N14ZZ" = "1" /* Release Splenic Vein, Percutaneous Endoscopic Approach */
"06N20ZZ" = "1" /* Release Gastric Vein, Open Approach */
"06N23ZZ" = "1" /* Release Gastric Vein, Percutaneous Approach */
"06N24ZZ" = "1" /* Release Gastric Vein, Percutaneous Endoscopic Approach */
"06N30ZZ" = "1" /* Release Esophageal Vein, Open Approach */
"06N33ZZ" = "1" /* Release Esophageal Vein, Percutaneous Approach */
"06N34ZZ" = "1" /* Release Esophageal Vein, Percutaneous Endoscopic Approach */
"06N40ZZ" = "1" /* Release Hepatic Vein, Open Approach */
"06N43ZZ" = "1" /* Release Hepatic Vein, Percutaneous Approach */
"06N44ZZ" = "1" /* Release Hepatic Vein, Percutaneous Endoscopic Approach */
"06N50ZZ" = "1" /* Release Superior Mesenteric Vein, Open Approach */
"06N53ZZ" = "1" /* Release Superior Mesenteric Vein, Percutaneous Approach */
"06N54ZZ" = "1" /* Release Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06N60ZZ" = "1" /* Release Inferior Mesenteric Vein, Open Approach */
"06N63ZZ" = "1" /* Release Inferior Mesenteric Vein, Percutaneous Approach */
"06N64ZZ" = "1" /* Release Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06N70ZZ" = "1" /* Release Colic Vein, Open Approach */
"06N73ZZ" = "1" /* Release Colic Vein, Percutaneous Approach */
"06N74ZZ" = "1" /* Release Colic Vein, Percutaneous Endoscopic Approach */
"06N80ZZ" = "1" /* Release Portal Vein, Open Approach */
"06N83ZZ" = "1" /* Release Portal Vein, Percutaneous Approach */
"06N84ZZ" = "1" /* Release Portal Vein, Percutaneous Endoscopic Approach */
"06N90ZZ" = "1" /* Release Right Renal Vein, Open Approach */
"06N93ZZ" = "1" /* Release Right Renal Vein, Percutaneous Approach */
"06N94ZZ" = "1" /* Release Right Renal Vein, Percutaneous Endoscopic Approach */
"06NB0ZZ" = "1" /* Release Left Renal Vein, Open Approach */
"06NB3ZZ" = "1" /* Release Left Renal Vein, Percutaneous Approach */
"06NB4ZZ" = "1" /* Release Left Renal Vein, Percutaneous Endoscopic Approach */
"06NC0ZZ" = "1" /* Release Right Common Iliac Vein, Open Approach */
"06NC3ZZ" = "1" /* Release Right Common Iliac Vein, Percutaneous Approach */
"06NC4ZZ" = "1" /* Release Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"06ND0ZZ" = "1" /* Release Left Common Iliac Vein, Open Approach */
"06ND3ZZ" = "1" /* Release Left Common Iliac Vein, Percutaneous Approach */
"06ND4ZZ" = "1" /* Release Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"06NF0ZZ" = "1" /* Release Right External Iliac Vein, Open Approach */
"06NF3ZZ" = "1" /* Release Right External Iliac Vein, Percutaneous Approach */
"06NF4ZZ" = "1" /* Release Right External Iliac Vein, Percutaneous Endoscopic Approach */
"06NG0ZZ" = "1" /* Release Left External Iliac Vein, Open Approach */
"06NG3ZZ" = "1" /* Release Left External Iliac Vein, Percutaneous Approach */
"06NG4ZZ" = "1" /* Release Left External Iliac Vein, Percutaneous Endoscopic Approach */
"06NH0ZZ" = "1" /* Release Right Hypogastric Vein, Open Approach */
"06NH3ZZ" = "1" /* Release Right Hypogastric Vein, Percutaneous Approach */
"06NH4ZZ" = "1" /* Release Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"06NJ0ZZ" = "1" /* Release Left Hypogastric Vein, Open Approach */
"06NJ3ZZ" = "1" /* Release Left Hypogastric Vein, Percutaneous Approach */
"06NJ4ZZ" = "1" /* Release Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"06NM0ZZ" = "1" /* Release Right Femoral Vein, Open Approach */
"06NM3ZZ" = "1" /* Release Right Femoral Vein, Percutaneous Approach */
"06NM4ZZ" = "1" /* Release Right Femoral Vein, Percutaneous Endoscopic Approach */
"06NN0ZZ" = "1" /* Release Left Femoral Vein, Open Approach */
"06NN3ZZ" = "1" /* Release Left Femoral Vein, Percutaneous Approach */
"06NN4ZZ" = "1" /* Release Left Femoral Vein, Percutaneous Endoscopic Approach */
"06NP0ZZ" = "1" /* Release Right Greater Saphenous Vein, Open Approach */
"06NP3ZZ" = "1" /* Release Right Greater Saphenous Vein, Percutaneous Approach */
"06NP4ZZ" = "1" /* Release Right Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"06NQ0ZZ" = "1" /* Release Left Greater Saphenous Vein, Open Approach */
"06NQ3ZZ" = "1" /* Release Left Greater Saphenous Vein, Percutaneous Approach */
"06NQ4ZZ" = "1" /* Release Left Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"06NR0ZZ" = "1" /* Release Right Lesser Saphenous Vein, Open Approach */
"06NR3ZZ" = "1" /* Release Right Lesser Saphenous Vein, Percutaneous Approach */
"06NR4ZZ" = "1" /* Release Right Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"06NS0ZZ" = "1" /* Release Left Lesser Saphenous Vein, Open Approach */
"06NS3ZZ" = "1" /* Release Left Lesser Saphenous Vein, Percutaneous Approach */
"06NS4ZZ" = "1" /* Release Left Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"06NT0ZZ" = "1" /* Release Right Foot Vein, Open Approach */
"06NT3ZZ" = "1" /* Release Right Foot Vein, Percutaneous Approach */
"06NT4ZZ" = "1" /* Release Right Foot Vein, Percutaneous Endoscopic Approach */
"06NV0ZZ" = "1" /* Release Left Foot Vein, Open Approach */
"06NV3ZZ" = "1" /* Release Left Foot Vein, Percutaneous Approach */
"06NV4ZZ" = "1" /* Release Left Foot Vein, Percutaneous Endoscopic Approach */
"06NY0ZZ" = "1" /* Release Lower Vein, Open Approach */
"06NY3ZZ" = "1" /* Release Lower Vein, Percutaneous Approach */
"06NY4ZZ" = "1" /* Release Lower Vein, Percutaneous Endoscopic Approach */
"06PY00Z" = "1" /* Removal of Drainage Device from Lower Vein, Open Approach */
"06PY02Z" = "1" /* Removal of Monitoring Device from Lower Vein, Open Approach */
"06PY03Z" = "1" /* Removal of Infusion Device from Lower Vein, Open Approach */
"06PY07Z" = "1" /* Removal of Autologous Tissue Substitute from Lower Vein, Open Approach */
"06PY0CZ" = "1" /* Removal of Extraluminal Device from Lower Vein, Open Approach */
"06PY0DZ" = "1" /* Removal of Intraluminal Device from Lower Vein, Open Approach */
"06PY0JZ" = "1" /* Removal of Synthetic Substitute from Lower Vein, Open Approach */
"06PY0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lower Vein, Open Approach */
"06PY37Z" = "1" /* Removal of Autologous Tissue Substitute from Lower Vein, Percutaneous Approach */
"06PY3CZ" = "1" /* Removal of Extraluminal Device from Lower Vein, Percutaneous Approach */
"06PY3JZ" = "1" /* Removal of Synthetic Substitute from Lower Vein, Percutaneous Approach */
"06PY3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lower Vein, Percutaneous Approach */
"06PY40Z" = "1" /* Removal of Drainage Device from Lower Vein, Percutaneous Endoscopic Approach */
"06PY42Z" = "1" /* Removal of Monitoring Device from Lower Vein, Percutaneous Endoscopic Approach */
"06PY43Z" = "1" /* Removal of Infusion Device from Lower Vein, Percutaneous Endoscopic Approach */
"06PY47Z" = "1" /* Removal of Autologous Tissue Substitute from Lower Vein, Percutaneous Endoscopic Approach */
"06PY4CZ" = "1" /* Removal of Extraluminal Device from Lower Vein, Percutaneous Endoscopic Approach */
"06PY4DZ" = "1" /* Removal of Intraluminal Device from Lower Vein, Percutaneous Endoscopic Approach */
"06PY4JZ" = "1" /* Removal of Synthetic Substitute from Lower Vein, Percutaneous Endoscopic Approach */
"06PY4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lower Vein, Percutaneous Endoscopic Approach */
"06Q00ZZ" = "1" /* Repair Inferior Vena Cava, Open Approach */
"06Q03ZZ" = "1" /* Repair Inferior Vena Cava, Percutaneous Approach */
"06Q04ZZ" = "1" /* Repair Inferior Vena Cava, Percutaneous Endoscopic Approach */
"06Q10ZZ" = "1" /* Repair Splenic Vein, Open Approach */
"06Q13ZZ" = "1" /* Repair Splenic Vein, Percutaneous Approach */
"06Q14ZZ" = "1" /* Repair Splenic Vein, Percutaneous Endoscopic Approach */
"06Q20ZZ" = "1" /* Repair Gastric Vein, Open Approach */
"06Q23ZZ" = "1" /* Repair Gastric Vein, Percutaneous Approach */
"06Q24ZZ" = "1" /* Repair Gastric Vein, Percutaneous Endoscopic Approach */
"06Q30ZZ" = "1" /* Repair Esophageal Vein, Open Approach */
"06Q33ZZ" = "1" /* Repair Esophageal Vein, Percutaneous Approach */
"06Q34ZZ" = "1" /* Repair Esophageal Vein, Percutaneous Endoscopic Approach */
"06Q40ZZ" = "1" /* Repair Hepatic Vein, Open Approach */
"06Q43ZZ" = "1" /* Repair Hepatic Vein, Percutaneous Approach */
"06Q44ZZ" = "1" /* Repair Hepatic Vein, Percutaneous Endoscopic Approach */
"06Q50ZZ" = "1" /* Repair Superior Mesenteric Vein, Open Approach */
"06Q53ZZ" = "1" /* Repair Superior Mesenteric Vein, Percutaneous Approach */
"06Q54ZZ" = "1" /* Repair Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06Q60ZZ" = "1" /* Repair Inferior Mesenteric Vein, Open Approach */
"06Q63ZZ" = "1" /* Repair Inferior Mesenteric Vein, Percutaneous Approach */
"06Q64ZZ" = "1" /* Repair Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06Q70ZZ" = "1" /* Repair Colic Vein, Open Approach */
"06Q73ZZ" = "1" /* Repair Colic Vein, Percutaneous Approach */
"06Q74ZZ" = "1" /* Repair Colic Vein, Percutaneous Endoscopic Approach */
"06Q80ZZ" = "1" /* Repair Portal Vein, Open Approach */
"06Q83ZZ" = "1" /* Repair Portal Vein, Percutaneous Approach */
"06Q84ZZ" = "1" /* Repair Portal Vein, Percutaneous Endoscopic Approach */
"06Q90ZZ" = "1" /* Repair Right Renal Vein, Open Approach */
"06Q93ZZ" = "1" /* Repair Right Renal Vein, Percutaneous Approach */
"06Q94ZZ" = "1" /* Repair Right Renal Vein, Percutaneous Endoscopic Approach */
"06QB0ZZ" = "1" /* Repair Left Renal Vein, Open Approach */
"06QB3ZZ" = "1" /* Repair Left Renal Vein, Percutaneous Approach */
"06QB4ZZ" = "1" /* Repair Left Renal Vein, Percutaneous Endoscopic Approach */
"06QC0ZZ" = "1" /* Repair Right Common Iliac Vein, Open Approach */
"06QC3ZZ" = "1" /* Repair Right Common Iliac Vein, Percutaneous Approach */
"06QC4ZZ" = "1" /* Repair Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"06QD0ZZ" = "1" /* Repair Left Common Iliac Vein, Open Approach */
"06QD3ZZ" = "1" /* Repair Left Common Iliac Vein, Percutaneous Approach */
"06QD4ZZ" = "1" /* Repair Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"06QF0ZZ" = "1" /* Repair Right External Iliac Vein, Open Approach */
"06QF3ZZ" = "1" /* Repair Right External Iliac Vein, Percutaneous Approach */
"06QF4ZZ" = "1" /* Repair Right External Iliac Vein, Percutaneous Endoscopic Approach */
"06QG0ZZ" = "1" /* Repair Left External Iliac Vein, Open Approach */
"06QG3ZZ" = "1" /* Repair Left External Iliac Vein, Percutaneous Approach */
"06QG4ZZ" = "1" /* Repair Left External Iliac Vein, Percutaneous Endoscopic Approach */
"06QH0ZZ" = "1" /* Repair Right Hypogastric Vein, Open Approach */
"06QH3ZZ" = "1" /* Repair Right Hypogastric Vein, Percutaneous Approach */
"06QH4ZZ" = "1" /* Repair Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"06QJ0ZZ" = "1" /* Repair Left Hypogastric Vein, Open Approach */
"06QJ3ZZ" = "1" /* Repair Left Hypogastric Vein, Percutaneous Approach */
"06QJ4ZZ" = "1" /* Repair Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"06QM0ZZ" = "1" /* Repair Right Femoral Vein, Open Approach */
"06QM3ZZ" = "1" /* Repair Right Femoral Vein, Percutaneous Approach */
"06QM4ZZ" = "1" /* Repair Right Femoral Vein, Percutaneous Endoscopic Approach */
"06QN0ZZ" = "1" /* Repair Left Femoral Vein, Open Approach */
"06QN3ZZ" = "1" /* Repair Left Femoral Vein, Percutaneous Approach */
"06QN4ZZ" = "1" /* Repair Left Femoral Vein, Percutaneous Endoscopic Approach */
"06QP0ZZ" = "1" /* Repair Right Greater Saphenous Vein, Open Approach */
"06QP3ZZ" = "1" /* Repair Right Greater Saphenous Vein, Percutaneous Approach */
"06QP4ZZ" = "1" /* Repair Right Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"06QQ0ZZ" = "1" /* Repair Left Greater Saphenous Vein, Open Approach */
"06QQ3ZZ" = "1" /* Repair Left Greater Saphenous Vein, Percutaneous Approach */
"06QQ4ZZ" = "1" /* Repair Left Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"06QR0ZZ" = "1" /* Repair Right Lesser Saphenous Vein, Open Approach */
"06QR3ZZ" = "1" /* Repair Right Lesser Saphenous Vein, Percutaneous Approach */
"06QR4ZZ" = "1" /* Repair Right Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"06QS0ZZ" = "1" /* Repair Left Lesser Saphenous Vein, Open Approach */
"06QS3ZZ" = "1" /* Repair Left Lesser Saphenous Vein, Percutaneous Approach */
"06QS4ZZ" = "1" /* Repair Left Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"06QT0ZZ" = "1" /* Repair Right Foot Vein, Open Approach */
"06QT3ZZ" = "1" /* Repair Right Foot Vein, Percutaneous Approach */
"06QT4ZZ" = "1" /* Repair Right Foot Vein, Percutaneous Endoscopic Approach */
"06QV0ZZ" = "1" /* Repair Left Foot Vein, Open Approach */
"06QV3ZZ" = "1" /* Repair Left Foot Vein, Percutaneous Approach */
"06QV4ZZ" = "1" /* Repair Left Foot Vein, Percutaneous Endoscopic Approach */
"06QY0ZZ" = "1" /* Repair Lower Vein, Open Approach */
"06QY3ZZ" = "1" /* Repair Lower Vein, Percutaneous Approach */
"06QY4ZZ" = "1" /* Repair Lower Vein, Percutaneous Endoscopic Approach */
"06R007Z" = "1" /* Replacement of Inferior Vena Cava with Autologous Tissue Substitute, Open Approach */
"06R00JZ" = "1" /* Replacement of Inferior Vena Cava with Synthetic Substitute, Open Approach */
"06R00KZ" = "1" /* Replacement of Inferior Vena Cava with Nonautologous Tissue Substitute, Open Approach */
"06R047Z" = "1" /* Replacement of Inferior Vena Cava with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R04JZ" = "1" /* Replacement of Inferior Vena Cava with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06R04KZ" = "1" /* Replacement of Inferior Vena Cava with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R107Z" = "1" /* Replacement of Splenic Vein with Autologous Tissue Substitute, Open Approach */
"06R10JZ" = "1" /* Replacement of Splenic Vein with Synthetic Substitute, Open Approach */
"06R10KZ" = "1" /* Replacement of Splenic Vein with Nonautologous Tissue Substitute, Open Approach */
"06R147Z" = "1" /* Replacement of Splenic Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R14JZ" = "1" /* Replacement of Splenic Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06R14KZ" = "1" /* Replacement of Splenic Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R207Z" = "1" /* Replacement of Gastric Vein with Autologous Tissue Substitute, Open Approach */
"06R20JZ" = "1" /* Replacement of Gastric Vein with Synthetic Substitute, Open Approach */
"06R20KZ" = "1" /* Replacement of Gastric Vein with Nonautologous Tissue Substitute, Open Approach */
"06R247Z" = "1" /* Replacement of Gastric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R24JZ" = "1" /* Replacement of Gastric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06R24KZ" = "1" /* Replacement of Gastric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R307Z" = "1" /* Replacement of Esophageal Vein with Autologous Tissue Substitute, Open Approach */
"06R30JZ" = "1" /* Replacement of Esophageal Vein with Synthetic Substitute, Open Approach */
"06R30KZ" = "1" /* Replacement of Esophageal Vein with Nonautologous Tissue Substitute, Open Approach */
"06R347Z" = "1" /* Replacement of Esophageal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R34JZ" = "1" /* Replacement of Esophageal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06R34KZ" = "1" /* Replacement of Esophageal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R407Z" = "1" /* Replacement of Hepatic Vein with Autologous Tissue Substitute, Open Approach */
"06R40JZ" = "1" /* Replacement of Hepatic Vein with Synthetic Substitute, Open Approach */
"06R40KZ" = "1" /* Replacement of Hepatic Vein with Nonautologous Tissue Substitute, Open Approach */
"06R447Z" = "1" /* Replacement of Hepatic Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R44JZ" = "1" /* Replacement of Hepatic Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06R44KZ" = "1" /* Replacement of Hepatic Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R507Z" = "1" /* Replacement of Superior Mesenteric Vein with Autologous Tissue Substitute, Open Approach */
"06R50JZ" = "1" /* Replacement of Superior Mesenteric Vein with Synthetic Substitute, Open Approach */
"06R50KZ" = "1" /* Replacement of Superior Mesenteric Vein with Nonautologous Tissue Substitute, Open Approach */
"06R547Z" = "1" /* Replacement of Superior Mesenteric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R54JZ" = "1" /* Replacement of Superior Mesenteric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06R54KZ" = "1" /* Replacement of Superior Mesenteric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R607Z" = "1" /* Replacement of Inferior Mesenteric Vein with Autologous Tissue Substitute, Open Approach */
"06R60JZ" = "1" /* Replacement of Inferior Mesenteric Vein with Synthetic Substitute, Open Approach */
"06R60KZ" = "1" /* Replacement of Inferior Mesenteric Vein with Nonautologous Tissue Substitute, Open Approach */
"06R647Z" = "1" /* Replacement of Inferior Mesenteric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R64JZ" = "1" /* Replacement of Inferior Mesenteric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06R64KZ" = "1" /* Replacement of Inferior Mesenteric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R707Z" = "1" /* Replacement of Colic Vein with Autologous Tissue Substitute, Open Approach */
"06R70JZ" = "1" /* Replacement of Colic Vein with Synthetic Substitute, Open Approach */
"06R70KZ" = "1" /* Replacement of Colic Vein with Nonautologous Tissue Substitute, Open Approach */
"06R747Z" = "1" /* Replacement of Colic Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R74JZ" = "1" /* Replacement of Colic Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06R74KZ" = "1" /* Replacement of Colic Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R807Z" = "1" /* Replacement of Portal Vein with Autologous Tissue Substitute, Open Approach */
"06R80JZ" = "1" /* Replacement of Portal Vein with Synthetic Substitute, Open Approach */
"06R80KZ" = "1" /* Replacement of Portal Vein with Nonautologous Tissue Substitute, Open Approach */
"06R847Z" = "1" /* Replacement of Portal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R84JZ" = "1" /* Replacement of Portal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06R84KZ" = "1" /* Replacement of Portal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R907Z" = "1" /* Replacement of Right Renal Vein with Autologous Tissue Substitute, Open Approach */
"06R90JZ" = "1" /* Replacement of Right Renal Vein with Synthetic Substitute, Open Approach */
"06R90KZ" = "1" /* Replacement of Right Renal Vein with Nonautologous Tissue Substitute, Open Approach */
"06R947Z" = "1" /* Replacement of Right Renal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06R94JZ" = "1" /* Replacement of Right Renal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06R94KZ" = "1" /* Replacement of Right Renal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RB07Z" = "1" /* Replacement of Left Renal Vein with Autologous Tissue Substitute, Open Approach */
"06RB0JZ" = "1" /* Replacement of Left Renal Vein with Synthetic Substitute, Open Approach */
"06RB0KZ" = "1" /* Replacement of Left Renal Vein with Nonautologous Tissue Substitute, Open Approach */
"06RB47Z" = "1" /* Replacement of Left Renal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RB4JZ" = "1" /* Replacement of Left Renal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06RB4KZ" = "1" /* Replacement of Left Renal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RC07Z" = "1" /* Replacement of Right Common Iliac Vein with Autologous Tissue Substitute, Open Approach */
"06RC0JZ" = "1" /* Replacement of Right Common Iliac Vein with Synthetic Substitute, Open Approach */
"06RC0KZ" = "1" /* Replacement of Right Common Iliac Vein with Nonautologous Tissue Substitute, Open Approach */
"06RC47Z" = "1" /* Replacement of Right Common Iliac Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RC4JZ" = "1" /* Replacement of Right Common Iliac Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06RC4KZ" = "1" /* Replacement of Right Common Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RD07Z" = "1" /* Replacement of Left Common Iliac Vein with Autologous Tissue Substitute, Open Approach */
"06RD0JZ" = "1" /* Replacement of Left Common Iliac Vein with Synthetic Substitute, Open Approach */
"06RD0KZ" = "1" /* Replacement of Left Common Iliac Vein with Nonautologous Tissue Substitute, Open Approach */
"06RD47Z" = "1" /* Replacement of Left Common Iliac Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RD4JZ" = "1" /* Replacement of Left Common Iliac Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06RD4KZ" = "1" /* Replacement of Left Common Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RF07Z" = "1" /* Replacement of Right External Iliac Vein with Autologous Tissue Substitute, Open Approach */
"06RF0JZ" = "1" /* Replacement of Right External Iliac Vein with Synthetic Substitute, Open Approach */
"06RF0KZ" = "1" /* Replacement of Right External Iliac Vein with Nonautologous Tissue Substitute, Open Approach */
"06RF47Z" = "1" /* Replacement of Right External Iliac Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RF4JZ" = "1" /* Replacement of Right External Iliac Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06RF4KZ" = "1" /* Replacement of Right External Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RG07Z" = "1" /* Replacement of Left External Iliac Vein with Autologous Tissue Substitute, Open Approach */
"06RG0JZ" = "1" /* Replacement of Left External Iliac Vein with Synthetic Substitute, Open Approach */
"06RG0KZ" = "1" /* Replacement of Left External Iliac Vein with Nonautologous Tissue Substitute, Open Approach */
"06RG47Z" = "1" /* Replacement of Left External Iliac Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RG4JZ" = "1" /* Replacement of Left External Iliac Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06RG4KZ" = "1" /* Replacement of Left External Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RH07Z" = "1" /* Replacement of Right Hypogastric Vein with Autologous Tissue Substitute, Open Approach */
"06RH0JZ" = "1" /* Replacement of Right Hypogastric Vein with Synthetic Substitute, Open Approach */
"06RH0KZ" = "1" /* Replacement of Right Hypogastric Vein with Nonautologous Tissue Substitute, Open Approach */
"06RH47Z" = "1" /* Replacement of Right Hypogastric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RH4JZ" = "1" /* Replacement of Right Hypogastric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06RH4KZ" = "1" /* Replacement of Right Hypogastric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RJ07Z" = "1" /* Replacement of Left Hypogastric Vein with Autologous Tissue Substitute, Open Approach */
"06RJ0JZ" = "1" /* Replacement of Left Hypogastric Vein with Synthetic Substitute, Open Approach */
"06RJ0KZ" = "1" /* Replacement of Left Hypogastric Vein with Nonautologous Tissue Substitute, Open Approach */
"06RJ47Z" = "1" /* Replacement of Left Hypogastric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RJ4JZ" = "1" /* Replacement of Left Hypogastric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06RJ4KZ" = "1" /* Replacement of Left Hypogastric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RM07Z" = "1" /* Replacement of Right Femoral Vein with Autologous Tissue Substitute, Open Approach */
"06RM0JZ" = "1" /* Replacement of Right Femoral Vein with Synthetic Substitute, Open Approach */
"06RM0KZ" = "1" /* Replacement of Right Femoral Vein with Nonautologous Tissue Substitute, Open Approach */
"06RM47Z" = "1" /* Replacement of Right Femoral Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RM4JZ" = "1" /* Replacement of Right Femoral Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06RM4KZ" = "1" /* Replacement of Right Femoral Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RN07Z" = "1" /* Replacement of Left Femoral Vein with Autologous Tissue Substitute, Open Approach */
"06RN0JZ" = "1" /* Replacement of Left Femoral Vein with Synthetic Substitute, Open Approach */
"06RN0KZ" = "1" /* Replacement of Left Femoral Vein with Nonautologous Tissue Substitute, Open Approach */
"06RN47Z" = "1" /* Replacement of Left Femoral Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RN4JZ" = "1" /* Replacement of Left Femoral Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06RN4KZ" = "1" /* Replacement of Left Femoral Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RP07Z" = "1" /* Replacement of Right Greater Saphenous Vein with Autologous Tissue Substitute, Open Approach */
"06RP0JZ" = "1" /* Replacement of Right Greater Saphenous Vein with Synthetic Substitute, Open Approach */
"06RP0KZ" = "1" /* Replacement of Right Greater Saphenous Vein with Nonautologous Tissue Substitute, Open Approach */
"06RP47Z" = "1" /* Replacement of Right Greater Saphenous Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RP4JZ" = "1" /* Replacement of Right Greater Saphenous Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06RP4KZ" = "1" /* Replacement of Right Greater Saphenous Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RQ07Z" = "1" /* Replacement of Left Greater Saphenous Vein with Autologous Tissue Substitute, Open Approach */
"06RQ0JZ" = "1" /* Replacement of Left Greater Saphenous Vein with Synthetic Substitute, Open Approach */
"06RQ0KZ" = "1" /* Replacement of Left Greater Saphenous Vein with Nonautologous Tissue Substitute, Open Approach */
"06RQ47Z" = "1" /* Replacement of Left Greater Saphenous Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RQ4JZ" = "1" /* Replacement of Left Greater Saphenous Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06RQ4KZ" = "1" /* Replacement of Left Greater Saphenous Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RR07Z" = "1" /* Replacement of Right Lesser Saphenous Vein with Autologous Tissue Substitute, Open Approach */
"06RR0JZ" = "1" /* Replacement of Right Lesser Saphenous Vein with Synthetic Substitute, Open Approach */
"06RR0KZ" = "1" /* Replacement of Right Lesser Saphenous Vein with Nonautologous Tissue Substitute, Open Approach */
"06RR47Z" = "1" /* Replacement of Right Lesser Saphenous Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RR4JZ" = "1" /* Replacement of Right Lesser Saphenous Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06RR4KZ" = "1" /* Replacement of Right Lesser Saphenous Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RS07Z" = "1" /* Replacement of Left Lesser Saphenous Vein with Autologous Tissue Substitute, Open Approach */
"06RS0JZ" = "1" /* Replacement of Left Lesser Saphenous Vein with Synthetic Substitute, Open Approach */
"06RS0KZ" = "1" /* Replacement of Left Lesser Saphenous Vein with Nonautologous Tissue Substitute, Open Approach */
"06RS47Z" = "1" /* Replacement of Left Lesser Saphenous Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RS4JZ" = "1" /* Replacement of Left Lesser Saphenous Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06RS4KZ" = "1" /* Replacement of Left Lesser Saphenous Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RT07Z" = "1" /* Replacement of Right Foot Vein with Autologous Tissue Substitute, Open Approach */
"06RT0JZ" = "1" /* Replacement of Right Foot Vein with Synthetic Substitute, Open Approach */
"06RT0KZ" = "1" /* Replacement of Right Foot Vein with Nonautologous Tissue Substitute, Open Approach */
"06RT47Z" = "1" /* Replacement of Right Foot Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RT4JZ" = "1" /* Replacement of Right Foot Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06RT4KZ" = "1" /* Replacement of Right Foot Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RV07Z" = "1" /* Replacement of Left Foot Vein with Autologous Tissue Substitute, Open Approach */
"06RV0JZ" = "1" /* Replacement of Left Foot Vein with Synthetic Substitute, Open Approach */
"06RV0KZ" = "1" /* Replacement of Left Foot Vein with Nonautologous Tissue Substitute, Open Approach */
"06RV47Z" = "1" /* Replacement of Left Foot Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RV4JZ" = "1" /* Replacement of Left Foot Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06RV4KZ" = "1" /* Replacement of Left Foot Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RY07Z" = "1" /* Replacement of Lower Vein with Autologous Tissue Substitute, Open Approach */
"06RY0JZ" = "1" /* Replacement of Lower Vein with Synthetic Substitute, Open Approach */
"06RY0KZ" = "1" /* Replacement of Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"06RY47Z" = "1" /* Replacement of Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06RY4JZ" = "1" /* Replacement of Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06RY4KZ" = "1" /* Replacement of Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06S00ZZ" = "1" /* Reposition Inferior Vena Cava, Open Approach */
"06S03ZZ" = "1" /* Reposition Inferior Vena Cava, Percutaneous Approach */
"06S04ZZ" = "1" /* Reposition Inferior Vena Cava, Percutaneous Endoscopic Approach */
"06S10ZZ" = "1" /* Reposition Splenic Vein, Open Approach */
"06S13ZZ" = "1" /* Reposition Splenic Vein, Percutaneous Approach */
"06S14ZZ" = "1" /* Reposition Splenic Vein, Percutaneous Endoscopic Approach */
"06S20ZZ" = "1" /* Reposition Gastric Vein, Open Approach */
"06S23ZZ" = "1" /* Reposition Gastric Vein, Percutaneous Approach */
"06S24ZZ" = "1" /* Reposition Gastric Vein, Percutaneous Endoscopic Approach */
"06S30ZZ" = "1" /* Reposition Esophageal Vein, Open Approach */
"06S33ZZ" = "1" /* Reposition Esophageal Vein, Percutaneous Approach */
"06S34ZZ" = "1" /* Reposition Esophageal Vein, Percutaneous Endoscopic Approach */
"06S40ZZ" = "1" /* Reposition Hepatic Vein, Open Approach */
"06S43ZZ" = "1" /* Reposition Hepatic Vein, Percutaneous Approach */
"06S44ZZ" = "1" /* Reposition Hepatic Vein, Percutaneous Endoscopic Approach */
"06S50ZZ" = "1" /* Reposition Superior Mesenteric Vein, Open Approach */
"06S53ZZ" = "1" /* Reposition Superior Mesenteric Vein, Percutaneous Approach */
"06S54ZZ" = "1" /* Reposition Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06S60ZZ" = "1" /* Reposition Inferior Mesenteric Vein, Open Approach */
"06S63ZZ" = "1" /* Reposition Inferior Mesenteric Vein, Percutaneous Approach */
"06S64ZZ" = "1" /* Reposition Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06S70ZZ" = "1" /* Reposition Colic Vein, Open Approach */
"06S73ZZ" = "1" /* Reposition Colic Vein, Percutaneous Approach */
"06S74ZZ" = "1" /* Reposition Colic Vein, Percutaneous Endoscopic Approach */
"06S80ZZ" = "1" /* Reposition Portal Vein, Open Approach */
"06S83ZZ" = "1" /* Reposition Portal Vein, Percutaneous Approach */
"06S84ZZ" = "1" /* Reposition Portal Vein, Percutaneous Endoscopic Approach */
"06S90ZZ" = "1" /* Reposition Right Renal Vein, Open Approach */
"06S93ZZ" = "1" /* Reposition Right Renal Vein, Percutaneous Approach */
"06S94ZZ" = "1" /* Reposition Right Renal Vein, Percutaneous Endoscopic Approach */
"06SB0ZZ" = "1" /* Reposition Left Renal Vein, Open Approach */
"06SB3ZZ" = "1" /* Reposition Left Renal Vein, Percutaneous Approach */
"06SB4ZZ" = "1" /* Reposition Left Renal Vein, Percutaneous Endoscopic Approach */
"06SC0ZZ" = "1" /* Reposition Right Common Iliac Vein, Open Approach */
"06SC3ZZ" = "1" /* Reposition Right Common Iliac Vein, Percutaneous Approach */
"06SC4ZZ" = "1" /* Reposition Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"06SD0ZZ" = "1" /* Reposition Left Common Iliac Vein, Open Approach */
"06SD3ZZ" = "1" /* Reposition Left Common Iliac Vein, Percutaneous Approach */
"06SD4ZZ" = "1" /* Reposition Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"06SF0ZZ" = "1" /* Reposition Right External Iliac Vein, Open Approach */
"06SF3ZZ" = "1" /* Reposition Right External Iliac Vein, Percutaneous Approach */
"06SF4ZZ" = "1" /* Reposition Right External Iliac Vein, Percutaneous Endoscopic Approach */
"06SG0ZZ" = "1" /* Reposition Left External Iliac Vein, Open Approach */
"06SG3ZZ" = "1" /* Reposition Left External Iliac Vein, Percutaneous Approach */
"06SG4ZZ" = "1" /* Reposition Left External Iliac Vein, Percutaneous Endoscopic Approach */
"06SH0ZZ" = "1" /* Reposition Right Hypogastric Vein, Open Approach */
"06SH3ZZ" = "1" /* Reposition Right Hypogastric Vein, Percutaneous Approach */
"06SH4ZZ" = "1" /* Reposition Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"06SJ0ZZ" = "1" /* Reposition Left Hypogastric Vein, Open Approach */
"06SJ3ZZ" = "1" /* Reposition Left Hypogastric Vein, Percutaneous Approach */
"06SJ4ZZ" = "1" /* Reposition Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"06SM0ZZ" = "1" /* Reposition Right Femoral Vein, Open Approach */
"06SM3ZZ" = "1" /* Reposition Right Femoral Vein, Percutaneous Approach */
"06SM4ZZ" = "1" /* Reposition Right Femoral Vein, Percutaneous Endoscopic Approach */
"06SN0ZZ" = "1" /* Reposition Left Femoral Vein, Open Approach */
"06SN3ZZ" = "1" /* Reposition Left Femoral Vein, Percutaneous Approach */
"06SN4ZZ" = "1" /* Reposition Left Femoral Vein, Percutaneous Endoscopic Approach */
"06SP0ZZ" = "1" /* Reposition Right Greater Saphenous Vein, Open Approach */
"06SP3ZZ" = "1" /* Reposition Right Greater Saphenous Vein, Percutaneous Approach */
"06SP4ZZ" = "1" /* Reposition Right Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"06SQ0ZZ" = "1" /* Reposition Left Greater Saphenous Vein, Open Approach */
"06SQ3ZZ" = "1" /* Reposition Left Greater Saphenous Vein, Percutaneous Approach */
"06SQ4ZZ" = "1" /* Reposition Left Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"06SR0ZZ" = "1" /* Reposition Right Lesser Saphenous Vein, Open Approach */
"06SR3ZZ" = "1" /* Reposition Right Lesser Saphenous Vein, Percutaneous Approach */
"06SR4ZZ" = "1" /* Reposition Right Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"06SS0ZZ" = "1" /* Reposition Left Lesser Saphenous Vein, Open Approach */
"06SS3ZZ" = "1" /* Reposition Left Lesser Saphenous Vein, Percutaneous Approach */
"06SS4ZZ" = "1" /* Reposition Left Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"06ST0ZZ" = "1" /* Reposition Right Foot Vein, Open Approach */
"06ST3ZZ" = "1" /* Reposition Right Foot Vein, Percutaneous Approach */
"06ST4ZZ" = "1" /* Reposition Right Foot Vein, Percutaneous Endoscopic Approach */
"06SV0ZZ" = "1" /* Reposition Left Foot Vein, Open Approach */
"06SV3ZZ" = "1" /* Reposition Left Foot Vein, Percutaneous Approach */
"06SV4ZZ" = "1" /* Reposition Left Foot Vein, Percutaneous Endoscopic Approach */
"06SY0ZZ" = "1" /* Reposition Lower Vein, Open Approach */
"06SY3ZZ" = "1" /* Reposition Lower Vein, Percutaneous Approach */
"06SY4ZZ" = "1" /* Reposition Lower Vein, Percutaneous Endoscopic Approach */
"06U007Z" = "1" /* Supplement Inferior Vena Cava with Autologous Tissue Substitute, Open Approach */
"06U00JZ" = "1" /* Supplement Inferior Vena Cava with Synthetic Substitute, Open Approach */
"06U00KZ" = "1" /* Supplement Inferior Vena Cava with Nonautologous Tissue Substitute, Open Approach */
"06U037Z" = "1" /* Supplement Inferior Vena Cava with Autologous Tissue Substitute, Percutaneous Approach */
"06U03JZ" = "1" /* Supplement Inferior Vena Cava with Synthetic Substitute, Percutaneous Approach */
"06U03KZ" = "1" /* Supplement Inferior Vena Cava with Nonautologous Tissue Substitute, Percutaneous Approach */
"06U047Z" = "1" /* Supplement Inferior Vena Cava with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U04JZ" = "1" /* Supplement Inferior Vena Cava with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06U04KZ" = "1" /* Supplement Inferior Vena Cava with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U107Z" = "1" /* Supplement Splenic Vein with Autologous Tissue Substitute, Open Approach */
"06U10JZ" = "1" /* Supplement Splenic Vein with Synthetic Substitute, Open Approach */
"06U10KZ" = "1" /* Supplement Splenic Vein with Nonautologous Tissue Substitute, Open Approach */
"06U137Z" = "1" /* Supplement Splenic Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06U13JZ" = "1" /* Supplement Splenic Vein with Synthetic Substitute, Percutaneous Approach */
"06U13KZ" = "1" /* Supplement Splenic Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06U147Z" = "1" /* Supplement Splenic Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U14JZ" = "1" /* Supplement Splenic Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06U14KZ" = "1" /* Supplement Splenic Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U207Z" = "1" /* Supplement Gastric Vein with Autologous Tissue Substitute, Open Approach */
"06U20JZ" = "1" /* Supplement Gastric Vein with Synthetic Substitute, Open Approach */
"06U20KZ" = "1" /* Supplement Gastric Vein with Nonautologous Tissue Substitute, Open Approach */
"06U237Z" = "1" /* Supplement Gastric Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06U23JZ" = "1" /* Supplement Gastric Vein with Synthetic Substitute, Percutaneous Approach */
"06U23KZ" = "1" /* Supplement Gastric Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06U247Z" = "1" /* Supplement Gastric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U24JZ" = "1" /* Supplement Gastric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06U24KZ" = "1" /* Supplement Gastric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U307Z" = "1" /* Supplement Esophageal Vein with Autologous Tissue Substitute, Open Approach */
"06U30JZ" = "1" /* Supplement Esophageal Vein with Synthetic Substitute, Open Approach */
"06U30KZ" = "1" /* Supplement Esophageal Vein with Nonautologous Tissue Substitute, Open Approach */
"06U337Z" = "1" /* Supplement Esophageal Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06U33JZ" = "1" /* Supplement Esophageal Vein with Synthetic Substitute, Percutaneous Approach */
"06U33KZ" = "1" /* Supplement Esophageal Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06U347Z" = "1" /* Supplement Esophageal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U34JZ" = "1" /* Supplement Esophageal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06U34KZ" = "1" /* Supplement Esophageal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U407Z" = "1" /* Supplement Hepatic Vein with Autologous Tissue Substitute, Open Approach */
"06U40JZ" = "1" /* Supplement Hepatic Vein with Synthetic Substitute, Open Approach */
"06U40KZ" = "1" /* Supplement Hepatic Vein with Nonautologous Tissue Substitute, Open Approach */
"06U437Z" = "1" /* Supplement Hepatic Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06U43JZ" = "1" /* Supplement Hepatic Vein with Synthetic Substitute, Percutaneous Approach */
"06U43KZ" = "1" /* Supplement Hepatic Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06U447Z" = "1" /* Supplement Hepatic Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U44JZ" = "1" /* Supplement Hepatic Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06U44KZ" = "1" /* Supplement Hepatic Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U507Z" = "1" /* Supplement Superior Mesenteric Vein with Autologous Tissue Substitute, Open Approach */
"06U50JZ" = "1" /* Supplement Superior Mesenteric Vein with Synthetic Substitute, Open Approach */
"06U50KZ" = "1" /* Supplement Superior Mesenteric Vein with Nonautologous Tissue Substitute, Open Approach */
"06U537Z" = "1" /* Supplement Superior Mesenteric Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06U53JZ" = "1" /* Supplement Superior Mesenteric Vein with Synthetic Substitute, Percutaneous Approach */
"06U53KZ" = "1" /* Supplement Superior Mesenteric Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06U547Z" = "1" /* Supplement Superior Mesenteric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U54JZ" = "1" /* Supplement Superior Mesenteric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06U54KZ" = "1" /* Supplement Superior Mesenteric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U607Z" = "1" /* Supplement Inferior Mesenteric Vein with Autologous Tissue Substitute, Open Approach */
"06U60JZ" = "1" /* Supplement Inferior Mesenteric Vein with Synthetic Substitute, Open Approach */
"06U60KZ" = "1" /* Supplement Inferior Mesenteric Vein with Nonautologous Tissue Substitute, Open Approach */
"06U637Z" = "1" /* Supplement Inferior Mesenteric Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06U63JZ" = "1" /* Supplement Inferior Mesenteric Vein with Synthetic Substitute, Percutaneous Approach */
"06U63KZ" = "1" /* Supplement Inferior Mesenteric Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06U647Z" = "1" /* Supplement Inferior Mesenteric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U64JZ" = "1" /* Supplement Inferior Mesenteric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06U64KZ" = "1" /* Supplement Inferior Mesenteric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U707Z" = "1" /* Supplement Colic Vein with Autologous Tissue Substitute, Open Approach */
"06U70JZ" = "1" /* Supplement Colic Vein with Synthetic Substitute, Open Approach */
"06U70KZ" = "1" /* Supplement Colic Vein with Nonautologous Tissue Substitute, Open Approach */
"06U737Z" = "1" /* Supplement Colic Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06U73JZ" = "1" /* Supplement Colic Vein with Synthetic Substitute, Percutaneous Approach */
"06U73KZ" = "1" /* Supplement Colic Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06U747Z" = "1" /* Supplement Colic Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U74JZ" = "1" /* Supplement Colic Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06U74KZ" = "1" /* Supplement Colic Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U807Z" = "1" /* Supplement Portal Vein with Autologous Tissue Substitute, Open Approach */
"06U80JZ" = "1" /* Supplement Portal Vein with Synthetic Substitute, Open Approach */
"06U80KZ" = "1" /* Supplement Portal Vein with Nonautologous Tissue Substitute, Open Approach */
"06U837Z" = "1" /* Supplement Portal Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06U83JZ" = "1" /* Supplement Portal Vein with Synthetic Substitute, Percutaneous Approach */
"06U83KZ" = "1" /* Supplement Portal Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06U847Z" = "1" /* Supplement Portal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U84JZ" = "1" /* Supplement Portal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06U84KZ" = "1" /* Supplement Portal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U907Z" = "1" /* Supplement Right Renal Vein with Autologous Tissue Substitute, Open Approach */
"06U90JZ" = "1" /* Supplement Right Renal Vein with Synthetic Substitute, Open Approach */
"06U90KZ" = "1" /* Supplement Right Renal Vein with Nonautologous Tissue Substitute, Open Approach */
"06U937Z" = "1" /* Supplement Right Renal Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06U93JZ" = "1" /* Supplement Right Renal Vein with Synthetic Substitute, Percutaneous Approach */
"06U93KZ" = "1" /* Supplement Right Renal Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06U947Z" = "1" /* Supplement Right Renal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06U94JZ" = "1" /* Supplement Right Renal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06U94KZ" = "1" /* Supplement Right Renal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UB07Z" = "1" /* Supplement Left Renal Vein with Autologous Tissue Substitute, Open Approach */
"06UB0JZ" = "1" /* Supplement Left Renal Vein with Synthetic Substitute, Open Approach */
"06UB0KZ" = "1" /* Supplement Left Renal Vein with Nonautologous Tissue Substitute, Open Approach */
"06UB37Z" = "1" /* Supplement Left Renal Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06UB3JZ" = "1" /* Supplement Left Renal Vein with Synthetic Substitute, Percutaneous Approach */
"06UB3KZ" = "1" /* Supplement Left Renal Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06UB47Z" = "1" /* Supplement Left Renal Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UB4JZ" = "1" /* Supplement Left Renal Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06UB4KZ" = "1" /* Supplement Left Renal Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UC07Z" = "1" /* Supplement Right Common Iliac Vein with Autologous Tissue Substitute, Open Approach */
"06UC0JZ" = "1" /* Supplement Right Common Iliac Vein with Synthetic Substitute, Open Approach */
"06UC0KZ" = "1" /* Supplement Right Common Iliac Vein with Nonautologous Tissue Substitute, Open Approach */
"06UC37Z" = "1" /* Supplement Right Common Iliac Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06UC3JZ" = "1" /* Supplement Right Common Iliac Vein with Synthetic Substitute, Percutaneous Approach */
"06UC3KZ" = "1" /* Supplement Right Common Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06UC47Z" = "1" /* Supplement Right Common Iliac Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UC4JZ" = "1" /* Supplement Right Common Iliac Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06UC4KZ" = "1" /* Supplement Right Common Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UD07Z" = "1" /* Supplement Left Common Iliac Vein with Autologous Tissue Substitute, Open Approach */
"06UD0JZ" = "1" /* Supplement Left Common Iliac Vein with Synthetic Substitute, Open Approach */
"06UD0KZ" = "1" /* Supplement Left Common Iliac Vein with Nonautologous Tissue Substitute, Open Approach */
"06UD37Z" = "1" /* Supplement Left Common Iliac Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06UD3JZ" = "1" /* Supplement Left Common Iliac Vein with Synthetic Substitute, Percutaneous Approach */
"06UD3KZ" = "1" /* Supplement Left Common Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06UD47Z" = "1" /* Supplement Left Common Iliac Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UD4JZ" = "1" /* Supplement Left Common Iliac Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06UD4KZ" = "1" /* Supplement Left Common Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UF07Z" = "1" /* Supplement Right External Iliac Vein with Autologous Tissue Substitute, Open Approach */
"06UF0JZ" = "1" /* Supplement Right External Iliac Vein with Synthetic Substitute, Open Approach */
"06UF0KZ" = "1" /* Supplement Right External Iliac Vein with Nonautologous Tissue Substitute, Open Approach */
"06UF37Z" = "1" /* Supplement Right External Iliac Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06UF3JZ" = "1" /* Supplement Right External Iliac Vein with Synthetic Substitute, Percutaneous Approach */
"06UF3KZ" = "1" /* Supplement Right External Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06UF47Z" = "1" /* Supplement Right External Iliac Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UF4JZ" = "1" /* Supplement Right External Iliac Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06UF4KZ" = "1" /* Supplement Right External Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UG07Z" = "1" /* Supplement Left External Iliac Vein with Autologous Tissue Substitute, Open Approach */
"06UG0JZ" = "1" /* Supplement Left External Iliac Vein with Synthetic Substitute, Open Approach */
"06UG0KZ" = "1" /* Supplement Left External Iliac Vein with Nonautologous Tissue Substitute, Open Approach */
"06UG37Z" = "1" /* Supplement Left External Iliac Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06UG3JZ" = "1" /* Supplement Left External Iliac Vein with Synthetic Substitute, Percutaneous Approach */
"06UG3KZ" = "1" /* Supplement Left External Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06UG47Z" = "1" /* Supplement Left External Iliac Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UG4JZ" = "1" /* Supplement Left External Iliac Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06UG4KZ" = "1" /* Supplement Left External Iliac Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UH07Z" = "1" /* Supplement Right Hypogastric Vein with Autologous Tissue Substitute, Open Approach */
"06UH0JZ" = "1" /* Supplement Right Hypogastric Vein with Synthetic Substitute, Open Approach */
"06UH0KZ" = "1" /* Supplement Right Hypogastric Vein with Nonautologous Tissue Substitute, Open Approach */
"06UH37Z" = "1" /* Supplement Right Hypogastric Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06UH3JZ" = "1" /* Supplement Right Hypogastric Vein with Synthetic Substitute, Percutaneous Approach */
"06UH3KZ" = "1" /* Supplement Right Hypogastric Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06UH47Z" = "1" /* Supplement Right Hypogastric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UH4JZ" = "1" /* Supplement Right Hypogastric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06UH4KZ" = "1" /* Supplement Right Hypogastric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UJ07Z" = "1" /* Supplement Left Hypogastric Vein with Autologous Tissue Substitute, Open Approach */
"06UJ0JZ" = "1" /* Supplement Left Hypogastric Vein with Synthetic Substitute, Open Approach */
"06UJ0KZ" = "1" /* Supplement Left Hypogastric Vein with Nonautologous Tissue Substitute, Open Approach */
"06UJ37Z" = "1" /* Supplement Left Hypogastric Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06UJ3JZ" = "1" /* Supplement Left Hypogastric Vein with Synthetic Substitute, Percutaneous Approach */
"06UJ3KZ" = "1" /* Supplement Left Hypogastric Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06UJ47Z" = "1" /* Supplement Left Hypogastric Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UJ4JZ" = "1" /* Supplement Left Hypogastric Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06UJ4KZ" = "1" /* Supplement Left Hypogastric Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UM07Z" = "1" /* Supplement Right Femoral Vein with Autologous Tissue Substitute, Open Approach */
"06UM0JZ" = "1" /* Supplement Right Femoral Vein with Synthetic Substitute, Open Approach */
"06UM0KZ" = "1" /* Supplement Right Femoral Vein with Nonautologous Tissue Substitute, Open Approach */
"06UM37Z" = "1" /* Supplement Right Femoral Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06UM3JZ" = "1" /* Supplement Right Femoral Vein with Synthetic Substitute, Percutaneous Approach */
"06UM3KZ" = "1" /* Supplement Right Femoral Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06UM47Z" = "1" /* Supplement Right Femoral Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UM4JZ" = "1" /* Supplement Right Femoral Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06UM4KZ" = "1" /* Supplement Right Femoral Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UN07Z" = "1" /* Supplement Left Femoral Vein with Autologous Tissue Substitute, Open Approach */
"06UN0JZ" = "1" /* Supplement Left Femoral Vein with Synthetic Substitute, Open Approach */
"06UN0KZ" = "1" /* Supplement Left Femoral Vein with Nonautologous Tissue Substitute, Open Approach */
"06UN37Z" = "1" /* Supplement Left Femoral Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06UN3JZ" = "1" /* Supplement Left Femoral Vein with Synthetic Substitute, Percutaneous Approach */
"06UN3KZ" = "1" /* Supplement Left Femoral Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06UN47Z" = "1" /* Supplement Left Femoral Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UN4JZ" = "1" /* Supplement Left Femoral Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06UN4KZ" = "1" /* Supplement Left Femoral Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UP07Z" = "1" /* Supplement Right Greater Saphenous Vein with Autologous Tissue Substitute, Open Approach */
"06UP0JZ" = "1" /* Supplement Right Greater Saphenous Vein with Synthetic Substitute, Open Approach */
"06UP0KZ" = "1" /* Supplement Right Greater Saphenous Vein with Nonautologous Tissue Substitute, Open Approach */
"06UP37Z" = "1" /* Supplement Right Greater Saphenous Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06UP3JZ" = "1" /* Supplement Right Greater Saphenous Vein with Synthetic Substitute, Percutaneous Approach */
"06UP3KZ" = "1" /* Supplement Right Greater Saphenous Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06UP47Z" = "1" /* Supplement Right Greater Saphenous Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UP4JZ" = "1" /* Supplement Right Greater Saphenous Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06UP4KZ" = "1" /* Supplement Right Greater Saphenous Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UQ07Z" = "1" /* Supplement Left Greater Saphenous Vein with Autologous Tissue Substitute, Open Approach */
"06UQ0JZ" = "1" /* Supplement Left Greater Saphenous Vein with Synthetic Substitute, Open Approach */
"06UQ0KZ" = "1" /* Supplement Left Greater Saphenous Vein with Nonautologous Tissue Substitute, Open Approach */
"06UQ37Z" = "1" /* Supplement Left Greater Saphenous Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06UQ3JZ" = "1" /* Supplement Left Greater Saphenous Vein with Synthetic Substitute, Percutaneous Approach */
"06UQ3KZ" = "1" /* Supplement Left Greater Saphenous Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06UQ47Z" = "1" /* Supplement Left Greater Saphenous Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UQ4JZ" = "1" /* Supplement Left Greater Saphenous Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06UQ4KZ" = "1" /* Supplement Left Greater Saphenous Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UR07Z" = "1" /* Supplement Right Lesser Saphenous Vein with Autologous Tissue Substitute, Open Approach */
"06UR0JZ" = "1" /* Supplement Right Lesser Saphenous Vein with Synthetic Substitute, Open Approach */
"06UR0KZ" = "1" /* Supplement Right Lesser Saphenous Vein with Nonautologous Tissue Substitute, Open Approach */
"06UR37Z" = "1" /* Supplement Right Lesser Saphenous Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06UR3JZ" = "1" /* Supplement Right Lesser Saphenous Vein with Synthetic Substitute, Percutaneous Approach */
"06UR3KZ" = "1" /* Supplement Right Lesser Saphenous Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06UR47Z" = "1" /* Supplement Right Lesser Saphenous Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UR4JZ" = "1" /* Supplement Right Lesser Saphenous Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06UR4KZ" = "1" /* Supplement Right Lesser Saphenous Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06US07Z" = "1" /* Supplement Left Lesser Saphenous Vein with Autologous Tissue Substitute, Open Approach */
"06US0JZ" = "1" /* Supplement Left Lesser Saphenous Vein with Synthetic Substitute, Open Approach */
"06US0KZ" = "1" /* Supplement Left Lesser Saphenous Vein with Nonautologous Tissue Substitute, Open Approach */
"06US37Z" = "1" /* Supplement Left Lesser Saphenous Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06US3JZ" = "1" /* Supplement Left Lesser Saphenous Vein with Synthetic Substitute, Percutaneous Approach */
"06US3KZ" = "1" /* Supplement Left Lesser Saphenous Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06US47Z" = "1" /* Supplement Left Lesser Saphenous Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06US4JZ" = "1" /* Supplement Left Lesser Saphenous Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06US4KZ" = "1" /* Supplement Left Lesser Saphenous Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UT07Z" = "1" /* Supplement Right Foot Vein with Autologous Tissue Substitute, Open Approach */
"06UT0JZ" = "1" /* Supplement Right Foot Vein with Synthetic Substitute, Open Approach */
"06UT0KZ" = "1" /* Supplement Right Foot Vein with Nonautologous Tissue Substitute, Open Approach */
"06UT37Z" = "1" /* Supplement Right Foot Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06UT3JZ" = "1" /* Supplement Right Foot Vein with Synthetic Substitute, Percutaneous Approach */
"06UT3KZ" = "1" /* Supplement Right Foot Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06UT47Z" = "1" /* Supplement Right Foot Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UT4JZ" = "1" /* Supplement Right Foot Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06UT4KZ" = "1" /* Supplement Right Foot Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UV07Z" = "1" /* Supplement Left Foot Vein with Autologous Tissue Substitute, Open Approach */
"06UV0JZ" = "1" /* Supplement Left Foot Vein with Synthetic Substitute, Open Approach */
"06UV0KZ" = "1" /* Supplement Left Foot Vein with Nonautologous Tissue Substitute, Open Approach */
"06UV37Z" = "1" /* Supplement Left Foot Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06UV3JZ" = "1" /* Supplement Left Foot Vein with Synthetic Substitute, Percutaneous Approach */
"06UV3KZ" = "1" /* Supplement Left Foot Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06UV47Z" = "1" /* Supplement Left Foot Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UV4JZ" = "1" /* Supplement Left Foot Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06UV4KZ" = "1" /* Supplement Left Foot Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UY07Z" = "1" /* Supplement Lower Vein with Autologous Tissue Substitute, Open Approach */
"06UY0JZ" = "1" /* Supplement Lower Vein with Synthetic Substitute, Open Approach */
"06UY0KZ" = "1" /* Supplement Lower Vein with Nonautologous Tissue Substitute, Open Approach */
"06UY37Z" = "1" /* Supplement Lower Vein with Autologous Tissue Substitute, Percutaneous Approach */
"06UY3JZ" = "1" /* Supplement Lower Vein with Synthetic Substitute, Percutaneous Approach */
"06UY3KZ" = "1" /* Supplement Lower Vein with Nonautologous Tissue Substitute, Percutaneous Approach */
"06UY47Z" = "1" /* Supplement Lower Vein with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06UY4JZ" = "1" /* Supplement Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06UY4KZ" = "1" /* Supplement Lower Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06V00CZ" = "1" /* Restriction of Inferior Vena Cava with Extraluminal Device, Open Approach */
"06V00DZ" = "1" /* Restriction of Inferior Vena Cava with Intraluminal Device, Open Approach */
"06V00ZZ" = "1" /* Restriction of Inferior Vena Cava, Open Approach */
"06V03CZ" = "1" /* Restriction of Inferior Vena Cava with Extraluminal Device, Percutaneous Approach */
"06V03DZ" = "1" /* Restriction of Inferior Vena Cava with Intraluminal Device, Percutaneous Approach */
"06V03ZZ" = "1" /* Restriction of Inferior Vena Cava, Percutaneous Approach */
"06V04CZ" = "1" /* Restriction of Inferior Vena Cava with Extraluminal Device, Percutaneous Endoscopic Approach */
"06V04DZ" = "1" /* Restriction of Inferior Vena Cava with Intraluminal Device, Percutaneous Endoscopic Approach */
"06V04ZZ" = "1" /* Restriction of Inferior Vena Cava, Percutaneous Endoscopic Approach */
"06V10CZ" = "1" /* Restriction of Splenic Vein with Extraluminal Device, Open Approach */
"06V10DZ" = "1" /* Restriction of Splenic Vein with Intraluminal Device, Open Approach */
"06V10ZZ" = "1" /* Restriction of Splenic Vein, Open Approach */
"06V13CZ" = "1" /* Restriction of Splenic Vein with Extraluminal Device, Percutaneous Approach */
"06V13DZ" = "1" /* Restriction of Splenic Vein with Intraluminal Device, Percutaneous Approach */
"06V13ZZ" = "1" /* Restriction of Splenic Vein, Percutaneous Approach */
"06V14CZ" = "1" /* Restriction of Splenic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06V14DZ" = "1" /* Restriction of Splenic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06V14ZZ" = "1" /* Restriction of Splenic Vein, Percutaneous Endoscopic Approach */
"06V20CZ" = "1" /* Restriction of Gastric Vein with Extraluminal Device, Open Approach */
"06V20DZ" = "1" /* Restriction of Gastric Vein with Intraluminal Device, Open Approach */
"06V20ZZ" = "1" /* Restriction of Gastric Vein, Open Approach */
"06V23CZ" = "1" /* Restriction of Gastric Vein with Extraluminal Device, Percutaneous Approach */
"06V23DZ" = "1" /* Restriction of Gastric Vein with Intraluminal Device, Percutaneous Approach */
"06V23ZZ" = "1" /* Restriction of Gastric Vein, Percutaneous Approach */
"06V24CZ" = "1" /* Restriction of Gastric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06V24DZ" = "1" /* Restriction of Gastric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06V24ZZ" = "1" /* Restriction of Gastric Vein, Percutaneous Endoscopic Approach */
"06V30CZ" = "1" /* Restriction of Esophageal Vein with Extraluminal Device, Open Approach */
"06V30DZ" = "1" /* Restriction of Esophageal Vein with Intraluminal Device, Open Approach */
"06V30ZZ" = "1" /* Restriction of Esophageal Vein, Open Approach */
"06V33CZ" = "1" /* Restriction of Esophageal Vein with Extraluminal Device, Percutaneous Approach */
"06V33DZ" = "1" /* Restriction of Esophageal Vein with Intraluminal Device, Percutaneous Approach */
"06V33ZZ" = "1" /* Restriction of Esophageal Vein, Percutaneous Approach */
"06V34CZ" = "1" /* Restriction of Esophageal Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06V34DZ" = "1" /* Restriction of Esophageal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06V34ZZ" = "1" /* Restriction of Esophageal Vein, Percutaneous Endoscopic Approach */
"06V40CZ" = "1" /* Restriction of Hepatic Vein with Extraluminal Device, Open Approach */
"06V40DZ" = "1" /* Restriction of Hepatic Vein with Intraluminal Device, Open Approach */
"06V40ZZ" = "1" /* Restriction of Hepatic Vein, Open Approach */
"06V43CZ" = "1" /* Restriction of Hepatic Vein with Extraluminal Device, Percutaneous Approach */
"06V43DZ" = "1" /* Restriction of Hepatic Vein with Intraluminal Device, Percutaneous Approach */
"06V43ZZ" = "1" /* Restriction of Hepatic Vein, Percutaneous Approach */
"06V44CZ" = "1" /* Restriction of Hepatic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06V44DZ" = "1" /* Restriction of Hepatic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06V44ZZ" = "1" /* Restriction of Hepatic Vein, Percutaneous Endoscopic Approach */
"06V50CZ" = "1" /* Restriction of Superior Mesenteric Vein with Extraluminal Device, Open Approach */
"06V50DZ" = "1" /* Restriction of Superior Mesenteric Vein with Intraluminal Device, Open Approach */
"06V50ZZ" = "1" /* Restriction of Superior Mesenteric Vein, Open Approach */
"06V53CZ" = "1" /* Restriction of Superior Mesenteric Vein with Extraluminal Device, Percutaneous Approach */
"06V53DZ" = "1" /* Restriction of Superior Mesenteric Vein with Intraluminal Device, Percutaneous Approach */
"06V53ZZ" = "1" /* Restriction of Superior Mesenteric Vein, Percutaneous Approach */
"06V54CZ" = "1" /* Restriction of Superior Mesenteric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06V54DZ" = "1" /* Restriction of Superior Mesenteric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06V54ZZ" = "1" /* Restriction of Superior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06V60CZ" = "1" /* Restriction of Inferior Mesenteric Vein with Extraluminal Device, Open Approach */
"06V60DZ" = "1" /* Restriction of Inferior Mesenteric Vein with Intraluminal Device, Open Approach */
"06V60ZZ" = "1" /* Restriction of Inferior Mesenteric Vein, Open Approach */
"06V63CZ" = "1" /* Restriction of Inferior Mesenteric Vein with Extraluminal Device, Percutaneous Approach */
"06V63DZ" = "1" /* Restriction of Inferior Mesenteric Vein with Intraluminal Device, Percutaneous Approach */
"06V63ZZ" = "1" /* Restriction of Inferior Mesenteric Vein, Percutaneous Approach */
"06V64CZ" = "1" /* Restriction of Inferior Mesenteric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06V64DZ" = "1" /* Restriction of Inferior Mesenteric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06V64ZZ" = "1" /* Restriction of Inferior Mesenteric Vein, Percutaneous Endoscopic Approach */
"06V70CZ" = "1" /* Restriction of Colic Vein with Extraluminal Device, Open Approach */
"06V70DZ" = "1" /* Restriction of Colic Vein with Intraluminal Device, Open Approach */
"06V70ZZ" = "1" /* Restriction of Colic Vein, Open Approach */
"06V73CZ" = "1" /* Restriction of Colic Vein with Extraluminal Device, Percutaneous Approach */
"06V73DZ" = "1" /* Restriction of Colic Vein with Intraluminal Device, Percutaneous Approach */
"06V73ZZ" = "1" /* Restriction of Colic Vein, Percutaneous Approach */
"06V74CZ" = "1" /* Restriction of Colic Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06V74DZ" = "1" /* Restriction of Colic Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06V74ZZ" = "1" /* Restriction of Colic Vein, Percutaneous Endoscopic Approach */
"06V80CZ" = "1" /* Restriction of Portal Vein with Extraluminal Device, Open Approach */
"06V80DZ" = "1" /* Restriction of Portal Vein with Intraluminal Device, Open Approach */
"06V80ZZ" = "1" /* Restriction of Portal Vein, Open Approach */
"06V83CZ" = "1" /* Restriction of Portal Vein with Extraluminal Device, Percutaneous Approach */
"06V83DZ" = "1" /* Restriction of Portal Vein with Intraluminal Device, Percutaneous Approach */
"06V83ZZ" = "1" /* Restriction of Portal Vein, Percutaneous Approach */
"06V84CZ" = "1" /* Restriction of Portal Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06V84DZ" = "1" /* Restriction of Portal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06V84ZZ" = "1" /* Restriction of Portal Vein, Percutaneous Endoscopic Approach */
"06V90CZ" = "1" /* Restriction of Right Renal Vein with Extraluminal Device, Open Approach */
"06V90DZ" = "1" /* Restriction of Right Renal Vein with Intraluminal Device, Open Approach */
"06V90ZZ" = "1" /* Restriction of Right Renal Vein, Open Approach */
"06V93CZ" = "1" /* Restriction of Right Renal Vein with Extraluminal Device, Percutaneous Approach */
"06V93DZ" = "1" /* Restriction of Right Renal Vein with Intraluminal Device, Percutaneous Approach */
"06V93ZZ" = "1" /* Restriction of Right Renal Vein, Percutaneous Approach */
"06V94CZ" = "1" /* Restriction of Right Renal Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06V94DZ" = "1" /* Restriction of Right Renal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06V94ZZ" = "1" /* Restriction of Right Renal Vein, Percutaneous Endoscopic Approach */
"06VB0CZ" = "1" /* Restriction of Left Renal Vein with Extraluminal Device, Open Approach */
"06VB0DZ" = "1" /* Restriction of Left Renal Vein with Intraluminal Device, Open Approach */
"06VB0ZZ" = "1" /* Restriction of Left Renal Vein, Open Approach */
"06VB3CZ" = "1" /* Restriction of Left Renal Vein with Extraluminal Device, Percutaneous Approach */
"06VB3DZ" = "1" /* Restriction of Left Renal Vein with Intraluminal Device, Percutaneous Approach */
"06VB3ZZ" = "1" /* Restriction of Left Renal Vein, Percutaneous Approach */
"06VB4CZ" = "1" /* Restriction of Left Renal Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06VB4DZ" = "1" /* Restriction of Left Renal Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06VB4ZZ" = "1" /* Restriction of Left Renal Vein, Percutaneous Endoscopic Approach */
"06VC0CZ" = "1" /* Restriction of Right Common Iliac Vein with Extraluminal Device, Open Approach */
"06VC0DZ" = "1" /* Restriction of Right Common Iliac Vein with Intraluminal Device, Open Approach */
"06VC0ZZ" = "1" /* Restriction of Right Common Iliac Vein, Open Approach */
"06VC3CZ" = "1" /* Restriction of Right Common Iliac Vein with Extraluminal Device, Percutaneous Approach */
"06VC3DZ" = "1" /* Restriction of Right Common Iliac Vein with Intraluminal Device, Percutaneous Approach */
"06VC3ZZ" = "1" /* Restriction of Right Common Iliac Vein, Percutaneous Approach */
"06VC4CZ" = "1" /* Restriction of Right Common Iliac Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06VC4DZ" = "1" /* Restriction of Right Common Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06VC4ZZ" = "1" /* Restriction of Right Common Iliac Vein, Percutaneous Endoscopic Approach */
"06VD0CZ" = "1" /* Restriction of Left Common Iliac Vein with Extraluminal Device, Open Approach */
"06VD0DZ" = "1" /* Restriction of Left Common Iliac Vein with Intraluminal Device, Open Approach */
"06VD0ZZ" = "1" /* Restriction of Left Common Iliac Vein, Open Approach */
"06VD3CZ" = "1" /* Restriction of Left Common Iliac Vein with Extraluminal Device, Percutaneous Approach */
"06VD3DZ" = "1" /* Restriction of Left Common Iliac Vein with Intraluminal Device, Percutaneous Approach */
"06VD3ZZ" = "1" /* Restriction of Left Common Iliac Vein, Percutaneous Approach */
"06VD4CZ" = "1" /* Restriction of Left Common Iliac Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06VD4DZ" = "1" /* Restriction of Left Common Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06VD4ZZ" = "1" /* Restriction of Left Common Iliac Vein, Percutaneous Endoscopic Approach */
"06VF0CZ" = "1" /* Restriction of Right External Iliac Vein with Extraluminal Device, Open Approach */
"06VF0DZ" = "1" /* Restriction of Right External Iliac Vein with Intraluminal Device, Open Approach */
"06VF0ZZ" = "1" /* Restriction of Right External Iliac Vein, Open Approach */
"06VF3CZ" = "1" /* Restriction of Right External Iliac Vein with Extraluminal Device, Percutaneous Approach */
"06VF3DZ" = "1" /* Restriction of Right External Iliac Vein with Intraluminal Device, Percutaneous Approach */
"06VF3ZZ" = "1" /* Restriction of Right External Iliac Vein, Percutaneous Approach */
"06VF4CZ" = "1" /* Restriction of Right External Iliac Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06VF4DZ" = "1" /* Restriction of Right External Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06VF4ZZ" = "1" /* Restriction of Right External Iliac Vein, Percutaneous Endoscopic Approach */
"06VG0CZ" = "1" /* Restriction of Left External Iliac Vein with Extraluminal Device, Open Approach */
"06VG0DZ" = "1" /* Restriction of Left External Iliac Vein with Intraluminal Device, Open Approach */
"06VG0ZZ" = "1" /* Restriction of Left External Iliac Vein, Open Approach */
"06VG3CZ" = "1" /* Restriction of Left External Iliac Vein with Extraluminal Device, Percutaneous Approach */
"06VG3DZ" = "1" /* Restriction of Left External Iliac Vein with Intraluminal Device, Percutaneous Approach */
"06VG3ZZ" = "1" /* Restriction of Left External Iliac Vein, Percutaneous Approach */
"06VG4CZ" = "1" /* Restriction of Left External Iliac Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06VG4DZ" = "1" /* Restriction of Left External Iliac Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06VG4ZZ" = "1" /* Restriction of Left External Iliac Vein, Percutaneous Endoscopic Approach */
"06VH0CZ" = "1" /* Restriction of Right Hypogastric Vein with Extraluminal Device, Open Approach */
"06VH0DZ" = "1" /* Restriction of Right Hypogastric Vein with Intraluminal Device, Open Approach */
"06VH0ZZ" = "1" /* Restriction of Right Hypogastric Vein, Open Approach */
"06VH3CZ" = "1" /* Restriction of Right Hypogastric Vein with Extraluminal Device, Percutaneous Approach */
"06VH3DZ" = "1" /* Restriction of Right Hypogastric Vein with Intraluminal Device, Percutaneous Approach */
"06VH3ZZ" = "1" /* Restriction of Right Hypogastric Vein, Percutaneous Approach */
"06VH4CZ" = "1" /* Restriction of Right Hypogastric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06VH4DZ" = "1" /* Restriction of Right Hypogastric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06VH4ZZ" = "1" /* Restriction of Right Hypogastric Vein, Percutaneous Endoscopic Approach */
"06VJ0CZ" = "1" /* Restriction of Left Hypogastric Vein with Extraluminal Device, Open Approach */
"06VJ0DZ" = "1" /* Restriction of Left Hypogastric Vein with Intraluminal Device, Open Approach */
"06VJ0ZZ" = "1" /* Restriction of Left Hypogastric Vein, Open Approach */
"06VJ3CZ" = "1" /* Restriction of Left Hypogastric Vein with Extraluminal Device, Percutaneous Approach */
"06VJ3DZ" = "1" /* Restriction of Left Hypogastric Vein with Intraluminal Device, Percutaneous Approach */
"06VJ3ZZ" = "1" /* Restriction of Left Hypogastric Vein, Percutaneous Approach */
"06VJ4CZ" = "1" /* Restriction of Left Hypogastric Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06VJ4DZ" = "1" /* Restriction of Left Hypogastric Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06VJ4ZZ" = "1" /* Restriction of Left Hypogastric Vein, Percutaneous Endoscopic Approach */
"06VM0CZ" = "1" /* Restriction of Right Femoral Vein with Extraluminal Device, Open Approach */
"06VM0DZ" = "1" /* Restriction of Right Femoral Vein with Intraluminal Device, Open Approach */
"06VM0ZZ" = "1" /* Restriction of Right Femoral Vein, Open Approach */
"06VM3CZ" = "1" /* Restriction of Right Femoral Vein with Extraluminal Device, Percutaneous Approach */
"06VM3DZ" = "1" /* Restriction of Right Femoral Vein with Intraluminal Device, Percutaneous Approach */
"06VM3ZZ" = "1" /* Restriction of Right Femoral Vein, Percutaneous Approach */
"06VM4CZ" = "1" /* Restriction of Right Femoral Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06VM4DZ" = "1" /* Restriction of Right Femoral Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06VM4ZZ" = "1" /* Restriction of Right Femoral Vein, Percutaneous Endoscopic Approach */
"06VN0CZ" = "1" /* Restriction of Left Femoral Vein with Extraluminal Device, Open Approach */
"06VN0DZ" = "1" /* Restriction of Left Femoral Vein with Intraluminal Device, Open Approach */
"06VN0ZZ" = "1" /* Restriction of Left Femoral Vein, Open Approach */
"06VN3CZ" = "1" /* Restriction of Left Femoral Vein with Extraluminal Device, Percutaneous Approach */
"06VN3DZ" = "1" /* Restriction of Left Femoral Vein with Intraluminal Device, Percutaneous Approach */
"06VN3ZZ" = "1" /* Restriction of Left Femoral Vein, Percutaneous Approach */
"06VN4CZ" = "1" /* Restriction of Left Femoral Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06VN4DZ" = "1" /* Restriction of Left Femoral Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06VN4ZZ" = "1" /* Restriction of Left Femoral Vein, Percutaneous Endoscopic Approach */
"06VP0CZ" = "1" /* Restriction of Right Greater Saphenous Vein with Extraluminal Device, Open Approach */
"06VP0DZ" = "1" /* Restriction of Right Greater Saphenous Vein with Intraluminal Device, Open Approach */
"06VP0ZZ" = "1" /* Restriction of Right Greater Saphenous Vein, Open Approach */
"06VP3CZ" = "1" /* Restriction of Right Greater Saphenous Vein with Extraluminal Device, Percutaneous Approach */
"06VP3DZ" = "1" /* Restriction of Right Greater Saphenous Vein with Intraluminal Device, Percutaneous Approach */
"06VP3ZZ" = "1" /* Restriction of Right Greater Saphenous Vein, Percutaneous Approach */
"06VP4CZ" = "1" /* Restriction of Right Greater Saphenous Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06VP4DZ" = "1" /* Restriction of Right Greater Saphenous Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06VP4ZZ" = "1" /* Restriction of Right Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"06VQ0CZ" = "1" /* Restriction of Left Greater Saphenous Vein with Extraluminal Device, Open Approach */
"06VQ0DZ" = "1" /* Restriction of Left Greater Saphenous Vein with Intraluminal Device, Open Approach */
"06VQ0ZZ" = "1" /* Restriction of Left Greater Saphenous Vein, Open Approach */
"06VQ3CZ" = "1" /* Restriction of Left Greater Saphenous Vein with Extraluminal Device, Percutaneous Approach */
"06VQ3DZ" = "1" /* Restriction of Left Greater Saphenous Vein with Intraluminal Device, Percutaneous Approach */
"06VQ3ZZ" = "1" /* Restriction of Left Greater Saphenous Vein, Percutaneous Approach */
"06VQ4CZ" = "1" /* Restriction of Left Greater Saphenous Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06VQ4DZ" = "1" /* Restriction of Left Greater Saphenous Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06VQ4ZZ" = "1" /* Restriction of Left Greater Saphenous Vein, Percutaneous Endoscopic Approach */
"06VR0CZ" = "1" /* Restriction of Right Lesser Saphenous Vein with Extraluminal Device, Open Approach */
"06VR0DZ" = "1" /* Restriction of Right Lesser Saphenous Vein with Intraluminal Device, Open Approach */
"06VR0ZZ" = "1" /* Restriction of Right Lesser Saphenous Vein, Open Approach */
"06VR3CZ" = "1" /* Restriction of Right Lesser Saphenous Vein with Extraluminal Device, Percutaneous Approach */
"06VR3DZ" = "1" /* Restriction of Right Lesser Saphenous Vein with Intraluminal Device, Percutaneous Approach */
"06VR3ZZ" = "1" /* Restriction of Right Lesser Saphenous Vein, Percutaneous Approach */
"06VR4CZ" = "1" /* Restriction of Right Lesser Saphenous Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06VR4DZ" = "1" /* Restriction of Right Lesser Saphenous Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06VR4ZZ" = "1" /* Restriction of Right Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"06VS0CZ" = "1" /* Restriction of Left Lesser Saphenous Vein with Extraluminal Device, Open Approach */
"06VS0DZ" = "1" /* Restriction of Left Lesser Saphenous Vein with Intraluminal Device, Open Approach */
"06VS0ZZ" = "1" /* Restriction of Left Lesser Saphenous Vein, Open Approach */
"06VS3CZ" = "1" /* Restriction of Left Lesser Saphenous Vein with Extraluminal Device, Percutaneous Approach */
"06VS3DZ" = "1" /* Restriction of Left Lesser Saphenous Vein with Intraluminal Device, Percutaneous Approach */
"06VS3ZZ" = "1" /* Restriction of Left Lesser Saphenous Vein, Percutaneous Approach */
"06VS4CZ" = "1" /* Restriction of Left Lesser Saphenous Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06VS4DZ" = "1" /* Restriction of Left Lesser Saphenous Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06VS4ZZ" = "1" /* Restriction of Left Lesser Saphenous Vein, Percutaneous Endoscopic Approach */
"06VT0CZ" = "1" /* Restriction of Right Foot Vein with Extraluminal Device, Open Approach */
"06VT0DZ" = "1" /* Restriction of Right Foot Vein with Intraluminal Device, Open Approach */
"06VT0ZZ" = "1" /* Restriction of Right Foot Vein, Open Approach */
"06VT3CZ" = "1" /* Restriction of Right Foot Vein with Extraluminal Device, Percutaneous Approach */
"06VT3DZ" = "1" /* Restriction of Right Foot Vein with Intraluminal Device, Percutaneous Approach */
"06VT3ZZ" = "1" /* Restriction of Right Foot Vein, Percutaneous Approach */
"06VT4CZ" = "1" /* Restriction of Right Foot Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06VT4DZ" = "1" /* Restriction of Right Foot Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06VT4ZZ" = "1" /* Restriction of Right Foot Vein, Percutaneous Endoscopic Approach */
"06VV0CZ" = "1" /* Restriction of Left Foot Vein with Extraluminal Device, Open Approach */
"06VV0DZ" = "1" /* Restriction of Left Foot Vein with Intraluminal Device, Open Approach */
"06VV0ZZ" = "1" /* Restriction of Left Foot Vein, Open Approach */
"06VV3CZ" = "1" /* Restriction of Left Foot Vein with Extraluminal Device, Percutaneous Approach */
"06VV3DZ" = "1" /* Restriction of Left Foot Vein with Intraluminal Device, Percutaneous Approach */
"06VV3ZZ" = "1" /* Restriction of Left Foot Vein, Percutaneous Approach */
"06VV4CZ" = "1" /* Restriction of Left Foot Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06VV4DZ" = "1" /* Restriction of Left Foot Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06VV4ZZ" = "1" /* Restriction of Left Foot Vein, Percutaneous Endoscopic Approach */
"06VY0CZ" = "1" /* Restriction of Lower Vein with Extraluminal Device, Open Approach */
"06VY0DZ" = "1" /* Restriction of Lower Vein with Intraluminal Device, Open Approach */
"06VY0ZZ" = "1" /* Restriction of Lower Vein, Open Approach */
"06VY3CZ" = "1" /* Restriction of Lower Vein with Extraluminal Device, Percutaneous Approach */
"06VY3DZ" = "1" /* Restriction of Lower Vein with Intraluminal Device, Percutaneous Approach */
"06VY3ZZ" = "1" /* Restriction of Lower Vein, Percutaneous Approach */
"06VY4CZ" = "1" /* Restriction of Lower Vein with Extraluminal Device, Percutaneous Endoscopic Approach */
"06VY4DZ" = "1" /* Restriction of Lower Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"06VY4ZZ" = "1" /* Restriction of Lower Vein, Percutaneous Endoscopic Approach */
"06WY00Z" = "1" /* Revision of Drainage Device in Lower Vein, Open Approach */
"06WY02Z" = "1" /* Revision of Monitoring Device in Lower Vein, Open Approach */
"06WY03Z" = "1" /* Revision of Infusion Device in Lower Vein, Open Approach */
"06WY07Z" = "1" /* Revision of Autologous Tissue Substitute in Lower Vein, Open Approach */
"06WY0CZ" = "1" /* Revision of Extraluminal Device in Lower Vein, Open Approach */
"06WY0DZ" = "1" /* Revision of Intraluminal Device in Lower Vein, Open Approach */
"06WY0JZ" = "1" /* Revision of Synthetic Substitute in Lower Vein, Open Approach */
"06WY0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Vein, Open Approach */
"06WY37Z" = "1" /* Revision of Autologous Tissue Substitute in Lower Vein, Percutaneous Approach */
"06WY3CZ" = "1" /* Revision of Extraluminal Device in Lower Vein, Percutaneous Approach */
"06WY3JZ" = "1" /* Revision of Synthetic Substitute in Lower Vein, Percutaneous Approach */
"06WY3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Vein, Percutaneous Approach */
"06WY40Z" = "1" /* Revision of Drainage Device in Lower Vein, Percutaneous Endoscopic Approach */
"06WY42Z" = "1" /* Revision of Monitoring Device in Lower Vein, Percutaneous Endoscopic Approach */
"06WY43Z" = "1" /* Revision of Infusion Device in Lower Vein, Percutaneous Endoscopic Approach */
"06WY47Z" = "1" /* Revision of Autologous Tissue Substitute in Lower Vein, Percutaneous Endoscopic Approach */
"06WY4CZ" = "1" /* Revision of Extraluminal Device in Lower Vein, Percutaneous Endoscopic Approach */
"06WY4DZ" = "1" /* Revision of Intraluminal Device in Lower Vein, Percutaneous Endoscopic Approach */
"06WY4JZ" = "1" /* Revision of Synthetic Substitute in Lower Vein, Percutaneous Endoscopic Approach */
"06WY4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Vein, Percutaneous Endoscopic Approach */
"07500ZZ" = "1" /* Destruction of Head Lymphatic, Open Approach */
"07503ZZ" = "1" /* Destruction of Head Lymphatic, Percutaneous Approach */
"07504ZZ" = "1" /* Destruction of Head Lymphatic, Percutaneous Endoscopic Approach */
"07510ZZ" = "1" /* Destruction of Right Neck Lymphatic, Open Approach */
"07513ZZ" = "1" /* Destruction of Right Neck Lymphatic, Percutaneous Approach */
"07514ZZ" = "1" /* Destruction of Right Neck Lymphatic, Percutaneous Endoscopic Approach */
"07520ZZ" = "1" /* Destruction of Left Neck Lymphatic, Open Approach */
"07523ZZ" = "1" /* Destruction of Left Neck Lymphatic, Percutaneous Approach */
"07524ZZ" = "1" /* Destruction of Left Neck Lymphatic, Percutaneous Endoscopic Approach */
"07530ZZ" = "1" /* Destruction of Right Upper Extremity Lymphatic, Open Approach */
"07533ZZ" = "1" /* Destruction of Right Upper Extremity Lymphatic, Percutaneous Approach */
"07534ZZ" = "1" /* Destruction of Right Upper Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07540ZZ" = "1" /* Destruction of Left Upper Extremity Lymphatic, Open Approach */
"07543ZZ" = "1" /* Destruction of Left Upper Extremity Lymphatic, Percutaneous Approach */
"07544ZZ" = "1" /* Destruction of Left Upper Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07550ZZ" = "1" /* Destruction of Right Axillary Lymphatic, Open Approach */
"07553ZZ" = "1" /* Destruction of Right Axillary Lymphatic, Percutaneous Approach */
"07554ZZ" = "1" /* Destruction of Right Axillary Lymphatic, Percutaneous Endoscopic Approach */
"07560ZZ" = "1" /* Destruction of Left Axillary Lymphatic, Open Approach */
"07563ZZ" = "1" /* Destruction of Left Axillary Lymphatic, Percutaneous Approach */
"07564ZZ" = "1" /* Destruction of Left Axillary Lymphatic, Percutaneous Endoscopic Approach */
"07570ZZ" = "1" /* Destruction of Thorax Lymphatic, Open Approach */
"07573ZZ" = "1" /* Destruction of Thorax Lymphatic, Percutaneous Approach */
"07574ZZ" = "1" /* Destruction of Thorax Lymphatic, Percutaneous Endoscopic Approach */
"07580ZZ" = "1" /* Destruction of Right Internal Mammary Lymphatic, Open Approach */
"07583ZZ" = "1" /* Destruction of Right Internal Mammary Lymphatic, Percutaneous Approach */
"07584ZZ" = "1" /* Destruction of Right Internal Mammary Lymphatic, Percutaneous Endoscopic Approach */
"07590ZZ" = "1" /* Destruction of Left Internal Mammary Lymphatic, Open Approach */
"07593ZZ" = "1" /* Destruction of Left Internal Mammary Lymphatic, Percutaneous Approach */
"07594ZZ" = "1" /* Destruction of Left Internal Mammary Lymphatic, Percutaneous Endoscopic Approach */
"075B0ZZ" = "1" /* Destruction of Mesenteric Lymphatic, Open Approach */
"075B3ZZ" = "1" /* Destruction of Mesenteric Lymphatic, Percutaneous Approach */
"075B4ZZ" = "1" /* Destruction of Mesenteric Lymphatic, Percutaneous Endoscopic Approach */
"075C0ZZ" = "1" /* Destruction of Pelvis Lymphatic, Open Approach */
"075C3ZZ" = "1" /* Destruction of Pelvis Lymphatic, Percutaneous Approach */
"075C4ZZ" = "1" /* Destruction of Pelvis Lymphatic, Percutaneous Endoscopic Approach */
"075D0ZZ" = "1" /* Destruction of Aortic Lymphatic, Open Approach */
"075D3ZZ" = "1" /* Destruction of Aortic Lymphatic, Percutaneous Approach */
"075D4ZZ" = "1" /* Destruction of Aortic Lymphatic, Percutaneous Endoscopic Approach */
"075F0ZZ" = "1" /* Destruction of Right Lower Extremity Lymphatic, Open Approach */
"075F3ZZ" = "1" /* Destruction of Right Lower Extremity Lymphatic, Percutaneous Approach */
"075F4ZZ" = "1" /* Destruction of Right Lower Extremity Lymphatic, Percutaneous Endoscopic Approach */
"075G0ZZ" = "1" /* Destruction of Left Lower Extremity Lymphatic, Open Approach */
"075G3ZZ" = "1" /* Destruction of Left Lower Extremity Lymphatic, Percutaneous Approach */
"075G4ZZ" = "1" /* Destruction of Left Lower Extremity Lymphatic, Percutaneous Endoscopic Approach */
"075H0ZZ" = "1" /* Destruction of Right Inguinal Lymphatic, Open Approach */
"075H3ZZ" = "1" /* Destruction of Right Inguinal Lymphatic, Percutaneous Approach */
"075H4ZZ" = "1" /* Destruction of Right Inguinal Lymphatic, Percutaneous Endoscopic Approach */
"075J0ZZ" = "1" /* Destruction of Left Inguinal Lymphatic, Open Approach */
"075J3ZZ" = "1" /* Destruction of Left Inguinal Lymphatic, Percutaneous Approach */
"075J4ZZ" = "1" /* Destruction of Left Inguinal Lymphatic, Percutaneous Endoscopic Approach */
"075K0ZZ" = "1" /* Destruction of Thoracic Duct, Open Approach */
"075K3ZZ" = "1" /* Destruction of Thoracic Duct, Percutaneous Approach */
"075K4ZZ" = "1" /* Destruction of Thoracic Duct, Percutaneous Endoscopic Approach */
"075L0ZZ" = "1" /* Destruction of Cisterna Chyli, Open Approach */
"075L3ZZ" = "1" /* Destruction of Cisterna Chyli, Percutaneous Approach */
"075L4ZZ" = "1" /* Destruction of Cisterna Chyli, Percutaneous Endoscopic Approach */
"075M0ZZ" = "1" /* Destruction of Thymus, Open Approach */
"075M3ZZ" = "1" /* Destruction of Thymus, Percutaneous Approach */
"075M4ZZ" = "1" /* Destruction of Thymus, Percutaneous Endoscopic Approach */
"075P0ZZ" = "1" /* Destruction of Spleen, Open Approach */
"075P3ZZ" = "1" /* Destruction of Spleen, Percutaneous Approach */
"075P4ZZ" = "1" /* Destruction of Spleen, Percutaneous Endoscopic Approach */
"079000Z" = "1" /* Drainage of Head Lymphatic with Drainage Device, Open Approach */
"07900ZX" = "1" /* Drainage of Head Lymphatic, Open Approach, Diagnostic */
"07900ZZ" = "1" /* Drainage of Head Lymphatic, Open Approach */
"079040Z" = "1" /* Drainage of Head Lymphatic with Drainage Device, Percutaneous Endoscopic Approach */
"07904ZX" = "1" /* Drainage of Head Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07904ZZ" = "1" /* Drainage of Head Lymphatic, Percutaneous Endoscopic Approach */
"079100Z" = "1" /* Drainage of Right Neck Lymphatic with Drainage Device, Open Approach */
"07910ZX" = "1" /* Drainage of Right Neck Lymphatic, Open Approach, Diagnostic */
"07910ZZ" = "1" /* Drainage of Right Neck Lymphatic, Open Approach */
"079140Z" = "1" /* Drainage of Right Neck Lymphatic with Drainage Device, Percutaneous Endoscopic Approach */
"07914ZX" = "1" /* Drainage of Right Neck Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07914ZZ" = "1" /* Drainage of Right Neck Lymphatic, Percutaneous Endoscopic Approach */
"079200Z" = "1" /* Drainage of Left Neck Lymphatic with Drainage Device, Open Approach */
"07920ZX" = "1" /* Drainage of Left Neck Lymphatic, Open Approach, Diagnostic */
"07920ZZ" = "1" /* Drainage of Left Neck Lymphatic, Open Approach */
"079240Z" = "1" /* Drainage of Left Neck Lymphatic with Drainage Device, Percutaneous Endoscopic Approach */
"07924ZX" = "1" /* Drainage of Left Neck Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07924ZZ" = "1" /* Drainage of Left Neck Lymphatic, Percutaneous Endoscopic Approach */
"079300Z" = "1" /* Drainage of Right Upper Extremity Lymphatic with Drainage Device, Open Approach */
"07930ZX" = "1" /* Drainage of Right Upper Extremity Lymphatic, Open Approach, Diagnostic */
"07930ZZ" = "1" /* Drainage of Right Upper Extremity Lymphatic, Open Approach */
"079340Z" = "1" /* Drainage of Right Upper Extremity Lymphatic with Drainage Device, Percutaneous Endoscopic Approach */
"07934ZX" = "1" /* Drainage of Right Upper Extremity Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07934ZZ" = "1" /* Drainage of Right Upper Extremity Lymphatic, Percutaneous Endoscopic Approach */
"079400Z" = "1" /* Drainage of Left Upper Extremity Lymphatic with Drainage Device, Open Approach */
"07940ZX" = "1" /* Drainage of Left Upper Extremity Lymphatic, Open Approach, Diagnostic */
"07940ZZ" = "1" /* Drainage of Left Upper Extremity Lymphatic, Open Approach */
"079440Z" = "1" /* Drainage of Left Upper Extremity Lymphatic with Drainage Device, Percutaneous Endoscopic Approach */
"07944ZX" = "1" /* Drainage of Left Upper Extremity Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07944ZZ" = "1" /* Drainage of Left Upper Extremity Lymphatic, Percutaneous Endoscopic Approach */
"079500Z" = "1" /* Drainage of Right Axillary Lymphatic with Drainage Device, Open Approach */
"07950ZX" = "1" /* Drainage of Right Axillary Lymphatic, Open Approach, Diagnostic */
"07950ZZ" = "1" /* Drainage of Right Axillary Lymphatic, Open Approach */
"079540Z" = "1" /* Drainage of Right Axillary Lymphatic with Drainage Device, Percutaneous Endoscopic Approach */
"07954ZX" = "1" /* Drainage of Right Axillary Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07954ZZ" = "1" /* Drainage of Right Axillary Lymphatic, Percutaneous Endoscopic Approach */
"079600Z" = "1" /* Drainage of Left Axillary Lymphatic with Drainage Device, Open Approach */
"07960ZX" = "1" /* Drainage of Left Axillary Lymphatic, Open Approach, Diagnostic */
"07960ZZ" = "1" /* Drainage of Left Axillary Lymphatic, Open Approach */
"079640Z" = "1" /* Drainage of Left Axillary Lymphatic with Drainage Device, Percutaneous Endoscopic Approach */
"07964ZX" = "1" /* Drainage of Left Axillary Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07964ZZ" = "1" /* Drainage of Left Axillary Lymphatic, Percutaneous Endoscopic Approach */
"079700Z" = "1" /* Drainage of Thorax Lymphatic with Drainage Device, Open Approach */
"07970ZX" = "1" /* Drainage of Thorax Lymphatic, Open Approach, Diagnostic */
"07970ZZ" = "1" /* Drainage of Thorax Lymphatic, Open Approach */
"079740Z" = "1" /* Drainage of Thorax Lymphatic with Drainage Device, Percutaneous Endoscopic Approach */
"07974ZX" = "1" /* Drainage of Thorax Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07974ZZ" = "1" /* Drainage of Thorax Lymphatic, Percutaneous Endoscopic Approach */
"079800Z" = "1" /* Drainage of Right Internal Mammary Lymphatic with Drainage Device, Open Approach */
"07980ZX" = "1" /* Drainage of Right Internal Mammary Lymphatic, Open Approach, Diagnostic */
"07980ZZ" = "1" /* Drainage of Right Internal Mammary Lymphatic, Open Approach */
"079840Z" = "1" /* Drainage of Right Internal Mammary Lymphatic with Drainage Device, Percutaneous Endoscopic Approach */
"07984ZX" = "1" /* Drainage of Right Internal Mammary Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07984ZZ" = "1" /* Drainage of Right Internal Mammary Lymphatic, Percutaneous Endoscopic Approach */
"079900Z" = "1" /* Drainage of Left Internal Mammary Lymphatic with Drainage Device, Open Approach */
"07990ZX" = "1" /* Drainage of Left Internal Mammary Lymphatic, Open Approach, Diagnostic */
"07990ZZ" = "1" /* Drainage of Left Internal Mammary Lymphatic, Open Approach */
"079940Z" = "1" /* Drainage of Left Internal Mammary Lymphatic with Drainage Device, Percutaneous Endoscopic Approach */
"07994ZX" = "1" /* Drainage of Left Internal Mammary Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07994ZZ" = "1" /* Drainage of Left Internal Mammary Lymphatic, Percutaneous Endoscopic Approach */
"079B00Z" = "1" /* Drainage of Mesenteric Lymphatic with Drainage Device, Open Approach */
"079B0ZX" = "1" /* Drainage of Mesenteric Lymphatic, Open Approach, Diagnostic */
"079B0ZZ" = "1" /* Drainage of Mesenteric Lymphatic, Open Approach */
"079B40Z" = "1" /* Drainage of Mesenteric Lymphatic with Drainage Device, Percutaneous Endoscopic Approach */
"079B4ZX" = "1" /* Drainage of Mesenteric Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"079B4ZZ" = "1" /* Drainage of Mesenteric Lymphatic, Percutaneous Endoscopic Approach */
"079C00Z" = "1" /* Drainage of Pelvis Lymphatic with Drainage Device, Open Approach */
"079C0ZX" = "1" /* Drainage of Pelvis Lymphatic, Open Approach, Diagnostic */
"079C0ZZ" = "1" /* Drainage of Pelvis Lymphatic, Open Approach */
"079C40Z" = "1" /* Drainage of Pelvis Lymphatic with Drainage Device, Percutaneous Endoscopic Approach */
"079C4ZX" = "1" /* Drainage of Pelvis Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"079C4ZZ" = "1" /* Drainage of Pelvis Lymphatic, Percutaneous Endoscopic Approach */
"079D00Z" = "1" /* Drainage of Aortic Lymphatic with Drainage Device, Open Approach */
"079D0ZX" = "1" /* Drainage of Aortic Lymphatic, Open Approach, Diagnostic */
"079D0ZZ" = "1" /* Drainage of Aortic Lymphatic, Open Approach */
"079D40Z" = "1" /* Drainage of Aortic Lymphatic with Drainage Device, Percutaneous Endoscopic Approach */
"079D4ZX" = "1" /* Drainage of Aortic Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"079D4ZZ" = "1" /* Drainage of Aortic Lymphatic, Percutaneous Endoscopic Approach */
"079F00Z" = "1" /* Drainage of Right Lower Extremity Lymphatic with Drainage Device, Open Approach */
"079F0ZX" = "1" /* Drainage of Right Lower Extremity Lymphatic, Open Approach, Diagnostic */
"079F0ZZ" = "1" /* Drainage of Right Lower Extremity Lymphatic, Open Approach */
"079F40Z" = "1" /* Drainage of Right Lower Extremity Lymphatic with Drainage Device, Percutaneous Endoscopic Approach */
"079F4ZX" = "1" /* Drainage of Right Lower Extremity Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"079F4ZZ" = "1" /* Drainage of Right Lower Extremity Lymphatic, Percutaneous Endoscopic Approach */
"079G00Z" = "1" /* Drainage of Left Lower Extremity Lymphatic with Drainage Device, Open Approach */
"079G0ZX" = "1" /* Drainage of Left Lower Extremity Lymphatic, Open Approach, Diagnostic */
"079G0ZZ" = "1" /* Drainage of Left Lower Extremity Lymphatic, Open Approach */
"079G40Z" = "1" /* Drainage of Left Lower Extremity Lymphatic with Drainage Device, Percutaneous Endoscopic Approach */
"079G4ZX" = "1" /* Drainage of Left Lower Extremity Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"079G4ZZ" = "1" /* Drainage of Left Lower Extremity Lymphatic, Percutaneous Endoscopic Approach */
"079H00Z" = "1" /* Drainage of Right Inguinal Lymphatic with Drainage Device, Open Approach */
"079H0ZX" = "1" /* Drainage of Right Inguinal Lymphatic, Open Approach, Diagnostic */
"079H0ZZ" = "1" /* Drainage of Right Inguinal Lymphatic, Open Approach */
"079H40Z" = "1" /* Drainage of Right Inguinal Lymphatic with Drainage Device, Percutaneous Endoscopic Approach */
"079H4ZX" = "1" /* Drainage of Right Inguinal Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"079H4ZZ" = "1" /* Drainage of Right Inguinal Lymphatic, Percutaneous Endoscopic Approach */
"079J00Z" = "1" /* Drainage of Left Inguinal Lymphatic with Drainage Device, Open Approach */
"079J0ZX" = "1" /* Drainage of Left Inguinal Lymphatic, Open Approach, Diagnostic */
"079J0ZZ" = "1" /* Drainage of Left Inguinal Lymphatic, Open Approach */
"079J40Z" = "1" /* Drainage of Left Inguinal Lymphatic with Drainage Device, Percutaneous Endoscopic Approach */
"079J4ZX" = "1" /* Drainage of Left Inguinal Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"079J4ZZ" = "1" /* Drainage of Left Inguinal Lymphatic, Percutaneous Endoscopic Approach */
"079K00Z" = "1" /* Drainage of Thoracic Duct with Drainage Device, Open Approach */
"079K0ZX" = "1" /* Drainage of Thoracic Duct, Open Approach, Diagnostic */
"079K0ZZ" = "1" /* Drainage of Thoracic Duct, Open Approach */
"079K40Z" = "1" /* Drainage of Thoracic Duct with Drainage Device, Percutaneous Endoscopic Approach */
"079K4ZX" = "1" /* Drainage of Thoracic Duct, Percutaneous Endoscopic Approach, Diagnostic */
"079K4ZZ" = "1" /* Drainage of Thoracic Duct, Percutaneous Endoscopic Approach */
"079L00Z" = "1" /* Drainage of Cisterna Chyli with Drainage Device, Open Approach */
"079L0ZX" = "1" /* Drainage of Cisterna Chyli, Open Approach, Diagnostic */
"079L0ZZ" = "1" /* Drainage of Cisterna Chyli, Open Approach */
"079L40Z" = "1" /* Drainage of Cisterna Chyli with Drainage Device, Percutaneous Endoscopic Approach */
"079L4ZX" = "1" /* Drainage of Cisterna Chyli, Percutaneous Endoscopic Approach, Diagnostic */
"079L4ZZ" = "1" /* Drainage of Cisterna Chyli, Percutaneous Endoscopic Approach */
"079M00Z" = "1" /* Drainage of Thymus with Drainage Device, Open Approach */
"079M0ZX" = "1" /* Drainage of Thymus, Open Approach, Diagnostic */
"079M0ZZ" = "1" /* Drainage of Thymus, Open Approach */
"079M40Z" = "1" /* Drainage of Thymus with Drainage Device, Percutaneous Endoscopic Approach */
"079M4ZX" = "1" /* Drainage of Thymus, Percutaneous Endoscopic Approach, Diagnostic */
"079M4ZZ" = "1" /* Drainage of Thymus, Percutaneous Endoscopic Approach */
"079P00Z" = "1" /* Drainage of Spleen with Drainage Device, Open Approach */
"079P0ZX" = "1" /* Drainage of Spleen, Open Approach, Diagnostic */
"079P0ZZ" = "1" /* Drainage of Spleen, Open Approach */
"07B00ZX" = "1" /* Excision of Head Lymphatic, Open Approach, Diagnostic */
"07B00ZZ" = "1" /* Excision of Head Lymphatic, Open Approach */
"07B03ZX" = "1" /* Excision of Head Lymphatic, Percutaneous Approach, Diagnostic */
"07B03ZZ" = "1" /* Excision of Head Lymphatic, Percutaneous Approach */
"07B04ZX" = "1" /* Excision of Head Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07B04ZZ" = "1" /* Excision of Head Lymphatic, Percutaneous Endoscopic Approach */
"07B10ZX" = "1" /* Excision of Right Neck Lymphatic, Open Approach, Diagnostic */
"07B10ZZ" = "1" /* Excision of Right Neck Lymphatic, Open Approach */
"07B13ZX" = "1" /* Excision of Right Neck Lymphatic, Percutaneous Approach, Diagnostic */
"07B13ZZ" = "1" /* Excision of Right Neck Lymphatic, Percutaneous Approach */
"07B14ZX" = "1" /* Excision of Right Neck Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07B14ZZ" = "1" /* Excision of Right Neck Lymphatic, Percutaneous Endoscopic Approach */
"07B20ZX" = "1" /* Excision of Left Neck Lymphatic, Open Approach, Diagnostic */
"07B20ZZ" = "1" /* Excision of Left Neck Lymphatic, Open Approach */
"07B23ZX" = "1" /* Excision of Left Neck Lymphatic, Percutaneous Approach, Diagnostic */
"07B23ZZ" = "1" /* Excision of Left Neck Lymphatic, Percutaneous Approach */
"07B24ZX" = "1" /* Excision of Left Neck Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07B24ZZ" = "1" /* Excision of Left Neck Lymphatic, Percutaneous Endoscopic Approach */
"07B30ZX" = "1" /* Excision of Right Upper Extremity Lymphatic, Open Approach, Diagnostic */
"07B30ZZ" = "1" /* Excision of Right Upper Extremity Lymphatic, Open Approach */
"07B33ZX" = "1" /* Excision of Right Upper Extremity Lymphatic, Percutaneous Approach, Diagnostic */
"07B33ZZ" = "1" /* Excision of Right Upper Extremity Lymphatic, Percutaneous Approach */
"07B34ZX" = "1" /* Excision of Right Upper Extremity Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07B34ZZ" = "1" /* Excision of Right Upper Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07B40ZX" = "1" /* Excision of Left Upper Extremity Lymphatic, Open Approach, Diagnostic */
"07B40ZZ" = "1" /* Excision of Left Upper Extremity Lymphatic, Open Approach */
"07B43ZX" = "1" /* Excision of Left Upper Extremity Lymphatic, Percutaneous Approach, Diagnostic */
"07B43ZZ" = "1" /* Excision of Left Upper Extremity Lymphatic, Percutaneous Approach */
"07B44ZX" = "1" /* Excision of Left Upper Extremity Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07B44ZZ" = "1" /* Excision of Left Upper Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07B50ZX" = "1" /* Excision of Right Axillary Lymphatic, Open Approach, Diagnostic */
"07B50ZZ" = "1" /* Excision of Right Axillary Lymphatic, Open Approach */
"07B53ZX" = "1" /* Excision of Right Axillary Lymphatic, Percutaneous Approach, Diagnostic */
"07B53ZZ" = "1" /* Excision of Right Axillary Lymphatic, Percutaneous Approach */
"07B54ZX" = "1" /* Excision of Right Axillary Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07B54ZZ" = "1" /* Excision of Right Axillary Lymphatic, Percutaneous Endoscopic Approach */
"07B60ZX" = "1" /* Excision of Left Axillary Lymphatic, Open Approach, Diagnostic */
"07B60ZZ" = "1" /* Excision of Left Axillary Lymphatic, Open Approach */
"07B63ZX" = "1" /* Excision of Left Axillary Lymphatic, Percutaneous Approach, Diagnostic */
"07B63ZZ" = "1" /* Excision of Left Axillary Lymphatic, Percutaneous Approach */
"07B64ZX" = "1" /* Excision of Left Axillary Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07B64ZZ" = "1" /* Excision of Left Axillary Lymphatic, Percutaneous Endoscopic Approach */
"07B70ZX" = "1" /* Excision of Thorax Lymphatic, Open Approach, Diagnostic */
"07B70ZZ" = "1" /* Excision of Thorax Lymphatic, Open Approach */
"07B73ZX" = "1" /* Excision of Thorax Lymphatic, Percutaneous Approach, Diagnostic */
"07B73ZZ" = "1" /* Excision of Thorax Lymphatic, Percutaneous Approach */
"07B74ZX" = "1" /* Excision of Thorax Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07B74ZZ" = "1" /* Excision of Thorax Lymphatic, Percutaneous Endoscopic Approach */
"07B80ZX" = "1" /* Excision of Right Internal Mammary Lymphatic, Open Approach, Diagnostic */
"07B80ZZ" = "1" /* Excision of Right Internal Mammary Lymphatic, Open Approach */
"07B83ZX" = "1" /* Excision of Right Internal Mammary Lymphatic, Percutaneous Approach, Diagnostic */
"07B83ZZ" = "1" /* Excision of Right Internal Mammary Lymphatic, Percutaneous Approach */
"07B84ZX" = "1" /* Excision of Right Internal Mammary Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07B84ZZ" = "1" /* Excision of Right Internal Mammary Lymphatic, Percutaneous Endoscopic Approach */
"07B90ZX" = "1" /* Excision of Left Internal Mammary Lymphatic, Open Approach, Diagnostic */
"07B90ZZ" = "1" /* Excision of Left Internal Mammary Lymphatic, Open Approach */
"07B93ZX" = "1" /* Excision of Left Internal Mammary Lymphatic, Percutaneous Approach, Diagnostic */
"07B93ZZ" = "1" /* Excision of Left Internal Mammary Lymphatic, Percutaneous Approach */
"07B94ZX" = "1" /* Excision of Left Internal Mammary Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07B94ZZ" = "1" /* Excision of Left Internal Mammary Lymphatic, Percutaneous Endoscopic Approach */
"07BB0ZX" = "1" /* Excision of Mesenteric Lymphatic, Open Approach, Diagnostic */
"07BB0ZZ" = "1" /* Excision of Mesenteric Lymphatic, Open Approach */
"07BB3ZX" = "1" /* Excision of Mesenteric Lymphatic, Percutaneous Approach, Diagnostic */
"07BB3ZZ" = "1" /* Excision of Mesenteric Lymphatic, Percutaneous Approach */
"07BB4ZX" = "1" /* Excision of Mesenteric Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07BB4ZZ" = "1" /* Excision of Mesenteric Lymphatic, Percutaneous Endoscopic Approach */
"07BC0ZX" = "1" /* Excision of Pelvis Lymphatic, Open Approach, Diagnostic */
"07BC0ZZ" = "1" /* Excision of Pelvis Lymphatic, Open Approach */
"07BC3ZX" = "1" /* Excision of Pelvis Lymphatic, Percutaneous Approach, Diagnostic */
"07BC3ZZ" = "1" /* Excision of Pelvis Lymphatic, Percutaneous Approach */
"07BC4ZX" = "1" /* Excision of Pelvis Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07BC4ZZ" = "1" /* Excision of Pelvis Lymphatic, Percutaneous Endoscopic Approach */
"07BD0ZX" = "1" /* Excision of Aortic Lymphatic, Open Approach, Diagnostic */
"07BD0ZZ" = "1" /* Excision of Aortic Lymphatic, Open Approach */
"07BD3ZX" = "1" /* Excision of Aortic Lymphatic, Percutaneous Approach, Diagnostic */
"07BD3ZZ" = "1" /* Excision of Aortic Lymphatic, Percutaneous Approach */
"07BD4ZX" = "1" /* Excision of Aortic Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07BD4ZZ" = "1" /* Excision of Aortic Lymphatic, Percutaneous Endoscopic Approach */
"07BF0ZX" = "1" /* Excision of Right Lower Extremity Lymphatic, Open Approach, Diagnostic */
"07BF0ZZ" = "1" /* Excision of Right Lower Extremity Lymphatic, Open Approach */
"07BF3ZX" = "1" /* Excision of Right Lower Extremity Lymphatic, Percutaneous Approach, Diagnostic */
"07BF3ZZ" = "1" /* Excision of Right Lower Extremity Lymphatic, Percutaneous Approach */
"07BF4ZX" = "1" /* Excision of Right Lower Extremity Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07BF4ZZ" = "1" /* Excision of Right Lower Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07BG0ZX" = "1" /* Excision of Left Lower Extremity Lymphatic, Open Approach, Diagnostic */
"07BG0ZZ" = "1" /* Excision of Left Lower Extremity Lymphatic, Open Approach */
"07BG3ZX" = "1" /* Excision of Left Lower Extremity Lymphatic, Percutaneous Approach, Diagnostic */
"07BG3ZZ" = "1" /* Excision of Left Lower Extremity Lymphatic, Percutaneous Approach */
"07BG4ZX" = "1" /* Excision of Left Lower Extremity Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07BG4ZZ" = "1" /* Excision of Left Lower Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07BH0ZX" = "1" /* Excision of Right Inguinal Lymphatic, Open Approach, Diagnostic */
"07BH0ZZ" = "1" /* Excision of Right Inguinal Lymphatic, Open Approach */
"07BH3ZX" = "1" /* Excision of Right Inguinal Lymphatic, Percutaneous Approach, Diagnostic */
"07BH3ZZ" = "1" /* Excision of Right Inguinal Lymphatic, Percutaneous Approach */
"07BH4ZX" = "1" /* Excision of Right Inguinal Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07BH4ZZ" = "1" /* Excision of Right Inguinal Lymphatic, Percutaneous Endoscopic Approach */
"07BJ0ZX" = "1" /* Excision of Left Inguinal Lymphatic, Open Approach, Diagnostic */
"07BJ0ZZ" = "1" /* Excision of Left Inguinal Lymphatic, Open Approach */
"07BJ3ZX" = "1" /* Excision of Left Inguinal Lymphatic, Percutaneous Approach, Diagnostic */
"07BJ3ZZ" = "1" /* Excision of Left Inguinal Lymphatic, Percutaneous Approach */
"07BJ4ZX" = "1" /* Excision of Left Inguinal Lymphatic, Percutaneous Endoscopic Approach, Diagnostic */
"07BJ4ZZ" = "1" /* Excision of Left Inguinal Lymphatic, Percutaneous Endoscopic Approach */
"07BK0ZX" = "1" /* Excision of Thoracic Duct, Open Approach, Diagnostic */
"07BK0ZZ" = "1" /* Excision of Thoracic Duct, Open Approach */
"07BK3ZX" = "1" /* Excision of Thoracic Duct, Percutaneous Approach, Diagnostic */
"07BK3ZZ" = "1" /* Excision of Thoracic Duct, Percutaneous Approach */
"07BK4ZX" = "1" /* Excision of Thoracic Duct, Percutaneous Endoscopic Approach, Diagnostic */
"07BK4ZZ" = "1" /* Excision of Thoracic Duct, Percutaneous Endoscopic Approach */
"07BL0ZX" = "1" /* Excision of Cisterna Chyli, Open Approach, Diagnostic */
"07BL0ZZ" = "1" /* Excision of Cisterna Chyli, Open Approach */
"07BL3ZX" = "1" /* Excision of Cisterna Chyli, Percutaneous Approach, Diagnostic */
"07BL3ZZ" = "1" /* Excision of Cisterna Chyli, Percutaneous Approach */
"07BL4ZX" = "1" /* Excision of Cisterna Chyli, Percutaneous Endoscopic Approach, Diagnostic */
"07BL4ZZ" = "1" /* Excision of Cisterna Chyli, Percutaneous Endoscopic Approach */
"07BM0ZX" = "1" /* Excision of Thymus, Open Approach, Diagnostic */
"07BM0ZZ" = "1" /* Excision of Thymus, Open Approach */
"07BM3ZX" = "1" /* Excision of Thymus, Percutaneous Approach, Diagnostic */
"07BM3ZZ" = "1" /* Excision of Thymus, Percutaneous Approach */
"07BM4ZX" = "1" /* Excision of Thymus, Percutaneous Endoscopic Approach, Diagnostic */
"07BM4ZZ" = "1" /* Excision of Thymus, Percutaneous Endoscopic Approach */
"07BP0ZX" = "1" /* Excision of Spleen, Open Approach, Diagnostic */
"07BP0ZZ" = "1" /* Excision of Spleen, Open Approach */
"07BP3ZZ" = "1" /* Excision of Spleen, Percutaneous Approach */
"07BP4ZZ" = "1" /* Excision of Spleen, Percutaneous Endoscopic Approach */
"07C00ZZ" = "1" /* Extirpation of Matter from Head Lymphatic, Open Approach */
"07C03ZZ" = "1" /* Extirpation of Matter from Head Lymphatic, Percutaneous Approach */
"07C04ZZ" = "1" /* Extirpation of Matter from Head Lymphatic, Percutaneous Endoscopic Approach */
"07C10ZZ" = "1" /* Extirpation of Matter from Right Neck Lymphatic, Open Approach */
"07C13ZZ" = "1" /* Extirpation of Matter from Right Neck Lymphatic, Percutaneous Approach */
"07C14ZZ" = "1" /* Extirpation of Matter from Right Neck Lymphatic, Percutaneous Endoscopic Approach */
"07C20ZZ" = "1" /* Extirpation of Matter from Left Neck Lymphatic, Open Approach */
"07C23ZZ" = "1" /* Extirpation of Matter from Left Neck Lymphatic, Percutaneous Approach */
"07C24ZZ" = "1" /* Extirpation of Matter from Left Neck Lymphatic, Percutaneous Endoscopic Approach */
"07C30ZZ" = "1" /* Extirpation of Matter from Right Upper Extremity Lymphatic, Open Approach */
"07C33ZZ" = "1" /* Extirpation of Matter from Right Upper Extremity Lymphatic, Percutaneous Approach */
"07C34ZZ" = "1" /* Extirpation of Matter from Right Upper Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07C40ZZ" = "1" /* Extirpation of Matter from Left Upper Extremity Lymphatic, Open Approach */
"07C43ZZ" = "1" /* Extirpation of Matter from Left Upper Extremity Lymphatic, Percutaneous Approach */
"07C44ZZ" = "1" /* Extirpation of Matter from Left Upper Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07C50ZZ" = "1" /* Extirpation of Matter from Right Axillary Lymphatic, Open Approach */
"07C53ZZ" = "1" /* Extirpation of Matter from Right Axillary Lymphatic, Percutaneous Approach */
"07C54ZZ" = "1" /* Extirpation of Matter from Right Axillary Lymphatic, Percutaneous Endoscopic Approach */
"07C60ZZ" = "1" /* Extirpation of Matter from Left Axillary Lymphatic, Open Approach */
"07C63ZZ" = "1" /* Extirpation of Matter from Left Axillary Lymphatic, Percutaneous Approach */
"07C64ZZ" = "1" /* Extirpation of Matter from Left Axillary Lymphatic, Percutaneous Endoscopic Approach */
"07C70ZZ" = "1" /* Extirpation of Matter from Thorax Lymphatic, Open Approach */
"07C73ZZ" = "1" /* Extirpation of Matter from Thorax Lymphatic, Percutaneous Approach */
"07C74ZZ" = "1" /* Extirpation of Matter from Thorax Lymphatic, Percutaneous Endoscopic Approach */
"07C80ZZ" = "1" /* Extirpation of Matter from Right Internal Mammary Lymphatic, Open Approach */
"07C83ZZ" = "1" /* Extirpation of Matter from Right Internal Mammary Lymphatic, Percutaneous Approach */
"07C84ZZ" = "1" /* Extirpation of Matter from Right Internal Mammary Lymphatic, Percutaneous Endoscopic Approach */
"07C90ZZ" = "1" /* Extirpation of Matter from Left Internal Mammary Lymphatic, Open Approach */
"07C93ZZ" = "1" /* Extirpation of Matter from Left Internal Mammary Lymphatic, Percutaneous Approach */
"07C94ZZ" = "1" /* Extirpation of Matter from Left Internal Mammary Lymphatic, Percutaneous Endoscopic Approach */
"07CB0ZZ" = "1" /* Extirpation of Matter from Mesenteric Lymphatic, Open Approach */
"07CB3ZZ" = "1" /* Extirpation of Matter from Mesenteric Lymphatic, Percutaneous Approach */
"07CB4ZZ" = "1" /* Extirpation of Matter from Mesenteric Lymphatic, Percutaneous Endoscopic Approach */
"07CC0ZZ" = "1" /* Extirpation of Matter from Pelvis Lymphatic, Open Approach */
"07CC3ZZ" = "1" /* Extirpation of Matter from Pelvis Lymphatic, Percutaneous Approach */
"07CC4ZZ" = "1" /* Extirpation of Matter from Pelvis Lymphatic, Percutaneous Endoscopic Approach */
"07CD0ZZ" = "1" /* Extirpation of Matter from Aortic Lymphatic, Open Approach */
"07CD3ZZ" = "1" /* Extirpation of Matter from Aortic Lymphatic, Percutaneous Approach */
"07CD4ZZ" = "1" /* Extirpation of Matter from Aortic Lymphatic, Percutaneous Endoscopic Approach */
"07CF0ZZ" = "1" /* Extirpation of Matter from Right Lower Extremity Lymphatic, Open Approach */
"07CF3ZZ" = "1" /* Extirpation of Matter from Right Lower Extremity Lymphatic, Percutaneous Approach */
"07CF4ZZ" = "1" /* Extirpation of Matter from Right Lower Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07CG0ZZ" = "1" /* Extirpation of Matter from Left Lower Extremity Lymphatic, Open Approach */
"07CG3ZZ" = "1" /* Extirpation of Matter from Left Lower Extremity Lymphatic, Percutaneous Approach */
"07CG4ZZ" = "1" /* Extirpation of Matter from Left Lower Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07CH0ZZ" = "1" /* Extirpation of Matter from Right Inguinal Lymphatic, Open Approach */
"07CH3ZZ" = "1" /* Extirpation of Matter from Right Inguinal Lymphatic, Percutaneous Approach */
"07CH4ZZ" = "1" /* Extirpation of Matter from Right Inguinal Lymphatic, Percutaneous Endoscopic Approach */
"07CJ0ZZ" = "1" /* Extirpation of Matter from Left Inguinal Lymphatic, Open Approach */
"07CJ3ZZ" = "1" /* Extirpation of Matter from Left Inguinal Lymphatic, Percutaneous Approach */
"07CJ4ZZ" = "1" /* Extirpation of Matter from Left Inguinal Lymphatic, Percutaneous Endoscopic Approach */
"07CK0ZZ" = "1" /* Extirpation of Matter from Thoracic Duct, Open Approach */
"07CK3ZZ" = "1" /* Extirpation of Matter from Thoracic Duct, Percutaneous Approach */
"07CK4ZZ" = "1" /* Extirpation of Matter from Thoracic Duct, Percutaneous Endoscopic Approach */
"07CL0ZZ" = "1" /* Extirpation of Matter from Cisterna Chyli, Open Approach */
"07CL3ZZ" = "1" /* Extirpation of Matter from Cisterna Chyli, Percutaneous Approach */
"07CL4ZZ" = "1" /* Extirpation of Matter from Cisterna Chyli, Percutaneous Endoscopic Approach */
"07CM0ZZ" = "1" /* Extirpation of Matter from Thymus, Open Approach */
"07CM3ZZ" = "1" /* Extirpation of Matter from Thymus, Percutaneous Approach */
"07CM4ZZ" = "1" /* Extirpation of Matter from Thymus, Percutaneous Endoscopic Approach */
"07CP0ZZ" = "1" /* Extirpation of Matter from Spleen, Open Approach */
"07JK0ZZ" = "1" /* Inspection of Thoracic Duct, Open Approach */
"07JK4ZZ" = "1" /* Inspection of Thoracic Duct, Percutaneous Endoscopic Approach */
"07JL0ZZ" = "1" /* Inspection of Cisterna Chyli, Open Approach */
"07JL4ZZ" = "1" /* Inspection of Cisterna Chyli, Percutaneous Endoscopic Approach */
"07JM0ZZ" = "1" /* Inspection of Thymus, Open Approach */
"07JM4ZZ" = "1" /* Inspection of Thymus, Percutaneous Endoscopic Approach */
"07JN0ZZ" = "1" /* Inspection of Lymphatic, Open Approach */
"07JN4ZZ" = "1" /* Inspection of Lymphatic, Percutaneous Endoscopic Approach */
"07JP0ZZ" = "1" /* Inspection of Spleen, Open Approach */
"07L00CZ" = "1" /* Occlusion of Head Lymphatic with Extraluminal Device, Open Approach */
"07L00DZ" = "1" /* Occlusion of Head Lymphatic with Intraluminal Device, Open Approach */
"07L00ZZ" = "1" /* Occlusion of Head Lymphatic, Open Approach */
"07L03CZ" = "1" /* Occlusion of Head Lymphatic with Extraluminal Device, Percutaneous Approach */
"07L03DZ" = "1" /* Occlusion of Head Lymphatic with Intraluminal Device, Percutaneous Approach */
"07L03ZZ" = "1" /* Occlusion of Head Lymphatic, Percutaneous Approach */
"07L04CZ" = "1" /* Occlusion of Head Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07L04DZ" = "1" /* Occlusion of Head Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07L04ZZ" = "1" /* Occlusion of Head Lymphatic, Percutaneous Endoscopic Approach */
"07L10CZ" = "1" /* Occlusion of Right Neck Lymphatic with Extraluminal Device, Open Approach */
"07L10DZ" = "1" /* Occlusion of Right Neck Lymphatic with Intraluminal Device, Open Approach */
"07L10ZZ" = "1" /* Occlusion of Right Neck Lymphatic, Open Approach */
"07L13CZ" = "1" /* Occlusion of Right Neck Lymphatic with Extraluminal Device, Percutaneous Approach */
"07L13DZ" = "1" /* Occlusion of Right Neck Lymphatic with Intraluminal Device, Percutaneous Approach */
"07L13ZZ" = "1" /* Occlusion of Right Neck Lymphatic, Percutaneous Approach */
"07L14CZ" = "1" /* Occlusion of Right Neck Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07L14DZ" = "1" /* Occlusion of Right Neck Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07L14ZZ" = "1" /* Occlusion of Right Neck Lymphatic, Percutaneous Endoscopic Approach */
"07L20CZ" = "1" /* Occlusion of Left Neck Lymphatic with Extraluminal Device, Open Approach */
"07L20DZ" = "1" /* Occlusion of Left Neck Lymphatic with Intraluminal Device, Open Approach */
"07L20ZZ" = "1" /* Occlusion of Left Neck Lymphatic, Open Approach */
"07L23CZ" = "1" /* Occlusion of Left Neck Lymphatic with Extraluminal Device, Percutaneous Approach */
"07L23DZ" = "1" /* Occlusion of Left Neck Lymphatic with Intraluminal Device, Percutaneous Approach */
"07L23ZZ" = "1" /* Occlusion of Left Neck Lymphatic, Percutaneous Approach */
"07L24CZ" = "1" /* Occlusion of Left Neck Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07L24DZ" = "1" /* Occlusion of Left Neck Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07L24ZZ" = "1" /* Occlusion of Left Neck Lymphatic, Percutaneous Endoscopic Approach */
"07L30CZ" = "1" /* Occlusion of Right Upper Extremity Lymphatic with Extraluminal Device, Open Approach */
"07L30DZ" = "1" /* Occlusion of Right Upper Extremity Lymphatic with Intraluminal Device, Open Approach */
"07L30ZZ" = "1" /* Occlusion of Right Upper Extremity Lymphatic, Open Approach */
"07L33CZ" = "1" /* Occlusion of Right Upper Extremity Lymphatic with Extraluminal Device, Percutaneous Approach */
"07L33DZ" = "1" /* Occlusion of Right Upper Extremity Lymphatic with Intraluminal Device, Percutaneous Approach */
"07L33ZZ" = "1" /* Occlusion of Right Upper Extremity Lymphatic, Percutaneous Approach */
"07L34CZ" = "1" /* Occlusion of Right Upper Extremity Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07L34DZ" = "1" /* Occlusion of Right Upper Extremity Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07L34ZZ" = "1" /* Occlusion of Right Upper Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07L40CZ" = "1" /* Occlusion of Left Upper Extremity Lymphatic with Extraluminal Device, Open Approach */
"07L40DZ" = "1" /* Occlusion of Left Upper Extremity Lymphatic with Intraluminal Device, Open Approach */
"07L40ZZ" = "1" /* Occlusion of Left Upper Extremity Lymphatic, Open Approach */
"07L43CZ" = "1" /* Occlusion of Left Upper Extremity Lymphatic with Extraluminal Device, Percutaneous Approach */
"07L43DZ" = "1" /* Occlusion of Left Upper Extremity Lymphatic with Intraluminal Device, Percutaneous Approach */
"07L43ZZ" = "1" /* Occlusion of Left Upper Extremity Lymphatic, Percutaneous Approach */
"07L44CZ" = "1" /* Occlusion of Left Upper Extremity Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07L44DZ" = "1" /* Occlusion of Left Upper Extremity Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07L44ZZ" = "1" /* Occlusion of Left Upper Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07L50CZ" = "1" /* Occlusion of Right Axillary Lymphatic with Extraluminal Device, Open Approach */
"07L50DZ" = "1" /* Occlusion of Right Axillary Lymphatic with Intraluminal Device, Open Approach */
"07L50ZZ" = "1" /* Occlusion of Right Axillary Lymphatic, Open Approach */
"07L53CZ" = "1" /* Occlusion of Right Axillary Lymphatic with Extraluminal Device, Percutaneous Approach */
"07L53DZ" = "1" /* Occlusion of Right Axillary Lymphatic with Intraluminal Device, Percutaneous Approach */
"07L53ZZ" = "1" /* Occlusion of Right Axillary Lymphatic, Percutaneous Approach */
"07L54CZ" = "1" /* Occlusion of Right Axillary Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07L54DZ" = "1" /* Occlusion of Right Axillary Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07L54ZZ" = "1" /* Occlusion of Right Axillary Lymphatic, Percutaneous Endoscopic Approach */
"07L60CZ" = "1" /* Occlusion of Left Axillary Lymphatic with Extraluminal Device, Open Approach */
"07L60DZ" = "1" /* Occlusion of Left Axillary Lymphatic with Intraluminal Device, Open Approach */
"07L60ZZ" = "1" /* Occlusion of Left Axillary Lymphatic, Open Approach */
"07L63CZ" = "1" /* Occlusion of Left Axillary Lymphatic with Extraluminal Device, Percutaneous Approach */
"07L63DZ" = "1" /* Occlusion of Left Axillary Lymphatic with Intraluminal Device, Percutaneous Approach */
"07L63ZZ" = "1" /* Occlusion of Left Axillary Lymphatic, Percutaneous Approach */
"07L64CZ" = "1" /* Occlusion of Left Axillary Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07L64DZ" = "1" /* Occlusion of Left Axillary Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07L64ZZ" = "1" /* Occlusion of Left Axillary Lymphatic, Percutaneous Endoscopic Approach */
"07L70CZ" = "1" /* Occlusion of Thorax Lymphatic with Extraluminal Device, Open Approach */
"07L70DZ" = "1" /* Occlusion of Thorax Lymphatic with Intraluminal Device, Open Approach */
"07L70ZZ" = "1" /* Occlusion of Thorax Lymphatic, Open Approach */
"07L73CZ" = "1" /* Occlusion of Thorax Lymphatic with Extraluminal Device, Percutaneous Approach */
"07L73DZ" = "1" /* Occlusion of Thorax Lymphatic with Intraluminal Device, Percutaneous Approach */
"07L73ZZ" = "1" /* Occlusion of Thorax Lymphatic, Percutaneous Approach */
"07L74CZ" = "1" /* Occlusion of Thorax Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07L74DZ" = "1" /* Occlusion of Thorax Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07L74ZZ" = "1" /* Occlusion of Thorax Lymphatic, Percutaneous Endoscopic Approach */
"07L80CZ" = "1" /* Occlusion of Right Internal Mammary Lymphatic with Extraluminal Device, Open Approach */
"07L80DZ" = "1" /* Occlusion of Right Internal Mammary Lymphatic with Intraluminal Device, Open Approach */
"07L80ZZ" = "1" /* Occlusion of Right Internal Mammary Lymphatic, Open Approach */
"07L83CZ" = "1" /* Occlusion of Right Internal Mammary Lymphatic with Extraluminal Device, Percutaneous Approach */
"07L83DZ" = "1" /* Occlusion of Right Internal Mammary Lymphatic with Intraluminal Device, Percutaneous Approach */
"07L83ZZ" = "1" /* Occlusion of Right Internal Mammary Lymphatic, Percutaneous Approach */
"07L84CZ" = "1" /* Occlusion of Right Internal Mammary Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07L84DZ" = "1" /* Occlusion of Right Internal Mammary Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07L84ZZ" = "1" /* Occlusion of Right Internal Mammary Lymphatic, Percutaneous Endoscopic Approach */
"07L90CZ" = "1" /* Occlusion of Left Internal Mammary Lymphatic with Extraluminal Device, Open Approach */
"07L90DZ" = "1" /* Occlusion of Left Internal Mammary Lymphatic with Intraluminal Device, Open Approach */
"07L90ZZ" = "1" /* Occlusion of Left Internal Mammary Lymphatic, Open Approach */
"07L93CZ" = "1" /* Occlusion of Left Internal Mammary Lymphatic with Extraluminal Device, Percutaneous Approach */
"07L93DZ" = "1" /* Occlusion of Left Internal Mammary Lymphatic with Intraluminal Device, Percutaneous Approach */
"07L93ZZ" = "1" /* Occlusion of Left Internal Mammary Lymphatic, Percutaneous Approach */
"07L94CZ" = "1" /* Occlusion of Left Internal Mammary Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07L94DZ" = "1" /* Occlusion of Left Internal Mammary Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07L94ZZ" = "1" /* Occlusion of Left Internal Mammary Lymphatic, Percutaneous Endoscopic Approach */
"07LB0CZ" = "1" /* Occlusion of Mesenteric Lymphatic with Extraluminal Device, Open Approach */
"07LB0DZ" = "1" /* Occlusion of Mesenteric Lymphatic with Intraluminal Device, Open Approach */
"07LB0ZZ" = "1" /* Occlusion of Mesenteric Lymphatic, Open Approach */
"07LB3CZ" = "1" /* Occlusion of Mesenteric Lymphatic with Extraluminal Device, Percutaneous Approach */
"07LB3DZ" = "1" /* Occlusion of Mesenteric Lymphatic with Intraluminal Device, Percutaneous Approach */
"07LB3ZZ" = "1" /* Occlusion of Mesenteric Lymphatic, Percutaneous Approach */
"07LB4CZ" = "1" /* Occlusion of Mesenteric Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07LB4DZ" = "1" /* Occlusion of Mesenteric Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07LB4ZZ" = "1" /* Occlusion of Mesenteric Lymphatic, Percutaneous Endoscopic Approach */
"07LC0CZ" = "1" /* Occlusion of Pelvis Lymphatic with Extraluminal Device, Open Approach */
"07LC0DZ" = "1" /* Occlusion of Pelvis Lymphatic with Intraluminal Device, Open Approach */
"07LC0ZZ" = "1" /* Occlusion of Pelvis Lymphatic, Open Approach */
"07LC3CZ" = "1" /* Occlusion of Pelvis Lymphatic with Extraluminal Device, Percutaneous Approach */
"07LC3DZ" = "1" /* Occlusion of Pelvis Lymphatic with Intraluminal Device, Percutaneous Approach */
"07LC3ZZ" = "1" /* Occlusion of Pelvis Lymphatic, Percutaneous Approach */
"07LC4CZ" = "1" /* Occlusion of Pelvis Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07LC4DZ" = "1" /* Occlusion of Pelvis Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07LC4ZZ" = "1" /* Occlusion of Pelvis Lymphatic, Percutaneous Endoscopic Approach */
"07LD0CZ" = "1" /* Occlusion of Aortic Lymphatic with Extraluminal Device, Open Approach */
"07LD0DZ" = "1" /* Occlusion of Aortic Lymphatic with Intraluminal Device, Open Approach */
"07LD0ZZ" = "1" /* Occlusion of Aortic Lymphatic, Open Approach */
"07LD3CZ" = "1" /* Occlusion of Aortic Lymphatic with Extraluminal Device, Percutaneous Approach */
"07LD3DZ" = "1" /* Occlusion of Aortic Lymphatic with Intraluminal Device, Percutaneous Approach */
"07LD3ZZ" = "1" /* Occlusion of Aortic Lymphatic, Percutaneous Approach */
"07LD4CZ" = "1" /* Occlusion of Aortic Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07LD4DZ" = "1" /* Occlusion of Aortic Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07LD4ZZ" = "1" /* Occlusion of Aortic Lymphatic, Percutaneous Endoscopic Approach */
"07LF0CZ" = "1" /* Occlusion of Right Lower Extremity Lymphatic with Extraluminal Device, Open Approach */
"07LF0DZ" = "1" /* Occlusion of Right Lower Extremity Lymphatic with Intraluminal Device, Open Approach */
"07LF0ZZ" = "1" /* Occlusion of Right Lower Extremity Lymphatic, Open Approach */
"07LF3CZ" = "1" /* Occlusion of Right Lower Extremity Lymphatic with Extraluminal Device, Percutaneous Approach */
"07LF3DZ" = "1" /* Occlusion of Right Lower Extremity Lymphatic with Intraluminal Device, Percutaneous Approach */
"07LF3ZZ" = "1" /* Occlusion of Right Lower Extremity Lymphatic, Percutaneous Approach */
"07LF4CZ" = "1" /* Occlusion of Right Lower Extremity Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07LF4DZ" = "1" /* Occlusion of Right Lower Extremity Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07LF4ZZ" = "1" /* Occlusion of Right Lower Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07LG0CZ" = "1" /* Occlusion of Left Lower Extremity Lymphatic with Extraluminal Device, Open Approach */
"07LG0DZ" = "1" /* Occlusion of Left Lower Extremity Lymphatic with Intraluminal Device, Open Approach */
"07LG0ZZ" = "1" /* Occlusion of Left Lower Extremity Lymphatic, Open Approach */
"07LG3CZ" = "1" /* Occlusion of Left Lower Extremity Lymphatic with Extraluminal Device, Percutaneous Approach */
"07LG3DZ" = "1" /* Occlusion of Left Lower Extremity Lymphatic with Intraluminal Device, Percutaneous Approach */
"07LG3ZZ" = "1" /* Occlusion of Left Lower Extremity Lymphatic, Percutaneous Approach */
"07LG4CZ" = "1" /* Occlusion of Left Lower Extremity Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07LG4DZ" = "1" /* Occlusion of Left Lower Extremity Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07LG4ZZ" = "1" /* Occlusion of Left Lower Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07LH0CZ" = "1" /* Occlusion of Right Inguinal Lymphatic with Extraluminal Device, Open Approach */
"07LH0DZ" = "1" /* Occlusion of Right Inguinal Lymphatic with Intraluminal Device, Open Approach */
"07LH0ZZ" = "1" /* Occlusion of Right Inguinal Lymphatic, Open Approach */
"07LH3CZ" = "1" /* Occlusion of Right Inguinal Lymphatic with Extraluminal Device, Percutaneous Approach */
"07LH3DZ" = "1" /* Occlusion of Right Inguinal Lymphatic with Intraluminal Device, Percutaneous Approach */
"07LH3ZZ" = "1" /* Occlusion of Right Inguinal Lymphatic, Percutaneous Approach */
"07LH4CZ" = "1" /* Occlusion of Right Inguinal Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07LH4DZ" = "1" /* Occlusion of Right Inguinal Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07LH4ZZ" = "1" /* Occlusion of Right Inguinal Lymphatic, Percutaneous Endoscopic Approach */
"07LJ0CZ" = "1" /* Occlusion of Left Inguinal Lymphatic with Extraluminal Device, Open Approach */
"07LJ0DZ" = "1" /* Occlusion of Left Inguinal Lymphatic with Intraluminal Device, Open Approach */
"07LJ0ZZ" = "1" /* Occlusion of Left Inguinal Lymphatic, Open Approach */
"07LJ3CZ" = "1" /* Occlusion of Left Inguinal Lymphatic with Extraluminal Device, Percutaneous Approach */
"07LJ3DZ" = "1" /* Occlusion of Left Inguinal Lymphatic with Intraluminal Device, Percutaneous Approach */
"07LJ3ZZ" = "1" /* Occlusion of Left Inguinal Lymphatic, Percutaneous Approach */
"07LJ4CZ" = "1" /* Occlusion of Left Inguinal Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07LJ4DZ" = "1" /* Occlusion of Left Inguinal Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07LJ4ZZ" = "1" /* Occlusion of Left Inguinal Lymphatic, Percutaneous Endoscopic Approach */
"07LK0CZ" = "1" /* Occlusion of Thoracic Duct with Extraluminal Device, Open Approach */
"07LK0DZ" = "1" /* Occlusion of Thoracic Duct with Intraluminal Device, Open Approach */
"07LK0ZZ" = "1" /* Occlusion of Thoracic Duct, Open Approach */
"07LK3CZ" = "1" /* Occlusion of Thoracic Duct with Extraluminal Device, Percutaneous Approach */
"07LK3DZ" = "1" /* Occlusion of Thoracic Duct with Intraluminal Device, Percutaneous Approach */
"07LK3ZZ" = "1" /* Occlusion of Thoracic Duct, Percutaneous Approach */
"07LK4CZ" = "1" /* Occlusion of Thoracic Duct with Extraluminal Device, Percutaneous Endoscopic Approach */
"07LK4DZ" = "1" /* Occlusion of Thoracic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"07LK4ZZ" = "1" /* Occlusion of Thoracic Duct, Percutaneous Endoscopic Approach */
"07LL0CZ" = "1" /* Occlusion of Cisterna Chyli with Extraluminal Device, Open Approach */
"07LL0DZ" = "1" /* Occlusion of Cisterna Chyli with Intraluminal Device, Open Approach */
"07LL0ZZ" = "1" /* Occlusion of Cisterna Chyli, Open Approach */
"07LL3CZ" = "1" /* Occlusion of Cisterna Chyli with Extraluminal Device, Percutaneous Approach */
"07LL3DZ" = "1" /* Occlusion of Cisterna Chyli with Intraluminal Device, Percutaneous Approach */
"07LL3ZZ" = "1" /* Occlusion of Cisterna Chyli, Percutaneous Approach */
"07LL4CZ" = "1" /* Occlusion of Cisterna Chyli with Extraluminal Device, Percutaneous Endoscopic Approach */
"07LL4DZ" = "1" /* Occlusion of Cisterna Chyli with Intraluminal Device, Percutaneous Endoscopic Approach */
"07LL4ZZ" = "1" /* Occlusion of Cisterna Chyli, Percutaneous Endoscopic Approach */
"07N00ZZ" = "1" /* Release Head Lymphatic, Open Approach */
"07N03ZZ" = "1" /* Release Head Lymphatic, Percutaneous Approach */
"07N04ZZ" = "1" /* Release Head Lymphatic, Percutaneous Endoscopic Approach */
"07N10ZZ" = "1" /* Release Right Neck Lymphatic, Open Approach */
"07N13ZZ" = "1" /* Release Right Neck Lymphatic, Percutaneous Approach */
"07N14ZZ" = "1" /* Release Right Neck Lymphatic, Percutaneous Endoscopic Approach */
"07N20ZZ" = "1" /* Release Left Neck Lymphatic, Open Approach */
"07N23ZZ" = "1" /* Release Left Neck Lymphatic, Percutaneous Approach */
"07N24ZZ" = "1" /* Release Left Neck Lymphatic, Percutaneous Endoscopic Approach */
"07N30ZZ" = "1" /* Release Right Upper Extremity Lymphatic, Open Approach */
"07N33ZZ" = "1" /* Release Right Upper Extremity Lymphatic, Percutaneous Approach */
"07N34ZZ" = "1" /* Release Right Upper Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07N40ZZ" = "1" /* Release Left Upper Extremity Lymphatic, Open Approach */
"07N43ZZ" = "1" /* Release Left Upper Extremity Lymphatic, Percutaneous Approach */
"07N44ZZ" = "1" /* Release Left Upper Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07N50ZZ" = "1" /* Release Right Axillary Lymphatic, Open Approach */
"07N53ZZ" = "1" /* Release Right Axillary Lymphatic, Percutaneous Approach */
"07N54ZZ" = "1" /* Release Right Axillary Lymphatic, Percutaneous Endoscopic Approach */
"07N60ZZ" = "1" /* Release Left Axillary Lymphatic, Open Approach */
"07N63ZZ" = "1" /* Release Left Axillary Lymphatic, Percutaneous Approach */
"07N64ZZ" = "1" /* Release Left Axillary Lymphatic, Percutaneous Endoscopic Approach */
"07N70ZZ" = "1" /* Release Thorax Lymphatic, Open Approach */
"07N73ZZ" = "1" /* Release Thorax Lymphatic, Percutaneous Approach */
"07N74ZZ" = "1" /* Release Thorax Lymphatic, Percutaneous Endoscopic Approach */
"07N80ZZ" = "1" /* Release Right Internal Mammary Lymphatic, Open Approach */
"07N83ZZ" = "1" /* Release Right Internal Mammary Lymphatic, Percutaneous Approach */
"07N84ZZ" = "1" /* Release Right Internal Mammary Lymphatic, Percutaneous Endoscopic Approach */
"07N90ZZ" = "1" /* Release Left Internal Mammary Lymphatic, Open Approach */
"07N93ZZ" = "1" /* Release Left Internal Mammary Lymphatic, Percutaneous Approach */
"07N94ZZ" = "1" /* Release Left Internal Mammary Lymphatic, Percutaneous Endoscopic Approach */
"07NB0ZZ" = "1" /* Release Mesenteric Lymphatic, Open Approach */
"07NB3ZZ" = "1" /* Release Mesenteric Lymphatic, Percutaneous Approach */
"07NB4ZZ" = "1" /* Release Mesenteric Lymphatic, Percutaneous Endoscopic Approach */
"07NC0ZZ" = "1" /* Release Pelvis Lymphatic, Open Approach */
"07NC3ZZ" = "1" /* Release Pelvis Lymphatic, Percutaneous Approach */
"07NC4ZZ" = "1" /* Release Pelvis Lymphatic, Percutaneous Endoscopic Approach */
"07ND0ZZ" = "1" /* Release Aortic Lymphatic, Open Approach */
"07ND3ZZ" = "1" /* Release Aortic Lymphatic, Percutaneous Approach */
"07ND4ZZ" = "1" /* Release Aortic Lymphatic, Percutaneous Endoscopic Approach */
"07NF0ZZ" = "1" /* Release Right Lower Extremity Lymphatic, Open Approach */
"07NF3ZZ" = "1" /* Release Right Lower Extremity Lymphatic, Percutaneous Approach */
"07NF4ZZ" = "1" /* Release Right Lower Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07NG0ZZ" = "1" /* Release Left Lower Extremity Lymphatic, Open Approach */
"07NG3ZZ" = "1" /* Release Left Lower Extremity Lymphatic, Percutaneous Approach */
"07NG4ZZ" = "1" /* Release Left Lower Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07NH0ZZ" = "1" /* Release Right Inguinal Lymphatic, Open Approach */
"07NH3ZZ" = "1" /* Release Right Inguinal Lymphatic, Percutaneous Approach */
"07NH4ZZ" = "1" /* Release Right Inguinal Lymphatic, Percutaneous Endoscopic Approach */
"07NJ0ZZ" = "1" /* Release Left Inguinal Lymphatic, Open Approach */
"07NJ3ZZ" = "1" /* Release Left Inguinal Lymphatic, Percutaneous Approach */
"07NJ4ZZ" = "1" /* Release Left Inguinal Lymphatic, Percutaneous Endoscopic Approach */
"07NK0ZZ" = "1" /* Release Thoracic Duct, Open Approach */
"07NK3ZZ" = "1" /* Release Thoracic Duct, Percutaneous Approach */
"07NK4ZZ" = "1" /* Release Thoracic Duct, Percutaneous Endoscopic Approach */
"07NL0ZZ" = "1" /* Release Cisterna Chyli, Open Approach */
"07NL3ZZ" = "1" /* Release Cisterna Chyli, Percutaneous Approach */
"07NL4ZZ" = "1" /* Release Cisterna Chyli, Percutaneous Endoscopic Approach */
"07NM0ZZ" = "1" /* Release Thymus, Open Approach */
"07NM3ZZ" = "1" /* Release Thymus, Percutaneous Approach */
"07NM4ZZ" = "1" /* Release Thymus, Percutaneous Endoscopic Approach */
"07NP0ZZ" = "1" /* Release Spleen, Open Approach */
"07NP3ZZ" = "1" /* Release Spleen, Percutaneous Approach */
"07NP4ZZ" = "1" /* Release Spleen, Percutaneous Endoscopic Approach */
"07PK00Z" = "1" /* Removal of Drainage Device from Thoracic Duct, Open Approach */
"07PK03Z" = "1" /* Removal of Infusion Device from Thoracic Duct, Open Approach */
"07PK07Z" = "1" /* Removal of Autologous Tissue Substitute from Thoracic Duct, Open Approach */
"07PK0CZ" = "1" /* Removal of Extraluminal Device from Thoracic Duct, Open Approach */
"07PK0DZ" = "1" /* Removal of Intraluminal Device from Thoracic Duct, Open Approach */
"07PK0JZ" = "1" /* Removal of Synthetic Substitute from Thoracic Duct, Open Approach */
"07PK0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Thoracic Duct, Open Approach */
"07PK30Z" = "1" /* Removal of Drainage Device from Thoracic Duct, Percutaneous Approach */
"07PK33Z" = "1" /* Removal of Infusion Device from Thoracic Duct, Percutaneous Approach */
"07PK37Z" = "1" /* Removal of Autologous Tissue Substitute from Thoracic Duct, Percutaneous Approach */
"07PK3CZ" = "1" /* Removal of Extraluminal Device from Thoracic Duct, Percutaneous Approach */
"07PK3DZ" = "1" /* Removal of Intraluminal Device from Thoracic Duct, Percutaneous Approach */
"07PK3JZ" = "1" /* Removal of Synthetic Substitute from Thoracic Duct, Percutaneous Approach */
"07PK3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Thoracic Duct, Percutaneous Approach */
"07PK40Z" = "1" /* Removal of Drainage Device from Thoracic Duct, Percutaneous Endoscopic Approach */
"07PK43Z" = "1" /* Removal of Infusion Device from Thoracic Duct, Percutaneous Endoscopic Approach */
"07PK47Z" = "1" /* Removal of Autologous Tissue Substitute from Thoracic Duct, Percutaneous Endoscopic Approach */
"07PK4CZ" = "1" /* Removal of Extraluminal Device from Thoracic Duct, Percutaneous Endoscopic Approach */
"07PK4DZ" = "1" /* Removal of Intraluminal Device from Thoracic Duct, Percutaneous Endoscopic Approach */
"07PK4JZ" = "1" /* Removal of Synthetic Substitute from Thoracic Duct, Percutaneous Endoscopic Approach */
"07PK4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Thoracic Duct, Percutaneous Endoscopic Approach */
"07PL00Z" = "1" /* Removal of Drainage Device from Cisterna Chyli, Open Approach */
"07PL03Z" = "1" /* Removal of Infusion Device from Cisterna Chyli, Open Approach */
"07PL07Z" = "1" /* Removal of Autologous Tissue Substitute from Cisterna Chyli, Open Approach */
"07PL0CZ" = "1" /* Removal of Extraluminal Device from Cisterna Chyli, Open Approach */
"07PL0DZ" = "1" /* Removal of Intraluminal Device from Cisterna Chyli, Open Approach */
"07PL0JZ" = "1" /* Removal of Synthetic Substitute from Cisterna Chyli, Open Approach */
"07PL0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Cisterna Chyli, Open Approach */
"07PL30Z" = "1" /* Removal of Drainage Device from Cisterna Chyli, Percutaneous Approach */
"07PL33Z" = "1" /* Removal of Infusion Device from Cisterna Chyli, Percutaneous Approach */
"07PL37Z" = "1" /* Removal of Autologous Tissue Substitute from Cisterna Chyli, Percutaneous Approach */
"07PL3CZ" = "1" /* Removal of Extraluminal Device from Cisterna Chyli, Percutaneous Approach */
"07PL3DZ" = "1" /* Removal of Intraluminal Device from Cisterna Chyli, Percutaneous Approach */
"07PL3JZ" = "1" /* Removal of Synthetic Substitute from Cisterna Chyli, Percutaneous Approach */
"07PL3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Cisterna Chyli, Percutaneous Approach */
"07PL40Z" = "1" /* Removal of Drainage Device from Cisterna Chyli, Percutaneous Endoscopic Approach */
"07PL43Z" = "1" /* Removal of Infusion Device from Cisterna Chyli, Percutaneous Endoscopic Approach */
"07PL47Z" = "1" /* Removal of Autologous Tissue Substitute from Cisterna Chyli, Percutaneous Endoscopic Approach */
"07PL4CZ" = "1" /* Removal of Extraluminal Device from Cisterna Chyli, Percutaneous Endoscopic Approach */
"07PL4DZ" = "1" /* Removal of Intraluminal Device from Cisterna Chyli, Percutaneous Endoscopic Approach */
"07PL4JZ" = "1" /* Removal of Synthetic Substitute from Cisterna Chyli, Percutaneous Endoscopic Approach */
"07PL4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Cisterna Chyli, Percutaneous Endoscopic Approach */
"07PM00Z" = "1" /* Removal of Drainage Device from Thymus, Open Approach */
"07PM03Z" = "1" /* Removal of Infusion Device from Thymus, Open Approach */
"07PM30Z" = "1" /* Removal of Drainage Device from Thymus, Percutaneous Approach */
"07PM33Z" = "1" /* Removal of Infusion Device from Thymus, Percutaneous Approach */
"07PM40Z" = "1" /* Removal of Drainage Device from Thymus, Percutaneous Endoscopic Approach */
"07PM43Z" = "1" /* Removal of Infusion Device from Thymus, Percutaneous Endoscopic Approach */
"07PN00Z" = "1" /* Removal of Drainage Device from Lymphatic, Open Approach */
"07PN03Z" = "1" /* Removal of Infusion Device from Lymphatic, Open Approach */
"07PN07Z" = "1" /* Removal of Autologous Tissue Substitute from Lymphatic, Open Approach */
"07PN0CZ" = "1" /* Removal of Extraluminal Device from Lymphatic, Open Approach */
"07PN0DZ" = "1" /* Removal of Intraluminal Device from Lymphatic, Open Approach */
"07PN0JZ" = "1" /* Removal of Synthetic Substitute from Lymphatic, Open Approach */
"07PN0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lymphatic, Open Approach */
"07PN30Z" = "1" /* Removal of Drainage Device from Lymphatic, Percutaneous Approach */
"07PN33Z" = "1" /* Removal of Infusion Device from Lymphatic, Percutaneous Approach */
"07PN37Z" = "1" /* Removal of Autologous Tissue Substitute from Lymphatic, Percutaneous Approach */
"07PN3CZ" = "1" /* Removal of Extraluminal Device from Lymphatic, Percutaneous Approach */
"07PN3DZ" = "1" /* Removal of Intraluminal Device from Lymphatic, Percutaneous Approach */
"07PN3JZ" = "1" /* Removal of Synthetic Substitute from Lymphatic, Percutaneous Approach */
"07PN3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lymphatic, Percutaneous Approach */
"07PN40Z" = "1" /* Removal of Drainage Device from Lymphatic, Percutaneous Endoscopic Approach */
"07PN43Z" = "1" /* Removal of Infusion Device from Lymphatic, Percutaneous Endoscopic Approach */
"07PN47Z" = "1" /* Removal of Autologous Tissue Substitute from Lymphatic, Percutaneous Endoscopic Approach */
"07PN4CZ" = "1" /* Removal of Extraluminal Device from Lymphatic, Percutaneous Endoscopic Approach */
"07PN4DZ" = "1" /* Removal of Intraluminal Device from Lymphatic, Percutaneous Endoscopic Approach */
"07PN4JZ" = "1" /* Removal of Synthetic Substitute from Lymphatic, Percutaneous Endoscopic Approach */
"07PN4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lymphatic, Percutaneous Endoscopic Approach */
"07PP00Z" = "1" /* Removal of Drainage Device from Spleen, Open Approach */
"07PP03Z" = "1" /* Removal of Infusion Device from Spleen, Open Approach */
"07PP30Z" = "1" /* Removal of Drainage Device from Spleen, Percutaneous Approach */
"07PP33Z" = "1" /* Removal of Infusion Device from Spleen, Percutaneous Approach */
"07PP40Z" = "1" /* Removal of Drainage Device from Spleen, Percutaneous Endoscopic Approach */
"07PP43Z" = "1" /* Removal of Infusion Device from Spleen, Percutaneous Endoscopic Approach */
"07Q00ZZ" = "1" /* Repair Head Lymphatic, Open Approach */
"07Q03ZZ" = "1" /* Repair Head Lymphatic, Percutaneous Approach */
"07Q04ZZ" = "1" /* Repair Head Lymphatic, Percutaneous Endoscopic Approach */
"07Q10ZZ" = "1" /* Repair Right Neck Lymphatic, Open Approach */
"07Q13ZZ" = "1" /* Repair Right Neck Lymphatic, Percutaneous Approach */
"07Q14ZZ" = "1" /* Repair Right Neck Lymphatic, Percutaneous Endoscopic Approach */
"07Q20ZZ" = "1" /* Repair Left Neck Lymphatic, Open Approach */
"07Q23ZZ" = "1" /* Repair Left Neck Lymphatic, Percutaneous Approach */
"07Q24ZZ" = "1" /* Repair Left Neck Lymphatic, Percutaneous Endoscopic Approach */
"07Q30ZZ" = "1" /* Repair Right Upper Extremity Lymphatic, Open Approach */
"07Q33ZZ" = "1" /* Repair Right Upper Extremity Lymphatic, Percutaneous Approach */
"07Q34ZZ" = "1" /* Repair Right Upper Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07Q40ZZ" = "1" /* Repair Left Upper Extremity Lymphatic, Open Approach */
"07Q43ZZ" = "1" /* Repair Left Upper Extremity Lymphatic, Percutaneous Approach */
"07Q44ZZ" = "1" /* Repair Left Upper Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07Q50ZZ" = "1" /* Repair Right Axillary Lymphatic, Open Approach */
"07Q53ZZ" = "1" /* Repair Right Axillary Lymphatic, Percutaneous Approach */
"07Q54ZZ" = "1" /* Repair Right Axillary Lymphatic, Percutaneous Endoscopic Approach */
"07Q60ZZ" = "1" /* Repair Left Axillary Lymphatic, Open Approach */
"07Q63ZZ" = "1" /* Repair Left Axillary Lymphatic, Percutaneous Approach */
"07Q64ZZ" = "1" /* Repair Left Axillary Lymphatic, Percutaneous Endoscopic Approach */
"07Q70ZZ" = "1" /* Repair Thorax Lymphatic, Open Approach */
"07Q73ZZ" = "1" /* Repair Thorax Lymphatic, Percutaneous Approach */
"07Q74ZZ" = "1" /* Repair Thorax Lymphatic, Percutaneous Endoscopic Approach */
"07Q80ZZ" = "1" /* Repair Right Internal Mammary Lymphatic, Open Approach */
"07Q83ZZ" = "1" /* Repair Right Internal Mammary Lymphatic, Percutaneous Approach */
"07Q84ZZ" = "1" /* Repair Right Internal Mammary Lymphatic, Percutaneous Endoscopic Approach */
"07Q90ZZ" = "1" /* Repair Left Internal Mammary Lymphatic, Open Approach */
"07Q93ZZ" = "1" /* Repair Left Internal Mammary Lymphatic, Percutaneous Approach */
"07Q94ZZ" = "1" /* Repair Left Internal Mammary Lymphatic, Percutaneous Endoscopic Approach */
"07QB0ZZ" = "1" /* Repair Mesenteric Lymphatic, Open Approach */
"07QB3ZZ" = "1" /* Repair Mesenteric Lymphatic, Percutaneous Approach */
"07QB4ZZ" = "1" /* Repair Mesenteric Lymphatic, Percutaneous Endoscopic Approach */
"07QC0ZZ" = "1" /* Repair Pelvis Lymphatic, Open Approach */
"07QC3ZZ" = "1" /* Repair Pelvis Lymphatic, Percutaneous Approach */
"07QC4ZZ" = "1" /* Repair Pelvis Lymphatic, Percutaneous Endoscopic Approach */
"07QD0ZZ" = "1" /* Repair Aortic Lymphatic, Open Approach */
"07QD3ZZ" = "1" /* Repair Aortic Lymphatic, Percutaneous Approach */
"07QD4ZZ" = "1" /* Repair Aortic Lymphatic, Percutaneous Endoscopic Approach */
"07QF0ZZ" = "1" /* Repair Right Lower Extremity Lymphatic, Open Approach */
"07QF3ZZ" = "1" /* Repair Right Lower Extremity Lymphatic, Percutaneous Approach */
"07QF4ZZ" = "1" /* Repair Right Lower Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07QG0ZZ" = "1" /* Repair Left Lower Extremity Lymphatic, Open Approach */
"07QG3ZZ" = "1" /* Repair Left Lower Extremity Lymphatic, Percutaneous Approach */
"07QG4ZZ" = "1" /* Repair Left Lower Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07QH0ZZ" = "1" /* Repair Right Inguinal Lymphatic, Open Approach */
"07QH3ZZ" = "1" /* Repair Right Inguinal Lymphatic, Percutaneous Approach */
"07QH4ZZ" = "1" /* Repair Right Inguinal Lymphatic, Percutaneous Endoscopic Approach */
"07QJ0ZZ" = "1" /* Repair Left Inguinal Lymphatic, Open Approach */
"07QJ3ZZ" = "1" /* Repair Left Inguinal Lymphatic, Percutaneous Approach */
"07QJ4ZZ" = "1" /* Repair Left Inguinal Lymphatic, Percutaneous Endoscopic Approach */
"07QK0ZZ" = "1" /* Repair Thoracic Duct, Open Approach */
"07QK3ZZ" = "1" /* Repair Thoracic Duct, Percutaneous Approach */
"07QK4ZZ" = "1" /* Repair Thoracic Duct, Percutaneous Endoscopic Approach */
"07QL0ZZ" = "1" /* Repair Cisterna Chyli, Open Approach */
"07QL3ZZ" = "1" /* Repair Cisterna Chyli, Percutaneous Approach */
"07QL4ZZ" = "1" /* Repair Cisterna Chyli, Percutaneous Endoscopic Approach */
"07QM0ZZ" = "1" /* Repair Thymus, Open Approach */
"07QM3ZZ" = "1" /* Repair Thymus, Percutaneous Approach */
"07QM4ZZ" = "1" /* Repair Thymus, Percutaneous Endoscopic Approach */
"07QP0ZZ" = "1" /* Repair Spleen, Open Approach */
"07QP3ZZ" = "1" /* Repair Spleen, Percutaneous Approach */
"07QP4ZZ" = "1" /* Repair Spleen, Percutaneous Endoscopic Approach */
"07SM0ZZ" = "1" /* Reposition Thymus, Open Approach */
"07SP0ZZ" = "1" /* Reposition Spleen, Open Approach */
"07T00ZZ" = "1" /* Resection of Head Lymphatic, Open Approach */
"07T04ZZ" = "1" /* Resection of Head Lymphatic, Percutaneous Endoscopic Approach */
"07T10ZZ" = "1" /* Resection of Right Neck Lymphatic, Open Approach */
"07T14ZZ" = "1" /* Resection of Right Neck Lymphatic, Percutaneous Endoscopic Approach */
"07T20ZZ" = "1" /* Resection of Left Neck Lymphatic, Open Approach */
"07T24ZZ" = "1" /* Resection of Left Neck Lymphatic, Percutaneous Endoscopic Approach */
"07T30ZZ" = "1" /* Resection of Right Upper Extremity Lymphatic, Open Approach */
"07T34ZZ" = "1" /* Resection of Right Upper Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07T40ZZ" = "1" /* Resection of Left Upper Extremity Lymphatic, Open Approach */
"07T44ZZ" = "1" /* Resection of Left Upper Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07T50ZZ" = "1" /* Resection of Right Axillary Lymphatic, Open Approach */
"07T54ZZ" = "1" /* Resection of Right Axillary Lymphatic, Percutaneous Endoscopic Approach */
"07T60ZZ" = "1" /* Resection of Left Axillary Lymphatic, Open Approach */
"07T64ZZ" = "1" /* Resection of Left Axillary Lymphatic, Percutaneous Endoscopic Approach */
"07T70ZZ" = "1" /* Resection of Thorax Lymphatic, Open Approach */
"07T74ZZ" = "1" /* Resection of Thorax Lymphatic, Percutaneous Endoscopic Approach */
"07T80ZZ" = "1" /* Resection of Right Internal Mammary Lymphatic, Open Approach */
"07T84ZZ" = "1" /* Resection of Right Internal Mammary Lymphatic, Percutaneous Endoscopic Approach */
"07T90ZZ" = "1" /* Resection of Left Internal Mammary Lymphatic, Open Approach */
"07T94ZZ" = "1" /* Resection of Left Internal Mammary Lymphatic, Percutaneous Endoscopic Approach */
"07TB0ZZ" = "1" /* Resection of Mesenteric Lymphatic, Open Approach */
"07TB4ZZ" = "1" /* Resection of Mesenteric Lymphatic, Percutaneous Endoscopic Approach */
"07TC0ZZ" = "1" /* Resection of Pelvis Lymphatic, Open Approach */
"07TC4ZZ" = "1" /* Resection of Pelvis Lymphatic, Percutaneous Endoscopic Approach */
"07TD0ZZ" = "1" /* Resection of Aortic Lymphatic, Open Approach */
"07TD4ZZ" = "1" /* Resection of Aortic Lymphatic, Percutaneous Endoscopic Approach */
"07TF0ZZ" = "1" /* Resection of Right Lower Extremity Lymphatic, Open Approach */
"07TF4ZZ" = "1" /* Resection of Right Lower Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07TG0ZZ" = "1" /* Resection of Left Lower Extremity Lymphatic, Open Approach */
"07TG4ZZ" = "1" /* Resection of Left Lower Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07TH0ZZ" = "1" /* Resection of Right Inguinal Lymphatic, Open Approach */
"07TH4ZZ" = "1" /* Resection of Right Inguinal Lymphatic, Percutaneous Endoscopic Approach */
"07TJ0ZZ" = "1" /* Resection of Left Inguinal Lymphatic, Open Approach */
"07TJ4ZZ" = "1" /* Resection of Left Inguinal Lymphatic, Percutaneous Endoscopic Approach */
"07TK0ZZ" = "1" /* Resection of Thoracic Duct, Open Approach */
"07TK4ZZ" = "1" /* Resection of Thoracic Duct, Percutaneous Endoscopic Approach */
"07TL0ZZ" = "1" /* Resection of Cisterna Chyli, Open Approach */
"07TL4ZZ" = "1" /* Resection of Cisterna Chyli, Percutaneous Endoscopic Approach */
"07TM0ZZ" = "1" /* Resection of Thymus, Open Approach */
"07TM4ZZ" = "1" /* Resection of Thymus, Percutaneous Endoscopic Approach */
"07TP0ZZ" = "1" /* Resection of Spleen, Open Approach */
"07TP4ZZ" = "1" /* Resection of Spleen, Percutaneous Endoscopic Approach */
"07U007Z" = "1" /* Supplement Head Lymphatic with Autologous Tissue Substitute, Open Approach */
"07U00JZ" = "1" /* Supplement Head Lymphatic with Synthetic Substitute, Open Approach */
"07U00KZ" = "1" /* Supplement Head Lymphatic with Nonautologous Tissue Substitute, Open Approach */
"07U047Z" = "1" /* Supplement Head Lymphatic with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07U04JZ" = "1" /* Supplement Head Lymphatic with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07U04KZ" = "1" /* Supplement Head Lymphatic with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07U107Z" = "1" /* Supplement Right Neck Lymphatic with Autologous Tissue Substitute, Open Approach */
"07U10JZ" = "1" /* Supplement Right Neck Lymphatic with Synthetic Substitute, Open Approach */
"07U10KZ" = "1" /* Supplement Right Neck Lymphatic with Nonautologous Tissue Substitute, Open Approach */
"07U147Z" = "1" /* Supplement Right Neck Lymphatic with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07U14JZ" = "1" /* Supplement Right Neck Lymphatic with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07U14KZ" = "1" /* Supplement Right Neck Lymphatic with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07U207Z" = "1" /* Supplement Left Neck Lymphatic with Autologous Tissue Substitute, Open Approach */
"07U20JZ" = "1" /* Supplement Left Neck Lymphatic with Synthetic Substitute, Open Approach */
"07U20KZ" = "1" /* Supplement Left Neck Lymphatic with Nonautologous Tissue Substitute, Open Approach */
"07U247Z" = "1" /* Supplement Left Neck Lymphatic with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07U24JZ" = "1" /* Supplement Left Neck Lymphatic with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07U24KZ" = "1" /* Supplement Left Neck Lymphatic with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07U307Z" = "1" /* Supplement Right Upper Extremity Lymphatic with Autologous Tissue Substitute, Open Approach */
"07U30JZ" = "1" /* Supplement Right Upper Extremity Lymphatic with Synthetic Substitute, Open Approach */
"07U30KZ" = "1" /* Supplement Right Upper Extremity Lymphatic with Nonautologous Tissue Substitute, Open Approach */
"07U347Z" = "1" /* Supplement Right Upper Extremity Lymphatic with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07U34JZ" = "1" /* Supplement Right Upper Extremity Lymphatic with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07U34KZ" = "1" /* Supplement Right Upper Extremity Lymphatic with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07U407Z" = "1" /* Supplement Left Upper Extremity Lymphatic with Autologous Tissue Substitute, Open Approach */
"07U40JZ" = "1" /* Supplement Left Upper Extremity Lymphatic with Synthetic Substitute, Open Approach */
"07U40KZ" = "1" /* Supplement Left Upper Extremity Lymphatic with Nonautologous Tissue Substitute, Open Approach */
"07U447Z" = "1" /* Supplement Left Upper Extremity Lymphatic with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07U44JZ" = "1" /* Supplement Left Upper Extremity Lymphatic with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07U44KZ" = "1" /* Supplement Left Upper Extremity Lymphatic with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07U507Z" = "1" /* Supplement Right Axillary Lymphatic with Autologous Tissue Substitute, Open Approach */
"07U50JZ" = "1" /* Supplement Right Axillary Lymphatic with Synthetic Substitute, Open Approach */
"07U50KZ" = "1" /* Supplement Right Axillary Lymphatic with Nonautologous Tissue Substitute, Open Approach */
"07U547Z" = "1" /* Supplement Right Axillary Lymphatic with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07U54JZ" = "1" /* Supplement Right Axillary Lymphatic with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07U54KZ" = "1" /* Supplement Right Axillary Lymphatic with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07U607Z" = "1" /* Supplement Left Axillary Lymphatic with Autologous Tissue Substitute, Open Approach */
"07U60JZ" = "1" /* Supplement Left Axillary Lymphatic with Synthetic Substitute, Open Approach */
"07U60KZ" = "1" /* Supplement Left Axillary Lymphatic with Nonautologous Tissue Substitute, Open Approach */
"07U647Z" = "1" /* Supplement Left Axillary Lymphatic with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07U64JZ" = "1" /* Supplement Left Axillary Lymphatic with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07U64KZ" = "1" /* Supplement Left Axillary Lymphatic with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07U707Z" = "1" /* Supplement Thorax Lymphatic with Autologous Tissue Substitute, Open Approach */
"07U70JZ" = "1" /* Supplement Thorax Lymphatic with Synthetic Substitute, Open Approach */
"07U70KZ" = "1" /* Supplement Thorax Lymphatic with Nonautologous Tissue Substitute, Open Approach */
"07U747Z" = "1" /* Supplement Thorax Lymphatic with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07U74JZ" = "1" /* Supplement Thorax Lymphatic with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07U74KZ" = "1" /* Supplement Thorax Lymphatic with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07U807Z" = "1" /* Supplement Right Internal Mammary Lymphatic with Autologous Tissue Substitute, Open Approach */
"07U80JZ" = "1" /* Supplement Right Internal Mammary Lymphatic with Synthetic Substitute, Open Approach */
"07U80KZ" = "1" /* Supplement Right Internal Mammary Lymphatic with Nonautologous Tissue Substitute, Open Approach */
"07U847Z" = "1" /* Supplement Right Internal Mammary Lymphatic with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07U84JZ" = "1" /* Supplement Right Internal Mammary Lymphatic with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07U84KZ" = "1" /* Supplement Right Internal Mammary Lymphatic with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07U907Z" = "1" /* Supplement Left Internal Mammary Lymphatic with Autologous Tissue Substitute, Open Approach */
"07U90JZ" = "1" /* Supplement Left Internal Mammary Lymphatic with Synthetic Substitute, Open Approach */
"07U90KZ" = "1" /* Supplement Left Internal Mammary Lymphatic with Nonautologous Tissue Substitute, Open Approach */
"07U947Z" = "1" /* Supplement Left Internal Mammary Lymphatic with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07U94JZ" = "1" /* Supplement Left Internal Mammary Lymphatic with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07U94KZ" = "1" /* Supplement Left Internal Mammary Lymphatic with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UB07Z" = "1" /* Supplement Mesenteric Lymphatic with Autologous Tissue Substitute, Open Approach */
"07UB0JZ" = "1" /* Supplement Mesenteric Lymphatic with Synthetic Substitute, Open Approach */
"07UB0KZ" = "1" /* Supplement Mesenteric Lymphatic with Nonautologous Tissue Substitute, Open Approach */
"07UB47Z" = "1" /* Supplement Mesenteric Lymphatic with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UB4JZ" = "1" /* Supplement Mesenteric Lymphatic with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07UB4KZ" = "1" /* Supplement Mesenteric Lymphatic with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UC07Z" = "1" /* Supplement Pelvis Lymphatic with Autologous Tissue Substitute, Open Approach */
"07UC0JZ" = "1" /* Supplement Pelvis Lymphatic with Synthetic Substitute, Open Approach */
"07UC0KZ" = "1" /* Supplement Pelvis Lymphatic with Nonautologous Tissue Substitute, Open Approach */
"07UC47Z" = "1" /* Supplement Pelvis Lymphatic with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UC4JZ" = "1" /* Supplement Pelvis Lymphatic with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07UC4KZ" = "1" /* Supplement Pelvis Lymphatic with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UD07Z" = "1" /* Supplement Aortic Lymphatic with Autologous Tissue Substitute, Open Approach */
"07UD0JZ" = "1" /* Supplement Aortic Lymphatic with Synthetic Substitute, Open Approach */
"07UD0KZ" = "1" /* Supplement Aortic Lymphatic with Nonautologous Tissue Substitute, Open Approach */
"07UD47Z" = "1" /* Supplement Aortic Lymphatic with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UD4JZ" = "1" /* Supplement Aortic Lymphatic with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07UD4KZ" = "1" /* Supplement Aortic Lymphatic with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UF07Z" = "1" /* Supplement Right Lower Extremity Lymphatic with Autologous Tissue Substitute, Open Approach */
"07UF0JZ" = "1" /* Supplement Right Lower Extremity Lymphatic with Synthetic Substitute, Open Approach */
"07UF0KZ" = "1" /* Supplement Right Lower Extremity Lymphatic with Nonautologous Tissue Substitute, Open Approach */
"07UF47Z" = "1" /* Supplement Right Lower Extremity Lymphatic with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UF4JZ" = "1" /* Supplement Right Lower Extremity Lymphatic with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07UF4KZ" = "1" /* Supplement Right Lower Extremity Lymphatic with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UG07Z" = "1" /* Supplement Left Lower Extremity Lymphatic with Autologous Tissue Substitute, Open Approach */
"07UG0JZ" = "1" /* Supplement Left Lower Extremity Lymphatic with Synthetic Substitute, Open Approach */
"07UG0KZ" = "1" /* Supplement Left Lower Extremity Lymphatic with Nonautologous Tissue Substitute, Open Approach */
"07UG47Z" = "1" /* Supplement Left Lower Extremity Lymphatic with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UG4JZ" = "1" /* Supplement Left Lower Extremity Lymphatic with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07UG4KZ" = "1" /* Supplement Left Lower Extremity Lymphatic with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UH07Z" = "1" /* Supplement Right Inguinal Lymphatic with Autologous Tissue Substitute, Open Approach */
"07UH0JZ" = "1" /* Supplement Right Inguinal Lymphatic with Synthetic Substitute, Open Approach */
"07UH0KZ" = "1" /* Supplement Right Inguinal Lymphatic with Nonautologous Tissue Substitute, Open Approach */
"07UH47Z" = "1" /* Supplement Right Inguinal Lymphatic with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UH4JZ" = "1" /* Supplement Right Inguinal Lymphatic with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07UH4KZ" = "1" /* Supplement Right Inguinal Lymphatic with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UJ07Z" = "1" /* Supplement Left Inguinal Lymphatic with Autologous Tissue Substitute, Open Approach */
"07UJ0JZ" = "1" /* Supplement Left Inguinal Lymphatic with Synthetic Substitute, Open Approach */
"07UJ0KZ" = "1" /* Supplement Left Inguinal Lymphatic with Nonautologous Tissue Substitute, Open Approach */
"07UJ47Z" = "1" /* Supplement Left Inguinal Lymphatic with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UJ4JZ" = "1" /* Supplement Left Inguinal Lymphatic with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07UJ4KZ" = "1" /* Supplement Left Inguinal Lymphatic with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UK07Z" = "1" /* Supplement Thoracic Duct with Autologous Tissue Substitute, Open Approach */
"07UK0JZ" = "1" /* Supplement Thoracic Duct with Synthetic Substitute, Open Approach */
"07UK0KZ" = "1" /* Supplement Thoracic Duct with Nonautologous Tissue Substitute, Open Approach */
"07UK47Z" = "1" /* Supplement Thoracic Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UK4JZ" = "1" /* Supplement Thoracic Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07UK4KZ" = "1" /* Supplement Thoracic Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UL07Z" = "1" /* Supplement Cisterna Chyli with Autologous Tissue Substitute, Open Approach */
"07UL0JZ" = "1" /* Supplement Cisterna Chyli with Synthetic Substitute, Open Approach */
"07UL0KZ" = "1" /* Supplement Cisterna Chyli with Nonautologous Tissue Substitute, Open Approach */
"07UL47Z" = "1" /* Supplement Cisterna Chyli with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UL4JZ" = "1" /* Supplement Cisterna Chyli with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07UL4KZ" = "1" /* Supplement Cisterna Chyli with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07V00CZ" = "1" /* Restriction of Head Lymphatic with Extraluminal Device, Open Approach */
"07V00DZ" = "1" /* Restriction of Head Lymphatic with Intraluminal Device, Open Approach */
"07V00ZZ" = "1" /* Restriction of Head Lymphatic, Open Approach */
"07V03CZ" = "1" /* Restriction of Head Lymphatic with Extraluminal Device, Percutaneous Approach */
"07V03DZ" = "1" /* Restriction of Head Lymphatic with Intraluminal Device, Percutaneous Approach */
"07V03ZZ" = "1" /* Restriction of Head Lymphatic, Percutaneous Approach */
"07V04CZ" = "1" /* Restriction of Head Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07V04DZ" = "1" /* Restriction of Head Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07V04ZZ" = "1" /* Restriction of Head Lymphatic, Percutaneous Endoscopic Approach */
"07V10CZ" = "1" /* Restriction of Right Neck Lymphatic with Extraluminal Device, Open Approach */
"07V10DZ" = "1" /* Restriction of Right Neck Lymphatic with Intraluminal Device, Open Approach */
"07V10ZZ" = "1" /* Restriction of Right Neck Lymphatic, Open Approach */
"07V13CZ" = "1" /* Restriction of Right Neck Lymphatic with Extraluminal Device, Percutaneous Approach */
"07V13DZ" = "1" /* Restriction of Right Neck Lymphatic with Intraluminal Device, Percutaneous Approach */
"07V13ZZ" = "1" /* Restriction of Right Neck Lymphatic, Percutaneous Approach */
"07V14CZ" = "1" /* Restriction of Right Neck Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07V14DZ" = "1" /* Restriction of Right Neck Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07V14ZZ" = "1" /* Restriction of Right Neck Lymphatic, Percutaneous Endoscopic Approach */
"07V20CZ" = "1" /* Restriction of Left Neck Lymphatic with Extraluminal Device, Open Approach */
"07V20DZ" = "1" /* Restriction of Left Neck Lymphatic with Intraluminal Device, Open Approach */
"07V20ZZ" = "1" /* Restriction of Left Neck Lymphatic, Open Approach */
"07V23CZ" = "1" /* Restriction of Left Neck Lymphatic with Extraluminal Device, Percutaneous Approach */
"07V23DZ" = "1" /* Restriction of Left Neck Lymphatic with Intraluminal Device, Percutaneous Approach */
"07V23ZZ" = "1" /* Restriction of Left Neck Lymphatic, Percutaneous Approach */
"07V24CZ" = "1" /* Restriction of Left Neck Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07V24DZ" = "1" /* Restriction of Left Neck Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07V24ZZ" = "1" /* Restriction of Left Neck Lymphatic, Percutaneous Endoscopic Approach */
"07V30CZ" = "1" /* Restriction of Right Upper Extremity Lymphatic with Extraluminal Device, Open Approach */
"07V30DZ" = "1" /* Restriction of Right Upper Extremity Lymphatic with Intraluminal Device, Open Approach */
"07V30ZZ" = "1" /* Restriction of Right Upper Extremity Lymphatic, Open Approach */
"07V33CZ" = "1" /* Restriction of Right Upper Extremity Lymphatic with Extraluminal Device, Percutaneous Approach */
"07V33DZ" = "1" /* Restriction of Right Upper Extremity Lymphatic with Intraluminal Device, Percutaneous Approach */
"07V33ZZ" = "1" /* Restriction of Right Upper Extremity Lymphatic, Percutaneous Approach */
"07V34CZ" = "1" /* Restriction of Right Upper Extremity Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07V34DZ" = "1" /* Restriction of Right Upper Extremity Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07V34ZZ" = "1" /* Restriction of Right Upper Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07V40CZ" = "1" /* Restriction of Left Upper Extremity Lymphatic with Extraluminal Device, Open Approach */
"07V40DZ" = "1" /* Restriction of Left Upper Extremity Lymphatic with Intraluminal Device, Open Approach */
"07V40ZZ" = "1" /* Restriction of Left Upper Extremity Lymphatic, Open Approach */
"07V43CZ" = "1" /* Restriction of Left Upper Extremity Lymphatic with Extraluminal Device, Percutaneous Approach */
"07V43DZ" = "1" /* Restriction of Left Upper Extremity Lymphatic with Intraluminal Device, Percutaneous Approach */
"07V43ZZ" = "1" /* Restriction of Left Upper Extremity Lymphatic, Percutaneous Approach */
"07V44CZ" = "1" /* Restriction of Left Upper Extremity Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07V44DZ" = "1" /* Restriction of Left Upper Extremity Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07V44ZZ" = "1" /* Restriction of Left Upper Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07V50CZ" = "1" /* Restriction of Right Axillary Lymphatic with Extraluminal Device, Open Approach */
"07V50DZ" = "1" /* Restriction of Right Axillary Lymphatic with Intraluminal Device, Open Approach */
"07V50ZZ" = "1" /* Restriction of Right Axillary Lymphatic, Open Approach */
"07V53CZ" = "1" /* Restriction of Right Axillary Lymphatic with Extraluminal Device, Percutaneous Approach */
"07V53DZ" = "1" /* Restriction of Right Axillary Lymphatic with Intraluminal Device, Percutaneous Approach */
"07V53ZZ" = "1" /* Restriction of Right Axillary Lymphatic, Percutaneous Approach */
"07V54CZ" = "1" /* Restriction of Right Axillary Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07V54DZ" = "1" /* Restriction of Right Axillary Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07V54ZZ" = "1" /* Restriction of Right Axillary Lymphatic, Percutaneous Endoscopic Approach */
"07V60CZ" = "1" /* Restriction of Left Axillary Lymphatic with Extraluminal Device, Open Approach */
"07V60DZ" = "1" /* Restriction of Left Axillary Lymphatic with Intraluminal Device, Open Approach */
"07V60ZZ" = "1" /* Restriction of Left Axillary Lymphatic, Open Approach */
"07V63CZ" = "1" /* Restriction of Left Axillary Lymphatic with Extraluminal Device, Percutaneous Approach */
"07V63DZ" = "1" /* Restriction of Left Axillary Lymphatic with Intraluminal Device, Percutaneous Approach */
"07V63ZZ" = "1" /* Restriction of Left Axillary Lymphatic, Percutaneous Approach */
"07V64CZ" = "1" /* Restriction of Left Axillary Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07V64DZ" = "1" /* Restriction of Left Axillary Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07V64ZZ" = "1" /* Restriction of Left Axillary Lymphatic, Percutaneous Endoscopic Approach */
"07V70CZ" = "1" /* Restriction of Thorax Lymphatic with Extraluminal Device, Open Approach */
"07V70DZ" = "1" /* Restriction of Thorax Lymphatic with Intraluminal Device, Open Approach */
"07V70ZZ" = "1" /* Restriction of Thorax Lymphatic, Open Approach */
"07V73CZ" = "1" /* Restriction of Thorax Lymphatic with Extraluminal Device, Percutaneous Approach */
"07V73DZ" = "1" /* Restriction of Thorax Lymphatic with Intraluminal Device, Percutaneous Approach */
"07V73ZZ" = "1" /* Restriction of Thorax Lymphatic, Percutaneous Approach */
"07V74CZ" = "1" /* Restriction of Thorax Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07V74DZ" = "1" /* Restriction of Thorax Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07V74ZZ" = "1" /* Restriction of Thorax Lymphatic, Percutaneous Endoscopic Approach */
"07V80CZ" = "1" /* Restriction of Right Internal Mammary Lymphatic with Extraluminal Device, Open Approach */
"07V80DZ" = "1" /* Restriction of Right Internal Mammary Lymphatic with Intraluminal Device, Open Approach */
"07V80ZZ" = "1" /* Restriction of Right Internal Mammary Lymphatic, Open Approach */
"07V83CZ" = "1" /* Restriction of Right Internal Mammary Lymphatic with Extraluminal Device, Percutaneous Approach */
"07V83DZ" = "1" /* Restriction of Right Internal Mammary Lymphatic with Intraluminal Device, Percutaneous Approach */
"07V83ZZ" = "1" /* Restriction of Right Internal Mammary Lymphatic, Percutaneous Approach */
"07V84CZ" = "1" /* Restriction of Right Internal Mammary Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07V84DZ" = "1" /* Restriction of Right Internal Mammary Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07V84ZZ" = "1" /* Restriction of Right Internal Mammary Lymphatic, Percutaneous Endoscopic Approach */
"07V90CZ" = "1" /* Restriction of Left Internal Mammary Lymphatic with Extraluminal Device, Open Approach */
"07V90DZ" = "1" /* Restriction of Left Internal Mammary Lymphatic with Intraluminal Device, Open Approach */
"07V90ZZ" = "1" /* Restriction of Left Internal Mammary Lymphatic, Open Approach */
"07V93CZ" = "1" /* Restriction of Left Internal Mammary Lymphatic with Extraluminal Device, Percutaneous Approach */
"07V93DZ" = "1" /* Restriction of Left Internal Mammary Lymphatic with Intraluminal Device, Percutaneous Approach */
"07V93ZZ" = "1" /* Restriction of Left Internal Mammary Lymphatic, Percutaneous Approach */
"07V94CZ" = "1" /* Restriction of Left Internal Mammary Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07V94DZ" = "1" /* Restriction of Left Internal Mammary Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07V94ZZ" = "1" /* Restriction of Left Internal Mammary Lymphatic, Percutaneous Endoscopic Approach */
"07VB0CZ" = "1" /* Restriction of Mesenteric Lymphatic with Extraluminal Device, Open Approach */
"07VB0DZ" = "1" /* Restriction of Mesenteric Lymphatic with Intraluminal Device, Open Approach */
"07VB0ZZ" = "1" /* Restriction of Mesenteric Lymphatic, Open Approach */
"07VB3CZ" = "1" /* Restriction of Mesenteric Lymphatic with Extraluminal Device, Percutaneous Approach */
"07VB3DZ" = "1" /* Restriction of Mesenteric Lymphatic with Intraluminal Device, Percutaneous Approach */
"07VB3ZZ" = "1" /* Restriction of Mesenteric Lymphatic, Percutaneous Approach */
"07VB4CZ" = "1" /* Restriction of Mesenteric Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07VB4DZ" = "1" /* Restriction of Mesenteric Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07VB4ZZ" = "1" /* Restriction of Mesenteric Lymphatic, Percutaneous Endoscopic Approach */
"07VC0CZ" = "1" /* Restriction of Pelvis Lymphatic with Extraluminal Device, Open Approach */
"07VC0DZ" = "1" /* Restriction of Pelvis Lymphatic with Intraluminal Device, Open Approach */
"07VC0ZZ" = "1" /* Restriction of Pelvis Lymphatic, Open Approach */
"07VC3CZ" = "1" /* Restriction of Pelvis Lymphatic with Extraluminal Device, Percutaneous Approach */
"07VC3DZ" = "1" /* Restriction of Pelvis Lymphatic with Intraluminal Device, Percutaneous Approach */
"07VC3ZZ" = "1" /* Restriction of Pelvis Lymphatic, Percutaneous Approach */
"07VC4CZ" = "1" /* Restriction of Pelvis Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07VC4DZ" = "1" /* Restriction of Pelvis Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07VC4ZZ" = "1" /* Restriction of Pelvis Lymphatic, Percutaneous Endoscopic Approach */
"07VD0CZ" = "1" /* Restriction of Aortic Lymphatic with Extraluminal Device, Open Approach */
"07VD0DZ" = "1" /* Restriction of Aortic Lymphatic with Intraluminal Device, Open Approach */
"07VD0ZZ" = "1" /* Restriction of Aortic Lymphatic, Open Approach */
"07VD3CZ" = "1" /* Restriction of Aortic Lymphatic with Extraluminal Device, Percutaneous Approach */
"07VD3DZ" = "1" /* Restriction of Aortic Lymphatic with Intraluminal Device, Percutaneous Approach */
"07VD3ZZ" = "1" /* Restriction of Aortic Lymphatic, Percutaneous Approach */
"07VD4CZ" = "1" /* Restriction of Aortic Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07VD4DZ" = "1" /* Restriction of Aortic Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07VD4ZZ" = "1" /* Restriction of Aortic Lymphatic, Percutaneous Endoscopic Approach */
"07VF0CZ" = "1" /* Restriction of Right Lower Extremity Lymphatic with Extraluminal Device, Open Approach */
"07VF0DZ" = "1" /* Restriction of Right Lower Extremity Lymphatic with Intraluminal Device, Open Approach */
"07VF0ZZ" = "1" /* Restriction of Right Lower Extremity Lymphatic, Open Approach */
"07VF3CZ" = "1" /* Restriction of Right Lower Extremity Lymphatic with Extraluminal Device, Percutaneous Approach */
"07VF3DZ" = "1" /* Restriction of Right Lower Extremity Lymphatic with Intraluminal Device, Percutaneous Approach */
"07VF3ZZ" = "1" /* Restriction of Right Lower Extremity Lymphatic, Percutaneous Approach */
"07VF4CZ" = "1" /* Restriction of Right Lower Extremity Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07VF4DZ" = "1" /* Restriction of Right Lower Extremity Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07VF4ZZ" = "1" /* Restriction of Right Lower Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07VG0CZ" = "1" /* Restriction of Left Lower Extremity Lymphatic with Extraluminal Device, Open Approach */
"07VG0DZ" = "1" /* Restriction of Left Lower Extremity Lymphatic with Intraluminal Device, Open Approach */
"07VG0ZZ" = "1" /* Restriction of Left Lower Extremity Lymphatic, Open Approach */
"07VG3CZ" = "1" /* Restriction of Left Lower Extremity Lymphatic with Extraluminal Device, Percutaneous Approach */
"07VG3DZ" = "1" /* Restriction of Left Lower Extremity Lymphatic with Intraluminal Device, Percutaneous Approach */
"07VG3ZZ" = "1" /* Restriction of Left Lower Extremity Lymphatic, Percutaneous Approach */
"07VG4CZ" = "1" /* Restriction of Left Lower Extremity Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07VG4DZ" = "1" /* Restriction of Left Lower Extremity Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07VG4ZZ" = "1" /* Restriction of Left Lower Extremity Lymphatic, Percutaneous Endoscopic Approach */
"07VH0CZ" = "1" /* Restriction of Right Inguinal Lymphatic with Extraluminal Device, Open Approach */
"07VH0DZ" = "1" /* Restriction of Right Inguinal Lymphatic with Intraluminal Device, Open Approach */
"07VH0ZZ" = "1" /* Restriction of Right Inguinal Lymphatic, Open Approach */
"07VH3CZ" = "1" /* Restriction of Right Inguinal Lymphatic with Extraluminal Device, Percutaneous Approach */
"07VH3DZ" = "1" /* Restriction of Right Inguinal Lymphatic with Intraluminal Device, Percutaneous Approach */
"07VH3ZZ" = "1" /* Restriction of Right Inguinal Lymphatic, Percutaneous Approach */
"07VH4CZ" = "1" /* Restriction of Right Inguinal Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07VH4DZ" = "1" /* Restriction of Right Inguinal Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07VH4ZZ" = "1" /* Restriction of Right Inguinal Lymphatic, Percutaneous Endoscopic Approach */
"07VJ0CZ" = "1" /* Restriction of Left Inguinal Lymphatic with Extraluminal Device, Open Approach */
"07VJ0DZ" = "1" /* Restriction of Left Inguinal Lymphatic with Intraluminal Device, Open Approach */
"07VJ0ZZ" = "1" /* Restriction of Left Inguinal Lymphatic, Open Approach */
"07VJ3CZ" = "1" /* Restriction of Left Inguinal Lymphatic with Extraluminal Device, Percutaneous Approach */
"07VJ3DZ" = "1" /* Restriction of Left Inguinal Lymphatic with Intraluminal Device, Percutaneous Approach */
"07VJ3ZZ" = "1" /* Restriction of Left Inguinal Lymphatic, Percutaneous Approach */
"07VJ4CZ" = "1" /* Restriction of Left Inguinal Lymphatic with Extraluminal Device, Percutaneous Endoscopic Approach */
"07VJ4DZ" = "1" /* Restriction of Left Inguinal Lymphatic with Intraluminal Device, Percutaneous Endoscopic Approach */
"07VJ4ZZ" = "1" /* Restriction of Left Inguinal Lymphatic, Percutaneous Endoscopic Approach */
"07VK0CZ" = "1" /* Restriction of Thoracic Duct with Extraluminal Device, Open Approach */
"07VK0DZ" = "1" /* Restriction of Thoracic Duct with Intraluminal Device, Open Approach */
"07VK0ZZ" = "1" /* Restriction of Thoracic Duct, Open Approach */
"07VK3CZ" = "1" /* Restriction of Thoracic Duct with Extraluminal Device, Percutaneous Approach */
"07VK3DZ" = "1" /* Restriction of Thoracic Duct with Intraluminal Device, Percutaneous Approach */
"07VK3ZZ" = "1" /* Restriction of Thoracic Duct, Percutaneous Approach */
"07VK4CZ" = "1" /* Restriction of Thoracic Duct with Extraluminal Device, Percutaneous Endoscopic Approach */
"07VK4DZ" = "1" /* Restriction of Thoracic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"07VK4ZZ" = "1" /* Restriction of Thoracic Duct, Percutaneous Endoscopic Approach */
"07VL0CZ" = "1" /* Restriction of Cisterna Chyli with Extraluminal Device, Open Approach */
"07VL0DZ" = "1" /* Restriction of Cisterna Chyli with Intraluminal Device, Open Approach */
"07VL0ZZ" = "1" /* Restriction of Cisterna Chyli, Open Approach */
"07VL3CZ" = "1" /* Restriction of Cisterna Chyli with Extraluminal Device, Percutaneous Approach */
"07VL3DZ" = "1" /* Restriction of Cisterna Chyli with Intraluminal Device, Percutaneous Approach */
"07VL3ZZ" = "1" /* Restriction of Cisterna Chyli, Percutaneous Approach */
"07VL4CZ" = "1" /* Restriction of Cisterna Chyli with Extraluminal Device, Percutaneous Endoscopic Approach */
"07VL4DZ" = "1" /* Restriction of Cisterna Chyli with Intraluminal Device, Percutaneous Endoscopic Approach */
"07VL4ZZ" = "1" /* Restriction of Cisterna Chyli, Percutaneous Endoscopic Approach */
"07WK00Z" = "1" /* Revision of Drainage Device in Thoracic Duct, Open Approach */
"07WK03Z" = "1" /* Revision of Infusion Device in Thoracic Duct, Open Approach */
"07WK07Z" = "1" /* Revision of Autologous Tissue Substitute in Thoracic Duct, Open Approach */
"07WK0CZ" = "1" /* Revision of Extraluminal Device in Thoracic Duct, Open Approach */
"07WK0DZ" = "1" /* Revision of Intraluminal Device in Thoracic Duct, Open Approach */
"07WK0JZ" = "1" /* Revision of Synthetic Substitute in Thoracic Duct, Open Approach */
"07WK0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Thoracic Duct, Open Approach */
"07WK30Z" = "1" /* Revision of Drainage Device in Thoracic Duct, Percutaneous Approach */
"07WK33Z" = "1" /* Revision of Infusion Device in Thoracic Duct, Percutaneous Approach */
"07WK37Z" = "1" /* Revision of Autologous Tissue Substitute in Thoracic Duct, Percutaneous Approach */
"07WK3CZ" = "1" /* Revision of Extraluminal Device in Thoracic Duct, Percutaneous Approach */
"07WK3DZ" = "1" /* Revision of Intraluminal Device in Thoracic Duct, Percutaneous Approach */
"07WK3JZ" = "1" /* Revision of Synthetic Substitute in Thoracic Duct, Percutaneous Approach */
"07WK3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Thoracic Duct, Percutaneous Approach */
"07WK40Z" = "1" /* Revision of Drainage Device in Thoracic Duct, Percutaneous Endoscopic Approach */
"07WK43Z" = "1" /* Revision of Infusion Device in Thoracic Duct, Percutaneous Endoscopic Approach */
"07WK47Z" = "1" /* Revision of Autologous Tissue Substitute in Thoracic Duct, Percutaneous Endoscopic Approach */
"07WK4CZ" = "1" /* Revision of Extraluminal Device in Thoracic Duct, Percutaneous Endoscopic Approach */
"07WK4DZ" = "1" /* Revision of Intraluminal Device in Thoracic Duct, Percutaneous Endoscopic Approach */
"07WK4JZ" = "1" /* Revision of Synthetic Substitute in Thoracic Duct, Percutaneous Endoscopic Approach */
"07WK4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Thoracic Duct, Percutaneous Endoscopic Approach */
"07WL00Z" = "1" /* Revision of Drainage Device in Cisterna Chyli, Open Approach */
"07WL03Z" = "1" /* Revision of Infusion Device in Cisterna Chyli, Open Approach */
"07WL07Z" = "1" /* Revision of Autologous Tissue Substitute in Cisterna Chyli, Open Approach */
"07WL0CZ" = "1" /* Revision of Extraluminal Device in Cisterna Chyli, Open Approach */
"07WL0DZ" = "1" /* Revision of Intraluminal Device in Cisterna Chyli, Open Approach */
"07WL0JZ" = "1" /* Revision of Synthetic Substitute in Cisterna Chyli, Open Approach */
"07WL0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Cisterna Chyli, Open Approach */
"07WL30Z" = "1" /* Revision of Drainage Device in Cisterna Chyli, Percutaneous Approach */
"07WL33Z" = "1" /* Revision of Infusion Device in Cisterna Chyli, Percutaneous Approach */
"07WL37Z" = "1" /* Revision of Autologous Tissue Substitute in Cisterna Chyli, Percutaneous Approach */
"07WL3CZ" = "1" /* Revision of Extraluminal Device in Cisterna Chyli, Percutaneous Approach */
"07WL3DZ" = "1" /* Revision of Intraluminal Device in Cisterna Chyli, Percutaneous Approach */
"07WL3JZ" = "1" /* Revision of Synthetic Substitute in Cisterna Chyli, Percutaneous Approach */
"07WL3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Cisterna Chyli, Percutaneous Approach */
"07WL40Z" = "1" /* Revision of Drainage Device in Cisterna Chyli, Percutaneous Endoscopic Approach */
"07WL43Z" = "1" /* Revision of Infusion Device in Cisterna Chyli, Percutaneous Endoscopic Approach */
"07WL47Z" = "1" /* Revision of Autologous Tissue Substitute in Cisterna Chyli, Percutaneous Endoscopic Approach */
"07WL4CZ" = "1" /* Revision of Extraluminal Device in Cisterna Chyli, Percutaneous Endoscopic Approach */
"07WL4DZ" = "1" /* Revision of Intraluminal Device in Cisterna Chyli, Percutaneous Endoscopic Approach */
"07WL4JZ" = "1" /* Revision of Synthetic Substitute in Cisterna Chyli, Percutaneous Endoscopic Approach */
"07WL4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Cisterna Chyli, Percutaneous Endoscopic Approach */
"07WM00Z" = "1" /* Revision of Drainage Device in Thymus, Open Approach */
"07WM03Z" = "1" /* Revision of Infusion Device in Thymus, Open Approach */
"07WM30Z" = "1" /* Revision of Drainage Device in Thymus, Percutaneous Approach */
"07WM33Z" = "1" /* Revision of Infusion Device in Thymus, Percutaneous Approach */
"07WM40Z" = "1" /* Revision of Drainage Device in Thymus, Percutaneous Endoscopic Approach */
"07WM43Z" = "1" /* Revision of Infusion Device in Thymus, Percutaneous Endoscopic Approach */
"07WN00Z" = "1" /* Revision of Drainage Device in Lymphatic, Open Approach */
"07WN03Z" = "1" /* Revision of Infusion Device in Lymphatic, Open Approach */
"07WN07Z" = "1" /* Revision of Autologous Tissue Substitute in Lymphatic, Open Approach */
"07WN0CZ" = "1" /* Revision of Extraluminal Device in Lymphatic, Open Approach */
"07WN0DZ" = "1" /* Revision of Intraluminal Device in Lymphatic, Open Approach */
"07WN0JZ" = "1" /* Revision of Synthetic Substitute in Lymphatic, Open Approach */
"07WN0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lymphatic, Open Approach */
"07WN30Z" = "1" /* Revision of Drainage Device in Lymphatic, Percutaneous Approach */
"07WN33Z" = "1" /* Revision of Infusion Device in Lymphatic, Percutaneous Approach */
"07WN37Z" = "1" /* Revision of Autologous Tissue Substitute in Lymphatic, Percutaneous Approach */
"07WN3CZ" = "1" /* Revision of Extraluminal Device in Lymphatic, Percutaneous Approach */
"07WN3DZ" = "1" /* Revision of Intraluminal Device in Lymphatic, Percutaneous Approach */
"07WN3JZ" = "1" /* Revision of Synthetic Substitute in Lymphatic, Percutaneous Approach */
"07WN3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lymphatic, Percutaneous Approach */
"07WN40Z" = "1" /* Revision of Drainage Device in Lymphatic, Percutaneous Endoscopic Approach */
"07WN43Z" = "1" /* Revision of Infusion Device in Lymphatic, Percutaneous Endoscopic Approach */
"07WN47Z" = "1" /* Revision of Autologous Tissue Substitute in Lymphatic, Percutaneous Endoscopic Approach */
"07WN4CZ" = "1" /* Revision of Extraluminal Device in Lymphatic, Percutaneous Endoscopic Approach */
"07WN4DZ" = "1" /* Revision of Intraluminal Device in Lymphatic, Percutaneous Endoscopic Approach */
"07WN4JZ" = "1" /* Revision of Synthetic Substitute in Lymphatic, Percutaneous Endoscopic Approach */
"07WN4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lymphatic, Percutaneous Endoscopic Approach */
"07WP00Z" = "1" /* Revision of Drainage Device in Spleen, Open Approach */
"07WP03Z" = "1" /* Revision of Infusion Device in Spleen, Open Approach */
"07WP30Z" = "1" /* Revision of Drainage Device in Spleen, Percutaneous Approach */
"07WP33Z" = "1" /* Revision of Infusion Device in Spleen, Percutaneous Approach */
"07WP40Z" = "1" /* Revision of Drainage Device in Spleen, Percutaneous Endoscopic Approach */
"07WP43Z" = "1" /* Revision of Infusion Device in Spleen, Percutaneous Endoscopic Approach */
"07YM0Z0" = "1" /* Transplantation of Thymus, Allogeneic, Open Approach */
"07YM0Z1" = "1" /* Transplantation of Thymus, Syngeneic, Open Approach */
"07YM0Z2" = "1" /* Transplantation of Thymus, Zooplastic, Open Approach */
"07YP0Z0" = "1" /* Transplantation of Spleen, Allogeneic, Open Approach */
"07YP0Z1" = "1" /* Transplantation of Spleen, Syngeneic, Open Approach */
"07YP0Z2" = "1" /* Transplantation of Spleen, Zooplastic, Open Approach */
"08123J4" = "1" /* Bypass Right Anterior Chamber to Sclera with Synthetic Substitute, Percutaneous Approach */
"08123K4" = "1" /* Bypass Right Anterior Chamber to Sclera with Nonautologous Tissue Substitute, Percutaneous Approach */
"08123Z4" = "1" /* Bypass Right Anterior Chamber to Sclera, Percutaneous Approach */
"08133J4" = "1" /* Bypass Left Anterior Chamber to Sclera with Synthetic Substitute, Percutaneous Approach */
"08133K4" = "1" /* Bypass Left Anterior Chamber to Sclera with Nonautologous Tissue Substitute, Percutaneous Approach */
"08133Z4" = "1" /* Bypass Left Anterior Chamber to Sclera, Percutaneous Approach */
"081X0J3" = "1" /* Bypass Right Lacrimal Duct to Nasal Cavity with Synthetic Substitute, Open Approach */
"081X0K3" = "1" /* Bypass Right Lacrimal Duct to Nasal Cavity with Nonautologous Tissue Substitute, Open Approach */
"081X0Z3" = "1" /* Bypass Right Lacrimal Duct to Nasal Cavity, Open Approach */
"081X3J3" = "1" /* Bypass Right Lacrimal Duct to Nasal Cavity with Synthetic Substitute, Percutaneous Approach */
"081X3K3" = "1" /* Bypass Right Lacrimal Duct to Nasal Cavity with Nonautologous Tissue Substitute, Percutaneous Approach */
"081X3Z3" = "1" /* Bypass Right Lacrimal Duct to Nasal Cavity, Percutaneous Approach */
"081Y0J3" = "1" /* Bypass Left Lacrimal Duct to Nasal Cavity with Synthetic Substitute, Open Approach */
"081Y0K3" = "1" /* Bypass Left Lacrimal Duct to Nasal Cavity with Nonautologous Tissue Substitute, Open Approach */
"081Y0Z3" = "1" /* Bypass Left Lacrimal Duct to Nasal Cavity, Open Approach */
"081Y3J3" = "1" /* Bypass Left Lacrimal Duct to Nasal Cavity with Synthetic Substitute, Percutaneous Approach */
"081Y3K3" = "1" /* Bypass Left Lacrimal Duct to Nasal Cavity with Nonautologous Tissue Substitute, Percutaneous Approach */
"081Y3Z3" = "1" /* Bypass Left Lacrimal Duct to Nasal Cavity, Percutaneous Approach */
"0850XZZ" = "1" /* Destruction of Right Eye, External Approach */
"0851XZZ" = "1" /* Destruction of Left Eye, External Approach */
"08523ZZ" = "1" /* Destruction of Right Anterior Chamber, Percutaneous Approach */
"08533ZZ" = "1" /* Destruction of Left Anterior Chamber, Percutaneous Approach */
"08543ZZ" = "1" /* Destruction of Right Vitreous, Percutaneous Approach */
"08553ZZ" = "1" /* Destruction of Left Vitreous, Percutaneous Approach */
"0856XZZ" = "1" /* Destruction of Right Sclera, External Approach */
"0857XZZ" = "1" /* Destruction of Left Sclera, External Approach */
"0858XZZ" = "1" /* Destruction of Right Cornea, External Approach */
"0859XZZ" = "1" /* Destruction of Left Cornea, External Approach */
"085A0ZZ" = "1" /* Destruction of Right Choroid, Open Approach */
"085A3ZZ" = "1" /* Destruction of Right Choroid, Percutaneous Approach */
"085B0ZZ" = "1" /* Destruction of Left Choroid, Open Approach */
"085B3ZZ" = "1" /* Destruction of Left Choroid, Percutaneous Approach */
"085C3ZZ" = "1" /* Destruction of Right Iris, Percutaneous Approach */
"085D3ZZ" = "1" /* Destruction of Left Iris, Percutaneous Approach */
"085G3ZZ" = "1" /* Destruction of Right Retinal Vessel, Percutaneous Approach */
"085H3ZZ" = "1" /* Destruction of Left Retinal Vessel, Percutaneous Approach */
"085J3ZZ" = "1" /* Destruction of Right Lens, Percutaneous Approach */
"085K3ZZ" = "1" /* Destruction of Left Lens, Percutaneous Approach */
"085L0ZZ" = "1" /* Destruction of Right Extraocular Muscle, Open Approach */
"085L3ZZ" = "1" /* Destruction of Right Extraocular Muscle, Percutaneous Approach */
"085M0ZZ" = "1" /* Destruction of Left Extraocular Muscle, Open Approach */
"085M3ZZ" = "1" /* Destruction of Left Extraocular Muscle, Percutaneous Approach */
"085N0ZZ" = "1" /* Destruction of Right Upper Eyelid, Open Approach */
"085N3ZZ" = "1" /* Destruction of Right Upper Eyelid, Percutaneous Approach */
"085NXZZ" = "1" /* Destruction of Right Upper Eyelid, External Approach */
"085P0ZZ" = "1" /* Destruction of Left Upper Eyelid, Open Approach */
"085P3ZZ" = "1" /* Destruction of Left Upper Eyelid, Percutaneous Approach */
"085PXZZ" = "1" /* Destruction of Left Upper Eyelid, External Approach */
"085Q0ZZ" = "1" /* Destruction of Right Lower Eyelid, Open Approach */
"085Q3ZZ" = "1" /* Destruction of Right Lower Eyelid, Percutaneous Approach */
"085QXZZ" = "1" /* Destruction of Right Lower Eyelid, External Approach */
"085R0ZZ" = "1" /* Destruction of Left Lower Eyelid, Open Approach */
"085R3ZZ" = "1" /* Destruction of Left Lower Eyelid, Percutaneous Approach */
"085RXZZ" = "1" /* Destruction of Left Lower Eyelid, External Approach */
"085SXZZ" = "1" /* Destruction of Right Conjunctiva, External Approach */
"085TXZZ" = "1" /* Destruction of Left Conjunctiva, External Approach */
"085V0ZZ" = "1" /* Destruction of Right Lacrimal Gland, Open Approach */
"085V3ZZ" = "1" /* Destruction of Right Lacrimal Gland, Percutaneous Approach */
"085W0ZZ" = "1" /* Destruction of Left Lacrimal Gland, Open Approach */
"085W3ZZ" = "1" /* Destruction of Left Lacrimal Gland, Percutaneous Approach */
"085X0ZZ" = "1" /* Destruction of Right Lacrimal Duct, Open Approach */
"085X3ZZ" = "1" /* Destruction of Right Lacrimal Duct, Percutaneous Approach */
"085X7ZZ" = "1" /* Destruction of Right Lacrimal Duct, Via Natural or Artificial Opening */
"085X8ZZ" = "1" /* Destruction of Right Lacrimal Duct, Via Natural or Artificial Opening Endoscopic */
"085Y0ZZ" = "1" /* Destruction of Left Lacrimal Duct, Open Approach */
"085Y3ZZ" = "1" /* Destruction of Left Lacrimal Duct, Percutaneous Approach */
"085Y7ZZ" = "1" /* Destruction of Left Lacrimal Duct, Via Natural or Artificial Opening */
"085Y8ZZ" = "1" /* Destruction of Left Lacrimal Duct, Via Natural or Artificial Opening Endoscopic */
"087X0DZ" = "1" /* Dilation of Right Lacrimal Duct with Intraluminal Device, Open Approach */
"087X0ZZ" = "1" /* Dilation of Right Lacrimal Duct, Open Approach */
"087X3DZ" = "1" /* Dilation of Right Lacrimal Duct with Intraluminal Device, Percutaneous Approach */
"087X3ZZ" = "1" /* Dilation of Right Lacrimal Duct, Percutaneous Approach */
"087X7DZ" = "1" /* Dilation of Right Lacrimal Duct with Intraluminal Device, Via Natural or Artificial Opening */
"087X7ZZ" = "1" /* Dilation of Right Lacrimal Duct, Via Natural or Artificial Opening */
"087X8DZ" = "1" /* Dilation of Right Lacrimal Duct with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"087X8ZZ" = "1" /* Dilation of Right Lacrimal Duct, Via Natural or Artificial Opening Endoscopic */
"087Y0DZ" = "1" /* Dilation of Left Lacrimal Duct with Intraluminal Device, Open Approach */
"087Y0ZZ" = "1" /* Dilation of Left Lacrimal Duct, Open Approach */
"087Y3DZ" = "1" /* Dilation of Left Lacrimal Duct with Intraluminal Device, Percutaneous Approach */
"087Y3ZZ" = "1" /* Dilation of Left Lacrimal Duct, Percutaneous Approach */
"087Y7DZ" = "1" /* Dilation of Left Lacrimal Duct with Intraluminal Device, Via Natural or Artificial Opening */
"087Y7ZZ" = "1" /* Dilation of Left Lacrimal Duct, Via Natural or Artificial Opening */
"087Y8DZ" = "1" /* Dilation of Left Lacrimal Duct with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"087Y8ZZ" = "1" /* Dilation of Left Lacrimal Duct, Via Natural or Artificial Opening Endoscopic */
"0890X0Z" = "1" /* Drainage of Right Eye with Drainage Device, External Approach */
"0891X0Z" = "1" /* Drainage of Left Eye with Drainage Device, External Approach */
"089230Z" = "1" /* Drainage of Right Anterior Chamber with Drainage Device, Percutaneous Approach */
"08923ZX" = "1" /* Drainage of Right Anterior Chamber, Percutaneous Approach, Diagnostic */
"08923ZZ" = "1" /* Drainage of Right Anterior Chamber, Percutaneous Approach */
"089330Z" = "1" /* Drainage of Left Anterior Chamber with Drainage Device, Percutaneous Approach */
"08933ZX" = "1" /* Drainage of Left Anterior Chamber, Percutaneous Approach, Diagnostic */
"08933ZZ" = "1" /* Drainage of Left Anterior Chamber, Percutaneous Approach */
"089430Z" = "1" /* Drainage of Right Vitreous with Drainage Device, Percutaneous Approach */
"08943ZX" = "1" /* Drainage of Right Vitreous, Percutaneous Approach, Diagnostic */
"08943ZZ" = "1" /* Drainage of Right Vitreous, Percutaneous Approach */
"089530Z" = "1" /* Drainage of Left Vitreous with Drainage Device, Percutaneous Approach */
"08953ZX" = "1" /* Drainage of Left Vitreous, Percutaneous Approach, Diagnostic */
"08953ZZ" = "1" /* Drainage of Left Vitreous, Percutaneous Approach */
"0896X0Z" = "1" /* Drainage of Right Sclera with Drainage Device, External Approach */
"0897X0Z" = "1" /* Drainage of Left Sclera with Drainage Device, External Approach */
"0898X0Z" = "1" /* Drainage of Right Cornea with Drainage Device, External Approach */
"0899X0Z" = "1" /* Drainage of Left Cornea with Drainage Device, External Approach */
"089A00Z" = "1" /* Drainage of Right Choroid with Drainage Device, Open Approach */
"089A0ZX" = "1" /* Drainage of Right Choroid, Open Approach, Diagnostic */
"089A0ZZ" = "1" /* Drainage of Right Choroid, Open Approach */
"089A30Z" = "1" /* Drainage of Right Choroid with Drainage Device, Percutaneous Approach */
"089A3ZX" = "1" /* Drainage of Right Choroid, Percutaneous Approach, Diagnostic */
"089A3ZZ" = "1" /* Drainage of Right Choroid, Percutaneous Approach */
"089B00Z" = "1" /* Drainage of Left Choroid with Drainage Device, Open Approach */
"089B0ZX" = "1" /* Drainage of Left Choroid, Open Approach, Diagnostic */
"089B0ZZ" = "1" /* Drainage of Left Choroid, Open Approach */
"089B30Z" = "1" /* Drainage of Left Choroid with Drainage Device, Percutaneous Approach */
"089B3ZX" = "1" /* Drainage of Left Choroid, Percutaneous Approach, Diagnostic */
"089B3ZZ" = "1" /* Drainage of Left Choroid, Percutaneous Approach */
"089C30Z" = "1" /* Drainage of Right Iris with Drainage Device, Percutaneous Approach */
"089C3ZX" = "1" /* Drainage of Right Iris, Percutaneous Approach, Diagnostic */
"089C3ZZ" = "1" /* Drainage of Right Iris, Percutaneous Approach */
"089D30Z" = "1" /* Drainage of Left Iris with Drainage Device, Percutaneous Approach */
"089D3ZX" = "1" /* Drainage of Left Iris, Percutaneous Approach, Diagnostic */
"089D3ZZ" = "1" /* Drainage of Left Iris, Percutaneous Approach */
"089E30Z" = "1" /* Drainage of Right Retina with Drainage Device, Percutaneous Approach */
"089E3ZX" = "1" /* Drainage of Right Retina, Percutaneous Approach, Diagnostic */
"089E3ZZ" = "1" /* Drainage of Right Retina, Percutaneous Approach */
"089F30Z" = "1" /* Drainage of Left Retina with Drainage Device, Percutaneous Approach */
"089F3ZX" = "1" /* Drainage of Left Retina, Percutaneous Approach, Diagnostic */
"089F3ZZ" = "1" /* Drainage of Left Retina, Percutaneous Approach */
"089G30Z" = "1" /* Drainage of Right Retinal Vessel with Drainage Device, Percutaneous Approach */
"089G3ZX" = "1" /* Drainage of Right Retinal Vessel, Percutaneous Approach, Diagnostic */
"089G3ZZ" = "1" /* Drainage of Right Retinal Vessel, Percutaneous Approach */
"089H30Z" = "1" /* Drainage of Left Retinal Vessel with Drainage Device, Percutaneous Approach */
"089H3ZX" = "1" /* Drainage of Left Retinal Vessel, Percutaneous Approach, Diagnostic */
"089H3ZZ" = "1" /* Drainage of Left Retinal Vessel, Percutaneous Approach */
"089J30Z" = "1" /* Drainage of Right Lens with Drainage Device, Percutaneous Approach */
"089J3ZX" = "1" /* Drainage of Right Lens, Percutaneous Approach, Diagnostic */
"089J3ZZ" = "1" /* Drainage of Right Lens, Percutaneous Approach */
"089K30Z" = "1" /* Drainage of Left Lens with Drainage Device, Percutaneous Approach */
"089K3ZX" = "1" /* Drainage of Left Lens, Percutaneous Approach, Diagnostic */
"089K3ZZ" = "1" /* Drainage of Left Lens, Percutaneous Approach */
"089L00Z" = "1" /* Drainage of Right Extraocular Muscle with Drainage Device, Open Approach */
"089L0ZX" = "1" /* Drainage of Right Extraocular Muscle, Open Approach, Diagnostic */
"089L0ZZ" = "1" /* Drainage of Right Extraocular Muscle, Open Approach */
"089L30Z" = "1" /* Drainage of Right Extraocular Muscle with Drainage Device, Percutaneous Approach */
"089L3ZX" = "1" /* Drainage of Right Extraocular Muscle, Percutaneous Approach, Diagnostic */
"089L3ZZ" = "1" /* Drainage of Right Extraocular Muscle, Percutaneous Approach */
"089M00Z" = "1" /* Drainage of Left Extraocular Muscle with Drainage Device, Open Approach */
"089M0ZX" = "1" /* Drainage of Left Extraocular Muscle, Open Approach, Diagnostic */
"089M0ZZ" = "1" /* Drainage of Left Extraocular Muscle, Open Approach */
"089M30Z" = "1" /* Drainage of Left Extraocular Muscle with Drainage Device, Percutaneous Approach */
"089M3ZX" = "1" /* Drainage of Left Extraocular Muscle, Percutaneous Approach, Diagnostic */
"089M3ZZ" = "1" /* Drainage of Left Extraocular Muscle, Percutaneous Approach */
"089N0ZX" = "1" /* Drainage of Right Upper Eyelid, Open Approach, Diagnostic */
"089P0ZX" = "1" /* Drainage of Left Upper Eyelid, Open Approach, Diagnostic */
"089Q0ZX" = "1" /* Drainage of Right Lower Eyelid, Open Approach, Diagnostic */
"089R0ZX" = "1" /* Drainage of Left Lower Eyelid, Open Approach, Diagnostic */
"089SX0Z" = "1" /* Drainage of Right Conjunctiva with Drainage Device, External Approach */
"089TX0Z" = "1" /* Drainage of Left Conjunctiva with Drainage Device, External Approach */
"089V00Z" = "1" /* Drainage of Right Lacrimal Gland with Drainage Device, Open Approach */
"089V0ZX" = "1" /* Drainage of Right Lacrimal Gland, Open Approach, Diagnostic */
"089V0ZZ" = "1" /* Drainage of Right Lacrimal Gland, Open Approach */
"089V30Z" = "1" /* Drainage of Right Lacrimal Gland with Drainage Device, Percutaneous Approach */
"089V3ZX" = "1" /* Drainage of Right Lacrimal Gland, Percutaneous Approach, Diagnostic */
"089V3ZZ" = "1" /* Drainage of Right Lacrimal Gland, Percutaneous Approach */
"089W00Z" = "1" /* Drainage of Left Lacrimal Gland with Drainage Device, Open Approach */
"089W0ZX" = "1" /* Drainage of Left Lacrimal Gland, Open Approach, Diagnostic */
"089W0ZZ" = "1" /* Drainage of Left Lacrimal Gland, Open Approach */
"089W30Z" = "1" /* Drainage of Left Lacrimal Gland with Drainage Device, Percutaneous Approach */
"089W3ZX" = "1" /* Drainage of Left Lacrimal Gland, Percutaneous Approach, Diagnostic */
"089W3ZZ" = "1" /* Drainage of Left Lacrimal Gland, Percutaneous Approach */
"089X00Z" = "1" /* Drainage of Right Lacrimal Duct with Drainage Device, Open Approach */
"089X0ZX" = "1" /* Drainage of Right Lacrimal Duct, Open Approach, Diagnostic */
"089X0ZZ" = "1" /* Drainage of Right Lacrimal Duct, Open Approach */
"089X30Z" = "1" /* Drainage of Right Lacrimal Duct with Drainage Device, Percutaneous Approach */
"089X3ZX" = "1" /* Drainage of Right Lacrimal Duct, Percutaneous Approach, Diagnostic */
"089X3ZZ" = "1" /* Drainage of Right Lacrimal Duct, Percutaneous Approach */
"089X70Z" = "1" /* Drainage of Right Lacrimal Duct with Drainage Device, Via Natural or Artificial Opening */
"089X7ZX" = "1" /* Drainage of Right Lacrimal Duct, Via Natural or Artificial Opening, Diagnostic */
"089X7ZZ" = "1" /* Drainage of Right Lacrimal Duct, Via Natural or Artificial Opening */
"089X80Z" = "1" /* Drainage of Right Lacrimal Duct with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"089X8ZX" = "1" /* Drainage of Right Lacrimal Duct, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"089X8ZZ" = "1" /* Drainage of Right Lacrimal Duct, Via Natural or Artificial Opening Endoscopic */
"089Y00Z" = "1" /* Drainage of Left Lacrimal Duct with Drainage Device, Open Approach */
"089Y0ZX" = "1" /* Drainage of Left Lacrimal Duct, Open Approach, Diagnostic */
"089Y0ZZ" = "1" /* Drainage of Left Lacrimal Duct, Open Approach */
"089Y30Z" = "1" /* Drainage of Left Lacrimal Duct with Drainage Device, Percutaneous Approach */
"089Y3ZX" = "1" /* Drainage of Left Lacrimal Duct, Percutaneous Approach, Diagnostic */
"089Y3ZZ" = "1" /* Drainage of Left Lacrimal Duct, Percutaneous Approach */
"089Y70Z" = "1" /* Drainage of Left Lacrimal Duct with Drainage Device, Via Natural or Artificial Opening */
"089Y7ZX" = "1" /* Drainage of Left Lacrimal Duct, Via Natural or Artificial Opening, Diagnostic */
"089Y7ZZ" = "1" /* Drainage of Left Lacrimal Duct, Via Natural or Artificial Opening */
"089Y80Z" = "1" /* Drainage of Left Lacrimal Duct with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"089Y8ZX" = "1" /* Drainage of Left Lacrimal Duct, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"089Y8ZZ" = "1" /* Drainage of Left Lacrimal Duct, Via Natural or Artificial Opening Endoscopic */
"08B00ZX" = "1" /* Excision of Right Eye, Open Approach, Diagnostic */
"08B00ZZ" = "1" /* Excision of Right Eye, Open Approach */
"08B03ZX" = "1" /* Excision of Right Eye, Percutaneous Approach, Diagnostic */
"08B03ZZ" = "1" /* Excision of Right Eye, Percutaneous Approach */
"08B0XZX" = "1" /* Excision of Right Eye, External Approach, Diagnostic */
"08B0XZZ" = "1" /* Excision of Right Eye, External Approach */
"08B10ZX" = "1" /* Excision of Left Eye, Open Approach, Diagnostic */
"08B10ZZ" = "1" /* Excision of Left Eye, Open Approach */
"08B13ZX" = "1" /* Excision of Left Eye, Percutaneous Approach, Diagnostic */
"08B13ZZ" = "1" /* Excision of Left Eye, Percutaneous Approach */
"08B1XZX" = "1" /* Excision of Left Eye, External Approach, Diagnostic */
"08B1XZZ" = "1" /* Excision of Left Eye, External Approach */
"08B43ZX" = "1" /* Excision of Right Vitreous, Percutaneous Approach, Diagnostic */
"08B43ZZ" = "1" /* Excision of Right Vitreous, Percutaneous Approach */
"08B53ZX" = "1" /* Excision of Left Vitreous, Percutaneous Approach, Diagnostic */
"08B53ZZ" = "1" /* Excision of Left Vitreous, Percutaneous Approach */
"08B6XZX" = "1" /* Excision of Right Sclera, External Approach, Diagnostic */
"08B6XZZ" = "1" /* Excision of Right Sclera, External Approach */
"08B7XZX" = "1" /* Excision of Left Sclera, External Approach, Diagnostic */
"08B7XZZ" = "1" /* Excision of Left Sclera, External Approach */
"08B8XZX" = "1" /* Excision of Right Cornea, External Approach, Diagnostic */
"08B8XZZ" = "1" /* Excision of Right Cornea, External Approach */
"08B9XZX" = "1" /* Excision of Left Cornea, External Approach, Diagnostic */
"08B9XZZ" = "1" /* Excision of Left Cornea, External Approach */
"08BA0ZX" = "1" /* Excision of Right Choroid, Open Approach, Diagnostic */
"08BA0ZZ" = "1" /* Excision of Right Choroid, Open Approach */
"08BA3ZX" = "1" /* Excision of Right Choroid, Percutaneous Approach, Diagnostic */
"08BA3ZZ" = "1" /* Excision of Right Choroid, Percutaneous Approach */
"08BB0ZX" = "1" /* Excision of Left Choroid, Open Approach, Diagnostic */
"08BB0ZZ" = "1" /* Excision of Left Choroid, Open Approach */
"08BB3ZX" = "1" /* Excision of Left Choroid, Percutaneous Approach, Diagnostic */
"08BB3ZZ" = "1" /* Excision of Left Choroid, Percutaneous Approach */
"08BC3ZX" = "1" /* Excision of Right Iris, Percutaneous Approach, Diagnostic */
"08BC3ZZ" = "1" /* Excision of Right Iris, Percutaneous Approach */
"08BD3ZX" = "1" /* Excision of Left Iris, Percutaneous Approach, Diagnostic */
"08BD3ZZ" = "1" /* Excision of Left Iris, Percutaneous Approach */
"08BE3ZX" = "1" /* Excision of Right Retina, Percutaneous Approach, Diagnostic */
"08BE3ZZ" = "1" /* Excision of Right Retina, Percutaneous Approach */
"08BF3ZX" = "1" /* Excision of Left Retina, Percutaneous Approach, Diagnostic */
"08BF3ZZ" = "1" /* Excision of Left Retina, Percutaneous Approach */
"08BJ3ZX" = "1" /* Excision of Right Lens, Percutaneous Approach, Diagnostic */
"08BJ3ZZ" = "1" /* Excision of Right Lens, Percutaneous Approach */
"08BK3ZX" = "1" /* Excision of Left Lens, Percutaneous Approach, Diagnostic */
"08BK3ZZ" = "1" /* Excision of Left Lens, Percutaneous Approach */
"08BL0ZX" = "1" /* Excision of Right Extraocular Muscle, Open Approach, Diagnostic */
"08BL0ZZ" = "1" /* Excision of Right Extraocular Muscle, Open Approach */
"08BL3ZX" = "1" /* Excision of Right Extraocular Muscle, Percutaneous Approach, Diagnostic */
"08BL3ZZ" = "1" /* Excision of Right Extraocular Muscle, Percutaneous Approach */
"08BM0ZX" = "1" /* Excision of Left Extraocular Muscle, Open Approach, Diagnostic */
"08BM0ZZ" = "1" /* Excision of Left Extraocular Muscle, Open Approach */
"08BM3ZX" = "1" /* Excision of Left Extraocular Muscle, Percutaneous Approach, Diagnostic */
"08BM3ZZ" = "1" /* Excision of Left Extraocular Muscle, Percutaneous Approach */
"08BN0ZX" = "1" /* Excision of Right Upper Eyelid, Open Approach, Diagnostic */
"08BN0ZZ" = "1" /* Excision of Right Upper Eyelid, Open Approach */
"08BN3ZX" = "1" /* Excision of Right Upper Eyelid, Percutaneous Approach, Diagnostic */
"08BN3ZZ" = "1" /* Excision of Right Upper Eyelid, Percutaneous Approach */
"08BNXZX" = "1" /* Excision of Right Upper Eyelid, External Approach, Diagnostic */
"08BNXZZ" = "1" /* Excision of Right Upper Eyelid, External Approach */
"08BP0ZX" = "1" /* Excision of Left Upper Eyelid, Open Approach, Diagnostic */
"08BP0ZZ" = "1" /* Excision of Left Upper Eyelid, Open Approach */
"08BP3ZX" = "1" /* Excision of Left Upper Eyelid, Percutaneous Approach, Diagnostic */
"08BP3ZZ" = "1" /* Excision of Left Upper Eyelid, Percutaneous Approach */
"08BPXZX" = "1" /* Excision of Left Upper Eyelid, External Approach, Diagnostic */
"08BPXZZ" = "1" /* Excision of Left Upper Eyelid, External Approach */
"08BQ0ZX" = "1" /* Excision of Right Lower Eyelid, Open Approach, Diagnostic */
"08BQ0ZZ" = "1" /* Excision of Right Lower Eyelid, Open Approach */
"08BQ3ZX" = "1" /* Excision of Right Lower Eyelid, Percutaneous Approach, Diagnostic */
"08BQ3ZZ" = "1" /* Excision of Right Lower Eyelid, Percutaneous Approach */
"08BQXZX" = "1" /* Excision of Right Lower Eyelid, External Approach, Diagnostic */
"08BQXZZ" = "1" /* Excision of Right Lower Eyelid, External Approach */
"08BR0ZX" = "1" /* Excision of Left Lower Eyelid, Open Approach, Diagnostic */
"08BR0ZZ" = "1" /* Excision of Left Lower Eyelid, Open Approach */
"08BR3ZX" = "1" /* Excision of Left Lower Eyelid, Percutaneous Approach, Diagnostic */
"08BR3ZZ" = "1" /* Excision of Left Lower Eyelid, Percutaneous Approach */
"08BRXZX" = "1" /* Excision of Left Lower Eyelid, External Approach, Diagnostic */
"08BRXZZ" = "1" /* Excision of Left Lower Eyelid, External Approach */
"08BSXZX" = "1" /* Excision of Right Conjunctiva, External Approach, Diagnostic */
"08BSXZZ" = "1" /* Excision of Right Conjunctiva, External Approach */
"08BTXZX" = "1" /* Excision of Left Conjunctiva, External Approach, Diagnostic */
"08BTXZZ" = "1" /* Excision of Left Conjunctiva, External Approach */
"08BV0ZX" = "1" /* Excision of Right Lacrimal Gland, Open Approach, Diagnostic */
"08BV0ZZ" = "1" /* Excision of Right Lacrimal Gland, Open Approach */
"08BV3ZX" = "1" /* Excision of Right Lacrimal Gland, Percutaneous Approach, Diagnostic */
"08BV3ZZ" = "1" /* Excision of Right Lacrimal Gland, Percutaneous Approach */
"08BW0ZX" = "1" /* Excision of Left Lacrimal Gland, Open Approach, Diagnostic */
"08BW0ZZ" = "1" /* Excision of Left Lacrimal Gland, Open Approach */
"08BW3ZX" = "1" /* Excision of Left Lacrimal Gland, Percutaneous Approach, Diagnostic */
"08BW3ZZ" = "1" /* Excision of Left Lacrimal Gland, Percutaneous Approach */
"08BX0ZX" = "1" /* Excision of Right Lacrimal Duct, Open Approach, Diagnostic */
"08BX0ZZ" = "1" /* Excision of Right Lacrimal Duct, Open Approach */
"08BX3ZX" = "1" /* Excision of Right Lacrimal Duct, Percutaneous Approach, Diagnostic */
"08BX3ZZ" = "1" /* Excision of Right Lacrimal Duct, Percutaneous Approach */
"08BX7ZX" = "1" /* Excision of Right Lacrimal Duct, Via Natural or Artificial Opening, Diagnostic */
"08BX7ZZ" = "1" /* Excision of Right Lacrimal Duct, Via Natural or Artificial Opening */
"08BX8ZX" = "1" /* Excision of Right Lacrimal Duct, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"08BX8ZZ" = "1" /* Excision of Right Lacrimal Duct, Via Natural or Artificial Opening Endoscopic */
"08BY0ZX" = "1" /* Excision of Left Lacrimal Duct, Open Approach, Diagnostic */
"08BY0ZZ" = "1" /* Excision of Left Lacrimal Duct, Open Approach */
"08BY3ZX" = "1" /* Excision of Left Lacrimal Duct, Percutaneous Approach, Diagnostic */
"08BY3ZZ" = "1" /* Excision of Left Lacrimal Duct, Percutaneous Approach */
"08BY7ZX" = "1" /* Excision of Left Lacrimal Duct, Via Natural or Artificial Opening, Diagnostic */
"08BY7ZZ" = "1" /* Excision of Left Lacrimal Duct, Via Natural or Artificial Opening */
"08BY8ZX" = "1" /* Excision of Left Lacrimal Duct, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"08BY8ZZ" = "1" /* Excision of Left Lacrimal Duct, Via Natural or Artificial Opening Endoscopic */
"08C23ZZ" = "1" /* Extirpation of Matter from Right Anterior Chamber, Percutaneous Approach */
"08C33ZZ" = "1" /* Extirpation of Matter from Left Anterior Chamber, Percutaneous Approach */
"08C43ZZ" = "1" /* Extirpation of Matter from Right Vitreous, Percutaneous Approach */
"08C4XZZ" = "1" /* Extirpation of Matter from Right Vitreous, External Approach */
"08C53ZZ" = "1" /* Extirpation of Matter from Left Vitreous, Percutaneous Approach */
"08C5XZZ" = "1" /* Extirpation of Matter from Left Vitreous, External Approach */
"08C8XZZ" = "1" /* Extirpation of Matter from Right Cornea, External Approach */
"08C9XZZ" = "1" /* Extirpation of Matter from Left Cornea, External Approach */
"08CA0ZZ" = "1" /* Extirpation of Matter from Right Choroid, Open Approach */
"08CA3ZZ" = "1" /* Extirpation of Matter from Right Choroid, Percutaneous Approach */
"08CAXZZ" = "1" /* Extirpation of Matter from Right Choroid, External Approach */
"08CB0ZZ" = "1" /* Extirpation of Matter from Left Choroid, Open Approach */
"08CB3ZZ" = "1" /* Extirpation of Matter from Left Choroid, Percutaneous Approach */
"08CBXZZ" = "1" /* Extirpation of Matter from Left Choroid, External Approach */
"08CC3ZZ" = "1" /* Extirpation of Matter from Right Iris, Percutaneous Approach */
"08CCXZZ" = "1" /* Extirpation of Matter from Right Iris, External Approach */
"08CD3ZZ" = "1" /* Extirpation of Matter from Left Iris, Percutaneous Approach */
"08CDXZZ" = "1" /* Extirpation of Matter from Left Iris, External Approach */
"08CE3ZZ" = "1" /* Extirpation of Matter from Right Retina, Percutaneous Approach */
"08CEXZZ" = "1" /* Extirpation of Matter from Right Retina, External Approach */
"08CF3ZZ" = "1" /* Extirpation of Matter from Left Retina, Percutaneous Approach */
"08CFXZZ" = "1" /* Extirpation of Matter from Left Retina, External Approach */
"08CG3ZZ" = "1" /* Extirpation of Matter from Right Retinal Vessel, Percutaneous Approach */
"08CGXZZ" = "1" /* Extirpation of Matter from Right Retinal Vessel, External Approach */
"08CH3ZZ" = "1" /* Extirpation of Matter from Left Retinal Vessel, Percutaneous Approach */
"08CHXZZ" = "1" /* Extirpation of Matter from Left Retinal Vessel, External Approach */
"08CJ3ZZ" = "1" /* Extirpation of Matter from Right Lens, Percutaneous Approach */
"08CJXZZ" = "1" /* Extirpation of Matter from Right Lens, External Approach */
"08CK3ZZ" = "1" /* Extirpation of Matter from Left Lens, Percutaneous Approach */
"08CKXZZ" = "1" /* Extirpation of Matter from Left Lens, External Approach */
"08CL0ZZ" = "1" /* Extirpation of Matter from Right Extraocular Muscle, Open Approach */
"08CL3ZZ" = "1" /* Extirpation of Matter from Right Extraocular Muscle, Percutaneous Approach */
"08CLXZZ" = "1" /* Extirpation of Matter from Right Extraocular Muscle, External Approach */
"08CM0ZZ" = "1" /* Extirpation of Matter from Left Extraocular Muscle, Open Approach */
"08CM3ZZ" = "1" /* Extirpation of Matter from Left Extraocular Muscle, Percutaneous Approach */
"08CMXZZ" = "1" /* Extirpation of Matter from Left Extraocular Muscle, External Approach */
"08CV0ZZ" = "1" /* Extirpation of Matter from Right Lacrimal Gland, Open Approach */
"08CV3ZZ" = "1" /* Extirpation of Matter from Right Lacrimal Gland, Percutaneous Approach */
"08CVXZZ" = "1" /* Extirpation of Matter from Right Lacrimal Gland, External Approach */
"08CW0ZZ" = "1" /* Extirpation of Matter from Left Lacrimal Gland, Open Approach */
"08CW3ZZ" = "1" /* Extirpation of Matter from Left Lacrimal Gland, Percutaneous Approach */
"08CWXZZ" = "1" /* Extirpation of Matter from Left Lacrimal Gland, External Approach */
"08CX0ZZ" = "1" /* Extirpation of Matter from Right Lacrimal Duct, Open Approach */
"08CX3ZZ" = "1" /* Extirpation of Matter from Right Lacrimal Duct, Percutaneous Approach */
"08CX7ZZ" = "1" /* Extirpation of Matter from Right Lacrimal Duct, Via Natural or Artificial Opening */
"08CX8ZZ" = "1" /* Extirpation of Matter from Right Lacrimal Duct, Via Natural or Artificial Opening Endoscopic */
"08CY0ZZ" = "1" /* Extirpation of Matter from Left Lacrimal Duct, Open Approach */
"08CY3ZZ" = "1" /* Extirpation of Matter from Left Lacrimal Duct, Percutaneous Approach */
"08CY7ZZ" = "1" /* Extirpation of Matter from Left Lacrimal Duct, Via Natural or Artificial Opening */
"08CY8ZZ" = "1" /* Extirpation of Matter from Left Lacrimal Duct, Via Natural or Artificial Opening Endoscopic */
"08D8XZX" = "1" /* Extraction of Right Cornea, External Approach, Diagnostic */
"08D8XZZ" = "1" /* Extraction of Right Cornea, External Approach */
"08D9XZX" = "1" /* Extraction of Left Cornea, External Approach, Diagnostic */
"08D9XZZ" = "1" /* Extraction of Left Cornea, External Approach */
"08DJ3ZZ" = "1" /* Extraction of Right Lens, Percutaneous Approach */
"08DK3ZZ" = "1" /* Extraction of Left Lens, Percutaneous Approach */
"08F43ZZ" = "1" /* Fragmentation in Right Vitreous, Percutaneous Approach */
"08F53ZZ" = "1" /* Fragmentation in Left Vitreous, Percutaneous Approach */
"08H005Z" = "1" /* Insertion of Epiret Prosthetic  into Right Eye, Open Approach */
"08H031Z" = "1" /* Insertion of Radioactive Element into Right Eye, Percutaneous Approach */
"08H033Z" = "1" /* Insertion of Infusion Device into Right Eye, Percutaneous Approach */
"08H0X1Z" = "1" /* Insertion of Radioactive Element into Right Eye, External Approach */
"08H0X3Z" = "1" /* Insertion of Infusion Device into Right Eye, External Approach */
"08H105Z" = "1" /* Insertion of Epiret Prosthetic  into Left Eye, Open Approach */
"08H131Z" = "1" /* Insertion of Radioactive Element into Left Eye, Percutaneous Approach */
"08H133Z" = "1" /* Insertion of Infusion Device into Left Eye, Percutaneous Approach */
"08H1X1Z" = "1" /* Insertion of Radioactive Element into Left Eye, External Approach */
"08H1X3Z" = "1" /* Insertion of Infusion Device into Left Eye, External Approach */
"08JL0ZZ" = "1" /* Inspection of Right Extraocular Muscle, Open Approach */
"08JM0ZZ" = "1" /* Inspection of Left Extraocular Muscle, Open Approach */
"08LX0CZ" = "1" /* Occlusion of Right Lacrimal Duct with Extraluminal Device, Open Approach */
"08LX0DZ" = "1" /* Occlusion of Right Lacrimal Duct with Intraluminal Device, Open Approach */
"08LX0ZZ" = "1" /* Occlusion of Right Lacrimal Duct, Open Approach */
"08LX3CZ" = "1" /* Occlusion of Right Lacrimal Duct with Extraluminal Device, Percutaneous Approach */
"08LX3DZ" = "1" /* Occlusion of Right Lacrimal Duct with Intraluminal Device, Percutaneous Approach */
"08LX3ZZ" = "1" /* Occlusion of Right Lacrimal Duct, Percutaneous Approach */
"08LX7DZ" = "1" /* Occlusion of Right Lacrimal Duct with Intraluminal Device, Via Natural or Artificial Opening */
"08LX7ZZ" = "1" /* Occlusion of Right Lacrimal Duct, Via Natural or Artificial Opening */
"08LX8DZ" = "1" /* Occlusion of Right Lacrimal Duct with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"08LX8ZZ" = "1" /* Occlusion of Right Lacrimal Duct, Via Natural or Artificial Opening Endoscopic */
"08LY0CZ" = "1" /* Occlusion of Left Lacrimal Duct with Extraluminal Device, Open Approach */
"08LY0DZ" = "1" /* Occlusion of Left Lacrimal Duct with Intraluminal Device, Open Approach */
"08LY0ZZ" = "1" /* Occlusion of Left Lacrimal Duct, Open Approach */
"08LY3CZ" = "1" /* Occlusion of Left Lacrimal Duct with Extraluminal Device, Percutaneous Approach */
"08LY3DZ" = "1" /* Occlusion of Left Lacrimal Duct with Intraluminal Device, Percutaneous Approach */
"08LY3ZZ" = "1" /* Occlusion of Left Lacrimal Duct, Percutaneous Approach */
"08LY7DZ" = "1" /* Occlusion of Left Lacrimal Duct with Intraluminal Device, Via Natural or Artificial Opening */
"08LY7ZZ" = "1" /* Occlusion of Left Lacrimal Duct, Via Natural or Artificial Opening */
"08LY8DZ" = "1" /* Occlusion of Left Lacrimal Duct with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"08LY8ZZ" = "1" /* Occlusion of Left Lacrimal Duct, Via Natural or Artificial Opening Endoscopic */
"08MNXZZ" = "1" /* Reattachment of Right Upper Eyelid, External Approach */
"08MPXZZ" = "1" /* Reattachment of Left Upper Eyelid, External Approach */
"08MQXZZ" = "1" /* Reattachment of Right Lower Eyelid, External Approach */
"08MRXZZ" = "1" /* Reattachment of Left Lower Eyelid, External Approach */
"08N0XZZ" = "1" /* Release Right Eye, External Approach */
"08N1XZZ" = "1" /* Release Left Eye, External Approach */
"08N23ZZ" = "1" /* Release Right Anterior Chamber, Percutaneous Approach */
"08N33ZZ" = "1" /* Release Left Anterior Chamber, Percutaneous Approach */
"08N43ZZ" = "1" /* Release Right Vitreous, Percutaneous Approach */
"08N53ZZ" = "1" /* Release Left Vitreous, Percutaneous Approach */
"08N6XZZ" = "1" /* Release Right Sclera, External Approach */
"08N7XZZ" = "1" /* Release Left Sclera, External Approach */
"08N8XZZ" = "1" /* Release Right Cornea, External Approach */
"08N9XZZ" = "1" /* Release Left Cornea, External Approach */
"08NA0ZZ" = "1" /* Release Right Choroid, Open Approach */
"08NA3ZZ" = "1" /* Release Right Choroid, Percutaneous Approach */
"08NB0ZZ" = "1" /* Release Left Choroid, Open Approach */
"08NB3ZZ" = "1" /* Release Left Choroid, Percutaneous Approach */
"08NC3ZZ" = "1" /* Release Right Iris, Percutaneous Approach */
"08ND3ZZ" = "1" /* Release Left Iris, Percutaneous Approach */
"08NE3ZZ" = "1" /* Release Right Retina, Percutaneous Approach */
"08NF3ZZ" = "1" /* Release Left Retina, Percutaneous Approach */
"08NG3ZZ" = "1" /* Release Right Retinal Vessel, Percutaneous Approach */
"08NH3ZZ" = "1" /* Release Left Retinal Vessel, Percutaneous Approach */
"08NJ3ZZ" = "1" /* Release Right Lens, Percutaneous Approach */
"08NK3ZZ" = "1" /* Release Left Lens, Percutaneous Approach */
"08NL0ZZ" = "1" /* Release Right Extraocular Muscle, Open Approach */
"08NL3ZZ" = "1" /* Release Right Extraocular Muscle, Percutaneous Approach */
"08NM0ZZ" = "1" /* Release Left Extraocular Muscle, Open Approach */
"08NM3ZZ" = "1" /* Release Left Extraocular Muscle, Percutaneous Approach */
"08NN0ZZ" = "1" /* Release Right Upper Eyelid, Open Approach */
"08NN3ZZ" = "1" /* Release Right Upper Eyelid, Percutaneous Approach */
"08NNXZZ" = "1" /* Release Right Upper Eyelid, External Approach */
"08NP0ZZ" = "1" /* Release Left Upper Eyelid, Open Approach */
"08NP3ZZ" = "1" /* Release Left Upper Eyelid, Percutaneous Approach */
"08NPXZZ" = "1" /* Release Left Upper Eyelid, External Approach */
"08NQ0ZZ" = "1" /* Release Right Lower Eyelid, Open Approach */
"08NQ3ZZ" = "1" /* Release Right Lower Eyelid, Percutaneous Approach */
"08NQXZZ" = "1" /* Release Right Lower Eyelid, External Approach */
"08NR0ZZ" = "1" /* Release Left Lower Eyelid, Open Approach */
"08NR3ZZ" = "1" /* Release Left Lower Eyelid, Percutaneous Approach */
"08NRXZZ" = "1" /* Release Left Lower Eyelid, External Approach */
"08NSXZZ" = "1" /* Release Right Conjunctiva, External Approach */
"08NTXZZ" = "1" /* Release Left Conjunctiva, External Approach */
"08NV0ZZ" = "1" /* Release Right Lacrimal Gland, Open Approach */
"08NV3ZZ" = "1" /* Release Right Lacrimal Gland, Percutaneous Approach */
"08NW0ZZ" = "1" /* Release Left Lacrimal Gland, Open Approach */
"08NW3ZZ" = "1" /* Release Left Lacrimal Gland, Percutaneous Approach */
"08NX0ZZ" = "1" /* Release Right Lacrimal Duct, Open Approach */
"08NX3ZZ" = "1" /* Release Right Lacrimal Duct, Percutaneous Approach */
"08NX7ZZ" = "1" /* Release Right Lacrimal Duct, Via Natural or Artificial Opening */
"08NX8ZZ" = "1" /* Release Right Lacrimal Duct, Via Natural or Artificial Opening Endoscopic */
"08NY0ZZ" = "1" /* Release Left Lacrimal Duct, Open Approach */
"08NY3ZZ" = "1" /* Release Left Lacrimal Duct, Percutaneous Approach */
"08NY7ZZ" = "1" /* Release Left Lacrimal Duct, Via Natural or Artificial Opening */
"08NY8ZZ" = "1" /* Release Left Lacrimal Duct, Via Natural or Artificial Opening Endoscopic */
"08P000Z" = "1" /* Removal of Drainage Device from Right Eye, Open Approach */
"08P001Z" = "1" /* Removal of Radioactive Element from Right Eye, Open Approach */
"08P003Z" = "1" /* Removal of Infusion Device from Right Eye, Open Approach */
"08P007Z" = "1" /* Removal of Autologous Tissue Substitute from Right Eye, Open Approach */
"08P00CZ" = "1" /* Removal of Extraluminal Device from Right Eye, Open Approach */
"08P00DZ" = "1" /* Removal of Intraluminal Device from Right Eye, Open Approach */
"08P00JZ" = "1" /* Removal of Synthetic Substitute from Right Eye, Open Approach */
"08P00KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Eye, Open Approach */
"08P030Z" = "1" /* Removal of Drainage Device from Right Eye, Percutaneous Approach */
"08P031Z" = "1" /* Removal of Radioactive Element from Right Eye, Percutaneous Approach */
"08P033Z" = "1" /* Removal of Infusion Device from Right Eye, Percutaneous Approach */
"08P037Z" = "1" /* Removal of Autologous Tissue Substitute from Right Eye, Percutaneous Approach */
"08P03CZ" = "1" /* Removal of Extraluminal Device from Right Eye, Percutaneous Approach */
"08P03DZ" = "1" /* Removal of Intraluminal Device from Right Eye, Percutaneous Approach */
"08P03JZ" = "1" /* Removal of Synthetic Substitute from Right Eye, Percutaneous Approach */
"08P03KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Eye, Percutaneous Approach */
"08P071Z" = "1" /* Removal of Radioactive Element from Right Eye, Via Natural or Artificial Opening */
"08P077Z" = "1" /* Removal of Autologous Tissue Substitute from Right Eye, Via Natural or Artificial Opening */
"08P07CZ" = "1" /* Removal of Extraluminal Device from Right Eye, Via Natural or Artificial Opening */
"08P07JZ" = "1" /* Removal of Synthetic Substitute from Right Eye, Via Natural or Artificial Opening */
"08P07KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Eye, Via Natural or Artificial Opening */
"08P081Z" = "1" /* Removal of Radioactive Element from Right Eye, Via Natural or Artificial Opening Endoscopic */
"08P087Z" = "1" /* Removal of Autologous Tissue Substitute from Right Eye, Via Natural or Artificial Opening Endoscopic */
"08P08CZ" = "1" /* Removal of Extraluminal Device from Right Eye, Via Natural or Artificial Opening Endoscopic */
"08P08JZ" = "1" /* Removal of Synthetic Substitute from Right Eye, Via Natural or Artificial Opening Endoscopic */
"08P08KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Eye, Via Natural or Artificial Opening Endoscopic */
"08P0X7Z" = "1" /* Removal of Autologous Tissue Substitute from Right Eye, External Approach */
"08P0XKZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Eye, External Approach */
"08P100Z" = "1" /* Removal of Drainage Device from Left Eye, Open Approach */
"08P101Z" = "1" /* Removal of Radioactive Element from Left Eye, Open Approach */
"08P103Z" = "1" /* Removal of Infusion Device from Left Eye, Open Approach */
"08P107Z" = "1" /* Removal of Autologous Tissue Substitute from Left Eye, Open Approach */
"08P10CZ" = "1" /* Removal of Extraluminal Device from Left Eye, Open Approach */
"08P10DZ" = "1" /* Removal of Intraluminal Device from Left Eye, Open Approach */
"08P10JZ" = "1" /* Removal of Synthetic Substitute from Left Eye, Open Approach */
"08P10KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Eye, Open Approach */
"08P130Z" = "1" /* Removal of Drainage Device from Left Eye, Percutaneous Approach */
"08P131Z" = "1" /* Removal of Radioactive Element from Left Eye, Percutaneous Approach */
"08P133Z" = "1" /* Removal of Infusion Device from Left Eye, Percutaneous Approach */
"08P137Z" = "1" /* Removal of Autologous Tissue Substitute from Left Eye, Percutaneous Approach */
"08P13CZ" = "1" /* Removal of Extraluminal Device from Left Eye, Percutaneous Approach */
"08P13DZ" = "1" /* Removal of Intraluminal Device from Left Eye, Percutaneous Approach */
"08P13JZ" = "1" /* Removal of Synthetic Substitute from Left Eye, Percutaneous Approach */
"08P13KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Eye, Percutaneous Approach */
"08P171Z" = "1" /* Removal of Radioactive Element from Left Eye, Via Natural or Artificial Opening */
"08P177Z" = "1" /* Removal of Autologous Tissue Substitute from Left Eye, Via Natural or Artificial Opening */
"08P17CZ" = "1" /* Removal of Extraluminal Device from Left Eye, Via Natural or Artificial Opening */
"08P17JZ" = "1" /* Removal of Synthetic Substitute from Left Eye, Via Natural or Artificial Opening */
"08P17KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Eye, Via Natural or Artificial Opening */
"08P181Z" = "1" /* Removal of Radioactive Element from Left Eye, Via Natural or Artificial Opening Endoscopic */
"08P187Z" = "1" /* Removal of Autologous Tissue Substitute from Left Eye, Via Natural or Artificial Opening Endoscopic */
"08P18CZ" = "1" /* Removal of Extraluminal Device from Left Eye, Via Natural or Artificial Opening Endoscopic */
"08P18JZ" = "1" /* Removal of Synthetic Substitute from Left Eye, Via Natural or Artificial Opening Endoscopic */
"08P18KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Eye, Via Natural or Artificial Opening Endoscopic */
"08P1X7Z" = "1" /* Removal of Autologous Tissue Substitute from Left Eye, External Approach */
"08P1XKZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Eye, External Approach */
"08PJ3JZ" = "1" /* Removal of Synthetic Substitute from Right Lens, Percutaneous Approach */
"08PK3JZ" = "1" /* Removal of Synthetic Substitute from Left Lens, Percutaneous Approach */
"08PL00Z" = "1" /* Removal of Drainage Device from Right Extraocular Muscle, Open Approach */
"08PL07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Extraocular Muscle, Open Approach */
"08PL0JZ" = "1" /* Removal of Synthetic Substitute from Right Extraocular Muscle, Open Approach */
"08PL0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Extraocular Muscle, Open Approach */
"08PL30Z" = "1" /* Removal of Drainage Device from Right Extraocular Muscle, Percutaneous Approach */
"08PL37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Extraocular Muscle, Percutaneous Approach */
"08PL3JZ" = "1" /* Removal of Synthetic Substitute from Right Extraocular Muscle, Percutaneous Approach */
"08PL3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Extraocular Muscle, Percutaneous Approach */
"08PM00Z" = "1" /* Removal of Drainage Device from Left Extraocular Muscle, Open Approach */
"08PM07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Extraocular Muscle, Open Approach */
"08PM0JZ" = "1" /* Removal of Synthetic Substitute from Left Extraocular Muscle, Open Approach */
"08PM0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Extraocular Muscle, Open Approach */
"08PM30Z" = "1" /* Removal of Drainage Device from Left Extraocular Muscle, Percutaneous Approach */
"08PM37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Extraocular Muscle, Percutaneous Approach */
"08PM3JZ" = "1" /* Removal of Synthetic Substitute from Left Extraocular Muscle, Percutaneous Approach */
"08PM3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Extraocular Muscle, Percutaneous Approach */
"08Q0XZZ" = "1" /* Repair Right Eye, External Approach */
"08Q1XZZ" = "1" /* Repair Left Eye, External Approach */
"08Q23ZZ" = "1" /* Repair Right Anterior Chamber, Percutaneous Approach */
"08Q33ZZ" = "1" /* Repair Left Anterior Chamber, Percutaneous Approach */
"08Q43ZZ" = "1" /* Repair Right Vitreous, Percutaneous Approach */
"08Q53ZZ" = "1" /* Repair Left Vitreous, Percutaneous Approach */
"08Q6XZZ" = "1" /* Repair Right Sclera, External Approach */
"08Q7XZZ" = "1" /* Repair Left Sclera, External Approach */
"08Q8XZZ" = "1" /* Repair Right Cornea, External Approach */
"08Q9XZZ" = "1" /* Repair Left Cornea, External Approach */
"08QA0ZZ" = "1" /* Repair Right Choroid, Open Approach */
"08QA3ZZ" = "1" /* Repair Right Choroid, Percutaneous Approach */
"08QB0ZZ" = "1" /* Repair Left Choroid, Open Approach */
"08QB3ZZ" = "1" /* Repair Left Choroid, Percutaneous Approach */
"08QC3ZZ" = "1" /* Repair Right Iris, Percutaneous Approach */
"08QD3ZZ" = "1" /* Repair Left Iris, Percutaneous Approach */
"08QE3ZZ" = "1" /* Repair Right Retina, Percutaneous Approach */
"08QF3ZZ" = "1" /* Repair Left Retina, Percutaneous Approach */
"08QG3ZZ" = "1" /* Repair Right Retinal Vessel, Percutaneous Approach */
"08QH3ZZ" = "1" /* Repair Left Retinal Vessel, Percutaneous Approach */
"08QJ3ZZ" = "1" /* Repair Right Lens, Percutaneous Approach */
"08QK3ZZ" = "1" /* Repair Left Lens, Percutaneous Approach */
"08QL0ZZ" = "1" /* Repair Right Extraocular Muscle, Open Approach */
"08QL3ZZ" = "1" /* Repair Right Extraocular Muscle, Percutaneous Approach */
"08QM0ZZ" = "1" /* Repair Left Extraocular Muscle, Open Approach */
"08QM3ZZ" = "1" /* Repair Left Extraocular Muscle, Percutaneous Approach */
"08QSXZZ" = "1" /* Repair Right Conjunctiva, External Approach */
"08QTXZZ" = "1" /* Repair Left Conjunctiva, External Approach */
"08QV0ZZ" = "1" /* Repair Right Lacrimal Gland, Open Approach */
"08QV3ZZ" = "1" /* Repair Right Lacrimal Gland, Percutaneous Approach */
"08QW0ZZ" = "1" /* Repair Left Lacrimal Gland, Open Approach */
"08QW3ZZ" = "1" /* Repair Left Lacrimal Gland, Percutaneous Approach */
"08QX0ZZ" = "1" /* Repair Right Lacrimal Duct, Open Approach */
"08QX3ZZ" = "1" /* Repair Right Lacrimal Duct, Percutaneous Approach */
"08QX7ZZ" = "1" /* Repair Right Lacrimal Duct, Via Natural or Artificial Opening */
"08QX8ZZ" = "1" /* Repair Right Lacrimal Duct, Via Natural or Artificial Opening Endoscopic */
"08QY0ZZ" = "1" /* Repair Left Lacrimal Duct, Open Approach */
"08QY3ZZ" = "1" /* Repair Left Lacrimal Duct, Percutaneous Approach */
"08QY7ZZ" = "1" /* Repair Left Lacrimal Duct, Via Natural or Artificial Opening */
"08QY8ZZ" = "1" /* Repair Left Lacrimal Duct, Via Natural or Artificial Opening Endoscopic */
"08R007Z" = "1" /* Replacement of Right Eye with Autologous Tissue Substitute, Open Approach */
"08R00JZ" = "1" /* Replacement of Right Eye with Synthetic Substitute, Open Approach */
"08R00KZ" = "1" /* Replacement of Right Eye with Nonautologous Tissue Substitute, Open Approach */
"08R037Z" = "1" /* Replacement of Right Eye with Autologous Tissue Substitute, Percutaneous Approach */
"08R03JZ" = "1" /* Replacement of Right Eye with Synthetic Substitute, Percutaneous Approach */
"08R03KZ" = "1" /* Replacement of Right Eye with Nonautologous Tissue Substitute, Percutaneous Approach */
"08R107Z" = "1" /* Replacement of Left Eye with Autologous Tissue Substitute, Open Approach */
"08R10JZ" = "1" /* Replacement of Left Eye with Synthetic Substitute, Open Approach */
"08R10KZ" = "1" /* Replacement of Left Eye with Nonautologous Tissue Substitute, Open Approach */
"08R137Z" = "1" /* Replacement of Left Eye with Autologous Tissue Substitute, Percutaneous Approach */
"08R13JZ" = "1" /* Replacement of Left Eye with Synthetic Substitute, Percutaneous Approach */
"08R13KZ" = "1" /* Replacement of Left Eye with Nonautologous Tissue Substitute, Percutaneous Approach */
"08R437Z" = "1" /* Replacement of Right Vitreous with Autologous Tissue Substitute, Percutaneous Approach */
"08R43JZ" = "1" /* Replacement of Right Vitreous with Synthetic Substitute, Percutaneous Approach */
"08R43KZ" = "1" /* Replacement of Right Vitreous with Nonautologous Tissue Substitute, Percutaneous Approach */
"08R537Z" = "1" /* Replacement of Left Vitreous with Autologous Tissue Substitute, Percutaneous Approach */
"08R53JZ" = "1" /* Replacement of Left Vitreous with Synthetic Substitute, Percutaneous Approach */
"08R53KZ" = "1" /* Replacement of Left Vitreous with Nonautologous Tissue Substitute, Percutaneous Approach */
"08R6X7Z" = "1" /* Replacement of Right Sclera with Autologous Tissue Substitute, External Approach */
"08R6XJZ" = "1" /* Replacement of Right Sclera with Synthetic Substitute, External Approach */
"08R6XKZ" = "1" /* Replacement of Right Sclera with Nonautologous Tissue Substitute, External Approach */
"08R7X7Z" = "1" /* Replacement of Left Sclera with Autologous Tissue Substitute, External Approach */
"08R7XJZ" = "1" /* Replacement of Left Sclera with Synthetic Substitute, External Approach */
"08R7XKZ" = "1" /* Replacement of Left Sclera with Nonautologous Tissue Substitute, External Approach */
"08R837Z" = "1" /* Replacement of Right Cornea with Autologous Tissue Substitute, Percutaneous Approach */
"08R83JZ" = "1" /* Replacement of Right Cornea with Synthetic Substitute, Percutaneous Approach */
"08R83KZ" = "1" /* Replacement of Right Cornea with Nonautologous Tissue Substitute, Percutaneous Approach */
"08R8X7Z" = "1" /* Replacement of Right Cornea with Autologous Tissue Substitute, External Approach */
"08R8XJZ" = "1" /* Replacement of Right Cornea with Synthetic Substitute, External Approach */
"08R8XKZ" = "1" /* Replacement of Right Cornea with Nonautologous Tissue Substitute, External Approach */
"08R937Z" = "1" /* Replacement of Left Cornea with Autologous Tissue Substitute, Percutaneous Approach */
"08R93JZ" = "1" /* Replacement of Left Cornea with Synthetic Substitute, Percutaneous Approach */
"08R93KZ" = "1" /* Replacement of Left Cornea with Nonautologous Tissue Substitute, Percutaneous Approach */
"08R9X7Z" = "1" /* Replacement of Left Cornea with Autologous Tissue Substitute, External Approach */
"08R9XJZ" = "1" /* Replacement of Left Cornea with Synthetic Substitute, External Approach */
"08R9XKZ" = "1" /* Replacement of Left Cornea with Nonautologous Tissue Substitute, External Approach */
"08RA07Z" = "1" /* Replacement of Right Choroid with Autologous Tissue Substitute, Open Approach */
"08RA0JZ" = "1" /* Replacement of Right Choroid with Synthetic Substitute, Open Approach */
"08RA0KZ" = "1" /* Replacement of Right Choroid with Nonautologous Tissue Substitute, Open Approach */
"08RA37Z" = "1" /* Replacement of Right Choroid with Autologous Tissue Substitute, Percutaneous Approach */
"08RA3JZ" = "1" /* Replacement of Right Choroid with Synthetic Substitute, Percutaneous Approach */
"08RA3KZ" = "1" /* Replacement of Right Choroid with Nonautologous Tissue Substitute, Percutaneous Approach */
"08RB07Z" = "1" /* Replacement of Left Choroid with Autologous Tissue Substitute, Open Approach */
"08RB0JZ" = "1" /* Replacement of Left Choroid with Synthetic Substitute, Open Approach */
"08RB0KZ" = "1" /* Replacement of Left Choroid with Nonautologous Tissue Substitute, Open Approach */
"08RB37Z" = "1" /* Replacement of Left Choroid with Autologous Tissue Substitute, Percutaneous Approach */
"08RB3JZ" = "1" /* Replacement of Left Choroid with Synthetic Substitute, Percutaneous Approach */
"08RB3KZ" = "1" /* Replacement of Left Choroid with Nonautologous Tissue Substitute, Percutaneous Approach */
"08RC37Z" = "1" /* Replacement of Right Iris with Autologous Tissue Substitute, Percutaneous Approach */
"08RC3JZ" = "1" /* Replacement of Right Iris with Synthetic Substitute, Percutaneous Approach */
"08RC3KZ" = "1" /* Replacement of Right Iris with Nonautologous Tissue Substitute, Percutaneous Approach */
"08RD37Z" = "1" /* Replacement of Left Iris with Autologous Tissue Substitute, Percutaneous Approach */
"08RD3JZ" = "1" /* Replacement of Left Iris with Synthetic Substitute, Percutaneous Approach */
"08RD3KZ" = "1" /* Replacement of Left Iris with Nonautologous Tissue Substitute, Percutaneous Approach */
"08RG37Z" = "1" /* Replacement of Right Retinal Vessel with Autologous Tissue Substitute, Percutaneous Approach */
"08RG3JZ" = "1" /* Replacement of Right Retinal Vessel with Synthetic Substitute, Percutaneous Approach */
"08RG3KZ" = "1" /* Replacement of Right Retinal Vessel with Nonautologous Tissue Substitute, Percutaneous Approach */
"08RH37Z" = "1" /* Replacement of Left Retinal Vessel with Autologous Tissue Substitute, Percutaneous Approach */
"08RH3JZ" = "1" /* Replacement of Left Retinal Vessel with Synthetic Substitute, Percutaneous Approach */
"08RH3KZ" = "1" /* Replacement of Left Retinal Vessel with Nonautologous Tissue Substitute, Percutaneous Approach */
"08RJ30Z" = "1" /* Replacement of Right Lens with Intraocular Telescope, Percutaneous Approach */
"08RJ37Z" = "1" /* Replacement of Right Lens with Autologous Tissue Substitute, Percutaneous Approach */
"08RJ3JZ" = "1" /* Replacement of Right Lens with Synthetic Substitute, Percutaneous Approach */
"08RJ3KZ" = "1" /* Replacement of Right Lens with Nonautologous Tissue Substitute, Percutaneous Approach */
"08RK30Z" = "1" /* Replacement of Left Lens with Intraocular Telescope, Percutaneous Approach */
"08RK37Z" = "1" /* Replacement of Left Lens with Autologous Tissue Substitute, Percutaneous Approach */
"08RK3JZ" = "1" /* Replacement of Left Lens with Synthetic Substitute, Percutaneous Approach */
"08RK3KZ" = "1" /* Replacement of Left Lens with Nonautologous Tissue Substitute, Percutaneous Approach */
"08RN07Z" = "1" /* Replacement of Right Upper Eyelid with Autologous Tissue Substitute, Open Approach */
"08RN0JZ" = "1" /* Replacement of Right Upper Eyelid with Synthetic Substitute, Open Approach */
"08RN0KZ" = "1" /* Replacement of Right Upper Eyelid with Nonautologous Tissue Substitute, Open Approach */
"08RN37Z" = "1" /* Replacement of Right Upper Eyelid with Autologous Tissue Substitute, Percutaneous Approach */
"08RN3JZ" = "1" /* Replacement of Right Upper Eyelid with Synthetic Substitute, Percutaneous Approach */
"08RN3KZ" = "1" /* Replacement of Right Upper Eyelid with Nonautologous Tissue Substitute, Percutaneous Approach */
"08RNX7Z" = "1" /* Replacement of Right Upper Eyelid with Autologous Tissue Substitute, External Approach */
"08RNXJZ" = "1" /* Replacement of Right Upper Eyelid with Synthetic Substitute, External Approach */
"08RNXKZ" = "1" /* Replacement of Right Upper Eyelid with Nonautologous Tissue Substitute, External Approach */
"08RP07Z" = "1" /* Replacement of Left Upper Eyelid with Autologous Tissue Substitute, Open Approach */
"08RP0JZ" = "1" /* Replacement of Left Upper Eyelid with Synthetic Substitute, Open Approach */
"08RP0KZ" = "1" /* Replacement of Left Upper Eyelid with Nonautologous Tissue Substitute, Open Approach */
"08RP37Z" = "1" /* Replacement of Left Upper Eyelid with Autologous Tissue Substitute, Percutaneous Approach */
"08RP3JZ" = "1" /* Replacement of Left Upper Eyelid with Synthetic Substitute, Percutaneous Approach */
"08RP3KZ" = "1" /* Replacement of Left Upper Eyelid with Nonautologous Tissue Substitute, Percutaneous Approach */
"08RPX7Z" = "1" /* Replacement of Left Upper Eyelid with Autologous Tissue Substitute, External Approach */
"08RPXJZ" = "1" /* Replacement of Left Upper Eyelid with Synthetic Substitute, External Approach */
"08RPXKZ" = "1" /* Replacement of Left Upper Eyelid with Nonautologous Tissue Substitute, External Approach */
"08RQ07Z" = "1" /* Replacement of Right Lower Eyelid with Autologous Tissue Substitute, Open Approach */
"08RQ0JZ" = "1" /* Replacement of Right Lower Eyelid with Synthetic Substitute, Open Approach */
"08RQ0KZ" = "1" /* Replacement of Right Lower Eyelid with Nonautologous Tissue Substitute, Open Approach */
"08RQ37Z" = "1" /* Replacement of Right Lower Eyelid with Autologous Tissue Substitute, Percutaneous Approach */
"08RQ3JZ" = "1" /* Replacement of Right Lower Eyelid with Synthetic Substitute, Percutaneous Approach */
"08RQ3KZ" = "1" /* Replacement of Right Lower Eyelid with Nonautologous Tissue Substitute, Percutaneous Approach */
"08RQX7Z" = "1" /* Replacement of Right Lower Eyelid with Autologous Tissue Substitute, External Approach */
"08RQXJZ" = "1" /* Replacement of Right Lower Eyelid with Synthetic Substitute, External Approach */
"08RQXKZ" = "1" /* Replacement of Right Lower Eyelid with Nonautologous Tissue Substitute, External Approach */
"08RR07Z" = "1" /* Replacement of Left Lower Eyelid with Autologous Tissue Substitute, Open Approach */
"08RR0JZ" = "1" /* Replacement of Left Lower Eyelid with Synthetic Substitute, Open Approach */
"08RR0KZ" = "1" /* Replacement of Left Lower Eyelid with Nonautologous Tissue Substitute, Open Approach */
"08RR37Z" = "1" /* Replacement of Left Lower Eyelid with Autologous Tissue Substitute, Percutaneous Approach */
"08RR3JZ" = "1" /* Replacement of Left Lower Eyelid with Synthetic Substitute, Percutaneous Approach */
"08RR3KZ" = "1" /* Replacement of Left Lower Eyelid with Nonautologous Tissue Substitute, Percutaneous Approach */
"08RRX7Z" = "1" /* Replacement of Left Lower Eyelid with Autologous Tissue Substitute, External Approach */
"08RRXJZ" = "1" /* Replacement of Left Lower Eyelid with Synthetic Substitute, External Approach */
"08RRXKZ" = "1" /* Replacement of Left Lower Eyelid with Nonautologous Tissue Substitute, External Approach */
"08RSX7Z" = "1" /* Replacement of Right Conjunctiva with Autologous Tissue Substitute, External Approach */
"08RSXJZ" = "1" /* Replacement of Right Conjunctiva with Synthetic Substitute, External Approach */
"08RSXKZ" = "1" /* Replacement of Right Conjunctiva with Nonautologous Tissue Substitute, External Approach */
"08RTX7Z" = "1" /* Replacement of Left Conjunctiva with Autologous Tissue Substitute, External Approach */
"08RTXJZ" = "1" /* Replacement of Left Conjunctiva with Synthetic Substitute, External Approach */
"08RTXKZ" = "1" /* Replacement of Left Conjunctiva with Nonautologous Tissue Substitute, External Approach */
"08RX07Z" = "1" /* Replacement of Right Lacrimal Duct with Autologous Tissue Substitute, Open Approach */
"08RX0JZ" = "1" /* Replacement of Right Lacrimal Duct with Synthetic Substitute, Open Approach */
"08RX0KZ" = "1" /* Replacement of Right Lacrimal Duct with Nonautologous Tissue Substitute, Open Approach */
"08RX37Z" = "1" /* Replacement of Right Lacrimal Duct with Autologous Tissue Substitute, Percutaneous Approach */
"08RX3JZ" = "1" /* Replacement of Right Lacrimal Duct with Synthetic Substitute, Percutaneous Approach */
"08RX3KZ" = "1" /* Replacement of Right Lacrimal Duct with Nonautologous Tissue Substitute, Percutaneous Approach */
"08RX77Z" = "1" /* Replacement of Right Lacrimal Duct with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"08RX7JZ" = "1" /* Replacement of Right Lacrimal Duct with Synthetic Substitute, Via Natural or Artificial Opening */
"08RX7KZ" = "1" /* Replacement of Right Lacrimal Duct with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"08RX87Z" = "1" /* Replacement of Right Lacrimal Duct with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"08RX8JZ" = "1" /* Replacement of Right Lacrimal Duct with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"08RX8KZ" = "1" /* Replacement of Right Lacrimal Duct with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"08RY07Z" = "1" /* Replacement of Left Lacrimal Duct with Autologous Tissue Substitute, Open Approach */
"08RY0JZ" = "1" /* Replacement of Left Lacrimal Duct with Synthetic Substitute, Open Approach */
"08RY0KZ" = "1" /* Replacement of Left Lacrimal Duct with Nonautologous Tissue Substitute, Open Approach */
"08RY37Z" = "1" /* Replacement of Left Lacrimal Duct with Autologous Tissue Substitute, Percutaneous Approach */
"08RY3JZ" = "1" /* Replacement of Left Lacrimal Duct with Synthetic Substitute, Percutaneous Approach */
"08RY3KZ" = "1" /* Replacement of Left Lacrimal Duct with Nonautologous Tissue Substitute, Percutaneous Approach */
"08RY77Z" = "1" /* Replacement of Left Lacrimal Duct with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"08RY7JZ" = "1" /* Replacement of Left Lacrimal Duct with Synthetic Substitute, Via Natural or Artificial Opening */
"08RY7KZ" = "1" /* Replacement of Left Lacrimal Duct with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"08RY87Z" = "1" /* Replacement of Left Lacrimal Duct with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"08RY8JZ" = "1" /* Replacement of Left Lacrimal Duct with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"08RY8KZ" = "1" /* Replacement of Left Lacrimal Duct with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"08SC3ZZ" = "1" /* Reposition Right Iris, Percutaneous Approach */
"08SD3ZZ" = "1" /* Reposition Left Iris, Percutaneous Approach */
"08SG3ZZ" = "1" /* Reposition Right Retinal Vessel, Percutaneous Approach */
"08SH3ZZ" = "1" /* Reposition Left Retinal Vessel, Percutaneous Approach */
"08SJ3ZZ" = "1" /* Reposition Right Lens, Percutaneous Approach */
"08SK3ZZ" = "1" /* Reposition Left Lens, Percutaneous Approach */
"08SL0ZZ" = "1" /* Reposition Right Extraocular Muscle, Open Approach */
"08SL3ZZ" = "1" /* Reposition Right Extraocular Muscle, Percutaneous Approach */
"08SM0ZZ" = "1" /* Reposition Left Extraocular Muscle, Open Approach */
"08SM3ZZ" = "1" /* Reposition Left Extraocular Muscle, Percutaneous Approach */
"08SN0ZZ" = "1" /* Reposition Right Upper Eyelid, Open Approach */
"08SN3ZZ" = "1" /* Reposition Right Upper Eyelid, Percutaneous Approach */
"08SNXZZ" = "1" /* Reposition Right Upper Eyelid, External Approach */
"08SP0ZZ" = "1" /* Reposition Left Upper Eyelid, Open Approach */
"08SP3ZZ" = "1" /* Reposition Left Upper Eyelid, Percutaneous Approach */
"08SPXZZ" = "1" /* Reposition Left Upper Eyelid, External Approach */
"08SQ0ZZ" = "1" /* Reposition Right Lower Eyelid, Open Approach */
"08SQ3ZZ" = "1" /* Reposition Right Lower Eyelid, Percutaneous Approach */
"08SQXZZ" = "1" /* Reposition Right Lower Eyelid, External Approach */
"08SR0ZZ" = "1" /* Reposition Left Lower Eyelid, Open Approach */
"08SR3ZZ" = "1" /* Reposition Left Lower Eyelid, Percutaneous Approach */
"08SRXZZ" = "1" /* Reposition Left Lower Eyelid, External Approach */
"08SV0ZZ" = "1" /* Reposition Right Lacrimal Gland, Open Approach */
"08SV3ZZ" = "1" /* Reposition Right Lacrimal Gland, Percutaneous Approach */
"08SW0ZZ" = "1" /* Reposition Left Lacrimal Gland, Open Approach */
"08SW3ZZ" = "1" /* Reposition Left Lacrimal Gland, Percutaneous Approach */
"08SX0ZZ" = "1" /* Reposition Right Lacrimal Duct, Open Approach */
"08SX3ZZ" = "1" /* Reposition Right Lacrimal Duct, Percutaneous Approach */
"08SX7ZZ" = "1" /* Reposition Right Lacrimal Duct, Via Natural or Artificial Opening */
"08SX8ZZ" = "1" /* Reposition Right Lacrimal Duct, Via Natural or Artificial Opening Endoscopic */
"08SY0ZZ" = "1" /* Reposition Left Lacrimal Duct, Open Approach */
"08SY3ZZ" = "1" /* Reposition Left Lacrimal Duct, Percutaneous Approach */
"08SY7ZZ" = "1" /* Reposition Left Lacrimal Duct, Via Natural or Artificial Opening */
"08SY8ZZ" = "1" /* Reposition Left Lacrimal Duct, Via Natural or Artificial Opening Endoscopic */
"08T0XZZ" = "1" /* Resection of Right Eye, External Approach */
"08T1XZZ" = "1" /* Resection of Left Eye, External Approach */
"08T43ZZ" = "1" /* Resection of Right Vitreous, Percutaneous Approach */
"08T53ZZ" = "1" /* Resection of Left Vitreous, Percutaneous Approach */
"08T8XZZ" = "1" /* Resection of Right Cornea, External Approach */
"08T9XZZ" = "1" /* Resection of Left Cornea, External Approach */
"08TC3ZZ" = "1" /* Resection of Right Iris, Percutaneous Approach */
"08TD3ZZ" = "1" /* Resection of Left Iris, Percutaneous Approach */
"08TJ3ZZ" = "1" /* Resection of Right Lens, Percutaneous Approach */
"08TK3ZZ" = "1" /* Resection of Left Lens, Percutaneous Approach */
"08TL0ZZ" = "1" /* Resection of Right Extraocular Muscle, Open Approach */
"08TL3ZZ" = "1" /* Resection of Right Extraocular Muscle, Percutaneous Approach */
"08TM0ZZ" = "1" /* Resection of Left Extraocular Muscle, Open Approach */
"08TM3ZZ" = "1" /* Resection of Left Extraocular Muscle, Percutaneous Approach */
"08TN0ZZ" = "1" /* Resection of Right Upper Eyelid, Open Approach */
"08TNXZZ" = "1" /* Resection of Right Upper Eyelid, External Approach */
"08TP0ZZ" = "1" /* Resection of Left Upper Eyelid, Open Approach */
"08TPXZZ" = "1" /* Resection of Left Upper Eyelid, External Approach */
"08TQ0ZZ" = "1" /* Resection of Right Lower Eyelid, Open Approach */
"08TQXZZ" = "1" /* Resection of Right Lower Eyelid, External Approach */
"08TR0ZZ" = "1" /* Resection of Left Lower Eyelid, Open Approach */
"08TRXZZ" = "1" /* Resection of Left Lower Eyelid, External Approach */
"08TV0ZZ" = "1" /* Resection of Right Lacrimal Gland, Open Approach */
"08TV3ZZ" = "1" /* Resection of Right Lacrimal Gland, Percutaneous Approach */
"08TW0ZZ" = "1" /* Resection of Left Lacrimal Gland, Open Approach */
"08TW3ZZ" = "1" /* Resection of Left Lacrimal Gland, Percutaneous Approach */
"08TX0ZZ" = "1" /* Resection of Right Lacrimal Duct, Open Approach */
"08TX3ZZ" = "1" /* Resection of Right Lacrimal Duct, Percutaneous Approach */
"08TX7ZZ" = "1" /* Resection of Right Lacrimal Duct, Via Natural or Artificial Opening */
"08TX8ZZ" = "1" /* Resection of Right Lacrimal Duct, Via Natural or Artificial Opening Endoscopic */
"08TY0ZZ" = "1" /* Resection of Left Lacrimal Duct, Open Approach */
"08TY3ZZ" = "1" /* Resection of Left Lacrimal Duct, Percutaneous Approach */
"08TY7ZZ" = "1" /* Resection of Left Lacrimal Duct, Via Natural or Artificial Opening */
"08TY8ZZ" = "1" /* Resection of Left Lacrimal Duct, Via Natural or Artificial Opening Endoscopic */
"08U007Z" = "1" /* Supplement of Right Eye with Autologous Tissue Substitute, Open Approach */
"08U00JZ" = "1" /* Supplement of Right Eye with Synthetic Substitute, Open Approach */
"08U00KZ" = "1" /* Supplement of Right Eye with Nonautologous Tissue Substitute, Open Approach */
"08U037Z" = "1" /* Supplement of Right Eye with Autologous Tissue Substitute, Percutaneous Approach */
"08U03JZ" = "1" /* Supplement of Right Eye with Synthetic Substitute, Percutaneous Approach */
"08U03KZ" = "1" /* Supplement of Right Eye with Nonautologous Tissue Substitute, Percutaneous Approach */
"08U107Z" = "1" /* Supplement of Left Eye with Autologous Tissue Substitute, Open Approach */
"08U10JZ" = "1" /* Supplement of Left Eye with Synthetic Substitute, Open Approach */
"08U10KZ" = "1" /* Supplement of Left Eye with Nonautologous Tissue Substitute, Open Approach */
"08U137Z" = "1" /* Supplement of Left Eye with Autologous Tissue Substitute, Percutaneous Approach */
"08U13JZ" = "1" /* Supplement of Left Eye with Synthetic Substitute, Percutaneous Approach */
"08U13KZ" = "1" /* Supplement of Left Eye with Nonautologous Tissue Substitute, Percutaneous Approach */
"08U807Z" = "1" /* Supplement Right Cornea with Autologous Tissue Substitute, Open Approach */
"08U80JZ" = "1" /* Supplement Right Cornea with Synthetic Substitute, Open Approach */
"08U80KZ" = "1" /* Supplement Right Cornea with Nonautologous Tissue Substitute, Open Approach */
"08U837Z" = "1" /* Supplement Right Cornea with Autologous Tissue Substitute, Percutaneous Approach */
"08U83JZ" = "1" /* Supplement Right Cornea with Synthetic Substitute, Percutaneous Approach */
"08U83KZ" = "1" /* Supplement Right Cornea with Nonautologous Tissue Substitute, Percutaneous Approach */
"08U8X7Z" = "1" /* Supplement Right Cornea with Autologous Tissue Substitute, External Approach */
"08U8XJZ" = "1" /* Supplement Right Cornea with Synthetic Substitute, External Approach */
"08U8XKZ" = "1" /* Supplement Right Cornea with Nonautologous Tissue Substitute, External Approach */
"08U907Z" = "1" /* Supplement Left Cornea with Autologous Tissue Substitute, Open Approach */
"08U90JZ" = "1" /* Supplement Left Cornea with Synthetic Substitute, Open Approach */
"08U90KZ" = "1" /* Supplement Left Cornea with Nonautologous Tissue Substitute, Open Approach */
"08U937Z" = "1" /* Supplement Left Cornea with Autologous Tissue Substitute, Percutaneous Approach */
"08U93JZ" = "1" /* Supplement Left Cornea with Synthetic Substitute, Percutaneous Approach */
"08U93KZ" = "1" /* Supplement Left Cornea with Nonautologous Tissue Substitute, Percutaneous Approach */
"08U9X7Z" = "1" /* Supplement Left Cornea with Autologous Tissue Substitute, External Approach */
"08U9XJZ" = "1" /* Supplement Left Cornea with Synthetic Substitute, External Approach */
"08U9XKZ" = "1" /* Supplement Left Cornea with Nonautologous Tissue Substitute, External Approach */
"08UC07Z" = "1" /* Supplement Right Iris with Autologous Tissue Substitute, Open Approach */
"08UC0JZ" = "1" /* Supplement Right Iris with Synthetic Substitute, Open Approach */
"08UC0KZ" = "1" /* Supplement Right Iris with Nonautologous Tissue Substitute, Open Approach */
"08UC37Z" = "1" /* Supplement Right Iris with Autologous Tissue Substitute, Percutaneous Approach */
"08UC3JZ" = "1" /* Supplement Right Iris with Synthetic Substitute, Percutaneous Approach */
"08UC3KZ" = "1" /* Supplement Right Iris with Nonautologous Tissue Substitute, Percutaneous Approach */
"08UD07Z" = "1" /* Supplement Left Iris with Autologous Tissue Substitute, Open Approach */
"08UD0JZ" = "1" /* Supplement Left Iris with Synthetic Substitute, Open Approach */
"08UD0KZ" = "1" /* Supplement Left Iris with Nonautologous Tissue Substitute, Open Approach */
"08UD37Z" = "1" /* Supplement Left Iris with Autologous Tissue Substitute, Percutaneous Approach */
"08UD3JZ" = "1" /* Supplement Left Iris with Synthetic Substitute, Percutaneous Approach */
"08UD3KZ" = "1" /* Supplement Left Iris with Nonautologous Tissue Substitute, Percutaneous Approach */
"08UE07Z" = "1" /* Supplement Right Retina with Autologous Tissue Substitute, Open Approach */
"08UE0JZ" = "1" /* Supplement Right Retina with Synthetic Substitute, Open Approach */
"08UE0KZ" = "1" /* Supplement Right Retina with Nonautologous Tissue Substitute, Open Approach */
"08UE37Z" = "1" /* Supplement Right Retina with Autologous Tissue Substitute, Percutaneous Approach */
"08UE3JZ" = "1" /* Supplement Right Retina with Synthetic Substitute, Percutaneous Approach */
"08UE3KZ" = "1" /* Supplement Right Retina with Nonautologous Tissue Substitute, Percutaneous Approach */
"08UF07Z" = "1" /* Supplement Left Retina with Autologous Tissue Substitute, Open Approach */
"08UF0JZ" = "1" /* Supplement Left Retina with Synthetic Substitute, Open Approach */
"08UF0KZ" = "1" /* Supplement Left Retina with Nonautologous Tissue Substitute, Open Approach */
"08UF37Z" = "1" /* Supplement Left Retina with Autologous Tissue Substitute, Percutaneous Approach */
"08UF3JZ" = "1" /* Supplement Left Retina with Synthetic Substitute, Percutaneous Approach */
"08UF3KZ" = "1" /* Supplement Left Retina with Nonautologous Tissue Substitute, Percutaneous Approach */
"08UG07Z" = "1" /* Supplement Right Retinal Vessel with Autologous Tissue Substitute, Open Approach */
"08UG0JZ" = "1" /* Supplement Right Retinal Vessel with Synthetic Substitute, Open Approach */
"08UG0KZ" = "1" /* Supplement Right Retinal Vessel with Nonautologous Tissue Substitute, Open Approach */
"08UG37Z" = "1" /* Supplement Right Retinal Vessel with Autologous Tissue Substitute, Percutaneous Approach */
"08UG3JZ" = "1" /* Supplement Right Retinal Vessel with Synthetic Substitute, Percutaneous Approach */
"08UG3KZ" = "1" /* Supplement Right Retinal Vessel with Nonautologous Tissue Substitute, Percutaneous Approach */
"08UH07Z" = "1" /* Supplement Left Retinal Vessel with Autologous Tissue Substitute, Open Approach */
"08UH0JZ" = "1" /* Supplement Left Retinal Vessel with Synthetic Substitute, Open Approach */
"08UH0KZ" = "1" /* Supplement Left Retinal Vessel with Nonautologous Tissue Substitute, Open Approach */
"08UH37Z" = "1" /* Supplement Left Retinal Vessel with Autologous Tissue Substitute, Percutaneous Approach */
"08UH3JZ" = "1" /* Supplement Left Retinal Vessel with Synthetic Substitute, Percutaneous Approach */
"08UH3KZ" = "1" /* Supplement Left Retinal Vessel with Nonautologous Tissue Substitute, Percutaneous Approach */
"08UL07Z" = "1" /* Supplement Right Extraocular Muscle with Autologous Tissue Substitute, Open Approach */
"08UL0JZ" = "1" /* Supplement Right Extraocular Muscle with Synthetic Substitute, Open Approach */
"08UL0KZ" = "1" /* Supplement Right Extraocular Muscle with Nonautologous Tissue Substitute, Open Approach */
"08UL37Z" = "1" /* Supplement Right Extraocular Muscle with Autologous Tissue Substitute, Percutaneous Approach */
"08UL3JZ" = "1" /* Supplement Right Extraocular Muscle with Synthetic Substitute, Percutaneous Approach */
"08UL3KZ" = "1" /* Supplement Right Extraocular Muscle with Nonautologous Tissue Substitute, Percutaneous Approach */
"08UM07Z" = "1" /* Supplement Left Extraocular Muscle with Autologous Tissue Substitute, Open Approach */
"08UM0JZ" = "1" /* Supplement Left Extraocular Muscle with Synthetic Substitute, Open Approach */
"08UM0KZ" = "1" /* Supplement Left Extraocular Muscle with Nonautologous Tissue Substitute, Open Approach */
"08UM37Z" = "1" /* Supplement Left Extraocular Muscle with Autologous Tissue Substitute, Percutaneous Approach */
"08UM3JZ" = "1" /* Supplement Left Extraocular Muscle with Synthetic Substitute, Percutaneous Approach */
"08UM3KZ" = "1" /* Supplement Left Extraocular Muscle with Nonautologous Tissue Substitute, Percutaneous Approach */
"08UN07Z" = "1" /* Supplement Right Upper Eyelid with Autologous Tissue Substitute, Open Approach */
"08UN0JZ" = "1" /* Supplement Right Upper Eyelid with Synthetic Substitute, Open Approach */
"08UN0KZ" = "1" /* Supplement Right Upper Eyelid with Nonautologous Tissue Substitute, Open Approach */
"08UN37Z" = "1" /* Supplement Right Upper Eyelid with Autologous Tissue Substitute, Percutaneous Approach */
"08UN3JZ" = "1" /* Supplement Right Upper Eyelid with Synthetic Substitute, Percutaneous Approach */
"08UN3KZ" = "1" /* Supplement Right Upper Eyelid with Nonautologous Tissue Substitute, Percutaneous Approach */
"08UNX7Z" = "1" /* Supplement Right Upper Eyelid with Autologous Tissue Substitute, External Approach */
"08UNXJZ" = "1" /* Supplement Right Upper Eyelid with Synthetic Substitute, External Approach */
"08UNXKZ" = "1" /* Supplement Right Upper Eyelid with Nonautologous Tissue Substitute, External Approach */
"08UP07Z" = "1" /* Supplement Left Upper Eyelid with Autologous Tissue Substitute, Open Approach */
"08UP0JZ" = "1" /* Supplement Left Upper Eyelid with Synthetic Substitute, Open Approach */
"08UP0KZ" = "1" /* Supplement Left Upper Eyelid with Nonautologous Tissue Substitute, Open Approach */
"08UP37Z" = "1" /* Supplement Left Upper Eyelid with Autologous Tissue Substitute, Percutaneous Approach */
"08UP3JZ" = "1" /* Supplement Left Upper Eyelid with Synthetic Substitute, Percutaneous Approach */
"08UP3KZ" = "1" /* Supplement Left Upper Eyelid with Nonautologous Tissue Substitute, Percutaneous Approach */
"08UPX7Z" = "1" /* Supplement Left Upper Eyelid with Autologous Tissue Substitute, External Approach */
"08UPXJZ" = "1" /* Supplement Left Upper Eyelid with Synthetic Substitute, External Approach */
"08UPXKZ" = "1" /* Supplement Left Upper Eyelid with Nonautologous Tissue Substitute, External Approach */
"08UQ07Z" = "1" /* Supplement Right Lower Eyelid with Autologous Tissue Substitute, Open Approach */
"08UQ0JZ" = "1" /* Supplement Right Lower Eyelid with Synthetic Substitute, Open Approach */
"08UQ0KZ" = "1" /* Supplement Right Lower Eyelid with Nonautologous Tissue Substitute, Open Approach */
"08UQ37Z" = "1" /* Supplement Right Lower Eyelid with Autologous Tissue Substitute, Percutaneous Approach */
"08UQ3JZ" = "1" /* Supplement Right Lower Eyelid with Synthetic Substitute, Percutaneous Approach */
"08UQ3KZ" = "1" /* Supplement Right Lower Eyelid with Nonautologous Tissue Substitute, Percutaneous Approach */
"08UQX7Z" = "1" /* Supplement Right Lower Eyelid with Autologous Tissue Substitute, External Approach */
"08UQXJZ" = "1" /* Supplement Right Lower Eyelid with Synthetic Substitute, External Approach */
"08UQXKZ" = "1" /* Supplement Right Lower Eyelid with Nonautologous Tissue Substitute, External Approach */
"08UR07Z" = "1" /* Supplement Left Lower Eyelid with Autologous Tissue Substitute, Open Approach */
"08UR0JZ" = "1" /* Supplement Left Lower Eyelid with Synthetic Substitute, Open Approach */
"08UR0KZ" = "1" /* Supplement Left Lower Eyelid with Nonautologous Tissue Substitute, Open Approach */
"08UR37Z" = "1" /* Supplement Left Lower Eyelid with Autologous Tissue Substitute, Percutaneous Approach */
"08UR3JZ" = "1" /* Supplement Left Lower Eyelid with Synthetic Substitute, Percutaneous Approach */
"08UR3KZ" = "1" /* Supplement Left Lower Eyelid with Nonautologous Tissue Substitute, Percutaneous Approach */
"08URX7Z" = "1" /* Supplement Left Lower Eyelid with Autologous Tissue Substitute, External Approach */
"08URXJZ" = "1" /* Supplement Left Lower Eyelid with Synthetic Substitute, External Approach */
"08URXKZ" = "1" /* Supplement Left Lower Eyelid with Nonautologous Tissue Substitute, External Approach */
"08UX07Z" = "1" /* Supplement Right Lacrimal Duct with Autologous Tissue Substitute, Open Approach */
"08UX0JZ" = "1" /* Supplement Right Lacrimal Duct with Synthetic Substitute, Open Approach */
"08UX0KZ" = "1" /* Supplement Right Lacrimal Duct with Nonautologous Tissue Substitute, Open Approach */
"08UX37Z" = "1" /* Supplement Right Lacrimal Duct with Autologous Tissue Substitute, Percutaneous Approach */
"08UX3JZ" = "1" /* Supplement Right Lacrimal Duct with Synthetic Substitute, Percutaneous Approach */
"08UX3KZ" = "1" /* Supplement Right Lacrimal Duct with Nonautologous Tissue Substitute, Percutaneous Approach */
"08UX77Z" = "1" /* Supplement Right Lacrimal Duct with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"08UX7JZ" = "1" /* Supplement Right Lacrimal Duct with Synthetic Substitute, Via Natural or Artificial Opening */
"08UX7KZ" = "1" /* Supplement Right Lacrimal Duct with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"08UX87Z" = "1" /* Supplement Right Lacrimal Duct with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"08UX8JZ" = "1" /* Supplement Right Lacrimal Duct with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"08UX8KZ" = "1" /* Supplement Right Lacrimal Duct with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"08UY07Z" = "1" /* Supplement Left Lacrimal Duct with Autologous Tissue Substitute, Open Approach */
"08UY0JZ" = "1" /* Supplement Left Lacrimal Duct with Synthetic Substitute, Open Approach */
"08UY0KZ" = "1" /* Supplement Left Lacrimal Duct with Nonautologous Tissue Substitute, Open Approach */
"08UY37Z" = "1" /* Supplement Left Lacrimal Duct with Autologous Tissue Substitute, Percutaneous Approach */
"08UY3JZ" = "1" /* Supplement Left Lacrimal Duct with Synthetic Substitute, Percutaneous Approach */
"08UY3KZ" = "1" /* Supplement Left Lacrimal Duct with Nonautologous Tissue Substitute, Percutaneous Approach */
"08UY77Z" = "1" /* Supplement Left Lacrimal Duct with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"08UY7JZ" = "1" /* Supplement Left Lacrimal Duct with Synthetic Substitute, Via Natural or Artificial Opening */
"08UY7KZ" = "1" /* Supplement Left Lacrimal Duct with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"08UY87Z" = "1" /* Supplement Left Lacrimal Duct with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"08UY8JZ" = "1" /* Supplement Left Lacrimal Duct with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"08UY8KZ" = "1" /* Supplement Left Lacrimal Duct with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"08VX0CZ" = "1" /* Restriction of Right Lacrimal Duct with Extraluminal Device, Open Approach */
"08VX0DZ" = "1" /* Restriction of Right Lacrimal Duct with Intraluminal Device, Open Approach */
"08VX0ZZ" = "1" /* Restriction of Right Lacrimal Duct, Open Approach */
"08VX3CZ" = "1" /* Restriction of Right Lacrimal Duct with Extraluminal Device, Percutaneous Approach */
"08VX3DZ" = "1" /* Restriction of Right Lacrimal Duct with Intraluminal Device, Percutaneous Approach */
"08VX3ZZ" = "1" /* Restriction of Right Lacrimal Duct, Percutaneous Approach */
"08VX7DZ" = "1" /* Restriction of Right Lacrimal Duct with Intraluminal Device, Via Natural or Artificial Opening */
"08VX7ZZ" = "1" /* Restriction of Right Lacrimal Duct, Via Natural or Artificial Opening */
"08VX8DZ" = "1" /* Restriction of Right Lacrimal Duct with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"08VX8ZZ" = "1" /* Restriction of Right Lacrimal Duct, Via Natural or Artificial Opening Endoscopic */
"08VY0CZ" = "1" /* Restriction of Left Lacrimal Duct with Extraluminal Device, Open Approach */
"08VY0DZ" = "1" /* Restriction of Left Lacrimal Duct with Intraluminal Device, Open Approach */
"08VY0ZZ" = "1" /* Restriction of Left Lacrimal Duct, Open Approach */
"08VY3CZ" = "1" /* Restriction of Left Lacrimal Duct with Extraluminal Device, Percutaneous Approach */
"08VY3DZ" = "1" /* Restriction of Left Lacrimal Duct with Intraluminal Device, Percutaneous Approach */
"08VY3ZZ" = "1" /* Restriction of Left Lacrimal Duct, Percutaneous Approach */
"08VY7DZ" = "1" /* Restriction of Left Lacrimal Duct with Intraluminal Device, Via Natural or Artificial Opening */
"08VY7ZZ" = "1" /* Restriction of Left Lacrimal Duct, Via Natural or Artificial Opening */
"08VY8DZ" = "1" /* Restriction of Left Lacrimal Duct with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"08VY8ZZ" = "1" /* Restriction of Left Lacrimal Duct, Via Natural or Artificial Opening Endoscopic */
"08W000Z" = "1" /* Revision of Drainage Device in Right Eye, Open Approach */
"08W003Z" = "1" /* Revision of Infusion Device in Right Eye, Open Approach */
"08W007Z" = "1" /* Revision of Autologous Tissue Substitute in Right Eye, Open Approach */
"08W00CZ" = "1" /* Revision of Extraluminal Device in Right Eye, Open Approach */
"08W00DZ" = "1" /* Revision of Intraluminal Device in Right Eye, Open Approach */
"08W00JZ" = "1" /* Revision of Synthetic Substitute in Right Eye, Open Approach */
"08W00KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Eye, Open Approach */
"08W030Z" = "1" /* Revision of Drainage Device in Right Eye, Percutaneous Approach */
"08W033Z" = "1" /* Revision of Infusion Device in Right Eye, Percutaneous Approach */
"08W037Z" = "1" /* Revision of Autologous Tissue Substitute in Right Eye, Percutaneous Approach */
"08W03CZ" = "1" /* Revision of Extraluminal Device in Right Eye, Percutaneous Approach */
"08W03DZ" = "1" /* Revision of Intraluminal Device in Right Eye, Percutaneous Approach */
"08W03JZ" = "1" /* Revision of Synthetic Substitute in Right Eye, Percutaneous Approach */
"08W03KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Eye, Percutaneous Approach */
"08W070Z" = "1" /* Revision of Drainage Device in Right Eye, Via Natural or Artificial Opening */
"08W073Z" = "1" /* Revision of Infusion Device in Right Eye, Via Natural or Artificial Opening */
"08W077Z" = "1" /* Revision of Autologous Tissue Substitute in Right Eye, Via Natural or Artificial Opening */
"08W07CZ" = "1" /* Revision of Extraluminal Device in Right Eye, Via Natural or Artificial Opening */
"08W07DZ" = "1" /* Revision of Intraluminal Device in Right Eye, Via Natural or Artificial Opening */
"08W07JZ" = "1" /* Revision of Synthetic Substitute in Right Eye, Via Natural or Artificial Opening */
"08W07KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Eye, Via Natural or Artificial Opening */
"08W080Z" = "1" /* Revision of Drainage Device in Right Eye, Via Natural or Artificial Opening Endoscopic */
"08W083Z" = "1" /* Revision of Infusion Device in Right Eye, Via Natural or Artificial Opening Endoscopic */
"08W087Z" = "1" /* Revision of Autologous Tissue Substitute in Right Eye, Via Natural or Artificial Opening Endoscopic */
"08W08CZ" = "1" /* Revision of Extraluminal Device in Right Eye, Via Natural or Artificial Opening Endoscopic */
"08W08DZ" = "1" /* Revision of Intraluminal Device in Right Eye, Via Natural or Artificial Opening Endoscopic */
"08W08JZ" = "1" /* Revision of Synthetic Substitute in Right Eye, Via Natural or Artificial Opening Endoscopic */
"08W08KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Eye, Via Natural or Artificial Opening Endoscopic */
"08W100Z" = "1" /* Revision of Drainage Device in Left Eye, Open Approach */
"08W103Z" = "1" /* Revision of Infusion Device in Left Eye, Open Approach */
"08W107Z" = "1" /* Revision of Autologous Tissue Substitute in Left Eye, Open Approach */
"08W10CZ" = "1" /* Revision of Extraluminal Device in Left Eye, Open Approach */
"08W10DZ" = "1" /* Revision of Intraluminal Device in Left Eye, Open Approach */
"08W10JZ" = "1" /* Revision of Synthetic Substitute in Left Eye, Open Approach */
"08W10KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Eye, Open Approach */
"08W130Z" = "1" /* Revision of Drainage Device in Left Eye, Percutaneous Approach */
"08W133Z" = "1" /* Revision of Infusion Device in Left Eye, Percutaneous Approach */
"08W137Z" = "1" /* Revision of Autologous Tissue Substitute in Left Eye, Percutaneous Approach */
"08W13CZ" = "1" /* Revision of Extraluminal Device in Left Eye, Percutaneous Approach */
"08W13DZ" = "1" /* Revision of Intraluminal Device in Left Eye, Percutaneous Approach */
"08W13JZ" = "1" /* Revision of Synthetic Substitute in Left Eye, Percutaneous Approach */
"08W13KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Eye, Percutaneous Approach */
"08W170Z" = "1" /* Revision of Drainage Device in Left Eye, Via Natural or Artificial Opening */
"08W173Z" = "1" /* Revision of Infusion Device in Left Eye, Via Natural or Artificial Opening */
"08W177Z" = "1" /* Revision of Autologous Tissue Substitute in Left Eye, Via Natural or Artificial Opening */
"08W17CZ" = "1" /* Revision of Extraluminal Device in Left Eye, Via Natural or Artificial Opening */
"08W17DZ" = "1" /* Revision of Intraluminal Device in Left Eye, Via Natural or Artificial Opening */
"08W17JZ" = "1" /* Revision of Synthetic Substitute in Left Eye, Via Natural or Artificial Opening */
"08W17KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Eye, Via Natural or Artificial Opening */
"08W180Z" = "1" /* Revision of Drainage Device in Left Eye, Via Natural or Artificial Opening Endoscopic */
"08W183Z" = "1" /* Revision of Infusion Device in Left Eye, Via Natural or Artificial Opening Endoscopic */
"08W187Z" = "1" /* Revision of Autologous Tissue Substitute in Left Eye, Via Natural or Artificial Opening Endoscopic */
"08W18CZ" = "1" /* Revision of Extraluminal Device in Left Eye, Via Natural or Artificial Opening Endoscopic */
"08W18DZ" = "1" /* Revision of Intraluminal Device in Left Eye, Via Natural or Artificial Opening Endoscopic */
"08W18JZ" = "1" /* Revision of Synthetic Substitute in Left Eye, Via Natural or Artificial Opening Endoscopic */
"08W18KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Eye, Via Natural or Artificial Opening Endoscopic */
"08WJ3JZ" = "1" /* Revision of Synthetic Substitute in Right Lens, Percutaneous Approach */
"08WK3JZ" = "1" /* Revision of Synthetic Substitute in Left Lens, Percutaneous Approach */
"08WL00Z" = "1" /* Revision of Drainage Device in Right Extraocular Muscle, Open Approach */
"08WL07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Extraocular Muscle, Open Approach */
"08WL0JZ" = "1" /* Revision of Synthetic Substitute in Right Extraocular Muscle, Open Approach */
"08WL0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Extraocular Muscle, Open Approach */
"08WL30Z" = "1" /* Revision of Drainage Device in Right Extraocular Muscle, Percutaneous Approach */
"08WL37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Extraocular Muscle, Percutaneous Approach */
"08WL3JZ" = "1" /* Revision of Synthetic Substitute in Right Extraocular Muscle, Percutaneous Approach */
"08WL3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Extraocular Muscle, Percutaneous Approach */
"08WM00Z" = "1" /* Revision of Drainage Device in Left Extraocular Muscle, Open Approach */
"08WM07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Extraocular Muscle, Open Approach */
"08WM0JZ" = "1" /* Revision of Synthetic Substitute in Left Extraocular Muscle, Open Approach */
"08WM0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Extraocular Muscle, Open Approach */
"08WM30Z" = "1" /* Revision of Drainage Device in Left Extraocular Muscle, Percutaneous Approach */
"08WM37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Extraocular Muscle, Percutaneous Approach */
"08WM3JZ" = "1" /* Revision of Synthetic Substitute in Left Extraocular Muscle, Percutaneous Approach */
"08WM3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Extraocular Muscle, Percutaneous Approach */
"08XL0ZZ" = "1" /* Transfer Right Extraocular Muscle, Open Approach */
"08XL3ZZ" = "1" /* Transfer Right Extraocular Muscle, Percutaneous Approach */
"08XM0ZZ" = "1" /* Transfer Left Extraocular Muscle, Open Approach */
"08XM3ZZ" = "1" /* Transfer Left Extraocular Muscle, Percutaneous Approach */
"090007Z" = "1" /* Alteration of Right External Ear with Autologous Tissue Substitute, Open Approach */
"09000JZ" = "1" /* Alteration of Right External Ear with Synthetic Substitute, Open Approach */
"09000KZ" = "1" /* Alteration of Right External Ear with Nonautologous Tissue Substitute, Open Approach */
"09000ZZ" = "1" /* Alteration of Right External Ear, Open Approach */
"090037Z" = "1" /* Alteration of Right External Ear with Autologous Tissue Substitute, Percutaneous Approach */
"09003JZ" = "1" /* Alteration of Right External Ear with Synthetic Substitute, Percutaneous Approach */
"09003KZ" = "1" /* Alteration of Right External Ear with Nonautologous Tissue Substitute, Percutaneous Approach */
"09003ZZ" = "1" /* Alteration of Right External Ear, Percutaneous Approach */
"090047Z" = "1" /* Alteration of Right External Ear with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"09004JZ" = "1" /* Alteration of Right External Ear with Synthetic Substitute, Percutaneous Endoscopic Approach */
"09004KZ" = "1" /* Alteration of Right External Ear with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"09004ZZ" = "1" /* Alteration of Right External Ear, Percutaneous Endoscopic Approach */
"0900X7Z" = "1" /* Alteration of Right External Ear with Autologous Tissue Substitute, External Approach */
"0900XJZ" = "1" /* Alteration of Right External Ear with Synthetic Substitute, External Approach */
"0900XKZ" = "1" /* Alteration of Right External Ear with Nonautologous Tissue Substitute, External Approach */
"0900XZZ" = "1" /* Alteration of Right External Ear, External Approach */
"090107Z" = "1" /* Alteration of Left External Ear with Autologous Tissue Substitute, Open Approach */
"09010JZ" = "1" /* Alteration of Left External Ear with Synthetic Substitute, Open Approach */
"09010KZ" = "1" /* Alteration of Left External Ear with Nonautologous Tissue Substitute, Open Approach */
"09010ZZ" = "1" /* Alteration of Left External Ear, Open Approach */
"090137Z" = "1" /* Alteration of Left External Ear with Autologous Tissue Substitute, Percutaneous Approach */
"09013JZ" = "1" /* Alteration of Left External Ear with Synthetic Substitute, Percutaneous Approach */
"09013KZ" = "1" /* Alteration of Left External Ear with Nonautologous Tissue Substitute, Percutaneous Approach */
"09013ZZ" = "1" /* Alteration of Left External Ear, Percutaneous Approach */
"090147Z" = "1" /* Alteration of Left External Ear with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"09014JZ" = "1" /* Alteration of Left External Ear with Synthetic Substitute, Percutaneous Endoscopic Approach */
"09014KZ" = "1" /* Alteration of Left External Ear with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"09014ZZ" = "1" /* Alteration of Left External Ear, Percutaneous Endoscopic Approach */
"0901X7Z" = "1" /* Alteration of Left External Ear with Autologous Tissue Substitute, External Approach */
"0901XJZ" = "1" /* Alteration of Left External Ear with Synthetic Substitute, External Approach */
"0901XKZ" = "1" /* Alteration of Left External Ear with Nonautologous Tissue Substitute, External Approach */
"0901XZZ" = "1" /* Alteration of Left External Ear, External Approach */
"090207Z" = "1" /* Alteration of Bilateral External Ear with Autologous Tissue Substitute, Open Approach */
"09020JZ" = "1" /* Alteration of Bilateral External Ear with Synthetic Substitute, Open Approach */
"09020KZ" = "1" /* Alteration of Bilateral External Ear with Nonautologous Tissue Substitute, Open Approach */
"09020ZZ" = "1" /* Alteration of Bilateral External Ear, Open Approach */
"090237Z" = "1" /* Alteration of Bilateral External Ear with Autologous Tissue Substitute, Percutaneous Approach */
"09023JZ" = "1" /* Alteration of Bilateral External Ear with Synthetic Substitute, Percutaneous Approach */
"09023KZ" = "1" /* Alteration of Bilateral External Ear with Nonautologous Tissue Substitute, Percutaneous Approach */
"09023ZZ" = "1" /* Alteration of Bilateral External Ear, Percutaneous Approach */
"090247Z" = "1" /* Alteration of Bilateral External Ear with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"09024JZ" = "1" /* Alteration of Bilateral External Ear with Synthetic Substitute, Percutaneous Endoscopic Approach */
"09024KZ" = "1" /* Alteration of Bilateral External Ear with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"09024ZZ" = "1" /* Alteration of Bilateral External Ear, Percutaneous Endoscopic Approach */
"0902X7Z" = "1" /* Alteration of Bilateral External Ear with Autologous Tissue Substitute, External Approach */
"0902XJZ" = "1" /* Alteration of Bilateral External Ear with Synthetic Substitute, External Approach */
"0902XKZ" = "1" /* Alteration of Bilateral External Ear with Nonautologous Tissue Substitute, External Approach */
"0902XZZ" = "1" /* Alteration of Bilateral External Ear, External Approach */
"090K07Z" = "1" /* Alteration of Nose with Autologous Tissue Substitute, Open Approach */
"090K0JZ" = "1" /* Alteration of Nose with Synthetic Substitute, Open Approach */
"090K0KZ" = "1" /* Alteration of Nose with Nonautologous Tissue Substitute, Open Approach */
"090K0ZZ" = "1" /* Alteration of Nose, Open Approach */
"090K37Z" = "1" /* Alteration of Nose with Autologous Tissue Substitute, Percutaneous Approach */
"090K3JZ" = "1" /* Alteration of Nose with Synthetic Substitute, Percutaneous Approach */
"090K3KZ" = "1" /* Alteration of Nose with Nonautologous Tissue Substitute, Percutaneous Approach */
"090K3ZZ" = "1" /* Alteration of Nose, Percutaneous Approach */
"090K47Z" = "1" /* Alteration of Nose with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"090K4JZ" = "1" /* Alteration of Nose with Synthetic Substitute, Percutaneous Endoscopic Approach */
"090K4KZ" = "1" /* Alteration of Nose with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"090K4ZZ" = "1" /* Alteration of Nose, Percutaneous Endoscopic Approach */
"090KX7Z" = "1" /* Alteration of Nose with Autologous Tissue Substitute, External Approach */
"090KXJZ" = "1" /* Alteration of Nose with Synthetic Substitute, External Approach */
"090KXKZ" = "1" /* Alteration of Nose with Nonautologous Tissue Substitute, External Approach */
"090KXZZ" = "1" /* Alteration of Nose, External Approach */
"091D070" = "1" /* Bypass Right Inner Ear to Endolymphatic with Autologous Tissue Substitute, Open Approach */
"091D0J0" = "1" /* Bypass Right Inner Ear to Endolymphatic with Synthetic Substitute, Open Approach */
"091D0K0" = "1" /* Bypass Right Inner Ear to Endolymphatic with Nonautologous Tissue Substitute, Open Approach */
"091D0Z0" = "1" /* Bypass Right Inner Ear to Endolymphatic, Open Approach */
"091E070" = "1" /* Bypass Left Inner Ear to Endolymphatic with Autologous Tissue Substitute, Open Approach */
"091E0J0" = "1" /* Bypass Left Inner Ear to Endolymphatic with Synthetic Substitute, Open Approach */
"091E0K0" = "1" /* Bypass Left Inner Ear to Endolymphatic with Nonautologous Tissue Substitute, Open Approach */
"091E0Z0" = "1" /* Bypass Left Inner Ear to Endolymphatic, Open Approach */
"09550ZZ" = "1" /* Destruction of Right Middle Ear, Open Approach */
"09560ZZ" = "1" /* Destruction of Left Middle Ear, Open Approach */
"09570ZZ" = "1" /* Destruction of Right Tympanic Membrane, Open Approach */
"09573ZZ" = "1" /* Destruction of Right Tympanic Membrane, Percutaneous Approach */
"09574ZZ" = "1" /* Destruction of Right Tympanic Membrane, Percutaneous Endoscopic Approach */
"09577ZZ" = "1" /* Destruction of Right Tympanic Membrane, Via Natural or Artificial Opening */
"09578ZZ" = "1" /* Destruction of Right Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"09580ZZ" = "1" /* Destruction of Left Tympanic Membrane, Open Approach */
"09583ZZ" = "1" /* Destruction of Left Tympanic Membrane, Percutaneous Approach */
"09584ZZ" = "1" /* Destruction of Left Tympanic Membrane, Percutaneous Endoscopic Approach */
"09587ZZ" = "1" /* Destruction of Left Tympanic Membrane, Via Natural or Artificial Opening */
"09588ZZ" = "1" /* Destruction of Left Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"09590ZZ" = "1" /* Destruction of Right Auditory Ossicle, Open Approach */
"095A0ZZ" = "1" /* Destruction of Left Auditory Ossicle, Open Approach */
"095B0ZZ" = "1" /* Destruction of Right Mastoid Sinus, Open Approach */
"095B3ZZ" = "1" /* Destruction of Right Mastoid Sinus, Percutaneous Approach */
"095B4ZZ" = "1" /* Destruction of Right Mastoid Sinus, Percutaneous Endoscopic Approach */
"095C0ZZ" = "1" /* Destruction of Left Mastoid Sinus, Open Approach */
"095C3ZZ" = "1" /* Destruction of Left Mastoid Sinus, Percutaneous Approach */
"095C4ZZ" = "1" /* Destruction of Left Mastoid Sinus, Percutaneous Endoscopic Approach */
"095D0ZZ" = "1" /* Destruction of Right Inner Ear, Open Approach */
"095E0ZZ" = "1" /* Destruction of Left Inner Ear, Open Approach */
"095L0ZZ" = "1" /* Destruction of Nasal Turbinate, Open Approach */
"095L3ZZ" = "1" /* Destruction of Nasal Turbinate, Percutaneous Approach */
"095L4ZZ" = "1" /* Destruction of Nasal Turbinate, Percutaneous Endoscopic Approach */
"095L7ZZ" = "1" /* Destruction of Nasal Turbinate, Via Natural or Artificial Opening */
"095L8ZZ" = "1" /* Destruction of Nasal Turbinate, Via Natural or Artificial Opening Endoscopic */
"095N0ZZ" = "1" /* Destruction of Nasopharynx, Open Approach */
"095N3ZZ" = "1" /* Destruction of Nasopharynx, Percutaneous Approach */
"095N4ZZ" = "1" /* Destruction of Nasopharynx, Percutaneous Endoscopic Approach */
"095N7ZZ" = "1" /* Destruction of Nasopharynx, Via Natural or Artificial Opening */
"095N8ZZ" = "1" /* Destruction of Nasopharynx, Via Natural or Artificial Opening Endoscopic */
"095P0ZZ" = "1" /* Destruction of Accessory Sinus, Open Approach */
"095P3ZZ" = "1" /* Destruction of Accessory Sinus, Percutaneous Approach */
"095P4ZZ" = "1" /* Destruction of Accessory Sinus, Percutaneous Endoscopic Approach */
"095Q0ZZ" = "1" /* Destruction of Right Maxillary Sinus, Open Approach */
"095Q3ZZ" = "1" /* Destruction of Right Maxillary Sinus, Percutaneous Approach */
"095Q4ZZ" = "1" /* Destruction of Right Maxillary Sinus, Percutaneous Endoscopic Approach */
"095R0ZZ" = "1" /* Destruction of Left Maxillary Sinus, Open Approach */
"095R3ZZ" = "1" /* Destruction of Left Maxillary Sinus, Percutaneous Approach */
"095R4ZZ" = "1" /* Destruction of Left Maxillary Sinus, Percutaneous Endoscopic Approach */
"095S0ZZ" = "1" /* Destruction of Right Frontal Sinus, Open Approach */
"095S3ZZ" = "1" /* Destruction of Right Frontal Sinus, Percutaneous Approach */
"095S4ZZ" = "1" /* Destruction of Right Frontal Sinus, Percutaneous Endoscopic Approach */
"095T0ZZ" = "1" /* Destruction of Left Frontal Sinus, Open Approach */
"095T3ZZ" = "1" /* Destruction of Left Frontal Sinus, Percutaneous Approach */
"095T4ZZ" = "1" /* Destruction of Left Frontal Sinus, Percutaneous Endoscopic Approach */
"095U0ZZ" = "1" /* Destruction of Right Ethmoid Sinus, Open Approach */
"095U3ZZ" = "1" /* Destruction of Right Ethmoid Sinus, Percutaneous Approach */
"095U4ZZ" = "1" /* Destruction of Right Ethmoid Sinus, Percutaneous Endoscopic Approach */
"095V0ZZ" = "1" /* Destruction of Left Ethmoid Sinus, Open Approach */
"095V3ZZ" = "1" /* Destruction of Left Ethmoid Sinus, Percutaneous Approach */
"095V4ZZ" = "1" /* Destruction of Left Ethmoid Sinus, Percutaneous Endoscopic Approach */
"095W0ZZ" = "1" /* Destruction of Right Sphenoid Sinus, Open Approach */
"095W3ZZ" = "1" /* Destruction of Right Sphenoid Sinus, Percutaneous Approach */
"095W4ZZ" = "1" /* Destruction of Right Sphenoid Sinus, Percutaneous Endoscopic Approach */
"095X0ZZ" = "1" /* Destruction of Left Sphenoid Sinus, Open Approach */
"095X3ZZ" = "1" /* Destruction of Left Sphenoid Sinus, Percutaneous Approach */
"095X4ZZ" = "1" /* Destruction of Left Sphenoid Sinus, Percutaneous Endoscopic Approach */
"098L0ZZ" = "1" /* Division of Nasal Turbinate, Open Approach */
"098L3ZZ" = "1" /* Division of Nasal Turbinate, Percutaneous Approach */
"098L4ZZ" = "1" /* Division of Nasal Turbinate, Percutaneous Endoscopic Approach */
"098L7ZZ" = "1" /* Division of Nasal Turbinate, Via Natural or Artificial Opening */
"098L8ZZ" = "1" /* Division of Nasal Turbinate, Via Natural or Artificial Opening Endoscopic */
"099500Z" = "1" /* Drainage of Right Middle Ear with Drainage Device, Open Approach */
"09950ZX" = "1" /* Drainage of Right Middle Ear, Open Approach, Diagnostic */
"099600Z" = "1" /* Drainage of Left Middle Ear with Drainage Device, Open Approach */
"09960ZX" = "1" /* Drainage of Left Middle Ear, Open Approach, Diagnostic */
"099700Z" = "1" /* Drainage of Right Tympanic Membrane with Drainage Device, Open Approach */
"09970ZX" = "1" /* Drainage of Right Tympanic Membrane, Open Approach, Diagnostic */
"099730Z" = "1" /* Drainage of Right Tympanic Membrane with Drainage Device, Percutaneous Approach */
"09973ZX" = "1" /* Drainage of Right Tympanic Membrane, Percutaneous Approach, Diagnostic */
"099740Z" = "1" /* Drainage of Right Tympanic Membrane with Drainage Device, Percutaneous Endoscopic Approach */
"09974ZX" = "1" /* Drainage of Right Tympanic Membrane, Percutaneous Endoscopic Approach, Diagnostic */
"099770Z" = "1" /* Drainage of Right Tympanic Membrane with Drainage Device, Via Natural or Artificial Opening */
"099780Z" = "1" /* Drainage of Right Tympanic Membrane with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"099800Z" = "1" /* Drainage of Left Tympanic Membrane with Drainage Device, Open Approach */
"09980ZX" = "1" /* Drainage of Left Tympanic Membrane, Open Approach, Diagnostic */
"099830Z" = "1" /* Drainage of Left Tympanic Membrane with Drainage Device, Percutaneous Approach */
"09983ZX" = "1" /* Drainage of Left Tympanic Membrane, Percutaneous Approach, Diagnostic */
"099840Z" = "1" /* Drainage of Left Tympanic Membrane with Drainage Device, Percutaneous Endoscopic Approach */
"09984ZX" = "1" /* Drainage of Left Tympanic Membrane, Percutaneous Endoscopic Approach, Diagnostic */
"099870Z" = "1" /* Drainage of Left Tympanic Membrane with Drainage Device, Via Natural or Artificial Opening */
"099880Z" = "1" /* Drainage of Left Tympanic Membrane with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"099900Z" = "1" /* Drainage of Right Auditory Ossicle with Drainage Device, Open Approach */
"09990ZX" = "1" /* Drainage of Right Auditory Ossicle, Open Approach, Diagnostic */
"09990ZZ" = "1" /* Drainage of Right Auditory Ossicle, Open Approach */
"099A00Z" = "1" /* Drainage of Left Auditory Ossicle with Drainage Device, Open Approach */
"099A0ZX" = "1" /* Drainage of Left Auditory Ossicle, Open Approach, Diagnostic */
"099A0ZZ" = "1" /* Drainage of Left Auditory Ossicle, Open Approach */
"099B00Z" = "1" /* Drainage of Right Mastoid Sinus with Drainage Device, Open Approach */
"099B0ZX" = "1" /* Drainage of Right Mastoid Sinus, Open Approach, Diagnostic */
"099B0ZZ" = "1" /* Drainage of Right Mastoid Sinus, Open Approach */
"099B40Z" = "1" /* Drainage of Right Mastoid Sinus with Drainage Device, Percutaneous Endoscopic Approach */
"099B4ZX" = "1" /* Drainage of Right Mastoid Sinus, Percutaneous Endoscopic Approach, Diagnostic */
"099B4ZZ" = "1" /* Drainage of Right Mastoid Sinus, Percutaneous Endoscopic Approach */
"099C00Z" = "1" /* Drainage of Left Mastoid Sinus with Drainage Device, Open Approach */
"099C0ZX" = "1" /* Drainage of Left Mastoid Sinus, Open Approach, Diagnostic */
"099C0ZZ" = "1" /* Drainage of Left Mastoid Sinus, Open Approach */
"099C40Z" = "1" /* Drainage of Left Mastoid Sinus with Drainage Device, Percutaneous Endoscopic Approach */
"099C4ZX" = "1" /* Drainage of Left Mastoid Sinus, Percutaneous Endoscopic Approach, Diagnostic */
"099C4ZZ" = "1" /* Drainage of Left Mastoid Sinus, Percutaneous Endoscopic Approach */
"099D00Z" = "1" /* Drainage of Right Inner Ear with Drainage Device, Open Approach */
"099D0ZX" = "1" /* Drainage of Right Inner Ear, Open Approach, Diagnostic */
"099D0ZZ" = "1" /* Drainage of Right Inner Ear, Open Approach */
"099E00Z" = "1" /* Drainage of Left Inner Ear with Drainage Device, Open Approach */
"099E0ZX" = "1" /* Drainage of Left Inner Ear, Open Approach, Diagnostic */
"099E0ZZ" = "1" /* Drainage of Left Inner Ear, Open Approach */
"099F0ZX" = "1" /* Drainage of Right Eustachian Tube, Open Approach, Diagnostic */
"099F4ZX" = "1" /* Drainage of Right Eustachian Tube, Percutaneous Endoscopic Approach, Diagnostic */
"099G0ZX" = "1" /* Drainage of Left Eustachian Tube, Open Approach, Diagnostic */
"099G4ZX" = "1" /* Drainage of Left Eustachian Tube, Percutaneous Endoscopic Approach, Diagnostic */
"099N00Z" = "1" /* Drainage of Nasopharynx with Drainage Device, Open Approach */
"099N0ZZ" = "1" /* Drainage of Nasopharynx, Open Approach */
"099N40Z" = "1" /* Drainage of Nasopharynx with Drainage Device, Percutaneous Endoscopic Approach */
"099N4ZZ" = "1" /* Drainage of Nasopharynx, Percutaneous Endoscopic Approach */
"099N70Z" = "1" /* Drainage of Nasopharynx with Drainage Device, Via Natural or Artificial Opening */
"099N7ZZ" = "1" /* Drainage of Nasopharynx, Via Natural or Artificial Opening */
"099N80Z" = "1" /* Drainage of Nasopharynx with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"099N8ZZ" = "1" /* Drainage of Nasopharynx, Via Natural or Artificial Opening Endoscopic */
"099P00Z" = "1" /* Drainage of Accessory Sinus with Drainage Device, Open Approach */
"099P0ZX" = "1" /* Drainage of Accessory Sinus, Open Approach, Diagnostic */
"099P0ZZ" = "1" /* Drainage of Accessory Sinus, Open Approach */
"099Q00Z" = "1" /* Drainage of Right Maxillary Sinus with Drainage Device, Open Approach */
"099Q0ZX" = "1" /* Drainage of Right Maxillary Sinus, Open Approach, Diagnostic */
"099Q0ZZ" = "1" /* Drainage of Right Maxillary Sinus, Open Approach */
"099R00Z" = "1" /* Drainage of Left Maxillary Sinus with Drainage Device, Open Approach */
"099R0ZX" = "1" /* Drainage of Left Maxillary Sinus, Open Approach, Diagnostic */
"099R0ZZ" = "1" /* Drainage of Left Maxillary Sinus, Open Approach */
"099S00Z" = "1" /* Drainage of Right Frontal Sinus with Drainage Device, Open Approach */
"099S0ZX" = "1" /* Drainage of Right Frontal Sinus, Open Approach, Diagnostic */
"099S0ZZ" = "1" /* Drainage of Right Frontal Sinus, Open Approach */
"099T00Z" = "1" /* Drainage of Left Frontal Sinus with Drainage Device, Open Approach */
"099T0ZX" = "1" /* Drainage of Left Frontal Sinus, Open Approach, Diagnostic */
"099T0ZZ" = "1" /* Drainage of Left Frontal Sinus, Open Approach */
"099U00Z" = "1" /* Drainage of Right Ethmoid Sinus with Drainage Device, Open Approach */
"099U0ZX" = "1" /* Drainage of Right Ethmoid Sinus, Open Approach, Diagnostic */
"099U0ZZ" = "1" /* Drainage of Right Ethmoid Sinus, Open Approach */
"099V00Z" = "1" /* Drainage of Left Ethmoid Sinus with Drainage Device, Open Approach */
"099V0ZX" = "1" /* Drainage of Left Ethmoid Sinus, Open Approach, Diagnostic */
"099V0ZZ" = "1" /* Drainage of Left Ethmoid Sinus, Open Approach */
"099W00Z" = "1" /* Drainage of Right Sphenoid Sinus with Drainage Device, Open Approach */
"099W0ZX" = "1" /* Drainage of Right Sphenoid Sinus, Open Approach, Diagnostic */
"099W0ZZ" = "1" /* Drainage of Right Sphenoid Sinus, Open Approach */
"099X00Z" = "1" /* Drainage of Left Sphenoid Sinus with Drainage Device, Open Approach */
"099X0ZX" = "1" /* Drainage of Left Sphenoid Sinus, Open Approach, Diagnostic */
"099X0ZZ" = "1" /* Drainage of Left Sphenoid Sinus, Open Approach */
"09B50ZX" = "1" /* Excision of Right Middle Ear, Open Approach, Diagnostic */
"09B50ZZ" = "1" /* Excision of Right Middle Ear, Open Approach */
"09B60ZX" = "1" /* Excision of Left Middle Ear, Open Approach, Diagnostic */
"09B60ZZ" = "1" /* Excision of Left Middle Ear, Open Approach */
"09B70ZX" = "1" /* Excision of Right Tympanic Membrane, Open Approach, Diagnostic */
"09B70ZZ" = "1" /* Excision of Right Tympanic Membrane, Open Approach */
"09B73ZX" = "1" /* Excision of Right Tympanic Membrane, Percutaneous Approach, Diagnostic */
"09B73ZZ" = "1" /* Excision of Right Tympanic Membrane, Percutaneous Approach */
"09B74ZX" = "1" /* Excision of Right Tympanic Membrane, Percutaneous Endoscopic Approach, Diagnostic */
"09B74ZZ" = "1" /* Excision of Right Tympanic Membrane, Percutaneous Endoscopic Approach */
"09B77ZX" = "1" /* Excision of Right Tympanic Membrane, Via Natural or Artificial Opening, Diagnostic */
"09B77ZZ" = "1" /* Excision of Right Tympanic Membrane, Via Natural or Artificial Opening */
"09B78ZX" = "1" /* Excision of Right Tympanic Membrane, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"09B78ZZ" = "1" /* Excision of Right Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"09B80ZX" = "1" /* Excision of Left Tympanic Membrane, Open Approach, Diagnostic */
"09B80ZZ" = "1" /* Excision of Left Tympanic Membrane, Open Approach */
"09B83ZX" = "1" /* Excision of Left Tympanic Membrane, Percutaneous Approach, Diagnostic */
"09B83ZZ" = "1" /* Excision of Left Tympanic Membrane, Percutaneous Approach */
"09B84ZX" = "1" /* Excision of Left Tympanic Membrane, Percutaneous Endoscopic Approach, Diagnostic */
"09B84ZZ" = "1" /* Excision of Left Tympanic Membrane, Percutaneous Endoscopic Approach */
"09B87ZX" = "1" /* Excision of Left Tympanic Membrane, Via Natural or Artificial Opening, Diagnostic */
"09B87ZZ" = "1" /* Excision of Left Tympanic Membrane, Via Natural or Artificial Opening */
"09B88ZX" = "1" /* Excision of Left Tympanic Membrane, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"09B88ZZ" = "1" /* Excision of Left Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"09B90ZX" = "1" /* Excision of Right Auditory Ossicle, Open Approach, Diagnostic */
"09B90ZZ" = "1" /* Excision of Right Auditory Ossicle, Open Approach */
"09BA0ZX" = "1" /* Excision of Left Auditory Ossicle, Open Approach, Diagnostic */
"09BA0ZZ" = "1" /* Excision of Left Auditory Ossicle, Open Approach */
"09BB0ZX" = "1" /* Excision of Right Mastoid Sinus, Open Approach, Diagnostic */
"09BB0ZZ" = "1" /* Excision of Right Mastoid Sinus, Open Approach */
"09BB3ZX" = "1" /* Excision of Right Mastoid Sinus, Percutaneous Approach, Diagnostic */
"09BB3ZZ" = "1" /* Excision of Right Mastoid Sinus, Percutaneous Approach */
"09BB4ZX" = "1" /* Excision of Right Mastoid Sinus, Percutaneous Endoscopic Approach, Diagnostic */
"09BB4ZZ" = "1" /* Excision of Right Mastoid Sinus, Percutaneous Endoscopic Approach */
"09BC0ZX" = "1" /* Excision of Left Mastoid Sinus, Open Approach, Diagnostic */
"09BC0ZZ" = "1" /* Excision of Left Mastoid Sinus, Open Approach */
"09BC3ZX" = "1" /* Excision of Left Mastoid Sinus, Percutaneous Approach, Diagnostic */
"09BC3ZZ" = "1" /* Excision of Left Mastoid Sinus, Percutaneous Approach */
"09BC4ZX" = "1" /* Excision of Left Mastoid Sinus, Percutaneous Endoscopic Approach, Diagnostic */
"09BC4ZZ" = "1" /* Excision of Left Mastoid Sinus, Percutaneous Endoscopic Approach */
"09BD0ZX" = "1" /* Excision of Right Inner Ear, Open Approach, Diagnostic */
"09BD0ZZ" = "1" /* Excision of Right Inner Ear, Open Approach */
"09BE0ZX" = "1" /* Excision of Left Inner Ear, Open Approach, Diagnostic */
"09BE0ZZ" = "1" /* Excision of Left Inner Ear, Open Approach */
"09BL0ZZ" = "1" /* Excision of Nasal Turbinate, Open Approach */
"09BL3ZZ" = "1" /* Excision of Nasal Turbinate, Percutaneous Approach */
"09BL4ZZ" = "1" /* Excision of Nasal Turbinate, Percutaneous Endoscopic Approach */
"09BL7ZZ" = "1" /* Excision of Nasal Turbinate, Via Natural or Artificial Opening */
"09BL8ZZ" = "1" /* Excision of Nasal Turbinate, Via Natural or Artificial Opening Endoscopic */
"09BM0ZZ" = "1" /* Excision of Nasal Septum, Open Approach */
"09BM3ZZ" = "1" /* Excision of Nasal Septum, Percutaneous Approach */
"09BM4ZZ" = "1" /* Excision of Nasal Septum, Percutaneous Endoscopic Approach */
"09BN0ZZ" = "1" /* Excision of Nasopharynx, Open Approach */
"09BN3ZZ" = "1" /* Excision of Nasopharynx, Percutaneous Approach */
"09BN4ZZ" = "1" /* Excision of Nasopharynx, Percutaneous Endoscopic Approach */
"09BN7ZZ" = "1" /* Excision of Nasopharynx, Via Natural or Artificial Opening */
"09BN8ZZ" = "1" /* Excision of Nasopharynx, Via Natural or Artificial Opening Endoscopic */
"09BP0ZX" = "1" /* Excision of Accessory Sinus, Open Approach, Diagnostic */
"09BP0ZZ" = "1" /* Excision of Accessory Sinus, Open Approach */
"09BP3ZZ" = "1" /* Excision of Accessory Sinus, Percutaneous Approach */
"09BP4ZZ" = "1" /* Excision of Accessory Sinus, Percutaneous Endoscopic Approach */
"09BQ0ZX" = "1" /* Excision of Right Maxillary Sinus, Open Approach, Diagnostic */
"09BQ0ZZ" = "1" /* Excision of Right Maxillary Sinus, Open Approach */
"09BQ3ZZ" = "1" /* Excision of Right Maxillary Sinus, Percutaneous Approach */
"09BQ4ZZ" = "1" /* Excision of Right Maxillary Sinus, Percutaneous Endoscopic Approach */
"09BR0ZX" = "1" /* Excision of Left Maxillary Sinus, Open Approach, Diagnostic */
"09BR0ZZ" = "1" /* Excision of Left Maxillary Sinus, Open Approach */
"09BR3ZZ" = "1" /* Excision of Left Maxillary Sinus, Percutaneous Approach */
"09BR4ZZ" = "1" /* Excision of Left Maxillary Sinus, Percutaneous Endoscopic Approach */
"09BS0ZX" = "1" /* Excision of Right Frontal Sinus, Open Approach, Diagnostic */
"09BS0ZZ" = "1" /* Excision of Right Frontal Sinus, Open Approach */
"09BS3ZZ" = "1" /* Excision of Right Frontal Sinus, Percutaneous Approach */
"09BS4ZZ" = "1" /* Excision of Right Frontal Sinus, Percutaneous Endoscopic Approach */
"09BT0ZX" = "1" /* Excision of Left Frontal Sinus, Open Approach, Diagnostic */
"09BT0ZZ" = "1" /* Excision of Left Frontal Sinus, Open Approach */
"09BT3ZZ" = "1" /* Excision of Left Frontal Sinus, Percutaneous Approach */
"09BT4ZZ" = "1" /* Excision of Left Frontal Sinus, Percutaneous Endoscopic Approach */
"09BU0ZX" = "1" /* Excision of Right Ethmoid Sinus, Open Approach, Diagnostic */
"09BU0ZZ" = "1" /* Excision of Right Ethmoid Sinus, Open Approach */
"09BU3ZZ" = "1" /* Excision of Right Ethmoid Sinus, Percutaneous Approach */
"09BU4ZZ" = "1" /* Excision of Right Ethmoid Sinus, Percutaneous Endoscopic Approach */
"09BV0ZX" = "1" /* Excision of Left Ethmoid Sinus, Open Approach, Diagnostic */
"09BV0ZZ" = "1" /* Excision of Left Ethmoid Sinus, Open Approach */
"09BV3ZZ" = "1" /* Excision of Left Ethmoid Sinus, Percutaneous Approach */
"09BV4ZZ" = "1" /* Excision of Left Ethmoid Sinus, Percutaneous Endoscopic Approach */
"09BW0ZX" = "1" /* Excision of Right Sphenoid Sinus, Open Approach, Diagnostic */
"09BW0ZZ" = "1" /* Excision of Right Sphenoid Sinus, Open Approach */
"09BW3ZZ" = "1" /* Excision of Right Sphenoid Sinus, Percutaneous Approach */
"09BW4ZZ" = "1" /* Excision of Right Sphenoid Sinus, Percutaneous Endoscopic Approach */
"09BX0ZX" = "1" /* Excision of Left Sphenoid Sinus, Open Approach, Diagnostic */
"09BX0ZZ" = "1" /* Excision of Left Sphenoid Sinus, Open Approach */
"09BX3ZZ" = "1" /* Excision of Left Sphenoid Sinus, Percutaneous Approach */
"09BX4ZZ" = "1" /* Excision of Left Sphenoid Sinus, Percutaneous Endoscopic Approach */
"09C50ZZ" = "1" /* Extirpation of Matter from Right Middle Ear, Open Approach */
"09C60ZZ" = "1" /* Extirpation of Matter from Left Middle Ear, Open Approach */
"09C90ZZ" = "1" /* Extirpation of Matter from Right Auditory Ossicle, Open Approach */
"09CA0ZZ" = "1" /* Extirpation of Matter from Left Auditory Ossicle, Open Approach */
"09CB0ZZ" = "1" /* Extirpation of Matter from Right Mastoid Sinus, Open Approach */
"09CB3ZZ" = "1" /* Extirpation of Matter from Right Mastoid Sinus, Percutaneous Approach */
"09CB4ZZ" = "1" /* Extirpation of Matter from Right Mastoid Sinus, Percutaneous Endoscopic Approach */
"09CC0ZZ" = "1" /* Extirpation of Matter from Left Mastoid Sinus, Open Approach */
"09CC3ZZ" = "1" /* Extirpation of Matter from Left Mastoid Sinus, Percutaneous Approach */
"09CC4ZZ" = "1" /* Extirpation of Matter from Left Mastoid Sinus, Percutaneous Endoscopic Approach */
"09CD0ZZ" = "1" /* Extirpation of Matter from Right Inner Ear, Open Approach */
"09CE0ZZ" = "1" /* Extirpation of Matter from Left Inner Ear, Open Approach */
"09CN0ZZ" = "1" /* Extirpation of Matter from Nasopharynx, Open Approach */
"09CN3ZZ" = "1" /* Extirpation of Matter from Nasopharynx, Percutaneous Approach */
"09CN4ZZ" = "1" /* Extirpation of Matter from Nasopharynx, Percutaneous Endoscopic Approach */
"09CN7ZZ" = "1" /* Extirpation of Matter from Nasopharynx, Via Natural or Artificial Opening */
"09CN8ZZ" = "1" /* Extirpation of Matter from Nasopharynx, Via Natural or Artificial Opening Endoscopic */
"09CP0ZZ" = "1" /* Extirpation of Matter from Accessory Sinus, Open Approach */
"09CP3ZZ" = "1" /* Extirpation of Matter from Accessory Sinus, Percutaneous Approach */
"09CP4ZZ" = "1" /* Extirpation of Matter from Accessory Sinus, Percutaneous Endoscopic Approach */
"09CQ0ZZ" = "1" /* Extirpation of Matter from Right Maxillary Sinus, Open Approach */
"09CQ3ZZ" = "1" /* Extirpation of Matter from Right Maxillary Sinus, Percutaneous Approach */
"09CQ4ZZ" = "1" /* Extirpation of Matter from Right Maxillary Sinus, Percutaneous Endoscopic Approach */
"09CR0ZZ" = "1" /* Extirpation of Matter from Left Maxillary Sinus, Open Approach */
"09CR3ZZ" = "1" /* Extirpation of Matter from Left Maxillary Sinus, Percutaneous Approach */
"09CR4ZZ" = "1" /* Extirpation of Matter from Left Maxillary Sinus, Percutaneous Endoscopic Approach */
"09CS0ZZ" = "1" /* Extirpation of Matter from Right Frontal Sinus, Open Approach */
"09CS3ZZ" = "1" /* Extirpation of Matter from Right Frontal Sinus, Percutaneous Approach */
"09CS4ZZ" = "1" /* Extirpation of Matter from Right Frontal Sinus, Percutaneous Endoscopic Approach */
"09CT0ZZ" = "1" /* Extirpation of Matter from Left Frontal Sinus, Open Approach */
"09CT3ZZ" = "1" /* Extirpation of Matter from Left Frontal Sinus, Percutaneous Approach */
"09CT4ZZ" = "1" /* Extirpation of Matter from Left Frontal Sinus, Percutaneous Endoscopic Approach */
"09CU0ZZ" = "1" /* Extirpation of Matter from Right Ethmoid Sinus, Open Approach */
"09CU3ZZ" = "1" /* Extirpation of Matter from Right Ethmoid Sinus, Percutaneous Approach */
"09CU4ZZ" = "1" /* Extirpation of Matter from Right Ethmoid Sinus, Percutaneous Endoscopic Approach */
"09CV0ZZ" = "1" /* Extirpation of Matter from Left Ethmoid Sinus, Open Approach */
"09CV3ZZ" = "1" /* Extirpation of Matter from Left Ethmoid Sinus, Percutaneous Approach */
"09CV4ZZ" = "1" /* Extirpation of Matter from Left Ethmoid Sinus, Percutaneous Endoscopic Approach */
"09CW0ZZ" = "1" /* Extirpation of Matter from Right Sphenoid Sinus, Open Approach */
"09CW3ZZ" = "1" /* Extirpation of Matter from Right Sphenoid Sinus, Percutaneous Approach */
"09CW4ZZ" = "1" /* Extirpation of Matter from Right Sphenoid Sinus, Percutaneous Endoscopic Approach */
"09CX0ZZ" = "1" /* Extirpation of Matter from Left Sphenoid Sinus, Open Approach */
"09CX3ZZ" = "1" /* Extirpation of Matter from Left Sphenoid Sinus, Percutaneous Approach */
"09CX4ZZ" = "1" /* Extirpation of Matter from Left Sphenoid Sinus, Percutaneous Endoscopic Approach */
"09D70ZZ" = "1" /* Extraction of Right Tympanic Membrane, Open Approach */
"09D73ZZ" = "1" /* Extraction of Right Tympanic Membrane, Percutaneous Approach */
"09D74ZZ" = "1" /* Extraction of Right Tympanic Membrane, Percutaneous Endoscopic Approach */
"09D77ZZ" = "1" /* Extraction of Right Tympanic Membrane, Via Natural or Artificial Opening */
"09D78ZZ" = "1" /* Extraction of Right Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"09D80ZZ" = "1" /* Extraction of Left Tympanic Membrane, Open Approach */
"09D83ZZ" = "1" /* Extraction of Left Tympanic Membrane, Percutaneous Approach */
"09D84ZZ" = "1" /* Extraction of Left Tympanic Membrane, Percutaneous Endoscopic Approach */
"09D87ZZ" = "1" /* Extraction of Left Tympanic Membrane, Via Natural or Artificial Opening */
"09D88ZZ" = "1" /* Extraction of Left Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"09D90ZZ" = "1" /* Extraction of Right Auditory Ossicle, Open Approach */
"09DA0ZZ" = "1" /* Extraction of Left Auditory Ossicle, Open Approach */
"09DB0ZZ" = "1" /* Extraction of Right Mastoid Sinus, Open Approach */
"09DB3ZZ" = "1" /* Extraction of Right Mastoid Sinus, Percutaneous Approach */
"09DB4ZZ" = "1" /* Extraction of Right Mastoid Sinus, Percutaneous Endoscopic Approach */
"09DC0ZZ" = "1" /* Extraction of Left Mastoid Sinus, Open Approach */
"09DC3ZZ" = "1" /* Extraction of Left Mastoid Sinus, Percutaneous Approach */
"09DC4ZZ" = "1" /* Extraction of Left Mastoid Sinus, Percutaneous Endoscopic Approach */
"09DL0ZZ" = "1" /* Extraction of Nasal Turbinate, Open Approach */
"09DL3ZZ" = "1" /* Extraction of Nasal Turbinate, Percutaneous Approach */
"09DL4ZZ" = "1" /* Extraction of Nasal Turbinate, Percutaneous Endoscopic Approach */
"09DL7ZZ" = "1" /* Extraction of Nasal Turbinate, Via Natural or Artificial Opening */
"09DL8ZZ" = "1" /* Extraction of Nasal Turbinate, Via Natural or Artificial Opening Endoscopic */
"09DM0ZZ" = "1" /* Extraction of Nasal Septum, Open Approach */
"09DM3ZZ" = "1" /* Extraction of Nasal Septum, Percutaneous Approach */
"09DM4ZZ" = "1" /* Extraction of Nasal Septum, Percutaneous Endoscopic Approach */
"09DP0ZZ" = "1" /* Extraction of Accessory Sinus, Open Approach */
"09DP3ZZ" = "1" /* Extraction of Accessory Sinus, Percutaneous Approach */
"09DP4ZZ" = "1" /* Extraction of Accessory Sinus, Percutaneous Endoscopic Approach */
"09DQ0ZZ" = "1" /* Extraction of Right Maxillary Sinus, Open Approach */
"09DQ3ZZ" = "1" /* Extraction of Right Maxillary Sinus, Percutaneous Approach */
"09DQ4ZZ" = "1" /* Extraction of Right Maxillary Sinus, Percutaneous Endoscopic Approach */
"09DR0ZZ" = "1" /* Extraction of Left Maxillary Sinus, Open Approach */
"09DR3ZZ" = "1" /* Extraction of Left Maxillary Sinus, Percutaneous Approach */
"09DR4ZZ" = "1" /* Extraction of Left Maxillary Sinus, Percutaneous Endoscopic Approach */
"09DS0ZZ" = "1" /* Extraction of Right Frontal Sinus, Open Approach */
"09DS3ZZ" = "1" /* Extraction of Right Frontal Sinus, Percutaneous Approach */
"09DS4ZZ" = "1" /* Extraction of Right Frontal Sinus, Percutaneous Endoscopic Approach */
"09DT0ZZ" = "1" /* Extraction of Left Frontal Sinus, Open Approach */
"09DT3ZZ" = "1" /* Extraction of Left Frontal Sinus, Percutaneous Approach */
"09DT4ZZ" = "1" /* Extraction of Left Frontal Sinus, Percutaneous Endoscopic Approach */
"09DU0ZZ" = "1" /* Extraction of Right Ethmoid Sinus, Open Approach */
"09DU3ZZ" = "1" /* Extraction of Right Ethmoid Sinus, Percutaneous Approach */
"09DU4ZZ" = "1" /* Extraction of Right Ethmoid Sinus, Percutaneous Endoscopic Approach */
"09DV0ZZ" = "1" /* Extraction of Left Ethmoid Sinus, Open Approach */
"09DV3ZZ" = "1" /* Extraction of Left Ethmoid Sinus, Percutaneous Approach */
"09DV4ZZ" = "1" /* Extraction of Left Ethmoid Sinus, Percutaneous Endoscopic Approach */
"09DW0ZZ" = "1" /* Extraction of Right Sphenoid Sinus, Open Approach */
"09DW3ZZ" = "1" /* Extraction of Right Sphenoid Sinus, Percutaneous Approach */
"09DW4ZZ" = "1" /* Extraction of Right Sphenoid Sinus, Percutaneous Endoscopic Approach */
"09DX0ZZ" = "1" /* Extraction of Left Sphenoid Sinus, Open Approach */
"09DX3ZZ" = "1" /* Extraction of Left Sphenoid Sinus, Percutaneous Approach */
"09DX4ZZ" = "1" /* Extraction of Left Sphenoid Sinus, Percutaneous Endoscopic Approach */
"09HD04Z" = "1" /* Insertion of Bone Conduction Hearing Device into Right Inner Ear, Open Approach */
"09HD05Z" = "1" /* Insertion of Single Channel Cochlear Prosthesis into Right Inner Ear, Open Approach */
"09HD06Z" = "1" /* Insertion of Multiple Channel Cochlear Prosthesis into Right Inner Ear, Open Approach */
"09HD0SZ" = "1" /* Insertion of Hearing Device into Right Inner Ear, Open Approach */
"09HD34Z" = "1" /* Insertion of Bone Conduction Hearing Device into Right Inner Ear, Percutaneous Approach */
"09HD35Z" = "1" /* Insertion of Single Channel Cochlear Prosthesis into Right Inner Ear, Percutaneous Approach */
"09HD36Z" = "1" /* Insertion of Multiple Channel Cochlear Prosthesis into Right Inner Ear, Percutaneous Approach */
"09HD3SZ" = "1" /* Insertion of Hearing Device into Right Inner Ear, Percutaneous Approach */
"09HD44Z" = "1" /* Insertion of Bone Conduction Hearing Device into Right Inner Ear, Percutaneous Endoscopic Approach */
"09HD45Z" = "1" /* Insertion of Single Channel Cochlear Prosthesis into Right Inner Ear, Percutaneous Endoscopic Approach */
"09HD46Z" = "1" /* Insertion of Multiple Channel Cochlear Prosthesis into Right Inner Ear, Percutaneous Endoscopic Approach */
"09HD4SZ" = "1" /* Insertion of Hearing Device into Right Inner Ear, Percutaneous Endoscopic Approach */
"09HE04Z" = "1" /* Insertion of Bone Conduction Hearing Device into Left Inner Ear, Open Approach */
"09HE05Z" = "1" /* Insertion of Single Channel Cochlear Prosthesis into Left Inner Ear, Open Approach */
"09HE06Z" = "1" /* Insertion of Multiple Channel Cochlear Prosthesis into Left Inner Ear, Open Approach */
"09HE0SZ" = "1" /* Insertion of Hearing Device into Left Inner Ear, Open Approach */
"09HE34Z" = "1" /* Insertion of Bone Conduction Hearing Device into Left Inner Ear, Percutaneous Approach */
"09HE35Z" = "1" /* Insertion of Single Channel Cochlear Prosthesis into Left Inner Ear, Percutaneous Approach */
"09HE36Z" = "1" /* Insertion of Multiple Channel Cochlear Prosthesis into Left Inner Ear, Percutaneous Approach */
"09HE3SZ" = "1" /* Insertion of Hearing Device into Left Inner Ear, Percutaneous Approach */
"09HE44Z" = "1" /* Insertion of Bone Conduction Hearing Device into Left Inner Ear, Percutaneous Endoscopic Approach */
"09HE45Z" = "1" /* Insertion of Single Channel Cochlear Prosthesis into Left Inner Ear, Percutaneous Endoscopic Approach */
"09HE46Z" = "1" /* Insertion of Multiple Channel Cochlear Prosthesis into Left Inner Ear, Percutaneous Endoscopic Approach */
"09HE4SZ" = "1" /* Insertion of Hearing Device into Left Inner Ear, Percutaneous Endoscopic Approach */
"09J70ZZ" = "1" /* Inspection of Right Tympanic Membrane, Open Approach */
"09J74ZZ" = "1" /* Inspection of Right Tympanic Membrane, Percutaneous Endoscopic Approach */
"09J80ZZ" = "1" /* Inspection of Left Tympanic Membrane, Open Approach */
"09J84ZZ" = "1" /* Inspection of Left Tympanic Membrane, Percutaneous Endoscopic Approach */
"09JD0ZZ" = "1" /* Inspection of Right Inner Ear, Open Approach */
"09JD4ZZ" = "1" /* Inspection of Right Inner Ear, Percutaneous Endoscopic Approach */
"09JE0ZZ" = "1" /* Inspection of Left Inner Ear, Open Approach */
"09JE4ZZ" = "1" /* Inspection of Left Inner Ear, Percutaneous Endoscopic Approach */
"09M0XZZ" = "1" /* Reattachment of Right External Ear, External Approach */
"09M1XZZ" = "1" /* Reattachment of Left External Ear, External Approach */
"09MKXZZ" = "1" /* Reattachment of Nose, External Approach */
"09N00ZZ" = "1" /* Release Right External Ear, Open Approach */
"09N03ZZ" = "1" /* Release Right External Ear, Percutaneous Approach */
"09N04ZZ" = "1" /* Release Right External Ear, Percutaneous Endoscopic Approach */
"09N10ZZ" = "1" /* Release Left External Ear, Open Approach */
"09N13ZZ" = "1" /* Release Left External Ear, Percutaneous Approach */
"09N14ZZ" = "1" /* Release Left External Ear, Percutaneous Endoscopic Approach */
"09N30ZZ" = "1" /* Release Right External Auditory Canal, Open Approach */
"09N33ZZ" = "1" /* Release Right External Auditory Canal, Percutaneous Approach */
"09N34ZZ" = "1" /* Release Right External Auditory Canal, Percutaneous Endoscopic Approach */
"09N37ZZ" = "1" /* Release Right External Auditory Canal, Via Natural or Artificial Opening */
"09N38ZZ" = "1" /* Release Right External Auditory Canal, Via Natural or Artificial Opening Endoscopic */
"09N40ZZ" = "1" /* Release Left External Auditory Canal, Open Approach */
"09N43ZZ" = "1" /* Release Left External Auditory Canal, Percutaneous Approach */
"09N44ZZ" = "1" /* Release Left External Auditory Canal, Percutaneous Endoscopic Approach */
"09N47ZZ" = "1" /* Release Left External Auditory Canal, Via Natural or Artificial Opening */
"09N48ZZ" = "1" /* Release Left External Auditory Canal, Via Natural or Artificial Opening Endoscopic */
"09N50ZZ" = "1" /* Release Right Middle Ear, Open Approach */
"09N60ZZ" = "1" /* Release Left Middle Ear, Open Approach */
"09N70ZZ" = "1" /* Release Right Tympanic Membrane, Open Approach */
"09N73ZZ" = "1" /* Release Right Tympanic Membrane, Percutaneous Approach */
"09N74ZZ" = "1" /* Release Right Tympanic Membrane, Percutaneous Endoscopic Approach */
"09N77ZZ" = "1" /* Release Right Tympanic Membrane, Via Natural or Artificial Opening */
"09N78ZZ" = "1" /* Release Right Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"09N80ZZ" = "1" /* Release Left Tympanic Membrane, Open Approach */
"09N83ZZ" = "1" /* Release Left Tympanic Membrane, Percutaneous Approach */
"09N84ZZ" = "1" /* Release Left Tympanic Membrane, Percutaneous Endoscopic Approach */
"09N87ZZ" = "1" /* Release Left Tympanic Membrane, Via Natural or Artificial Opening */
"09N88ZZ" = "1" /* Release Left Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"09N90ZZ" = "1" /* Release Right Auditory Ossicle, Open Approach */
"09NA0ZZ" = "1" /* Release Left Auditory Ossicle, Open Approach */
"09NB0ZZ" = "1" /* Release Right Mastoid Sinus, Open Approach */
"09NB3ZZ" = "1" /* Release Right Mastoid Sinus, Percutaneous Approach */
"09NB4ZZ" = "1" /* Release Right Mastoid Sinus, Percutaneous Endoscopic Approach */
"09NC0ZZ" = "1" /* Release Left Mastoid Sinus, Open Approach */
"09NC3ZZ" = "1" /* Release Left Mastoid Sinus, Percutaneous Approach */
"09NC4ZZ" = "1" /* Release Left Mastoid Sinus, Percutaneous Endoscopic Approach */
"09ND0ZZ" = "1" /* Release Right Inner Ear, Open Approach */
"09NE0ZZ" = "1" /* Release Left Inner Ear, Open Approach */
"09NN0ZZ" = "1" /* Release Nasopharynx, Open Approach */
"09NN3ZZ" = "1" /* Release Nasopharynx, Percutaneous Approach */
"09NN4ZZ" = "1" /* Release Nasopharynx, Percutaneous Endoscopic Approach */
"09NN7ZZ" = "1" /* Release Nasopharynx, Via Natural or Artificial Opening */
"09NN8ZZ" = "1" /* Release Nasopharynx, Via Natural or Artificial Opening Endoscopic */
"09NP0ZZ" = "1" /* Release Accessory Sinus, Open Approach */
"09NP3ZZ" = "1" /* Release Accessory Sinus, Percutaneous Approach */
"09NP4ZZ" = "1" /* Release Accessory Sinus, Percutaneous Endoscopic Approach */
"09NQ0ZZ" = "1" /* Release Right Maxillary Sinus, Open Approach */
"09NQ3ZZ" = "1" /* Release Right Maxillary Sinus, Percutaneous Approach */
"09NQ4ZZ" = "1" /* Release Right Maxillary Sinus, Percutaneous Endoscopic Approach */
"09NR0ZZ" = "1" /* Release Left Maxillary Sinus, Open Approach */
"09NR3ZZ" = "1" /* Release Left Maxillary Sinus, Percutaneous Approach */
"09NR4ZZ" = "1" /* Release Left Maxillary Sinus, Percutaneous Endoscopic Approach */
"09NS0ZZ" = "1" /* Release Right Frontal Sinus, Open Approach */
"09NS3ZZ" = "1" /* Release Right Frontal Sinus, Percutaneous Approach */
"09NS4ZZ" = "1" /* Release Right Frontal Sinus, Percutaneous Endoscopic Approach */
"09NT0ZZ" = "1" /* Release Left Frontal Sinus, Open Approach */
"09NT3ZZ" = "1" /* Release Left Frontal Sinus, Percutaneous Approach */
"09NT4ZZ" = "1" /* Release Left Frontal Sinus, Percutaneous Endoscopic Approach */
"09NU0ZZ" = "1" /* Release Right Ethmoid Sinus, Open Approach */
"09NU3ZZ" = "1" /* Release Right Ethmoid Sinus, Percutaneous Approach */
"09NU4ZZ" = "1" /* Release Right Ethmoid Sinus, Percutaneous Endoscopic Approach */
"09NV0ZZ" = "1" /* Release Left Ethmoid Sinus, Open Approach */
"09NV3ZZ" = "1" /* Release Left Ethmoid Sinus, Percutaneous Approach */
"09NV4ZZ" = "1" /* Release Left Ethmoid Sinus, Percutaneous Endoscopic Approach */
"09NW0ZZ" = "1" /* Release Right Sphenoid Sinus, Open Approach */
"09NW3ZZ" = "1" /* Release Right Sphenoid Sinus, Percutaneous Approach */
"09NW4ZZ" = "1" /* Release Right Sphenoid Sinus, Percutaneous Endoscopic Approach */
"09NX0ZZ" = "1" /* Release Left Sphenoid Sinus, Open Approach */
"09NX3ZZ" = "1" /* Release Left Sphenoid Sinus, Percutaneous Approach */
"09NX4ZZ" = "1" /* Release Left Sphenoid Sinus, Percutaneous Endoscopic Approach */
"09PD0SZ" = "1" /* Removal of Hearing Device from Right Inner Ear, Open Approach */
"09PD7SZ" = "1" /* Removal of Hearing Device from Right Inner Ear, Via Natural or Artificial Opening */
"09PD8SZ" = "1" /* Removal of Hearing Device from Right Inner Ear, Via Natural or Artificial Opening Endoscopic */
"09PE0SZ" = "1" /* Removal of Hearing Device from Left Inner Ear, Open Approach */
"09PE7SZ" = "1" /* Removal of Hearing Device from Left Inner Ear, Via Natural or Artificial Opening */
"09PE8SZ" = "1" /* Removal of Hearing Device from Left Inner Ear, Via Natural or Artificial Opening Endoscopic */
"09PH00Z" = "1" /* Removal of Drainage Device from Right Ear, Open Approach */
"09PH07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Ear, Open Approach */
"09PH0DZ" = "1" /* Removal of Intraluminal Device from Right Ear, Open Approach */
"09PH0JZ" = "1" /* Removal of Synthetic Substitute from Right Ear, Open Approach */
"09PH0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Ear, Open Approach */
"09PH37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Ear, Percutaneous Approach */
"09PH3DZ" = "1" /* Removal of Intraluminal Device from Right Ear, Percutaneous Approach */
"09PH47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Ear, Percutaneous Endoscopic Approach */
"09PH4DZ" = "1" /* Removal of Intraluminal Device from Right Ear, Percutaneous Endoscopic Approach */
"09PH77Z" = "1" /* Removal of Autologous Tissue Substitute from Right Ear, Via Natural or Artificial Opening */
"09PH7JZ" = "1" /* Removal of Synthetic Substitute from Right Ear, Via Natural or Artificial Opening */
"09PH7KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Ear, Via Natural or Artificial Opening */
"09PH87Z" = "1" /* Removal of Autologous Tissue Substitute from Right Ear, Via Natural or Artificial Opening Endoscopic */
"09PH8JZ" = "1" /* Removal of Synthetic Substitute from Right Ear, Via Natural or Artificial Opening Endoscopic */
"09PH8KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Ear, Via Natural or Artificial Opening Endoscopic */
"09PJ00Z" = "1" /* Removal of Drainage Device from Left Ear, Open Approach */
"09PJ07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Ear, Open Approach */
"09PJ0DZ" = "1" /* Removal of Intraluminal Device from Left Ear, Open Approach */
"09PJ0JZ" = "1" /* Removal of Synthetic Substitute from Left Ear, Open Approach */
"09PJ0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Ear, Open Approach */
"09PJ37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Ear, Percutaneous Approach */
"09PJ3DZ" = "1" /* Removal of Intraluminal Device from Left Ear, Percutaneous Approach */
"09PJ47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Ear, Percutaneous Endoscopic Approach */
"09PJ4DZ" = "1" /* Removal of Intraluminal Device from Left Ear, Percutaneous Endoscopic Approach */
"09PJ77Z" = "1" /* Removal of Autologous Tissue Substitute from Left Ear, Via Natural or Artificial Opening */
"09PJ7JZ" = "1" /* Removal of Synthetic Substitute from Left Ear, Via Natural or Artificial Opening */
"09PJ7KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Ear, Via Natural or Artificial Opening */
"09PJ87Z" = "1" /* Removal of Autologous Tissue Substitute from Left Ear, Via Natural or Artificial Opening Endoscopic */
"09PJ8JZ" = "1" /* Removal of Synthetic Substitute from Left Ear, Via Natural or Artificial Opening Endoscopic */
"09PJ8KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Ear, Via Natural or Artificial Opening Endoscopic */
"09PY00Z" = "1" /* Removal of Drainage Device from Sinus, Open Approach */
"09PY30Z" = "1" /* Removal of Drainage Device from Sinus, Percutaneous Approach */
"09PY40Z" = "1" /* Removal of Drainage Device from Sinus, Percutaneous Endoscopic Approach */
"09Q00ZZ" = "1" /* Repair Right External Ear, Open Approach */
"09Q03ZZ" = "1" /* Repair Right External Ear, Percutaneous Approach */
"09Q04ZZ" = "1" /* Repair Right External Ear, Percutaneous Endoscopic Approach */
"09Q10ZZ" = "1" /* Repair Left External Ear, Open Approach */
"09Q13ZZ" = "1" /* Repair Left External Ear, Percutaneous Approach */
"09Q14ZZ" = "1" /* Repair Left External Ear, Percutaneous Endoscopic Approach */
"09Q20ZZ" = "1" /* Repair Bilateral External Ear, Open Approach */
"09Q23ZZ" = "1" /* Repair Bilateral External Ear, Percutaneous Approach */
"09Q24ZZ" = "1" /* Repair Bilateral External Ear, Percutaneous Endoscopic Approach */
"09Q30ZZ" = "1" /* Repair Right External Auditory Canal, Open Approach */
"09Q33ZZ" = "1" /* Repair Right External Auditory Canal, Percutaneous Approach */
"09Q34ZZ" = "1" /* Repair Right External Auditory Canal, Percutaneous Endoscopic Approach */
"09Q37ZZ" = "1" /* Repair Right External Auditory Canal, Via Natural or Artificial Opening */
"09Q38ZZ" = "1" /* Repair Right External Auditory Canal, Via Natural or Artificial Opening Endoscopic */
"09Q40ZZ" = "1" /* Repair Left External Auditory Canal, Open Approach */
"09Q43ZZ" = "1" /* Repair Left External Auditory Canal, Percutaneous Approach */
"09Q44ZZ" = "1" /* Repair Left External Auditory Canal, Percutaneous Endoscopic Approach */
"09Q47ZZ" = "1" /* Repair Left External Auditory Canal, Via Natural or Artificial Opening */
"09Q48ZZ" = "1" /* Repair Left External Auditory Canal, Via Natural or Artificial Opening Endoscopic */
"09Q50ZZ" = "1" /* Repair Right Middle Ear, Open Approach */
"09Q60ZZ" = "1" /* Repair Left Middle Ear, Open Approach */
"09Q70ZZ" = "1" /* Repair Right Tympanic Membrane, Open Approach */
"09Q73ZZ" = "1" /* Repair Right Tympanic Membrane, Percutaneous Approach */
"09Q74ZZ" = "1" /* Repair Right Tympanic Membrane, Percutaneous Endoscopic Approach */
"09Q77ZZ" = "1" /* Repair Right Tympanic Membrane, Via Natural or Artificial Opening */
"09Q78ZZ" = "1" /* Repair Right Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"09Q80ZZ" = "1" /* Repair Left Tympanic Membrane, Open Approach */
"09Q83ZZ" = "1" /* Repair Left Tympanic Membrane, Percutaneous Approach */
"09Q84ZZ" = "1" /* Repair Left Tympanic Membrane, Percutaneous Endoscopic Approach */
"09Q87ZZ" = "1" /* Repair Left Tympanic Membrane, Via Natural or Artificial Opening */
"09Q88ZZ" = "1" /* Repair Left Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"09Q90ZZ" = "1" /* Repair Right Auditory Ossicle, Open Approach */
"09QA0ZZ" = "1" /* Repair Left Auditory Ossicle, Open Approach */
"09QB0ZZ" = "1" /* Repair Right Mastoid Sinus, Open Approach */
"09QB3ZZ" = "1" /* Repair Right Mastoid Sinus, Percutaneous Approach */
"09QB4ZZ" = "1" /* Repair Right Mastoid Sinus, Percutaneous Endoscopic Approach */
"09QC0ZZ" = "1" /* Repair Left Mastoid Sinus, Open Approach */
"09QC3ZZ" = "1" /* Repair Left Mastoid Sinus, Percutaneous Approach */
"09QC4ZZ" = "1" /* Repair Left Mastoid Sinus, Percutaneous Endoscopic Approach */
"09QD0ZZ" = "1" /* Repair Right Inner Ear, Open Approach */
"09QE0ZZ" = "1" /* Repair Left Inner Ear, Open Approach */
"09QK0ZZ" = "1" /* Repair Nose, Open Approach */
"09QK3ZZ" = "1" /* Repair Nose, Percutaneous Approach */
"09QK4ZZ" = "1" /* Repair Nose, Percutaneous Endoscopic Approach */
"09QL0ZZ" = "1" /* Repair Nasal Turbinate, Open Approach */
"09QL3ZZ" = "1" /* Repair Nasal Turbinate, Percutaneous Approach */
"09QL4ZZ" = "1" /* Repair Nasal Turbinate, Percutaneous Endoscopic Approach */
"09QL7ZZ" = "1" /* Repair Nasal Turbinate, Via Natural or Artificial Opening */
"09QL8ZZ" = "1" /* Repair Nasal Turbinate, Via Natural or Artificial Opening Endoscopic */
"09QM0ZZ" = "1" /* Repair Nasal Septum, Open Approach */
"09QM3ZZ" = "1" /* Repair Nasal Septum, Percutaneous Approach */
"09QM4ZZ" = "1" /* Repair Nasal Septum, Percutaneous Endoscopic Approach */
"09QN0ZZ" = "1" /* Repair Nasopharynx, Open Approach */
"09QN3ZZ" = "1" /* Repair Nasopharynx, Percutaneous Approach */
"09QN4ZZ" = "1" /* Repair Nasopharynx, Percutaneous Endoscopic Approach */
"09QN7ZZ" = "1" /* Repair Nasopharynx, Via Natural or Artificial Opening */
"09QN8ZZ" = "1" /* Repair Nasopharynx, Via Natural or Artificial Opening Endoscopic */
"09QP0ZZ" = "1" /* Repair Accessory Sinus, Open Approach */
"09QP3ZZ" = "1" /* Repair Accessory Sinus, Percutaneous Approach */
"09QP4ZZ" = "1" /* Repair Accessory Sinus, Percutaneous Endoscopic Approach */
"09QQ0ZZ" = "1" /* Repair Right Maxillary Sinus, Open Approach */
"09QQ3ZZ" = "1" /* Repair Right Maxillary Sinus, Percutaneous Approach */
"09QQ4ZZ" = "1" /* Repair Right Maxillary Sinus, Percutaneous Endoscopic Approach */
"09QR0ZZ" = "1" /* Repair Left Maxillary Sinus, Open Approach */
"09QR3ZZ" = "1" /* Repair Left Maxillary Sinus, Percutaneous Approach */
"09QR4ZZ" = "1" /* Repair Left Maxillary Sinus, Percutaneous Endoscopic Approach */
"09QS0ZZ" = "1" /* Repair Right Frontal Sinus, Open Approach */
"09QS3ZZ" = "1" /* Repair Right Frontal Sinus, Percutaneous Approach */
"09QS4ZZ" = "1" /* Repair Right Frontal Sinus, Percutaneous Endoscopic Approach */
"09QT0ZZ" = "1" /* Repair Left Frontal Sinus, Open Approach */
"09QT3ZZ" = "1" /* Repair Left Frontal Sinus, Percutaneous Approach */
"09QT4ZZ" = "1" /* Repair Left Frontal Sinus, Percutaneous Endoscopic Approach */
"09QU0ZZ" = "1" /* Repair Right Ethmoid Sinus, Open Approach */
"09QU3ZZ" = "1" /* Repair Right Ethmoid Sinus, Percutaneous Approach */
"09QU4ZZ" = "1" /* Repair Right Ethmoid Sinus, Percutaneous Endoscopic Approach */
"09QV0ZZ" = "1" /* Repair Left Ethmoid Sinus, Open Approach */
"09QV3ZZ" = "1" /* Repair Left Ethmoid Sinus, Percutaneous Approach */
"09QV4ZZ" = "1" /* Repair Left Ethmoid Sinus, Percutaneous Endoscopic Approach */
"09QW0ZZ" = "1" /* Repair Right Sphenoid Sinus, Open Approach */
"09QW3ZZ" = "1" /* Repair Right Sphenoid Sinus, Percutaneous Approach */
"09QW4ZZ" = "1" /* Repair Right Sphenoid Sinus, Percutaneous Endoscopic Approach */
"09QX0ZZ" = "1" /* Repair Left Sphenoid Sinus, Open Approach */
"09QX3ZZ" = "1" /* Repair Left Sphenoid Sinus, Percutaneous Approach */
"09QX4ZZ" = "1" /* Repair Left Sphenoid Sinus, Percutaneous Endoscopic Approach */
"09R007Z" = "1" /* Replacement of Right External Ear with Autologous Tissue Substitute, Open Approach */
"09R00JZ" = "1" /* Replacement of Right External Ear with Synthetic Substitute, Open Approach */
"09R00KZ" = "1" /* Replacement of Right External Ear with Nonautologous Tissue Substitute, Open Approach */
"09R0X7Z" = "1" /* Replacement of Right External Ear with Autologous Tissue Substitute, External Approach */
"09R0XJZ" = "1" /* Replacement of Right External Ear with Synthetic Substitute, External Approach */
"09R0XKZ" = "1" /* Replacement of Right External Ear with Nonautologous Tissue Substitute, External Approach */
"09R107Z" = "1" /* Replacement of Left External Ear with Autologous Tissue Substitute, Open Approach */
"09R10JZ" = "1" /* Replacement of Left External Ear with Synthetic Substitute, Open Approach */
"09R10KZ" = "1" /* Replacement of Left External Ear with Nonautologous Tissue Substitute, Open Approach */
"09R1X7Z" = "1" /* Replacement of Left External Ear with Autologous Tissue Substitute, External Approach */
"09R1XJZ" = "1" /* Replacement of Left External Ear with Synthetic Substitute, External Approach */
"09R1XKZ" = "1" /* Replacement of Left External Ear with Nonautologous Tissue Substitute, External Approach */
"09R207Z" = "1" /* Replacement of Bilateral External Ear with Autologous Tissue Substitute, Open Approach */
"09R20JZ" = "1" /* Replacement of Bilateral External Ear with Synthetic Substitute, Open Approach */
"09R20KZ" = "1" /* Replacement of Bilateral External Ear with Nonautologous Tissue Substitute, Open Approach */
"09R2X7Z" = "1" /* Replacement of Bilateral External Ear with Autologous Tissue Substitute, External Approach */
"09R2XJZ" = "1" /* Replacement of Bilateral External Ear with Synthetic Substitute, External Approach */
"09R2XKZ" = "1" /* Replacement of Bilateral External Ear with Nonautologous Tissue Substitute, External Approach */
"09R507Z" = "1" /* Replacement of Right Middle Ear with Autologous Tissue Substitute, Open Approach */
"09R50JZ" = "1" /* Replacement of Right Middle Ear with Synthetic Substitute, Open Approach */
"09R50KZ" = "1" /* Replacement of Right Middle Ear with Nonautologous Tissue Substitute, Open Approach */
"09R607Z" = "1" /* Replacement of Left Middle Ear with Autologous Tissue Substitute, Open Approach */
"09R60JZ" = "1" /* Replacement of Left Middle Ear with Synthetic Substitute, Open Approach */
"09R60KZ" = "1" /* Replacement of Left Middle Ear with Nonautologous Tissue Substitute, Open Approach */
"09R707Z" = "1" /* Replacement of Right Tympanic Membrane with Autologous Tissue Substitute, Open Approach */
"09R70JZ" = "1" /* Replacement of Right Tympanic Membrane with Synthetic Substitute, Open Approach */
"09R70KZ" = "1" /* Replacement of Right Tympanic Membrane with Nonautologous Tissue Substitute, Open Approach */
"09R777Z" = "1" /* Replacement of Right Tympanic Membrane with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"09R77JZ" = "1" /* Replacement of Right Tympanic Membrane with Synthetic Substitute, Via Natural or Artificial Opening */
"09R77KZ" = "1" /* Replacement of Right Tympanic Membrane with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"09R787Z" = "1" /* Replacement of Right Tympanic Membrane with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"09R78JZ" = "1" /* Replacement of Right Tympanic Membrane with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"09R78KZ" = "1" /* Replacement of Right Tympanic Membrane with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"09R807Z" = "1" /* Replacement of Left Tympanic Membrane with Autologous Tissue Substitute, Open Approach */
"09R80JZ" = "1" /* Replacement of Left Tympanic Membrane with Synthetic Substitute, Open Approach */
"09R80KZ" = "1" /* Replacement of Left Tympanic Membrane with Nonautologous Tissue Substitute, Open Approach */
"09R877Z" = "1" /* Replacement of Left Tympanic Membrane with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"09R87JZ" = "1" /* Replacement of Left Tympanic Membrane with Synthetic Substitute, Via Natural or Artificial Opening */
"09R87KZ" = "1" /* Replacement of Left Tympanic Membrane with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"09R887Z" = "1" /* Replacement of Left Tympanic Membrane with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"09R88JZ" = "1" /* Replacement of Left Tympanic Membrane with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"09R88KZ" = "1" /* Replacement of Left Tympanic Membrane with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"09R907Z" = "1" /* Replacement of Right Auditory Ossicle with Autologous Tissue Substitute, Open Approach */
"09R90JZ" = "1" /* Replacement of Right Auditory Ossicle with Synthetic Substitute, Open Approach */
"09R90KZ" = "1" /* Replacement of Right Auditory Ossicle with Nonautologous Tissue Substitute, Open Approach */
"09RA07Z" = "1" /* Replacement of Left Auditory Ossicle with Autologous Tissue Substitute, Open Approach */
"09RA0JZ" = "1" /* Replacement of Left Auditory Ossicle with Synthetic Substitute, Open Approach */
"09RA0KZ" = "1" /* Replacement of Left Auditory Ossicle with Nonautologous Tissue Substitute, Open Approach */
"09RD07Z" = "1" /* Replacement of Right Inner Ear with Autologous Tissue Substitute, Open Approach */
"09RD0JZ" = "1" /* Replacement of Right Inner Ear with Synthetic Substitute, Open Approach */
"09RD0KZ" = "1" /* Replacement of Right Inner Ear with Nonautologous Tissue Substitute, Open Approach */
"09RE07Z" = "1" /* Replacement of Left Inner Ear with Autologous Tissue Substitute, Open Approach */
"09RE0JZ" = "1" /* Replacement of Left Inner Ear with Synthetic Substitute, Open Approach */
"09RE0KZ" = "1" /* Replacement of Left Inner Ear with Nonautologous Tissue Substitute, Open Approach */
"09RK07Z" = "1" /* Replacement of Nose with Autologous Tissue Substitute, Open Approach */
"09RK0JZ" = "1" /* Replacement of Nose with Synthetic Substitute, Open Approach */
"09RK0KZ" = "1" /* Replacement of Nose with Nonautologous Tissue Substitute, Open Approach */
"09RKX7Z" = "1" /* Replacement of Nose with Autologous Tissue Substitute, External Approach */
"09RKXJZ" = "1" /* Replacement of Nose with Synthetic Substitute, External Approach */
"09RKXKZ" = "1" /* Replacement of Nose with Nonautologous Tissue Substitute, External Approach */
"09RL07Z" = "1" /* Replacement of Nasal Turbinate with Autologous Tissue Substitute, Open Approach */
"09RL0JZ" = "1" /* Replacement of Nasal Turbinate with Synthetic Substitute, Open Approach */
"09RL0KZ" = "1" /* Replacement of Nasal Turbinate with Nonautologous Tissue Substitute, Open Approach */
"09RL37Z" = "1" /* Replacement of Nasal Turbinate with Autologous Tissue Substitute, Percutaneous Approach */
"09RL3JZ" = "1" /* Replacement of Nasal Turbinate with Synthetic Substitute, Percutaneous Approach */
"09RL3KZ" = "1" /* Replacement of Nasal Turbinate with Nonautologous Tissue Substitute, Percutaneous Approach */
"09RL47Z" = "1" /* Replacement of Nasal Turbinate with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"09RL4JZ" = "1" /* Replacement of Nasal Turbinate with Synthetic Substitute, Percutaneous Endoscopic Approach */
"09RL4KZ" = "1" /* Replacement of Nasal Turbinate with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"09RL77Z" = "1" /* Replacement of Nasal Turbinate with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"09RL7JZ" = "1" /* Replacement of Nasal Turbinate with Synthetic Substitute, Via Natural or Artificial Opening */
"09RL7KZ" = "1" /* Replacement of Nasal Turbinate with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"09RL87Z" = "1" /* Replacement of Nasal Turbinate with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"09RL8JZ" = "1" /* Replacement of Nasal Turbinate with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"09RL8KZ" = "1" /* Replacement of Nasal Turbinate with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"09RM07Z" = "1" /* Replacement of Nasal Septum with Autologous Tissue Substitute, Open Approach */
"09RM0JZ" = "1" /* Replacement of Nasal Septum with Synthetic Substitute, Open Approach */
"09RM0KZ" = "1" /* Replacement of Nasal Septum with Nonautologous Tissue Substitute, Open Approach */
"09RM37Z" = "1" /* Replacement of Nasal Septum with Autologous Tissue Substitute, Percutaneous Approach */
"09RM3JZ" = "1" /* Replacement of Nasal Septum with Synthetic Substitute, Percutaneous Approach */
"09RM3KZ" = "1" /* Replacement of Nasal Septum with Nonautologous Tissue Substitute, Percutaneous Approach */
"09RM47Z" = "1" /* Replacement of Nasal Septum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"09RM4JZ" = "1" /* Replacement of Nasal Septum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"09RM4KZ" = "1" /* Replacement of Nasal Septum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"09RN07Z" = "1" /* Replacement of Nasopharynx with Autologous Tissue Substitute, Open Approach */
"09RN0JZ" = "1" /* Replacement of Nasopharynx with Synthetic Substitute, Open Approach */
"09RN0KZ" = "1" /* Replacement of Nasopharynx with Nonautologous Tissue Substitute, Open Approach */
"09RN77Z" = "1" /* Replacement of Nasopharynx with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"09RN7JZ" = "1" /* Replacement of Nasopharynx with Synthetic Substitute, Via Natural or Artificial Opening */
"09RN7KZ" = "1" /* Replacement of Nasopharynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"09RN87Z" = "1" /* Replacement of Nasopharynx with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"09RN8JZ" = "1" /* Replacement of Nasopharynx with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"09RN8KZ" = "1" /* Replacement of Nasopharynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"09S00ZZ" = "1" /* Reposition Right External Ear, Open Approach */
"09S04ZZ" = "1" /* Reposition Right External Ear, Percutaneous Endoscopic Approach */
"09S0XZZ" = "1" /* Reposition Right External Ear, External Approach */
"09S10ZZ" = "1" /* Reposition Left External Ear, Open Approach */
"09S14ZZ" = "1" /* Reposition Left External Ear, Percutaneous Endoscopic Approach */
"09S1XZZ" = "1" /* Reposition Left External Ear, External Approach */
"09S20ZZ" = "1" /* Reposition Bilateral External Ear, Open Approach */
"09S24ZZ" = "1" /* Reposition Bilateral External Ear, Percutaneous Endoscopic Approach */
"09S2XZZ" = "1" /* Reposition Bilateral External Ear, External Approach */
"09S70ZZ" = "1" /* Reposition Right Tympanic Membrane, Open Approach */
"09S74ZZ" = "1" /* Reposition Right Tympanic Membrane, Percutaneous Endoscopic Approach */
"09S77ZZ" = "1" /* Reposition Right Tympanic Membrane, Via Natural or Artificial Opening */
"09S78ZZ" = "1" /* Reposition Right Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"09S80ZZ" = "1" /* Reposition Left Tympanic Membrane, Open Approach */
"09S84ZZ" = "1" /* Reposition Left Tympanic Membrane, Percutaneous Endoscopic Approach */
"09S87ZZ" = "1" /* Reposition Left Tympanic Membrane, Via Natural or Artificial Opening */
"09S88ZZ" = "1" /* Reposition Left Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"09S90ZZ" = "1" /* Reposition Right Auditory Ossicle, Open Approach */
"09S94ZZ" = "1" /* Reposition Right Auditory Ossicle, Percutaneous Endoscopic Approach */
"09SA0ZZ" = "1" /* Reposition Left Auditory Ossicle, Open Approach */
"09SA4ZZ" = "1" /* Reposition Left Auditory Ossicle, Percutaneous Endoscopic Approach */
"09SK0ZZ" = "1" /* Reposition Nose, Open Approach */
"09SK4ZZ" = "1" /* Reposition Nose, Percutaneous Endoscopic Approach */
"09SKXZZ" = "1" /* Reposition Nose, External Approach */
"09SL0ZZ" = "1" /* Reposition Nasal Turbinate, Open Approach */
"09SL4ZZ" = "1" /* Reposition Nasal Turbinate, Percutaneous Endoscopic Approach */
"09SL7ZZ" = "1" /* Reposition Nasal Turbinate, Via Natural or Artificial Opening */
"09SL8ZZ" = "1" /* Reposition Nasal Turbinate, Via Natural or Artificial Opening Endoscopic */
"09SM0ZZ" = "1" /* Reposition Nasal Septum, Open Approach */
"09SM4ZZ" = "1" /* Reposition Nasal Septum, Percutaneous Endoscopic Approach */
"09T00ZZ" = "1" /* Resection of Right External Ear, Open Approach */
"09T04ZZ" = "1" /* Resection of Right External Ear, Percutaneous Endoscopic Approach */
"09T0XZZ" = "1" /* Resection of Right External Ear, External Approach */
"09T10ZZ" = "1" /* Resection of Left External Ear, Open Approach */
"09T14ZZ" = "1" /* Resection of Left External Ear, Percutaneous Endoscopic Approach */
"09T1XZZ" = "1" /* Resection of Left External Ear, External Approach */
"09T50ZZ" = "1" /* Resection of Right Middle Ear, Open Approach */
"09T60ZZ" = "1" /* Resection of Left Middle Ear, Open Approach */
"09T70ZZ" = "1" /* Resection of Right Tympanic Membrane, Open Approach */
"09T74ZZ" = "1" /* Resection of Right Tympanic Membrane, Percutaneous Endoscopic Approach */
"09T77ZZ" = "1" /* Resection of Right Tympanic Membrane, Via Natural or Artificial Opening */
"09T78ZZ" = "1" /* Resection of Right Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"09T80ZZ" = "1" /* Resection of Left Tympanic Membrane, Open Approach */
"09T84ZZ" = "1" /* Resection of Left Tympanic Membrane, Percutaneous Endoscopic Approach */
"09T87ZZ" = "1" /* Resection of Left Tympanic Membrane, Via Natural or Artificial Opening */
"09T88ZZ" = "1" /* Resection of Left Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"09T90ZZ" = "1" /* Resection of Right Auditory Ossicle, Open Approach */
"09TA0ZZ" = "1" /* Resection of Left Auditory Ossicle, Open Approach */
"09TB0ZZ" = "1" /* Resection of Right Mastoid Sinus, Open Approach */
"09TB4ZZ" = "1" /* Resection of Right Mastoid Sinus, Percutaneous Endoscopic Approach */
"09TC0ZZ" = "1" /* Resection of Left Mastoid Sinus, Open Approach */
"09TC4ZZ" = "1" /* Resection of Left Mastoid Sinus, Percutaneous Endoscopic Approach */
"09TD0ZZ" = "1" /* Resection of Right Inner Ear, Open Approach */
"09TE0ZZ" = "1" /* Resection of Left Inner Ear, Open Approach */
"09TK0ZZ" = "1" /* Resection of Nose, Open Approach */
"09TK4ZZ" = "1" /* Resection of Nose, Percutaneous Endoscopic Approach */
"09TKXZZ" = "1" /* Resection of Nose, External Approach */
"09TL0ZZ" = "1" /* Resection of Nasal Turbinate, Open Approach */
"09TL4ZZ" = "1" /* Resection of Nasal Turbinate, Percutaneous Endoscopic Approach */
"09TL7ZZ" = "1" /* Resection of Nasal Turbinate, Via Natural or Artificial Opening */
"09TL8ZZ" = "1" /* Resection of Nasal Turbinate, Via Natural or Artificial Opening Endoscopic */
"09TM0ZZ" = "1" /* Resection of Nasal Septum, Open Approach */
"09TM4ZZ" = "1" /* Resection of Nasal Septum, Percutaneous Endoscopic Approach */
"09TN0ZZ" = "1" /* Resection of Nasopharynx, Open Approach */
"09TN4ZZ" = "1" /* Resection of Nasopharynx, Percutaneous Endoscopic Approach */
"09TN7ZZ" = "1" /* Resection of Nasopharynx, Via Natural or Artificial Opening */
"09TN8ZZ" = "1" /* Resection of Nasopharynx, Via Natural or Artificial Opening Endoscopic */
"09TP0ZZ" = "1" /* Resection of Accessory Sinus, Open Approach */
"09TP4ZZ" = "1" /* Resection of Accessory Sinus, Percutaneous Endoscopic Approach */
"09TQ0ZZ" = "1" /* Resection of Right Maxillary Sinus, Open Approach */
"09TQ4ZZ" = "1" /* Resection of Right Maxillary Sinus, Percutaneous Endoscopic Approach */
"09TR0ZZ" = "1" /* Resection of Left Maxillary Sinus, Open Approach */
"09TR4ZZ" = "1" /* Resection of Left Maxillary Sinus, Percutaneous Endoscopic Approach */
"09TS0ZZ" = "1" /* Resection of Right Frontal Sinus, Open Approach */
"09TS4ZZ" = "1" /* Resection of Right Frontal Sinus, Percutaneous Endoscopic Approach */
"09TT0ZZ" = "1" /* Resection of Left Frontal Sinus, Open Approach */
"09TT4ZZ" = "1" /* Resection of Left Frontal Sinus, Percutaneous Endoscopic Approach */
"09TU0ZZ" = "1" /* Resection of Right Ethmoid Sinus, Open Approach */
"09TU4ZZ" = "1" /* Resection of Right Ethmoid Sinus, Percutaneous Endoscopic Approach */
"09TV0ZZ" = "1" /* Resection of Left Ethmoid Sinus, Open Approach */
"09TV4ZZ" = "1" /* Resection of Left Ethmoid Sinus, Percutaneous Endoscopic Approach */
"09TW0ZZ" = "1" /* Resection of Right Sphenoid Sinus, Open Approach */
"09TW4ZZ" = "1" /* Resection of Right Sphenoid Sinus, Percutaneous Endoscopic Approach */
"09TX0ZZ" = "1" /* Resection of Left Sphenoid Sinus, Open Approach */
"09TX4ZZ" = "1" /* Resection of Left Sphenoid Sinus, Percutaneous Endoscopic Approach */
"09U007Z" = "1" /* Supplement Right External Ear with Autologous Tissue Substitute, Open Approach */
"09U00JZ" = "1" /* Supplement Right External Ear with Synthetic Substitute, Open Approach */
"09U00KZ" = "1" /* Supplement Right External Ear with Nonautologous Tissue Substitute, Open Approach */
"09U0X7Z" = "1" /* Supplement Right External Ear with Autologous Tissue Substitute, External Approach */
"09U0XJZ" = "1" /* Supplement Right External Ear with Synthetic Substitute, External Approach */
"09U0XKZ" = "1" /* Supplement Right External Ear with Nonautologous Tissue Substitute, External Approach */
"09U107Z" = "1" /* Supplement Left External Ear with Autologous Tissue Substitute, Open Approach */
"09U10JZ" = "1" /* Supplement Left External Ear with Synthetic Substitute, Open Approach */
"09U10KZ" = "1" /* Supplement Left External Ear with Nonautologous Tissue Substitute, Open Approach */
"09U1X7Z" = "1" /* Supplement Left External Ear with Autologous Tissue Substitute, External Approach */
"09U1XJZ" = "1" /* Supplement Left External Ear with Synthetic Substitute, External Approach */
"09U1XKZ" = "1" /* Supplement Left External Ear with Nonautologous Tissue Substitute, External Approach */
"09U207Z" = "1" /* Supplement Bilateral External Ear with Autologous Tissue Substitute, Open Approach */
"09U20JZ" = "1" /* Supplement Bilateral External Ear with Synthetic Substitute, Open Approach */
"09U20KZ" = "1" /* Supplement Bilateral External Ear with Nonautologous Tissue Substitute, Open Approach */
"09U2X7Z" = "1" /* Supplement Bilateral External Ear with Autologous Tissue Substitute, External Approach */
"09U2XJZ" = "1" /* Supplement Bilateral External Ear with Synthetic Substitute, External Approach */
"09U2XKZ" = "1" /* Supplement Bilateral External Ear with Nonautologous Tissue Substitute, External Approach */
"09U507Z" = "1" /* Supplement Right Middle Ear with Autologous Tissue Substitute, Open Approach */
"09U50JZ" = "1" /* Supplement Right Middle Ear with Synthetic Substitute, Open Approach */
"09U50KZ" = "1" /* Supplement Right Middle Ear with Nonautologous Tissue Substitute, Open Approach */
"09U607Z" = "1" /* Supplement Left Middle Ear with Autologous Tissue Substitute, Open Approach */
"09U60JZ" = "1" /* Supplement Left Middle Ear with Synthetic Substitute, Open Approach */
"09U60KZ" = "1" /* Supplement Left Middle Ear with Nonautologous Tissue Substitute, Open Approach */
"09U707Z" = "1" /* Supplement Right Tympanic Membrane with Autologous Tissue Substitute, Open Approach */
"09U70JZ" = "1" /* Supplement Right Tympanic Membrane with Synthetic Substitute, Open Approach */
"09U70KZ" = "1" /* Supplement Right Tympanic Membrane with Nonautologous Tissue Substitute, Open Approach */
"09U777Z" = "1" /* Supplement Right Tympanic Membrane with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"09U77JZ" = "1" /* Supplement Right Tympanic Membrane with Synthetic Substitute, Via Natural or Artificial Opening */
"09U77KZ" = "1" /* Supplement Right Tympanic Membrane with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"09U787Z" = "1" /* Supplement Right Tympanic Membrane with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"09U78JZ" = "1" /* Supplement Right Tympanic Membrane with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"09U78KZ" = "1" /* Supplement Right Tympanic Membrane with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"09U807Z" = "1" /* Supplement Left Tympanic Membrane with Autologous Tissue Substitute, Open Approach */
"09U80JZ" = "1" /* Supplement Left Tympanic Membrane with Synthetic Substitute, Open Approach */
"09U80KZ" = "1" /* Supplement Left Tympanic Membrane with Nonautologous Tissue Substitute, Open Approach */
"09U877Z" = "1" /* Supplement Left Tympanic Membrane with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"09U87JZ" = "1" /* Supplement Left Tympanic Membrane with Synthetic Substitute, Via Natural or Artificial Opening */
"09U87KZ" = "1" /* Supplement Left Tympanic Membrane with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"09U887Z" = "1" /* Supplement Left Tympanic Membrane with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"09U88JZ" = "1" /* Supplement Left Tympanic Membrane with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"09U88KZ" = "1" /* Supplement Left Tympanic Membrane with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"09U907Z" = "1" /* Supplement Right Auditory Ossicle with Autologous Tissue Substitute, Open Approach */
"09U90JZ" = "1" /* Supplement Right Auditory Ossicle with Synthetic Substitute, Open Approach */
"09U90KZ" = "1" /* Supplement Right Auditory Ossicle with Nonautologous Tissue Substitute, Open Approach */
"09UA07Z" = "1" /* Supplement Left Auditory Ossicle with Autologous Tissue Substitute, Open Approach */
"09UA0JZ" = "1" /* Supplement Left Auditory Ossicle with Synthetic Substitute, Open Approach */
"09UA0KZ" = "1" /* Supplement Left Auditory Ossicle with Nonautologous Tissue Substitute, Open Approach */
"09UD07Z" = "1" /* Supplement Right Inner Ear with Autologous Tissue Substitute, Open Approach */
"09UD0JZ" = "1" /* Supplement Right Inner Ear with Synthetic Substitute, Open Approach */
"09UD0KZ" = "1" /* Supplement Right Inner Ear with Nonautologous Tissue Substitute, Open Approach */
"09UE07Z" = "1" /* Supplement Left Inner Ear with Autologous Tissue Substitute, Open Approach */
"09UE0JZ" = "1" /* Supplement Left Inner Ear with Synthetic Substitute, Open Approach */
"09UE0KZ" = "1" /* Supplement Left Inner Ear with Nonautologous Tissue Substitute, Open Approach */
"09UK07Z" = "1" /* Supplement Nose with Autologous Tissue Substitute, Open Approach */
"09UK0JZ" = "1" /* Supplement Nose with Synthetic Substitute, Open Approach */
"09UK0KZ" = "1" /* Supplement Nose with Nonautologous Tissue Substitute, Open Approach */
"09UKX7Z" = "1" /* Supplement Nose with Autologous Tissue Substitute, External Approach */
"09UKXJZ" = "1" /* Supplement Nose with Synthetic Substitute, External Approach */
"09UKXKZ" = "1" /* Supplement Nose with Nonautologous Tissue Substitute, External Approach */
"09UL07Z" = "1" /* Supplement Nasal Turbinate with Autologous Tissue Substitute, Open Approach */
"09UL0JZ" = "1" /* Supplement Nasal Turbinate with Synthetic Substitute, Open Approach */
"09UL0KZ" = "1" /* Supplement Nasal Turbinate with Nonautologous Tissue Substitute, Open Approach */
"09UL37Z" = "1" /* Supplement Nasal Turbinate with Autologous Tissue Substitute, Percutaneous Approach */
"09UL3JZ" = "1" /* Supplement Nasal Turbinate with Synthetic Substitute, Percutaneous Approach */
"09UL3KZ" = "1" /* Supplement Nasal Turbinate with Nonautologous Tissue Substitute, Percutaneous Approach */
"09UL47Z" = "1" /* Supplement Nasal Turbinate with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"09UL4JZ" = "1" /* Supplement Nasal Turbinate with Synthetic Substitute, Percutaneous Endoscopic Approach */
"09UL4KZ" = "1" /* Supplement Nasal Turbinate with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"09UL77Z" = "1" /* Supplement Nasal Turbinate with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"09UL7JZ" = "1" /* Supplement Nasal Turbinate with Synthetic Substitute, Via Natural or Artificial Opening */
"09UL7KZ" = "1" /* Supplement Nasal Turbinate with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"09UL87Z" = "1" /* Supplement Nasal Turbinate with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"09UL8JZ" = "1" /* Supplement Nasal Turbinate with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"09UL8KZ" = "1" /* Supplement Nasal Turbinate with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"09UM07Z" = "1" /* Supplement Nasal Septum with Autologous Tissue Substitute, Open Approach */
"09UM0JZ" = "1" /* Supplement Nasal Septum with Synthetic Substitute, Open Approach */
"09UM0KZ" = "1" /* Supplement Nasal Septum with Nonautologous Tissue Substitute, Open Approach */
"09UM37Z" = "1" /* Supplement Nasal Septum with Autologous Tissue Substitute, Percutaneous Approach */
"09UM3JZ" = "1" /* Supplement Nasal Septum with Synthetic Substitute, Percutaneous Approach */
"09UM3KZ" = "1" /* Supplement Nasal Septum with Nonautologous Tissue Substitute, Percutaneous Approach */
"09UM47Z" = "1" /* Supplement Nasal Septum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"09UM4JZ" = "1" /* Supplement Nasal Septum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"09UM4KZ" = "1" /* Supplement Nasal Septum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"09UN07Z" = "1" /* Supplement Nasopharynx with Autologous Tissue Substitute, Open Approach */
"09UN0JZ" = "1" /* Supplement Nasopharynx with Synthetic Substitute, Open Approach */
"09UN0KZ" = "1" /* Supplement Nasopharynx with Nonautologous Tissue Substitute, Open Approach */
"09UN77Z" = "1" /* Supplement Nasopharynx with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"09UN7JZ" = "1" /* Supplement Nasopharynx with Synthetic Substitute, Via Natural or Artificial Opening */
"09UN7KZ" = "1" /* Supplement Nasopharynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"09UN87Z" = "1" /* Supplement Nasopharynx with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"09UN8JZ" = "1" /* Supplement Nasopharynx with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"09UN8KZ" = "1" /* Supplement Nasopharynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"09W707Z" = "1" /* Revision of Autologous Tissue Substitute in Right Tympanic Membrane, Open Approach */
"09W70JZ" = "1" /* Revision of Synthetic Substitute in Right Tympanic Membrane, Open Approach */
"09W70KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Tympanic Membrane, Open Approach */
"09W777Z" = "1" /* Revision of Autologous Tissue Substitute in Right Tympanic Membrane, Via Natural or Artificial Opening */
"09W77JZ" = "1" /* Revision of Synthetic Substitute in Right Tympanic Membrane, Via Natural or Artificial Opening */
"09W77KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Tympanic Membrane, Via Natural or Artificial Opening */
"09W787Z" = "1" /* Revision of Autologous Tissue Substitute in Right Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"09W78JZ" = "1" /* Revision of Synthetic Substitute in Right Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"09W78KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"09W807Z" = "1" /* Revision of Autologous Tissue Substitute in Left Tympanic Membrane, Open Approach */
"09W80JZ" = "1" /* Revision of Synthetic Substitute in Left Tympanic Membrane, Open Approach */
"09W80KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Tympanic Membrane, Open Approach */
"09W877Z" = "1" /* Revision of Autologous Tissue Substitute in Left Tympanic Membrane, Via Natural or Artificial Opening */
"09W87JZ" = "1" /* Revision of Synthetic Substitute in Left Tympanic Membrane, Via Natural or Artificial Opening */
"09W87KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Tympanic Membrane, Via Natural or Artificial Opening */
"09W887Z" = "1" /* Revision of Autologous Tissue Substitute in Left Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"09W88JZ" = "1" /* Revision of Synthetic Substitute in Left Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"09W88KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Tympanic Membrane, Via Natural or Artificial Opening Endoscopic */
"09W907Z" = "1" /* Revision of Autologous Tissue Substitute in Right Auditory Ossicle, Open Approach */
"09W90JZ" = "1" /* Revision of Synthetic Substitute in Right Auditory Ossicle, Open Approach */
"09W90KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Auditory Ossicle, Open Approach */
"09W977Z" = "1" /* Revision of Autologous Tissue Substitute in Right Auditory Ossicle, Via Natural or Artificial Opening */
"09W97JZ" = "1" /* Revision of Synthetic Substitute in Right Auditory Ossicle, Via Natural or Artificial Opening */
"09W97KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Auditory Ossicle, Via Natural or Artificial Opening */
"09W987Z" = "1" /* Revision of Autologous Tissue Substitute in Right Auditory Ossicle, Via Natural or Artificial Opening Endoscopic */
"09W98JZ" = "1" /* Revision of Synthetic Substitute in Right Auditory Ossicle, Via Natural or Artificial Opening Endoscopic */
"09W98KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Auditory Ossicle, Via Natural or Artificial Opening Endoscopic */
"09WA07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Auditory Ossicle, Open Approach */
"09WA0JZ" = "1" /* Revision of Synthetic Substitute in Left Auditory Ossicle, Open Approach */
"09WA0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Auditory Ossicle, Open Approach */
"09WA77Z" = "1" /* Revision of Autologous Tissue Substitute in Left Auditory Ossicle, Via Natural or Artificial Opening */
"09WA7JZ" = "1" /* Revision of Synthetic Substitute in Left Auditory Ossicle, Via Natural or Artificial Opening */
"09WA7KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Auditory Ossicle, Via Natural or Artificial Opening */
"09WA87Z" = "1" /* Revision of Autologous Tissue Substitute in Left Auditory Ossicle, Via Natural or Artificial Opening Endoscopic */
"09WA8JZ" = "1" /* Revision of Synthetic Substitute in Left Auditory Ossicle, Via Natural or Artificial Opening Endoscopic */
"09WA8KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Auditory Ossicle, Via Natural or Artificial Opening Endoscopic */
"09WD0SZ" = "1" /* Revision of Hearing Device in Right Inner Ear, Open Approach */
"09WD7SZ" = "1" /* Revision of Hearing Device in Right Inner Ear, Via Natural or Artificial Opening */
"09WD8SZ" = "1" /* Revision of Hearing Device in Right Inner Ear, Via Natural or Artificial Opening Endoscopic */
"09WE0SZ" = "1" /* Revision of Hearing Device in Left Inner Ear, Open Approach */
"09WE7SZ" = "1" /* Revision of Hearing Device in Left Inner Ear, Via Natural or Artificial Opening */
"09WE8SZ" = "1" /* Revision of Hearing Device in Left Inner Ear, Via Natural or Artificial Opening Endoscopic */
"09WH00Z" = "1" /* Revision of Drainage Device in Right Ear, Open Approach */
"09WH07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Ear, Open Approach */
"09WH0DZ" = "1" /* Revision of Intraluminal Device in Right Ear, Open Approach */
"09WH0JZ" = "1" /* Revision of Synthetic Substitute in Right Ear, Open Approach */
"09WH0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Ear, Open Approach */
"09WH30Z" = "1" /* Revision of Drainage Device in Right Ear, Percutaneous Approach */
"09WH37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Ear, Percutaneous Approach */
"09WH3DZ" = "1" /* Revision of Intraluminal Device in Right Ear, Percutaneous Approach */
"09WH40Z" = "1" /* Revision of Drainage Device in Right Ear, Percutaneous Endoscopic Approach */
"09WH47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Ear, Percutaneous Endoscopic Approach */
"09WH4DZ" = "1" /* Revision of Intraluminal Device in Right Ear, Percutaneous Endoscopic Approach */
"09WH70Z" = "1" /* Revision of Drainage Device in Right Ear, Via Natural or Artificial Opening */
"09WH77Z" = "1" /* Revision of Autologous Tissue Substitute in Right Ear, Via Natural or Artificial Opening */
"09WH7JZ" = "1" /* Revision of Synthetic Substitute in Right Ear, Via Natural or Artificial Opening */
"09WH7KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Ear, Via Natural or Artificial Opening */
"09WH80Z" = "1" /* Revision of Drainage Device in Right Ear, Via Natural or Artificial Opening Endoscopic */
"09WH87Z" = "1" /* Revision of Autologous Tissue Substitute in Right Ear, Via Natural or Artificial Opening Endoscopic */
"09WH8JZ" = "1" /* Revision of Synthetic Substitute in Right Ear, Via Natural or Artificial Opening Endoscopic */
"09WH8KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Ear, Via Natural or Artificial Opening Endoscopic */
"09WJ00Z" = "1" /* Revision of Drainage Device in Left Ear, Open Approach */
"09WJ07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Ear, Open Approach */
"09WJ0DZ" = "1" /* Revision of Intraluminal Device in Left Ear, Open Approach */
"09WJ0JZ" = "1" /* Revision of Synthetic Substitute in Left Ear, Open Approach */
"09WJ0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Ear, Open Approach */
"09WJ30Z" = "1" /* Revision of Drainage Device in Left Ear, Percutaneous Approach */
"09WJ37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Ear, Percutaneous Approach */
"09WJ3DZ" = "1" /* Revision of Intraluminal Device in Left Ear, Percutaneous Approach */
"09WJ40Z" = "1" /* Revision of Drainage Device in Left Ear, Percutaneous Endoscopic Approach */
"09WJ47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Ear, Percutaneous Endoscopic Approach */
"09WJ4DZ" = "1" /* Revision of Intraluminal Device in Left Ear, Percutaneous Endoscopic Approach */
"09WJ70Z" = "1" /* Revision of Drainage Device in Left Ear, Via Natural or Artificial Opening */
"09WJ77Z" = "1" /* Revision of Autologous Tissue Substitute in Left Ear, Via Natural or Artificial Opening */
"09WJ7JZ" = "1" /* Revision of Synthetic Substitute in Left Ear, Via Natural or Artificial Opening */
"09WJ7KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Ear, Via Natural or Artificial Opening */
"09WJ80Z" = "1" /* Revision of Drainage Device in Left Ear, Via Natural or Artificial Opening Endoscopic */
"09WJ87Z" = "1" /* Revision of Autologous Tissue Substitute in Left Ear, Via Natural or Artificial Opening Endoscopic */
"09WJ8JZ" = "1" /* Revision of Synthetic Substitute in Left Ear, Via Natural or Artificial Opening Endoscopic */
"09WJ8KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Ear, Via Natural or Artificial Opening Endoscopic */
"09WY00Z" = "1" /* Revision of Drainage Device in Sinus, Open Approach */
"09WY30Z" = "1" /* Revision of Drainage Device in Sinus, Percutaneous Approach */
"09WY40Z" = "1" /* Revision of Drainage Device in Sinus, Percutaneous Endoscopic Approach */
"0B110F4" = "1" /* Bypass Trachea to Cutaneous with Tracheostomy Device, Open Approach */
"0B110Z4" = "1" /* Bypass Trachea to Cutaneous, Open Approach */
"0B114F4" = "1" /* Bypass Trachea to Cutaneous with Tracheostomy Device, Percutaneous Endoscopic Approach */
"0B114Z4" = "1" /* Bypass Trachea to Cutaneous, Percutaneous Endoscopic Approach */
"0B510ZZ" = "1" /* Destruction of Trachea, Open Approach */
"0B513ZZ" = "1" /* Destruction of Trachea, Percutaneous Approach */
"0B514ZZ" = "1" /* Destruction of Trachea, Percutaneous Endoscopic Approach */
"0B517ZZ" = "1" /* Destruction of Trachea, Via Natural or Artificial Opening */
"0B518ZZ" = "1" /* Destruction of Trachea, Via Natural or Artificial Opening Endoscopic */
"0B520ZZ" = "1" /* Destruction of Carina, Open Approach */
"0B523ZZ" = "1" /* Destruction of Carina, Percutaneous Approach */
"0B524ZZ" = "1" /* Destruction of Carina, Percutaneous Endoscopic Approach */
"0B527ZZ" = "1" /* Destruction of Carina, Via Natural or Artificial Opening */
"0B528ZZ" = "1" /* Destruction of Carina, Via Natural or Artificial Opening Endoscopic */
"0B530ZZ" = "1" /* Destruction of Right Main Bronchus, Open Approach */
"0B533ZZ" = "1" /* Destruction of Right Main Bronchus, Percutaneous Approach */
"0B537ZZ" = "1" /* Destruction of Right Main Bronchus, Via Natural or Artificial Opening */
"0B540ZZ" = "1" /* Destruction of Right Upper Lobe Bronchus, Open Approach */
"0B543ZZ" = "1" /* Destruction of Right Upper Lobe Bronchus, Percutaneous Approach */
"0B547ZZ" = "1" /* Destruction of Right Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0B550ZZ" = "1" /* Destruction of Right Middle Lobe Bronchus, Open Approach */
"0B553ZZ" = "1" /* Destruction of Right Middle Lobe Bronchus, Percutaneous Approach */
"0B557ZZ" = "1" /* Destruction of Right Middle Lobe Bronchus, Via Natural or Artificial Opening */
"0B560ZZ" = "1" /* Destruction of Right Lower Lobe Bronchus, Open Approach */
"0B563ZZ" = "1" /* Destruction of Right Lower Lobe Bronchus, Percutaneous Approach */
"0B567ZZ" = "1" /* Destruction of Right Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0B570ZZ" = "1" /* Destruction of Left Main Bronchus, Open Approach */
"0B573ZZ" = "1" /* Destruction of Left Main Bronchus, Percutaneous Approach */
"0B577ZZ" = "1" /* Destruction of Left Main Bronchus, Via Natural or Artificial Opening */
"0B580ZZ" = "1" /* Destruction of Left Upper Lobe Bronchus, Open Approach */
"0B583ZZ" = "1" /* Destruction of Left Upper Lobe Bronchus, Percutaneous Approach */
"0B587ZZ" = "1" /* Destruction of Left Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0B590ZZ" = "1" /* Destruction of Lingula Bronchus, Open Approach */
"0B593ZZ" = "1" /* Destruction of Lingula Bronchus, Percutaneous Approach */
"0B597ZZ" = "1" /* Destruction of Lingula Bronchus, Via Natural or Artificial Opening */
"0B5B0ZZ" = "1" /* Destruction of Left Lower Lobe Bronchus, Open Approach */
"0B5B3ZZ" = "1" /* Destruction of Left Lower Lobe Bronchus, Percutaneous Approach */
"0B5B7ZZ" = "1" /* Destruction of Left Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0B5C0ZZ" = "1" /* Destruction of Right Upper Lung Lobe, Open Approach */
"0B5C3ZZ" = "1" /* Destruction of Right Upper Lung Lobe, Percutaneous Approach */
"0B5C4ZZ" = "1" /* Destruction of Right Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0B5C7ZZ" = "1" /* Destruction of Right Upper Lung Lobe, Via Natural or Artificial Opening */
"0B5D0ZZ" = "1" /* Destruction of Right Middle Lung Lobe, Open Approach */
"0B5D3ZZ" = "1" /* Destruction of Right Middle Lung Lobe, Percutaneous Approach */
"0B5D4ZZ" = "1" /* Destruction of Right Middle Lung Lobe, Percutaneous Endoscopic Approach */
"0B5D7ZZ" = "1" /* Destruction of Right Middle Lung Lobe, Via Natural or Artificial Opening */
"0B5F0ZZ" = "1" /* Destruction of Right Lower Lung Lobe, Open Approach */
"0B5F3ZZ" = "1" /* Destruction of Right Lower Lung Lobe, Percutaneous Approach */
"0B5F4ZZ" = "1" /* Destruction of Right Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0B5F7ZZ" = "1" /* Destruction of Right Lower Lung Lobe, Via Natural or Artificial Opening */
"0B5G0ZZ" = "1" /* Destruction of Left Upper Lung Lobe, Open Approach */
"0B5G3ZZ" = "1" /* Destruction of Left Upper Lung Lobe, Percutaneous Approach */
"0B5G4ZZ" = "1" /* Destruction of Left Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0B5G7ZZ" = "1" /* Destruction of Left Upper Lung Lobe, Via Natural or Artificial Opening */
"0B5H0ZZ" = "1" /* Destruction of Lung Lingula, Open Approach */
"0B5H3ZZ" = "1" /* Destruction of Lung Lingula, Percutaneous Approach */
"0B5H4ZZ" = "1" /* Destruction of Lung Lingula, Percutaneous Endoscopic Approach */
"0B5H7ZZ" = "1" /* Destruction of Lung Lingula, Via Natural or Artificial Opening */
"0B5J0ZZ" = "1" /* Destruction of Left Lower Lung Lobe, Open Approach */
"0B5J3ZZ" = "1" /* Destruction of Left Lower Lung Lobe, Percutaneous Approach */
"0B5J4ZZ" = "1" /* Destruction of Left Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0B5J7ZZ" = "1" /* Destruction of Left Lower Lung Lobe, Via Natural or Artificial Opening */
"0B5K0ZZ" = "1" /* Destruction of Right Lung, Open Approach */
"0B5K3ZZ" = "1" /* Destruction of Right Lung, Percutaneous Approach */
"0B5K4ZZ" = "1" /* Destruction of Right Lung, Percutaneous Endoscopic Approach */
"0B5K7ZZ" = "1" /* Destruction of Right Lung, Via Natural or Artificial Opening */
"0B5L0ZZ" = "1" /* Destruction of Left Lung, Open Approach */
"0B5L3ZZ" = "1" /* Destruction of Left Lung, Percutaneous Approach */
"0B5L4ZZ" = "1" /* Destruction of Left Lung, Percutaneous Endoscopic Approach */
"0B5L7ZZ" = "1" /* Destruction of Left Lung, Via Natural or Artificial Opening */
"0B5M0ZZ" = "1" /* Destruction of Bilateral Lungs, Open Approach */
"0B5M3ZZ" = "1" /* Destruction of Bilateral Lungs, Percutaneous Approach */
"0B5M4ZZ" = "1" /* Destruction of Bilateral Lungs, Percutaneous Endoscopic Approach */
"0B5M7ZZ" = "1" /* Destruction of Bilateral Lungs, Via Natural or Artificial Opening */
"0B5N0ZZ" = "1" /* Destruction of Right Pleura, Open Approach */
"0B5N3ZZ" = "1" /* Destruction of Right Pleura, Percutaneous Approach */
"0B5N4ZZ" = "1" /* Destruction of Right Pleura, Percutaneous Endoscopic Approach */
"0B5P0ZZ" = "1" /* Destruction of Left Pleura, Open Approach */
"0B5P3ZZ" = "1" /* Destruction of Left Pleura, Percutaneous Approach */
"0B5P4ZZ" = "1" /* Destruction of Left Pleura, Percutaneous Endoscopic Approach */
"0B5R0ZZ" = "1" /* Destruction of Right Diaphragm, Open Approach */
"0B5R3ZZ" = "1" /* Destruction of Right Diaphragm, Percutaneous Approach */
"0B5R4ZZ" = "1" /* Destruction of Right Diaphragm, Percutaneous Endoscopic Approach */
"0B5S0ZZ" = "1" /* Destruction of Left Diaphragm, Open Approach */
"0B5S3ZZ" = "1" /* Destruction of Left Diaphragm, Percutaneous Approach */
"0B5S4ZZ" = "1" /* Destruction of Left Diaphragm, Percutaneous Endoscopic Approach */
"0B710DZ" = "1" /* Dilation of Trachea with Intraluminal Device, Open Approach */
"0B710ZZ" = "1" /* Dilation of Trachea, Open Approach */
"0B713DZ" = "1" /* Dilation of Trachea with Intraluminal Device, Percutaneous Approach */
"0B713ZZ" = "1" /* Dilation of Trachea, Percutaneous Approach */
"0B714DZ" = "1" /* Dilation of Trachea with Intraluminal Device, Percutaneous Endoscopic Approach */
"0B714ZZ" = "1" /* Dilation of Trachea, Percutaneous Endoscopic Approach */
"0B717DZ" = "1" /* Dilation of Trachea with Intraluminal Device, Via Natural or Artificial Opening */
"0B717ZZ" = "1" /* Dilation of Trachea, Via Natural or Artificial Opening */
"0B718DZ" = "1" /* Dilation of Trachea with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0B718ZZ" = "1" /* Dilation of Trachea, Via Natural or Artificial Opening Endoscopic */
"0B720DZ" = "1" /* Dilation of Carina with Intraluminal Device, Open Approach */
"0B720ZZ" = "1" /* Dilation of Carina, Open Approach */
"0B723DZ" = "1" /* Dilation of Carina with Intraluminal Device, Percutaneous Approach */
"0B723ZZ" = "1" /* Dilation of Carina, Percutaneous Approach */
"0B724DZ" = "1" /* Dilation of Carina with Intraluminal Device, Percutaneous Endoscopic Approach */
"0B724ZZ" = "1" /* Dilation of Carina, Percutaneous Endoscopic Approach */
"0B727DZ" = "1" /* Dilation of Carina with Intraluminal Device, Via Natural or Artificial Opening */
"0B727ZZ" = "1" /* Dilation of Carina, Via Natural or Artificial Opening */
"0B728DZ" = "1" /* Dilation of Carina with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0B728ZZ" = "1" /* Dilation of Carina, Via Natural or Artificial Opening Endoscopic */
"0B9100Z" = "1" /* Drainage of Trachea with Drainage Device, Open Approach */
"0B910ZX" = "1" /* Drainage of Trachea, Open Approach, Diagnostic */
"0B910ZZ" = "1" /* Drainage of Trachea, Open Approach */
"0B9130Z" = "1" /* Drainage of Trachea with Drainage Device, Percutaneous Approach */
"0B913ZZ" = "1" /* Drainage of Trachea, Percutaneous Approach */
"0B9140Z" = "1" /* Drainage of Trachea with Drainage Device, Percutaneous Endoscopic Approach */
"0B914ZZ" = "1" /* Drainage of Trachea, Percutaneous Endoscopic Approach */
"0B9200Z" = "1" /* Drainage of Carina with Drainage Device, Open Approach */
"0B920ZX" = "1" /* Drainage of Carina, Open Approach, Diagnostic */
"0B920ZZ" = "1" /* Drainage of Carina, Open Approach */
"0B9230Z" = "1" /* Drainage of Carina with Drainage Device, Percutaneous Approach */
"0B923ZZ" = "1" /* Drainage of Carina, Percutaneous Approach */
"0B9240Z" = "1" /* Drainage of Carina with Drainage Device, Percutaneous Endoscopic Approach */
"0B924ZZ" = "1" /* Drainage of Carina, Percutaneous Endoscopic Approach */
"0B9300Z" = "1" /* Drainage of Right Main Bronchus with Drainage Device, Open Approach */
"0B930ZX" = "1" /* Drainage of Right Main Bronchus, Open Approach, Diagnostic */
"0B930ZZ" = "1" /* Drainage of Right Main Bronchus, Open Approach */
"0B9330Z" = "1" /* Drainage of Right Main Bronchus with Drainage Device, Percutaneous Approach */
"0B933ZZ" = "1" /* Drainage of Right Main Bronchus, Percutaneous Approach */
"0B9340Z" = "1" /* Drainage of Right Main Bronchus with Drainage Device, Percutaneous Endoscopic Approach */
"0B934ZZ" = "1" /* Drainage of Right Main Bronchus, Percutaneous Endoscopic Approach */
"0B9400Z" = "1" /* Drainage of Right Upper Lobe Bronchus with Drainage Device, Open Approach */
"0B940ZX" = "1" /* Drainage of Right Upper Lobe Bronchus, Open Approach, Diagnostic */
"0B940ZZ" = "1" /* Drainage of Right Upper Lobe Bronchus, Open Approach */
"0B9430Z" = "1" /* Drainage of Right Upper Lobe Bronchus with Drainage Device, Percutaneous Approach */
"0B943ZZ" = "1" /* Drainage of Right Upper Lobe Bronchus, Percutaneous Approach */
"0B9440Z" = "1" /* Drainage of Right Upper Lobe Bronchus with Drainage Device, Percutaneous Endoscopic Approach */
"0B944ZZ" = "1" /* Drainage of Right Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0B9500Z" = "1" /* Drainage of Right Middle Lobe Bronchus with Drainage Device, Open Approach */
"0B950ZX" = "1" /* Drainage of Right Middle Lobe Bronchus, Open Approach, Diagnostic */
"0B950ZZ" = "1" /* Drainage of Right Middle Lobe Bronchus, Open Approach */
"0B9530Z" = "1" /* Drainage of Right Middle Lobe Bronchus with Drainage Device, Percutaneous Approach */
"0B953ZZ" = "1" /* Drainage of Right Middle Lobe Bronchus, Percutaneous Approach */
"0B9540Z" = "1" /* Drainage of Right Middle Lobe Bronchus with Drainage Device, Percutaneous Endoscopic Approach */
"0B954ZZ" = "1" /* Drainage of Right Middle Lobe Bronchus, Percutaneous Endoscopic Approach */
"0B9600Z" = "1" /* Drainage of Right Lower Lobe Bronchus with Drainage Device, Open Approach */
"0B960ZX" = "1" /* Drainage of Right Lower Lobe Bronchus, Open Approach, Diagnostic */
"0B960ZZ" = "1" /* Drainage of Right Lower Lobe Bronchus, Open Approach */
"0B9630Z" = "1" /* Drainage of Right Lower Lobe Bronchus with Drainage Device, Percutaneous Approach */
"0B963ZZ" = "1" /* Drainage of Right Lower Lobe Bronchus, Percutaneous Approach */
"0B9640Z" = "1" /* Drainage of Right Lower Lobe Bronchus with Drainage Device, Percutaneous Endoscopic Approach */
"0B964ZZ" = "1" /* Drainage of Right Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0B9700Z" = "1" /* Drainage of Left Main Bronchus with Drainage Device, Open Approach */
"0B970ZX" = "1" /* Drainage of Left Main Bronchus, Open Approach, Diagnostic */
"0B970ZZ" = "1" /* Drainage of Left Main Bronchus, Open Approach */
"0B9730Z" = "1" /* Drainage of Left Main Bronchus with Drainage Device, Percutaneous Approach */
"0B973ZZ" = "1" /* Drainage of Left Main Bronchus, Percutaneous Approach */
"0B9740Z" = "1" /* Drainage of Left Main Bronchus with Drainage Device, Percutaneous Endoscopic Approach */
"0B974ZZ" = "1" /* Drainage of Left Main Bronchus, Percutaneous Endoscopic Approach */
"0B9800Z" = "1" /* Drainage of Left Upper Lobe Bronchus with Drainage Device, Open Approach */
"0B980ZX" = "1" /* Drainage of Left Upper Lobe Bronchus, Open Approach, Diagnostic */
"0B980ZZ" = "1" /* Drainage of Left Upper Lobe Bronchus, Open Approach */
"0B9830Z" = "1" /* Drainage of Left Upper Lobe Bronchus with Drainage Device, Percutaneous Approach */
"0B983ZZ" = "1" /* Drainage of Left Upper Lobe Bronchus, Percutaneous Approach */
"0B9840Z" = "1" /* Drainage of Left Upper Lobe Bronchus with Drainage Device, Percutaneous Endoscopic Approach */
"0B984ZZ" = "1" /* Drainage of Left Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0B9900Z" = "1" /* Drainage of Lingula Bronchus with Drainage Device, Open Approach */
"0B990ZX" = "1" /* Drainage of Lingula Bronchus, Open Approach, Diagnostic */
"0B990ZZ" = "1" /* Drainage of Lingula Bronchus, Open Approach */
"0B9930Z" = "1" /* Drainage of Lingula Bronchus with Drainage Device, Percutaneous Approach */
"0B993ZZ" = "1" /* Drainage of Lingula Bronchus, Percutaneous Approach */
"0B9940Z" = "1" /* Drainage of Lingula Bronchus with Drainage Device, Percutaneous Endoscopic Approach */
"0B994ZZ" = "1" /* Drainage of Lingula Bronchus, Percutaneous Endoscopic Approach */
"0B9B00Z" = "1" /* Drainage of Left Lower Lobe Bronchus with Drainage Device, Open Approach */
"0B9B0ZX" = "1" /* Drainage of Left Lower Lobe Bronchus, Open Approach, Diagnostic */
"0B9B0ZZ" = "1" /* Drainage of Left Lower Lobe Bronchus, Open Approach */
"0B9B30Z" = "1" /* Drainage of Left Lower Lobe Bronchus with Drainage Device, Percutaneous Approach */
"0B9B3ZZ" = "1" /* Drainage of Left Lower Lobe Bronchus, Percutaneous Approach */
"0B9B40Z" = "1" /* Drainage of Left Lower Lobe Bronchus with Drainage Device, Percutaneous Endoscopic Approach */
"0B9B4ZZ" = "1" /* Drainage of Left Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0B9C00Z" = "1" /* Drainage of Right Upper Lung Lobe with Drainage Device, Open Approach */
"0B9C0ZX" = "1" /* Drainage of Right Upper Lung Lobe, Open Approach, Diagnostic */
"0B9C0ZZ" = "1" /* Drainage of Right Upper Lung Lobe, Open Approach */
"0B9C30Z" = "1" /* Drainage of Right Upper Lung Lobe with Drainage Device, Percutaneous Approach */
"0B9C3ZZ" = "1" /* Drainage of Right Upper Lung Lobe, Percutaneous Approach */
"0B9C40Z" = "1" /* Drainage of Right Upper Lung Lobe with Drainage Device, Percutaneous Endoscopic Approach */
"0B9C4ZZ" = "1" /* Drainage of Right Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0B9C70Z" = "1" /* Drainage of Right Upper Lung Lobe with Drainage Device, Via Natural or Artificial Opening */
"0B9C7ZZ" = "1" /* Drainage of Right Upper Lung Lobe, Via Natural or Artificial Opening */
"0B9C80Z" = "1" /* Drainage of Right Upper Lung Lobe with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B9C8ZX" = "1" /* Drainage of Right Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0B9C8ZZ" = "1" /* Drainage of Right Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0B9D00Z" = "1" /* Drainage of Right Middle Lung Lobe with Drainage Device, Open Approach */
"0B9D0ZX" = "1" /* Drainage of Right Middle Lung Lobe, Open Approach, Diagnostic */
"0B9D0ZZ" = "1" /* Drainage of Right Middle Lung Lobe, Open Approach */
"0B9D30Z" = "1" /* Drainage of Right Middle Lung Lobe with Drainage Device, Percutaneous Approach */
"0B9D3ZZ" = "1" /* Drainage of Right Middle Lung Lobe, Percutaneous Approach */
"0B9D40Z" = "1" /* Drainage of Right Middle Lung Lobe with Drainage Device, Percutaneous Endoscopic Approach */
"0B9D4ZZ" = "1" /* Drainage of Right Middle Lung Lobe, Percutaneous Endoscopic Approach */
"0B9D70Z" = "1" /* Drainage of Right Middle Lung Lobe with Drainage Device, Via Natural or Artificial Opening */
"0B9D7ZZ" = "1" /* Drainage of Right Middle Lung Lobe, Via Natural or Artificial Opening */
"0B9D80Z" = "1" /* Drainage of Right Middle Lung Lobe with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B9D8ZX" = "1" /* Drainage of Right Middle Lung Lobe, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0B9D8ZZ" = "1" /* Drainage of Right Middle Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0B9F00Z" = "1" /* Drainage of Right Lower Lung Lobe with Drainage Device, Open Approach */
"0B9F0ZX" = "1" /* Drainage of Right Lower Lung Lobe, Open Approach, Diagnostic */
"0B9F0ZZ" = "1" /* Drainage of Right Lower Lung Lobe, Open Approach */
"0B9F30Z" = "1" /* Drainage of Right Lower Lung Lobe with Drainage Device, Percutaneous Approach */
"0B9F3ZZ" = "1" /* Drainage of Right Lower Lung Lobe, Percutaneous Approach */
"0B9F40Z" = "1" /* Drainage of Right Lower Lung Lobe with Drainage Device, Percutaneous Endoscopic Approach */
"0B9F4ZZ" = "1" /* Drainage of Right Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0B9F70Z" = "1" /* Drainage of Right Lower Lung Lobe with Drainage Device, Via Natural or Artificial Opening */
"0B9F7ZZ" = "1" /* Drainage of Right Lower Lung Lobe, Via Natural or Artificial Opening */
"0B9F80Z" = "1" /* Drainage of Right Lower Lung Lobe with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B9F8ZX" = "1" /* Drainage of Right Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0B9F8ZZ" = "1" /* Drainage of Right Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0B9G00Z" = "1" /* Drainage of Left Upper Lung Lobe with Drainage Device, Open Approach */
"0B9G0ZX" = "1" /* Drainage of Left Upper Lung Lobe, Open Approach, Diagnostic */
"0B9G0ZZ" = "1" /* Drainage of Left Upper Lung Lobe, Open Approach */
"0B9G30Z" = "1" /* Drainage of Left Upper Lung Lobe with Drainage Device, Percutaneous Approach */
"0B9G3ZZ" = "1" /* Drainage of Left Upper Lung Lobe, Percutaneous Approach */
"0B9G40Z" = "1" /* Drainage of Left Upper Lung Lobe with Drainage Device, Percutaneous Endoscopic Approach */
"0B9G4ZZ" = "1" /* Drainage of Left Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0B9G70Z" = "1" /* Drainage of Left Upper Lung Lobe with Drainage Device, Via Natural or Artificial Opening */
"0B9G7ZZ" = "1" /* Drainage of Left Upper Lung Lobe, Via Natural or Artificial Opening */
"0B9G80Z" = "1" /* Drainage of Left Upper Lung Lobe with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B9G8ZX" = "1" /* Drainage of Left Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0B9G8ZZ" = "1" /* Drainage of Left Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0B9H00Z" = "1" /* Drainage of Lung Lingula with Drainage Device, Open Approach */
"0B9H0ZX" = "1" /* Drainage of Lung Lingula, Open Approach, Diagnostic */
"0B9H0ZZ" = "1" /* Drainage of Lung Lingula, Open Approach */
"0B9H30Z" = "1" /* Drainage of Lung Lingula with Drainage Device, Percutaneous Approach */
"0B9H3ZZ" = "1" /* Drainage of Lung Lingula, Percutaneous Approach */
"0B9H40Z" = "1" /* Drainage of Lung Lingula with Drainage Device, Percutaneous Endoscopic Approach */
"0B9H4ZZ" = "1" /* Drainage of Lung Lingula, Percutaneous Endoscopic Approach */
"0B9H70Z" = "1" /* Drainage of Lung Lingula with Drainage Device, Via Natural or Artificial Opening */
"0B9H7ZZ" = "1" /* Drainage of Lung Lingula, Via Natural or Artificial Opening */
"0B9H80Z" = "1" /* Drainage of Lung Lingula with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B9H8ZX" = "1" /* Drainage of Lung Lingula, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0B9H8ZZ" = "1" /* Drainage of Lung Lingula, Via Natural or Artificial Opening Endoscopic */
"0B9J00Z" = "1" /* Drainage of Left Lower Lung Lobe with Drainage Device, Open Approach */
"0B9J0ZX" = "1" /* Drainage of Left Lower Lung Lobe, Open Approach, Diagnostic */
"0B9J0ZZ" = "1" /* Drainage of Left Lower Lung Lobe, Open Approach */
"0B9J30Z" = "1" /* Drainage of Left Lower Lung Lobe with Drainage Device, Percutaneous Approach */
"0B9J3ZZ" = "1" /* Drainage of Left Lower Lung Lobe, Percutaneous Approach */
"0B9J40Z" = "1" /* Drainage of Left Lower Lung Lobe with Drainage Device, Percutaneous Endoscopic Approach */
"0B9J4ZZ" = "1" /* Drainage of Left Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0B9J70Z" = "1" /* Drainage of Left Lower Lung Lobe with Drainage Device, Via Natural or Artificial Opening */
"0B9J7ZZ" = "1" /* Drainage of Left Lower Lung Lobe, Via Natural or Artificial Opening */
"0B9J80Z" = "1" /* Drainage of Left Lower Lung Lobe with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B9J8ZX" = "1" /* Drainage of Left Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0B9J8ZZ" = "1" /* Drainage of Left Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0B9K00Z" = "1" /* Drainage of Right Lung with Drainage Device, Open Approach */
"0B9K0ZX" = "1" /* Drainage of Right Lung, Open Approach, Diagnostic */
"0B9K0ZZ" = "1" /* Drainage of Right Lung, Open Approach */
"0B9K30Z" = "1" /* Drainage of Right Lung with Drainage Device, Percutaneous Approach */
"0B9K3ZZ" = "1" /* Drainage of Right Lung, Percutaneous Approach */
"0B9K40Z" = "1" /* Drainage of Right Lung with Drainage Device, Percutaneous Endoscopic Approach */
"0B9K4ZZ" = "1" /* Drainage of Right Lung, Percutaneous Endoscopic Approach */
"0B9K70Z" = "1" /* Drainage of Right Lung with Drainage Device, Via Natural or Artificial Opening */
"0B9K7ZZ" = "1" /* Drainage of Right Lung, Via Natural or Artificial Opening */
"0B9K80Z" = "1" /* Drainage of Right Lung with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B9K8ZX" = "1" /* Drainage of Right Lung, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0B9K8ZZ" = "1" /* Drainage of Right Lung, Via Natural or Artificial Opening Endoscopic */
"0B9L00Z" = "1" /* Drainage of Left Lung with Drainage Device, Open Approach */
"0B9L0ZX" = "1" /* Drainage of Left Lung, Open Approach, Diagnostic */
"0B9L0ZZ" = "1" /* Drainage of Left Lung, Open Approach */
"0B9L30Z" = "1" /* Drainage of Left Lung with Drainage Device, Percutaneous Approach */
"0B9L3ZZ" = "1" /* Drainage of Left Lung, Percutaneous Approach */
"0B9L40Z" = "1" /* Drainage of Left Lung with Drainage Device, Percutaneous Endoscopic Approach */
"0B9L4ZZ" = "1" /* Drainage of Left Lung, Percutaneous Endoscopic Approach */
"0B9L70Z" = "1" /* Drainage of Left Lung with Drainage Device, Via Natural or Artificial Opening */
"0B9L7ZZ" = "1" /* Drainage of Left Lung, Via Natural or Artificial Opening */
"0B9L80Z" = "1" /* Drainage of Left Lung with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B9L8ZX" = "1" /* Drainage of Left Lung, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0B9L8ZZ" = "1" /* Drainage of Left Lung, Via Natural or Artificial Opening Endoscopic */
"0B9M00Z" = "1" /* Drainage of Bilateral Lungs with Drainage Device, Open Approach */
"0B9M0ZX" = "1" /* Drainage of Bilateral Lungs, Open Approach, Diagnostic */
"0B9M0ZZ" = "1" /* Drainage of Bilateral Lungs, Open Approach */
"0B9M30Z" = "1" /* Drainage of Bilateral Lungs with Drainage Device, Percutaneous Approach */
"0B9M3ZZ" = "1" /* Drainage of Bilateral Lungs, Percutaneous Approach */
"0B9M40Z" = "1" /* Drainage of Bilateral Lungs with Drainage Device, Percutaneous Endoscopic Approach */
"0B9M4ZZ" = "1" /* Drainage of Bilateral Lungs, Percutaneous Endoscopic Approach */
"0B9M70Z" = "1" /* Drainage of Bilateral Lungs with Drainage Device, Via Natural or Artificial Opening */
"0B9M7ZZ" = "1" /* Drainage of Bilateral Lungs, Via Natural or Artificial Opening */
"0B9M80Z" = "1" /* Drainage of Bilateral Lungs with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B9M8ZX" = "1" /* Drainage of Bilateral Lungs, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0B9M8ZZ" = "1" /* Drainage of Bilateral Lungs, Via Natural or Artificial Opening Endoscopic */
"0B9N40Z" = "1" /* Drainage of Right Pleura with Drainage Device, Percutaneous Endoscopic Approach */
"0B9N4ZZ" = "1" /* Drainage of Right Pleura, Percutaneous Endoscopic Approach */
"0B9P40Z" = "1" /* Drainage of Left Pleura with Drainage Device, Percutaneous Endoscopic Approach */
"0B9P4ZZ" = "1" /* Drainage of Left Pleura, Percutaneous Endoscopic Approach */
"0B9R00Z" = "1" /* Drainage of Right Diaphragm with Drainage Device, Open Approach */
"0B9R0ZX" = "1" /* Drainage of Right Diaphragm, Open Approach, Diagnostic */
"0B9R0ZZ" = "1" /* Drainage of Right Diaphragm, Open Approach */
"0B9R40Z" = "1" /* Drainage of Right Diaphragm with Drainage Device, Percutaneous Endoscopic Approach */
"0B9R4ZX" = "1" /* Drainage of Right Diaphragm, Percutaneous Endoscopic Approach, Diagnostic */
"0B9R4ZZ" = "1" /* Drainage of Right Diaphragm, Percutaneous Endoscopic Approach */
"0B9S00Z" = "1" /* Drainage of Left Diaphragm with Drainage Device, Open Approach */
"0B9S0ZX" = "1" /* Drainage of Left Diaphragm, Open Approach, Diagnostic */
"0B9S0ZZ" = "1" /* Drainage of Left Diaphragm, Open Approach */
"0B9S40Z" = "1" /* Drainage of Left Diaphragm with Drainage Device, Percutaneous Endoscopic Approach */
"0B9S4ZX" = "1" /* Drainage of Left Diaphragm, Percutaneous Endoscopic Approach, Diagnostic */
"0B9S4ZZ" = "1" /* Drainage of Left Diaphragm, Percutaneous Endoscopic Approach */
"0BB10ZX" = "1" /* Excision of Trachea, Open Approach, Diagnostic */
"0BB10ZZ" = "1" /* Excision of Trachea, Open Approach */
"0BB13ZZ" = "1" /* Excision of Trachea, Percutaneous Approach */
"0BB14ZZ" = "1" /* Excision of Trachea, Percutaneous Endoscopic Approach */
"0BB17ZZ" = "1" /* Excision of Trachea, Via Natural or Artificial Opening */
"0BB18ZZ" = "1" /* Excision of Trachea, Via Natural or Artificial Opening Endoscopic */
"0BB20ZX" = "1" /* Excision of Carina, Open Approach, Diagnostic */
"0BB20ZZ" = "1" /* Excision of Carina, Open Approach */
"0BB23ZZ" = "1" /* Excision of Carina, Percutaneous Approach */
"0BB24ZZ" = "1" /* Excision of Carina, Percutaneous Endoscopic Approach */
"0BB27ZZ" = "1" /* Excision of Carina, Via Natural or Artificial Opening */
"0BB28ZZ" = "1" /* Excision of Carina, Via Natural or Artificial Opening Endoscopic */
"0BB30ZX" = "1" /* Excision of Right Main Bronchus, Open Approach, Diagnostic */
"0BB30ZZ" = "1" /* Excision of Right Main Bronchus, Open Approach */
"0BB33ZZ" = "1" /* Excision of Right Main Bronchus, Percutaneous Approach */
"0BB37ZZ" = "1" /* Excision of Right Main Bronchus, Via Natural or Artificial Opening */
"0BB40ZX" = "1" /* Excision of Right Upper Lobe Bronchus, Open Approach, Diagnostic */
"0BB40ZZ" = "1" /* Excision of Right Upper Lobe Bronchus, Open Approach */
"0BB43ZZ" = "1" /* Excision of Right Upper Lobe Bronchus, Percutaneous Approach */
"0BB47ZZ" = "1" /* Excision of Right Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BB50ZX" = "1" /* Excision of Right Middle Lobe Bronchus, Open Approach, Diagnostic */
"0BB50ZZ" = "1" /* Excision of Right Middle Lobe Bronchus, Open Approach */
"0BB53ZZ" = "1" /* Excision of Right Middle Lobe Bronchus, Percutaneous Approach */
"0BB57ZZ" = "1" /* Excision of Right Middle Lobe Bronchus, Via Natural or Artificial Opening */
"0BB60ZX" = "1" /* Excision of Right Lower Lobe Bronchus, Open Approach, Diagnostic */
"0BB60ZZ" = "1" /* Excision of Right Lower Lobe Bronchus, Open Approach */
"0BB63ZZ" = "1" /* Excision of Right Lower Lobe Bronchus, Percutaneous Approach */
"0BB67ZZ" = "1" /* Excision of Right Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BB70ZX" = "1" /* Excision of Left Main Bronchus, Open Approach, Diagnostic */
"0BB70ZZ" = "1" /* Excision of Left Main Bronchus, Open Approach */
"0BB73ZZ" = "1" /* Excision of Left Main Bronchus, Percutaneous Approach */
"0BB77ZZ" = "1" /* Excision of Left Main Bronchus, Via Natural or Artificial Opening */
"0BB80ZX" = "1" /* Excision of Left Upper Lobe Bronchus, Open Approach, Diagnostic */
"0BB80ZZ" = "1" /* Excision of Left Upper Lobe Bronchus, Open Approach */
"0BB83ZZ" = "1" /* Excision of Left Upper Lobe Bronchus, Percutaneous Approach */
"0BB87ZZ" = "1" /* Excision of Left Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BB90ZX" = "1" /* Excision of Lingula Bronchus, Open Approach, Diagnostic */
"0BB90ZZ" = "1" /* Excision of Lingula Bronchus, Open Approach */
"0BB93ZZ" = "1" /* Excision of Lingula Bronchus, Percutaneous Approach */
"0BB97ZZ" = "1" /* Excision of Lingula Bronchus, Via Natural or Artificial Opening */
"0BBB0ZX" = "1" /* Excision of Left Lower Lobe Bronchus, Open Approach, Diagnostic */
"0BBB0ZZ" = "1" /* Excision of Left Lower Lobe Bronchus, Open Approach */
"0BBB3ZZ" = "1" /* Excision of Left Lower Lobe Bronchus, Percutaneous Approach */
"0BBB7ZZ" = "1" /* Excision of Left Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BBC0ZX" = "1" /* Excision of Right Upper Lung Lobe, Open Approach, Diagnostic */
"0BBC0ZZ" = "1" /* Excision of Right Upper Lung Lobe, Open Approach */
"0BBC3ZZ" = "1" /* Excision of Right Upper Lung Lobe, Percutaneous Approach */
"0BBC4ZX" = "1" /* Excision of Right Upper Lung Lobe, Percutaneous Endoscopic Approach, Diagnostic */
"0BBC4ZZ" = "1" /* Excision of Right Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BBC7ZX" = "1" /* Excision of Right Upper Lung Lobe, Via Natural or Artificial Opening, Diagnostic */
"0BBC7ZZ" = "1" /* Excision of Right Upper Lung Lobe, Via Natural or Artificial Opening */
"0BBC8ZX" = "1" /* Excision of Right Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0BBD0ZX" = "1" /* Excision of Right Middle Lung Lobe, Open Approach, Diagnostic */
"0BBD0ZZ" = "1" /* Excision of Right Middle Lung Lobe, Open Approach */
"0BBD3ZZ" = "1" /* Excision of Right Middle Lung Lobe, Percutaneous Approach */
"0BBD4ZX" = "1" /* Excision of Right Middle Lung Lobe, Percutaneous Endoscopic Approach, Diagnostic */
"0BBD4ZZ" = "1" /* Excision of Right Middle Lung Lobe, Percutaneous Endoscopic Approach */
"0BBD7ZX" = "1" /* Excision of Right Middle Lung Lobe, Via Natural or Artificial Opening, Diagnostic */
"0BBD7ZZ" = "1" /* Excision of Right Middle Lung Lobe, Via Natural or Artificial Opening */
"0BBD8ZX" = "1" /* Excision of Right Middle Lung Lobe, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0BBF0ZX" = "1" /* Excision of Right Lower Lung Lobe, Open Approach, Diagnostic */
"0BBF0ZZ" = "1" /* Excision of Right Lower Lung Lobe, Open Approach */
"0BBF3ZZ" = "1" /* Excision of Right Lower Lung Lobe, Percutaneous Approach */
"0BBF4ZX" = "1" /* Excision of Right Lower Lung Lobe, Percutaneous Endoscopic Approach, Diagnostic */
"0BBF4ZZ" = "1" /* Excision of Right Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BBF7ZX" = "1" /* Excision of Right Lower Lung Lobe, Via Natural or Artificial Opening, Diagnostic */
"0BBF7ZZ" = "1" /* Excision of Right Lower Lung Lobe, Via Natural or Artificial Opening */
"0BBF8ZX" = "1" /* Excision of Right Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0BBG0ZX" = "1" /* Excision of Left Upper Lung Lobe, Open Approach, Diagnostic */
"0BBG0ZZ" = "1" /* Excision of Left Upper Lung Lobe, Open Approach */
"0BBG3ZZ" = "1" /* Excision of Left Upper Lung Lobe, Percutaneous Approach */
"0BBG4ZX" = "1" /* Excision of Left Upper Lung Lobe, Percutaneous Endoscopic Approach, Diagnostic */
"0BBG4ZZ" = "1" /* Excision of Left Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BBG7ZX" = "1" /* Excision of Left Upper Lung Lobe, Via Natural or Artificial Opening, Diagnostic */
"0BBG7ZZ" = "1" /* Excision of Left Upper Lung Lobe, Via Natural or Artificial Opening */
"0BBG8ZX" = "1" /* Excision of Left Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0BBH0ZX" = "1" /* Excision of Lung Lingula, Open Approach, Diagnostic */
"0BBH0ZZ" = "1" /* Excision of Lung Lingula, Open Approach */
"0BBH3ZZ" = "1" /* Excision of Lung Lingula, Percutaneous Approach */
"0BBH4ZX" = "1" /* Excision of Lung Lingula, Percutaneous Endoscopic Approach, Diagnostic */
"0BBH4ZZ" = "1" /* Excision of Lung Lingula, Percutaneous Endoscopic Approach */
"0BBH7ZX" = "1" /* Excision of Lung Lingula, Via Natural or Artificial Opening, Diagnostic */
"0BBH7ZZ" = "1" /* Excision of Lung Lingula, Via Natural or Artificial Opening */
"0BBH8ZX" = "1" /* Excision of Lung Lingula, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0BBJ0ZX" = "1" /* Excision of Left Lower Lung Lobe, Open Approach, Diagnostic */
"0BBJ0ZZ" = "1" /* Excision of Left Lower Lung Lobe, Open Approach */
"0BBJ3ZZ" = "1" /* Excision of Left Lower Lung Lobe, Percutaneous Approach */
"0BBJ4ZX" = "1" /* Excision of Left Lower Lung Lobe, Percutaneous Endoscopic Approach, Diagnostic */
"0BBJ4ZZ" = "1" /* Excision of Left Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BBJ7ZX" = "1" /* Excision of Left Lower Lung Lobe, Via Natural or Artificial Opening, Diagnostic */
"0BBJ7ZZ" = "1" /* Excision of Left Lower Lung Lobe, Via Natural or Artificial Opening */
"0BBJ8ZX" = "1" /* Excision of Left Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0BBK0ZX" = "1" /* Excision of Right Lung, Open Approach, Diagnostic */
"0BBK0ZZ" = "1" /* Excision of Right Lung, Open Approach */
"0BBK3ZZ" = "1" /* Excision of Right Lung, Percutaneous Approach */
"0BBK4ZX" = "1" /* Excision of Right Lung, Percutaneous Endoscopic Approach, Diagnostic */
"0BBK4ZZ" = "1" /* Excision of Right Lung, Percutaneous Endoscopic Approach */
"0BBK7ZX" = "1" /* Excision of Right Lung, Via Natural or Artificial Opening, Diagnostic */
"0BBK7ZZ" = "1" /* Excision of Right Lung, Via Natural or Artificial Opening */
"0BBK8ZX" = "1" /* Excision of Right Lung, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0BBL0ZX" = "1" /* Excision of Left Lung, Open Approach, Diagnostic */
"0BBL0ZZ" = "1" /* Excision of Left Lung, Open Approach */
"0BBL3ZZ" = "1" /* Excision of Left Lung, Percutaneous Approach */
"0BBL4ZX" = "1" /* Excision of Left Lung, Percutaneous Endoscopic Approach, Diagnostic */
"0BBL4ZZ" = "1" /* Excision of Left Lung, Percutaneous Endoscopic Approach */
"0BBL7ZX" = "1" /* Excision of Left Lung, Via Natural or Artificial Opening, Diagnostic */
"0BBL7ZZ" = "1" /* Excision of Left Lung, Via Natural or Artificial Opening */
"0BBL8ZX" = "1" /* Excision of Left Lung, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0BBM0ZX" = "1" /* Excision of Bilateral Lungs, Open Approach, Diagnostic */
"0BBM0ZZ" = "1" /* Excision of Bilateral Lungs, Open Approach */
"0BBM3ZZ" = "1" /* Excision of Bilateral Lungs, Percutaneous Approach */
"0BBM4ZX" = "1" /* Excision of Bilateral Lungs, Percutaneous Endoscopic Approach, Diagnostic */
"0BBM7ZX" = "1" /* Excision of Bilateral Lungs, Via Natural or Artificial Opening, Diagnostic */
"0BBM7ZZ" = "1" /* Excision of Bilateral Lungs, Via Natural or Artificial Opening */
"0BBM8ZX" = "1" /* Excision of Bilateral Lungs, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0BBN0ZZ" = "1" /* Excision of Right Pleura, Open Approach */
"0BBN3ZZ" = "1" /* Excision of Right Pleura, Percutaneous Approach */
"0BBN4ZX" = "1" /* Excision of Right Pleura, Percutaneous Endoscopic Approach, Diagnostic */
"0BBN4ZZ" = "1" /* Excision of Right Pleura, Percutaneous Endoscopic Approach */
"0BBP0ZZ" = "1" /* Excision of Left Pleura, Open Approach */
"0BBP3ZZ" = "1" /* Excision of Left Pleura, Percutaneous Approach */
"0BBP4ZX" = "1" /* Excision of Left Pleura, Percutaneous Endoscopic Approach, Diagnostic */
"0BBP4ZZ" = "1" /* Excision of Left Pleura, Percutaneous Endoscopic Approach */
"0BBR0ZX" = "1" /* Excision of Right Diaphragm, Open Approach, Diagnostic */
"0BBR0ZZ" = "1" /* Excision of Right Diaphragm, Open Approach */
"0BBR3ZX" = "1" /* Excision of Right Diaphragm, Percutaneous Approach, Diagnostic */
"0BBR3ZZ" = "1" /* Excision of Right Diaphragm, Percutaneous Approach */
"0BBR4ZX" = "1" /* Excision of Right Diaphragm, Percutaneous Endoscopic Approach, Diagnostic */
"0BBR4ZZ" = "1" /* Excision of Right Diaphragm, Percutaneous Endoscopic Approach */
"0BBS0ZX" = "1" /* Excision of Left Diaphragm, Open Approach, Diagnostic */
"0BBS0ZZ" = "1" /* Excision of Left Diaphragm, Open Approach */
"0BBS3ZX" = "1" /* Excision of Left Diaphragm, Percutaneous Approach, Diagnostic */
"0BBS3ZZ" = "1" /* Excision of Left Diaphragm, Percutaneous Approach */
"0BBS4ZX" = "1" /* Excision of Left Diaphragm, Percutaneous Endoscopic Approach, Diagnostic */
"0BBS4ZZ" = "1" /* Excision of Left Diaphragm, Percutaneous Endoscopic Approach */
"0BC10ZZ" = "1" /* Extirpation of Matter from Trachea, Open Approach */
"0BC13ZZ" = "1" /* Extirpation of Matter from Trachea, Percutaneous Approach */
"0BC14ZZ" = "1" /* Extirpation of Matter from Trachea, Percutaneous Endoscopic Approach */
"0BC20ZZ" = "1" /* Extirpation of Matter from Carina, Open Approach */
"0BC23ZZ" = "1" /* Extirpation of Matter from Carina, Percutaneous Approach */
"0BC24ZZ" = "1" /* Extirpation of Matter from Carina, Percutaneous Endoscopic Approach */
"0BC30ZZ" = "1" /* Extirpation of Matter from Right Main Bronchus, Open Approach */
"0BC33ZZ" = "1" /* Extirpation of Matter from Right Main Bronchus, Percutaneous Approach */
"0BC34ZZ" = "1" /* Extirpation of Matter from Right Main Bronchus, Percutaneous Endoscopic Approach */
"0BC40ZZ" = "1" /* Extirpation of Matter from Right Upper Lobe Bronchus, Open Approach */
"0BC43ZZ" = "1" /* Extirpation of Matter from Right Upper Lobe Bronchus, Percutaneous Approach */
"0BC44ZZ" = "1" /* Extirpation of Matter from Right Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BC50ZZ" = "1" /* Extirpation of Matter from Right Middle Lobe Bronchus, Open Approach */
"0BC53ZZ" = "1" /* Extirpation of Matter from Right Middle Lobe Bronchus, Percutaneous Approach */
"0BC54ZZ" = "1" /* Extirpation of Matter from Right Middle Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BC60ZZ" = "1" /* Extirpation of Matter from Right Lower Lobe Bronchus, Open Approach */
"0BC63ZZ" = "1" /* Extirpation of Matter from Right Lower Lobe Bronchus, Percutaneous Approach */
"0BC64ZZ" = "1" /* Extirpation of Matter from Right Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BC70ZZ" = "1" /* Extirpation of Matter from Left Main Bronchus, Open Approach */
"0BC73ZZ" = "1" /* Extirpation of Matter from Left Main Bronchus, Percutaneous Approach */
"0BC74ZZ" = "1" /* Extirpation of Matter from Left Main Bronchus, Percutaneous Endoscopic Approach */
"0BC80ZZ" = "1" /* Extirpation of Matter from Left Upper Lobe Bronchus, Open Approach */
"0BC83ZZ" = "1" /* Extirpation of Matter from Left Upper Lobe Bronchus, Percutaneous Approach */
"0BC84ZZ" = "1" /* Extirpation of Matter from Left Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BC90ZZ" = "1" /* Extirpation of Matter from Lingula Bronchus, Open Approach */
"0BC93ZZ" = "1" /* Extirpation of Matter from Lingula Bronchus, Percutaneous Approach */
"0BC94ZZ" = "1" /* Extirpation of Matter from Lingula Bronchus, Percutaneous Endoscopic Approach */
"0BCB0ZZ" = "1" /* Extirpation of Matter from Left Lower Lobe Bronchus, Open Approach */
"0BCB3ZZ" = "1" /* Extirpation of Matter from Left Lower Lobe Bronchus, Percutaneous Approach */
"0BCB4ZZ" = "1" /* Extirpation of Matter from Left Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BCC0ZZ" = "1" /* Extirpation of Matter from Right Upper Lung Lobe, Open Approach */
"0BCC3ZZ" = "1" /* Extirpation of Matter from Right Upper Lung Lobe, Percutaneous Approach */
"0BCC4ZZ" = "1" /* Extirpation of Matter from Right Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BCC7ZZ" = "1" /* Extirpation of Matter from Right Upper Lung Lobe, Via Natural or Artificial Opening */
"0BCD0ZZ" = "1" /* Extirpation of Matter from Right Middle Lung Lobe, Open Approach */
"0BCD3ZZ" = "1" /* Extirpation of Matter from Right Middle Lung Lobe, Percutaneous Approach */
"0BCD4ZZ" = "1" /* Extirpation of Matter from Right Middle Lung Lobe, Percutaneous Endoscopic Approach */
"0BCD7ZZ" = "1" /* Extirpation of Matter from Right Middle Lung Lobe, Via Natural or Artificial Opening */
"0BCF0ZZ" = "1" /* Extirpation of Matter from Right Lower Lung Lobe, Open Approach */
"0BCF3ZZ" = "1" /* Extirpation of Matter from Right Lower Lung Lobe, Percutaneous Approach */
"0BCF4ZZ" = "1" /* Extirpation of Matter from Right Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BCF7ZZ" = "1" /* Extirpation of Matter from Right Lower Lung Lobe, Via Natural or Artificial Opening */
"0BCG0ZZ" = "1" /* Extirpation of Matter from Left Upper Lung Lobe, Open Approach */
"0BCG3ZZ" = "1" /* Extirpation of Matter from Left Upper Lung Lobe, Percutaneous Approach */
"0BCG4ZZ" = "1" /* Extirpation of Matter from Left Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BCG7ZZ" = "1" /* Extirpation of Matter from Left Upper Lung Lobe, Via Natural or Artificial Opening */
"0BCH0ZZ" = "1" /* Extirpation of Matter from Lung Lingula, Open Approach */
"0BCH3ZZ" = "1" /* Extirpation of Matter from Lung Lingula, Percutaneous Approach */
"0BCH4ZZ" = "1" /* Extirpation of Matter from Lung Lingula, Percutaneous Endoscopic Approach */
"0BCH7ZZ" = "1" /* Extirpation of Matter from Lung Lingula, Via Natural or Artificial Opening */
"0BCJ0ZZ" = "1" /* Extirpation of Matter from Left Lower Lung Lobe, Open Approach */
"0BCJ3ZZ" = "1" /* Extirpation of Matter from Left Lower Lung Lobe, Percutaneous Approach */
"0BCJ4ZZ" = "1" /* Extirpation of Matter from Left Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BCJ7ZZ" = "1" /* Extirpation of Matter from Left Lower Lung Lobe, Via Natural or Artificial Opening */
"0BCK0ZZ" = "1" /* Extirpation of Matter from Right Lung, Open Approach */
"0BCK3ZZ" = "1" /* Extirpation of Matter from Right Lung, Percutaneous Approach */
"0BCK4ZZ" = "1" /* Extirpation of Matter from Right Lung, Percutaneous Endoscopic Approach */
"0BCK7ZZ" = "1" /* Extirpation of Matter from Right Lung, Via Natural or Artificial Opening */
"0BCL0ZZ" = "1" /* Extirpation of Matter from Left Lung, Open Approach */
"0BCL3ZZ" = "1" /* Extirpation of Matter from Left Lung, Percutaneous Approach */
"0BCL4ZZ" = "1" /* Extirpation of Matter from Left Lung, Percutaneous Endoscopic Approach */
"0BCL7ZZ" = "1" /* Extirpation of Matter from Left Lung, Via Natural or Artificial Opening */
"0BCM0ZZ" = "1" /* Extirpation of Matter from Bilateral Lungs, Open Approach */
"0BCM3ZZ" = "1" /* Extirpation of Matter from Bilateral Lungs, Percutaneous Approach */
"0BCM4ZZ" = "1" /* Extirpation of Matter from Bilateral Lungs, Percutaneous Endoscopic Approach */
"0BCM7ZZ" = "1" /* Extirpation of Matter from Bilateral Lungs, Via Natural or Artificial Opening */
"0BCR0ZZ" = "1" /* Extirpation of Matter from Right Diaphragm, Open Approach */
"0BCR3ZZ" = "1" /* Extirpation of Matter from Right Diaphragm, Percutaneous Approach */
"0BCR4ZZ" = "1" /* Extirpation of Matter from Right Diaphragm, Percutaneous Endoscopic Approach */
"0BCS0ZZ" = "1" /* Extirpation of Matter from Left Diaphragm, Open Approach */
"0BCS3ZZ" = "1" /* Extirpation of Matter from Left Diaphragm, Percutaneous Approach */
"0BCS4ZZ" = "1" /* Extirpation of Matter from Left Diaphragm, Percutaneous Endoscopic Approach */
"0BDN0ZX" = "1" /* Extraction of Right Pleura, Open Approach, Diagnostic */
"0BDN0ZZ" = "1" /* Extraction of Right Pleura, Open Approach */
"0BDN3ZX" = "1" /* Extraction of Right Pleura, Percutaneous Approach, Diagnostic */
"0BDN3ZZ" = "1" /* Extraction of Right Pleura, Percutaneous Approach */
"0BDN4ZX" = "1" /* Extraction of Right Pleura, Percutaneous Endoscopic Approach, Diagnostic */
"0BDN4ZZ" = "1" /* Extraction of Right Pleura, Percutaneous Endoscopic Approach */
"0BDP0ZX" = "1" /* Extraction of Left Pleura, Open Approach, Diagnostic */
"0BDP0ZZ" = "1" /* Extraction of Left Pleura, Open Approach */
"0BDP3ZX" = "1" /* Extraction of Left Pleura, Percutaneous Approach, Diagnostic */
"0BDP3ZZ" = "1" /* Extraction of Left Pleura, Percutaneous Approach */
"0BDP4ZX" = "1" /* Extraction of Left Pleura, Percutaneous Endoscopic Approach, Diagnostic */
"0BDP4ZZ" = "1" /* Extraction of Left Pleura, Percutaneous Endoscopic Approach */
"0BF10ZZ" = "1" /* Fragmentation in Trachea, Open Approach */
"0BF13ZZ" = "1" /* Fragmentation in Trachea, Percutaneous Approach */
"0BF14ZZ" = "1" /* Fragmentation in Trachea, Percutaneous Endoscopic Approach */
"0BF17ZZ" = "1" /* Fragmentation in Trachea, Via Natural or Artificial Opening */
"0BF18ZZ" = "1" /* Fragmentation in Trachea, Via Natural or Artificial Opening Endoscopic */
"0BF20ZZ" = "1" /* Fragmentation in Carina, Open Approach */
"0BF23ZZ" = "1" /* Fragmentation in Carina, Percutaneous Approach */
"0BF24ZZ" = "1" /* Fragmentation in Carina, Percutaneous Endoscopic Approach */
"0BF27ZZ" = "1" /* Fragmentation in Carina, Via Natural or Artificial Opening */
"0BF28ZZ" = "1" /* Fragmentation in Carina, Via Natural or Artificial Opening Endoscopic */
"0BF30ZZ" = "1" /* Fragmentation in Right Main Bronchus, Open Approach */
"0BF33ZZ" = "1" /* Fragmentation in Right Main Bronchus, Percutaneous Approach */
"0BF34ZZ" = "1" /* Fragmentation in Right Main Bronchus, Percutaneous Endoscopic Approach */
"0BF40ZZ" = "1" /* Fragmentation in Right Upper Lobe Bronchus, Open Approach */
"0BF43ZZ" = "1" /* Fragmentation in Right Upper Lobe Bronchus, Percutaneous Approach */
"0BF44ZZ" = "1" /* Fragmentation in Right Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BF50ZZ" = "1" /* Fragmentation in Right Middle Lobe Bronchus, Open Approach */
"0BF53ZZ" = "1" /* Fragmentation in Right Middle Lobe Bronchus, Percutaneous Approach */
"0BF54ZZ" = "1" /* Fragmentation in Right Middle Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BF60ZZ" = "1" /* Fragmentation in Right Lower Lobe Bronchus, Open Approach */
"0BF63ZZ" = "1" /* Fragmentation in Right Lower Lobe Bronchus, Percutaneous Approach */
"0BF64ZZ" = "1" /* Fragmentation in Right Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BF70ZZ" = "1" /* Fragmentation in Left Main Bronchus, Open Approach */
"0BF73ZZ" = "1" /* Fragmentation in Left Main Bronchus, Percutaneous Approach */
"0BF74ZZ" = "1" /* Fragmentation in Left Main Bronchus, Percutaneous Endoscopic Approach */
"0BF80ZZ" = "1" /* Fragmentation in Left Upper Lobe Bronchus, Open Approach */
"0BF83ZZ" = "1" /* Fragmentation in Left Upper Lobe Bronchus, Percutaneous Approach */
"0BF84ZZ" = "1" /* Fragmentation in Left Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BF90ZZ" = "1" /* Fragmentation in Lingula Bronchus, Open Approach */
"0BF93ZZ" = "1" /* Fragmentation in Lingula Bronchus, Percutaneous Approach */
"0BF94ZZ" = "1" /* Fragmentation in Lingula Bronchus, Percutaneous Endoscopic Approach */
"0BFB0ZZ" = "1" /* Fragmentation in Left Lower Lobe Bronchus, Open Approach */
"0BFB3ZZ" = "1" /* Fragmentation in Left Lower Lobe Bronchus, Percutaneous Approach */
"0BFB4ZZ" = "1" /* Fragmentation in Left Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BH001Z" = "1" /* Insertion of Radioactive Element into Tracheobronchial Tree, Open Approach */
"0BH002Z" = "1" /* Insertion of Monitoring Device into Tracheobronchial Tree, Open Approach */
"0BH003Z" = "1" /* Insertion of Infusion Device into Tracheobronchial Tree, Open Approach */
"0BH00DZ" = "1" /* Insertion of Intraluminal Device into Tracheobronchial Tree, Open Approach */
"0BH031Z" = "1" /* Insertion of Radioactive Element into Tracheobronchial Tree, Percutaneous Approach */
"0BH032Z" = "1" /* Insertion of Monitoring Device into Tracheobronchial Tree, Percutaneous Approach */
"0BH033Z" = "1" /* Insertion of Infusion Device into Tracheobronchial Tree, Percutaneous Approach */
"0BH03DZ" = "1" /* Insertion of Intraluminal Device into Tracheobronchial Tree, Percutaneous Approach */
"0BH041Z" = "1" /* Insertion of Radioactive Element into Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BH042Z" = "1" /* Insertion of Monitoring Device into Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BH043Z" = "1" /* Insertion of Infusion Device into Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BH04DZ" = "1" /* Insertion of Intraluminal Device into Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BH071Z" = "1" /* Insertion of Radioactive Element into Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BH081Z" = "1" /* Insertion of Radioactive Element into Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BH102Z" = "1" /* Insertion of Monitoring Device into Trachea, Open Approach */
"0BH10DZ" = "1" /* Insertion of Intraluminal Device into Trachea, Open Approach */
"0BH13DZ" = "1" /* Insertion of Intraluminal Device into Trachea, Percutaneous Approach */
"0BH14DZ" = "1" /* Insertion of Intraluminal Device into Trachea, Percutaneous Endoscopic Approach */
"0BH30GZ" = "1" /* Insertion of Endobronchial Valve into Right Main Bronchus, Open Approach */
"0BH33GZ" = "1" /* Insertion of Endobronchial Valve into Right Main Bronchus, Percutaneous Approach */
"0BH34GZ" = "1" /* Insertion of Endobronchial Valve into Right Main Bronchus, Percutaneous Endoscopic Approach */
"0BH37GZ" = "1" /* Insertion of Endobronchial Valve into Right Main Bronchus, Via Natural or Artificial Opening */
"0BH40GZ" = "1" /* Insertion of Endobronchial Valve into Right Upper Lobe Bronchus, Open Approach */
"0BH43GZ" = "1" /* Insertion of Endobronchial Valve into Right Upper Lobe Bronchus, Percutaneous Approach */
"0BH44GZ" = "1" /* Insertion of Endobronchial Valve into Right Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BH47GZ" = "1" /* Insertion of Endobronchial Valve into Right Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BH50GZ" = "1" /* Insertion of Endobronchial Valve into Right Middle Lobe Bronchus, Open Approach */
"0BH53GZ" = "1" /* Insertion of Endobronchial Valve into Right Middle Lobe Bronchus, Percutaneous Approach */
"0BH54GZ" = "1" /* Insertion of Endobronchial Valve into Right Middle Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BH57GZ" = "1" /* Insertion of Endobronchial Valve into Right Middle Lobe Bronchus, Via Natural or Artificial Opening */
"0BH60GZ" = "1" /* Insertion of Endobronchial Valve into Right Lower Lobe Bronchus, Open Approach */
"0BH63GZ" = "1" /* Insertion of Endobronchial Valve into Right Lower Lobe Bronchus, Percutaneous Approach */
"0BH64GZ" = "1" /* Insertion of Endobronchial Valve into Right Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BH67GZ" = "1" /* Insertion of Endobronchial Valve into Right Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BH70GZ" = "1" /* Insertion of Endobronchial Valve into Left Main Bronchus, Open Approach */
"0BH73GZ" = "1" /* Insertion of Endobronchial Valve into Left Main Bronchus, Percutaneous Approach */
"0BH74GZ" = "1" /* Insertion of Endobronchial Valve into Left Main Bronchus, Percutaneous Endoscopic Approach */
"0BH77GZ" = "1" /* Insertion of Endobronchial Valve into Left Main Bronchus, Via Natural or Artificial Opening */
"0BH80GZ" = "1" /* Insertion of Endobronchial Valve into Left Upper Lobe Bronchus, Open Approach */
"0BH83GZ" = "1" /* Insertion of Endobronchial Valve into Left Upper Lobe Bronchus, Percutaneous Approach */
"0BH84GZ" = "1" /* Insertion of Endobronchial Valve into Left Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BH87GZ" = "1" /* Insertion of Endobronchial Valve into Left Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BH90GZ" = "1" /* Insertion of Endobronchial Valve into Lingula Bronchus, Open Approach */
"0BH93GZ" = "1" /* Insertion of Endobronchial Valve into Lingula Bronchus, Percutaneous Approach */
"0BH94GZ" = "1" /* Insertion of Endobronchial Valve into Lingula Bronchus, Percutaneous Endoscopic Approach */
"0BH97GZ" = "1" /* Insertion of Endobronchial Valve into Lingula Bronchus, Via Natural or Artificial Opening */
"0BHB0GZ" = "1" /* Insertion of Endobronchial Valve into Left Lower Lobe Bronchus, Open Approach */
"0BHB3GZ" = "1" /* Insertion of Endobronchial Valve into Left Lower Lobe Bronchus, Percutaneous Approach */
"0BHB4GZ" = "1" /* Insertion of Endobronchial Valve into Left Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BHB7GZ" = "1" /* Insertion of Endobronchial Valve into Left Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BHK01Z" = "1" /* Insertion of Radioactive Element into Right Lung, Open Approach */
"0BHK02Z" = "1" /* Insertion of Monitoring Device into Right Lung, Open Approach */
"0BHK03Z" = "1" /* Insertion of Infusion Device into Right Lung, Open Approach */
"0BHK31Z" = "1" /* Insertion of Radioactive Element into Right Lung, Percutaneous Approach */
"0BHK32Z" = "1" /* Insertion of Monitoring Device into Right Lung, Percutaneous Approach */
"0BHK33Z" = "1" /* Insertion of Infusion Device into Right Lung, Percutaneous Approach */
"0BHK41Z" = "1" /* Insertion of Radioactive Element into Right Lung, Percutaneous Endoscopic Approach */
"0BHK42Z" = "1" /* Insertion of Monitoring Device into Right Lung, Percutaneous Endoscopic Approach */
"0BHK43Z" = "1" /* Insertion of Infusion Device into Right Lung, Percutaneous Endoscopic Approach */
"0BHK71Z" = "1" /* Insertion of Radioactive Element into Right Lung, Via Natural or Artificial Opening */
"0BHK81Z" = "1" /* Insertion of Radioactive Element into Right Lung, Via Natural or Artificial Opening Endoscopic */
"0BHL01Z" = "1" /* Insertion of Radioactive Element into Left Lung, Open Approach */
"0BHL02Z" = "1" /* Insertion of Monitoring Device into Left Lung, Open Approach */
"0BHL03Z" = "1" /* Insertion of Infusion Device into Left Lung, Open Approach */
"0BHL31Z" = "1" /* Insertion of Radioactive Element into Left Lung, Percutaneous Approach */
"0BHL32Z" = "1" /* Insertion of Monitoring Device into Left Lung, Percutaneous Approach */
"0BHL33Z" = "1" /* Insertion of Infusion Device into Left Lung, Percutaneous Approach */
"0BHL41Z" = "1" /* Insertion of Radioactive Element into Left Lung, Percutaneous Endoscopic Approach */
"0BHL42Z" = "1" /* Insertion of Monitoring Device into Left Lung, Percutaneous Endoscopic Approach */
"0BHL43Z" = "1" /* Insertion of Infusion Device into Left Lung, Percutaneous Endoscopic Approach */
"0BHL71Z" = "1" /* Insertion of Radioactive Element into Left Lung, Via Natural or Artificial Opening */
"0BHL81Z" = "1" /* Insertion of Radioactive Element into Left Lung, Via Natural or Artificial Opening Endoscopic */
"0BHR02Z" = "1" /* Insertion of Monitoring Device into Right Diaphragm, Open Approach */
"0BHR0MZ" = "1" /* Insertion of Diaphragmatic Pacemaker Lead into Right Diaphragm, Open Approach */
"0BHR32Z" = "1" /* Insertion of Monitoring Device into Right Diaphragm, Percutaneous Approach */
"0BHR3MZ" = "1" /* Insertion of Diaphragmatic Pacemaker Lead into Right Diaphragm, Percutaneous Approach */
"0BHR42Z" = "1" /* Insertion of Monitoring Device into Right Diaphragm, Percutaneous Endoscopic Approach */
"0BHR4MZ" = "1" /* Insertion of Diaphragmatic Pacemaker Lead into Right Diaphragm, Percutaneous Endoscopic Approach */
"0BHS02Z" = "1" /* Insertion of Monitoring Device into Left Diaphragm, Open Approach */
"0BHS0MZ" = "1" /* Insertion of Diaphragmatic Pacemaker Lead into Left Diaphragm, Open Approach */
"0BHS32Z" = "1" /* Insertion of Monitoring Device into Left Diaphragm, Percutaneous Approach */
"0BHS3MZ" = "1" /* Insertion of Diaphragmatic Pacemaker Lead into Left Diaphragm, Percutaneous Approach */
"0BHS42Z" = "1" /* Insertion of Monitoring Device into Left Diaphragm, Percutaneous Endoscopic Approach */
"0BHS4MZ" = "1" /* Insertion of Diaphragmatic Pacemaker Lead into Left Diaphragm, Percutaneous Endoscopic Approach */
"0BJ00ZZ" = "1" /* Inspection of Tracheobronchial Tree, Open Approach */
"0BJ04ZZ" = "1" /* Inspection of Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BJ10ZZ" = "1" /* Inspection of Trachea, Open Approach */
"0BJK0ZZ" = "1" /* Inspection of Right Lung, Open Approach */
"0BJK4ZZ" = "1" /* Inspection of Right Lung, Percutaneous Endoscopic Approach */
"0BJL0ZZ" = "1" /* Inspection of Left Lung, Open Approach */
"0BJL4ZZ" = "1" /* Inspection of Left Lung, Percutaneous Endoscopic Approach */
"0BJQ0ZZ" = "1" /* Inspection of Pleura, Open Approach */
"0BJQ4ZZ" = "1" /* Inspection of Pleura, Percutaneous Endoscopic Approach */
"0BJT0ZZ" = "1" /* Inspection of Diaphragm, Open Approach */
"0BJT4ZZ" = "1" /* Inspection of Diaphragm, Percutaneous Endoscopic Approach */
"0BL10CZ" = "1" /* Occlusion of Trachea with Extraluminal Device, Open Approach */
"0BL10DZ" = "1" /* Occlusion of Trachea with Intraluminal Device, Open Approach */
"0BL10ZZ" = "1" /* Occlusion of Trachea, Open Approach */
"0BL13CZ" = "1" /* Occlusion of Trachea with Extraluminal Device, Percutaneous Approach */
"0BL13DZ" = "1" /* Occlusion of Trachea with Intraluminal Device, Percutaneous Approach */
"0BL13ZZ" = "1" /* Occlusion of Trachea, Percutaneous Approach */
"0BL14CZ" = "1" /* Occlusion of Trachea with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BL14DZ" = "1" /* Occlusion of Trachea with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BL14ZZ" = "1" /* Occlusion of Trachea, Percutaneous Endoscopic Approach */
"0BL17DZ" = "1" /* Occlusion of Trachea with Intraluminal Device, Via Natural or Artificial Opening */
"0BL17ZZ" = "1" /* Occlusion of Trachea, Via Natural or Artificial Opening */
"0BL18DZ" = "1" /* Occlusion of Trachea with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BL18ZZ" = "1" /* Occlusion of Trachea, Via Natural or Artificial Opening Endoscopic */
"0BL20CZ" = "1" /* Occlusion of Carina with Extraluminal Device, Open Approach */
"0BL20DZ" = "1" /* Occlusion of Carina with Intraluminal Device, Open Approach */
"0BL20ZZ" = "1" /* Occlusion of Carina, Open Approach */
"0BL23CZ" = "1" /* Occlusion of Carina with Extraluminal Device, Percutaneous Approach */
"0BL23DZ" = "1" /* Occlusion of Carina with Intraluminal Device, Percutaneous Approach */
"0BL23ZZ" = "1" /* Occlusion of Carina, Percutaneous Approach */
"0BL24CZ" = "1" /* Occlusion of Carina with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BL24DZ" = "1" /* Occlusion of Carina with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BL24ZZ" = "1" /* Occlusion of Carina, Percutaneous Endoscopic Approach */
"0BL27DZ" = "1" /* Occlusion of Carina with Intraluminal Device, Via Natural or Artificial Opening */
"0BL27ZZ" = "1" /* Occlusion of Carina, Via Natural or Artificial Opening */
"0BL28DZ" = "1" /* Occlusion of Carina with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BL28ZZ" = "1" /* Occlusion of Carina, Via Natural or Artificial Opening Endoscopic */
"0BL30CZ" = "1" /* Occlusion of Right Main Bronchus with Extraluminal Device, Open Approach */
"0BL30DZ" = "1" /* Occlusion of Right Main Bronchus with Intraluminal Device, Open Approach */
"0BL30ZZ" = "1" /* Occlusion of Right Main Bronchus, Open Approach */
"0BL33CZ" = "1" /* Occlusion of Right Main Bronchus with Extraluminal Device, Percutaneous Approach */
"0BL33DZ" = "1" /* Occlusion of Right Main Bronchus with Intraluminal Device, Percutaneous Approach */
"0BL33ZZ" = "1" /* Occlusion of Right Main Bronchus, Percutaneous Approach */
"0BL34CZ" = "1" /* Occlusion of Right Main Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BL34DZ" = "1" /* Occlusion of Right Main Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BL34ZZ" = "1" /* Occlusion of Right Main Bronchus, Percutaneous Endoscopic Approach */
"0BL37DZ" = "1" /* Occlusion of Right Main Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BL37ZZ" = "1" /* Occlusion of Right Main Bronchus, Via Natural or Artificial Opening */
"0BL38DZ" = "1" /* Occlusion of Right Main Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BL38ZZ" = "1" /* Occlusion of Right Main Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BL40CZ" = "1" /* Occlusion of Right Upper Lobe Bronchus with Extraluminal Device, Open Approach */
"0BL40DZ" = "1" /* Occlusion of Right Upper Lobe Bronchus with Intraluminal Device, Open Approach */
"0BL40ZZ" = "1" /* Occlusion of Right Upper Lobe Bronchus, Open Approach */
"0BL43CZ" = "1" /* Occlusion of Right Upper Lobe Bronchus with Extraluminal Device, Percutaneous Approach */
"0BL43DZ" = "1" /* Occlusion of Right Upper Lobe Bronchus with Intraluminal Device, Percutaneous Approach */
"0BL43ZZ" = "1" /* Occlusion of Right Upper Lobe Bronchus, Percutaneous Approach */
"0BL44CZ" = "1" /* Occlusion of Right Upper Lobe Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BL44DZ" = "1" /* Occlusion of Right Upper Lobe Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BL44ZZ" = "1" /* Occlusion of Right Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BL47DZ" = "1" /* Occlusion of Right Upper Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BL47ZZ" = "1" /* Occlusion of Right Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BL48DZ" = "1" /* Occlusion of Right Upper Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BL48ZZ" = "1" /* Occlusion of Right Upper Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BL50CZ" = "1" /* Occlusion of Right Middle Lobe Bronchus with Extraluminal Device, Open Approach */
"0BL50DZ" = "1" /* Occlusion of Right Middle Lobe Bronchus with Intraluminal Device, Open Approach */
"0BL50ZZ" = "1" /* Occlusion of Right Middle Lobe Bronchus, Open Approach */
"0BL53CZ" = "1" /* Occlusion of Right Middle Lobe Bronchus with Extraluminal Device, Percutaneous Approach */
"0BL53DZ" = "1" /* Occlusion of Right Middle Lobe Bronchus with Intraluminal Device, Percutaneous Approach */
"0BL53ZZ" = "1" /* Occlusion of Right Middle Lobe Bronchus, Percutaneous Approach */
"0BL54CZ" = "1" /* Occlusion of Right Middle Lobe Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BL54DZ" = "1" /* Occlusion of Right Middle Lobe Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BL54ZZ" = "1" /* Occlusion of Right Middle Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BL57DZ" = "1" /* Occlusion of Right Middle Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BL57ZZ" = "1" /* Occlusion of Right Middle Lobe Bronchus, Via Natural or Artificial Opening */
"0BL58DZ" = "1" /* Occlusion of Right Middle Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BL58ZZ" = "1" /* Occlusion of Right Middle Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BL60CZ" = "1" /* Occlusion of Right Lower Lobe Bronchus with Extraluminal Device, Open Approach */
"0BL60DZ" = "1" /* Occlusion of Right Lower Lobe Bronchus with Intraluminal Device, Open Approach */
"0BL60ZZ" = "1" /* Occlusion of Right Lower Lobe Bronchus, Open Approach */
"0BL63CZ" = "1" /* Occlusion of Right Lower Lobe Bronchus with Extraluminal Device, Percutaneous Approach */
"0BL63DZ" = "1" /* Occlusion of Right Lower Lobe Bronchus with Intraluminal Device, Percutaneous Approach */
"0BL63ZZ" = "1" /* Occlusion of Right Lower Lobe Bronchus, Percutaneous Approach */
"0BL64CZ" = "1" /* Occlusion of Right Lower Lobe Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BL64DZ" = "1" /* Occlusion of Right Lower Lobe Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BL64ZZ" = "1" /* Occlusion of Right Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BL67DZ" = "1" /* Occlusion of Right Lower Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BL67ZZ" = "1" /* Occlusion of Right Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BL68DZ" = "1" /* Occlusion of Right Lower Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BL68ZZ" = "1" /* Occlusion of Right Lower Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BL70CZ" = "1" /* Occlusion of Left Main Bronchus with Extraluminal Device, Open Approach */
"0BL70DZ" = "1" /* Occlusion of Left Main Bronchus with Intraluminal Device, Open Approach */
"0BL70ZZ" = "1" /* Occlusion of Left Main Bronchus, Open Approach */
"0BL73CZ" = "1" /* Occlusion of Left Main Bronchus with Extraluminal Device, Percutaneous Approach */
"0BL73DZ" = "1" /* Occlusion of Left Main Bronchus with Intraluminal Device, Percutaneous Approach */
"0BL73ZZ" = "1" /* Occlusion of Left Main Bronchus, Percutaneous Approach */
"0BL74CZ" = "1" /* Occlusion of Left Main Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BL74DZ" = "1" /* Occlusion of Left Main Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BL74ZZ" = "1" /* Occlusion of Left Main Bronchus, Percutaneous Endoscopic Approach */
"0BL77DZ" = "1" /* Occlusion of Left Main Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BL77ZZ" = "1" /* Occlusion of Left Main Bronchus, Via Natural or Artificial Opening */
"0BL78DZ" = "1" /* Occlusion of Left Main Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BL78ZZ" = "1" /* Occlusion of Left Main Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BL80CZ" = "1" /* Occlusion of Left Upper Lobe Bronchus with Extraluminal Device, Open Approach */
"0BL80DZ" = "1" /* Occlusion of Left Upper Lobe Bronchus with Intraluminal Device, Open Approach */
"0BL80ZZ" = "1" /* Occlusion of Left Upper Lobe Bronchus, Open Approach */
"0BL83CZ" = "1" /* Occlusion of Left Upper Lobe Bronchus with Extraluminal Device, Percutaneous Approach */
"0BL83DZ" = "1" /* Occlusion of Left Upper Lobe Bronchus with Intraluminal Device, Percutaneous Approach */
"0BL83ZZ" = "1" /* Occlusion of Left Upper Lobe Bronchus, Percutaneous Approach */
"0BL84CZ" = "1" /* Occlusion of Left Upper Lobe Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BL84DZ" = "1" /* Occlusion of Left Upper Lobe Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BL84ZZ" = "1" /* Occlusion of Left Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BL87DZ" = "1" /* Occlusion of Left Upper Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BL87ZZ" = "1" /* Occlusion of Left Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BL88DZ" = "1" /* Occlusion of Left Upper Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BL88ZZ" = "1" /* Occlusion of Left Upper Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BL90CZ" = "1" /* Occlusion of Lingula Bronchus with Extraluminal Device, Open Approach */
"0BL90DZ" = "1" /* Occlusion of Lingula Bronchus with Intraluminal Device, Open Approach */
"0BL90ZZ" = "1" /* Occlusion of Lingula Bronchus, Open Approach */
"0BL93CZ" = "1" /* Occlusion of Lingula Bronchus with Extraluminal Device, Percutaneous Approach */
"0BL93DZ" = "1" /* Occlusion of Lingula Bronchus with Intraluminal Device, Percutaneous Approach */
"0BL93ZZ" = "1" /* Occlusion of Lingula Bronchus, Percutaneous Approach */
"0BL94CZ" = "1" /* Occlusion of Lingula Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BL94DZ" = "1" /* Occlusion of Lingula Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BL94ZZ" = "1" /* Occlusion of Lingula Bronchus, Percutaneous Endoscopic Approach */
"0BL97DZ" = "1" /* Occlusion of Lingula Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BL97ZZ" = "1" /* Occlusion of Lingula Bronchus, Via Natural or Artificial Opening */
"0BL98DZ" = "1" /* Occlusion of Lingula Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BL98ZZ" = "1" /* Occlusion of Lingula Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BLB0CZ" = "1" /* Occlusion of Left Lower Lobe Bronchus with Extraluminal Device, Open Approach */
"0BLB0DZ" = "1" /* Occlusion of Left Lower Lobe Bronchus with Intraluminal Device, Open Approach */
"0BLB0ZZ" = "1" /* Occlusion of Left Lower Lobe Bronchus, Open Approach */
"0BLB3CZ" = "1" /* Occlusion of Left Lower Lobe Bronchus with Extraluminal Device, Percutaneous Approach */
"0BLB3DZ" = "1" /* Occlusion of Left Lower Lobe Bronchus with Intraluminal Device, Percutaneous Approach */
"0BLB3ZZ" = "1" /* Occlusion of Left Lower Lobe Bronchus, Percutaneous Approach */
"0BLB4CZ" = "1" /* Occlusion of Left Lower Lobe Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BLB4DZ" = "1" /* Occlusion of Left Lower Lobe Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BLB4ZZ" = "1" /* Occlusion of Left Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BLB7DZ" = "1" /* Occlusion of Left Lower Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BLB7ZZ" = "1" /* Occlusion of Left Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BLB8DZ" = "1" /* Occlusion of Left Lower Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BLB8ZZ" = "1" /* Occlusion of Left Lower Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BM10ZZ" = "1" /* Reattachment of Trachea, Open Approach */
"0BM20ZZ" = "1" /* Reattachment of Carina, Open Approach */
"0BM30ZZ" = "1" /* Reattachment of Right Main Bronchus, Open Approach */
"0BM40ZZ" = "1" /* Reattachment of Right Upper Lobe Bronchus, Open Approach */
"0BM50ZZ" = "1" /* Reattachment of Right Middle Lobe Bronchus, Open Approach */
"0BM60ZZ" = "1" /* Reattachment of Right Lower Lobe Bronchus, Open Approach */
"0BM70ZZ" = "1" /* Reattachment of Left Main Bronchus, Open Approach */
"0BM80ZZ" = "1" /* Reattachment of Left Upper Lobe Bronchus, Open Approach */
"0BM90ZZ" = "1" /* Reattachment of Lingula Bronchus, Open Approach */
"0BMB0ZZ" = "1" /* Reattachment of Left Lower Lobe Bronchus, Open Approach */
"0BMC0ZZ" = "1" /* Reattachment of Right Upper Lung Lobe, Open Approach */
"0BMD0ZZ" = "1" /* Reattachment of Right Middle Lung Lobe, Open Approach */
"0BMF0ZZ" = "1" /* Reattachment of Right Lower Lung Lobe, Open Approach */
"0BMG0ZZ" = "1" /* Reattachment of Left Upper Lung Lobe, Open Approach */
"0BMH0ZZ" = "1" /* Reattachment of Lung Lingula, Open Approach */
"0BMJ0ZZ" = "1" /* Reattachment of Left Lower Lung Lobe, Open Approach */
"0BMK0ZZ" = "1" /* Reattachment of Right Lung, Open Approach */
"0BML0ZZ" = "1" /* Reattachment of Left Lung, Open Approach */
"0BMR0ZZ" = "1" /* Reattachment of Right Diaphragm, Open Approach */
"0BMS0ZZ" = "1" /* Reattachment of Left Diaphragm, Open Approach */
"0BN10ZZ" = "1" /* Release Trachea, Open Approach */
"0BN13ZZ" = "1" /* Release Trachea, Percutaneous Approach */
"0BN14ZZ" = "1" /* Release Trachea, Percutaneous Endoscopic Approach */
"0BN17ZZ" = "1" /* Release Trachea, Via Natural or Artificial Opening */
"0BN18ZZ" = "1" /* Release Trachea, Via Natural or Artificial Opening Endoscopic */
"0BN20ZZ" = "1" /* Release Carina, Open Approach */
"0BN23ZZ" = "1" /* Release Carina, Percutaneous Approach */
"0BN24ZZ" = "1" /* Release Carina, Percutaneous Endoscopic Approach */
"0BN27ZZ" = "1" /* Release Carina, Via Natural or Artificial Opening */
"0BN28ZZ" = "1" /* Release Carina, Via Natural or Artificial Opening Endoscopic */
"0BN30ZZ" = "1" /* Release Right Main Bronchus, Open Approach */
"0BN33ZZ" = "1" /* Release Right Main Bronchus, Percutaneous Approach */
"0BN34ZZ" = "1" /* Release Right Main Bronchus, Percutaneous Endoscopic Approach */
"0BN37ZZ" = "1" /* Release Right Main Bronchus, Via Natural or Artificial Opening */
"0BN38ZZ" = "1" /* Release Right Main Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BN40ZZ" = "1" /* Release Right Upper Lobe Bronchus, Open Approach */
"0BN43ZZ" = "1" /* Release Right Upper Lobe Bronchus, Percutaneous Approach */
"0BN44ZZ" = "1" /* Release Right Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BN47ZZ" = "1" /* Release Right Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BN48ZZ" = "1" /* Release Right Upper Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BN50ZZ" = "1" /* Release Right Middle Lobe Bronchus, Open Approach */
"0BN53ZZ" = "1" /* Release Right Middle Lobe Bronchus, Percutaneous Approach */
"0BN54ZZ" = "1" /* Release Right Middle Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BN57ZZ" = "1" /* Release Right Middle Lobe Bronchus, Via Natural or Artificial Opening */
"0BN58ZZ" = "1" /* Release Right Middle Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BN60ZZ" = "1" /* Release Right Lower Lobe Bronchus, Open Approach */
"0BN63ZZ" = "1" /* Release Right Lower Lobe Bronchus, Percutaneous Approach */
"0BN64ZZ" = "1" /* Release Right Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BN67ZZ" = "1" /* Release Right Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BN68ZZ" = "1" /* Release Right Lower Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BN70ZZ" = "1" /* Release Left Main Bronchus, Open Approach */
"0BN73ZZ" = "1" /* Release Left Main Bronchus, Percutaneous Approach */
"0BN74ZZ" = "1" /* Release Left Main Bronchus, Percutaneous Endoscopic Approach */
"0BN77ZZ" = "1" /* Release Left Main Bronchus, Via Natural or Artificial Opening */
"0BN78ZZ" = "1" /* Release Left Main Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BN80ZZ" = "1" /* Release Left Upper Lobe Bronchus, Open Approach */
"0BN83ZZ" = "1" /* Release Left Upper Lobe Bronchus, Percutaneous Approach */
"0BN84ZZ" = "1" /* Release Left Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BN87ZZ" = "1" /* Release Left Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BN88ZZ" = "1" /* Release Left Upper Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BN90ZZ" = "1" /* Release Lingula Bronchus, Open Approach */
"0BN93ZZ" = "1" /* Release Lingula Bronchus, Percutaneous Approach */
"0BN94ZZ" = "1" /* Release Lingula Bronchus, Percutaneous Endoscopic Approach */
"0BN97ZZ" = "1" /* Release Lingula Bronchus, Via Natural or Artificial Opening */
"0BN98ZZ" = "1" /* Release Lingula Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BNB0ZZ" = "1" /* Release Left Lower Lobe Bronchus, Open Approach */
"0BNB3ZZ" = "1" /* Release Left Lower Lobe Bronchus, Percutaneous Approach */
"0BNB4ZZ" = "1" /* Release Left Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BNB7ZZ" = "1" /* Release Left Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BNB8ZZ" = "1" /* Release Left Lower Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BNC0ZZ" = "1" /* Release Right Upper Lung Lobe, Open Approach */
"0BNC3ZZ" = "1" /* Release Right Upper Lung Lobe, Percutaneous Approach */
"0BNC4ZZ" = "1" /* Release Right Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BNC7ZZ" = "1" /* Release Right Upper Lung Lobe, Via Natural or Artificial Opening */
"0BNC8ZZ" = "1" /* Release Right Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BND0ZZ" = "1" /* Release Right Middle Lung Lobe, Open Approach */
"0BND3ZZ" = "1" /* Release Right Middle Lung Lobe, Percutaneous Approach */
"0BND4ZZ" = "1" /* Release Right Middle Lung Lobe, Percutaneous Endoscopic Approach */
"0BND7ZZ" = "1" /* Release Right Middle Lung Lobe, Via Natural or Artificial Opening */
"0BND8ZZ" = "1" /* Release Right Middle Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BNF0ZZ" = "1" /* Release Right Lower Lung Lobe, Open Approach */
"0BNF3ZZ" = "1" /* Release Right Lower Lung Lobe, Percutaneous Approach */
"0BNF4ZZ" = "1" /* Release Right Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BNF7ZZ" = "1" /* Release Right Lower Lung Lobe, Via Natural or Artificial Opening */
"0BNF8ZZ" = "1" /* Release Right Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BNG0ZZ" = "1" /* Release Left Upper Lung Lobe, Open Approach */
"0BNG3ZZ" = "1" /* Release Left Upper Lung Lobe, Percutaneous Approach */
"0BNG4ZZ" = "1" /* Release Left Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BNG7ZZ" = "1" /* Release Left Upper Lung Lobe, Via Natural or Artificial Opening */
"0BNG8ZZ" = "1" /* Release Left Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BNH0ZZ" = "1" /* Release Lung Lingula, Open Approach */
"0BNH3ZZ" = "1" /* Release Lung Lingula, Percutaneous Approach */
"0BNH4ZZ" = "1" /* Release Lung Lingula, Percutaneous Endoscopic Approach */
"0BNH7ZZ" = "1" /* Release Lung Lingula, Via Natural or Artificial Opening */
"0BNH8ZZ" = "1" /* Release Lung Lingula, Via Natural or Artificial Opening Endoscopic */
"0BNJ0ZZ" = "1" /* Release Left Lower Lung Lobe, Open Approach */
"0BNJ3ZZ" = "1" /* Release Left Lower Lung Lobe, Percutaneous Approach */
"0BNJ4ZZ" = "1" /* Release Left Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BNJ7ZZ" = "1" /* Release Left Lower Lung Lobe, Via Natural or Artificial Opening */
"0BNJ8ZZ" = "1" /* Release Left Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BNK0ZZ" = "1" /* Release Right Lung, Open Approach */
"0BNK3ZZ" = "1" /* Release Right Lung, Percutaneous Approach */
"0BNK4ZZ" = "1" /* Release Right Lung, Percutaneous Endoscopic Approach */
"0BNK7ZZ" = "1" /* Release Right Lung, Via Natural or Artificial Opening */
"0BNK8ZZ" = "1" /* Release Right Lung, Via Natural or Artificial Opening Endoscopic */
"0BNL0ZZ" = "1" /* Release Left Lung, Open Approach */
"0BNL3ZZ" = "1" /* Release Left Lung, Percutaneous Approach */
"0BNL4ZZ" = "1" /* Release Left Lung, Percutaneous Endoscopic Approach */
"0BNL7ZZ" = "1" /* Release Left Lung, Via Natural or Artificial Opening */
"0BNL8ZZ" = "1" /* Release Left Lung, Via Natural or Artificial Opening Endoscopic */
"0BNM0ZZ" = "1" /* Release Bilateral Lungs, Open Approach */
"0BNM3ZZ" = "1" /* Release Bilateral Lungs, Percutaneous Approach */
"0BNM4ZZ" = "1" /* Release Bilateral Lungs, Percutaneous Endoscopic Approach */
"0BNM7ZZ" = "1" /* Release Bilateral Lungs, Via Natural or Artificial Opening */
"0BNM8ZZ" = "1" /* Release Bilateral Lungs, Via Natural or Artificial Opening Endoscopic */
"0BNN0ZZ" = "1" /* Release Right Pleura, Open Approach */
"0BNN3ZZ" = "1" /* Release Right Pleura, Percutaneous Approach */
"0BNN4ZZ" = "1" /* Release Right Pleura, Percutaneous Endoscopic Approach */
"0BNP0ZZ" = "1" /* Release Left Pleura, Open Approach */
"0BNP3ZZ" = "1" /* Release Left Pleura, Percutaneous Approach */
"0BNP4ZZ" = "1" /* Release Left Pleura, Percutaneous Endoscopic Approach */
"0BNR0ZZ" = "1" /* Release Right Diaphragm, Open Approach */
"0BNR3ZZ" = "1" /* Release Right Diaphragm, Percutaneous Approach */
"0BNR4ZZ" = "1" /* Release Right Diaphragm, Percutaneous Endoscopic Approach */
"0BNS0ZZ" = "1" /* Release Left Diaphragm, Open Approach */
"0BNS3ZZ" = "1" /* Release Left Diaphragm, Percutaneous Approach */
"0BNS4ZZ" = "1" /* Release Left Diaphragm, Percutaneous Endoscopic Approach */
"0BP000Z" = "1" /* Removal of Drainage Device from Tracheobronchial Tree, Open Approach */
"0BP001Z" = "1" /* Removal of Radioactive Element from Tracheobronchial Tree, Open Approach */
"0BP002Z" = "1" /* Removal of Monitoring Device from Tracheobronchial Tree, Open Approach */
"0BP003Z" = "1" /* Removal of Infusion Device from Tracheobronchial Tree, Open Approach */
"0BP007Z" = "1" /* Removal of Autologous Tissue Substitute from Tracheobronchial Tree, Open Approach */
"0BP00CZ" = "1" /* Removal of Extraluminal Device from Tracheobronchial Tree, Open Approach */
"0BP00DZ" = "1" /* Removal of Intraluminal Device from Tracheobronchial Tree, Open Approach */
"0BP00JZ" = "1" /* Removal of Synthetic Substitute from Tracheobronchial Tree, Open Approach */
"0BP00KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Tracheobronchial Tree, Open Approach */
"0BP030Z" = "1" /* Removal of Drainage Device from Tracheobronchial Tree, Percutaneous Approach */
"0BP031Z" = "1" /* Removal of Radioactive Element from Tracheobronchial Tree, Percutaneous Approach */
"0BP032Z" = "1" /* Removal of Monitoring Device from Tracheobronchial Tree, Percutaneous Approach */
"0BP033Z" = "1" /* Removal of Infusion Device from Tracheobronchial Tree, Percutaneous Approach */
"0BP037Z" = "1" /* Removal of Autologous Tissue Substitute from Tracheobronchial Tree, Percutaneous Approach */
"0BP03CZ" = "1" /* Removal of Extraluminal Device from Tracheobronchial Tree, Percutaneous Approach */
"0BP03DZ" = "1" /* Removal of Intraluminal Device from Tracheobronchial Tree, Percutaneous Approach */
"0BP03JZ" = "1" /* Removal of Synthetic Substitute from Tracheobronchial Tree, Percutaneous Approach */
"0BP03KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Tracheobronchial Tree, Percutaneous Approach */
"0BP040Z" = "1" /* Removal of Drainage Device from Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BP041Z" = "1" /* Removal of Radioactive Element from Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BP042Z" = "1" /* Removal of Monitoring Device from Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BP043Z" = "1" /* Removal of Infusion Device from Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BP047Z" = "1" /* Removal of Autologous Tissue Substitute from Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BP04CZ" = "1" /* Removal of Extraluminal Device from Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BP04DZ" = "1" /* Removal of Intraluminal Device from Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BP04JZ" = "1" /* Removal of Synthetic Substitute from Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BP04KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BP071Z" = "1" /* Removal of Radioactive Element from Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BP077Z" = "1" /* Removal of Autologous Tissue Substitute from Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BP07CZ" = "1" /* Removal of Extraluminal Device from Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BP07JZ" = "1" /* Removal of Synthetic Substitute from Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BP07KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BP081Z" = "1" /* Removal of Radioactive Element from Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BP087Z" = "1" /* Removal of Autologous Tissue Substitute from Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BP08CZ" = "1" /* Removal of Extraluminal Device from Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BP08JZ" = "1" /* Removal of Synthetic Substitute from Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BP08KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BP100Z" = "1" /* Removal of Drainage Device from Trachea, Open Approach */
"0BP102Z" = "1" /* Removal of Monitoring Device from Trachea, Open Approach */
"0BP107Z" = "1" /* Removal of Autologous Tissue Substitute from Trachea, Open Approach */
"0BP10CZ" = "1" /* Removal of Extraluminal Device from Trachea, Open Approach */
"0BP10DZ" = "1" /* Removal of Intraluminal Device from Trachea, Open Approach */
"0BP10FZ" = "1" /* Removal of Tracheostomy Device from Trachea, Open Approach */
"0BP10JZ" = "1" /* Removal of Synthetic Substitute from Trachea, Open Approach */
"0BP10KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Trachea, Open Approach */
"0BP130Z" = "1" /* Removal of Drainage Device from Trachea, Percutaneous Approach */
"0BP132Z" = "1" /* Removal of Monitoring Device from Trachea, Percutaneous Approach */
"0BP137Z" = "1" /* Removal of Autologous Tissue Substitute from Trachea, Percutaneous Approach */
"0BP13CZ" = "1" /* Removal of Extraluminal Device from Trachea, Percutaneous Approach */
"0BP13DZ" = "1" /* Removal of Intraluminal Device from Trachea, Percutaneous Approach */
"0BP13JZ" = "1" /* Removal of Synthetic Substitute from Trachea, Percutaneous Approach */
"0BP13KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Trachea, Percutaneous Approach */
"0BP140Z" = "1" /* Removal of Drainage Device from Trachea, Percutaneous Endoscopic Approach */
"0BP142Z" = "1" /* Removal of Monitoring Device from Trachea, Percutaneous Endoscopic Approach */
"0BP147Z" = "1" /* Removal of Autologous Tissue Substitute from Trachea, Percutaneous Endoscopic Approach */
"0BP14CZ" = "1" /* Removal of Extraluminal Device from Trachea, Percutaneous Endoscopic Approach */
"0BP14DZ" = "1" /* Removal of Intraluminal Device from Trachea, Percutaneous Endoscopic Approach */
"0BP14FZ" = "1" /* Removal of Tracheostomy Device from Trachea, Percutaneous Endoscopic Approach */
"0BP14JZ" = "1" /* Removal of Synthetic Substitute from Trachea, Percutaneous Endoscopic Approach */
"0BP14KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Trachea, Percutaneous Endoscopic Approach */
"0BP177Z" = "1" /* Removal of Autologous Tissue Substitute from Trachea, Via Natural or Artificial Opening */
"0BP17CZ" = "1" /* Removal of Extraluminal Device from Trachea, Via Natural or Artificial Opening */
"0BP17JZ" = "1" /* Removal of Synthetic Substitute from Trachea, Via Natural or Artificial Opening */
"0BP17KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Trachea, Via Natural or Artificial Opening */
"0BP187Z" = "1" /* Removal of Autologous Tissue Substitute from Trachea, Via Natural or Artificial Opening Endoscopic */
"0BP18CZ" = "1" /* Removal of Extraluminal Device from Trachea, Via Natural or Artificial Opening Endoscopic */
"0BP18JZ" = "1" /* Removal of Synthetic Substitute from Trachea, Via Natural or Artificial Opening Endoscopic */
"0BP18KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Trachea, Via Natural or Artificial Opening Endoscopic */
"0BPK00Z" = "1" /* Removal of Drainage Device from Right Lung, Open Approach */
"0BPK01Z" = "1" /* Removal of Radioactive Element from Right Lung, Open Approach */
"0BPK02Z" = "1" /* Removal of Monitoring Device from Right Lung, Open Approach */
"0BPK03Z" = "1" /* Removal of Infusion Device from Right Lung, Open Approach */
"0BPK30Z" = "1" /* Removal of Drainage Device from Right Lung, Percutaneous Approach */
"0BPK31Z" = "1" /* Removal of Radioactive Element from Right Lung, Percutaneous Approach */
"0BPK32Z" = "1" /* Removal of Monitoring Device from Right Lung, Percutaneous Approach */
"0BPK33Z" = "1" /* Removal of Infusion Device from Right Lung, Percutaneous Approach */
"0BPK40Z" = "1" /* Removal of Drainage Device from Right Lung, Percutaneous Endoscopic Approach */
"0BPK41Z" = "1" /* Removal of Radioactive Element from Right Lung, Percutaneous Endoscopic Approach */
"0BPK42Z" = "1" /* Removal of Monitoring Device from Right Lung, Percutaneous Endoscopic Approach */
"0BPK43Z" = "1" /* Removal of Infusion Device from Right Lung, Percutaneous Endoscopic Approach */
"0BPK71Z" = "1" /* Removal of Radioactive Element from Right Lung, Via Natural or Artificial Opening */
"0BPK81Z" = "1" /* Removal of Radioactive Element from Right Lung, Via Natural or Artificial Opening Endoscopic */
"0BPL00Z" = "1" /* Removal of Drainage Device from Left Lung, Open Approach */
"0BPL01Z" = "1" /* Removal of Radioactive Element from Left Lung, Open Approach */
"0BPL02Z" = "1" /* Removal of Monitoring Device from Left Lung, Open Approach */
"0BPL03Z" = "1" /* Removal of Infusion Device from Left Lung, Open Approach */
"0BPL30Z" = "1" /* Removal of Drainage Device from Left Lung, Percutaneous Approach */
"0BPL31Z" = "1" /* Removal of Radioactive Element from Left Lung, Percutaneous Approach */
"0BPL32Z" = "1" /* Removal of Monitoring Device from Left Lung, Percutaneous Approach */
"0BPL33Z" = "1" /* Removal of Infusion Device from Left Lung, Percutaneous Approach */
"0BPL40Z" = "1" /* Removal of Drainage Device from Left Lung, Percutaneous Endoscopic Approach */
"0BPL41Z" = "1" /* Removal of Radioactive Element from Left Lung, Percutaneous Endoscopic Approach */
"0BPL42Z" = "1" /* Removal of Monitoring Device from Left Lung, Percutaneous Endoscopic Approach */
"0BPL43Z" = "1" /* Removal of Infusion Device from Left Lung, Percutaneous Endoscopic Approach */
"0BPL71Z" = "1" /* Removal of Radioactive Element from Left Lung, Via Natural or Artificial Opening */
"0BPL81Z" = "1" /* Removal of Radioactive Element from Left Lung, Via Natural or Artificial Opening Endoscopic */
"0BPT00Z" = "1" /* Removal of Drainage Device from Diaphragm, Open Approach */
"0BPT02Z" = "1" /* Removal of Monitoring Device from Diaphragm, Open Approach */
"0BPT07Z" = "1" /* Removal of Autologous Tissue Substitute from Diaphragm, Open Approach */
"0BPT0JZ" = "1" /* Removal of Synthetic Substitute from Diaphragm, Open Approach */
"0BPT0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Diaphragm, Open Approach */
"0BPT0MZ" = "1" /* Removal of Diaphragmatic Pacemaker Lead from Diaphragm, Open Approach */
"0BPT30Z" = "1" /* Removal of Drainage Device from Diaphragm, Percutaneous Approach */
"0BPT32Z" = "1" /* Removal of Monitoring Device from Diaphragm, Percutaneous Approach */
"0BPT37Z" = "1" /* Removal of Autologous Tissue Substitute from Diaphragm, Percutaneous Approach */
"0BPT3JZ" = "1" /* Removal of Synthetic Substitute from Diaphragm, Percutaneous Approach */
"0BPT3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Diaphragm, Percutaneous Approach */
"0BPT3MZ" = "1" /* Removal of Diaphragmatic Pacemaker Lead from Diaphragm, Percutaneous Approach */
"0BPT40Z" = "1" /* Removal of Drainage Device from Diaphragm, Percutaneous Endoscopic Approach */
"0BPT42Z" = "1" /* Removal of Monitoring Device from Diaphragm, Percutaneous Endoscopic Approach */
"0BPT47Z" = "1" /* Removal of Autologous Tissue Substitute from Diaphragm, Percutaneous Endoscopic Approach */
"0BPT4JZ" = "1" /* Removal of Synthetic Substitute from Diaphragm, Percutaneous Endoscopic Approach */
"0BPT4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Diaphragm, Percutaneous Endoscopic Approach */
"0BPT4MZ" = "1" /* Removal of Diaphragmatic Pacemaker Lead from Diaphragm, Percutaneous Endoscopic Approach */
"0BPT77Z" = "1" /* Removal of Autologous Tissue Substitute from Diaphragm, Via Natural or Artificial Opening */
"0BPT7JZ" = "1" /* Removal of Synthetic Substitute from Diaphragm, Via Natural or Artificial Opening */
"0BPT7KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Diaphragm, Via Natural or Artificial Opening */
"0BPT7MZ" = "1" /* Removal of Diaphragmatic Pacemaker Lead from Diaphragm, Via Natural or Artificial Opening */
"0BPT87Z" = "1" /* Removal of Autologous Tissue Substitute from Diaphragm, Via Natural or Artificial Opening Endoscopic */
"0BPT8JZ" = "1" /* Removal of Synthetic Substitute from Diaphragm, Via Natural or Artificial Opening Endoscopic */
"0BPT8KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Diaphragm, Via Natural or Artificial Opening Endoscopic */
"0BPT8MZ" = "1" /* Removal of Diaphragmatic Pacemaker Lead from Diaphragm, Via Natural or Artificial Opening Endoscopic */
"0BQ10ZZ" = "1" /* Repair Trachea, Open Approach */
"0BQ13ZZ" = "1" /* Repair Trachea, Percutaneous Approach */
"0BQ14ZZ" = "1" /* Repair Trachea, Percutaneous Endoscopic Approach */
"0BQ17ZZ" = "1" /* Repair Trachea, Via Natural or Artificial Opening */
"0BQ18ZZ" = "1" /* Repair Trachea, Via Natural or Artificial Opening Endoscopic */
"0BQ20ZZ" = "1" /* Repair Carina, Open Approach */
"0BQ23ZZ" = "1" /* Repair Carina, Percutaneous Approach */
"0BQ24ZZ" = "1" /* Repair Carina, Percutaneous Endoscopic Approach */
"0BQ27ZZ" = "1" /* Repair Carina, Via Natural or Artificial Opening */
"0BQ28ZZ" = "1" /* Repair Carina, Via Natural or Artificial Opening Endoscopic */
"0BQ30ZZ" = "1" /* Repair Right Main Bronchus, Open Approach */
"0BQ33ZZ" = "1" /* Repair Right Main Bronchus, Percutaneous Approach */
"0BQ34ZZ" = "1" /* Repair Right Main Bronchus, Percutaneous Endoscopic Approach */
"0BQ37ZZ" = "1" /* Repair Right Main Bronchus, Via Natural or Artificial Opening */
"0BQ38ZZ" = "1" /* Repair Right Main Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BQ40ZZ" = "1" /* Repair Right Upper Lobe Bronchus, Open Approach */
"0BQ43ZZ" = "1" /* Repair Right Upper Lobe Bronchus, Percutaneous Approach */
"0BQ44ZZ" = "1" /* Repair Right Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BQ47ZZ" = "1" /* Repair Right Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BQ48ZZ" = "1" /* Repair Right Upper Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BQ50ZZ" = "1" /* Repair Right Middle Lobe Bronchus, Open Approach */
"0BQ53ZZ" = "1" /* Repair Right Middle Lobe Bronchus, Percutaneous Approach */
"0BQ54ZZ" = "1" /* Repair Right Middle Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BQ57ZZ" = "1" /* Repair Right Middle Lobe Bronchus, Via Natural or Artificial Opening */
"0BQ58ZZ" = "1" /* Repair Right Middle Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BQ60ZZ" = "1" /* Repair Right Lower Lobe Bronchus, Open Approach */
"0BQ63ZZ" = "1" /* Repair Right Lower Lobe Bronchus, Percutaneous Approach */
"0BQ64ZZ" = "1" /* Repair Right Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BQ67ZZ" = "1" /* Repair Right Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BQ68ZZ" = "1" /* Repair Right Lower Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BQ70ZZ" = "1" /* Repair Left Main Bronchus, Open Approach */
"0BQ73ZZ" = "1" /* Repair Left Main Bronchus, Percutaneous Approach */
"0BQ74ZZ" = "1" /* Repair Left Main Bronchus, Percutaneous Endoscopic Approach */
"0BQ77ZZ" = "1" /* Repair Left Main Bronchus, Via Natural or Artificial Opening */
"0BQ78ZZ" = "1" /* Repair Left Main Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BQ80ZZ" = "1" /* Repair Left Upper Lobe Bronchus, Open Approach */
"0BQ83ZZ" = "1" /* Repair Left Upper Lobe Bronchus, Percutaneous Approach */
"0BQ84ZZ" = "1" /* Repair Left Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BQ87ZZ" = "1" /* Repair Left Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BQ88ZZ" = "1" /* Repair Left Upper Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BQ90ZZ" = "1" /* Repair Lingula Bronchus, Open Approach */
"0BQ93ZZ" = "1" /* Repair Lingula Bronchus, Percutaneous Approach */
"0BQ94ZZ" = "1" /* Repair Lingula Bronchus, Percutaneous Endoscopic Approach */
"0BQ97ZZ" = "1" /* Repair Lingula Bronchus, Via Natural or Artificial Opening */
"0BQ98ZZ" = "1" /* Repair Lingula Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BQB0ZZ" = "1" /* Repair Left Lower Lobe Bronchus, Open Approach */
"0BQB3ZZ" = "1" /* Repair Left Lower Lobe Bronchus, Percutaneous Approach */
"0BQB4ZZ" = "1" /* Repair Left Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BQB7ZZ" = "1" /* Repair Left Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BQB8ZZ" = "1" /* Repair Left Lower Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BQC0ZZ" = "1" /* Repair Right Upper Lung Lobe, Open Approach */
"0BQC3ZZ" = "1" /* Repair Right Upper Lung Lobe, Percutaneous Approach */
"0BQC4ZZ" = "1" /* Repair Right Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BQC7ZZ" = "1" /* Repair Right Upper Lung Lobe, Via Natural or Artificial Opening */
"0BQC8ZZ" = "1" /* Repair Right Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BQD0ZZ" = "1" /* Repair Right Middle Lung Lobe, Open Approach */
"0BQD3ZZ" = "1" /* Repair Right Middle Lung Lobe, Percutaneous Approach */
"0BQD4ZZ" = "1" /* Repair Right Middle Lung Lobe, Percutaneous Endoscopic Approach */
"0BQD7ZZ" = "1" /* Repair Right Middle Lung Lobe, Via Natural or Artificial Opening */
"0BQD8ZZ" = "1" /* Repair Right Middle Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BQF0ZZ" = "1" /* Repair Right Lower Lung Lobe, Open Approach */
"0BQF3ZZ" = "1" /* Repair Right Lower Lung Lobe, Percutaneous Approach */
"0BQF4ZZ" = "1" /* Repair Right Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BQF7ZZ" = "1" /* Repair Right Lower Lung Lobe, Via Natural or Artificial Opening */
"0BQF8ZZ" = "1" /* Repair Right Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BQG0ZZ" = "1" /* Repair Left Upper Lung Lobe, Open Approach */
"0BQG3ZZ" = "1" /* Repair Left Upper Lung Lobe, Percutaneous Approach */
"0BQG4ZZ" = "1" /* Repair Left Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BQG7ZZ" = "1" /* Repair Left Upper Lung Lobe, Via Natural or Artificial Opening */
"0BQG8ZZ" = "1" /* Repair Left Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BQH0ZZ" = "1" /* Repair Lung Lingula, Open Approach */
"0BQH3ZZ" = "1" /* Repair Lung Lingula, Percutaneous Approach */
"0BQH4ZZ" = "1" /* Repair Lung Lingula, Percutaneous Endoscopic Approach */
"0BQH7ZZ" = "1" /* Repair Lung Lingula, Via Natural or Artificial Opening */
"0BQH8ZZ" = "1" /* Repair Lung Lingula, Via Natural or Artificial Opening Endoscopic */
"0BQJ0ZZ" = "1" /* Repair Left Lower Lung Lobe, Open Approach */
"0BQJ3ZZ" = "1" /* Repair Left Lower Lung Lobe, Percutaneous Approach */
"0BQJ4ZZ" = "1" /* Repair Left Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BQJ7ZZ" = "1" /* Repair Left Lower Lung Lobe, Via Natural or Artificial Opening */
"0BQJ8ZZ" = "1" /* Repair Left Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BQK0ZZ" = "1" /* Repair Right Lung, Open Approach */
"0BQK3ZZ" = "1" /* Repair Right Lung, Percutaneous Approach */
"0BQK4ZZ" = "1" /* Repair Right Lung, Percutaneous Endoscopic Approach */
"0BQK7ZZ" = "1" /* Repair Right Lung, Via Natural or Artificial Opening */
"0BQK8ZZ" = "1" /* Repair Right Lung, Via Natural or Artificial Opening Endoscopic */
"0BQL0ZZ" = "1" /* Repair Left Lung, Open Approach */
"0BQL3ZZ" = "1" /* Repair Left Lung, Percutaneous Approach */
"0BQL4ZZ" = "1" /* Repair Left Lung, Percutaneous Endoscopic Approach */
"0BQL7ZZ" = "1" /* Repair Left Lung, Via Natural or Artificial Opening */
"0BQL8ZZ" = "1" /* Repair Left Lung, Via Natural or Artificial Opening Endoscopic */
"0BQM0ZZ" = "1" /* Repair Bilateral Lungs, Open Approach */
"0BQM3ZZ" = "1" /* Repair Bilateral Lungs, Percutaneous Approach */
"0BQM4ZZ" = "1" /* Repair Bilateral Lungs, Percutaneous Endoscopic Approach */
"0BQM7ZZ" = "1" /* Repair Bilateral Lungs, Via Natural or Artificial Opening */
"0BQM8ZZ" = "1" /* Repair Bilateral Lungs, Via Natural or Artificial Opening Endoscopic */
"0BQN0ZZ" = "1" /* Repair Right Pleura, Open Approach */
"0BQN3ZZ" = "1" /* Repair Right Pleura, Percutaneous Approach */
"0BQN4ZZ" = "1" /* Repair Right Pleura, Percutaneous Endoscopic Approach */
"0BQP0ZZ" = "1" /* Repair Left Pleura, Open Approach */
"0BQP3ZZ" = "1" /* Repair Left Pleura, Percutaneous Approach */
"0BQP4ZZ" = "1" /* Repair Left Pleura, Percutaneous Endoscopic Approach */
"0BQR0ZZ" = "1" /* Repair Right Diaphragm, Open Approach */
"0BQR3ZZ" = "1" /* Repair Right Diaphragm, Percutaneous Approach */
"0BQR4ZZ" = "1" /* Repair Right Diaphragm, Percutaneous Endoscopic Approach */
"0BQS0ZZ" = "1" /* Repair Left Diaphragm, Open Approach */
"0BQS3ZZ" = "1" /* Repair Left Diaphragm, Percutaneous Approach */
"0BQS4ZZ" = "1" /* Repair Left Diaphragm, Percutaneous Endoscopic Approach */
"0BS10ZZ" = "1" /* Reposition Trachea, Open Approach */
"0BS20ZZ" = "1" /* Reposition Carina, Open Approach */
"0BS30ZZ" = "1" /* Reposition Right Main Bronchus, Open Approach */
"0BS40ZZ" = "1" /* Reposition Right Upper Lobe Bronchus, Open Approach */
"0BS50ZZ" = "1" /* Reposition Right Middle Lobe Bronchus, Open Approach */
"0BS60ZZ" = "1" /* Reposition Right Lower Lobe Bronchus, Open Approach */
"0BS70ZZ" = "1" /* Reposition Left Main Bronchus, Open Approach */
"0BS80ZZ" = "1" /* Reposition Left Upper Lobe Bronchus, Open Approach */
"0BS90ZZ" = "1" /* Reposition Lingula Bronchus, Open Approach */
"0BSB0ZZ" = "1" /* Reposition Left Lower Lobe Bronchus, Open Approach */
"0BSC0ZZ" = "1" /* Reposition Right Upper Lung Lobe, Open Approach */
"0BSD0ZZ" = "1" /* Reposition Right Middle Lung Lobe, Open Approach */
"0BSF0ZZ" = "1" /* Reposition Right Lower Lung Lobe, Open Approach */
"0BSG0ZZ" = "1" /* Reposition Left Upper Lung Lobe, Open Approach */
"0BSH0ZZ" = "1" /* Reposition Lung Lingula, Open Approach */
"0BSJ0ZZ" = "1" /* Reposition Left Lower Lung Lobe, Open Approach */
"0BSK0ZZ" = "1" /* Reposition Right Lung, Open Approach */
"0BSL0ZZ" = "1" /* Reposition Left Lung, Open Approach */
"0BSR0ZZ" = "1" /* Reposition Right Diaphragm, Open Approach */
"0BSS0ZZ" = "1" /* Reposition Left Diaphragm, Open Approach */
"0BT10ZZ" = "1" /* Resection of Trachea, Open Approach */
"0BT14ZZ" = "1" /* Resection of Trachea, Percutaneous Endoscopic Approach */
"0BT20ZZ" = "1" /* Resection of Carina, Open Approach */
"0BT24ZZ" = "1" /* Resection of Carina, Percutaneous Endoscopic Approach */
"0BT30ZZ" = "1" /* Resection of Right Main Bronchus, Open Approach */
"0BT34ZZ" = "1" /* Resection of Right Main Bronchus, Percutaneous Endoscopic Approach */
"0BT40ZZ" = "1" /* Resection of Right Upper Lobe Bronchus, Open Approach */
"0BT44ZZ" = "1" /* Resection of Right Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BT50ZZ" = "1" /* Resection of Right Middle Lobe Bronchus, Open Approach */
"0BT54ZZ" = "1" /* Resection of Right Middle Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BT60ZZ" = "1" /* Resection of Right Lower Lobe Bronchus, Open Approach */
"0BT64ZZ" = "1" /* Resection of Right Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BT70ZZ" = "1" /* Resection of Left Main Bronchus, Open Approach */
"0BT74ZZ" = "1" /* Resection of Left Main Bronchus, Percutaneous Endoscopic Approach */
"0BT80ZZ" = "1" /* Resection of Left Upper Lobe Bronchus, Open Approach */
"0BT84ZZ" = "1" /* Resection of Left Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BT90ZZ" = "1" /* Resection of Lingula Bronchus, Open Approach */
"0BT94ZZ" = "1" /* Resection of Lingula Bronchus, Percutaneous Endoscopic Approach */
"0BTB0ZZ" = "1" /* Resection of Left Lower Lobe Bronchus, Open Approach */
"0BTB4ZZ" = "1" /* Resection of Left Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BTC0ZZ" = "1" /* Resection of Right Upper Lung Lobe, Open Approach */
"0BTC4ZZ" = "1" /* Resection of Right Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BTD0ZZ" = "1" /* Resection of Right Middle Lung Lobe, Open Approach */
"0BTD4ZZ" = "1" /* Resection of Right Middle Lung Lobe, Percutaneous Endoscopic Approach */
"0BTF0ZZ" = "1" /* Resection of Right Lower Lung Lobe, Open Approach */
"0BTF4ZZ" = "1" /* Resection of Right Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BTG0ZZ" = "1" /* Resection of Left Upper Lung Lobe, Open Approach */
"0BTG4ZZ" = "1" /* Resection of Left Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BTH0ZZ" = "1" /* Resection of Lung Lingula, Open Approach */
"0BTH4ZZ" = "1" /* Resection of Lung Lingula, Percutaneous Endoscopic Approach */
"0BTJ0ZZ" = "1" /* Resection of Left Lower Lung Lobe, Open Approach */
"0BTJ4ZZ" = "1" /* Resection of Left Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BTK0ZZ" = "1" /* Resection of Right Lung, Open Approach */
"0BTK4ZZ" = "1" /* Resection of Right Lung, Percutaneous Endoscopic Approach */
"0BTL0ZZ" = "1" /* Resection of Left Lung, Open Approach */
"0BTL4ZZ" = "1" /* Resection of Left Lung, Percutaneous Endoscopic Approach */
"0BTM0ZZ" = "1" /* Resection of Bilateral Lungs, Open Approach */
"0BTM4ZZ" = "1" /* Resection of Bilateral Lungs, Percutaneous Endoscopic Approach */
"0BTR0ZZ" = "1" /* Resection of Right Diaphragm, Open Approach */
"0BTR4ZZ" = "1" /* Resection of Right Diaphragm, Percutaneous Endoscopic Approach */
"0BTS0ZZ" = "1" /* Resection of Left Diaphragm, Open Approach */
"0BTS4ZZ" = "1" /* Resection of Left Diaphragm, Percutaneous Endoscopic Approach */
"0BU107Z" = "1" /* Supplement Trachea with Autologous Tissue Substitute, Open Approach */
"0BU10JZ" = "1" /* Supplement Trachea with Synthetic Substitute, Open Approach */
"0BU10KZ" = "1" /* Supplement Trachea with Nonautologous Tissue Substitute, Open Approach */
"0BU147Z" = "1" /* Supplement Trachea with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU14JZ" = "1" /* Supplement Trachea with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BU14KZ" = "1" /* Supplement Trachea with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU207Z" = "1" /* Supplement Carina with Autologous Tissue Substitute, Open Approach */
"0BU20JZ" = "1" /* Supplement Carina with Synthetic Substitute, Open Approach */
"0BU20KZ" = "1" /* Supplement Carina with Nonautologous Tissue Substitute, Open Approach */
"0BU247Z" = "1" /* Supplement Carina with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU24JZ" = "1" /* Supplement Carina with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BU24KZ" = "1" /* Supplement Carina with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU307Z" = "1" /* Supplement Right Main Bronchus with Autologous Tissue Substitute, Open Approach */
"0BU30JZ" = "1" /* Supplement Right Main Bronchus with Synthetic Substitute, Open Approach */
"0BU30KZ" = "1" /* Supplement Right Main Bronchus with Nonautologous Tissue Substitute, Open Approach */
"0BU347Z" = "1" /* Supplement Right Main Bronchus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU34JZ" = "1" /* Supplement Right Main Bronchus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BU34KZ" = "1" /* Supplement Right Main Bronchus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU407Z" = "1" /* Supplement Right Upper Lobe Bronchus with Autologous Tissue Substitute, Open Approach */
"0BU40JZ" = "1" /* Supplement Right Upper Lobe Bronchus with Synthetic Substitute, Open Approach */
"0BU40KZ" = "1" /* Supplement Right Upper Lobe Bronchus with Nonautologous Tissue Substitute, Open Approach */
"0BU447Z" = "1" /* Supplement Right Upper Lobe Bronchus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU44JZ" = "1" /* Supplement Right Upper Lobe Bronchus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BU44KZ" = "1" /* Supplement Right Upper Lobe Bronchus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU507Z" = "1" /* Supplement Right Middle Lobe Bronchus with Autologous Tissue Substitute, Open Approach */
"0BU50JZ" = "1" /* Supplement Right Middle Lobe Bronchus with Synthetic Substitute, Open Approach */
"0BU50KZ" = "1" /* Supplement Right Middle Lobe Bronchus with Nonautologous Tissue Substitute, Open Approach */
"0BU547Z" = "1" /* Supplement Right Middle Lobe Bronchus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU54JZ" = "1" /* Supplement Right Middle Lobe Bronchus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BU54KZ" = "1" /* Supplement Right Middle Lobe Bronchus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU607Z" = "1" /* Supplement Right Lower Lobe Bronchus with Autologous Tissue Substitute, Open Approach */
"0BU60JZ" = "1" /* Supplement Right Lower Lobe Bronchus with Synthetic Substitute, Open Approach */
"0BU60KZ" = "1" /* Supplement Right Lower Lobe Bronchus with Nonautologous Tissue Substitute, Open Approach */
"0BU647Z" = "1" /* Supplement Right Lower Lobe Bronchus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU64JZ" = "1" /* Supplement Right Lower Lobe Bronchus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BU64KZ" = "1" /* Supplement Right Lower Lobe Bronchus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU707Z" = "1" /* Supplement Left Main Bronchus with Autologous Tissue Substitute, Open Approach */
"0BU70JZ" = "1" /* Supplement Left Main Bronchus with Synthetic Substitute, Open Approach */
"0BU70KZ" = "1" /* Supplement Left Main Bronchus with Nonautologous Tissue Substitute, Open Approach */
"0BU747Z" = "1" /* Supplement Left Main Bronchus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU74JZ" = "1" /* Supplement Left Main Bronchus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BU74KZ" = "1" /* Supplement Left Main Bronchus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU807Z" = "1" /* Supplement Left Upper Lobe Bronchus with Autologous Tissue Substitute, Open Approach */
"0BU80JZ" = "1" /* Supplement Left Upper Lobe Bronchus with Synthetic Substitute, Open Approach */
"0BU80KZ" = "1" /* Supplement Left Upper Lobe Bronchus with Nonautologous Tissue Substitute, Open Approach */
"0BU847Z" = "1" /* Supplement Left Upper Lobe Bronchus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU84JZ" = "1" /* Supplement Left Upper Lobe Bronchus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BU84KZ" = "1" /* Supplement Left Upper Lobe Bronchus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU907Z" = "1" /* Supplement Lingula Bronchus with Autologous Tissue Substitute, Open Approach */
"0BU90JZ" = "1" /* Supplement Lingula Bronchus with Synthetic Substitute, Open Approach */
"0BU90KZ" = "1" /* Supplement Lingula Bronchus with Nonautologous Tissue Substitute, Open Approach */
"0BU947Z" = "1" /* Supplement Lingula Bronchus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU94JZ" = "1" /* Supplement Lingula Bronchus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BU94KZ" = "1" /* Supplement Lingula Bronchus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BUB07Z" = "1" /* Supplement Left Lower Lobe Bronchus with Autologous Tissue Substitute, Open Approach */
"0BUB0JZ" = "1" /* Supplement Left Lower Lobe Bronchus with Synthetic Substitute, Open Approach */
"0BUB0KZ" = "1" /* Supplement Left Lower Lobe Bronchus with Nonautologous Tissue Substitute, Open Approach */
"0BUB47Z" = "1" /* Supplement Left Lower Lobe Bronchus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BUB4JZ" = "1" /* Supplement Left Lower Lobe Bronchus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BUB4KZ" = "1" /* Supplement Left Lower Lobe Bronchus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BUR07Z" = "1" /* Supplement Right Diaphragm with Autologous Tissue Substitute, Open Approach */
"0BUR0JZ" = "1" /* Supplement Right Diaphragm with Synthetic Substitute, Open Approach */
"0BUR0KZ" = "1" /* Supplement Right Diaphragm with Nonautologous Tissue Substitute, Open Approach */
"0BUR47Z" = "1" /* Supplement Right Diaphragm with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BUR4JZ" = "1" /* Supplement Right Diaphragm with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BUR4KZ" = "1" /* Supplement Right Diaphragm with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BUS07Z" = "1" /* Supplement Left Diaphragm with Autologous Tissue Substitute, Open Approach */
"0BUS0JZ" = "1" /* Supplement Left Diaphragm with Synthetic Substitute, Open Approach */
"0BUS0KZ" = "1" /* Supplement Left Diaphragm with Nonautologous Tissue Substitute, Open Approach */
"0BUS47Z" = "1" /* Supplement Left Diaphragm with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BUS4JZ" = "1" /* Supplement Left Diaphragm with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BUS4KZ" = "1" /* Supplement Left Diaphragm with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BV10CZ" = "1" /* Restriction of Trachea with Extraluminal Device, Open Approach */
"0BV10DZ" = "1" /* Restriction of Trachea with Intraluminal Device, Open Approach */
"0BV10ZZ" = "1" /* Restriction of Trachea, Open Approach */
"0BV13CZ" = "1" /* Restriction of Trachea with Extraluminal Device, Percutaneous Approach */
"0BV13DZ" = "1" /* Restriction of Trachea with Intraluminal Device, Percutaneous Approach */
"0BV13ZZ" = "1" /* Restriction of Trachea, Percutaneous Approach */
"0BV14CZ" = "1" /* Restriction of Trachea with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BV14DZ" = "1" /* Restriction of Trachea with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BV14ZZ" = "1" /* Restriction of Trachea, Percutaneous Endoscopic Approach */
"0BV17DZ" = "1" /* Restriction of Trachea with Intraluminal Device, Via Natural or Artificial Opening */
"0BV17ZZ" = "1" /* Restriction of Trachea, Via Natural or Artificial Opening */
"0BV18DZ" = "1" /* Restriction of Trachea with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BV18ZZ" = "1" /* Restriction of Trachea, Via Natural or Artificial Opening Endoscopic */
"0BV20CZ" = "1" /* Restriction of Carina with Extraluminal Device, Open Approach */
"0BV20DZ" = "1" /* Restriction of Carina with Intraluminal Device, Open Approach */
"0BV20ZZ" = "1" /* Restriction of Carina, Open Approach */
"0BV23CZ" = "1" /* Restriction of Carina with Extraluminal Device, Percutaneous Approach */
"0BV23DZ" = "1" /* Restriction of Carina with Intraluminal Device, Percutaneous Approach */
"0BV23ZZ" = "1" /* Restriction of Carina, Percutaneous Approach */
"0BV24CZ" = "1" /* Restriction of Carina with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BV24DZ" = "1" /* Restriction of Carina with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BV24ZZ" = "1" /* Restriction of Carina, Percutaneous Endoscopic Approach */
"0BV27DZ" = "1" /* Restriction of Carina with Intraluminal Device, Via Natural or Artificial Opening */
"0BV27ZZ" = "1" /* Restriction of Carina, Via Natural or Artificial Opening */
"0BV28DZ" = "1" /* Restriction of Carina with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BV28ZZ" = "1" /* Restriction of Carina, Via Natural or Artificial Opening Endoscopic */
"0BV30CZ" = "1" /* Restriction of Right Main Bronchus with Extraluminal Device, Open Approach */
"0BV30DZ" = "1" /* Restriction of Right Main Bronchus with Intraluminal Device, Open Approach */
"0BV30ZZ" = "1" /* Restriction of Right Main Bronchus, Open Approach */
"0BV33CZ" = "1" /* Restriction of Right Main Bronchus with Extraluminal Device, Percutaneous Approach */
"0BV33DZ" = "1" /* Restriction of Right Main Bronchus with Intraluminal Device, Percutaneous Approach */
"0BV33ZZ" = "1" /* Restriction of Right Main Bronchus, Percutaneous Approach */
"0BV34CZ" = "1" /* Restriction of Right Main Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BV34DZ" = "1" /* Restriction of Right Main Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BV34ZZ" = "1" /* Restriction of Right Main Bronchus, Percutaneous Endoscopic Approach */
"0BV37DZ" = "1" /* Restriction of Right Main Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BV37ZZ" = "1" /* Restriction of Right Main Bronchus, Via Natural or Artificial Opening */
"0BV38DZ" = "1" /* Restriction of Right Main Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BV38ZZ" = "1" /* Restriction of Right Main Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BV40CZ" = "1" /* Restriction of Right Upper Lobe Bronchus with Extraluminal Device, Open Approach */
"0BV40DZ" = "1" /* Restriction of Right Upper Lobe Bronchus with Intraluminal Device, Open Approach */
"0BV40ZZ" = "1" /* Restriction of Right Upper Lobe Bronchus, Open Approach */
"0BV43CZ" = "1" /* Restriction of Right Upper Lobe Bronchus with Extraluminal Device, Percutaneous Approach */
"0BV43DZ" = "1" /* Restriction of Right Upper Lobe Bronchus with Intraluminal Device, Percutaneous Approach */
"0BV43ZZ" = "1" /* Restriction of Right Upper Lobe Bronchus, Percutaneous Approach */
"0BV44CZ" = "1" /* Restriction of Right Upper Lobe Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BV44DZ" = "1" /* Restriction of Right Upper Lobe Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BV44ZZ" = "1" /* Restriction of Right Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BV47DZ" = "1" /* Restriction of Right Upper Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BV47ZZ" = "1" /* Restriction of Right Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BV48DZ" = "1" /* Restriction of Right Upper Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BV48ZZ" = "1" /* Restriction of Right Upper Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BV50CZ" = "1" /* Restriction of Right Middle Lobe Bronchus with Extraluminal Device, Open Approach */
"0BV50DZ" = "1" /* Restriction of Right Middle Lobe Bronchus with Intraluminal Device, Open Approach */
"0BV50ZZ" = "1" /* Restriction of Right Middle Lobe Bronchus, Open Approach */
"0BV53CZ" = "1" /* Restriction of Right Middle Lobe Bronchus with Extraluminal Device, Percutaneous Approach */
"0BV53DZ" = "1" /* Restriction of Right Middle Lobe Bronchus with Intraluminal Device, Percutaneous Approach */
"0BV53ZZ" = "1" /* Restriction of Right Middle Lobe Bronchus, Percutaneous Approach */
"0BV54CZ" = "1" /* Restriction of Right Middle Lobe Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BV54DZ" = "1" /* Restriction of Right Middle Lobe Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BV54ZZ" = "1" /* Restriction of Right Middle Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BV57DZ" = "1" /* Restriction of Right Middle Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BV57ZZ" = "1" /* Restriction of Right Middle Lobe Bronchus, Via Natural or Artificial Opening */
"0BV58DZ" = "1" /* Restriction of Right Middle Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BV58ZZ" = "1" /* Restriction of Right Middle Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BV60CZ" = "1" /* Restriction of Right Lower Lobe Bronchus with Extraluminal Device, Open Approach */
"0BV60DZ" = "1" /* Restriction of Right Lower Lobe Bronchus with Intraluminal Device, Open Approach */
"0BV60ZZ" = "1" /* Restriction of Right Lower Lobe Bronchus, Open Approach */
"0BV63CZ" = "1" /* Restriction of Right Lower Lobe Bronchus with Extraluminal Device, Percutaneous Approach */
"0BV63DZ" = "1" /* Restriction of Right Lower Lobe Bronchus with Intraluminal Device, Percutaneous Approach */
"0BV63ZZ" = "1" /* Restriction of Right Lower Lobe Bronchus, Percutaneous Approach */
"0BV64CZ" = "1" /* Restriction of Right Lower Lobe Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BV64DZ" = "1" /* Restriction of Right Lower Lobe Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BV64ZZ" = "1" /* Restriction of Right Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BV67DZ" = "1" /* Restriction of Right Lower Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BV67ZZ" = "1" /* Restriction of Right Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BV68DZ" = "1" /* Restriction of Right Lower Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BV68ZZ" = "1" /* Restriction of Right Lower Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BV70CZ" = "1" /* Restriction of Left Main Bronchus with Extraluminal Device, Open Approach */
"0BV70DZ" = "1" /* Restriction of Left Main Bronchus with Intraluminal Device, Open Approach */
"0BV70ZZ" = "1" /* Restriction of Left Main Bronchus, Open Approach */
"0BV73CZ" = "1" /* Restriction of Left Main Bronchus with Extraluminal Device, Percutaneous Approach */
"0BV73DZ" = "1" /* Restriction of Left Main Bronchus with Intraluminal Device, Percutaneous Approach */
"0BV73ZZ" = "1" /* Restriction of Left Main Bronchus, Percutaneous Approach */
"0BV74CZ" = "1" /* Restriction of Left Main Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BV74DZ" = "1" /* Restriction of Left Main Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BV74ZZ" = "1" /* Restriction of Left Main Bronchus, Percutaneous Endoscopic Approach */
"0BV77DZ" = "1" /* Restriction of Left Main Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BV77ZZ" = "1" /* Restriction of Left Main Bronchus, Via Natural or Artificial Opening */
"0BV78DZ" = "1" /* Restriction of Left Main Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BV78ZZ" = "1" /* Restriction of Left Main Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BV80CZ" = "1" /* Restriction of Left Upper Lobe Bronchus with Extraluminal Device, Open Approach */
"0BV80DZ" = "1" /* Restriction of Left Upper Lobe Bronchus with Intraluminal Device, Open Approach */
"0BV80ZZ" = "1" /* Restriction of Left Upper Lobe Bronchus, Open Approach */
"0BV83CZ" = "1" /* Restriction of Left Upper Lobe Bronchus with Extraluminal Device, Percutaneous Approach */
"0BV83DZ" = "1" /* Restriction of Left Upper Lobe Bronchus with Intraluminal Device, Percutaneous Approach */
"0BV83ZZ" = "1" /* Restriction of Left Upper Lobe Bronchus, Percutaneous Approach */
"0BV84CZ" = "1" /* Restriction of Left Upper Lobe Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BV84DZ" = "1" /* Restriction of Left Upper Lobe Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BV84ZZ" = "1" /* Restriction of Left Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BV87DZ" = "1" /* Restriction of Left Upper Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BV87ZZ" = "1" /* Restriction of Left Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BV88DZ" = "1" /* Restriction of Left Upper Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BV88ZZ" = "1" /* Restriction of Left Upper Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BV90CZ" = "1" /* Restriction of Lingula Bronchus with Extraluminal Device, Open Approach */
"0BV90DZ" = "1" /* Restriction of Lingula Bronchus with Intraluminal Device, Open Approach */
"0BV90ZZ" = "1" /* Restriction of Lingula Bronchus, Open Approach */
"0BV93CZ" = "1" /* Restriction of Lingula Bronchus with Extraluminal Device, Percutaneous Approach */
"0BV93DZ" = "1" /* Restriction of Lingula Bronchus with Intraluminal Device, Percutaneous Approach */
"0BV93ZZ" = "1" /* Restriction of Lingula Bronchus, Percutaneous Approach */
"0BV94CZ" = "1" /* Restriction of Lingula Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BV94DZ" = "1" /* Restriction of Lingula Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BV94ZZ" = "1" /* Restriction of Lingula Bronchus, Percutaneous Endoscopic Approach */
"0BV97DZ" = "1" /* Restriction of Lingula Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BV97ZZ" = "1" /* Restriction of Lingula Bronchus, Via Natural or Artificial Opening */
"0BV98DZ" = "1" /* Restriction of Lingula Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BV98ZZ" = "1" /* Restriction of Lingula Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BVB0CZ" = "1" /* Restriction of Left Lower Lobe Bronchus with Extraluminal Device, Open Approach */
"0BVB0DZ" = "1" /* Restriction of Left Lower Lobe Bronchus with Intraluminal Device, Open Approach */
"0BVB0ZZ" = "1" /* Restriction of Left Lower Lobe Bronchus, Open Approach */
"0BVB3CZ" = "1" /* Restriction of Left Lower Lobe Bronchus with Extraluminal Device, Percutaneous Approach */
"0BVB3DZ" = "1" /* Restriction of Left Lower Lobe Bronchus with Intraluminal Device, Percutaneous Approach */
"0BVB3ZZ" = "1" /* Restriction of Left Lower Lobe Bronchus, Percutaneous Approach */
"0BVB4CZ" = "1" /* Restriction of Left Lower Lobe Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BVB4DZ" = "1" /* Restriction of Left Lower Lobe Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BVB4ZZ" = "1" /* Restriction of Left Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BVB7DZ" = "1" /* Restriction of Left Lower Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BVB7ZZ" = "1" /* Restriction of Left Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BVB8DZ" = "1" /* Restriction of Left Lower Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BVB8ZZ" = "1" /* Restriction of Left Lower Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BW000Z" = "1" /* Revision of Drainage Device in Tracheobronchial Tree, Open Approach */
"0BW002Z" = "1" /* Revision of Monitoring Device in Tracheobronchial Tree, Open Approach */
"0BW003Z" = "1" /* Revision of Infusion Device in Tracheobronchial Tree, Open Approach */
"0BW007Z" = "1" /* Revision of Autologous Tissue Substitute in Tracheobronchial Tree, Open Approach */
"0BW00CZ" = "1" /* Revision of Extraluminal Device in Tracheobronchial Tree, Open Approach */
"0BW00DZ" = "1" /* Revision of Intraluminal Device in Tracheobronchial Tree, Open Approach */
"0BW00JZ" = "1" /* Revision of Synthetic Substitute in Tracheobronchial Tree, Open Approach */
"0BW00KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Tracheobronchial Tree, Open Approach */
"0BW030Z" = "1" /* Revision of Drainage Device in Tracheobronchial Tree, Percutaneous Approach */
"0BW032Z" = "1" /* Revision of Monitoring Device in Tracheobronchial Tree, Percutaneous Approach */
"0BW033Z" = "1" /* Revision of Infusion Device in Tracheobronchial Tree, Percutaneous Approach */
"0BW037Z" = "1" /* Revision of Autologous Tissue Substitute in Tracheobronchial Tree, Percutaneous Approach */
"0BW03CZ" = "1" /* Revision of Extraluminal Device in Tracheobronchial Tree, Percutaneous Approach */
"0BW03DZ" = "1" /* Revision of Intraluminal Device in Tracheobronchial Tree, Percutaneous Approach */
"0BW03JZ" = "1" /* Revision of Synthetic Substitute in Tracheobronchial Tree, Percutaneous Approach */
"0BW03KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Tracheobronchial Tree, Percutaneous Approach */
"0BW040Z" = "1" /* Revision of Drainage Device in Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BW042Z" = "1" /* Revision of Monitoring Device in Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BW043Z" = "1" /* Revision of Infusion Device in Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BW047Z" = "1" /* Revision of Autologous Tissue Substitute in Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BW04CZ" = "1" /* Revision of Extraluminal Device in Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BW04DZ" = "1" /* Revision of Intraluminal Device in Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BW04JZ" = "1" /* Revision of Synthetic Substitute in Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BW04KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BW070Z" = "1" /* Revision of Drainage Device in Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BW077Z" = "1" /* Revision of Autologous Tissue Substitute in Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BW07CZ" = "1" /* Revision of Extraluminal Device in Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BW07JZ" = "1" /* Revision of Synthetic Substitute in Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BW07KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BW080Z" = "1" /* Revision of Drainage Device in Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BW087Z" = "1" /* Revision of Autologous Tissue Substitute in Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BW08CZ" = "1" /* Revision of Extraluminal Device in Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BW08JZ" = "1" /* Revision of Synthetic Substitute in Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BW08KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BW100Z" = "1" /* Revision of Drainage Device in Trachea, Open Approach */
"0BW102Z" = "1" /* Revision of Monitoring Device in Trachea, Open Approach */
"0BW107Z" = "1" /* Revision of Autologous Tissue Substitute in Trachea, Open Approach */
"0BW10CZ" = "1" /* Revision of Extraluminal Device in Trachea, Open Approach */
"0BW10DZ" = "1" /* Revision of Intraluminal Device in Trachea, Open Approach */
"0BW10FZ" = "1" /* Revision of Tracheostomy Device in Trachea, Open Approach */
"0BW10JZ" = "1" /* Revision of Synthetic Substitute in Trachea, Open Approach */
"0BW10KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Trachea, Open Approach */
"0BW130Z" = "1" /* Revision of Drainage Device in Trachea, Percutaneous Approach */
"0BW132Z" = "1" /* Revision of Monitoring Device in Trachea, Percutaneous Approach */
"0BW137Z" = "1" /* Revision of Autologous Tissue Substitute in Trachea, Percutaneous Approach */
"0BW13CZ" = "1" /* Revision of Extraluminal Device in Trachea, Percutaneous Approach */
"0BW13DZ" = "1" /* Revision of Intraluminal Device in Trachea, Percutaneous Approach */
"0BW13FZ" = "1" /* Revision of Tracheostomy Device in Trachea, Percutaneous Approach */
"0BW13JZ" = "1" /* Revision of Synthetic Substitute in Trachea, Percutaneous Approach */
"0BW13KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Trachea, Percutaneous Approach */
"0BW140Z" = "1" /* Revision of Drainage Device in Trachea, Percutaneous Endoscopic Approach */
"0BW142Z" = "1" /* Revision of Monitoring Device in Trachea, Percutaneous Endoscopic Approach */
"0BW147Z" = "1" /* Revision of Autologous Tissue Substitute in Trachea, Percutaneous Endoscopic Approach */
"0BW14CZ" = "1" /* Revision of Extraluminal Device in Trachea, Percutaneous Endoscopic Approach */
"0BW14DZ" = "1" /* Revision of Intraluminal Device in Trachea, Percutaneous Endoscopic Approach */
"0BW14FZ" = "1" /* Revision of Tracheostomy Device in Trachea, Percutaneous Endoscopic Approach */
"0BW14JZ" = "1" /* Revision of Synthetic Substitute in Trachea, Percutaneous Endoscopic Approach */
"0BW14KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Trachea, Percutaneous Endoscopic Approach */
"0BW170Z" = "1" /* Revision of Drainage Device in Trachea, Via Natural or Artificial Opening */
"0BW172Z" = "1" /* Revision of Monitoring Device in Trachea, Via Natural or Artificial Opening */
"0BW177Z" = "1" /* Revision of Autologous Tissue Substitute in Trachea, Via Natural or Artificial Opening */
"0BW17CZ" = "1" /* Revision of Extraluminal Device in Trachea, Via Natural or Artificial Opening */
"0BW17DZ" = "1" /* Revision of Intraluminal Device in Trachea, Via Natural or Artificial Opening */
"0BW17FZ" = "1" /* Revision of Tracheostomy Device in Trachea, Via Natural or Artificial Opening */
"0BW17JZ" = "1" /* Revision of Synthetic Substitute in Trachea, Via Natural or Artificial Opening */
"0BW17KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Trachea, Via Natural or Artificial Opening */
"0BW180Z" = "1" /* Revision of Drainage Device in Trachea, Via Natural or Artificial Opening Endoscopic */
"0BW182Z" = "1" /* Revision of Monitoring Device in Trachea, Via Natural or Artificial Opening Endoscopic */
"0BW187Z" = "1" /* Revision of Autologous Tissue Substitute in Trachea, Via Natural or Artificial Opening Endoscopic */
"0BW18CZ" = "1" /* Revision of Extraluminal Device in Trachea, Via Natural or Artificial Opening Endoscopic */
"0BW18DZ" = "1" /* Revision of Intraluminal Device in Trachea, Via Natural or Artificial Opening Endoscopic */
"0BW18FZ" = "1" /* Revision of Tracheostomy Device in Trachea, Via Natural or Artificial Opening Endoscopic */
"0BW18JZ" = "1" /* Revision of Synthetic Substitute in Trachea, Via Natural or Artificial Opening Endoscopic */
"0BW18KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Trachea, Via Natural or Artificial Opening Endoscopic */
"0BWK00Z" = "1" /* Revision of Drainage Device in Right Lung, Open Approach */
"0BWK02Z" = "1" /* Revision of Monitoring Device in Right Lung, Open Approach */
"0BWK03Z" = "1" /* Revision of Infusion Device in Right Lung, Open Approach */
"0BWK30Z" = "1" /* Revision of Drainage Device in Right Lung, Percutaneous Approach */
"0BWK32Z" = "1" /* Revision of Monitoring Device in Right Lung, Percutaneous Approach */
"0BWK33Z" = "1" /* Revision of Infusion Device in Right Lung, Percutaneous Approach */
"0BWK40Z" = "1" /* Revision of Drainage Device in Right Lung, Percutaneous Endoscopic Approach */
"0BWK42Z" = "1" /* Revision of Monitoring Device in Right Lung, Percutaneous Endoscopic Approach */
"0BWK43Z" = "1" /* Revision of Infusion Device in Right Lung, Percutaneous Endoscopic Approach */
"0BWL00Z" = "1" /* Revision of Drainage Device in Left Lung, Open Approach */
"0BWL02Z" = "1" /* Revision of Monitoring Device in Left Lung, Open Approach */
"0BWL03Z" = "1" /* Revision of Infusion Device in Left Lung, Open Approach */
"0BWL30Z" = "1" /* Revision of Drainage Device in Left Lung, Percutaneous Approach */
"0BWL32Z" = "1" /* Revision of Monitoring Device in Left Lung, Percutaneous Approach */
"0BWL33Z" = "1" /* Revision of Infusion Device in Left Lung, Percutaneous Approach */
"0BWL40Z" = "1" /* Revision of Drainage Device in Left Lung, Percutaneous Endoscopic Approach */
"0BWL42Z" = "1" /* Revision of Monitoring Device in Left Lung, Percutaneous Endoscopic Approach */
"0BWL43Z" = "1" /* Revision of Infusion Device in Left Lung, Percutaneous Endoscopic Approach */
"0BWT00Z" = "1" /* Revision of Drainage Device in Diaphragm, Open Approach */
"0BWT02Z" = "1" /* Revision of Monitoring Device in Diaphragm, Open Approach */
"0BWT07Z" = "1" /* Revision of Autologous Tissue Substitute in Diaphragm, Open Approach */
"0BWT0JZ" = "1" /* Revision of Synthetic Substitute in Diaphragm, Open Approach */
"0BWT0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Diaphragm, Open Approach */
"0BWT0MZ" = "1" /* Revision of Diaphragmatic Pacemaker Lead in Diaphragm, Open Approach */
"0BWT30Z" = "1" /* Revision of Drainage Device in Diaphragm, Percutaneous Approach */
"0BWT32Z" = "1" /* Revision of Monitoring Device in Diaphragm, Percutaneous Approach */
"0BWT37Z" = "1" /* Revision of Autologous Tissue Substitute in Diaphragm, Percutaneous Approach */
"0BWT3JZ" = "1" /* Revision of Synthetic Substitute in Diaphragm, Percutaneous Approach */
"0BWT3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Diaphragm, Percutaneous Approach */
"0BWT3MZ" = "1" /* Revision of Diaphragmatic Pacemaker Lead in Diaphragm, Percutaneous Approach */
"0BWT40Z" = "1" /* Revision of Drainage Device in Diaphragm, Percutaneous Endoscopic Approach */
"0BWT42Z" = "1" /* Revision of Monitoring Device in Diaphragm, Percutaneous Endoscopic Approach */
"0BWT47Z" = "1" /* Revision of Autologous Tissue Substitute in Diaphragm, Percutaneous Endoscopic Approach */
"0BWT4JZ" = "1" /* Revision of Synthetic Substitute in Diaphragm, Percutaneous Endoscopic Approach */
"0BWT4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Diaphragm, Percutaneous Endoscopic Approach */
"0BWT4MZ" = "1" /* Revision of Diaphragmatic Pacemaker Lead in Diaphragm, Percutaneous Endoscopic Approach */
"0BWT70Z" = "1" /* Revision of Drainage Device in Diaphragm, Via Natural or Artificial Opening */
"0BWT72Z" = "1" /* Revision of Monitoring Device in Diaphragm, Via Natural or Artificial Opening */
"0BWT77Z" = "1" /* Revision of Autologous Tissue Substitute in Diaphragm, Via Natural or Artificial Opening */
"0BWT7JZ" = "1" /* Revision of Synthetic Substitute in Diaphragm, Via Natural or Artificial Opening */
"0BWT7KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Diaphragm, Via Natural or Artificial Opening */
"0BWT7MZ" = "1" /* Revision of Diaphragmatic Pacemaker Lead in Diaphragm, Via Natural or Artificial Opening */
"0BWT80Z" = "1" /* Revision of Drainage Device in Diaphragm, Via Natural or Artificial Opening Endoscopic */
"0BWT82Z" = "1" /* Revision of Monitoring Device in Diaphragm, Via Natural or Artificial Opening Endoscopic */
"0BWT87Z" = "1" /* Revision of Autologous Tissue Substitute in Diaphragm, Via Natural or Artificial Opening Endoscopic */
"0BWT8JZ" = "1" /* Revision of Synthetic Substitute in Diaphragm, Via Natural or Artificial Opening Endoscopic */
"0BWT8KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Diaphragm, Via Natural or Artificial Opening Endoscopic */
"0BWT8MZ" = "1" /* Revision of Diaphragmatic Pacemaker Lead in Diaphragm, Via Natural or Artificial Opening Endoscopic */
"0BYC0Z0" = "1" /* Transplantation of Right Upper Lung Lobe, Allogeneic, Open Approach */
"0BYC0Z1" = "1" /* Transplantation of Right Upper Lung Lobe, Syngeneic, Open Approach */
"0BYC0Z2" = "1" /* Transplantation of Right Upper Lung Lobe, Zooplastic, Open Approach */
"0BYD0Z0" = "1" /* Transplantation of Right Middle Lung Lobe, Allogeneic, Open Approach */
"0BYD0Z1" = "1" /* Transplantation of Right Middle Lung Lobe, Syngeneic, Open Approach */
"0BYD0Z2" = "1" /* Transplantation of Right Middle Lung Lobe, Zooplastic, Open Approach */
"0BYF0Z0" = "1" /* Transplantation of Right Lower Lung Lobe, Allogeneic, Open Approach */
"0BYF0Z1" = "1" /* Transplantation of Right Lower Lung Lobe, Syngeneic, Open Approach */
"0BYF0Z2" = "1" /* Transplantation of Right Lower Lung Lobe, Zooplastic, Open Approach */
"0BYG0Z0" = "1" /* Transplantation of Left Upper Lung Lobe, Allogeneic, Open Approach */
"0BYG0Z1" = "1" /* Transplantation of Left Upper Lung Lobe, Syngeneic, Open Approach */
"0BYG0Z2" = "1" /* Transplantation of Left Upper Lung Lobe, Zooplastic, Open Approach */
"0BYH0Z0" = "1" /* Transplantation of Lung Lingula, Allogeneic, Open Approach */
"0BYH0Z1" = "1" /* Transplantation of Lung Lingula, Syngeneic, Open Approach */
"0BYH0Z2" = "1" /* Transplantation of Lung Lingula, Zooplastic, Open Approach */
"0BYJ0Z0" = "1" /* Transplantation of Left Lower Lung Lobe, Allogeneic, Open Approach */
"0BYJ0Z1" = "1" /* Transplantation of Left Lower Lung Lobe, Syngeneic, Open Approach */
"0BYJ0Z2" = "1" /* Transplantation of Left Lower Lung Lobe, Zooplastic, Open Approach */
"0BYK0Z0" = "1" /* Transplantation of Right Lung, Allogeneic, Open Approach */
"0BYK0Z1" = "1" /* Transplantation of Right Lung, Syngeneic, Open Approach */
"0BYK0Z2" = "1" /* Transplantation of Right Lung, Zooplastic, Open Approach */
"0BYL0Z0" = "1" /* Transplantation of Left Lung, Allogeneic, Open Approach */
"0BYL0Z1" = "1" /* Transplantation of Left Lung, Syngeneic, Open Approach */
"0BYL0Z2" = "1" /* Transplantation of Left Lung, Zooplastic, Open Approach */
"0BYM0Z0" = "1" /* Transplantation of Bilateral Lungs, Allogeneic, Open Approach */
"0BYM0Z1" = "1" /* Transplantation of Bilateral Lungs, Syngeneic, Open Approach */
"0BYM0Z2" = "1" /* Transplantation of Bilateral Lungs, Zooplastic, Open Approach */
"0C00X7Z" = "1" /* Alteration of Upper Lip with Autologous Tissue Substitute, External Approach */
"0C00XJZ" = "1" /* Alteration of Upper Lip with Synthetic Substitute, External Approach */
"0C00XKZ" = "1" /* Alteration of Upper Lip with Nonautologous Tissue Substitute, External Approach */
"0C00XZZ" = "1" /* Alteration of Upper Lip, External Approach */
"0C01X7Z" = "1" /* Alteration of Lower Lip with Autologous Tissue Substitute, External Approach */
"0C01XJZ" = "1" /* Alteration of Lower Lip with Synthetic Substitute, External Approach */
"0C01XKZ" = "1" /* Alteration of Lower Lip with Nonautologous Tissue Substitute, External Approach */
"0C01XZZ" = "1" /* Alteration of Lower Lip, External Approach */
"0C500ZZ" = "1" /* Destruction of Upper Lip, Open Approach */
"0C503ZZ" = "1" /* Destruction of Upper Lip, Percutaneous Approach */
"0C50XZZ" = "1" /* Destruction of Upper Lip, External Approach */
"0C510ZZ" = "1" /* Destruction of Lower Lip, Open Approach */
"0C513ZZ" = "1" /* Destruction of Lower Lip, Percutaneous Approach */
"0C51XZZ" = "1" /* Destruction of Lower Lip, External Approach */
"0C520ZZ" = "1" /* Destruction of Hard Palate, Open Approach */
"0C523ZZ" = "1" /* Destruction of Hard Palate, Percutaneous Approach */
"0C52XZZ" = "1" /* Destruction of Hard Palate, External Approach */
"0C530ZZ" = "1" /* Destruction of Soft Palate, Open Approach */
"0C533ZZ" = "1" /* Destruction of Soft Palate, Percutaneous Approach */
"0C53XZZ" = "1" /* Destruction of Soft Palate, External Approach */
"0C540ZZ" = "1" /* Destruction of Buccal Mucosa, Open Approach */
"0C543ZZ" = "1" /* Destruction of Buccal Mucosa, Percutaneous Approach */
"0C54XZZ" = "1" /* Destruction of Buccal Mucosa, External Approach */
"0C570ZZ" = "1" /* Destruction of Tongue, Open Approach */
"0C573ZZ" = "1" /* Destruction of Tongue, Percutaneous Approach */
"0C57XZZ" = "1" /* Destruction of Tongue, External Approach */
"0C580ZZ" = "1" /* Destruction of Right Parotid Gland, Open Approach */
"0C583ZZ" = "1" /* Destruction of Right Parotid Gland, Percutaneous Approach */
"0C590ZZ" = "1" /* Destruction of Left Parotid Gland, Open Approach */
"0C593ZZ" = "1" /* Destruction of Left Parotid Gland, Percutaneous Approach */
"0C5B0ZZ" = "1" /* Destruction of Right Parotid Duct, Open Approach */
"0C5B3ZZ" = "1" /* Destruction of Right Parotid Duct, Percutaneous Approach */
"0C5C0ZZ" = "1" /* Destruction of Left Parotid Duct, Open Approach */
"0C5C3ZZ" = "1" /* Destruction of Left Parotid Duct, Percutaneous Approach */
"0C5D0ZZ" = "1" /* Destruction of Right Sublingual Gland, Open Approach */
"0C5D3ZZ" = "1" /* Destruction of Right Sublingual Gland, Percutaneous Approach */
"0C5F0ZZ" = "1" /* Destruction of Left Sublingual Gland, Open Approach */
"0C5F3ZZ" = "1" /* Destruction of Left Sublingual Gland, Percutaneous Approach */
"0C5G0ZZ" = "1" /* Destruction of Right Submaxillary Gland, Open Approach */
"0C5G3ZZ" = "1" /* Destruction of Right Submaxillary Gland, Percutaneous Approach */
"0C5H0ZZ" = "1" /* Destruction of Left Submaxillary Gland, Open Approach */
"0C5H3ZZ" = "1" /* Destruction of Left Submaxillary Gland, Percutaneous Approach */
"0C5J0ZZ" = "1" /* Destruction of Minor Salivary Gland, Open Approach */
"0C5J3ZZ" = "1" /* Destruction of Minor Salivary Gland, Percutaneous Approach */
"0C5M0ZZ" = "1" /* Destruction of Pharynx, Open Approach */
"0C5M3ZZ" = "1" /* Destruction of Pharynx, Percutaneous Approach */
"0C5M4ZZ" = "1" /* Destruction of Pharynx, Percutaneous Endoscopic Approach */
"0C5M7ZZ" = "1" /* Destruction of Pharynx, Via Natural or Artificial Opening */
"0C5M8ZZ" = "1" /* Destruction of Pharynx, Via Natural or Artificial Opening Endoscopic */
"0C5N0ZZ" = "1" /* Destruction of Uvula, Open Approach */
"0C5N3ZZ" = "1" /* Destruction of Uvula, Percutaneous Approach */
"0C5NXZZ" = "1" /* Destruction of Uvula, External Approach */
"0C5P0ZZ" = "1" /* Destruction of Tonsils, Open Approach */
"0C5P3ZZ" = "1" /* Destruction of Tonsils, Percutaneous Approach */
"0C5PXZZ" = "1" /* Destruction of Tonsils, External Approach */
"0C5Q0ZZ" = "1" /* Destruction of Adenoids, Open Approach */
"0C5Q3ZZ" = "1" /* Destruction of Adenoids, Percutaneous Approach */
"0C5QXZZ" = "1" /* Destruction of Adenoids, External Approach */
"0C5R0ZZ" = "1" /* Destruction of Epiglottis, Open Approach */
"0C5R3ZZ" = "1" /* Destruction of Epiglottis, Percutaneous Approach */
"0C5R4ZZ" = "1" /* Destruction of Epiglottis, Percutaneous Endoscopic Approach */
"0C5R7ZZ" = "1" /* Destruction of Epiglottis, Via Natural or Artificial Opening */
"0C5R8ZZ" = "1" /* Destruction of Epiglottis, Via Natural or Artificial Opening Endoscopic */
"0C5S0ZZ" = "1" /* Destruction of Larynx, Open Approach */
"0C5S3ZZ" = "1" /* Destruction of Larynx, Percutaneous Approach */
"0C5S4ZZ" = "1" /* Destruction of Larynx, Percutaneous Endoscopic Approach */
"0C5S7ZZ" = "1" /* Destruction of Larynx, Via Natural or Artificial Opening */
"0C5S8ZZ" = "1" /* Destruction of Larynx, Via Natural or Artificial Opening Endoscopic */
"0C5T0ZZ" = "1" /* Destruction of Right Vocal Cord, Open Approach */
"0C5T3ZZ" = "1" /* Destruction of Right Vocal Cord, Percutaneous Approach */
"0C5T4ZZ" = "1" /* Destruction of Right Vocal Cord, Percutaneous Endoscopic Approach */
"0C5T7ZZ" = "1" /* Destruction of Right Vocal Cord, Via Natural or Artificial Opening */
"0C5T8ZZ" = "1" /* Destruction of Right Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0C5V0ZZ" = "1" /* Destruction of Left Vocal Cord, Open Approach */
"0C5V3ZZ" = "1" /* Destruction of Left Vocal Cord, Percutaneous Approach */
"0C5V4ZZ" = "1" /* Destruction of Left Vocal Cord, Percutaneous Endoscopic Approach */
"0C5V7ZZ" = "1" /* Destruction of Left Vocal Cord, Via Natural or Artificial Opening */
"0C5V8ZZ" = "1" /* Destruction of Left Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0C7S0DZ" = "1" /* Dilation of Larynx with Intraluminal Device, Open Approach */
"0C7S0ZZ" = "1" /* Dilation of Larynx, Open Approach */
"0C7S3DZ" = "1" /* Dilation of Larynx with Intraluminal Device, Percutaneous Approach */
"0C7S3ZZ" = "1" /* Dilation of Larynx, Percutaneous Approach */
"0C7S4DZ" = "1" /* Dilation of Larynx with Intraluminal Device, Percutaneous Endoscopic Approach */
"0C7S4ZZ" = "1" /* Dilation of Larynx, Percutaneous Endoscopic Approach */
"0C7S7DZ" = "1" /* Dilation of Larynx with Intraluminal Device, Via Natural or Artificial Opening */
"0C7S7ZZ" = "1" /* Dilation of Larynx, Via Natural or Artificial Opening */
"0C7S8DZ" = "1" /* Dilation of Larynx with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0C7S8ZZ" = "1" /* Dilation of Larynx, Via Natural or Artificial Opening Endoscopic */
"0C9000Z" = "1" /* Drainage of Upper Lip with Drainage Device, Open Approach */
"0C900ZZ" = "1" /* Drainage of Upper Lip, Open Approach */
"0C90X0Z" = "1" /* Drainage of Upper Lip with Drainage Device, External Approach */
"0C90XZZ" = "1" /* Drainage of Upper Lip, External Approach */
"0C9100Z" = "1" /* Drainage of Lower Lip with Drainage Device, Open Approach */
"0C910ZZ" = "1" /* Drainage of Lower Lip, Open Approach */
"0C91X0Z" = "1" /* Drainage of Lower Lip with Drainage Device, External Approach */
"0C91XZZ" = "1" /* Drainage of Lower Lip, External Approach */
"0C9200Z" = "1" /* Drainage of Hard Palate with Drainage Device, Open Approach */
"0C920ZX" = "1" /* Drainage of Hard Palate, Open Approach, Diagnostic */
"0C920ZZ" = "1" /* Drainage of Hard Palate, Open Approach */
"0C92X0Z" = "1" /* Drainage of Hard Palate with Drainage Device, External Approach */
"0C92XZX" = "1" /* Drainage of Hard Palate, External Approach, Diagnostic */
"0C92XZZ" = "1" /* Drainage of Hard Palate, External Approach */
"0C9300Z" = "1" /* Drainage of Soft Palate with Drainage Device, Open Approach */
"0C930ZX" = "1" /* Drainage of Soft Palate, Open Approach, Diagnostic */
"0C930ZZ" = "1" /* Drainage of Soft Palate, Open Approach */
"0C93X0Z" = "1" /* Drainage of Soft Palate with Drainage Device, External Approach */
"0C93XZX" = "1" /* Drainage of Soft Palate, External Approach, Diagnostic */
"0C93XZZ" = "1" /* Drainage of Soft Palate, External Approach */
"0C9400Z" = "1" /* Drainage of Buccal Mucosa with Drainage Device, Open Approach */
"0C940ZZ" = "1" /* Drainage of Buccal Mucosa, Open Approach */
"0C94X0Z" = "1" /* Drainage of Buccal Mucosa with Drainage Device, External Approach */
"0C94XZZ" = "1" /* Drainage of Buccal Mucosa, External Approach */
"0C9700Z" = "1" /* Drainage of Tongue with Drainage Device, Open Approach */
"0C970ZX" = "1" /* Drainage of Tongue, Open Approach, Diagnostic */
"0C970ZZ" = "1" /* Drainage of Tongue, Open Approach */
"0C97X0Z" = "1" /* Drainage of Tongue with Drainage Device, External Approach */
"0C97XZZ" = "1" /* Drainage of Tongue, External Approach */
"0C980ZX" = "1" /* Drainage of Right Parotid Gland, Open Approach, Diagnostic */
"0C990ZX" = "1" /* Drainage of Left Parotid Gland, Open Approach, Diagnostic */
"0C9B0ZX" = "1" /* Drainage of Right Parotid Duct, Open Approach, Diagnostic */
"0C9C0ZX" = "1" /* Drainage of Left Parotid Duct, Open Approach, Diagnostic */
"0C9D0ZX" = "1" /* Drainage of Right Sublingual Gland, Open Approach, Diagnostic */
"0C9F0ZX" = "1" /* Drainage of Left Sublingual Gland, Open Approach, Diagnostic */
"0C9G0ZX" = "1" /* Drainage of Right Submaxillary Gland, Open Approach, Diagnostic */
"0C9H0ZX" = "1" /* Drainage of Left Submaxillary Gland, Open Approach, Diagnostic */
"0C9J0ZX" = "1" /* Drainage of Minor Salivary Gland, Open Approach, Diagnostic */
"0C9M00Z" = "1" /* Drainage of Pharynx with Drainage Device, Open Approach */
"0C9M0ZZ" = "1" /* Drainage of Pharynx, Open Approach */
"0C9M40Z" = "1" /* Drainage of Pharynx with Drainage Device, Percutaneous Endoscopic Approach */
"0C9M4ZZ" = "1" /* Drainage of Pharynx, Percutaneous Endoscopic Approach */
"0C9M70Z" = "1" /* Drainage of Pharynx with Drainage Device, Via Natural or Artificial Opening */
"0C9M7ZZ" = "1" /* Drainage of Pharynx, Via Natural or Artificial Opening */
"0C9M80Z" = "1" /* Drainage of Pharynx with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0C9M8ZZ" = "1" /* Drainage of Pharynx, Via Natural or Artificial Opening Endoscopic */
"0C9N00Z" = "1" /* Drainage of Uvula with Drainage Device, Open Approach */
"0C9N0ZX" = "1" /* Drainage of Uvula, Open Approach, Diagnostic */
"0C9N0ZZ" = "1" /* Drainage of Uvula, Open Approach */
"0C9NX0Z" = "1" /* Drainage of Uvula with Drainage Device, External Approach */
"0C9NXZX" = "1" /* Drainage of Uvula, External Approach, Diagnostic */
"0C9NXZZ" = "1" /* Drainage of Uvula, External Approach */
"0C9P00Z" = "1" /* Drainage of Tonsils with Drainage Device, Open Approach */
"0C9P0ZX" = "1" /* Drainage of Tonsils, Open Approach, Diagnostic */
"0C9P0ZZ" = "1" /* Drainage of Tonsils, Open Approach */
"0C9PX0Z" = "1" /* Drainage of Tonsils with Drainage Device, External Approach */
"0C9PXZX" = "1" /* Drainage of Tonsils, External Approach, Diagnostic */
"0C9PXZZ" = "1" /* Drainage of Tonsils, External Approach */
"0C9Q00Z" = "1" /* Drainage of Adenoids with Drainage Device, Open Approach */
"0C9Q0ZX" = "1" /* Drainage of Adenoids, Open Approach, Diagnostic */
"0C9Q0ZZ" = "1" /* Drainage of Adenoids, Open Approach */
"0C9QX0Z" = "1" /* Drainage of Adenoids with Drainage Device, External Approach */
"0C9QXZX" = "1" /* Drainage of Adenoids, External Approach, Diagnostic */
"0C9QXZZ" = "1" /* Drainage of Adenoids, External Approach */
"0C9R00Z" = "1" /* Drainage of Epiglottis with Drainage Device, Open Approach */
"0C9R0ZX" = "1" /* Drainage of Epiglottis, Open Approach, Diagnostic */
"0C9R0ZZ" = "1" /* Drainage of Epiglottis, Open Approach */
"0C9R40Z" = "1" /* Drainage of Epiglottis with Drainage Device, Percutaneous Endoscopic Approach */
"0C9R4ZZ" = "1" /* Drainage of Epiglottis, Percutaneous Endoscopic Approach */
"0C9R70Z" = "1" /* Drainage of Epiglottis with Drainage Device, Via Natural or Artificial Opening */
"0C9R7ZZ" = "1" /* Drainage of Epiglottis, Via Natural or Artificial Opening */
"0C9R80Z" = "1" /* Drainage of Epiglottis with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0C9R8ZZ" = "1" /* Drainage of Epiglottis, Via Natural or Artificial Opening Endoscopic */
"0C9S00Z" = "1" /* Drainage of Larynx with Drainage Device, Open Approach */
"0C9S0ZX" = "1" /* Drainage of Larynx, Open Approach, Diagnostic */
"0C9S0ZZ" = "1" /* Drainage of Larynx, Open Approach */
"0C9S40Z" = "1" /* Drainage of Larynx with Drainage Device, Percutaneous Endoscopic Approach */
"0C9S4ZZ" = "1" /* Drainage of Larynx, Percutaneous Endoscopic Approach */
"0C9S70Z" = "1" /* Drainage of Larynx with Drainage Device, Via Natural or Artificial Opening */
"0C9S7ZZ" = "1" /* Drainage of Larynx, Via Natural or Artificial Opening */
"0C9S80Z" = "1" /* Drainage of Larynx with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0C9S8ZZ" = "1" /* Drainage of Larynx, Via Natural or Artificial Opening Endoscopic */
"0C9T00Z" = "1" /* Drainage of Right Vocal Cord with Drainage Device, Open Approach */
"0C9T0ZX" = "1" /* Drainage of Right Vocal Cord, Open Approach, Diagnostic */
"0C9T0ZZ" = "1" /* Drainage of Right Vocal Cord, Open Approach */
"0C9T40Z" = "1" /* Drainage of Right Vocal Cord with Drainage Device, Percutaneous Endoscopic Approach */
"0C9T4ZZ" = "1" /* Drainage of Right Vocal Cord, Percutaneous Endoscopic Approach */
"0C9T70Z" = "1" /* Drainage of Right Vocal Cord with Drainage Device, Via Natural or Artificial Opening */
"0C9T7ZZ" = "1" /* Drainage of Right Vocal Cord, Via Natural or Artificial Opening */
"0C9T80Z" = "1" /* Drainage of Right Vocal Cord with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0C9T8ZZ" = "1" /* Drainage of Right Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0C9V00Z" = "1" /* Drainage of Left Vocal Cord with Drainage Device, Open Approach */
"0C9V0ZX" = "1" /* Drainage of Left Vocal Cord, Open Approach, Diagnostic */
"0C9V0ZZ" = "1" /* Drainage of Left Vocal Cord, Open Approach */
"0C9V40Z" = "1" /* Drainage of Left Vocal Cord with Drainage Device, Percutaneous Endoscopic Approach */
"0C9V4ZZ" = "1" /* Drainage of Left Vocal Cord, Percutaneous Endoscopic Approach */
"0C9V70Z" = "1" /* Drainage of Left Vocal Cord with Drainage Device, Via Natural or Artificial Opening */
"0C9V7ZZ" = "1" /* Drainage of Left Vocal Cord, Via Natural or Artificial Opening */
"0C9V80Z" = "1" /* Drainage of Left Vocal Cord with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0C9V8ZZ" = "1" /* Drainage of Left Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CB00ZZ" = "1" /* Excision of Upper Lip, Open Approach */
"0CB03ZZ" = "1" /* Excision of Upper Lip, Percutaneous Approach */
"0CB0XZZ" = "1" /* Excision of Upper Lip, External Approach */
"0CB10ZZ" = "1" /* Excision of Lower Lip, Open Approach */
"0CB13ZZ" = "1" /* Excision of Lower Lip, Percutaneous Approach */
"0CB1XZZ" = "1" /* Excision of Lower Lip, External Approach */
"0CB20ZX" = "1" /* Excision of Hard Palate, Open Approach, Diagnostic */
"0CB20ZZ" = "1" /* Excision of Hard Palate, Open Approach */
"0CB23ZX" = "1" /* Excision of Hard Palate, Percutaneous Approach, Diagnostic */
"0CB23ZZ" = "1" /* Excision of Hard Palate, Percutaneous Approach */
"0CB2XZX" = "1" /* Excision of Hard Palate, External Approach, Diagnostic */
"0CB2XZZ" = "1" /* Excision of Hard Palate, External Approach */
"0CB30ZX" = "1" /* Excision of Soft Palate, Open Approach, Diagnostic */
"0CB30ZZ" = "1" /* Excision of Soft Palate, Open Approach */
"0CB33ZX" = "1" /* Excision of Soft Palate, Percutaneous Approach, Diagnostic */
"0CB33ZZ" = "1" /* Excision of Soft Palate, Percutaneous Approach */
"0CB3XZX" = "1" /* Excision of Soft Palate, External Approach, Diagnostic */
"0CB3XZZ" = "1" /* Excision of Soft Palate, External Approach */
"0CB40ZZ" = "1" /* Excision of Buccal Mucosa, Open Approach */
"0CB43ZZ" = "1" /* Excision of Buccal Mucosa, Percutaneous Approach */
"0CB4XZZ" = "1" /* Excision of Buccal Mucosa, External Approach */
"0CB70ZX" = "1" /* Excision of Tongue, Open Approach, Diagnostic */
"0CB70ZZ" = "1" /* Excision of Tongue, Open Approach */
"0CB73ZZ" = "1" /* Excision of Tongue, Percutaneous Approach */
"0CB7XZZ" = "1" /* Excision of Tongue, External Approach */
"0CB80ZX" = "1" /* Excision of Right Parotid Gland, Open Approach, Diagnostic */
"0CB80ZZ" = "1" /* Excision of Right Parotid Gland, Open Approach */
"0CB83ZZ" = "1" /* Excision of Right Parotid Gland, Percutaneous Approach */
"0CB90ZX" = "1" /* Excision of Left Parotid Gland, Open Approach, Diagnostic */
"0CB90ZZ" = "1" /* Excision of Left Parotid Gland, Open Approach */
"0CB93ZZ" = "1" /* Excision of Left Parotid Gland, Percutaneous Approach */
"0CBB0ZX" = "1" /* Excision of Right Parotid Duct, Open Approach, Diagnostic */
"0CBB0ZZ" = "1" /* Excision of Right Parotid Duct, Open Approach */
"0CBB3ZZ" = "1" /* Excision of Right Parotid Duct, Percutaneous Approach */
"0CBC0ZX" = "1" /* Excision of Left Parotid Duct, Open Approach, Diagnostic */
"0CBC0ZZ" = "1" /* Excision of Left Parotid Duct, Open Approach */
"0CBC3ZZ" = "1" /* Excision of Left Parotid Duct, Percutaneous Approach */
"0CBD0ZX" = "1" /* Excision of Right Sublingual Gland, Open Approach, Diagnostic */
"0CBD0ZZ" = "1" /* Excision of Right Sublingual Gland, Open Approach */
"0CBD3ZZ" = "1" /* Excision of Right Sublingual Gland, Percutaneous Approach */
"0CBF0ZX" = "1" /* Excision of Left Sublingual Gland, Open Approach, Diagnostic */
"0CBF0ZZ" = "1" /* Excision of Left Sublingual Gland, Open Approach */
"0CBF3ZZ" = "1" /* Excision of Left Sublingual Gland, Percutaneous Approach */
"0CBG0ZX" = "1" /* Excision of Right Submaxillary Gland, Open Approach, Diagnostic */
"0CBG0ZZ" = "1" /* Excision of Right Submaxillary Gland, Open Approach */
"0CBG3ZZ" = "1" /* Excision of Right Submaxillary Gland, Percutaneous Approach */
"0CBH0ZX" = "1" /* Excision of Left Submaxillary Gland, Open Approach, Diagnostic */
"0CBH0ZZ" = "1" /* Excision of Left Submaxillary Gland, Open Approach */
"0CBH3ZZ" = "1" /* Excision of Left Submaxillary Gland, Percutaneous Approach */
"0CBJ0ZX" = "1" /* Excision of Minor Salivary Gland, Open Approach, Diagnostic */
"0CBJ0ZZ" = "1" /* Excision of Minor Salivary Gland, Open Approach */
"0CBJ3ZZ" = "1" /* Excision of Minor Salivary Gland, Percutaneous Approach */
"0CBM0ZZ" = "1" /* Excision of Pharynx, Open Approach */
"0CBM3ZZ" = "1" /* Excision of Pharynx, Percutaneous Approach */
"0CBM4ZZ" = "1" /* Excision of Pharynx, Percutaneous Endoscopic Approach */
"0CBM7ZZ" = "1" /* Excision of Pharynx, Via Natural or Artificial Opening */
"0CBM8ZZ" = "1" /* Excision of Pharynx, Via Natural or Artificial Opening Endoscopic */
"0CBN0ZX" = "1" /* Excision of Uvula, Open Approach, Diagnostic */
"0CBN0ZZ" = "1" /* Excision of Uvula, Open Approach */
"0CBN3ZX" = "1" /* Excision of Uvula, Percutaneous Approach, Diagnostic */
"0CBN3ZZ" = "1" /* Excision of Uvula, Percutaneous Approach */
"0CBNXZX" = "1" /* Excision of Uvula, External Approach, Diagnostic */
"0CBNXZZ" = "1" /* Excision of Uvula, External Approach */
"0CBP0ZX" = "1" /* Excision of Tonsils, Open Approach, Diagnostic */
"0CBP0ZZ" = "1" /* Excision of Tonsils, Open Approach */
"0CBP3ZX" = "1" /* Excision of Tonsils, Percutaneous Approach, Diagnostic */
"0CBP3ZZ" = "1" /* Excision of Tonsils, Percutaneous Approach */
"0CBPXZX" = "1" /* Excision of Tonsils, External Approach, Diagnostic */
"0CBPXZZ" = "1" /* Excision of Tonsils, External Approach */
"0CBQ0ZX" = "1" /* Excision of Adenoids, Open Approach, Diagnostic */
"0CBQ0ZZ" = "1" /* Excision of Adenoids, Open Approach */
"0CBQ3ZX" = "1" /* Excision of Adenoids, Percutaneous Approach, Diagnostic */
"0CBQ3ZZ" = "1" /* Excision of Adenoids, Percutaneous Approach */
"0CBQXZX" = "1" /* Excision of Adenoids, External Approach, Diagnostic */
"0CBQXZZ" = "1" /* Excision of Adenoids, External Approach */
"0CBR0ZX" = "1" /* Excision of Epiglottis, Open Approach, Diagnostic */
"0CBR0ZZ" = "1" /* Excision of Epiglottis, Open Approach */
"0CBR3ZZ" = "1" /* Excision of Epiglottis, Percutaneous Approach */
"0CBR4ZZ" = "1" /* Excision of Epiglottis, Percutaneous Endoscopic Approach */
"0CBR7ZZ" = "1" /* Excision of Epiglottis, Via Natural or Artificial Opening */
"0CBR8ZZ" = "1" /* Excision of Epiglottis, Via Natural or Artificial Opening Endoscopic */
"0CBS0ZX" = "1" /* Excision of Larynx, Open Approach, Diagnostic */
"0CBS0ZZ" = "1" /* Excision of Larynx, Open Approach */
"0CBS3ZZ" = "1" /* Excision of Larynx, Percutaneous Approach */
"0CBS4ZZ" = "1" /* Excision of Larynx, Percutaneous Endoscopic Approach */
"0CBS7ZZ" = "1" /* Excision of Larynx, Via Natural or Artificial Opening */
"0CBS8ZZ" = "1" /* Excision of Larynx, Via Natural or Artificial Opening Endoscopic */
"0CBT0ZX" = "1" /* Excision of Right Vocal Cord, Open Approach, Diagnostic */
"0CBT0ZZ" = "1" /* Excision of Right Vocal Cord, Open Approach */
"0CBT3ZZ" = "1" /* Excision of Right Vocal Cord, Percutaneous Approach */
"0CBT4ZZ" = "1" /* Excision of Right Vocal Cord, Percutaneous Endoscopic Approach */
"0CBT7ZZ" = "1" /* Excision of Right Vocal Cord, Via Natural or Artificial Opening */
"0CBT8ZZ" = "1" /* Excision of Right Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CBV0ZX" = "1" /* Excision of Left Vocal Cord, Open Approach, Diagnostic */
"0CBV0ZZ" = "1" /* Excision of Left Vocal Cord, Open Approach */
"0CBV3ZZ" = "1" /* Excision of Left Vocal Cord, Percutaneous Approach */
"0CBV4ZZ" = "1" /* Excision of Left Vocal Cord, Percutaneous Endoscopic Approach */
"0CBV7ZZ" = "1" /* Excision of Left Vocal Cord, Via Natural or Artificial Opening */
"0CBV8ZZ" = "1" /* Excision of Left Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CC00ZZ" = "1" /* Extirpation of Matter from Upper Lip, Open Approach */
"0CC03ZZ" = "1" /* Extirpation of Matter from Upper Lip, Percutaneous Approach */
"0CC10ZZ" = "1" /* Extirpation of Matter from Lower Lip, Open Approach */
"0CC13ZZ" = "1" /* Extirpation of Matter from Lower Lip, Percutaneous Approach */
"0CC20ZZ" = "1" /* Extirpation of Matter from Hard Palate, Open Approach */
"0CC23ZZ" = "1" /* Extirpation of Matter from Hard Palate, Percutaneous Approach */
"0CC30ZZ" = "1" /* Extirpation of Matter from Soft Palate, Open Approach */
"0CC33ZZ" = "1" /* Extirpation of Matter from Soft Palate, Percutaneous Approach */
"0CC40ZZ" = "1" /* Extirpation of Matter from Buccal Mucosa, Open Approach */
"0CC43ZZ" = "1" /* Extirpation of Matter from Buccal Mucosa, Percutaneous Approach */
"0CC70ZZ" = "1" /* Extirpation of Matter from Tongue, Open Approach */
"0CC73ZZ" = "1" /* Extirpation of Matter from Tongue, Percutaneous Approach */
"0CCM0ZZ" = "1" /* Extirpation of Matter from Pharynx, Open Approach */
"0CCM3ZZ" = "1" /* Extirpation of Matter from Pharynx, Percutaneous Approach */
"0CCM4ZZ" = "1" /* Extirpation of Matter from Pharynx, Percutaneous Endoscopic Approach */
"0CCN0ZZ" = "1" /* Extirpation of Matter from Uvula, Open Approach */
"0CCN3ZZ" = "1" /* Extirpation of Matter from Uvula, Percutaneous Approach */
"0CCP0ZZ" = "1" /* Extirpation of Matter from Tonsils, Open Approach */
"0CCP3ZZ" = "1" /* Extirpation of Matter from Tonsils, Percutaneous Approach */
"0CCQ0ZZ" = "1" /* Extirpation of Matter from Adenoids, Open Approach */
"0CCQ3ZZ" = "1" /* Extirpation of Matter from Adenoids, Percutaneous Approach */
"0CCR0ZZ" = "1" /* Extirpation of Matter from Epiglottis, Open Approach */
"0CCR3ZZ" = "1" /* Extirpation of Matter from Epiglottis, Percutaneous Approach */
"0CCR4ZZ" = "1" /* Extirpation of Matter from Epiglottis, Percutaneous Endoscopic Approach */
"0CCR7ZZ" = "1" /* Extirpation of Matter from Epiglottis, Via Natural or Artificial Opening */
"0CCR8ZZ" = "1" /* Extirpation of Matter from Epiglottis, Via Natural or Artificial Opening Endoscopic */
"0CCS0ZZ" = "1" /* Extirpation of Matter from Larynx, Open Approach */
"0CCS3ZZ" = "1" /* Extirpation of Matter from Larynx, Percutaneous Approach */
"0CCS4ZZ" = "1" /* Extirpation of Matter from Larynx, Percutaneous Endoscopic Approach */
"0CCT0ZZ" = "1" /* Extirpation of Matter from Right Vocal Cord, Open Approach */
"0CCT3ZZ" = "1" /* Extirpation of Matter from Right Vocal Cord, Percutaneous Approach */
"0CCT4ZZ" = "1" /* Extirpation of Matter from Right Vocal Cord, Percutaneous Endoscopic Approach */
"0CCT7ZZ" = "1" /* Extirpation of Matter from Right Vocal Cord, Via Natural or Artificial Opening */
"0CCT8ZZ" = "1" /* Extirpation of Matter from Right Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CCV0ZZ" = "1" /* Extirpation of Matter from Left Vocal Cord, Open Approach */
"0CCV3ZZ" = "1" /* Extirpation of Matter from Left Vocal Cord, Percutaneous Approach */
"0CCV4ZZ" = "1" /* Extirpation of Matter from Left Vocal Cord, Percutaneous Endoscopic Approach */
"0CCV7ZZ" = "1" /* Extirpation of Matter from Left Vocal Cord, Via Natural or Artificial Opening */
"0CCV8ZZ" = "1" /* Extirpation of Matter from Left Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CDT0ZZ" = "1" /* Extraction of Right Vocal Cord, Open Approach */
"0CDT3ZZ" = "1" /* Extraction of Right Vocal Cord, Percutaneous Approach */
"0CDT4ZZ" = "1" /* Extraction of Right Vocal Cord, Percutaneous Endoscopic Approach */
"0CDT7ZZ" = "1" /* Extraction of Right Vocal Cord, Via Natural or Artificial Opening */
"0CDT8ZZ" = "1" /* Extraction of Right Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CDV0ZZ" = "1" /* Extraction of Left Vocal Cord, Open Approach */
"0CDV3ZZ" = "1" /* Extraction of Left Vocal Cord, Percutaneous Approach */
"0CDV4ZZ" = "1" /* Extraction of Left Vocal Cord, Percutaneous Endoscopic Approach */
"0CDV7ZZ" = "1" /* Extraction of Left Vocal Cord, Via Natural or Artificial Opening */
"0CDV8ZZ" = "1" /* Extraction of Left Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CH701Z" = "1" /* Insertion of Radioactive Element into Tongue, Open Approach */
"0CH731Z" = "1" /* Insertion of Radioactive Element into Tongue, Percutaneous Approach */
"0CH7X1Z" = "1" /* Insertion of Radioactive Element into Tongue, External Approach */
"0CLB0CZ" = "1" /* Occlusion of Right Parotid Duct with Extraluminal Device, Open Approach */
"0CLB0DZ" = "1" /* Occlusion of Right Parotid Duct with Intraluminal Device, Open Approach */
"0CLB0ZZ" = "1" /* Occlusion of Right Parotid Duct, Open Approach */
"0CLB3CZ" = "1" /* Occlusion of Right Parotid Duct with Extraluminal Device, Percutaneous Approach */
"0CLB3DZ" = "1" /* Occlusion of Right Parotid Duct with Intraluminal Device, Percutaneous Approach */
"0CLB3ZZ" = "1" /* Occlusion of Right Parotid Duct, Percutaneous Approach */
"0CLB4CZ" = "1" /* Occlusion of Right Parotid Duct with Extraluminal Device, Percutaneous Endoscopic Approach */
"0CLB4DZ" = "1" /* Occlusion of Right Parotid Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0CLB4ZZ" = "1" /* Occlusion of Right Parotid Duct, Percutaneous Endoscopic Approach */
"0CLB7DZ" = "1" /* Occlusion of Right Parotid Duct with Intraluminal Device, Via Natural or Artificial Opening */
"0CLB7ZZ" = "1" /* Occlusion of Right Parotid Duct, Via Natural or Artificial Opening */
"0CLB8DZ" = "1" /* Occlusion of Right Parotid Duct with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0CLB8ZZ" = "1" /* Occlusion of Right Parotid Duct, Via Natural or Artificial Opening Endoscopic */
"0CLC0CZ" = "1" /* Occlusion of Left Parotid Duct with Extraluminal Device, Open Approach */
"0CLC0DZ" = "1" /* Occlusion of Left Parotid Duct with Intraluminal Device, Open Approach */
"0CLC0ZZ" = "1" /* Occlusion of Left Parotid Duct, Open Approach */
"0CLC3CZ" = "1" /* Occlusion of Left Parotid Duct with Extraluminal Device, Percutaneous Approach */
"0CLC3DZ" = "1" /* Occlusion of Left Parotid Duct with Intraluminal Device, Percutaneous Approach */
"0CLC3ZZ" = "1" /* Occlusion of Left Parotid Duct, Percutaneous Approach */
"0CLC4CZ" = "1" /* Occlusion of Left Parotid Duct with Extraluminal Device, Percutaneous Endoscopic Approach */
"0CLC4DZ" = "1" /* Occlusion of Left Parotid Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0CLC4ZZ" = "1" /* Occlusion of Left Parotid Duct, Percutaneous Endoscopic Approach */
"0CLC7DZ" = "1" /* Occlusion of Left Parotid Duct with Intraluminal Device, Via Natural or Artificial Opening */
"0CLC7ZZ" = "1" /* Occlusion of Left Parotid Duct, Via Natural or Artificial Opening */
"0CLC8DZ" = "1" /* Occlusion of Left Parotid Duct with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0CLC8ZZ" = "1" /* Occlusion of Left Parotid Duct, Via Natural or Artificial Opening Endoscopic */
"0CM00ZZ" = "1" /* Reattachment of Upper Lip, Open Approach */
"0CM10ZZ" = "1" /* Reattachment of Lower Lip, Open Approach */
"0CM30ZZ" = "1" /* Reattachment of Soft Palate, Open Approach */
"0CM70ZZ" = "1" /* Reattachment of Tongue, Open Approach */
"0CMN0ZZ" = "1" /* Reattachment of Uvula, Open Approach */
"0CN20ZZ" = "1" /* Release Hard Palate, Open Approach */
"0CN23ZZ" = "1" /* Release Hard Palate, Percutaneous Approach */
"0CN2XZZ" = "1" /* Release Hard Palate, External Approach */
"0CN30ZZ" = "1" /* Release Soft Palate, Open Approach */
"0CN33ZZ" = "1" /* Release Soft Palate, Percutaneous Approach */
"0CN3XZZ" = "1" /* Release Soft Palate, External Approach */
"0CN40ZZ" = "1" /* Release Buccal Mucosa, Open Approach */
"0CN43ZZ" = "1" /* Release Buccal Mucosa, Percutaneous Approach */
"0CN80ZZ" = "1" /* Release Right Parotid Gland, Open Approach */
"0CN83ZZ" = "1" /* Release Right Parotid Gland, Percutaneous Approach */
"0CN90ZZ" = "1" /* Release Left Parotid Gland, Open Approach */
"0CN93ZZ" = "1" /* Release Left Parotid Gland, Percutaneous Approach */
"0CNB0ZZ" = "1" /* Release Right Parotid Duct, Open Approach */
"0CNB3ZZ" = "1" /* Release Right Parotid Duct, Percutaneous Approach */
"0CNC0ZZ" = "1" /* Release Left Parotid Duct, Open Approach */
"0CNC3ZZ" = "1" /* Release Left Parotid Duct, Percutaneous Approach */
"0CND0ZZ" = "1" /* Release Right Sublingual Gland, Open Approach */
"0CND3ZZ" = "1" /* Release Right Sublingual Gland, Percutaneous Approach */
"0CNF0ZZ" = "1" /* Release Left Sublingual Gland, Open Approach */
"0CNF3ZZ" = "1" /* Release Left Sublingual Gland, Percutaneous Approach */
"0CNG0ZZ" = "1" /* Release Right Submaxillary Gland, Open Approach */
"0CNG3ZZ" = "1" /* Release Right Submaxillary Gland, Percutaneous Approach */
"0CNH0ZZ" = "1" /* Release Left Submaxillary Gland, Open Approach */
"0CNH3ZZ" = "1" /* Release Left Submaxillary Gland, Percutaneous Approach */
"0CNJ0ZZ" = "1" /* Release Minor Salivary Gland, Open Approach */
"0CNJ3ZZ" = "1" /* Release Minor Salivary Gland, Percutaneous Approach */
"0CNM0ZZ" = "1" /* Release Pharynx, Open Approach */
"0CNM3ZZ" = "1" /* Release Pharynx, Percutaneous Approach */
"0CNM4ZZ" = "1" /* Release Pharynx, Percutaneous Endoscopic Approach */
"0CNM7ZZ" = "1" /* Release Pharynx, Via Natural or Artificial Opening */
"0CNM8ZZ" = "1" /* Release Pharynx, Via Natural or Artificial Opening Endoscopic */
"0CNN0ZZ" = "1" /* Release Uvula, Open Approach */
"0CNN3ZZ" = "1" /* Release Uvula, Percutaneous Approach */
"0CNNXZZ" = "1" /* Release Uvula, External Approach */
"0CNP0ZZ" = "1" /* Release Tonsils, Open Approach */
"0CNP3ZZ" = "1" /* Release Tonsils, Percutaneous Approach */
"0CNPXZZ" = "1" /* Release Tonsils, External Approach */
"0CNQ0ZZ" = "1" /* Release Adenoids, Open Approach */
"0CNQ3ZZ" = "1" /* Release Adenoids, Percutaneous Approach */
"0CNQXZZ" = "1" /* Release Adenoids, External Approach */
"0CNR0ZZ" = "1" /* Release Epiglottis, Open Approach */
"0CNR3ZZ" = "1" /* Release Epiglottis, Percutaneous Approach */
"0CNR4ZZ" = "1" /* Release Epiglottis, Percutaneous Endoscopic Approach */
"0CNR7ZZ" = "1" /* Release Epiglottis, Via Natural or Artificial Opening */
"0CNR8ZZ" = "1" /* Release Epiglottis, Via Natural or Artificial Opening Endoscopic */
"0CNS0ZZ" = "1" /* Release Larynx, Open Approach */
"0CNS3ZZ" = "1" /* Release Larynx, Percutaneous Approach */
"0CNS4ZZ" = "1" /* Release Larynx, Percutaneous Endoscopic Approach */
"0CNS7ZZ" = "1" /* Release Larynx, Via Natural or Artificial Opening */
"0CNS8ZZ" = "1" /* Release Larynx, Via Natural or Artificial Opening Endoscopic */
"0CNT0ZZ" = "1" /* Release Right Vocal Cord, Open Approach */
"0CNT3ZZ" = "1" /* Release Right Vocal Cord, Percutaneous Approach */
"0CNT4ZZ" = "1" /* Release Right Vocal Cord, Percutaneous Endoscopic Approach */
"0CNT7ZZ" = "1" /* Release Right Vocal Cord, Via Natural or Artificial Opening */
"0CNT8ZZ" = "1" /* Release Right Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CNV0ZZ" = "1" /* Release Left Vocal Cord, Open Approach */
"0CNV3ZZ" = "1" /* Release Left Vocal Cord, Percutaneous Approach */
"0CNV4ZZ" = "1" /* Release Left Vocal Cord, Percutaneous Endoscopic Approach */
"0CNV7ZZ" = "1" /* Release Left Vocal Cord, Via Natural or Artificial Opening */
"0CNV8ZZ" = "1" /* Release Left Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CPS00Z" = "1" /* Removal of Drainage Device from Larynx, Open Approach */
"0CPS07Z" = "1" /* Removal of Autologous Tissue Substitute from Larynx, Open Approach */
"0CPS0DZ" = "1" /* Removal of Intraluminal Device from Larynx, Open Approach */
"0CPS0JZ" = "1" /* Removal of Synthetic Substitute from Larynx, Open Approach */
"0CPS0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Larynx, Open Approach */
"0CPS30Z" = "1" /* Removal of Drainage Device from Larynx, Percutaneous Approach */
"0CPS37Z" = "1" /* Removal of Autologous Tissue Substitute from Larynx, Percutaneous Approach */
"0CPS3DZ" = "1" /* Removal of Intraluminal Device from Larynx, Percutaneous Approach */
"0CPS3JZ" = "1" /* Removal of Synthetic Substitute from Larynx, Percutaneous Approach */
"0CPS3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Larynx, Percutaneous Approach */
"0CPS77Z" = "1" /* Removal of Autologous Tissue Substitute from Larynx, Via Natural or Artificial Opening */
"0CPS7JZ" = "1" /* Removal of Synthetic Substitute from Larynx, Via Natural or Artificial Opening */
"0CPS7KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Larynx, Via Natural or Artificial Opening */
"0CPS87Z" = "1" /* Removal of Autologous Tissue Substitute from Larynx, Via Natural or Artificial Opening Endoscopic */
"0CPS8JZ" = "1" /* Removal of Synthetic Substitute from Larynx, Via Natural or Artificial Opening Endoscopic */
"0CPS8KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Larynx, Via Natural or Artificial Opening Endoscopic */
"0CPY00Z" = "1" /* Removal of Drainage Device from Mouth and Throat, Open Approach */
"0CPY01Z" = "1" /* Removal of Radioactive Element from Mouth and Throat, Open Approach */
"0CPY07Z" = "1" /* Removal of Autologous Tissue Substitute from Mouth and Throat, Open Approach */
"0CPY0DZ" = "1" /* Removal of Intraluminal Device from Mouth and Throat, Open Approach */
"0CPY0JZ" = "1" /* Removal of Synthetic Substitute from Mouth and Throat, Open Approach */
"0CPY0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Mouth and Throat, Open Approach */
"0CPY30Z" = "1" /* Removal of Drainage Device from Mouth and Throat, Percutaneous Approach */
"0CPY31Z" = "1" /* Removal of Radioactive Element from Mouth and Throat, Percutaneous Approach */
"0CPY37Z" = "1" /* Removal of Autologous Tissue Substitute from Mouth and Throat, Percutaneous Approach */
"0CPY3DZ" = "1" /* Removal of Intraluminal Device from Mouth and Throat, Percutaneous Approach */
"0CPY3JZ" = "1" /* Removal of Synthetic Substitute from Mouth and Throat, Percutaneous Approach */
"0CPY3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Mouth and Throat, Percutaneous Approach */
"0CPY71Z" = "1" /* Removal of Radioactive Element from Mouth and Throat, Via Natural or Artificial Opening */
"0CPY77Z" = "1" /* Removal of Autologous Tissue Substitute from Mouth and Throat, Via Natural or Artificial Opening */
"0CPY7JZ" = "1" /* Removal of Synthetic Substitute from Mouth and Throat, Via Natural or Artificial Opening */
"0CPY7KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Mouth and Throat, Via Natural or Artificial Opening */
"0CPY81Z" = "1" /* Removal of Radioactive Element from Mouth and Throat, Via Natural or Artificial Opening Endoscopic */
"0CPY87Z" = "1" /* Removal of Autologous Tissue Substitute from Mouth and Throat, Via Natural or Artificial Opening Endoscopic */
"0CPY8JZ" = "1" /* Removal of Synthetic Substitute from Mouth and Throat, Via Natural or Artificial Opening Endoscopic */
"0CPY8KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Mouth and Throat, Via Natural or Artificial Opening Endoscopic */
"0CQ00ZZ" = "1" /* Repair Upper Lip, Open Approach */
"0CQ03ZZ" = "1" /* Repair Upper Lip, Percutaneous Approach */
"0CQ10ZZ" = "1" /* Repair Lower Lip, Open Approach */
"0CQ13ZZ" = "1" /* Repair Lower Lip, Percutaneous Approach */
"0CQ20ZZ" = "1" /* Repair Hard Palate, Open Approach */
"0CQ23ZZ" = "1" /* Repair Hard Palate, Percutaneous Approach */
"0CQ2XZZ" = "1" /* Repair Hard Palate, External Approach */
"0CQ30ZZ" = "1" /* Repair Soft Palate, Open Approach */
"0CQ33ZZ" = "1" /* Repair Soft Palate, Percutaneous Approach */
"0CQ3XZZ" = "1" /* Repair Soft Palate, External Approach */
"0CQ40ZZ" = "1" /* Repair Buccal Mucosa, Open Approach */
"0CQ43ZZ" = "1" /* Repair Buccal Mucosa, Percutaneous Approach */
"0CQ70ZZ" = "1" /* Repair Tongue, Open Approach */
"0CQ73ZZ" = "1" /* Repair Tongue, Percutaneous Approach */
"0CQ80ZZ" = "1" /* Repair Right Parotid Gland, Open Approach */
"0CQ83ZZ" = "1" /* Repair Right Parotid Gland, Percutaneous Approach */
"0CQ90ZZ" = "1" /* Repair Left Parotid Gland, Open Approach */
"0CQ93ZZ" = "1" /* Repair Left Parotid Gland, Percutaneous Approach */
"0CQB0ZZ" = "1" /* Repair Right Parotid Duct, Open Approach */
"0CQB3ZZ" = "1" /* Repair Right Parotid Duct, Percutaneous Approach */
"0CQC0ZZ" = "1" /* Repair Left Parotid Duct, Open Approach */
"0CQC3ZZ" = "1" /* Repair Left Parotid Duct, Percutaneous Approach */
"0CQD0ZZ" = "1" /* Repair Right Sublingual Gland, Open Approach */
"0CQD3ZZ" = "1" /* Repair Right Sublingual Gland, Percutaneous Approach */
"0CQF0ZZ" = "1" /* Repair Left Sublingual Gland, Open Approach */
"0CQF3ZZ" = "1" /* Repair Left Sublingual Gland, Percutaneous Approach */
"0CQG0ZZ" = "1" /* Repair Right Submaxillary Gland, Open Approach */
"0CQG3ZZ" = "1" /* Repair Right Submaxillary Gland, Percutaneous Approach */
"0CQH0ZZ" = "1" /* Repair Left Submaxillary Gland, Open Approach */
"0CQH3ZZ" = "1" /* Repair Left Submaxillary Gland, Percutaneous Approach */
"0CQJ0ZZ" = "1" /* Repair Minor Salivary Gland, Open Approach */
"0CQJ3ZZ" = "1" /* Repair Minor Salivary Gland, Percutaneous Approach */
"0CQM0ZZ" = "1" /* Repair Pharynx, Open Approach */
"0CQM3ZZ" = "1" /* Repair Pharynx, Percutaneous Approach */
"0CQM4ZZ" = "1" /* Repair Pharynx, Percutaneous Endoscopic Approach */
"0CQM7ZZ" = "1" /* Repair Pharynx, Via Natural or Artificial Opening */
"0CQM8ZZ" = "1" /* Repair Pharynx, Via Natural or Artificial Opening Endoscopic */
"0CQN0ZZ" = "1" /* Repair Uvula, Open Approach */
"0CQN3ZZ" = "1" /* Repair Uvula, Percutaneous Approach */
"0CQNXZZ" = "1" /* Repair Uvula, External Approach */
"0CQP0ZZ" = "1" /* Repair Tonsils, Open Approach */
"0CQP3ZZ" = "1" /* Repair Tonsils, Percutaneous Approach */
"0CQPXZZ" = "1" /* Repair Tonsils, External Approach */
"0CQQ0ZZ" = "1" /* Repair Adenoids, Open Approach */
"0CQQ3ZZ" = "1" /* Repair Adenoids, Percutaneous Approach */
"0CQQXZZ" = "1" /* Repair Adenoids, External Approach */
"0CQR0ZZ" = "1" /* Repair Epiglottis, Open Approach */
"0CQR3ZZ" = "1" /* Repair Epiglottis, Percutaneous Approach */
"0CQR4ZZ" = "1" /* Repair Epiglottis, Percutaneous Endoscopic Approach */
"0CQR7ZZ" = "1" /* Repair Epiglottis, Via Natural or Artificial Opening */
"0CQR8ZZ" = "1" /* Repair Epiglottis, Via Natural or Artificial Opening Endoscopic */
"0CQS0ZZ" = "1" /* Repair Larynx, Open Approach */
"0CQS3ZZ" = "1" /* Repair Larynx, Percutaneous Approach */
"0CQS4ZZ" = "1" /* Repair Larynx, Percutaneous Endoscopic Approach */
"0CQS7ZZ" = "1" /* Repair Larynx, Via Natural or Artificial Opening */
"0CQS8ZZ" = "1" /* Repair Larynx, Via Natural or Artificial Opening Endoscopic */
"0CQT0ZZ" = "1" /* Repair Right Vocal Cord, Open Approach */
"0CQT3ZZ" = "1" /* Repair Right Vocal Cord, Percutaneous Approach */
"0CQT4ZZ" = "1" /* Repair Right Vocal Cord, Percutaneous Endoscopic Approach */
"0CQT7ZZ" = "1" /* Repair Right Vocal Cord, Via Natural or Artificial Opening */
"0CQT8ZZ" = "1" /* Repair Right Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CQV0ZZ" = "1" /* Repair Left Vocal Cord, Open Approach */
"0CQV3ZZ" = "1" /* Repair Left Vocal Cord, Percutaneous Approach */
"0CQV4ZZ" = "1" /* Repair Left Vocal Cord, Percutaneous Endoscopic Approach */
"0CQV7ZZ" = "1" /* Repair Left Vocal Cord, Via Natural or Artificial Opening */
"0CQV8ZZ" = "1" /* Repair Left Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CR007Z" = "1" /* Replacement of Upper Lip with Autologous Tissue Substitute, Open Approach */
"0CR00JZ" = "1" /* Replacement of Upper Lip with Synthetic Substitute, Open Approach */
"0CR00KZ" = "1" /* Replacement of Upper Lip with Nonautologous Tissue Substitute, Open Approach */
"0CR037Z" = "1" /* Replacement of Upper Lip with Autologous Tissue Substitute, Percutaneous Approach */
"0CR03JZ" = "1" /* Replacement of Upper Lip with Synthetic Substitute, Percutaneous Approach */
"0CR03KZ" = "1" /* Replacement of Upper Lip with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CR0X7Z" = "1" /* Replacement of Upper Lip with Autologous Tissue Substitute, External Approach */
"0CR0XJZ" = "1" /* Replacement of Upper Lip with Synthetic Substitute, External Approach */
"0CR0XKZ" = "1" /* Replacement of Upper Lip with Nonautologous Tissue Substitute, External Approach */
"0CR107Z" = "1" /* Replacement of Lower Lip with Autologous Tissue Substitute, Open Approach */
"0CR10JZ" = "1" /* Replacement of Lower Lip with Synthetic Substitute, Open Approach */
"0CR10KZ" = "1" /* Replacement of Lower Lip with Nonautologous Tissue Substitute, Open Approach */
"0CR137Z" = "1" /* Replacement of Lower Lip with Autologous Tissue Substitute, Percutaneous Approach */
"0CR13JZ" = "1" /* Replacement of Lower Lip with Synthetic Substitute, Percutaneous Approach */
"0CR13KZ" = "1" /* Replacement of Lower Lip with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CR1X7Z" = "1" /* Replacement of Lower Lip with Autologous Tissue Substitute, External Approach */
"0CR1XJZ" = "1" /* Replacement of Lower Lip with Synthetic Substitute, External Approach */
"0CR1XKZ" = "1" /* Replacement of Lower Lip with Nonautologous Tissue Substitute, External Approach */
"0CR207Z" = "1" /* Replacement of Hard Palate with Autologous Tissue Substitute, Open Approach */
"0CR20JZ" = "1" /* Replacement of Hard Palate with Synthetic Substitute, Open Approach */
"0CR20KZ" = "1" /* Replacement of Hard Palate with Nonautologous Tissue Substitute, Open Approach */
"0CR237Z" = "1" /* Replacement of Hard Palate with Autologous Tissue Substitute, Percutaneous Approach */
"0CR23JZ" = "1" /* Replacement of Hard Palate with Synthetic Substitute, Percutaneous Approach */
"0CR23KZ" = "1" /* Replacement of Hard Palate with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CR2X7Z" = "1" /* Replacement of Hard Palate with Autologous Tissue Substitute, External Approach */
"0CR2XJZ" = "1" /* Replacement of Hard Palate with Synthetic Substitute, External Approach */
"0CR2XKZ" = "1" /* Replacement of Hard Palate with Nonautologous Tissue Substitute, External Approach */
"0CR307Z" = "1" /* Replacement of Soft Palate with Autologous Tissue Substitute, Open Approach */
"0CR30JZ" = "1" /* Replacement of Soft Palate with Synthetic Substitute, Open Approach */
"0CR30KZ" = "1" /* Replacement of Soft Palate with Nonautologous Tissue Substitute, Open Approach */
"0CR337Z" = "1" /* Replacement of Soft Palate with Autologous Tissue Substitute, Percutaneous Approach */
"0CR33JZ" = "1" /* Replacement of Soft Palate with Synthetic Substitute, Percutaneous Approach */
"0CR33KZ" = "1" /* Replacement of Soft Palate with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CR3X7Z" = "1" /* Replacement of Soft Palate with Autologous Tissue Substitute, External Approach */
"0CR3XJZ" = "1" /* Replacement of Soft Palate with Synthetic Substitute, External Approach */
"0CR3XKZ" = "1" /* Replacement of Soft Palate with Nonautologous Tissue Substitute, External Approach */
"0CR407Z" = "1" /* Replacement of Buccal Mucosa with Autologous Tissue Substitute, Open Approach */
"0CR40JZ" = "1" /* Replacement of Buccal Mucosa with Synthetic Substitute, Open Approach */
"0CR40KZ" = "1" /* Replacement of Buccal Mucosa with Nonautologous Tissue Substitute, Open Approach */
"0CR437Z" = "1" /* Replacement of Buccal Mucosa with Autologous Tissue Substitute, Percutaneous Approach */
"0CR43JZ" = "1" /* Replacement of Buccal Mucosa with Synthetic Substitute, Percutaneous Approach */
"0CR43KZ" = "1" /* Replacement of Buccal Mucosa with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CR4X7Z" = "1" /* Replacement of Buccal Mucosa with Autologous Tissue Substitute, External Approach */
"0CR4XJZ" = "1" /* Replacement of Buccal Mucosa with Synthetic Substitute, External Approach */
"0CR4XKZ" = "1" /* Replacement of Buccal Mucosa with Nonautologous Tissue Substitute, External Approach */
"0CR507Z" = "1" /* Replacement of Upper Gingiva with Autologous Tissue Substitute, Open Approach */
"0CR50JZ" = "1" /* Replacement of Upper Gingiva with Synthetic Substitute, Open Approach */
"0CR50KZ" = "1" /* Replacement of Upper Gingiva with Nonautologous Tissue Substitute, Open Approach */
"0CR537Z" = "1" /* Replacement of Upper Gingiva with Autologous Tissue Substitute, Percutaneous Approach */
"0CR53JZ" = "1" /* Replacement of Upper Gingiva with Synthetic Substitute, Percutaneous Approach */
"0CR53KZ" = "1" /* Replacement of Upper Gingiva with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CR5X7Z" = "1" /* Replacement of Upper Gingiva with Autologous Tissue Substitute, External Approach */
"0CR5XJZ" = "1" /* Replacement of Upper Gingiva with Synthetic Substitute, External Approach */
"0CR5XKZ" = "1" /* Replacement of Upper Gingiva with Nonautologous Tissue Substitute, External Approach */
"0CR607Z" = "1" /* Replacement of Lower Gingiva with Autologous Tissue Substitute, Open Approach */
"0CR60JZ" = "1" /* Replacement of Lower Gingiva with Synthetic Substitute, Open Approach */
"0CR60KZ" = "1" /* Replacement of Lower Gingiva with Nonautologous Tissue Substitute, Open Approach */
"0CR637Z" = "1" /* Replacement of Lower Gingiva with Autologous Tissue Substitute, Percutaneous Approach */
"0CR63JZ" = "1" /* Replacement of Lower Gingiva with Synthetic Substitute, Percutaneous Approach */
"0CR63KZ" = "1" /* Replacement of Lower Gingiva with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CR6X7Z" = "1" /* Replacement of Lower Gingiva with Autologous Tissue Substitute, External Approach */
"0CR6XJZ" = "1" /* Replacement of Lower Gingiva with Synthetic Substitute, External Approach */
"0CR6XKZ" = "1" /* Replacement of Lower Gingiva with Nonautologous Tissue Substitute, External Approach */
"0CR707Z" = "1" /* Replacement of Tongue with Autologous Tissue Substitute, Open Approach */
"0CR70JZ" = "1" /* Replacement of Tongue with Synthetic Substitute, Open Approach */
"0CR70KZ" = "1" /* Replacement of Tongue with Nonautologous Tissue Substitute, Open Approach */
"0CR737Z" = "1" /* Replacement of Tongue with Autologous Tissue Substitute, Percutaneous Approach */
"0CR73JZ" = "1" /* Replacement of Tongue with Synthetic Substitute, Percutaneous Approach */
"0CR73KZ" = "1" /* Replacement of Tongue with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CR7X7Z" = "1" /* Replacement of Tongue with Autologous Tissue Substitute, External Approach */
"0CR7XJZ" = "1" /* Replacement of Tongue with Synthetic Substitute, External Approach */
"0CR7XKZ" = "1" /* Replacement of Tongue with Nonautologous Tissue Substitute, External Approach */
"0CRB07Z" = "1" /* Replacement of Right Parotid Duct with Autologous Tissue Substitute, Open Approach */
"0CRB0JZ" = "1" /* Replacement of Right Parotid Duct with Synthetic Substitute, Open Approach */
"0CRB0KZ" = "1" /* Replacement of Right Parotid Duct with Nonautologous Tissue Substitute, Open Approach */
"0CRB37Z" = "1" /* Replacement of Right Parotid Duct with Autologous Tissue Substitute, Percutaneous Approach */
"0CRB3JZ" = "1" /* Replacement of Right Parotid Duct with Synthetic Substitute, Percutaneous Approach */
"0CRB3KZ" = "1" /* Replacement of Right Parotid Duct with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CRC07Z" = "1" /* Replacement of Left Parotid Duct with Autologous Tissue Substitute, Open Approach */
"0CRC0JZ" = "1" /* Replacement of Left Parotid Duct with Synthetic Substitute, Open Approach */
"0CRC0KZ" = "1" /* Replacement of Left Parotid Duct with Nonautologous Tissue Substitute, Open Approach */
"0CRC37Z" = "1" /* Replacement of Left Parotid Duct with Autologous Tissue Substitute, Percutaneous Approach */
"0CRC3JZ" = "1" /* Replacement of Left Parotid Duct with Synthetic Substitute, Percutaneous Approach */
"0CRC3KZ" = "1" /* Replacement of Left Parotid Duct with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CRM07Z" = "1" /* Replacement of Pharynx with Autologous Tissue Substitute, Open Approach */
"0CRM0JZ" = "1" /* Replacement of Pharynx with Synthetic Substitute, Open Approach */
"0CRM0KZ" = "1" /* Replacement of Pharynx with Nonautologous Tissue Substitute, Open Approach */
"0CRM77Z" = "1" /* Replacement of Pharynx with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0CRM7JZ" = "1" /* Replacement of Pharynx with Synthetic Substitute, Via Natural or Artificial Opening */
"0CRM7KZ" = "1" /* Replacement of Pharynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0CRM87Z" = "1" /* Replacement of Pharynx with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRM8JZ" = "1" /* Replacement of Pharynx with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRM8KZ" = "1" /* Replacement of Pharynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRN07Z" = "1" /* Replacement of Uvula with Autologous Tissue Substitute, Open Approach */
"0CRN0JZ" = "1" /* Replacement of Uvula with Synthetic Substitute, Open Approach */
"0CRN0KZ" = "1" /* Replacement of Uvula with Nonautologous Tissue Substitute, Open Approach */
"0CRN37Z" = "1" /* Replacement of Uvula with Autologous Tissue Substitute, Percutaneous Approach */
"0CRN3JZ" = "1" /* Replacement of Uvula with Synthetic Substitute, Percutaneous Approach */
"0CRN3KZ" = "1" /* Replacement of Uvula with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CRNX7Z" = "1" /* Replacement of Uvula with Autologous Tissue Substitute, External Approach */
"0CRNXJZ" = "1" /* Replacement of Uvula with Synthetic Substitute, External Approach */
"0CRNXKZ" = "1" /* Replacement of Uvula with Nonautologous Tissue Substitute, External Approach */
"0CRR07Z" = "1" /* Replacement of Epiglottis with Autologous Tissue Substitute, Open Approach */
"0CRR0JZ" = "1" /* Replacement of Epiglottis with Synthetic Substitute, Open Approach */
"0CRR0KZ" = "1" /* Replacement of Epiglottis with Nonautologous Tissue Substitute, Open Approach */
"0CRR77Z" = "1" /* Replacement of Epiglottis with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0CRR7JZ" = "1" /* Replacement of Epiglottis with Synthetic Substitute, Via Natural or Artificial Opening */
"0CRR7KZ" = "1" /* Replacement of Epiglottis with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0CRR87Z" = "1" /* Replacement of Epiglottis with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRR8JZ" = "1" /* Replacement of Epiglottis with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRR8KZ" = "1" /* Replacement of Epiglottis with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRS07Z" = "1" /* Replacement of Larynx with Autologous Tissue Substitute, Open Approach */
"0CRS0JZ" = "1" /* Replacement of Larynx with Synthetic Substitute, Open Approach */
"0CRS0KZ" = "1" /* Replacement of Larynx with Nonautologous Tissue Substitute, Open Approach */
"0CRS77Z" = "1" /* Replacement of Larynx with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0CRS7JZ" = "1" /* Replacement of Larynx with Synthetic Substitute, Via Natural or Artificial Opening */
"0CRS7KZ" = "1" /* Replacement of Larynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0CRS87Z" = "1" /* Replacement of Larynx with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRS8JZ" = "1" /* Replacement of Larynx with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRS8KZ" = "1" /* Replacement of Larynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRT07Z" = "1" /* Replacement of Right Vocal Cord with Autologous Tissue Substitute, Open Approach */
"0CRT0JZ" = "1" /* Replacement of Right Vocal Cord with Synthetic Substitute, Open Approach */
"0CRT0KZ" = "1" /* Replacement of Right Vocal Cord with Nonautologous Tissue Substitute, Open Approach */
"0CRT77Z" = "1" /* Replacement of Right Vocal Cord with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0CRT7JZ" = "1" /* Replacement of Right Vocal Cord with Synthetic Substitute, Via Natural or Artificial Opening */
"0CRT7KZ" = "1" /* Replacement of Right Vocal Cord with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0CRT87Z" = "1" /* Replacement of Right Vocal Cord with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRT8JZ" = "1" /* Replacement of Right Vocal Cord with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRT8KZ" = "1" /* Replacement of Right Vocal Cord with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRV07Z" = "1" /* Replacement of Left Vocal Cord with Autologous Tissue Substitute, Open Approach */
"0CRV0JZ" = "1" /* Replacement of Left Vocal Cord with Synthetic Substitute, Open Approach */
"0CRV0KZ" = "1" /* Replacement of Left Vocal Cord with Nonautologous Tissue Substitute, Open Approach */
"0CRV77Z" = "1" /* Replacement of Left Vocal Cord with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0CRV7JZ" = "1" /* Replacement of Left Vocal Cord with Synthetic Substitute, Via Natural or Artificial Opening */
"0CRV7KZ" = "1" /* Replacement of Left Vocal Cord with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0CRV87Z" = "1" /* Replacement of Left Vocal Cord with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRV8JZ" = "1" /* Replacement of Left Vocal Cord with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0CRV8KZ" = "1" /* Replacement of Left Vocal Cord with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CS00ZZ" = "1" /* Reposition Upper Lip, Open Approach */
"0CS0XZZ" = "1" /* Reposition Upper Lip, External Approach */
"0CS10ZZ" = "1" /* Reposition Lower Lip, Open Approach */
"0CS1XZZ" = "1" /* Reposition Lower Lip, External Approach */
"0CS20ZZ" = "1" /* Reposition Hard Palate, Open Approach */
"0CS2XZZ" = "1" /* Reposition Hard Palate, External Approach */
"0CS30ZZ" = "1" /* Reposition Soft Palate, Open Approach */
"0CS3XZZ" = "1" /* Reposition Soft Palate, External Approach */
"0CS70ZZ" = "1" /* Reposition Tongue, Open Approach */
"0CS7XZZ" = "1" /* Reposition Tongue, External Approach */
"0CSB0ZZ" = "1" /* Reposition Right Parotid Duct, Open Approach */
"0CSB3ZZ" = "1" /* Reposition Right Parotid Duct, Percutaneous Approach */
"0CSC0ZZ" = "1" /* Reposition Left Parotid Duct, Open Approach */
"0CSC3ZZ" = "1" /* Reposition Left Parotid Duct, Percutaneous Approach */
"0CSN0ZZ" = "1" /* Reposition Uvula, Open Approach */
"0CSNXZZ" = "1" /* Reposition Uvula, External Approach */
"0CSR0ZZ" = "1" /* Reposition Epiglottis, Open Approach */
"0CSR7ZZ" = "1" /* Reposition Epiglottis, Via Natural or Artificial Opening */
"0CSR8ZZ" = "1" /* Reposition Epiglottis, Via Natural or Artificial Opening Endoscopic */
"0CST0ZZ" = "1" /* Reposition Right Vocal Cord, Open Approach */
"0CST7ZZ" = "1" /* Reposition Right Vocal Cord, Via Natural or Artificial Opening */
"0CST8ZZ" = "1" /* Reposition Right Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CSV0ZZ" = "1" /* Reposition Left Vocal Cord, Open Approach */
"0CSV7ZZ" = "1" /* Reposition Left Vocal Cord, Via Natural or Artificial Opening */
"0CSV8ZZ" = "1" /* Reposition Left Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CT00ZZ" = "1" /* Resection of Upper Lip, Open Approach */
"0CT0XZZ" = "1" /* Resection of Upper Lip, External Approach */
"0CT10ZZ" = "1" /* Resection of Lower Lip, Open Approach */
"0CT1XZZ" = "1" /* Resection of Lower Lip, External Approach */
"0CT20ZZ" = "1" /* Resection of Hard Palate, Open Approach */
"0CT2XZZ" = "1" /* Resection of Hard Palate, External Approach */
"0CT30ZZ" = "1" /* Resection of Soft Palate, Open Approach */
"0CT3XZZ" = "1" /* Resection of Soft Palate, External Approach */
"0CT70ZZ" = "1" /* Resection of Tongue, Open Approach */
"0CT7XZZ" = "1" /* Resection of Tongue, External Approach */
"0CT80ZZ" = "1" /* Resection of Right Parotid Gland, Open Approach */
"0CT90ZZ" = "1" /* Resection of Left Parotid Gland, Open Approach */
"0CTB0ZZ" = "1" /* Resection of Right Parotid Duct, Open Approach */
"0CTC0ZZ" = "1" /* Resection of Left Parotid Duct, Open Approach */
"0CTD0ZZ" = "1" /* Resection of Right Sublingual Gland, Open Approach */
"0CTF0ZZ" = "1" /* Resection of Left Sublingual Gland, Open Approach */
"0CTG0ZZ" = "1" /* Resection of Right Submaxillary Gland, Open Approach */
"0CTH0ZZ" = "1" /* Resection of Left Submaxillary Gland, Open Approach */
"0CTJ0ZZ" = "1" /* Resection of Minor Salivary Gland, Open Approach */
"0CTM0ZZ" = "1" /* Resection of Pharynx, Open Approach */
"0CTM4ZZ" = "1" /* Resection of Pharynx, Percutaneous Endoscopic Approach */
"0CTM7ZZ" = "1" /* Resection of Pharynx, Via Natural or Artificial Opening */
"0CTM8ZZ" = "1" /* Resection of Pharynx, Via Natural or Artificial Opening Endoscopic */
"0CTN0ZZ" = "1" /* Resection of Uvula, Open Approach */
"0CTNXZZ" = "1" /* Resection of Uvula, External Approach */
"0CTP0ZZ" = "1" /* Resection of Tonsils, Open Approach */
"0CTPXZZ" = "1" /* Resection of Tonsils, External Approach */
"0CTQ0ZZ" = "1" /* Resection of Adenoids, Open Approach */
"0CTQXZZ" = "1" /* Resection of Adenoids, External Approach */
"0CTR0ZZ" = "1" /* Resection of Epiglottis, Open Approach */
"0CTR4ZZ" = "1" /* Resection of Epiglottis, Percutaneous Endoscopic Approach */
"0CTR7ZZ" = "1" /* Resection of Epiglottis, Via Natural or Artificial Opening */
"0CTR8ZZ" = "1" /* Resection of Epiglottis, Via Natural or Artificial Opening Endoscopic */
"0CTS0ZZ" = "1" /* Resection of Larynx, Open Approach */
"0CTS4ZZ" = "1" /* Resection of Larynx, Percutaneous Endoscopic Approach */
"0CTS7ZZ" = "1" /* Resection of Larynx, Via Natural or Artificial Opening */
"0CTS8ZZ" = "1" /* Resection of Larynx, Via Natural or Artificial Opening Endoscopic */
"0CTT0ZZ" = "1" /* Resection of Right Vocal Cord, Open Approach */
"0CTT4ZZ" = "1" /* Resection of Right Vocal Cord, Percutaneous Endoscopic Approach */
"0CTT7ZZ" = "1" /* Resection of Right Vocal Cord, Via Natural or Artificial Opening */
"0CTT8ZZ" = "1" /* Resection of Right Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CTV0ZZ" = "1" /* Resection of Left Vocal Cord, Open Approach */
"0CTV4ZZ" = "1" /* Resection of Left Vocal Cord, Percutaneous Endoscopic Approach */
"0CTV7ZZ" = "1" /* Resection of Left Vocal Cord, Via Natural or Artificial Opening */
"0CTV8ZZ" = "1" /* Resection of Left Vocal Cord, Via Natural or Artificial Opening Endoscopic */
"0CU007Z" = "1" /* Supplement Upper Lip with Autologous Tissue Substitute, Open Approach */
"0CU00JZ" = "1" /* Supplement Upper Lip with Synthetic Substitute, Open Approach */
"0CU00KZ" = "1" /* Supplement Upper Lip with Nonautologous Tissue Substitute, Open Approach */
"0CU037Z" = "1" /* Supplement Upper Lip with Autologous Tissue Substitute, Percutaneous Approach */
"0CU03JZ" = "1" /* Supplement Upper Lip with Synthetic Substitute, Percutaneous Approach */
"0CU03KZ" = "1" /* Supplement Upper Lip with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CU0X7Z" = "1" /* Supplement Upper Lip with Autologous Tissue Substitute, External Approach */
"0CU0XJZ" = "1" /* Supplement Upper Lip with Synthetic Substitute, External Approach */
"0CU0XKZ" = "1" /* Supplement Upper Lip with Nonautologous Tissue Substitute, External Approach */
"0CU107Z" = "1" /* Supplement Lower Lip with Autologous Tissue Substitute, Open Approach */
"0CU10JZ" = "1" /* Supplement Lower Lip with Synthetic Substitute, Open Approach */
"0CU10KZ" = "1" /* Supplement Lower Lip with Nonautologous Tissue Substitute, Open Approach */
"0CU137Z" = "1" /* Supplement Lower Lip with Autologous Tissue Substitute, Percutaneous Approach */
"0CU13JZ" = "1" /* Supplement Lower Lip with Synthetic Substitute, Percutaneous Approach */
"0CU13KZ" = "1" /* Supplement Lower Lip with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CU1X7Z" = "1" /* Supplement Lower Lip with Autologous Tissue Substitute, External Approach */
"0CU1XJZ" = "1" /* Supplement Lower Lip with Synthetic Substitute, External Approach */
"0CU1XKZ" = "1" /* Supplement Lower Lip with Nonautologous Tissue Substitute, External Approach */
"0CU207Z" = "1" /* Supplement Hard Palate with Autologous Tissue Substitute, Open Approach */
"0CU20KZ" = "1" /* Supplement Hard Palate with Nonautologous Tissue Substitute, Open Approach */
"0CU237Z" = "1" /* Supplement Hard Palate with Autologous Tissue Substitute, Percutaneous Approach */
"0CU23KZ" = "1" /* Supplement Hard Palate with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CU2X7Z" = "1" /* Supplement Hard Palate with Autologous Tissue Substitute, External Approach */
"0CU2XJZ" = "1" /* Supplement Hard Palate with Synthetic Substitute, External Approach */
"0CU2XKZ" = "1" /* Supplement Hard Palate with Nonautologous Tissue Substitute, External Approach */
"0CU307Z" = "1" /* Supplement Soft Palate with Autologous Tissue Substitute, Open Approach */
"0CU30JZ" = "1" /* Supplement Soft Palate with Synthetic Substitute, Open Approach */
"0CU30KZ" = "1" /* Supplement Soft Palate with Nonautologous Tissue Substitute, Open Approach */
"0CU337Z" = "1" /* Supplement Soft Palate with Autologous Tissue Substitute, Percutaneous Approach */
"0CU33JZ" = "1" /* Supplement Soft Palate with Synthetic Substitute, Percutaneous Approach */
"0CU33KZ" = "1" /* Supplement Soft Palate with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CU3X7Z" = "1" /* Supplement Soft Palate with Autologous Tissue Substitute, External Approach */
"0CU3XJZ" = "1" /* Supplement Soft Palate with Synthetic Substitute, External Approach */
"0CU3XKZ" = "1" /* Supplement Soft Palate with Nonautologous Tissue Substitute, External Approach */
"0CU407Z" = "1" /* Supplement Buccal Mucosa with Autologous Tissue Substitute, Open Approach */
"0CU40JZ" = "1" /* Supplement Buccal Mucosa with Synthetic Substitute, Open Approach */
"0CU40KZ" = "1" /* Supplement Buccal Mucosa with Nonautologous Tissue Substitute, Open Approach */
"0CU437Z" = "1" /* Supplement Buccal Mucosa with Autologous Tissue Substitute, Percutaneous Approach */
"0CU43JZ" = "1" /* Supplement Buccal Mucosa with Synthetic Substitute, Percutaneous Approach */
"0CU43KZ" = "1" /* Supplement Buccal Mucosa with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CU4X7Z" = "1" /* Supplement Buccal Mucosa with Autologous Tissue Substitute, External Approach */
"0CU4XJZ" = "1" /* Supplement Buccal Mucosa with Synthetic Substitute, External Approach */
"0CU4XKZ" = "1" /* Supplement Buccal Mucosa with Nonautologous Tissue Substitute, External Approach */
"0CU507Z" = "1" /* Supplement Upper Gingiva with Autologous Tissue Substitute, Open Approach */
"0CU50JZ" = "1" /* Supplement Upper Gingiva with Synthetic Substitute, Open Approach */
"0CU50KZ" = "1" /* Supplement Upper Gingiva with Nonautologous Tissue Substitute, Open Approach */
"0CU537Z" = "1" /* Supplement Upper Gingiva with Autologous Tissue Substitute, Percutaneous Approach */
"0CU53JZ" = "1" /* Supplement Upper Gingiva with Synthetic Substitute, Percutaneous Approach */
"0CU53KZ" = "1" /* Supplement Upper Gingiva with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CU5X7Z" = "1" /* Supplement Upper Gingiva with Autologous Tissue Substitute, External Approach */
"0CU5XJZ" = "1" /* Supplement Upper Gingiva with Synthetic Substitute, External Approach */
"0CU5XKZ" = "1" /* Supplement Upper Gingiva with Nonautologous Tissue Substitute, External Approach */
"0CU607Z" = "1" /* Supplement Lower Gingiva with Autologous Tissue Substitute, Open Approach */
"0CU60JZ" = "1" /* Supplement Lower Gingiva with Synthetic Substitute, Open Approach */
"0CU60KZ" = "1" /* Supplement Lower Gingiva with Nonautologous Tissue Substitute, Open Approach */
"0CU637Z" = "1" /* Supplement Lower Gingiva with Autologous Tissue Substitute, Percutaneous Approach */
"0CU63JZ" = "1" /* Supplement Lower Gingiva with Synthetic Substitute, Percutaneous Approach */
"0CU63KZ" = "1" /* Supplement Lower Gingiva with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CU6X7Z" = "1" /* Supplement Lower Gingiva with Autologous Tissue Substitute, External Approach */
"0CU6XJZ" = "1" /* Supplement Lower Gingiva with Synthetic Substitute, External Approach */
"0CU6XKZ" = "1" /* Supplement Lower Gingiva with Nonautologous Tissue Substitute, External Approach */
"0CU707Z" = "1" /* Supplement Tongue with Autologous Tissue Substitute, Open Approach */
"0CU70JZ" = "1" /* Supplement Tongue with Synthetic Substitute, Open Approach */
"0CU70KZ" = "1" /* Supplement Tongue with Nonautologous Tissue Substitute, Open Approach */
"0CU737Z" = "1" /* Supplement Tongue with Autologous Tissue Substitute, Percutaneous Approach */
"0CU73JZ" = "1" /* Supplement Tongue with Synthetic Substitute, Percutaneous Approach */
"0CU73KZ" = "1" /* Supplement Tongue with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CU7X7Z" = "1" /* Supplement Tongue with Autologous Tissue Substitute, External Approach */
"0CU7XJZ" = "1" /* Supplement Tongue with Synthetic Substitute, External Approach */
"0CU7XKZ" = "1" /* Supplement Tongue with Nonautologous Tissue Substitute, External Approach */
"0CUM07Z" = "1" /* Supplement Pharynx with Autologous Tissue Substitute, Open Approach */
"0CUM0JZ" = "1" /* Supplement Pharynx with Synthetic Substitute, Open Approach */
"0CUM0KZ" = "1" /* Supplement Pharynx with Nonautologous Tissue Substitute, Open Approach */
"0CUM77Z" = "1" /* Supplement Pharynx with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0CUM7JZ" = "1" /* Supplement Pharynx with Synthetic Substitute, Via Natural or Artificial Opening */
"0CUM7KZ" = "1" /* Supplement Pharynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0CUM87Z" = "1" /* Supplement Pharynx with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUM8JZ" = "1" /* Supplement Pharynx with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUM8KZ" = "1" /* Supplement Pharynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUN07Z" = "1" /* Supplement Uvula with Autologous Tissue Substitute, Open Approach */
"0CUN0JZ" = "1" /* Supplement Uvula with Synthetic Substitute, Open Approach */
"0CUN0KZ" = "1" /* Supplement Uvula with Nonautologous Tissue Substitute, Open Approach */
"0CUN37Z" = "1" /* Supplement Uvula with Autologous Tissue Substitute, Percutaneous Approach */
"0CUN3JZ" = "1" /* Supplement Uvula with Synthetic Substitute, Percutaneous Approach */
"0CUN3KZ" = "1" /* Supplement Uvula with Nonautologous Tissue Substitute, Percutaneous Approach */
"0CUNX7Z" = "1" /* Supplement Uvula with Autologous Tissue Substitute, External Approach */
"0CUNXJZ" = "1" /* Supplement Uvula with Synthetic Substitute, External Approach */
"0CUNXKZ" = "1" /* Supplement Uvula with Nonautologous Tissue Substitute, External Approach */
"0CUR07Z" = "1" /* Supplement Epiglottis with Autologous Tissue Substitute, Open Approach */
"0CUR0JZ" = "1" /* Supplement Epiglottis with Synthetic Substitute, Open Approach */
"0CUR0KZ" = "1" /* Supplement Epiglottis with Nonautologous Tissue Substitute, Open Approach */
"0CUR77Z" = "1" /* Supplement Epiglottis with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0CUR7JZ" = "1" /* Supplement Epiglottis with Synthetic Substitute, Via Natural or Artificial Opening */
"0CUR7KZ" = "1" /* Supplement Epiglottis with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0CUR87Z" = "1" /* Supplement Epiglottis with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUR8JZ" = "1" /* Supplement Epiglottis with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUR8KZ" = "1" /* Supplement Epiglottis with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUS07Z" = "1" /* Supplement Larynx with Autologous Tissue Substitute, Open Approach */
"0CUS0JZ" = "1" /* Supplement Larynx with Synthetic Substitute, Open Approach */
"0CUS0KZ" = "1" /* Supplement Larynx with Nonautologous Tissue Substitute, Open Approach */
"0CUS77Z" = "1" /* Supplement Larynx with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0CUS7JZ" = "1" /* Supplement Larynx with Synthetic Substitute, Via Natural or Artificial Opening */
"0CUS7KZ" = "1" /* Supplement Larynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0CUS87Z" = "1" /* Supplement Larynx with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUS8JZ" = "1" /* Supplement Larynx with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUS8KZ" = "1" /* Supplement Larynx with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUT07Z" = "1" /* Supplement Right Vocal Cord with Autologous Tissue Substitute, Open Approach */
"0CUT0JZ" = "1" /* Supplement Right Vocal Cord with Synthetic Substitute, Open Approach */
"0CUT0KZ" = "1" /* Supplement Right Vocal Cord with Nonautologous Tissue Substitute, Open Approach */
"0CUT77Z" = "1" /* Supplement Right Vocal Cord with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0CUT7JZ" = "1" /* Supplement Right Vocal Cord with Synthetic Substitute, Via Natural or Artificial Opening */
"0CUT7KZ" = "1" /* Supplement Right Vocal Cord with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0CUT87Z" = "1" /* Supplement Right Vocal Cord with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUT8JZ" = "1" /* Supplement Right Vocal Cord with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUT8KZ" = "1" /* Supplement Right Vocal Cord with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUV07Z" = "1" /* Supplement Left Vocal Cord with Autologous Tissue Substitute, Open Approach */
"0CUV0JZ" = "1" /* Supplement Left Vocal Cord with Synthetic Substitute, Open Approach */
"0CUV0KZ" = "1" /* Supplement Left Vocal Cord with Nonautologous Tissue Substitute, Open Approach */
"0CUV77Z" = "1" /* Supplement Left Vocal Cord with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0CUV7JZ" = "1" /* Supplement Left Vocal Cord with Synthetic Substitute, Via Natural or Artificial Opening */
"0CUV7KZ" = "1" /* Supplement Left Vocal Cord with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0CUV87Z" = "1" /* Supplement Left Vocal Cord with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUV8JZ" = "1" /* Supplement Left Vocal Cord with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0CUV8KZ" = "1" /* Supplement Left Vocal Cord with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0CVB0CZ" = "1" /* Restriction of Right Parotid Duct with Extraluminal Device, Open Approach */
"0CVB0DZ" = "1" /* Restriction of Right Parotid Duct with Intraluminal Device, Open Approach */
"0CVB0ZZ" = "1" /* Restriction of Right Parotid Duct, Open Approach */
"0CVB3CZ" = "1" /* Restriction of Right Parotid Duct with Extraluminal Device, Percutaneous Approach */
"0CVB3DZ" = "1" /* Restriction of Right Parotid Duct with Intraluminal Device, Percutaneous Approach */
"0CVB3ZZ" = "1" /* Restriction of Right Parotid Duct, Percutaneous Approach */
"0CVB7DZ" = "1" /* Restriction of Right Parotid Duct with Intraluminal Device, Via Natural or Artificial Opening */
"0CVB7ZZ" = "1" /* Restriction of Right Parotid Duct, Via Natural or Artificial Opening */
"0CVB8DZ" = "1" /* Restriction of Right Parotid Duct with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0CVB8ZZ" = "1" /* Restriction of Right Parotid Duct, Via Natural or Artificial Opening Endoscopic */
"0CVC0CZ" = "1" /* Restriction of Left Parotid Duct with Extraluminal Device, Open Approach */
"0CVC0DZ" = "1" /* Restriction of Left Parotid Duct with Intraluminal Device, Open Approach */
"0CVC0ZZ" = "1" /* Restriction of Left Parotid Duct, Open Approach */
"0CVC3CZ" = "1" /* Restriction of Left Parotid Duct with Extraluminal Device, Percutaneous Approach */
"0CVC3DZ" = "1" /* Restriction of Left Parotid Duct with Intraluminal Device, Percutaneous Approach */
"0CVC3ZZ" = "1" /* Restriction of Left Parotid Duct, Percutaneous Approach */
"0CVC7DZ" = "1" /* Restriction of Left Parotid Duct with Intraluminal Device, Via Natural or Artificial Opening */
"0CVC7ZZ" = "1" /* Restriction of Left Parotid Duct, Via Natural or Artificial Opening */
"0CVC8DZ" = "1" /* Restriction of Left Parotid Duct with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0CVC8ZZ" = "1" /* Restriction of Left Parotid Duct, Via Natural or Artificial Opening Endoscopic */
"0CWS00Z" = "1" /* Revision of Drainage Device in Larynx, Open Approach */
"0CWS07Z" = "1" /* Revision of Autologous Tissue Substitute in Larynx, Open Approach */
"0CWS0DZ" = "1" /* Revision of Intraluminal Device in Larynx, Open Approach */
"0CWS0JZ" = "1" /* Revision of Synthetic Substitute in Larynx, Open Approach */
"0CWS0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Larynx, Open Approach */
"0CWS30Z" = "1" /* Revision of Drainage Device in Larynx, Percutaneous Approach */
"0CWS37Z" = "1" /* Revision of Autologous Tissue Substitute in Larynx, Percutaneous Approach */
"0CWS3DZ" = "1" /* Revision of Intraluminal Device in Larynx, Percutaneous Approach */
"0CWS3JZ" = "1" /* Revision of Synthetic Substitute in Larynx, Percutaneous Approach */
"0CWS3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Larynx, Percutaneous Approach */
"0CWS70Z" = "1" /* Revision of Drainage Device in Larynx, Via Natural or Artificial Opening */
"0CWS77Z" = "1" /* Revision of Autologous Tissue Substitute in Larynx, Via Natural or Artificial Opening */
"0CWS7DZ" = "1" /* Revision of Intraluminal Device in Larynx, Via Natural or Artificial Opening */
"0CWS7JZ" = "1" /* Revision of Synthetic Substitute in Larynx, Via Natural or Artificial Opening */
"0CWS7KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Larynx, Via Natural or Artificial Opening */
"0CWS80Z" = "1" /* Revision of Drainage Device in Larynx, Via Natural or Artificial Opening Endoscopic */
"0CWS87Z" = "1" /* Revision of Autologous Tissue Substitute in Larynx, Via Natural or Artificial Opening Endoscopic */
"0CWS8DZ" = "1" /* Revision of Intraluminal Device in Larynx, Via Natural or Artificial Opening Endoscopic */
"0CWS8JZ" = "1" /* Revision of Synthetic Substitute in Larynx, Via Natural or Artificial Opening Endoscopic */
"0CWS8KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Larynx, Via Natural or Artificial Opening Endoscopic */
"0CWY00Z" = "1" /* Revision of Drainage Device in Mouth and Throat, Open Approach */
"0CWY01Z" = "1" /* Revision of Radioactive Element in Mouth and Throat, Open Approach */
"0CWY0DZ" = "1" /* Revision of Intraluminal Device in Mouth and Throat, Open Approach */
"0CWY0JZ" = "1" /* Revision of Synthetic Substitute in Mouth and Throat, Open Approach */
"0CWY0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mouth and Throat, Open Approach */
"0CWY30Z" = "1" /* Revision of Drainage Device in Mouth and Throat, Percutaneous Approach */
"0CWY31Z" = "1" /* Revision of Radioactive Element in Mouth and Throat, Percutaneous Approach */
"0CWY37Z" = "1" /* Revision of Autologous Tissue Substitute in Mouth and Throat, Percutaneous Approach */
"0CWY3DZ" = "1" /* Revision of Intraluminal Device in Mouth and Throat, Percutaneous Approach */
"0CWY3JZ" = "1" /* Revision of Synthetic Substitute in Mouth and Throat, Percutaneous Approach */
"0CWY3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mouth and Throat, Percutaneous Approach */
"0CWY70Z" = "1" /* Revision of Drainage Device in Mouth and Throat, Via Natural or Artificial Opening */
"0CWY71Z" = "1" /* Revision of Radioactive Element in Mouth and Throat, Via Natural or Artificial Opening */
"0CWY77Z" = "1" /* Revision of Autologous Tissue Substitute in Mouth and Throat, Via Natural or Artificial Opening */
"0CWY7DZ" = "1" /* Revision of Intraluminal Device in Mouth and Throat, Via Natural or Artificial Opening */
"0CWY7JZ" = "1" /* Revision of Synthetic Substitute in Mouth and Throat, Via Natural or Artificial Opening */
"0CWY7KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mouth and Throat, Via Natural or Artificial Opening */
"0CWY80Z" = "1" /* Revision of Drainage Device in Mouth and Throat, Via Natural or Artificial Opening Endoscopic */
"0CWY81Z" = "1" /* Revision of Radioactive Element in Mouth and Throat, Via Natural or Artificial Opening Endoscopic */
"0CWY87Z" = "1" /* Revision of Autologous Tissue Substitute in Mouth and Throat, Via Natural or Artificial Opening Endoscopic */
"0CWY8DZ" = "1" /* Revision of Intraluminal Device in Mouth and Throat, Via Natural or Artificial Opening Endoscopic */
"0CWY8JZ" = "1" /* Revision of Synthetic Substitute in Mouth and Throat, Via Natural or Artificial Opening Endoscopic */
"0CWY8KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mouth and Throat, Via Natural or Artificial Opening Endoscopic */
"0CX00ZZ" = "1" /* Transfer Upper Lip, Open Approach */
"0CX0XZZ" = "1" /* Transfer Upper Lip, External Approach */
"0CX10ZZ" = "1" /* Transfer Lower Lip, Open Approach */
"0CX1XZZ" = "1" /* Transfer Lower Lip, External Approach */
"0CX30ZZ" = "1" /* Transfer Soft Palate, Open Approach */
"0CX3XZZ" = "1" /* Transfer Soft Palate, External Approach */
"0CX40ZZ" = "1" /* Transfer Buccal Mucosa, Open Approach */
"0CX4XZZ" = "1" /* Transfer Buccal Mucosa, External Approach */
"0CX50ZZ" = "1" /* Transfer Upper Gingiva, Open Approach */
"0CX60ZZ" = "1" /* Transfer Lower Gingiva, Open Approach */
"0CX70ZZ" = "1" /* Transfer Tongue, Open Approach */
"0CX7XZZ" = "1" /* Transfer Tongue, External Approach */
"0D11074" = "1" /* Bypass Upper Esophagus to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D11076" = "1" /* Bypass Upper Esophagus to Stomach with Autologous Tissue Substitute, Open Approach */
"0D11079" = "1" /* Bypass Upper Esophagus to Duodenum with Autologous Tissue Substitute, Open Approach */
"0D1107A" = "1" /* Bypass Upper Esophagus to Jejunum with Autologous Tissue Substitute, Open Approach */
"0D1107B" = "1" /* Bypass Upper Esophagus to Ileum with Autologous Tissue Substitute, Open Approach */
"0D110J4" = "1" /* Bypass Upper Esophagus to Cutaneous with Synthetic Substitute, Open Approach */
"0D110J6" = "1" /* Bypass Upper Esophagus to Stomach with Synthetic Substitute, Open Approach */
"0D110J9" = "1" /* Bypass Upper Esophagus to Duodenum with Synthetic Substitute, Open Approach */
"0D110JA" = "1" /* Bypass Upper Esophagus to Jejunum with Synthetic Substitute, Open Approach */
"0D110JB" = "1" /* Bypass Upper Esophagus to Ileum with Synthetic Substitute, Open Approach */
"0D110K4" = "1" /* Bypass Upper Esophagus to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D110K6" = "1" /* Bypass Upper Esophagus to Stomach with Nonautologous Tissue Substitute, Open Approach */
"0D110K9" = "1" /* Bypass Upper Esophagus to Duodenum with Nonautologous Tissue Substitute, Open Approach */
"0D110KA" = "1" /* Bypass Upper Esophagus to Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0D110KB" = "1" /* Bypass Upper Esophagus to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D110Z4" = "1" /* Bypass Upper Esophagus to Cutaneous, Open Approach */
"0D110Z6" = "1" /* Bypass Upper Esophagus to Stomach, Open Approach */
"0D110Z9" = "1" /* Bypass Upper Esophagus to Duodenum, Open Approach */
"0D110ZA" = "1" /* Bypass Upper Esophagus to Jejunum, Open Approach */
"0D110ZB" = "1" /* Bypass Upper Esophagus to Ileum, Open Approach */
"0D113J4" = "1" /* Bypass Upper Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D11474" = "1" /* Bypass Upper Esophagus to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D11476" = "1" /* Bypass Upper Esophagus to Stomach with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D11479" = "1" /* Bypass Upper Esophagus to Duodenum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1147A" = "1" /* Bypass Upper Esophagus to Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1147B" = "1" /* Bypass Upper Esophagus to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D114J4" = "1" /* Bypass Upper Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D114J6" = "1" /* Bypass Upper Esophagus to Stomach with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D114J9" = "1" /* Bypass Upper Esophagus to Duodenum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D114JA" = "1" /* Bypass Upper Esophagus to Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D114JB" = "1" /* Bypass Upper Esophagus to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D114K4" = "1" /* Bypass Upper Esophagus to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D114K6" = "1" /* Bypass Upper Esophagus to Stomach with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D114K9" = "1" /* Bypass Upper Esophagus to Duodenum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D114KA" = "1" /* Bypass Upper Esophagus to Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D114KB" = "1" /* Bypass Upper Esophagus to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D114Z4" = "1" /* Bypass Upper Esophagus to Cutaneous, Percutaneous Endoscopic Approach */
"0D114Z6" = "1" /* Bypass Upper Esophagus to Stomach, Percutaneous Endoscopic Approach */
"0D114Z9" = "1" /* Bypass Upper Esophagus to Duodenum, Percutaneous Endoscopic Approach */
"0D114ZA" = "1" /* Bypass Upper Esophagus to Jejunum, Percutaneous Endoscopic Approach */
"0D114ZB" = "1" /* Bypass Upper Esophagus to Ileum, Percutaneous Endoscopic Approach */
"0D11874" = "1" /* Bypass Upper Esophagus to Cutaneous with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D11876" = "1" /* Bypass Upper Esophagus to Stomach with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D11879" = "1" /* Bypass Upper Esophagus to Duodenum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1187A" = "1" /* Bypass Upper Esophagus to Jejunum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1187B" = "1" /* Bypass Upper Esophagus to Ileum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118J4" = "1" /* Bypass Upper Esophagus to Cutaneous with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118J6" = "1" /* Bypass Upper Esophagus to Stomach with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118J9" = "1" /* Bypass Upper Esophagus to Duodenum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118JA" = "1" /* Bypass Upper Esophagus to Jejunum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118JB" = "1" /* Bypass Upper Esophagus to Ileum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118K4" = "1" /* Bypass Upper Esophagus to Cutaneous with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118K6" = "1" /* Bypass Upper Esophagus to Stomach with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118K9" = "1" /* Bypass Upper Esophagus to Duodenum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118KA" = "1" /* Bypass Upper Esophagus to Jejunum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118KB" = "1" /* Bypass Upper Esophagus to Ileum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118Z4" = "1" /* Bypass Upper Esophagus to Cutaneous, Via Natural or Artificial Opening Endoscopic */
"0D118Z6" = "1" /* Bypass Upper Esophagus to Stomach, Via Natural or Artificial Opening Endoscopic */
"0D118Z9" = "1" /* Bypass Upper Esophagus to Duodenum, Via Natural or Artificial Opening Endoscopic */
"0D118ZA" = "1" /* Bypass Upper Esophagus to Jejunum, Via Natural or Artificial Opening Endoscopic */
"0D118ZB" = "1" /* Bypass Upper Esophagus to Ileum, Via Natural or Artificial Opening Endoscopic */
"0D12074" = "1" /* Bypass Middle Esophagus to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D12076" = "1" /* Bypass Middle Esophagus to Stomach with Autologous Tissue Substitute, Open Approach */
"0D12079" = "1" /* Bypass Middle Esophagus to Duodenum with Autologous Tissue Substitute, Open Approach */
"0D1207A" = "1" /* Bypass Middle Esophagus to Jejunum with Autologous Tissue Substitute, Open Approach */
"0D1207B" = "1" /* Bypass Middle Esophagus to Ileum with Autologous Tissue Substitute, Open Approach */
"0D120J4" = "1" /* Bypass Middle Esophagus to Cutaneous with Synthetic Substitute, Open Approach */
"0D120J6" = "1" /* Bypass Middle Esophagus to Stomach with Synthetic Substitute, Open Approach */
"0D120J9" = "1" /* Bypass Middle Esophagus to Duodenum with Synthetic Substitute, Open Approach */
"0D120JA" = "1" /* Bypass Middle Esophagus to Jejunum with Synthetic Substitute, Open Approach */
"0D120JB" = "1" /* Bypass Middle Esophagus to Ileum with Synthetic Substitute, Open Approach */
"0D120K4" = "1" /* Bypass Middle Esophagus to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D120K6" = "1" /* Bypass Middle Esophagus to Stomach with Nonautologous Tissue Substitute, Open Approach */
"0D120K9" = "1" /* Bypass Middle Esophagus to Duodenum with Nonautologous Tissue Substitute, Open Approach */
"0D120KA" = "1" /* Bypass Middle Esophagus to Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0D120KB" = "1" /* Bypass Middle Esophagus to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D120Z4" = "1" /* Bypass Middle Esophagus to Cutaneous, Open Approach */
"0D120Z6" = "1" /* Bypass Middle Esophagus to Stomach, Open Approach */
"0D120Z9" = "1" /* Bypass Middle Esophagus to Duodenum, Open Approach */
"0D120ZA" = "1" /* Bypass Middle Esophagus to Jejunum, Open Approach */
"0D120ZB" = "1" /* Bypass Middle Esophagus to Ileum, Open Approach */
"0D123J4" = "1" /* Bypass Middle Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D12474" = "1" /* Bypass Middle Esophagus to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D12476" = "1" /* Bypass Middle Esophagus to Stomach with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D12479" = "1" /* Bypass Middle Esophagus to Duodenum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1247A" = "1" /* Bypass Middle Esophagus to Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1247B" = "1" /* Bypass Middle Esophagus to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D124J4" = "1" /* Bypass Middle Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D124J6" = "1" /* Bypass Middle Esophagus to Stomach with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D124J9" = "1" /* Bypass Middle Esophagus to Duodenum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D124JA" = "1" /* Bypass Middle Esophagus to Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D124JB" = "1" /* Bypass Middle Esophagus to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D124K4" = "1" /* Bypass Middle Esophagus to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D124K6" = "1" /* Bypass Middle Esophagus to Stomach with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D124K9" = "1" /* Bypass Middle Esophagus to Duodenum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D124KA" = "1" /* Bypass Middle Esophagus to Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D124KB" = "1" /* Bypass Middle Esophagus to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D124Z4" = "1" /* Bypass Middle Esophagus to Cutaneous, Percutaneous Endoscopic Approach */
"0D124Z6" = "1" /* Bypass Middle Esophagus to Stomach, Percutaneous Endoscopic Approach */
"0D124Z9" = "1" /* Bypass Middle Esophagus to Duodenum, Percutaneous Endoscopic Approach */
"0D124ZA" = "1" /* Bypass Middle Esophagus to Jejunum, Percutaneous Endoscopic Approach */
"0D124ZB" = "1" /* Bypass Middle Esophagus to Ileum, Percutaneous Endoscopic Approach */
"0D12874" = "1" /* Bypass Middle Esophagus to Cutaneous with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D12876" = "1" /* Bypass Middle Esophagus to Stomach with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D12879" = "1" /* Bypass Middle Esophagus to Duodenum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1287A" = "1" /* Bypass Middle Esophagus to Jejunum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1287B" = "1" /* Bypass Middle Esophagus to Ileum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128J4" = "1" /* Bypass Middle Esophagus to Cutaneous with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128J6" = "1" /* Bypass Middle Esophagus to Stomach with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128J9" = "1" /* Bypass Middle Esophagus to Duodenum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128JA" = "1" /* Bypass Middle Esophagus to Jejunum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128JB" = "1" /* Bypass Middle Esophagus to Ileum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128K4" = "1" /* Bypass Middle Esophagus to Cutaneous with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128K6" = "1" /* Bypass Middle Esophagus to Stomach with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128K9" = "1" /* Bypass Middle Esophagus to Duodenum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128KA" = "1" /* Bypass Middle Esophagus to Jejunum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128KB" = "1" /* Bypass Middle Esophagus to Ileum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128Z4" = "1" /* Bypass Middle Esophagus to Cutaneous, Via Natural or Artificial Opening Endoscopic */
"0D128Z6" = "1" /* Bypass Middle Esophagus to Stomach, Via Natural or Artificial Opening Endoscopic */
"0D128Z9" = "1" /* Bypass Middle Esophagus to Duodenum, Via Natural or Artificial Opening Endoscopic */
"0D128ZA" = "1" /* Bypass Middle Esophagus to Jejunum, Via Natural or Artificial Opening Endoscopic */
"0D128ZB" = "1" /* Bypass Middle Esophagus to Ileum, Via Natural or Artificial Opening Endoscopic */
"0D13074" = "1" /* Bypass Lower Esophagus to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D13076" = "1" /* Bypass Lower Esophagus to Stomach with Autologous Tissue Substitute, Open Approach */
"0D13079" = "1" /* Bypass Lower Esophagus to Duodenum with Autologous Tissue Substitute, Open Approach */
"0D1307A" = "1" /* Bypass Lower Esophagus to Jejunum with Autologous Tissue Substitute, Open Approach */
"0D1307B" = "1" /* Bypass Lower Esophagus to Ileum with Autologous Tissue Substitute, Open Approach */
"0D130J4" = "1" /* Bypass Lower Esophagus to Cutaneous with Synthetic Substitute, Open Approach */
"0D130J6" = "1" /* Bypass Lower Esophagus to Stomach with Synthetic Substitute, Open Approach */
"0D130J9" = "1" /* Bypass Lower Esophagus to Duodenum with Synthetic Substitute, Open Approach */
"0D130JA" = "1" /* Bypass Lower Esophagus to Jejunum with Synthetic Substitute, Open Approach */
"0D130JB" = "1" /* Bypass Lower Esophagus to Ileum with Synthetic Substitute, Open Approach */
"0D130K4" = "1" /* Bypass Lower Esophagus to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D130K6" = "1" /* Bypass Lower Esophagus to Stomach with Nonautologous Tissue Substitute, Open Approach */
"0D130K9" = "1" /* Bypass Lower Esophagus to Duodenum with Nonautologous Tissue Substitute, Open Approach */
"0D130KA" = "1" /* Bypass Lower Esophagus to Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0D130KB" = "1" /* Bypass Lower Esophagus to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D130Z4" = "1" /* Bypass Lower Esophagus to Cutaneous, Open Approach */
"0D130Z6" = "1" /* Bypass Lower Esophagus to Stomach, Open Approach */
"0D130Z9" = "1" /* Bypass Lower Esophagus to Duodenum, Open Approach */
"0D130ZA" = "1" /* Bypass Lower Esophagus to Jejunum, Open Approach */
"0D130ZB" = "1" /* Bypass Lower Esophagus to Ileum, Open Approach */
"0D133J4" = "1" /* Bypass Lower Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D13474" = "1" /* Bypass Lower Esophagus to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D13476" = "1" /* Bypass Lower Esophagus to Stomach with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D13479" = "1" /* Bypass Lower Esophagus to Duodenum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1347A" = "1" /* Bypass Lower Esophagus to Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1347B" = "1" /* Bypass Lower Esophagus to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134J4" = "1" /* Bypass Lower Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D134J6" = "1" /* Bypass Lower Esophagus to Stomach with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D134J9" = "1" /* Bypass Lower Esophagus to Duodenum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D134JA" = "1" /* Bypass Lower Esophagus to Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D134JB" = "1" /* Bypass Lower Esophagus to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D134K4" = "1" /* Bypass Lower Esophagus to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134K6" = "1" /* Bypass Lower Esophagus to Stomach with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134K9" = "1" /* Bypass Lower Esophagus to Duodenum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134KA" = "1" /* Bypass Lower Esophagus to Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134KB" = "1" /* Bypass Lower Esophagus to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134Z4" = "1" /* Bypass Lower Esophagus to Cutaneous, Percutaneous Endoscopic Approach */
"0D134Z6" = "1" /* Bypass Lower Esophagus to Stomach, Percutaneous Endoscopic Approach */
"0D134Z9" = "1" /* Bypass Lower Esophagus to Duodenum, Percutaneous Endoscopic Approach */
"0D134ZA" = "1" /* Bypass Lower Esophagus to Jejunum, Percutaneous Endoscopic Approach */
"0D134ZB" = "1" /* Bypass Lower Esophagus to Ileum, Percutaneous Endoscopic Approach */
"0D13874" = "1" /* Bypass Lower Esophagus to Cutaneous with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D13876" = "1" /* Bypass Lower Esophagus to Stomach with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D13879" = "1" /* Bypass Lower Esophagus to Duodenum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1387A" = "1" /* Bypass Lower Esophagus to Jejunum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1387B" = "1" /* Bypass Lower Esophagus to Ileum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138J4" = "1" /* Bypass Lower Esophagus to Cutaneous with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138J6" = "1" /* Bypass Lower Esophagus to Stomach with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138J9" = "1" /* Bypass Lower Esophagus to Duodenum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138JA" = "1" /* Bypass Lower Esophagus to Jejunum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138JB" = "1" /* Bypass Lower Esophagus to Ileum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138K4" = "1" /* Bypass Lower Esophagus to Cutaneous with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138K6" = "1" /* Bypass Lower Esophagus to Stomach with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138K9" = "1" /* Bypass Lower Esophagus to Duodenum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138KA" = "1" /* Bypass Lower Esophagus to Jejunum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138KB" = "1" /* Bypass Lower Esophagus to Ileum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138Z4" = "1" /* Bypass Lower Esophagus to Cutaneous, Via Natural or Artificial Opening Endoscopic */
"0D138Z6" = "1" /* Bypass Lower Esophagus to Stomach, Via Natural or Artificial Opening Endoscopic */
"0D138Z9" = "1" /* Bypass Lower Esophagus to Duodenum, Via Natural or Artificial Opening Endoscopic */
"0D138ZA" = "1" /* Bypass Lower Esophagus to Jejunum, Via Natural or Artificial Opening Endoscopic */
"0D138ZB" = "1" /* Bypass Lower Esophagus to Ileum, Via Natural or Artificial Opening Endoscopic */
"0D15074" = "1" /* Bypass Esophagus to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D15076" = "1" /* Bypass Esophagus to Stomach with Autologous Tissue Substitute, Open Approach */
"0D15079" = "1" /* Bypass Esophagus to Duodenum with Autologous Tissue Substitute, Open Approach */
"0D1507A" = "1" /* Bypass Esophagus to Jejunum with Autologous Tissue Substitute, Open Approach */
"0D1507B" = "1" /* Bypass Esophagus to Ileum with Autologous Tissue Substitute, Open Approach */
"0D150J4" = "1" /* Bypass Esophagus to Cutaneous with Synthetic Substitute, Open Approach */
"0D150J6" = "1" /* Bypass Esophagus to Stomach with Synthetic Substitute, Open Approach */
"0D150J9" = "1" /* Bypass Esophagus to Duodenum with Synthetic Substitute, Open Approach */
"0D150JA" = "1" /* Bypass Esophagus to Jejunum with Synthetic Substitute, Open Approach */
"0D150JB" = "1" /* Bypass Esophagus to Ileum with Synthetic Substitute, Open Approach */
"0D150K4" = "1" /* Bypass Esophagus to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D150K6" = "1" /* Bypass Esophagus to Stomach with Nonautologous Tissue Substitute, Open Approach */
"0D150K9" = "1" /* Bypass Esophagus to Duodenum with Nonautologous Tissue Substitute, Open Approach */
"0D150KA" = "1" /* Bypass Esophagus to Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0D150KB" = "1" /* Bypass Esophagus to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D150Z4" = "1" /* Bypass Esophagus to Cutaneous, Open Approach */
"0D150Z6" = "1" /* Bypass Esophagus to Stomach, Open Approach */
"0D150Z9" = "1" /* Bypass Esophagus to Duodenum, Open Approach */
"0D150ZA" = "1" /* Bypass Esophagus to Jejunum, Open Approach */
"0D150ZB" = "1" /* Bypass Esophagus to Ileum, Open Approach */
"0D153J4" = "1" /* Bypass Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D15474" = "1" /* Bypass Esophagus to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D15476" = "1" /* Bypass Esophagus to Stomach with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D15479" = "1" /* Bypass Esophagus to Duodenum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1547A" = "1" /* Bypass Esophagus to Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1547B" = "1" /* Bypass Esophagus to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D154J4" = "1" /* Bypass Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D154J6" = "1" /* Bypass Esophagus to Stomach with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D154J9" = "1" /* Bypass Esophagus to Duodenum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D154JA" = "1" /* Bypass Esophagus to Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D154JB" = "1" /* Bypass Esophagus to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D154K4" = "1" /* Bypass Esophagus to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D154K6" = "1" /* Bypass Esophagus to Stomach with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D154K9" = "1" /* Bypass Esophagus to Duodenum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D154KA" = "1" /* Bypass Esophagus to Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D154KB" = "1" /* Bypass Esophagus to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D154Z4" = "1" /* Bypass Esophagus to Cutaneous, Percutaneous Endoscopic Approach */
"0D154Z6" = "1" /* Bypass Esophagus to Stomach, Percutaneous Endoscopic Approach */
"0D154Z9" = "1" /* Bypass Esophagus to Duodenum, Percutaneous Endoscopic Approach */
"0D154ZA" = "1" /* Bypass Esophagus to Jejunum, Percutaneous Endoscopic Approach */
"0D154ZB" = "1" /* Bypass Esophagus to Ileum, Percutaneous Endoscopic Approach */
"0D15874" = "1" /* Bypass Esophagus to Cutaneous with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D15876" = "1" /* Bypass Esophagus to Stomach with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D15879" = "1" /* Bypass Esophagus to Duodenum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1587A" = "1" /* Bypass Esophagus to Jejunum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1587B" = "1" /* Bypass Esophagus to Ileum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158J4" = "1" /* Bypass Esophagus to Cutaneous with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158J6" = "1" /* Bypass Esophagus to Stomach with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158J9" = "1" /* Bypass Esophagus to Duodenum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158JA" = "1" /* Bypass Esophagus to Jejunum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158JB" = "1" /* Bypass Esophagus to Ileum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158K4" = "1" /* Bypass Esophagus to Cutaneous with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158K6" = "1" /* Bypass Esophagus to Stomach with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158K9" = "1" /* Bypass Esophagus to Duodenum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158KA" = "1" /* Bypass Esophagus to Jejunum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158KB" = "1" /* Bypass Esophagus to Ileum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158Z4" = "1" /* Bypass Esophagus to Cutaneous, Via Natural or Artificial Opening Endoscopic */
"0D158Z6" = "1" /* Bypass Esophagus to Stomach, Via Natural or Artificial Opening Endoscopic */
"0D158Z9" = "1" /* Bypass Esophagus to Duodenum, Via Natural or Artificial Opening Endoscopic */
"0D158ZA" = "1" /* Bypass Esophagus to Jejunum, Via Natural or Artificial Opening Endoscopic */
"0D158ZB" = "1" /* Bypass Esophagus to Ileum, Via Natural or Artificial Opening Endoscopic */
"0D16079" = "1" /* Bypass Stomach to Duodenum with Autologous Tissue Substitute, Open Approach */
"0D1607A" = "1" /* Bypass Stomach to Jejunum with Autologous Tissue Substitute, Open Approach */
"0D1607B" = "1" /* Bypass Stomach to Ileum with Autologous Tissue Substitute, Open Approach */
"0D1607L" = "1" /* Bypass Stomach to Transverse Colon with Autologous Tissue Substitute, Open Approach */
"0D160J9" = "1" /* Bypass Stomach to Duodenum with Synthetic Substitute, Open Approach */
"0D160JA" = "1" /* Bypass Stomach to Jejunum with Synthetic Substitute, Open Approach */
"0D160JB" = "1" /* Bypass Stomach to Ileum with Synthetic Substitute, Open Approach */
"0D160JL" = "1" /* Bypass Stomach to Transverse Colon with Synthetic Substitute, Open Approach */
"0D160K9" = "1" /* Bypass Stomach to Duodenum with Nonautologous Tissue Substitute, Open Approach */
"0D160KA" = "1" /* Bypass Stomach to Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0D160KB" = "1" /* Bypass Stomach to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D160KL" = "1" /* Bypass Stomach to Transverse Colon with Nonautologous Tissue Substitute, Open Approach */
"0D160Z9" = "1" /* Bypass Stomach to Duodenum, Open Approach */
"0D160ZA" = "1" /* Bypass Stomach to Jejunum, Open Approach */
"0D160ZB" = "1" /* Bypass Stomach to Ileum, Open Approach */
"0D160ZL" = "1" /* Bypass Stomach to Transverse Colon, Open Approach */
"0D16479" = "1" /* Bypass Stomach to Duodenum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1647A" = "1" /* Bypass Stomach to Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1647B" = "1" /* Bypass Stomach to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1647L" = "1" /* Bypass Stomach to Transverse Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D164J9" = "1" /* Bypass Stomach to Duodenum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D164JA" = "1" /* Bypass Stomach to Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D164JB" = "1" /* Bypass Stomach to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D164JL" = "1" /* Bypass Stomach to Transverse Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D164K9" = "1" /* Bypass Stomach to Duodenum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D164KA" = "1" /* Bypass Stomach to Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D164KB" = "1" /* Bypass Stomach to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D164KL" = "1" /* Bypass Stomach to Transverse Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D164Z9" = "1" /* Bypass Stomach to Duodenum, Percutaneous Endoscopic Approach */
"0D164ZA" = "1" /* Bypass Stomach to Jejunum, Percutaneous Endoscopic Approach */
"0D164ZB" = "1" /* Bypass Stomach to Ileum, Percutaneous Endoscopic Approach */
"0D164ZL" = "1" /* Bypass Stomach to Transverse Colon, Percutaneous Endoscopic Approach */
"0D16879" = "1" /* Bypass Stomach to Duodenum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1687A" = "1" /* Bypass Stomach to Jejunum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1687B" = "1" /* Bypass Stomach to Ileum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1687L" = "1" /* Bypass Stomach to Transverse Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D168J9" = "1" /* Bypass Stomach to Duodenum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D168JA" = "1" /* Bypass Stomach to Jejunum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D168JB" = "1" /* Bypass Stomach to Ileum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D168JL" = "1" /* Bypass Stomach to Transverse Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D168K9" = "1" /* Bypass Stomach to Duodenum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D168KA" = "1" /* Bypass Stomach to Jejunum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D168KB" = "1" /* Bypass Stomach to Ileum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D168KL" = "1" /* Bypass Stomach to Transverse Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D168Z9" = "1" /* Bypass Stomach to Duodenum, Via Natural or Artificial Opening Endoscopic */
"0D168ZA" = "1" /* Bypass Stomach to Jejunum, Via Natural or Artificial Opening Endoscopic */
"0D168ZB" = "1" /* Bypass Stomach to Ileum, Via Natural or Artificial Opening Endoscopic */
"0D168ZL" = "1" /* Bypass Stomach to Transverse Colon, Via Natural or Artificial Opening Endoscopic */
"0D19074" = "1" /* Bypass Duodenum to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D19079" = "1" /* Bypass Duodenum to Duodenum with Autologous Tissue Substitute, Open Approach */
"0D1907A" = "1" /* Bypass Duodenum to Jejunum with Autologous Tissue Substitute, Open Approach */
"0D1907B" = "1" /* Bypass Duodenum to Ileum with Autologous Tissue Substitute, Open Approach */
"0D1907L" = "1" /* Bypass Duodenum to Transverse Colon with Autologous Tissue Substitute, Open Approach */
"0D190J4" = "1" /* Bypass Duodenum to Cutaneous with Synthetic Substitute, Open Approach */
"0D190J9" = "1" /* Bypass Duodenum to Duodenum with Synthetic Substitute, Open Approach */
"0D190JA" = "1" /* Bypass Duodenum to Jejunum with Synthetic Substitute, Open Approach */
"0D190JB" = "1" /* Bypass Duodenum to Ileum with Synthetic Substitute, Open Approach */
"0D190JL" = "1" /* Bypass Duodenum to Transverse Colon with Synthetic Substitute, Open Approach */
"0D190K4" = "1" /* Bypass Duodenum to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D190K9" = "1" /* Bypass Duodenum to Duodenum with Nonautologous Tissue Substitute, Open Approach */
"0D190KA" = "1" /* Bypass Duodenum to Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0D190KB" = "1" /* Bypass Duodenum to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D190KL" = "1" /* Bypass Duodenum to Transverse Colon with Nonautologous Tissue Substitute, Open Approach */
"0D190Z4" = "1" /* Bypass Duodenum to Cutaneous, Open Approach */
"0D190Z9" = "1" /* Bypass Duodenum to Duodenum, Open Approach */
"0D190ZA" = "1" /* Bypass Duodenum to Jejunum, Open Approach */
"0D190ZB" = "1" /* Bypass Duodenum to Ileum, Open Approach */
"0D190ZL" = "1" /* Bypass Duodenum to Transverse Colon, Open Approach */
"0D193J4" = "1" /* Bypass Duodenum to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D19474" = "1" /* Bypass Duodenum to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D19479" = "1" /* Bypass Duodenum to Duodenum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1947A" = "1" /* Bypass Duodenum to Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1947B" = "1" /* Bypass Duodenum to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1947L" = "1" /* Bypass Duodenum to Transverse Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D194J4" = "1" /* Bypass Duodenum to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D194J9" = "1" /* Bypass Duodenum to Duodenum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D194JA" = "1" /* Bypass Duodenum to Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D194JB" = "1" /* Bypass Duodenum to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D194JL" = "1" /* Bypass Duodenum to Transverse Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D194K4" = "1" /* Bypass Duodenum to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D194K9" = "1" /* Bypass Duodenum to Duodenum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D194KA" = "1" /* Bypass Duodenum to Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D194KB" = "1" /* Bypass Duodenum to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D194KL" = "1" /* Bypass Duodenum to Transverse Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D194Z4" = "1" /* Bypass Duodenum to Cutaneous, Percutaneous Endoscopic Approach */
"0D194Z9" = "1" /* Bypass Duodenum to Duodenum, Percutaneous Endoscopic Approach */
"0D194ZA" = "1" /* Bypass Duodenum to Jejunum, Percutaneous Endoscopic Approach */
"0D194ZB" = "1" /* Bypass Duodenum to Ileum, Percutaneous Endoscopic Approach */
"0D194ZL" = "1" /* Bypass Duodenum to Transverse Colon, Percutaneous Endoscopic Approach */
"0D19874" = "1" /* Bypass Duodenum to Cutaneous with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D19879" = "1" /* Bypass Duodenum to Duodenum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1987A" = "1" /* Bypass Duodenum to Jejunum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1987B" = "1" /* Bypass Duodenum to Ileum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1987L" = "1" /* Bypass Duodenum to Transverse Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D198J4" = "1" /* Bypass Duodenum to Cutaneous with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D198J9" = "1" /* Bypass Duodenum to Duodenum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D198JA" = "1" /* Bypass Duodenum to Jejunum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D198JB" = "1" /* Bypass Duodenum to Ileum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D198JL" = "1" /* Bypass Duodenum to Transverse Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D198K4" = "1" /* Bypass Duodenum to Cutaneous with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D198K9" = "1" /* Bypass Duodenum to Duodenum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D198KA" = "1" /* Bypass Duodenum to Jejunum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D198KB" = "1" /* Bypass Duodenum to Ileum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D198KL" = "1" /* Bypass Duodenum to Transverse Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D198Z4" = "1" /* Bypass Duodenum to Cutaneous, Via Natural or Artificial Opening Endoscopic */
"0D198Z9" = "1" /* Bypass Duodenum to Duodenum, Via Natural or Artificial Opening Endoscopic */
"0D198ZA" = "1" /* Bypass Duodenum to Jejunum, Via Natural or Artificial Opening Endoscopic */
"0D198ZB" = "1" /* Bypass Duodenum to Ileum, Via Natural or Artificial Opening Endoscopic */
"0D198ZL" = "1" /* Bypass Duodenum to Transverse Colon, Via Natural or Artificial Opening Endoscopic */
"0D1A074" = "1" /* Bypass Jejunum to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D1A07A" = "1" /* Bypass Jejunum to Jejunum with Autologous Tissue Substitute, Open Approach */
"0D1A07B" = "1" /* Bypass Jejunum to Ileum with Autologous Tissue Substitute, Open Approach */
"0D1A07H" = "1" /* Bypass Jejunum to Cecum with Autologous Tissue Substitute, Open Approach */
"0D1A07K" = "1" /* Bypass Jejunum to Ascending Colon with Autologous Tissue Substitute, Open Approach */
"0D1A07L" = "1" /* Bypass Jejunum to Transverse Colon with Autologous Tissue Substitute, Open Approach */
"0D1A07M" = "1" /* Bypass Jejunum to Descending Colon with Autologous Tissue Substitute, Open Approach */
"0D1A07N" = "1" /* Bypass Jejunum to Sigmoid Colon with Autologous Tissue Substitute, Open Approach */
"0D1A07P" = "1" /* Bypass Jejunum to Rectum with Autologous Tissue Substitute, Open Approach */
"0D1A07Q" = "1" /* Bypass Jejunum to Anus with Autologous Tissue Substitute, Open Approach */
"0D1A0J4" = "1" /* Bypass Jejunum to Cutaneous with Synthetic Substitute, Open Approach */
"0D1A0JA" = "1" /* Bypass Jejunum to Jejunum with Synthetic Substitute, Open Approach */
"0D1A0JB" = "1" /* Bypass Jejunum to Ileum with Synthetic Substitute, Open Approach */
"0D1A0JH" = "1" /* Bypass Jejunum to Cecum with Synthetic Substitute, Open Approach */
"0D1A0JK" = "1" /* Bypass Jejunum to Ascending Colon with Synthetic Substitute, Open Approach */
"0D1A0JL" = "1" /* Bypass Jejunum to Transverse Colon with Synthetic Substitute, Open Approach */
"0D1A0JM" = "1" /* Bypass Jejunum to Descending Colon with Synthetic Substitute, Open Approach */
"0D1A0JN" = "1" /* Bypass Jejunum to Sigmoid Colon with Synthetic Substitute, Open Approach */
"0D1A0JP" = "1" /* Bypass Jejunum to Rectum with Synthetic Substitute, Open Approach */
"0D1A0JQ" = "1" /* Bypass Jejunum to Anus with Synthetic Substitute, Open Approach */
"0D1A0K4" = "1" /* Bypass Jejunum to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D1A0KA" = "1" /* Bypass Jejunum to Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0D1A0KB" = "1" /* Bypass Jejunum to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D1A0KH" = "1" /* Bypass Jejunum to Cecum with Nonautologous Tissue Substitute, Open Approach */
"0D1A0KK" = "1" /* Bypass Jejunum to Ascending Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1A0KL" = "1" /* Bypass Jejunum to Transverse Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1A0KM" = "1" /* Bypass Jejunum to Descending Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1A0KN" = "1" /* Bypass Jejunum to Sigmoid Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1A0KP" = "1" /* Bypass Jejunum to Rectum with Nonautologous Tissue Substitute, Open Approach */
"0D1A0KQ" = "1" /* Bypass Jejunum to Anus with Nonautologous Tissue Substitute, Open Approach */
"0D1A0Z4" = "1" /* Bypass Jejunum to Cutaneous, Open Approach */
"0D1A0ZA" = "1" /* Bypass Jejunum to Jejunum, Open Approach */
"0D1A0ZB" = "1" /* Bypass Jejunum to Ileum, Open Approach */
"0D1A0ZH" = "1" /* Bypass Jejunum to Cecum, Open Approach */
"0D1A0ZK" = "1" /* Bypass Jejunum to Ascending Colon, Open Approach */
"0D1A0ZL" = "1" /* Bypass Jejunum to Transverse Colon, Open Approach */
"0D1A0ZM" = "1" /* Bypass Jejunum to Descending Colon, Open Approach */
"0D1A0ZN" = "1" /* Bypass Jejunum to Sigmoid Colon, Open Approach */
"0D1A0ZP" = "1" /* Bypass Jejunum to Rectum, Open Approach */
"0D1A0ZQ" = "1" /* Bypass Jejunum to Anus, Open Approach */
"0D1A3J4" = "1" /* Bypass Jejunum to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D1A474" = "1" /* Bypass Jejunum to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A47A" = "1" /* Bypass Jejunum to Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A47B" = "1" /* Bypass Jejunum to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A47H" = "1" /* Bypass Jejunum to Cecum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A47K" = "1" /* Bypass Jejunum to Ascending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A47L" = "1" /* Bypass Jejunum to Transverse Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A47M" = "1" /* Bypass Jejunum to Descending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A47N" = "1" /* Bypass Jejunum to Sigmoid Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A47P" = "1" /* Bypass Jejunum to Rectum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A47Q" = "1" /* Bypass Jejunum to Anus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A4J4" = "1" /* Bypass Jejunum to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1A4JA" = "1" /* Bypass Jejunum to Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1A4JB" = "1" /* Bypass Jejunum to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1A4JH" = "1" /* Bypass Jejunum to Cecum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1A4JK" = "1" /* Bypass Jejunum to Ascending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1A4JL" = "1" /* Bypass Jejunum to Transverse Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1A4JM" = "1" /* Bypass Jejunum to Descending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1A4JN" = "1" /* Bypass Jejunum to Sigmoid Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1A4JP" = "1" /* Bypass Jejunum to Rectum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1A4JQ" = "1" /* Bypass Jejunum to Anus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1A4K4" = "1" /* Bypass Jejunum to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A4KA" = "1" /* Bypass Jejunum to Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A4KB" = "1" /* Bypass Jejunum to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A4KH" = "1" /* Bypass Jejunum to Cecum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A4KK" = "1" /* Bypass Jejunum to Ascending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A4KL" = "1" /* Bypass Jejunum to Transverse Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A4KM" = "1" /* Bypass Jejunum to Descending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A4KN" = "1" /* Bypass Jejunum to Sigmoid Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A4KP" = "1" /* Bypass Jejunum to Rectum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A4KQ" = "1" /* Bypass Jejunum to Anus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1A4Z4" = "1" /* Bypass Jejunum to Cutaneous, Percutaneous Endoscopic Approach */
"0D1A4ZA" = "1" /* Bypass Jejunum to Jejunum, Percutaneous Endoscopic Approach */
"0D1A4ZB" = "1" /* Bypass Jejunum to Ileum, Percutaneous Endoscopic Approach */
"0D1A4ZH" = "1" /* Bypass Jejunum to Cecum, Percutaneous Endoscopic Approach */
"0D1A4ZK" = "1" /* Bypass Jejunum to Ascending Colon, Percutaneous Endoscopic Approach */
"0D1A4ZL" = "1" /* Bypass Jejunum to Transverse Colon, Percutaneous Endoscopic Approach */
"0D1A4ZM" = "1" /* Bypass Jejunum to Descending Colon, Percutaneous Endoscopic Approach */
"0D1A4ZN" = "1" /* Bypass Jejunum to Sigmoid Colon, Percutaneous Endoscopic Approach */
"0D1A4ZP" = "1" /* Bypass Jejunum to Rectum, Percutaneous Endoscopic Approach */
"0D1A4ZQ" = "1" /* Bypass Jejunum to Anus, Percutaneous Endoscopic Approach */
"0D1A874" = "1" /* Bypass Jejunum to Cutaneous with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A87A" = "1" /* Bypass Jejunum to Jejunum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A87B" = "1" /* Bypass Jejunum to Ileum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A87H" = "1" /* Bypass Jejunum to Cecum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A87K" = "1" /* Bypass Jejunum to Ascending Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A87L" = "1" /* Bypass Jejunum to Transverse Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A87M" = "1" /* Bypass Jejunum to Descending Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A87N" = "1" /* Bypass Jejunum to Sigmoid Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A87P" = "1" /* Bypass Jejunum to Rectum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A87Q" = "1" /* Bypass Jejunum to Anus with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A8J4" = "1" /* Bypass Jejunum to Cutaneous with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A8JA" = "1" /* Bypass Jejunum to Jejunum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A8JB" = "1" /* Bypass Jejunum to Ileum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A8JH" = "1" /* Bypass Jejunum to Cecum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A8JK" = "1" /* Bypass Jejunum to Ascending Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A8JL" = "1" /* Bypass Jejunum to Transverse Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A8JM" = "1" /* Bypass Jejunum to Descending Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A8JN" = "1" /* Bypass Jejunum to Sigmoid Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A8JP" = "1" /* Bypass Jejunum to Rectum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A8JQ" = "1" /* Bypass Jejunum to Anus with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A8K4" = "1" /* Bypass Jejunum to Cutaneous with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A8KA" = "1" /* Bypass Jejunum to Jejunum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A8KB" = "1" /* Bypass Jejunum to Ileum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A8KH" = "1" /* Bypass Jejunum to Cecum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A8KK" = "1" /* Bypass Jejunum to Ascending Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A8KL" = "1" /* Bypass Jejunum to Transverse Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A8KM" = "1" /* Bypass Jejunum to Descending Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A8KN" = "1" /* Bypass Jejunum to Sigmoid Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A8KP" = "1" /* Bypass Jejunum to Rectum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A8KQ" = "1" /* Bypass Jejunum to Anus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1A8Z4" = "1" /* Bypass Jejunum to Cutaneous, Via Natural or Artificial Opening Endoscopic */
"0D1A8ZA" = "1" /* Bypass Jejunum to Jejunum, Via Natural or Artificial Opening Endoscopic */
"0D1A8ZB" = "1" /* Bypass Jejunum to Ileum, Via Natural or Artificial Opening Endoscopic */
"0D1A8ZH" = "1" /* Bypass Jejunum to Cecum, Via Natural or Artificial Opening Endoscopic */
"0D1A8ZK" = "1" /* Bypass Jejunum to Ascending Colon, Via Natural or Artificial Opening Endoscopic */
"0D1A8ZL" = "1" /* Bypass Jejunum to Transverse Colon, Via Natural or Artificial Opening Endoscopic */
"0D1A8ZM" = "1" /* Bypass Jejunum to Descending Colon, Via Natural or Artificial Opening Endoscopic */
"0D1A8ZN" = "1" /* Bypass Jejunum to Sigmoid Colon, Via Natural or Artificial Opening Endoscopic */
"0D1A8ZP" = "1" /* Bypass Jejunum to Rectum, Via Natural or Artificial Opening Endoscopic */
"0D1A8ZQ" = "1" /* Bypass Jejunum to Anus, Via Natural or Artificial Opening Endoscopic */
"0D1B074" = "1" /* Bypass Ileum to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D1B07B" = "1" /* Bypass Ileum to Ileum with Autologous Tissue Substitute, Open Approach */
"0D1B07H" = "1" /* Bypass Ileum to Cecum with Autologous Tissue Substitute, Open Approach */
"0D1B07K" = "1" /* Bypass Ileum to Ascending Colon with Autologous Tissue Substitute, Open Approach */
"0D1B07L" = "1" /* Bypass Ileum to Transverse Colon with Autologous Tissue Substitute, Open Approach */
"0D1B07M" = "1" /* Bypass Ileum to Descending Colon with Autologous Tissue Substitute, Open Approach */
"0D1B07N" = "1" /* Bypass Ileum to Sigmoid Colon with Autologous Tissue Substitute, Open Approach */
"0D1B07P" = "1" /* Bypass Ileum to Rectum with Autologous Tissue Substitute, Open Approach */
"0D1B07Q" = "1" /* Bypass Ileum to Anus with Autologous Tissue Substitute, Open Approach */
"0D1B0J4" = "1" /* Bypass Ileum to Cutaneous with Synthetic Substitute, Open Approach */
"0D1B0JB" = "1" /* Bypass Ileum to Ileum with Synthetic Substitute, Open Approach */
"0D1B0JH" = "1" /* Bypass Ileum to Cecum with Synthetic Substitute, Open Approach */
"0D1B0JK" = "1" /* Bypass Ileum to Ascending Colon with Synthetic Substitute, Open Approach */
"0D1B0JL" = "1" /* Bypass Ileum to Transverse Colon with Synthetic Substitute, Open Approach */
"0D1B0JM" = "1" /* Bypass Ileum to Descending Colon with Synthetic Substitute, Open Approach */
"0D1B0JN" = "1" /* Bypass Ileum to Sigmoid Colon with Synthetic Substitute, Open Approach */
"0D1B0JP" = "1" /* Bypass Ileum to Rectum with Synthetic Substitute, Open Approach */
"0D1B0JQ" = "1" /* Bypass Ileum to Anus with Synthetic Substitute, Open Approach */
"0D1B0K4" = "1" /* Bypass Ileum to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D1B0KB" = "1" /* Bypass Ileum to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D1B0KH" = "1" /* Bypass Ileum to Cecum with Nonautologous Tissue Substitute, Open Approach */
"0D1B0KK" = "1" /* Bypass Ileum to Ascending Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1B0KL" = "1" /* Bypass Ileum to Transverse Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1B0KM" = "1" /* Bypass Ileum to Descending Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1B0KN" = "1" /* Bypass Ileum to Sigmoid Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1B0KP" = "1" /* Bypass Ileum to Rectum with Nonautologous Tissue Substitute, Open Approach */
"0D1B0KQ" = "1" /* Bypass Ileum to Anus with Nonautologous Tissue Substitute, Open Approach */
"0D1B0Z4" = "1" /* Bypass Ileum to Cutaneous, Open Approach */
"0D1B0ZB" = "1" /* Bypass Ileum to Ileum, Open Approach */
"0D1B0ZH" = "1" /* Bypass Ileum to Cecum, Open Approach */
"0D1B0ZK" = "1" /* Bypass Ileum to Ascending Colon, Open Approach */
"0D1B0ZL" = "1" /* Bypass Ileum to Transverse Colon, Open Approach */
"0D1B0ZM" = "1" /* Bypass Ileum to Descending Colon, Open Approach */
"0D1B0ZN" = "1" /* Bypass Ileum to Sigmoid Colon, Open Approach */
"0D1B0ZP" = "1" /* Bypass Ileum to Rectum, Open Approach */
"0D1B0ZQ" = "1" /* Bypass Ileum to Anus, Open Approach */
"0D1B3J4" = "1" /* Bypass Ileum to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D1B474" = "1" /* Bypass Ileum to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B47B" = "1" /* Bypass Ileum to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B47H" = "1" /* Bypass Ileum to Cecum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B47K" = "1" /* Bypass Ileum to Ascending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B47L" = "1" /* Bypass Ileum to Transverse Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B47M" = "1" /* Bypass Ileum to Descending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B47N" = "1" /* Bypass Ileum to Sigmoid Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B47P" = "1" /* Bypass Ileum to Rectum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B47Q" = "1" /* Bypass Ileum to Anus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B4J4" = "1" /* Bypass Ileum to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1B4JB" = "1" /* Bypass Ileum to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1B4JH" = "1" /* Bypass Ileum to Cecum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1B4JK" = "1" /* Bypass Ileum to Ascending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1B4JL" = "1" /* Bypass Ileum to Transverse Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1B4JM" = "1" /* Bypass Ileum to Descending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1B4JN" = "1" /* Bypass Ileum to Sigmoid Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1B4JP" = "1" /* Bypass Ileum to Rectum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1B4JQ" = "1" /* Bypass Ileum to Anus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1B4K4" = "1" /* Bypass Ileum to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B4KB" = "1" /* Bypass Ileum to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B4KH" = "1" /* Bypass Ileum to Cecum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B4KK" = "1" /* Bypass Ileum to Ascending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B4KL" = "1" /* Bypass Ileum to Transverse Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B4KM" = "1" /* Bypass Ileum to Descending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B4KN" = "1" /* Bypass Ileum to Sigmoid Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B4KP" = "1" /* Bypass Ileum to Rectum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B4KQ" = "1" /* Bypass Ileum to Anus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1B4Z4" = "1" /* Bypass Ileum to Cutaneous, Percutaneous Endoscopic Approach */
"0D1B4ZB" = "1" /* Bypass Ileum to Ileum, Percutaneous Endoscopic Approach */
"0D1B4ZH" = "1" /* Bypass Ileum to Cecum, Percutaneous Endoscopic Approach */
"0D1B4ZK" = "1" /* Bypass Ileum to Ascending Colon, Percutaneous Endoscopic Approach */
"0D1B4ZL" = "1" /* Bypass Ileum to Transverse Colon, Percutaneous Endoscopic Approach */
"0D1B4ZM" = "1" /* Bypass Ileum to Descending Colon, Percutaneous Endoscopic Approach */
"0D1B4ZN" = "1" /* Bypass Ileum to Sigmoid Colon, Percutaneous Endoscopic Approach */
"0D1B4ZP" = "1" /* Bypass Ileum to Rectum, Percutaneous Endoscopic Approach */
"0D1B4ZQ" = "1" /* Bypass Ileum to Anus, Percutaneous Endoscopic Approach */
"0D1B874" = "1" /* Bypass Ileum to Cutaneous with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B87B" = "1" /* Bypass Ileum to Ileum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B87H" = "1" /* Bypass Ileum to Cecum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B87K" = "1" /* Bypass Ileum to Ascending Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B87L" = "1" /* Bypass Ileum to Transverse Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B87M" = "1" /* Bypass Ileum to Descending Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B87N" = "1" /* Bypass Ileum to Sigmoid Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B87P" = "1" /* Bypass Ileum to Rectum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B87Q" = "1" /* Bypass Ileum to Anus with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B8J4" = "1" /* Bypass Ileum to Cutaneous with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B8JB" = "1" /* Bypass Ileum to Ileum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B8JH" = "1" /* Bypass Ileum to Cecum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B8JK" = "1" /* Bypass Ileum to Ascending Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B8JL" = "1" /* Bypass Ileum to Transverse Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B8JM" = "1" /* Bypass Ileum to Descending Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B8JN" = "1" /* Bypass Ileum to Sigmoid Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B8JP" = "1" /* Bypass Ileum to Rectum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B8JQ" = "1" /* Bypass Ileum to Anus with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B8K4" = "1" /* Bypass Ileum to Cutaneous with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B8KB" = "1" /* Bypass Ileum to Ileum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B8KH" = "1" /* Bypass Ileum to Cecum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B8KK" = "1" /* Bypass Ileum to Ascending Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B8KL" = "1" /* Bypass Ileum to Transverse Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B8KM" = "1" /* Bypass Ileum to Descending Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B8KN" = "1" /* Bypass Ileum to Sigmoid Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B8KP" = "1" /* Bypass Ileum to Rectum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B8KQ" = "1" /* Bypass Ileum to Anus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1B8Z4" = "1" /* Bypass Ileum to Cutaneous, Via Natural or Artificial Opening Endoscopic */
"0D1B8ZB" = "1" /* Bypass Ileum to Ileum, Via Natural or Artificial Opening Endoscopic */
"0D1B8ZH" = "1" /* Bypass Ileum to Cecum, Via Natural or Artificial Opening Endoscopic */
"0D1B8ZK" = "1" /* Bypass Ileum to Ascending Colon, Via Natural or Artificial Opening Endoscopic */
"0D1B8ZL" = "1" /* Bypass Ileum to Transverse Colon, Via Natural or Artificial Opening Endoscopic */
"0D1B8ZM" = "1" /* Bypass Ileum to Descending Colon, Via Natural or Artificial Opening Endoscopic */
"0D1B8ZN" = "1" /* Bypass Ileum to Sigmoid Colon, Via Natural or Artificial Opening Endoscopic */
"0D1B8ZP" = "1" /* Bypass Ileum to Rectum, Via Natural or Artificial Opening Endoscopic */
"0D1B8ZQ" = "1" /* Bypass Ileum to Anus, Via Natural or Artificial Opening Endoscopic */
"0D1H074" = "1" /* Bypass Cecum to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D1H07H" = "1" /* Bypass Cecum to Cecum with Autologous Tissue Substitute, Open Approach */
"0D1H07K" = "1" /* Bypass Cecum to Ascending Colon with Autologous Tissue Substitute, Open Approach */
"0D1H07L" = "1" /* Bypass Cecum to Transverse Colon with Autologous Tissue Substitute, Open Approach */
"0D1H07M" = "1" /* Bypass Cecum to Descending Colon with Autologous Tissue Substitute, Open Approach */
"0D1H07N" = "1" /* Bypass Cecum to Sigmoid Colon with Autologous Tissue Substitute, Open Approach */
"0D1H07P" = "1" /* Bypass Cecum to Rectum with Autologous Tissue Substitute, Open Approach */
"0D1H0J4" = "1" /* Bypass Cecum to Cutaneous with Synthetic Substitute, Open Approach */
"0D1H0JH" = "1" /* Bypass Cecum to Cecum with Synthetic Substitute, Open Approach */
"0D1H0JK" = "1" /* Bypass Cecum to Ascending Colon with Synthetic Substitute, Open Approach */
"0D1H0JL" = "1" /* Bypass Cecum to Transverse Colon with Synthetic Substitute, Open Approach */
"0D1H0JM" = "1" /* Bypass Cecum to Descending Colon with Synthetic Substitute, Open Approach */
"0D1H0JN" = "1" /* Bypass Cecum to Sigmoid Colon with Synthetic Substitute, Open Approach */
"0D1H0JP" = "1" /* Bypass Cecum to Rectum with Synthetic Substitute, Open Approach */
"0D1H0K4" = "1" /* Bypass Cecum to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D1H0KH" = "1" /* Bypass Cecum to Cecum with Nonautologous Tissue Substitute, Open Approach */
"0D1H0KK" = "1" /* Bypass Cecum to Ascending Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1H0KL" = "1" /* Bypass Cecum to Transverse Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1H0KM" = "1" /* Bypass Cecum to Descending Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1H0KN" = "1" /* Bypass Cecum to Sigmoid Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1H0KP" = "1" /* Bypass Cecum to Rectum with Nonautologous Tissue Substitute, Open Approach */
"0D1H0Z4" = "1" /* Bypass Cecum to Cutaneous, Open Approach */
"0D1H0ZH" = "1" /* Bypass Cecum to Cecum, Open Approach */
"0D1H0ZK" = "1" /* Bypass Cecum to Ascending Colon, Open Approach */
"0D1H0ZL" = "1" /* Bypass Cecum to Transverse Colon, Open Approach */
"0D1H0ZM" = "1" /* Bypass Cecum to Descending Colon, Open Approach */
"0D1H0ZN" = "1" /* Bypass Cecum to Sigmoid Colon, Open Approach */
"0D1H0ZP" = "1" /* Bypass Cecum to Rectum, Open Approach */
"0D1H3J4" = "1" /* Bypass Cecum to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D1H474" = "1" /* Bypass Cecum to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H47H" = "1" /* Bypass Cecum to Cecum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H47K" = "1" /* Bypass Cecum to Ascending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H47L" = "1" /* Bypass Cecum to Transverse Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H47M" = "1" /* Bypass Cecum to Descending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H47N" = "1" /* Bypass Cecum to Sigmoid Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H47P" = "1" /* Bypass Cecum to Rectum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H4J4" = "1" /* Bypass Cecum to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1H4JH" = "1" /* Bypass Cecum to Cecum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1H4JK" = "1" /* Bypass Cecum to Ascending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1H4JL" = "1" /* Bypass Cecum to Transverse Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1H4JM" = "1" /* Bypass Cecum to Descending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1H4JN" = "1" /* Bypass Cecum to Sigmoid Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1H4JP" = "1" /* Bypass Cecum to Rectum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1H4K4" = "1" /* Bypass Cecum to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H4KH" = "1" /* Bypass Cecum to Cecum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H4KK" = "1" /* Bypass Cecum to Ascending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H4KL" = "1" /* Bypass Cecum to Transverse Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H4KM" = "1" /* Bypass Cecum to Descending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H4KN" = "1" /* Bypass Cecum to Sigmoid Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H4KP" = "1" /* Bypass Cecum to Rectum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1H4Z4" = "1" /* Bypass Cecum to Cutaneous, Percutaneous Endoscopic Approach */
"0D1H4ZH" = "1" /* Bypass Cecum to Cecum, Percutaneous Endoscopic Approach */
"0D1H4ZK" = "1" /* Bypass Cecum to Ascending Colon, Percutaneous Endoscopic Approach */
"0D1H4ZL" = "1" /* Bypass Cecum to Transverse Colon, Percutaneous Endoscopic Approach */
"0D1H4ZM" = "1" /* Bypass Cecum to Descending Colon, Percutaneous Endoscopic Approach */
"0D1H4ZN" = "1" /* Bypass Cecum to Sigmoid Colon, Percutaneous Endoscopic Approach */
"0D1H4ZP" = "1" /* Bypass Cecum to Rectum, Percutaneous Endoscopic Approach */
"0D1H874" = "1" /* Bypass Cecum to Cutaneous with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1H87H" = "1" /* Bypass Cecum to Cecum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1H87K" = "1" /* Bypass Cecum to Ascending Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1H87L" = "1" /* Bypass Cecum to Transverse Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1H87M" = "1" /* Bypass Cecum to Descending Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1H87N" = "1" /* Bypass Cecum to Sigmoid Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1H87P" = "1" /* Bypass Cecum to Rectum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1H8J4" = "1" /* Bypass Cecum to Cutaneous with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1H8JH" = "1" /* Bypass Cecum to Cecum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1H8JK" = "1" /* Bypass Cecum to Ascending Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1H8JL" = "1" /* Bypass Cecum to Transverse Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1H8JM" = "1" /* Bypass Cecum to Descending Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1H8JN" = "1" /* Bypass Cecum to Sigmoid Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1H8JP" = "1" /* Bypass Cecum to Rectum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1H8K4" = "1" /* Bypass Cecum to Cutaneous with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1H8KH" = "1" /* Bypass Cecum to Cecum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1H8KK" = "1" /* Bypass Cecum to Ascending Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1H8KL" = "1" /* Bypass Cecum to Transverse Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1H8KM" = "1" /* Bypass Cecum to Descending Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1H8KN" = "1" /* Bypass Cecum to Sigmoid Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1H8KP" = "1" /* Bypass Cecum to Rectum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1H8Z4" = "1" /* Bypass Cecum to Cutaneous, Via Natural or Artificial Opening Endoscopic */
"0D1H8ZH" = "1" /* Bypass Cecum to Cecum, Via Natural or Artificial Opening Endoscopic */
"0D1H8ZK" = "1" /* Bypass Cecum to Ascending Colon, Via Natural or Artificial Opening Endoscopic */
"0D1H8ZL" = "1" /* Bypass Cecum to Transverse Colon, Via Natural or Artificial Opening Endoscopic */
"0D1H8ZM" = "1" /* Bypass Cecum to Descending Colon, Via Natural or Artificial Opening Endoscopic */
"0D1H8ZN" = "1" /* Bypass Cecum to Sigmoid Colon, Via Natural or Artificial Opening Endoscopic */
"0D1H8ZP" = "1" /* Bypass Cecum to Rectum, Via Natural or Artificial Opening Endoscopic */
"0D1K074" = "1" /* Bypass Ascending Colon to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D1K07K" = "1" /* Bypass Ascending Colon to Ascending Colon with Autologous Tissue Substitute, Open Approach */
"0D1K07L" = "1" /* Bypass Ascending Colon to Transverse Colon with Autologous Tissue Substitute, Open Approach */
"0D1K07M" = "1" /* Bypass Ascending Colon to Descending Colon with Autologous Tissue Substitute, Open Approach */
"0D1K07N" = "1" /* Bypass Ascending Colon to Sigmoid Colon with Autologous Tissue Substitute, Open Approach */
"0D1K07P" = "1" /* Bypass Ascending Colon to Rectum with Autologous Tissue Substitute, Open Approach */
"0D1K0J4" = "1" /* Bypass Ascending Colon to Cutaneous with Synthetic Substitute, Open Approach */
"0D1K0JK" = "1" /* Bypass Ascending Colon to Ascending Colon with Synthetic Substitute, Open Approach */
"0D1K0JL" = "1" /* Bypass Ascending Colon to Transverse Colon with Synthetic Substitute, Open Approach */
"0D1K0JM" = "1" /* Bypass Ascending Colon to Descending Colon with Synthetic Substitute, Open Approach */
"0D1K0JN" = "1" /* Bypass Ascending Colon to Sigmoid Colon with Synthetic Substitute, Open Approach */
"0D1K0JP" = "1" /* Bypass Ascending Colon to Rectum with Synthetic Substitute, Open Approach */
"0D1K0K4" = "1" /* Bypass Ascending Colon to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D1K0KK" = "1" /* Bypass Ascending Colon to Ascending Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1K0KL" = "1" /* Bypass Ascending Colon to Transverse Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1K0KM" = "1" /* Bypass Ascending Colon to Descending Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1K0KN" = "1" /* Bypass Ascending Colon to Sigmoid Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1K0KP" = "1" /* Bypass Ascending Colon to Rectum with Nonautologous Tissue Substitute, Open Approach */
"0D1K0Z4" = "1" /* Bypass Ascending Colon to Cutaneous, Open Approach */
"0D1K0ZK" = "1" /* Bypass Ascending Colon to Ascending Colon, Open Approach */
"0D1K0ZL" = "1" /* Bypass Ascending Colon to Transverse Colon, Open Approach */
"0D1K0ZM" = "1" /* Bypass Ascending Colon to Descending Colon, Open Approach */
"0D1K0ZN" = "1" /* Bypass Ascending Colon to Sigmoid Colon, Open Approach */
"0D1K0ZP" = "1" /* Bypass Ascending Colon to Rectum, Open Approach */
"0D1K3J4" = "1" /* Bypass Ascending Colon to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D1K474" = "1" /* Bypass Ascending Colon to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K47K" = "1" /* Bypass Ascending Colon to Ascending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K47L" = "1" /* Bypass Ascending Colon to Transverse Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K47M" = "1" /* Bypass Ascending Colon to Descending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K47N" = "1" /* Bypass Ascending Colon to Sigmoid Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K47P" = "1" /* Bypass Ascending Colon to Rectum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K4J4" = "1" /* Bypass Ascending Colon to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1K4JK" = "1" /* Bypass Ascending Colon to Ascending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1K4JL" = "1" /* Bypass Ascending Colon to Transverse Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1K4JM" = "1" /* Bypass Ascending Colon to Descending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1K4JN" = "1" /* Bypass Ascending Colon to Sigmoid Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1K4JP" = "1" /* Bypass Ascending Colon to Rectum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1K4K4" = "1" /* Bypass Ascending Colon to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K4KK" = "1" /* Bypass Ascending Colon to Ascending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K4KL" = "1" /* Bypass Ascending Colon to Transverse Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K4KM" = "1" /* Bypass Ascending Colon to Descending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K4KN" = "1" /* Bypass Ascending Colon to Sigmoid Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K4KP" = "1" /* Bypass Ascending Colon to Rectum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1K4Z4" = "1" /* Bypass Ascending Colon to Cutaneous, Percutaneous Endoscopic Approach */
"0D1K4ZK" = "1" /* Bypass Ascending Colon to Ascending Colon, Percutaneous Endoscopic Approach */
"0D1K4ZL" = "1" /* Bypass Ascending Colon to Transverse Colon, Percutaneous Endoscopic Approach */
"0D1K4ZM" = "1" /* Bypass Ascending Colon to Descending Colon, Percutaneous Endoscopic Approach */
"0D1K4ZN" = "1" /* Bypass Ascending Colon to Sigmoid Colon, Percutaneous Endoscopic Approach */
"0D1K4ZP" = "1" /* Bypass Ascending Colon to Rectum, Percutaneous Endoscopic Approach */
"0D1K874" = "1" /* Bypass Ascending Colon to Cutaneous with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1K87K" = "1" /* Bypass Ascending Colon to Ascending Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1K87L" = "1" /* Bypass Ascending Colon to Transverse Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1K87M" = "1" /* Bypass Ascending Colon to Descending Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1K87N" = "1" /* Bypass Ascending Colon to Sigmoid Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1K87P" = "1" /* Bypass Ascending Colon to Rectum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1K8J4" = "1" /* Bypass Ascending Colon to Cutaneous with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1K8JK" = "1" /* Bypass Ascending Colon to Ascending Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1K8JL" = "1" /* Bypass Ascending Colon to Transverse Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1K8JM" = "1" /* Bypass Ascending Colon to Descending Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1K8JN" = "1" /* Bypass Ascending Colon to Sigmoid Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1K8JP" = "1" /* Bypass Ascending Colon to Rectum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1K8K4" = "1" /* Bypass Ascending Colon to Cutaneous with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1K8KK" = "1" /* Bypass Ascending Colon to Ascending Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1K8KL" = "1" /* Bypass Ascending Colon to Transverse Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1K8KM" = "1" /* Bypass Ascending Colon to Descending Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1K8KN" = "1" /* Bypass Ascending Colon to Sigmoid Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1K8KP" = "1" /* Bypass Ascending Colon to Rectum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1K8Z4" = "1" /* Bypass Ascending Colon to Cutaneous, Via Natural or Artificial Opening Endoscopic */
"0D1K8ZK" = "1" /* Bypass Ascending Colon to Ascending Colon, Via Natural or Artificial Opening Endoscopic */
"0D1K8ZL" = "1" /* Bypass Ascending Colon to Transverse Colon, Via Natural or Artificial Opening Endoscopic */
"0D1K8ZM" = "1" /* Bypass Ascending Colon to Descending Colon, Via Natural or Artificial Opening Endoscopic */
"0D1K8ZN" = "1" /* Bypass Ascending Colon to Sigmoid Colon, Via Natural or Artificial Opening Endoscopic */
"0D1K8ZP" = "1" /* Bypass Ascending Colon to Rectum, Via Natural or Artificial Opening Endoscopic */
"0D1L074" = "1" /* Bypass Transverse Colon to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D1L07L" = "1" /* Bypass Transverse Colon to Transverse Colon with Autologous Tissue Substitute, Open Approach */
"0D1L07M" = "1" /* Bypass Transverse Colon to Descending Colon with Autologous Tissue Substitute, Open Approach */
"0D1L07N" = "1" /* Bypass Transverse Colon to Sigmoid Colon with Autologous Tissue Substitute, Open Approach */
"0D1L07P" = "1" /* Bypass Transverse Colon to Rectum with Autologous Tissue Substitute, Open Approach */
"0D1L0J4" = "1" /* Bypass Transverse Colon to Cutaneous with Synthetic Substitute, Open Approach */
"0D1L0JL" = "1" /* Bypass Transverse Colon to Transverse Colon with Synthetic Substitute, Open Approach */
"0D1L0JM" = "1" /* Bypass Transverse Colon to Descending Colon with Synthetic Substitute, Open Approach */
"0D1L0JN" = "1" /* Bypass Transverse Colon to Sigmoid Colon with Synthetic Substitute, Open Approach */
"0D1L0JP" = "1" /* Bypass Transverse Colon to Rectum with Synthetic Substitute, Open Approach */
"0D1L0K4" = "1" /* Bypass Transverse Colon to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D1L0KL" = "1" /* Bypass Transverse Colon to Transverse Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1L0KM" = "1" /* Bypass Transverse Colon to Descending Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1L0KN" = "1" /* Bypass Transverse Colon to Sigmoid Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1L0KP" = "1" /* Bypass Transverse Colon to Rectum with Nonautologous Tissue Substitute, Open Approach */
"0D1L0Z4" = "1" /* Bypass Transverse Colon to Cutaneous, Open Approach */
"0D1L0ZL" = "1" /* Bypass Transverse Colon to Transverse Colon, Open Approach */
"0D1L0ZM" = "1" /* Bypass Transverse Colon to Descending Colon, Open Approach */
"0D1L0ZN" = "1" /* Bypass Transverse Colon to Sigmoid Colon, Open Approach */
"0D1L0ZP" = "1" /* Bypass Transverse Colon to Rectum, Open Approach */
"0D1L3J4" = "1" /* Bypass Transverse Colon to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D1L474" = "1" /* Bypass Transverse Colon to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1L47L" = "1" /* Bypass Transverse Colon to Transverse Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1L47M" = "1" /* Bypass Transverse Colon to Descending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1L47N" = "1" /* Bypass Transverse Colon to Sigmoid Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1L47P" = "1" /* Bypass Transverse Colon to Rectum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1L4J4" = "1" /* Bypass Transverse Colon to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1L4JL" = "1" /* Bypass Transverse Colon to Transverse Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1L4JM" = "1" /* Bypass Transverse Colon to Descending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1L4JN" = "1" /* Bypass Transverse Colon to Sigmoid Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1L4JP" = "1" /* Bypass Transverse Colon to Rectum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1L4K4" = "1" /* Bypass Transverse Colon to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1L4KL" = "1" /* Bypass Transverse Colon to Transverse Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1L4KM" = "1" /* Bypass Transverse Colon to Descending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1L4KN" = "1" /* Bypass Transverse Colon to Sigmoid Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1L4KP" = "1" /* Bypass Transverse Colon to Rectum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1L4Z4" = "1" /* Bypass Transverse Colon to Cutaneous, Percutaneous Endoscopic Approach */
"0D1L4ZL" = "1" /* Bypass Transverse Colon to Transverse Colon, Percutaneous Endoscopic Approach */
"0D1L4ZM" = "1" /* Bypass Transverse Colon to Descending Colon, Percutaneous Endoscopic Approach */
"0D1L4ZN" = "1" /* Bypass Transverse Colon to Sigmoid Colon, Percutaneous Endoscopic Approach */
"0D1L4ZP" = "1" /* Bypass Transverse Colon to Rectum, Percutaneous Endoscopic Approach */
"0D1L874" = "1" /* Bypass Transverse Colon to Cutaneous with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1L87L" = "1" /* Bypass Transverse Colon to Transverse Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1L87M" = "1" /* Bypass Transverse Colon to Descending Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1L87N" = "1" /* Bypass Transverse Colon to Sigmoid Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1L87P" = "1" /* Bypass Transverse Colon to Rectum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1L8J4" = "1" /* Bypass Transverse Colon to Cutaneous with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1L8JL" = "1" /* Bypass Transverse Colon to Transverse Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1L8JM" = "1" /* Bypass Transverse Colon to Descending Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1L8JN" = "1" /* Bypass Transverse Colon to Sigmoid Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1L8JP" = "1" /* Bypass Transverse Colon to Rectum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1L8K4" = "1" /* Bypass Transverse Colon to Cutaneous with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1L8KL" = "1" /* Bypass Transverse Colon to Transverse Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1L8KM" = "1" /* Bypass Transverse Colon to Descending Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1L8KN" = "1" /* Bypass Transverse Colon to Sigmoid Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1L8KP" = "1" /* Bypass Transverse Colon to Rectum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1L8Z4" = "1" /* Bypass Transverse Colon to Cutaneous, Via Natural or Artificial Opening Endoscopic */
"0D1L8ZL" = "1" /* Bypass Transverse Colon to Transverse Colon, Via Natural or Artificial Opening Endoscopic */
"0D1L8ZM" = "1" /* Bypass Transverse Colon to Descending Colon, Via Natural or Artificial Opening Endoscopic */
"0D1L8ZN" = "1" /* Bypass Transverse Colon to Sigmoid Colon, Via Natural or Artificial Opening Endoscopic */
"0D1L8ZP" = "1" /* Bypass Transverse Colon to Rectum, Via Natural or Artificial Opening Endoscopic */
"0D1M074" = "1" /* Bypass Descending Colon to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D1M07M" = "1" /* Bypass Descending Colon to Descending Colon with Autologous Tissue Substitute, Open Approach */
"0D1M07N" = "1" /* Bypass Descending Colon to Sigmoid Colon with Autologous Tissue Substitute, Open Approach */
"0D1M07P" = "1" /* Bypass Descending Colon to Rectum with Autologous Tissue Substitute, Open Approach */
"0D1M0J4" = "1" /* Bypass Descending Colon to Cutaneous with Synthetic Substitute, Open Approach */
"0D1M0JM" = "1" /* Bypass Descending Colon to Descending Colon with Synthetic Substitute, Open Approach */
"0D1M0JN" = "1" /* Bypass Descending Colon to Sigmoid Colon with Synthetic Substitute, Open Approach */
"0D1M0JP" = "1" /* Bypass Descending Colon to Rectum with Synthetic Substitute, Open Approach */
"0D1M0K4" = "1" /* Bypass Descending Colon to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D1M0KM" = "1" /* Bypass Descending Colon to Descending Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1M0KN" = "1" /* Bypass Descending Colon to Sigmoid Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1M0KP" = "1" /* Bypass Descending Colon to Rectum with Nonautologous Tissue Substitute, Open Approach */
"0D1M0Z4" = "1" /* Bypass Descending Colon to Cutaneous, Open Approach */
"0D1M0ZM" = "1" /* Bypass Descending Colon to Descending Colon, Open Approach */
"0D1M0ZN" = "1" /* Bypass Descending Colon to Sigmoid Colon, Open Approach */
"0D1M0ZP" = "1" /* Bypass Descending Colon to Rectum, Open Approach */
"0D1M3J4" = "1" /* Bypass Descending Colon to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D1M474" = "1" /* Bypass Descending Colon to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1M47M" = "1" /* Bypass Descending Colon to Descending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1M47N" = "1" /* Bypass Descending Colon to Sigmoid Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1M47P" = "1" /* Bypass Descending Colon to Rectum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1M4J4" = "1" /* Bypass Descending Colon to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1M4JM" = "1" /* Bypass Descending Colon to Descending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1M4JN" = "1" /* Bypass Descending Colon to Sigmoid Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1M4JP" = "1" /* Bypass Descending Colon to Rectum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1M4K4" = "1" /* Bypass Descending Colon to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1M4KM" = "1" /* Bypass Descending Colon to Descending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1M4KN" = "1" /* Bypass Descending Colon to Sigmoid Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1M4KP" = "1" /* Bypass Descending Colon to Rectum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1M4Z4" = "1" /* Bypass Descending Colon to Cutaneous, Percutaneous Endoscopic Approach */
"0D1M4ZM" = "1" /* Bypass Descending Colon to Descending Colon, Percutaneous Endoscopic Approach */
"0D1M4ZN" = "1" /* Bypass Descending Colon to Sigmoid Colon, Percutaneous Endoscopic Approach */
"0D1M4ZP" = "1" /* Bypass Descending Colon to Rectum, Percutaneous Endoscopic Approach */
"0D1M874" = "1" /* Bypass Descending Colon to Cutaneous with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1M87M" = "1" /* Bypass Descending Colon to Descending Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1M87N" = "1" /* Bypass Descending Colon to Sigmoid Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1M87P" = "1" /* Bypass Descending Colon to Rectum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1M8J4" = "1" /* Bypass Descending Colon to Cutaneous with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1M8JM" = "1" /* Bypass Descending Colon to Descending Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1M8JN" = "1" /* Bypass Descending Colon to Sigmoid Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1M8JP" = "1" /* Bypass Descending Colon to Rectum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1M8K4" = "1" /* Bypass Descending Colon to Cutaneous with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1M8KM" = "1" /* Bypass Descending Colon to Descending Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1M8KN" = "1" /* Bypass Descending Colon to Sigmoid Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1M8KP" = "1" /* Bypass Descending Colon to Rectum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1M8Z4" = "1" /* Bypass Descending Colon to Cutaneous, Via Natural or Artificial Opening Endoscopic */
"0D1M8ZM" = "1" /* Bypass Descending Colon to Descending Colon, Via Natural or Artificial Opening Endoscopic */
"0D1M8ZN" = "1" /* Bypass Descending Colon to Sigmoid Colon, Via Natural or Artificial Opening Endoscopic */
"0D1M8ZP" = "1" /* Bypass Descending Colon to Rectum, Via Natural or Artificial Opening Endoscopic */
"0D1N074" = "1" /* Bypass Sigmoid Colon to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D1N07N" = "1" /* Bypass Sigmoid Colon to Sigmoid Colon with Autologous Tissue Substitute, Open Approach */
"0D1N07P" = "1" /* Bypass Sigmoid Colon to Rectum with Autologous Tissue Substitute, Open Approach */
"0D1N0J4" = "1" /* Bypass Sigmoid Colon to Cutaneous with Synthetic Substitute, Open Approach */
"0D1N0JN" = "1" /* Bypass Sigmoid Colon to Sigmoid Colon with Synthetic Substitute, Open Approach */
"0D1N0JP" = "1" /* Bypass Sigmoid Colon to Rectum with Synthetic Substitute, Open Approach */
"0D1N0K4" = "1" /* Bypass Sigmoid Colon to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D1N0KN" = "1" /* Bypass Sigmoid Colon to Sigmoid Colon with Nonautologous Tissue Substitute, Open Approach */
"0D1N0KP" = "1" /* Bypass Sigmoid Colon to Rectum with Nonautologous Tissue Substitute, Open Approach */
"0D1N0Z4" = "1" /* Bypass Sigmoid Colon to Cutaneous, Open Approach */
"0D1N0ZN" = "1" /* Bypass Sigmoid Colon to Sigmoid Colon, Open Approach */
"0D1N0ZP" = "1" /* Bypass Sigmoid Colon to Rectum, Open Approach */
"0D1N3J4" = "1" /* Bypass Sigmoid Colon to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D1N474" = "1" /* Bypass Sigmoid Colon to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1N47N" = "1" /* Bypass Sigmoid Colon to Sigmoid Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1N47P" = "1" /* Bypass Sigmoid Colon to Rectum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1N4J4" = "1" /* Bypass Sigmoid Colon to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1N4JN" = "1" /* Bypass Sigmoid Colon to Sigmoid Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1N4JP" = "1" /* Bypass Sigmoid Colon to Rectum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D1N4K4" = "1" /* Bypass Sigmoid Colon to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1N4KN" = "1" /* Bypass Sigmoid Colon to Sigmoid Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1N4KP" = "1" /* Bypass Sigmoid Colon to Rectum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1N4Z4" = "1" /* Bypass Sigmoid Colon to Cutaneous, Percutaneous Endoscopic Approach */
"0D1N4ZN" = "1" /* Bypass Sigmoid Colon to Sigmoid Colon, Percutaneous Endoscopic Approach */
"0D1N4ZP" = "1" /* Bypass Sigmoid Colon to Rectum, Percutaneous Endoscopic Approach */
"0D1N874" = "1" /* Bypass Sigmoid Colon to Cutaneous with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1N87N" = "1" /* Bypass Sigmoid Colon to Sigmoid Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1N87P" = "1" /* Bypass Sigmoid Colon to Rectum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1N8J4" = "1" /* Bypass Sigmoid Colon to Cutaneous with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1N8JN" = "1" /* Bypass Sigmoid Colon to Sigmoid Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1N8JP" = "1" /* Bypass Sigmoid Colon to Rectum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1N8K4" = "1" /* Bypass Sigmoid Colon to Cutaneous with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1N8KN" = "1" /* Bypass Sigmoid Colon to Sigmoid Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1N8KP" = "1" /* Bypass Sigmoid Colon to Rectum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1N8Z4" = "1" /* Bypass Sigmoid Colon to Cutaneous, Via Natural or Artificial Opening Endoscopic */
"0D1N8ZN" = "1" /* Bypass Sigmoid Colon to Sigmoid Colon, Via Natural or Artificial Opening Endoscopic */
"0D1N8ZP" = "1" /* Bypass Sigmoid Colon to Rectum, Via Natural or Artificial Opening Endoscopic */
"0D510ZZ" = "1" /* Destruction of Upper Esophagus, Open Approach */
"0D513ZZ" = "1" /* Destruction of Upper Esophagus, Percutaneous Approach */
"0D517ZZ" = "1" /* Destruction of Upper Esophagus, Via Natural or Artificial Opening */
"0D520ZZ" = "1" /* Destruction of Middle Esophagus, Open Approach */
"0D523ZZ" = "1" /* Destruction of Middle Esophagus, Percutaneous Approach */
"0D527ZZ" = "1" /* Destruction of Middle Esophagus, Via Natural or Artificial Opening */
"0D530ZZ" = "1" /* Destruction of Lower Esophagus, Open Approach */
"0D533ZZ" = "1" /* Destruction of Lower Esophagus, Percutaneous Approach */
"0D537ZZ" = "1" /* Destruction of Lower Esophagus, Via Natural or Artificial Opening */
"0D540ZZ" = "1" /* Destruction of Esophagogastric Junction, Open Approach */
"0D543ZZ" = "1" /* Destruction of Esophagogastric Junction, Percutaneous Approach */
"0D547ZZ" = "1" /* Destruction of Esophagogastric Junction, Via Natural or Artificial Opening */
"0D550ZZ" = "1" /* Destruction of Esophagus, Open Approach */
"0D553ZZ" = "1" /* Destruction of Esophagus, Percutaneous Approach */
"0D557ZZ" = "1" /* Destruction of Esophagus, Via Natural or Artificial Opening */
"0D560ZZ" = "1" /* Destruction of Stomach, Open Approach */
"0D563ZZ" = "1" /* Destruction of Stomach, Percutaneous Approach */
"0D567ZZ" = "1" /* Destruction of Stomach, Via Natural or Artificial Opening */
"0D570ZZ" = "1" /* Destruction of Stomach, Pylorus, Open Approach */
"0D573ZZ" = "1" /* Destruction of Stomach, Pylorus, Percutaneous Approach */
"0D577ZZ" = "1" /* Destruction of Stomach, Pylorus, Via Natural or Artificial Opening */
"0D580ZZ" = "1" /* Destruction of Small Intestine, Open Approach */
"0D583ZZ" = "1" /* Destruction of Small Intestine, Percutaneous Approach */
"0D584ZZ" = "1" /* Destruction of Small Intestine, Percutaneous Endoscopic Approach */
"0D587ZZ" = "1" /* Destruction of Small Intestine, Via Natural or Artificial Opening */
"0D588ZZ" = "1" /* Destruction of Small Intestine, Via Natural or Artificial Opening Endoscopic */
"0D590ZZ" = "1" /* Destruction of Duodenum, Open Approach */
"0D593ZZ" = "1" /* Destruction of Duodenum, Percutaneous Approach */
"0D597ZZ" = "1" /* Destruction of Duodenum, Via Natural or Artificial Opening */
"0D5A0ZZ" = "1" /* Destruction of Jejunum, Open Approach */
"0D5A3ZZ" = "1" /* Destruction of Jejunum, Percutaneous Approach */
"0D5A4ZZ" = "1" /* Destruction of Jejunum, Percutaneous Endoscopic Approach */
"0D5A7ZZ" = "1" /* Destruction of Jejunum, Via Natural or Artificial Opening */
"0D5A8ZZ" = "1" /* Destruction of Jejunum, Via Natural or Artificial Opening Endoscopic */
"0D5B0ZZ" = "1" /* Destruction of Ileum, Open Approach */
"0D5B3ZZ" = "1" /* Destruction of Ileum, Percutaneous Approach */
"0D5B4ZZ" = "1" /* Destruction of Ileum, Percutaneous Endoscopic Approach */
"0D5B7ZZ" = "1" /* Destruction of Ileum, Via Natural or Artificial Opening */
"0D5B8ZZ" = "1" /* Destruction of Ileum, Via Natural or Artificial Opening Endoscopic */
"0D5C0ZZ" = "1" /* Destruction of Ileocecal Valve, Open Approach */
"0D5C3ZZ" = "1" /* Destruction of Ileocecal Valve, Percutaneous Approach */
"0D5C4ZZ" = "1" /* Destruction of Ileocecal Valve, Percutaneous Endoscopic Approach */
"0D5C7ZZ" = "1" /* Destruction of Ileocecal Valve, Via Natural or Artificial Opening */
"0D5C8ZZ" = "1" /* Destruction of Ileocecal Valve, Via Natural or Artificial Opening Endoscopic */
"0D5E0ZZ" = "1" /* Destruction of Large Intestine, Open Approach */
"0D5E3ZZ" = "1" /* Destruction of Large Intestine, Percutaneous Approach */
"0D5E7ZZ" = "1" /* Destruction of Large Intestine, Via Natural or Artificial Opening */
"0D5F0ZZ" = "1" /* Destruction of Right Large Intestine, Open Approach */
"0D5F3ZZ" = "1" /* Destruction of Right Large Intestine, Percutaneous Approach */
"0D5F7ZZ" = "1" /* Destruction of Right Large Intestine, Via Natural or Artificial Opening */
"0D5G0ZZ" = "1" /* Destruction of Left Large Intestine, Open Approach */
"0D5G3ZZ" = "1" /* Destruction of Left Large Intestine, Percutaneous Approach */
"0D5G7ZZ" = "1" /* Destruction of Left Large Intestine, Via Natural or Artificial Opening */
"0D5H0ZZ" = "1" /* Destruction of Cecum, Open Approach */
"0D5H3ZZ" = "1" /* Destruction of Cecum, Percutaneous Approach */
"0D5H7ZZ" = "1" /* Destruction of Cecum, Via Natural or Artificial Opening */
"0D5J0ZZ" = "1" /* Destruction of Appendix, Open Approach */
"0D5J3ZZ" = "1" /* Destruction of Appendix, Percutaneous Approach */
"0D5J4ZZ" = "1" /* Destruction of Appendix, Percutaneous Endoscopic Approach */
"0D5J7ZZ" = "1" /* Destruction of Appendix, Via Natural or Artificial Opening */
"0D5J8ZZ" = "1" /* Destruction of Appendix, Via Natural or Artificial Opening Endoscopic */
"0D5K0ZZ" = "1" /* Destruction of Ascending Colon, Open Approach */
"0D5K3ZZ" = "1" /* Destruction of Ascending Colon, Percutaneous Approach */
"0D5K7ZZ" = "1" /* Destruction of Ascending Colon, Via Natural or Artificial Opening */
"0D5L0ZZ" = "1" /* Destruction of Transverse Colon, Open Approach */
"0D5L3ZZ" = "1" /* Destruction of Transverse Colon, Percutaneous Approach */
"0D5L7ZZ" = "1" /* Destruction of Transverse Colon, Via Natural or Artificial Opening */
"0D5M0ZZ" = "1" /* Destruction of Descending Colon, Open Approach */
"0D5M3ZZ" = "1" /* Destruction of Descending Colon, Percutaneous Approach */
"0D5M7ZZ" = "1" /* Destruction of Descending Colon, Via Natural or Artificial Opening */
"0D5N0ZZ" = "1" /* Destruction of Sigmoid Colon, Open Approach */
"0D5N3ZZ" = "1" /* Destruction of Sigmoid Colon, Percutaneous Approach */
"0D5N7ZZ" = "1" /* Destruction of Sigmoid Colon, Via Natural or Artificial Opening */
"0D5Q0ZZ" = "1" /* Destruction of Anus, Open Approach */
"0D5Q3ZZ" = "1" /* Destruction of Anus, Percutaneous Approach */
"0D5Q7ZZ" = "1" /* Destruction of Anus, Via Natural or Artificial Opening */
"0D5QXZZ" = "1" /* Destruction of Anus, External Approach */
"0D5R0ZZ" = "1" /* Destruction of Anal Sphincter, Open Approach */
"0D5R3ZZ" = "1" /* Destruction of Anal Sphincter, Percutaneous Approach */
"0D5S0ZZ" = "1" /* Destruction of Greater Omentum, Open Approach */
"0D5S3ZZ" = "1" /* Destruction of Greater Omentum, Percutaneous Approach */
"0D5S4ZZ" = "1" /* Destruction of Greater Omentum, Percutaneous Endoscopic Approach */
"0D5T0ZZ" = "1" /* Destruction of Lesser Omentum, Open Approach */
"0D5T3ZZ" = "1" /* Destruction of Lesser Omentum, Percutaneous Approach */
"0D5T4ZZ" = "1" /* Destruction of Lesser Omentum, Percutaneous Endoscopic Approach */
"0D5V0ZZ" = "1" /* Destruction of Mesentery, Open Approach */
"0D5V3ZZ" = "1" /* Destruction of Mesentery, Percutaneous Approach */
"0D5V4ZZ" = "1" /* Destruction of Mesentery, Percutaneous Endoscopic Approach */
"0D5W0ZZ" = "1" /* Destruction of Peritoneum, Open Approach */
"0D5W3ZZ" = "1" /* Destruction of Peritoneum, Percutaneous Approach */
"0D5W4ZZ" = "1" /* Destruction of Peritoneum, Percutaneous Endoscopic Approach */
"0D710DZ" = "1" /* Dilation of Upper Esophagus with Intraluminal Device, Open Approach */
"0D710ZZ" = "1" /* Dilation of Upper Esophagus, Open Approach */
"0D713DZ" = "1" /* Dilation of Upper Esophagus with Intraluminal Device, Percutaneous Approach */
"0D713ZZ" = "1" /* Dilation of Upper Esophagus, Percutaneous Approach */
"0D714DZ" = "1" /* Dilation of Upper Esophagus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D714ZZ" = "1" /* Dilation of Upper Esophagus, Percutaneous Endoscopic Approach */
"0D720DZ" = "1" /* Dilation of Middle Esophagus with Intraluminal Device, Open Approach */
"0D720ZZ" = "1" /* Dilation of Middle Esophagus, Open Approach */
"0D723DZ" = "1" /* Dilation of Middle Esophagus with Intraluminal Device, Percutaneous Approach */
"0D723ZZ" = "1" /* Dilation of Middle Esophagus, Percutaneous Approach */
"0D724DZ" = "1" /* Dilation of Middle Esophagus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D724ZZ" = "1" /* Dilation of Middle Esophagus, Percutaneous Endoscopic Approach */
"0D730DZ" = "1" /* Dilation of Lower Esophagus with Intraluminal Device, Open Approach */
"0D730ZZ" = "1" /* Dilation of Lower Esophagus, Open Approach */
"0D733DZ" = "1" /* Dilation of Lower Esophagus with Intraluminal Device, Percutaneous Approach */
"0D733ZZ" = "1" /* Dilation of Lower Esophagus, Percutaneous Approach */
"0D734DZ" = "1" /* Dilation of Lower Esophagus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D734ZZ" = "1" /* Dilation of Lower Esophagus, Percutaneous Endoscopic Approach */
"0D740DZ" = "1" /* Dilation of Esophagogastric Junction with Intraluminal Device, Open Approach */
"0D740ZZ" = "1" /* Dilation of Esophagogastric Junction, Open Approach */
"0D743DZ" = "1" /* Dilation of Esophagogastric Junction with Intraluminal Device, Percutaneous Approach */
"0D743ZZ" = "1" /* Dilation of Esophagogastric Junction, Percutaneous Approach */
"0D744DZ" = "1" /* Dilation of Esophagogastric Junction with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D744ZZ" = "1" /* Dilation of Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0D750DZ" = "1" /* Dilation of Esophagus with Intraluminal Device, Open Approach */
"0D750ZZ" = "1" /* Dilation of Esophagus, Open Approach */
"0D753DZ" = "1" /* Dilation of Esophagus with Intraluminal Device, Percutaneous Approach */
"0D753ZZ" = "1" /* Dilation of Esophagus, Percutaneous Approach */
"0D754DZ" = "1" /* Dilation of Esophagus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D754ZZ" = "1" /* Dilation of Esophagus, Percutaneous Endoscopic Approach */
"0D760DZ" = "1" /* Dilation of Stomach with Intraluminal Device, Open Approach */
"0D760ZZ" = "1" /* Dilation of Stomach, Open Approach */
"0D763DZ" = "1" /* Dilation of Stomach with Intraluminal Device, Percutaneous Approach */
"0D763ZZ" = "1" /* Dilation of Stomach, Percutaneous Approach */
"0D764DZ" = "1" /* Dilation of Stomach with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D764ZZ" = "1" /* Dilation of Stomach, Percutaneous Endoscopic Approach */
"0D770DZ" = "1" /* Dilation of Stomach, Pylorus with Intraluminal Device, Open Approach */
"0D770ZZ" = "1" /* Dilation of Stomach, Pylorus, Open Approach */
"0D773DZ" = "1" /* Dilation of Stomach, Pylorus with Intraluminal Device, Percutaneous Approach */
"0D773ZZ" = "1" /* Dilation of Stomach, Pylorus, Percutaneous Approach */
"0D774ZZ" = "1" /* Dilation of Stomach, Pylorus, Percutaneous Endoscopic Approach */
"0D780ZZ" = "1" /* Dilation of Small Intestine, Open Approach */
"0D783ZZ" = "1" /* Dilation of Small Intestine, Percutaneous Approach */
"0D784ZZ" = "1" /* Dilation of Small Intestine, Percutaneous Endoscopic Approach */
"0D790ZZ" = "1" /* Dilation of Duodenum, Open Approach */
"0D793ZZ" = "1" /* Dilation of Duodenum, Percutaneous Approach */
"0D794ZZ" = "1" /* Dilation of Duodenum, Percutaneous Endoscopic Approach */
"0D7A0ZZ" = "1" /* Dilation of Jejunum, Open Approach */
"0D7A3ZZ" = "1" /* Dilation of Jejunum, Percutaneous Approach */
"0D7A4ZZ" = "1" /* Dilation of Jejunum, Percutaneous Endoscopic Approach */
"0D7B0ZZ" = "1" /* Dilation of Ileum, Open Approach */
"0D7B3ZZ" = "1" /* Dilation of Ileum, Percutaneous Approach */
"0D7B4ZZ" = "1" /* Dilation of Ileum, Percutaneous Endoscopic Approach */
"0D7C0ZZ" = "1" /* Dilation of Ileocecal Valve, Open Approach */
"0D7C3ZZ" = "1" /* Dilation of Ileocecal Valve, Percutaneous Approach */
"0D7C4ZZ" = "1" /* Dilation of Ileocecal Valve, Percutaneous Endoscopic Approach */
"0D7E0ZZ" = "1" /* Dilation of Large Intestine, Open Approach */
"0D7E3ZZ" = "1" /* Dilation of Large Intestine, Percutaneous Approach */
"0D7E4ZZ" = "1" /* Dilation of Large Intestine, Percutaneous Endoscopic Approach */
"0D7F0ZZ" = "1" /* Dilation of Right Large Intestine, Open Approach */
"0D7F3ZZ" = "1" /* Dilation of Right Large Intestine, Percutaneous Approach */
"0D7F4ZZ" = "1" /* Dilation of Right Large Intestine, Percutaneous Endoscopic Approach */
"0D7G0ZZ" = "1" /* Dilation of Left Large Intestine, Open Approach */
"0D7G3ZZ" = "1" /* Dilation of Left Large Intestine, Percutaneous Approach */
"0D7G4ZZ" = "1" /* Dilation of Left Large Intestine, Percutaneous Endoscopic Approach */
"0D7H0ZZ" = "1" /* Dilation of Cecum, Open Approach */
"0D7H3ZZ" = "1" /* Dilation of Cecum, Percutaneous Approach */
"0D7H4ZZ" = "1" /* Dilation of Cecum, Percutaneous Endoscopic Approach */
"0D7K0ZZ" = "1" /* Dilation of Ascending Colon, Open Approach */
"0D7K3ZZ" = "1" /* Dilation of Ascending Colon, Percutaneous Approach */
"0D7K4ZZ" = "1" /* Dilation of Ascending Colon, Percutaneous Endoscopic Approach */
"0D7L0ZZ" = "1" /* Dilation of Transverse Colon, Open Approach */
"0D7L3ZZ" = "1" /* Dilation of Transverse Colon, Percutaneous Approach */
"0D7L4ZZ" = "1" /* Dilation of Transverse Colon, Percutaneous Endoscopic Approach */
"0D7M0ZZ" = "1" /* Dilation of Descending Colon, Open Approach */
"0D7M3ZZ" = "1" /* Dilation of Descending Colon, Percutaneous Approach */
"0D7M4ZZ" = "1" /* Dilation of Descending Colon, Percutaneous Endoscopic Approach */
"0D7N0ZZ" = "1" /* Dilation of Sigmoid Colon, Open Approach */
"0D7N3ZZ" = "1" /* Dilation of Sigmoid Colon, Percutaneous Approach */
"0D7N4ZZ" = "1" /* Dilation of Sigmoid Colon, Percutaneous Endoscopic Approach */
"0D7P0DZ" = "1" /* Dilation of Rectum with Intraluminal Device, Open Approach */
"0D7P0ZZ" = "1" /* Dilation of Rectum, Open Approach */
"0D7P3DZ" = "1" /* Dilation of Rectum with Intraluminal Device, Percutaneous Approach */
"0D7P3ZZ" = "1" /* Dilation of Rectum, Percutaneous Approach */
"0D7P4DZ" = "1" /* Dilation of Rectum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D7P4ZZ" = "1" /* Dilation of Rectum, Percutaneous Endoscopic Approach */
"0D7Q0DZ" = "1" /* Dilation of Anus with Intraluminal Device, Open Approach */
"0D7Q0ZZ" = "1" /* Dilation of Anus, Open Approach */
"0D7Q3DZ" = "1" /* Dilation of Anus with Intraluminal Device, Percutaneous Approach */
"0D7Q3ZZ" = "1" /* Dilation of Anus, Percutaneous Approach */
"0D7Q4DZ" = "1" /* Dilation of Anus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D7Q4ZZ" = "1" /* Dilation of Anus, Percutaneous Endoscopic Approach */
"0D840ZZ" = "1" /* Division of Esophagogastric Junction, Open Approach */
"0D843ZZ" = "1" /* Division of Esophagogastric Junction, Percutaneous Approach */
"0D844ZZ" = "1" /* Division of Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0D847ZZ" = "1" /* Division of Esophagogastric Junction, Via Natural or Artificial Opening */
"0D848ZZ" = "1" /* Division of Esophagogastric Junction, Via Natural or Artificial Opening Endoscopic */
"0D870ZZ" = "1" /* Division of Stomach, Pylorus, Open Approach */
"0D873ZZ" = "1" /* Division of Stomach, Pylorus, Percutaneous Approach */
"0D874ZZ" = "1" /* Division of Stomach, Pylorus, Percutaneous Endoscopic Approach */
"0D877ZZ" = "1" /* Division of Stomach, Pylorus, Via Natural or Artificial Opening */
"0D878ZZ" = "1" /* Division of Stomach, Pylorus, Via Natural or Artificial Opening Endoscopic */
"0D8R0ZZ" = "1" /* Division of Anal Sphincter, Open Approach */
"0D8R3ZZ" = "1" /* Division of Anal Sphincter, Percutaneous Approach */
"0D9100Z" = "1" /* Drainage of Upper Esophagus with Drainage Device, Open Approach */
"0D910ZX" = "1" /* Drainage of Upper Esophagus, Open Approach, Diagnostic */
"0D910ZZ" = "1" /* Drainage of Upper Esophagus, Open Approach */
"0D9140Z" = "1" /* Drainage of Upper Esophagus with Drainage Device, Percutaneous Endoscopic Approach */
"0D914ZZ" = "1" /* Drainage of Upper Esophagus, Percutaneous Endoscopic Approach */
"0D9170Z" = "1" /* Drainage of Upper Esophagus with Drainage Device, Via Natural or Artificial Opening */
"0D917ZZ" = "1" /* Drainage of Upper Esophagus, Via Natural or Artificial Opening */
"0D9180Z" = "1" /* Drainage of Upper Esophagus with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0D918ZZ" = "1" /* Drainage of Upper Esophagus, Via Natural or Artificial Opening Endoscopic */
"0D9200Z" = "1" /* Drainage of Middle Esophagus with Drainage Device, Open Approach */
"0D920ZX" = "1" /* Drainage of Middle Esophagus, Open Approach, Diagnostic */
"0D920ZZ" = "1" /* Drainage of Middle Esophagus, Open Approach */
"0D9240Z" = "1" /* Drainage of Middle Esophagus with Drainage Device, Percutaneous Endoscopic Approach */
"0D924ZZ" = "1" /* Drainage of Middle Esophagus, Percutaneous Endoscopic Approach */
"0D9270Z" = "1" /* Drainage of Middle Esophagus with Drainage Device, Via Natural or Artificial Opening */
"0D927ZZ" = "1" /* Drainage of Middle Esophagus, Via Natural or Artificial Opening */
"0D9280Z" = "1" /* Drainage of Middle Esophagus with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0D928ZZ" = "1" /* Drainage of Middle Esophagus, Via Natural or Artificial Opening Endoscopic */
"0D9300Z" = "1" /* Drainage of Lower Esophagus with Drainage Device, Open Approach */
"0D930ZX" = "1" /* Drainage of Lower Esophagus, Open Approach, Diagnostic */
"0D930ZZ" = "1" /* Drainage of Lower Esophagus, Open Approach */
"0D9340Z" = "1" /* Drainage of Lower Esophagus with Drainage Device, Percutaneous Endoscopic Approach */
"0D934ZZ" = "1" /* Drainage of Lower Esophagus, Percutaneous Endoscopic Approach */
"0D9370Z" = "1" /* Drainage of Lower Esophagus with Drainage Device, Via Natural or Artificial Opening */
"0D937ZZ" = "1" /* Drainage of Lower Esophagus, Via Natural or Artificial Opening */
"0D9380Z" = "1" /* Drainage of Lower Esophagus with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0D938ZZ" = "1" /* Drainage of Lower Esophagus, Via Natural or Artificial Opening Endoscopic */
"0D9400Z" = "1" /* Drainage of Esophagogastric Junction with Drainage Device, Open Approach */
"0D940ZX" = "1" /* Drainage of Esophagogastric Junction, Open Approach, Diagnostic */
"0D940ZZ" = "1" /* Drainage of Esophagogastric Junction, Open Approach */
"0D9440Z" = "1" /* Drainage of Esophagogastric Junction with Drainage Device, Percutaneous Endoscopic Approach */
"0D944ZZ" = "1" /* Drainage of Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0D9470Z" = "1" /* Drainage of Esophagogastric Junction with Drainage Device, Via Natural or Artificial Opening */
"0D947ZZ" = "1" /* Drainage of Esophagogastric Junction, Via Natural or Artificial Opening */
"0D9480Z" = "1" /* Drainage of Esophagogastric Junction with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0D948ZZ" = "1" /* Drainage of Esophagogastric Junction, Via Natural or Artificial Opening Endoscopic */
"0D9500Z" = "1" /* Drainage of Esophagus with Drainage Device, Open Approach */
"0D950ZX" = "1" /* Drainage of Esophagus, Open Approach, Diagnostic */
"0D950ZZ" = "1" /* Drainage of Esophagus, Open Approach */
"0D9540Z" = "1" /* Drainage of Esophagus with Drainage Device, Percutaneous Endoscopic Approach */
"0D954ZZ" = "1" /* Drainage of Esophagus, Percutaneous Endoscopic Approach */
"0D9570Z" = "1" /* Drainage of Esophagus with Drainage Device, Via Natural or Artificial Opening */
"0D957ZZ" = "1" /* Drainage of Esophagus, Via Natural or Artificial Opening */
"0D9580Z" = "1" /* Drainage of Esophagus with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0D958ZZ" = "1" /* Drainage of Esophagus, Via Natural or Artificial Opening Endoscopic */
"0D9600Z" = "1" /* Drainage of Stomach with Drainage Device, Open Approach */
"0D960ZX" = "1" /* Drainage of Stomach, Open Approach, Diagnostic */
"0D960ZZ" = "1" /* Drainage of Stomach, Open Approach */
"0D9640Z" = "1" /* Drainage of Stomach with Drainage Device, Percutaneous Endoscopic Approach */
"0D964ZZ" = "1" /* Drainage of Stomach, Percutaneous Endoscopic Approach */
"0D967ZZ" = "1" /* Drainage of Stomach, Via Natural or Artificial Opening */
"0D968ZZ" = "1" /* Drainage of Stomach, Via Natural or Artificial Opening Endoscopic */
"0D9700Z" = "1" /* Drainage of Stomach, Pylorus with Drainage Device, Open Approach */
"0D970ZX" = "1" /* Drainage of Stomach, Pylorus, Open Approach, Diagnostic */
"0D970ZZ" = "1" /* Drainage of Stomach, Pylorus, Open Approach */
"0D9740Z" = "1" /* Drainage of Stomach, Pylorus with Drainage Device, Percutaneous Endoscopic Approach */
"0D974ZZ" = "1" /* Drainage of Stomach, Pylorus, Percutaneous Endoscopic Approach */
"0D977ZZ" = "1" /* Drainage of Stomach, Pylorus, Via Natural or Artificial Opening */
"0D978ZZ" = "1" /* Drainage of Stomach, Pylorus, Via Natural or Artificial Opening Endoscopic */
"0D9800Z" = "1" /* Drainage of Small Intestine with Drainage Device, Open Approach */
"0D980ZX" = "1" /* Drainage of Small Intestine, Open Approach, Diagnostic */
"0D980ZZ" = "1" /* Drainage of Small Intestine, Open Approach */
"0D9840Z" = "1" /* Drainage of Small Intestine with Drainage Device, Percutaneous Endoscopic Approach */
"0D984ZZ" = "1" /* Drainage of Small Intestine, Percutaneous Endoscopic Approach */
"0D987ZZ" = "1" /* Drainage of Small Intestine, Via Natural or Artificial Opening */
"0D988ZZ" = "1" /* Drainage of Small Intestine, Via Natural or Artificial Opening Endoscopic */
"0D9900Z" = "1" /* Drainage of Duodenum with Drainage Device, Open Approach */
"0D990ZX" = "1" /* Drainage of Duodenum, Open Approach, Diagnostic */
"0D990ZZ" = "1" /* Drainage of Duodenum, Open Approach */
"0D9940Z" = "1" /* Drainage of Duodenum with Drainage Device, Percutaneous Endoscopic Approach */
"0D994ZZ" = "1" /* Drainage of Duodenum, Percutaneous Endoscopic Approach */
"0D997ZZ" = "1" /* Drainage of Duodenum, Via Natural or Artificial Opening */
"0D998ZZ" = "1" /* Drainage of Duodenum, Via Natural or Artificial Opening Endoscopic */
"0D9A00Z" = "1" /* Drainage of Jejunum with Drainage Device, Open Approach */
"0D9A0ZX" = "1" /* Drainage of Jejunum, Open Approach, Diagnostic */
"0D9A0ZZ" = "1" /* Drainage of Jejunum, Open Approach */
"0D9A40Z" = "1" /* Drainage of Jejunum with Drainage Device, Percutaneous Endoscopic Approach */
"0D9A4ZZ" = "1" /* Drainage of Jejunum, Percutaneous Endoscopic Approach */
"0D9A7ZZ" = "1" /* Drainage of Jejunum, Via Natural or Artificial Opening */
"0D9A8ZZ" = "1" /* Drainage of Jejunum, Via Natural or Artificial Opening Endoscopic */
"0D9B00Z" = "1" /* Drainage of Ileum with Drainage Device, Open Approach */
"0D9B0ZX" = "1" /* Drainage of Ileum, Open Approach, Diagnostic */
"0D9B0ZZ" = "1" /* Drainage of Ileum, Open Approach */
"0D9B40Z" = "1" /* Drainage of Ileum with Drainage Device, Percutaneous Endoscopic Approach */
"0D9B4ZZ" = "1" /* Drainage of Ileum, Percutaneous Endoscopic Approach */
"0D9B7ZZ" = "1" /* Drainage of Ileum, Via Natural or Artificial Opening */
"0D9B8ZZ" = "1" /* Drainage of Ileum, Via Natural or Artificial Opening Endoscopic */
"0D9C00Z" = "1" /* Drainage of Ileocecal Valve with Drainage Device, Open Approach */
"0D9C0ZX" = "1" /* Drainage of Ileocecal Valve, Open Approach, Diagnostic */
"0D9C0ZZ" = "1" /* Drainage of Ileocecal Valve, Open Approach */
"0D9C40Z" = "1" /* Drainage of Ileocecal Valve with Drainage Device, Percutaneous Endoscopic Approach */
"0D9C4ZZ" = "1" /* Drainage of Ileocecal Valve, Percutaneous Endoscopic Approach */
"0D9C70Z" = "1" /* Drainage of Ileocecal Valve with Drainage Device, Via Natural or Artificial Opening */
"0D9C7ZZ" = "1" /* Drainage of Ileocecal Valve, Via Natural or Artificial Opening */
"0D9C80Z" = "1" /* Drainage of Ileocecal Valve with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0D9C8ZZ" = "1" /* Drainage of Ileocecal Valve, Via Natural or Artificial Opening Endoscopic */
"0D9E00Z" = "1" /* Drainage of Large Intestine with Drainage Device, Open Approach */
"0D9E0ZX" = "1" /* Drainage of Large Intestine, Open Approach, Diagnostic */
"0D9E0ZZ" = "1" /* Drainage of Large Intestine, Open Approach */
"0D9E40Z" = "1" /* Drainage of Large Intestine with Drainage Device, Percutaneous Endoscopic Approach */
"0D9E4ZZ" = "1" /* Drainage of Large Intestine, Percutaneous Endoscopic Approach */
"0D9E7ZZ" = "1" /* Drainage of Large Intestine, Via Natural or Artificial Opening */
"0D9E8ZZ" = "1" /* Drainage of Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0D9F00Z" = "1" /* Drainage of Right Large Intestine with Drainage Device, Open Approach */
"0D9F0ZX" = "1" /* Drainage of Right Large Intestine, Open Approach, Diagnostic */
"0D9F0ZZ" = "1" /* Drainage of Right Large Intestine, Open Approach */
"0D9F40Z" = "1" /* Drainage of Right Large Intestine with Drainage Device, Percutaneous Endoscopic Approach */
"0D9F4ZZ" = "1" /* Drainage of Right Large Intestine, Percutaneous Endoscopic Approach */
"0D9F7ZZ" = "1" /* Drainage of Right Large Intestine, Via Natural or Artificial Opening */
"0D9F8ZZ" = "1" /* Drainage of Right Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0D9G00Z" = "1" /* Drainage of Left Large Intestine with Drainage Device, Open Approach */
"0D9G0ZX" = "1" /* Drainage of Left Large Intestine, Open Approach, Diagnostic */
"0D9G0ZZ" = "1" /* Drainage of Left Large Intestine, Open Approach */
"0D9G40Z" = "1" /* Drainage of Left Large Intestine with Drainage Device, Percutaneous Endoscopic Approach */
"0D9G4ZZ" = "1" /* Drainage of Left Large Intestine, Percutaneous Endoscopic Approach */
"0D9G7ZZ" = "1" /* Drainage of Left Large Intestine, Via Natural or Artificial Opening */
"0D9G8ZZ" = "1" /* Drainage of Left Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0D9H00Z" = "1" /* Drainage of Cecum with Drainage Device, Open Approach */
"0D9H0ZX" = "1" /* Drainage of Cecum, Open Approach, Diagnostic */
"0D9H0ZZ" = "1" /* Drainage of Cecum, Open Approach */
"0D9H40Z" = "1" /* Drainage of Cecum with Drainage Device, Percutaneous Endoscopic Approach */
"0D9H4ZZ" = "1" /* Drainage of Cecum, Percutaneous Endoscopic Approach */
"0D9H7ZZ" = "1" /* Drainage of Cecum, Via Natural or Artificial Opening */
"0D9H8ZZ" = "1" /* Drainage of Cecum, Via Natural or Artificial Opening Endoscopic */
"0D9J00Z" = "1" /* Drainage of Appendix with Drainage Device, Open Approach */
"0D9J0ZX" = "1" /* Drainage of Appendix, Open Approach, Diagnostic */
"0D9J0ZZ" = "1" /* Drainage of Appendix, Open Approach */
"0D9J40Z" = "1" /* Drainage of Appendix with Drainage Device, Percutaneous Endoscopic Approach */
"0D9J4ZX" = "1" /* Drainage of Appendix, Percutaneous Endoscopic Approach, Diagnostic */
"0D9J4ZZ" = "1" /* Drainage of Appendix, Percutaneous Endoscopic Approach */
"0D9J70Z" = "1" /* Drainage of Appendix with Drainage Device, Via Natural or Artificial Opening */
"0D9J7ZX" = "1" /* Drainage of Appendix, Via Natural or Artificial Opening, Diagnostic */
"0D9J7ZZ" = "1" /* Drainage of Appendix, Via Natural or Artificial Opening */
"0D9J80Z" = "1" /* Drainage of Appendix with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0D9J8ZX" = "1" /* Drainage of Appendix, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0D9J8ZZ" = "1" /* Drainage of Appendix, Via Natural or Artificial Opening Endoscopic */
"0D9K00Z" = "1" /* Drainage of Ascending Colon with Drainage Device, Open Approach */
"0D9K0ZX" = "1" /* Drainage of Ascending Colon, Open Approach, Diagnostic */
"0D9K0ZZ" = "1" /* Drainage of Ascending Colon, Open Approach */
"0D9K40Z" = "1" /* Drainage of Ascending Colon with Drainage Device, Percutaneous Endoscopic Approach */
"0D9K4ZZ" = "1" /* Drainage of Ascending Colon, Percutaneous Endoscopic Approach */
"0D9K7ZZ" = "1" /* Drainage of Ascending Colon, Via Natural or Artificial Opening */
"0D9K8ZZ" = "1" /* Drainage of Ascending Colon, Via Natural or Artificial Opening Endoscopic */
"0D9L00Z" = "1" /* Drainage of Transverse Colon with Drainage Device, Open Approach */
"0D9L0ZX" = "1" /* Drainage of Transverse Colon, Open Approach, Diagnostic */
"0D9L0ZZ" = "1" /* Drainage of Transverse Colon, Open Approach */
"0D9L40Z" = "1" /* Drainage of Transverse Colon with Drainage Device, Percutaneous Endoscopic Approach */
"0D9L4ZZ" = "1" /* Drainage of Transverse Colon, Percutaneous Endoscopic Approach */
"0D9L7ZZ" = "1" /* Drainage of Transverse Colon, Via Natural or Artificial Opening */
"0D9L8ZZ" = "1" /* Drainage of Transverse Colon, Via Natural or Artificial Opening Endoscopic */
"0D9M00Z" = "1" /* Drainage of Descending Colon with Drainage Device, Open Approach */
"0D9M0ZX" = "1" /* Drainage of Descending Colon, Open Approach, Diagnostic */
"0D9M0ZZ" = "1" /* Drainage of Descending Colon, Open Approach */
"0D9M40Z" = "1" /* Drainage of Descending Colon with Drainage Device, Percutaneous Endoscopic Approach */
"0D9M4ZZ" = "1" /* Drainage of Descending Colon, Percutaneous Endoscopic Approach */
"0D9M7ZZ" = "1" /* Drainage of Descending Colon, Via Natural or Artificial Opening */
"0D9M8ZZ" = "1" /* Drainage of Descending Colon, Via Natural or Artificial Opening Endoscopic */
"0D9N00Z" = "1" /* Drainage of Sigmoid Colon with Drainage Device, Open Approach */
"0D9N0ZX" = "1" /* Drainage of Sigmoid Colon, Open Approach, Diagnostic */
"0D9N0ZZ" = "1" /* Drainage of Sigmoid Colon, Open Approach */
"0D9N40Z" = "1" /* Drainage of Sigmoid Colon with Drainage Device, Percutaneous Endoscopic Approach */
"0D9N4ZZ" = "1" /* Drainage of Sigmoid Colon, Percutaneous Endoscopic Approach */
"0D9N7ZZ" = "1" /* Drainage of Sigmoid Colon, Via Natural or Artificial Opening */
"0D9N8ZZ" = "1" /* Drainage of Sigmoid Colon, Via Natural or Artificial Opening Endoscopic */
"0D9P00Z" = "1" /* Drainage of Rectum with Drainage Device, Open Approach */
"0D9P0ZX" = "1" /* Drainage of Rectum, Open Approach, Diagnostic */
"0D9P0ZZ" = "1" /* Drainage of Rectum, Open Approach */
"0D9P40Z" = "1" /* Drainage of Rectum with Drainage Device, Percutaneous Endoscopic Approach */
"0D9P4ZZ" = "1" /* Drainage of Rectum, Percutaneous Endoscopic Approach */
"0D9P7ZZ" = "1" /* Drainage of Rectum, Via Natural or Artificial Opening */
"0D9P8ZZ" = "1" /* Drainage of Rectum, Via Natural or Artificial Opening Endoscopic */
"0D9Q00Z" = "1" /* Drainage of Anus with Drainage Device, Open Approach */
"0D9Q0ZZ" = "1" /* Drainage of Anus, Open Approach */
"0D9Q40Z" = "1" /* Drainage of Anus with Drainage Device, Percutaneous Endoscopic Approach */
"0D9Q4ZZ" = "1" /* Drainage of Anus, Percutaneous Endoscopic Approach */
"0D9Q70Z" = "1" /* Drainage of Anus with Drainage Device, Via Natural or Artificial Opening */
"0D9Q7ZZ" = "1" /* Drainage of Anus, Via Natural or Artificial Opening */
"0D9Q80Z" = "1" /* Drainage of Anus with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0D9Q8ZZ" = "1" /* Drainage of Anus, Via Natural or Artificial Opening Endoscopic */
"0D9QX0Z" = "1" /* Drainage of Anus with Drainage Device, External Approach */
"0D9QXZZ" = "1" /* Drainage of Anus, External Approach */
"0D9R00Z" = "1" /* Drainage of Anal Sphincter with Drainage Device, Open Approach */
"0D9R0ZZ" = "1" /* Drainage of Anal Sphincter, Open Approach */
"0D9R40Z" = "1" /* Drainage of Anal Sphincter with Drainage Device, Percutaneous Endoscopic Approach */
"0D9R4ZZ" = "1" /* Drainage of Anal Sphincter, Percutaneous Endoscopic Approach */
"0D9S00Z" = "1" /* Drainage of Greater Omentum with Drainage Device, Open Approach */
"0D9S0ZX" = "1" /* Drainage of Greater Omentum, Open Approach, Diagnostic */
"0D9S0ZZ" = "1" /* Drainage of Greater Omentum, Open Approach */
"0D9S4ZX" = "1" /* Drainage of Greater Omentum, Percutaneous Endoscopic Approach, Diagnostic */
"0D9T00Z" = "1" /* Drainage of Lesser Omentum with Drainage Device, Open Approach */
"0D9T0ZX" = "1" /* Drainage of Lesser Omentum, Open Approach, Diagnostic */
"0D9T0ZZ" = "1" /* Drainage of Lesser Omentum, Open Approach */
"0D9T4ZX" = "1" /* Drainage of Lesser Omentum, Percutaneous Endoscopic Approach, Diagnostic */
"0D9V00Z" = "1" /* Drainage of Mesentery with Drainage Device, Open Approach */
"0D9V0ZX" = "1" /* Drainage of Mesentery, Open Approach, Diagnostic */
"0D9V0ZZ" = "1" /* Drainage of Mesentery, Open Approach */
"0D9V4ZX" = "1" /* Drainage of Mesentery, Percutaneous Endoscopic Approach, Diagnostic */
"0D9W00Z" = "1" /* Drainage of Peritoneum with Drainage Device, Open Approach */
"0D9W0ZX" = "1" /* Drainage of Peritoneum, Open Approach, Diagnostic */
"0D9W0ZZ" = "1" /* Drainage of Peritoneum, Open Approach */
"0D9W4ZX" = "1" /* Drainage of Peritoneum, Percutaneous Endoscopic Approach, Diagnostic */
"0DB10ZX" = "1" /* Excision of Upper Esophagus, Open Approach, Diagnostic */
"0DB10ZZ" = "1" /* Excision of Upper Esophagus, Open Approach */
"0DB13ZZ" = "1" /* Excision of Upper Esophagus, Percutaneous Approach */
"0DB17ZZ" = "1" /* Excision of Upper Esophagus, Via Natural or Artificial Opening */
"0DB20ZX" = "1" /* Excision of Middle Esophagus, Open Approach, Diagnostic */
"0DB20ZZ" = "1" /* Excision of Middle Esophagus, Open Approach */
"0DB23ZZ" = "1" /* Excision of Middle Esophagus, Percutaneous Approach */
"0DB27ZZ" = "1" /* Excision of Middle Esophagus, Via Natural or Artificial Opening */
"0DB30ZX" = "1" /* Excision of Lower Esophagus, Open Approach, Diagnostic */
"0DB30ZZ" = "1" /* Excision of Lower Esophagus, Open Approach */
"0DB33ZZ" = "1" /* Excision of Lower Esophagus, Percutaneous Approach */
"0DB37ZZ" = "1" /* Excision of Lower Esophagus, Via Natural or Artificial Opening */
"0DB40ZX" = "1" /* Excision of Esophagogastric Junction, Open Approach, Diagnostic */
"0DB40ZZ" = "1" /* Excision of Esophagogastric Junction, Open Approach */
"0DB43ZZ" = "1" /* Excision of Esophagogastric Junction, Percutaneous Approach */
"0DB44ZZ" = "1" /* Excision of Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0DB47ZZ" = "1" /* Excision of Esophagogastric Junction, Via Natural or Artificial Opening */
"0DB50ZX" = "1" /* Excision of Esophagus, Open Approach, Diagnostic */
"0DB50ZZ" = "1" /* Excision of Esophagus, Open Approach */
"0DB53ZZ" = "1" /* Excision of Esophagus, Percutaneous Approach */
"0DB57ZZ" = "1" /* Excision of Esophagus, Via Natural or Artificial Opening */
"0DB60Z3" = "1" /* Excision of Stomach, Open Approach, Vertical */
"0DB60ZX" = "1" /* Excision of Stomach, Open Approach, Diagnostic */
"0DB60ZZ" = "1" /* Excision of Stomach, Open Approach */
"0DB63Z3" = "1" /* Excision of Stomach, Percutaneous Approach, Vertical */
"0DB63ZZ" = "1" /* Excision of Stomach, Percutaneous Approach */
"0DB64Z3" = "1" /* Excision of Stomach, Percutaneous Endoscopic Approach, Vertical */
"0DB67Z3" = "1" /* Excision of Stomach, Via Natural or Artificial Opening, Vertical */
"0DB67ZZ" = "1" /* Excision of Stomach, Via Natural or Artificial Opening */
"0DB68Z3" = "1" /* Excision of Stomach, Via Natural or Artificial Opening Endoscopic, Vertical */
"0DB70ZX" = "1" /* Excision of Stomach, Pylorus, Open Approach, Diagnostic */
"0DB70ZZ" = "1" /* Excision of Stomach, Pylorus, Open Approach */
"0DB73ZZ" = "1" /* Excision of Stomach, Pylorus, Percutaneous Approach */
"0DB77ZZ" = "1" /* Excision of Stomach, Pylorus, Via Natural or Artificial Opening */
"0DB80ZX" = "1" /* Excision of Small Intestine, Open Approach, Diagnostic */
"0DB80ZZ" = "1" /* Excision of Small Intestine, Open Approach */
"0DB83ZZ" = "1" /* Excision of Small Intestine, Percutaneous Approach */
"0DB84ZZ" = "1" /* Excision of Small Intestine, Percutaneous Endoscopic Approach */
"0DB87ZZ" = "1" /* Excision of Small Intestine, Via Natural or Artificial Opening */
"0DB88ZZ" = "1" /* Excision of Small Intestine, Via Natural or Artificial Opening Endoscopic */
"0DB90ZX" = "1" /* Excision of Duodenum, Open Approach, Diagnostic */
"0DB90ZZ" = "1" /* Excision of Duodenum, Open Approach */
"0DB93ZZ" = "1" /* Excision of Duodenum, Percutaneous Approach */
"0DB97ZZ" = "1" /* Excision of Duodenum, Via Natural or Artificial Opening */
"0DBA0ZX" = "1" /* Excision of Jejunum, Open Approach, Diagnostic */
"0DBA0ZZ" = "1" /* Excision of Jejunum, Open Approach */
"0DBA3ZZ" = "1" /* Excision of Jejunum, Percutaneous Approach */
"0DBA4ZZ" = "1" /* Excision of Jejunum, Percutaneous Endoscopic Approach */
"0DBA7ZZ" = "1" /* Excision of Jejunum, Via Natural or Artificial Opening */
"0DBA8ZZ" = "1" /* Excision of Jejunum, Via Natural or Artificial Opening Endoscopic */
"0DBB0ZX" = "1" /* Excision of Ileum, Open Approach, Diagnostic */
"0DBB0ZZ" = "1" /* Excision of Ileum, Open Approach */
"0DBB3ZZ" = "1" /* Excision of Ileum, Percutaneous Approach */
"0DBB4ZZ" = "1" /* Excision of Ileum, Percutaneous Endoscopic Approach */
"0DBB7ZZ" = "1" /* Excision of Ileum, Via Natural or Artificial Opening */
"0DBB8ZZ" = "1" /* Excision of Ileum, Via Natural or Artificial Opening Endoscopic */
"0DBC0ZX" = "1" /* Excision of Ileocecal Valve, Open Approach, Diagnostic */
"0DBC0ZZ" = "1" /* Excision of Ileocecal Valve, Open Approach */
"0DBC3ZZ" = "1" /* Excision of Ileocecal Valve, Percutaneous Approach */
"0DBC4ZZ" = "1" /* Excision of Ileocecal Valve, Percutaneous Endoscopic Approach */
"0DBC7ZZ" = "1" /* Excision of Ileocecal Valve, Via Natural or Artificial Opening */
"0DBC8ZZ" = "1" /* Excision of Ileocecal Valve, Via Natural or Artificial Opening Endoscopic */
"0DBE0ZX" = "1" /* Excision of Large Intestine, Open Approach, Diagnostic */
"0DBE0ZZ" = "1" /* Excision of Large Intestine, Open Approach */
"0DBE3ZZ" = "1" /* Excision of Large Intestine, Percutaneous Approach */
"0DBE4ZZ" = "1" /* Excision of Large Intestine, Percutaneous Endoscopic Approach */
"0DBE7ZZ" = "1" /* Excision of Large Intestine, Via Natural or Artificial Opening */
"0DBF0ZX" = "1" /* Excision of Right Large Intestine, Open Approach, Diagnostic */
"0DBF0ZZ" = "1" /* Excision of Right Large Intestine, Open Approach */
"0DBF3ZZ" = "1" /* Excision of Right Large Intestine, Percutaneous Approach */
"0DBF4ZZ" = "1" /* Excision of Right Large Intestine, Percutaneous Endoscopic Approach */
"0DBF7ZZ" = "1" /* Excision of Right Large Intestine, Via Natural or Artificial Opening */
"0DBG0ZX" = "1" /* Excision of Left Large Intestine, Open Approach, Diagnostic */
"0DBG0ZZ" = "1" /* Excision of Left Large Intestine, Open Approach */
"0DBG3ZZ" = "1" /* Excision of Left Large Intestine, Percutaneous Approach */
"0DBG4ZZ" = "1" /* Excision of Left Large Intestine, Percutaneous Endoscopic Approach */
"0DBG7ZZ" = "1" /* Excision of Left Large Intestine, Via Natural or Artificial Opening */
"0DBH0ZX" = "1" /* Excision of Cecum, Open Approach, Diagnostic */
"0DBH0ZZ" = "1" /* Excision of Cecum, Open Approach */
"0DBH3ZZ" = "1" /* Excision of Cecum, Percutaneous Approach */
"0DBH4ZZ" = "1" /* Excision of Cecum, Percutaneous Endoscopic Approach */
"0DBH7ZZ" = "1" /* Excision of Cecum, Via Natural or Artificial Opening */
"0DBJ0ZX" = "1" /* Excision of Appendix, Open Approach, Diagnostic */
"0DBJ0ZZ" = "1" /* Excision of Appendix, Open Approach */
"0DBJ3ZX" = "1" /* Excision of Appendix, Percutaneous Approach, Diagnostic */
"0DBJ3ZZ" = "1" /* Excision of Appendix, Percutaneous Approach */
"0DBJ4ZX" = "1" /* Excision of Appendix, Percutaneous Endoscopic Approach, Diagnostic */
"0DBJ4ZZ" = "1" /* Excision of Appendix, Percutaneous Endoscopic Approach */
"0DBJ7ZX" = "1" /* Excision of Appendix, Via Natural or Artificial Opening, Diagnostic */
"0DBJ7ZZ" = "1" /* Excision of Appendix, Via Natural or Artificial Opening */
"0DBJ8ZX" = "1" /* Excision of Appendix, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0DBJ8ZZ" = "1" /* Excision of Appendix, Via Natural or Artificial Opening Endoscopic */
"0DBK0ZX" = "1" /* Excision of Ascending Colon, Open Approach, Diagnostic */
"0DBK0ZZ" = "1" /* Excision of Ascending Colon, Open Approach */
"0DBK3ZZ" = "1" /* Excision of Ascending Colon, Percutaneous Approach */
"0DBK4ZZ" = "1" /* Excision of Ascending Colon, Percutaneous Endoscopic Approach */
"0DBK7ZZ" = "1" /* Excision of Ascending Colon, Via Natural or Artificial Opening */
"0DBL0ZX" = "1" /* Excision of Transverse Colon, Open Approach, Diagnostic */
"0DBL0ZZ" = "1" /* Excision of Transverse Colon, Open Approach */
"0DBL3ZZ" = "1" /* Excision of Transverse Colon, Percutaneous Approach */
"0DBL4ZZ" = "1" /* Excision of Transverse Colon, Percutaneous Endoscopic Approach */
"0DBL7ZZ" = "1" /* Excision of Transverse Colon, Via Natural or Artificial Opening */
"0DBM0ZX" = "1" /* Excision of Descending Colon, Open Approach, Diagnostic */
"0DBM0ZZ" = "1" /* Excision of Descending Colon, Open Approach */
"0DBM3ZZ" = "1" /* Excision of Descending Colon, Percutaneous Approach */
"0DBM4ZZ" = "1" /* Excision of Descending Colon, Percutaneous Endoscopic Approach */
"0DBM7ZZ" = "1" /* Excision of Descending Colon, Via Natural or Artificial Opening */
"0DBN0ZX" = "1" /* Excision of Sigmoid Colon, Open Approach, Diagnostic */
"0DBN0ZZ" = "1" /* Excision of Sigmoid Colon, Open Approach */
"0DBN3ZZ" = "1" /* Excision of Sigmoid Colon, Percutaneous Approach */
"0DBN4ZZ" = "1" /* Excision of Sigmoid Colon, Percutaneous Endoscopic Approach */
"0DBN7ZZ" = "1" /* Excision of Sigmoid Colon, Via Natural or Artificial Opening */
"0DBP0ZX" = "1" /* Excision of Rectum, Open Approach, Diagnostic */
"0DBP0ZZ" = "1" /* Excision of Rectum, Open Approach */
"0DBP3ZZ" = "1" /* Excision of Rectum, Percutaneous Approach */
"0DBP4ZZ" = "1" /* Excision of Rectum, Percutaneous Endoscopic Approach */
"0DBP7ZZ" = "1" /* Excision of Rectum, Via Natural or Artificial Opening */
"0DBQ0ZZ" = "1" /* Excision of Anus, Open Approach */
"0DBQ3ZZ" = "1" /* Excision of Anus, Percutaneous Approach */
"0DBQ4ZZ" = "1" /* Excision of Anus, Percutaneous Endoscopic Approach */
"0DBQ7ZZ" = "1" /* Excision of Anus, Via Natural or Artificial Opening */
"0DBQXZZ" = "1" /* Excision of Anus, External Approach */
"0DBR0ZZ" = "1" /* Excision of Anal Sphincter, Open Approach */
"0DBR3ZZ" = "1" /* Excision of Anal Sphincter, Percutaneous Approach */
"0DBR4ZZ" = "1" /* Excision of Anal Sphincter, Percutaneous Endoscopic Approach */
"0DBS0ZX" = "1" /* Excision of Greater Omentum, Open Approach, Diagnostic */
"0DBS0ZZ" = "1" /* Excision of Greater Omentum, Open Approach */
"0DBS3ZZ" = "1" /* Excision of Greater Omentum, Percutaneous Approach */
"0DBS4ZZ" = "1" /* Excision of Greater Omentum, Percutaneous Endoscopic Approach */
"0DBT0ZX" = "1" /* Excision of Lesser Omentum, Open Approach, Diagnostic */
"0DBT0ZZ" = "1" /* Excision of Lesser Omentum, Open Approach */
"0DBT3ZZ" = "1" /* Excision of Lesser Omentum, Percutaneous Approach */
"0DBT4ZZ" = "1" /* Excision of Lesser Omentum, Percutaneous Endoscopic Approach */
"0DBV0ZX" = "1" /* Excision of Mesentery, Open Approach, Diagnostic */
"0DBV0ZZ" = "1" /* Excision of Mesentery, Open Approach */
"0DBV3ZZ" = "1" /* Excision of Mesentery, Percutaneous Approach */
"0DBV4ZZ" = "1" /* Excision of Mesentery, Percutaneous Endoscopic Approach */
"0DBW0ZX" = "1" /* Excision of Peritoneum, Open Approach, Diagnostic */
"0DBW0ZZ" = "1" /* Excision of Peritoneum, Open Approach */
"0DBW3ZZ" = "1" /* Excision of Peritoneum, Percutaneous Approach */
"0DBW4ZZ" = "1" /* Excision of Peritoneum, Percutaneous Endoscopic Approach */
"0DC10ZZ" = "1" /* Extirpation of Matter from Upper Esophagus, Open Approach */
"0DC13ZZ" = "1" /* Extirpation of Matter from Upper Esophagus, Percutaneous Approach */
"0DC14ZZ" = "1" /* Extirpation of Matter from Upper Esophagus, Percutaneous Endoscopic Approach */
"0DC20ZZ" = "1" /* Extirpation of Matter from Middle Esophagus, Open Approach */
"0DC23ZZ" = "1" /* Extirpation of Matter from Middle Esophagus, Percutaneous Approach */
"0DC24ZZ" = "1" /* Extirpation of Matter from Middle Esophagus, Percutaneous Endoscopic Approach */
"0DC30ZZ" = "1" /* Extirpation of Matter from Lower Esophagus, Open Approach */
"0DC33ZZ" = "1" /* Extirpation of Matter from Lower Esophagus, Percutaneous Approach */
"0DC34ZZ" = "1" /* Extirpation of Matter from Lower Esophagus, Percutaneous Endoscopic Approach */
"0DC40ZZ" = "1" /* Extirpation of Matter from Esophagogastric Junction, Open Approach */
"0DC43ZZ" = "1" /* Extirpation of Matter from Esophagogastric Junction, Percutaneous Approach */
"0DC44ZZ" = "1" /* Extirpation of Matter from Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0DC50ZZ" = "1" /* Extirpation of Matter from Esophagus, Open Approach */
"0DC53ZZ" = "1" /* Extirpation of Matter from Esophagus, Percutaneous Approach */
"0DC54ZZ" = "1" /* Extirpation of Matter from Esophagus, Percutaneous Endoscopic Approach */
"0DC60ZZ" = "1" /* Extirpation of Matter from Stomach, Open Approach */
"0DC63ZZ" = "1" /* Extirpation of Matter from Stomach, Percutaneous Approach */
"0DC64ZZ" = "1" /* Extirpation of Matter from Stomach, Percutaneous Endoscopic Approach */
"0DC70ZZ" = "1" /* Extirpation of Matter from Stomach, Pylorus, Open Approach */
"0DC73ZZ" = "1" /* Extirpation of Matter from Stomach, Pylorus, Percutaneous Approach */
"0DC74ZZ" = "1" /* Extirpation of Matter from Stomach, Pylorus, Percutaneous Endoscopic Approach */
"0DC80ZZ" = "1" /* Extirpation of Matter from Small Intestine, Open Approach */
"0DC83ZZ" = "1" /* Extirpation of Matter from Small Intestine, Percutaneous Approach */
"0DC84ZZ" = "1" /* Extirpation of Matter from Small Intestine, Percutaneous Endoscopic Approach */
"0DC90ZZ" = "1" /* Extirpation of Matter from Duodenum, Open Approach */
"0DC93ZZ" = "1" /* Extirpation of Matter from Duodenum, Percutaneous Approach */
"0DC94ZZ" = "1" /* Extirpation of Matter from Duodenum, Percutaneous Endoscopic Approach */
"0DCA0ZZ" = "1" /* Extirpation of Matter from Jejunum, Open Approach */
"0DCA3ZZ" = "1" /* Extirpation of Matter from Jejunum, Percutaneous Approach */
"0DCA4ZZ" = "1" /* Extirpation of Matter from Jejunum, Percutaneous Endoscopic Approach */
"0DCB0ZZ" = "1" /* Extirpation of Matter from Ileum, Open Approach */
"0DCB3ZZ" = "1" /* Extirpation of Matter from Ileum, Percutaneous Approach */
"0DCB4ZZ" = "1" /* Extirpation of Matter from Ileum, Percutaneous Endoscopic Approach */
"0DCC0ZZ" = "1" /* Extirpation of Matter from Ileocecal Valve, Open Approach */
"0DCC3ZZ" = "1" /* Extirpation of Matter from Ileocecal Valve, Percutaneous Approach */
"0DCC4ZZ" = "1" /* Extirpation of Matter from Ileocecal Valve, Percutaneous Endoscopic Approach */
"0DCE0ZZ" = "1" /* Extirpation of Matter from Large Intestine, Open Approach */
"0DCE3ZZ" = "1" /* Extirpation of Matter from Large Intestine, Percutaneous Approach */
"0DCE4ZZ" = "1" /* Extirpation of Matter from Large Intestine, Percutaneous Endoscopic Approach */
"0DCF0ZZ" = "1" /* Extirpation of Matter from Right Large Intestine, Open Approach */
"0DCF3ZZ" = "1" /* Extirpation of Matter from Right Large Intestine, Percutaneous Approach */
"0DCF4ZZ" = "1" /* Extirpation of Matter from Right Large Intestine, Percutaneous Endoscopic Approach */
"0DCG0ZZ" = "1" /* Extirpation of Matter from Left Large Intestine, Open Approach */
"0DCG3ZZ" = "1" /* Extirpation of Matter from Left Large Intestine, Percutaneous Approach */
"0DCG4ZZ" = "1" /* Extirpation of Matter from Left Large Intestine, Percutaneous Endoscopic Approach */
"0DCH0ZZ" = "1" /* Extirpation of Matter from Cecum, Open Approach */
"0DCH3ZZ" = "1" /* Extirpation of Matter from Cecum, Percutaneous Approach */
"0DCH4ZZ" = "1" /* Extirpation of Matter from Cecum, Percutaneous Endoscopic Approach */
"0DCJ0ZZ" = "1" /* Extirpation of Matter from Appendix, Open Approach */
"0DCJ3ZZ" = "1" /* Extirpation of Matter from Appendix, Percutaneous Approach */
"0DCJ4ZZ" = "1" /* Extirpation of Matter from Appendix, Percutaneous Endoscopic Approach */
"0DCJ7ZZ" = "1" /* Extirpation of Matter from Appendix, Via Natural or Artificial Opening */
"0DCJ8ZZ" = "1" /* Extirpation of Matter from Appendix, Via Natural or Artificial Opening Endoscopic */
"0DCK0ZZ" = "1" /* Extirpation of Matter from Ascending Colon, Open Approach */
"0DCK3ZZ" = "1" /* Extirpation of Matter from Ascending Colon, Percutaneous Approach */
"0DCK4ZZ" = "1" /* Extirpation of Matter from Ascending Colon, Percutaneous Endoscopic Approach */
"0DCL0ZZ" = "1" /* Extirpation of Matter from Transverse Colon, Open Approach */
"0DCL3ZZ" = "1" /* Extirpation of Matter from Transverse Colon, Percutaneous Approach */
"0DCL4ZZ" = "1" /* Extirpation of Matter from Transverse Colon, Percutaneous Endoscopic Approach */
"0DCM0ZZ" = "1" /* Extirpation of Matter from Descending Colon, Open Approach */
"0DCM3ZZ" = "1" /* Extirpation of Matter from Descending Colon, Percutaneous Approach */
"0DCM4ZZ" = "1" /* Extirpation of Matter from Descending Colon, Percutaneous Endoscopic Approach */
"0DCN0ZZ" = "1" /* Extirpation of Matter from Sigmoid Colon, Open Approach */
"0DCN3ZZ" = "1" /* Extirpation of Matter from Sigmoid Colon, Percutaneous Approach */
"0DCN4ZZ" = "1" /* Extirpation of Matter from Sigmoid Colon, Percutaneous Endoscopic Approach */
"0DCP0ZZ" = "1" /* Extirpation of Matter from Rectum, Open Approach */
"0DCP3ZZ" = "1" /* Extirpation of Matter from Rectum, Percutaneous Approach */
"0DCP4ZZ" = "1" /* Extirpation of Matter from Rectum, Percutaneous Endoscopic Approach */
"0DCQ0ZZ" = "1" /* Extirpation of Matter from Anus, Open Approach */
"0DCQ3ZZ" = "1" /* Extirpation of Matter from Anus, Percutaneous Approach */
"0DCQ4ZZ" = "1" /* Extirpation of Matter from Anus, Percutaneous Endoscopic Approach */
"0DCR0ZZ" = "1" /* Extirpation of Matter from Anal Sphincter, Open Approach */
"0DCR3ZZ" = "1" /* Extirpation of Matter from Anal Sphincter, Percutaneous Approach */
"0DCR4ZZ" = "1" /* Extirpation of Matter from Anal Sphincter, Percutaneous Endoscopic Approach */
"0DCS0ZZ" = "1" /* Extirpation of Matter from Greater Omentum, Open Approach */
"0DCS3ZZ" = "1" /* Extirpation of Matter from Greater Omentum, Percutaneous Approach */
"0DCS4ZZ" = "1" /* Extirpation of Matter from Greater Omentum, Percutaneous Endoscopic Approach */
"0DCT0ZZ" = "1" /* Extirpation of Matter from Lesser Omentum, Open Approach */
"0DCT3ZZ" = "1" /* Extirpation of Matter from Lesser Omentum, Percutaneous Approach */
"0DCT4ZZ" = "1" /* Extirpation of Matter from Lesser Omentum, Percutaneous Endoscopic Approach */
"0DCV0ZZ" = "1" /* Extirpation of Matter from Mesentery, Open Approach */
"0DCV3ZZ" = "1" /* Extirpation of Matter from Mesentery, Percutaneous Approach */
"0DCV4ZZ" = "1" /* Extirpation of Matter from Mesentery, Percutaneous Endoscopic Approach */
"0DCW0ZZ" = "1" /* Extirpation of Matter from Peritoneum, Open Approach */
"0DCW3ZZ" = "1" /* Extirpation of Matter from Peritoneum, Percutaneous Approach */
"0DCW4ZZ" = "1" /* Extirpation of Matter from Peritoneum, Percutaneous Endoscopic Approach */
"0DF50ZZ" = "1" /* Fragmentation in Esophagus, Open Approach */
"0DF53ZZ" = "1" /* Fragmentation in Esophagus, Percutaneous Approach */
"0DF54ZZ" = "1" /* Fragmentation in Esophagus, Percutaneous Endoscopic Approach */
"0DF57ZZ" = "1" /* Fragmentation in Esophagus, Via Natural or Artificial Opening */
"0DF58ZZ" = "1" /* Fragmentation in Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DF60ZZ" = "1" /* Fragmentation in Stomach, Open Approach */
"0DF63ZZ" = "1" /* Fragmentation in Stomach, Percutaneous Approach */
"0DF64ZZ" = "1" /* Fragmentation in Stomach, Percutaneous Endoscopic Approach */
"0DF67ZZ" = "1" /* Fragmentation in Stomach, Via Natural or Artificial Opening */
"0DF68ZZ" = "1" /* Fragmentation in Stomach, Via Natural or Artificial Opening Endoscopic */
"0DF80ZZ" = "1" /* Fragmentation in Small Intestine, Open Approach */
"0DF83ZZ" = "1" /* Fragmentation in Small Intestine, Percutaneous Approach */
"0DF84ZZ" = "1" /* Fragmentation in Small Intestine, Percutaneous Endoscopic Approach */
"0DF87ZZ" = "1" /* Fragmentation in Small Intestine, Via Natural or Artificial Opening */
"0DF88ZZ" = "1" /* Fragmentation in Small Intestine, Via Natural or Artificial Opening Endoscopic */
"0DF90ZZ" = "1" /* Fragmentation in Duodenum, Open Approach */
"0DF93ZZ" = "1" /* Fragmentation in Duodenum, Percutaneous Approach */
"0DF94ZZ" = "1" /* Fragmentation in Duodenum, Percutaneous Endoscopic Approach */
"0DF97ZZ" = "1" /* Fragmentation in Duodenum, Via Natural or Artificial Opening */
"0DF98ZZ" = "1" /* Fragmentation in Duodenum, Via Natural or Artificial Opening Endoscopic */
"0DFA0ZZ" = "1" /* Fragmentation in Jejunum, Open Approach */
"0DFA3ZZ" = "1" /* Fragmentation in Jejunum, Percutaneous Approach */
"0DFA4ZZ" = "1" /* Fragmentation in Jejunum, Percutaneous Endoscopic Approach */
"0DFA7ZZ" = "1" /* Fragmentation in Jejunum, Via Natural or Artificial Opening */
"0DFA8ZZ" = "1" /* Fragmentation in Jejunum, Via Natural or Artificial Opening Endoscopic */
"0DFB0ZZ" = "1" /* Fragmentation in Ileum, Open Approach */
"0DFB3ZZ" = "1" /* Fragmentation in Ileum, Percutaneous Approach */
"0DFB4ZZ" = "1" /* Fragmentation in Ileum, Percutaneous Endoscopic Approach */
"0DFB7ZZ" = "1" /* Fragmentation in Ileum, Via Natural or Artificial Opening */
"0DFB8ZZ" = "1" /* Fragmentation in Ileum, Via Natural or Artificial Opening Endoscopic */
"0DFE0ZZ" = "1" /* Fragmentation in Large Intestine, Open Approach */
"0DFE3ZZ" = "1" /* Fragmentation in Large Intestine, Percutaneous Approach */
"0DFE4ZZ" = "1" /* Fragmentation in Large Intestine, Percutaneous Endoscopic Approach */
"0DFE7ZZ" = "1" /* Fragmentation in Large Intestine, Via Natural or Artificial Opening */
"0DFE8ZZ" = "1" /* Fragmentation in Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0DFF0ZZ" = "1" /* Fragmentation in Right Large Intestine, Open Approach */
"0DFF3ZZ" = "1" /* Fragmentation in Right Large Intestine, Percutaneous Approach */
"0DFF4ZZ" = "1" /* Fragmentation in Right Large Intestine, Percutaneous Endoscopic Approach */
"0DFF7ZZ" = "1" /* Fragmentation in Right Large Intestine, Via Natural or Artificial Opening */
"0DFF8ZZ" = "1" /* Fragmentation in Right Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0DFG0ZZ" = "1" /* Fragmentation in Left Large Intestine, Open Approach */
"0DFG3ZZ" = "1" /* Fragmentation in Left Large Intestine, Percutaneous Approach */
"0DFG4ZZ" = "1" /* Fragmentation in Left Large Intestine, Percutaneous Endoscopic Approach */
"0DFG7ZZ" = "1" /* Fragmentation in Left Large Intestine, Via Natural or Artificial Opening */
"0DFG8ZZ" = "1" /* Fragmentation in Left Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0DFH0ZZ" = "1" /* Fragmentation in Cecum, Open Approach */
"0DFH3ZZ" = "1" /* Fragmentation in Cecum, Percutaneous Approach */
"0DFH4ZZ" = "1" /* Fragmentation in Cecum, Percutaneous Endoscopic Approach */
"0DFH7ZZ" = "1" /* Fragmentation in Cecum, Via Natural or Artificial Opening */
"0DFH8ZZ" = "1" /* Fragmentation in Cecum, Via Natural or Artificial Opening Endoscopic */
"0DFJ0ZZ" = "1" /* Fragmentation in Appendix, Open Approach */
"0DFJ3ZZ" = "1" /* Fragmentation in Appendix, Percutaneous Approach */
"0DFJ4ZZ" = "1" /* Fragmentation in Appendix, Percutaneous Endoscopic Approach */
"0DFJ7ZZ" = "1" /* Fragmentation in Appendix, Via Natural or Artificial Opening */
"0DFJ8ZZ" = "1" /* Fragmentation in Appendix, Via Natural or Artificial Opening Endoscopic */
"0DFK0ZZ" = "1" /* Fragmentation in Ascending Colon, Open Approach */
"0DFK3ZZ" = "1" /* Fragmentation in Ascending Colon, Percutaneous Approach */
"0DFK4ZZ" = "1" /* Fragmentation in Ascending Colon, Percutaneous Endoscopic Approach */
"0DFK7ZZ" = "1" /* Fragmentation in Ascending Colon, Via Natural or Artificial Opening */
"0DFK8ZZ" = "1" /* Fragmentation in Ascending Colon, Via Natural or Artificial Opening Endoscopic */
"0DFL0ZZ" = "1" /* Fragmentation in Transverse Colon, Open Approach */
"0DFL3ZZ" = "1" /* Fragmentation in Transverse Colon, Percutaneous Approach */
"0DFL4ZZ" = "1" /* Fragmentation in Transverse Colon, Percutaneous Endoscopic Approach */
"0DFL7ZZ" = "1" /* Fragmentation in Transverse Colon, Via Natural or Artificial Opening */
"0DFL8ZZ" = "1" /* Fragmentation in Transverse Colon, Via Natural or Artificial Opening Endoscopic */
"0DFM0ZZ" = "1" /* Fragmentation in Descending Colon, Open Approach */
"0DFM3ZZ" = "1" /* Fragmentation in Descending Colon, Percutaneous Approach */
"0DFM4ZZ" = "1" /* Fragmentation in Descending Colon, Percutaneous Endoscopic Approach */
"0DFM7ZZ" = "1" /* Fragmentation in Descending Colon, Via Natural or Artificial Opening */
"0DFM8ZZ" = "1" /* Fragmentation in Descending Colon, Via Natural or Artificial Opening Endoscopic */
"0DFN0ZZ" = "1" /* Fragmentation in Sigmoid Colon, Open Approach */
"0DFN3ZZ" = "1" /* Fragmentation in Sigmoid Colon, Percutaneous Approach */
"0DFN4ZZ" = "1" /* Fragmentation in Sigmoid Colon, Percutaneous Endoscopic Approach */
"0DFN7ZZ" = "1" /* Fragmentation in Sigmoid Colon, Via Natural or Artificial Opening */
"0DFN8ZZ" = "1" /* Fragmentation in Sigmoid Colon, Via Natural or Artificial Opening Endoscopic */
"0DFP0ZZ" = "1" /* Fragmentation in Rectum, Open Approach */
"0DFP3ZZ" = "1" /* Fragmentation in Rectum, Percutaneous Approach */
"0DFP4ZZ" = "1" /* Fragmentation in Rectum, Percutaneous Endoscopic Approach */
"0DFP7ZZ" = "1" /* Fragmentation in Rectum, Via Natural or Artificial Opening */
"0DFP8ZZ" = "1" /* Fragmentation in Rectum, Via Natural or Artificial Opening Endoscopic */
"0DFQ0ZZ" = "1" /* Fragmentation in Anus, Open Approach */
"0DFQ3ZZ" = "1" /* Fragmentation in Anus, Percutaneous Approach */
"0DFQ4ZZ" = "1" /* Fragmentation in Anus, Percutaneous Endoscopic Approach */
"0DFQ7ZZ" = "1" /* Fragmentation in Anus, Via Natural or Artificial Opening */
"0DFQ8ZZ" = "1" /* Fragmentation in Anus, Via Natural or Artificial Opening Endoscopic */
"0DH501Z" = "1" /* Insertion of Radioactive Element into Esophagus, Open Approach */
"0DH502Z" = "1" /* Insertion of Monitoring Device into Esophagus, Open Approach */
"0DH503Z" = "1" /* Insertion of Infusion Device into Esophagus, Open Approach */
"0DH531Z" = "1" /* Insertion of Radioactive Element into Esophagus, Percutaneous Approach */
"0DH532Z" = "1" /* Insertion of Monitoring Device into Esophagus, Percutaneous Approach */
"0DH533Z" = "1" /* Insertion of Infusion Device into Esophagus, Percutaneous Approach */
"0DH541Z" = "1" /* Insertion of Radioactive Element into Esophagus, Percutaneous Endoscopic Approach */
"0DH542Z" = "1" /* Insertion of Monitoring Device into Esophagus, Percutaneous Endoscopic Approach */
"0DH543Z" = "1" /* Insertion of Infusion Device into Esophagus, Percutaneous Endoscopic Approach */
"0DH571Z" = "1" /* Insertion of Radioactive Element into Esophagus, Via Natural or Artificial Opening */
"0DH581Z" = "1" /* Insertion of Radioactive Element into Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DH602Z" = "1" /* Insertion of Monitoring Device into Stomach, Open Approach */
"0DH603Z" = "1" /* Insertion of Infusion Device into Stomach, Open Approach */
"0DH60DZ" = "1" /* Insertion of Intraluminal Device into Stomach, Open Approach */
"0DH60MZ" = "1" /* Insertion of Stimulator Lead into Stomach, Open Approach */
"0DH60UZ" = "1" /* Insertion of Feeding Device into Stomach, Open Approach */
"0DH632Z" = "1" /* Insertion of Monitoring Device into Stomach, Percutaneous Approach */
"0DH633Z" = "1" /* Insertion of Infusion Device into Stomach, Percutaneous Approach */
"0DH63DZ" = "1" /* Insertion of Intraluminal Device into Stomach, Percutaneous Approach */
"0DH63MZ" = "1" /* Insertion of Stimulator Lead into Stomach, Percutaneous Approach */
"0DH642Z" = "1" /* Insertion of Monitoring Device into Stomach, Percutaneous Endoscopic Approach */
"0DH643Z" = "1" /* Insertion of Infusion Device into Stomach, Percutaneous Endoscopic Approach */
"0DH64DZ" = "1" /* Insertion of Intraluminal Device into Stomach, Percutaneous Endoscopic Approach */
"0DH64MZ" = "1" /* Insertion of Stimulator Lead into Stomach, Percutaneous Endoscopic Approach */
"0DH802Z" = "1" /* Insertion of Monitoring Device into Small Intestine, Open Approach */
"0DH803Z" = "1" /* Insertion of Infusion Device into Small Intestine, Open Approach */
"0DH832Z" = "1" /* Insertion of Monitoring Device into Small Intestine, Percutaneous Approach */
"0DH833Z" = "1" /* Insertion of Infusion Device into Small Intestine, Percutaneous Approach */
"0DH842Z" = "1" /* Insertion of Monitoring Device into Small Intestine, Percutaneous Endoscopic Approach */
"0DH843Z" = "1" /* Insertion of Infusion Device into Small Intestine, Percutaneous Endoscopic Approach */
"0DH902Z" = "1" /* Insertion of Monitoring Device into Duodenum, Open Approach */
"0DH903Z" = "1" /* Insertion of Infusion Device into Duodenum, Open Approach */
"0DH932Z" = "1" /* Insertion of Monitoring Device into Duodenum, Percutaneous Approach */
"0DH933Z" = "1" /* Insertion of Infusion Device into Duodenum, Percutaneous Approach */
"0DH942Z" = "1" /* Insertion of Monitoring Device into Duodenum, Percutaneous Endoscopic Approach */
"0DH943Z" = "1" /* Insertion of Infusion Device into Duodenum, Percutaneous Endoscopic Approach */
"0DHA02Z" = "1" /* Insertion of Monitoring Device into Jejunum, Open Approach */
"0DHA03Z" = "1" /* Insertion of Infusion Device into Jejunum, Open Approach */
"0DHA32Z" = "1" /* Insertion of Monitoring Device into Jejunum, Percutaneous Approach */
"0DHA33Z" = "1" /* Insertion of Infusion Device into Jejunum, Percutaneous Approach */
"0DHA42Z" = "1" /* Insertion of Monitoring Device into Jejunum, Percutaneous Endoscopic Approach */
"0DHA43Z" = "1" /* Insertion of Infusion Device into Jejunum, Percutaneous Endoscopic Approach */
"0DHB02Z" = "1" /* Insertion of Monitoring Device into Ileum, Open Approach */
"0DHB03Z" = "1" /* Insertion of Infusion Device into Ileum, Open Approach */
"0DHB32Z" = "1" /* Insertion of Monitoring Device into Ileum, Percutaneous Approach */
"0DHB33Z" = "1" /* Insertion of Infusion Device into Ileum, Percutaneous Approach */
"0DHB42Z" = "1" /* Insertion of Monitoring Device into Ileum, Percutaneous Endoscopic Approach */
"0DHB43Z" = "1" /* Insertion of Infusion Device into Ileum, Percutaneous Endoscopic Approach */
"0DHP01Z" = "1" /* Insertion of Radioactive Element into Rectum, Open Approach */
"0DHP31Z" = "1" /* Insertion of Radioactive Element into Rectum, Percutaneous Approach */
"0DHP41Z" = "1" /* Insertion of Radioactive Element into Rectum, Percutaneous Endoscopic Approach */
"0DHP71Z" = "1" /* Insertion of Radioactive Element into Rectum, Via Natural or Artificial Opening */
"0DHP81Z" = "1" /* Insertion of Radioactive Element into Rectum, Via Natural or Artificial Opening Endoscopic */
"0DHQ0DZ" = "1" /* Insertion of Intraluminal Device into Anus, Open Approach */
"0DHQ0LZ" = "1" /* Insertion of Artificial Sphincter into Anus, Open Approach */
"0DHQ3DZ" = "1" /* Insertion of Intraluminal Device into Anus, Percutaneous Approach */
"0DHQ3LZ" = "1" /* Insertion of Artificial Sphincter into Anus, Percutaneous Approach */
"0DHQ4DZ" = "1" /* Insertion of Intraluminal Device into Anus, Percutaneous Endoscopic Approach */
"0DHQ4LZ" = "1" /* Insertion of Artificial Sphincter into Anus, Percutaneous Endoscopic Approach */
"0DHQ7DZ" = "1" /* Insertion of Intraluminal Device into Anus, Via Natural or Artificial Opening */
"0DHQ8DZ" = "1" /* Insertion of Intraluminal Device into Anus, Via Natural or Artificial Opening Endoscopic */
"0DHR0MZ" = "1" /* Insertion of Stimulator Lead into Anal Sphincter, Open Approach */
"0DHR3MZ" = "1" /* Insertion of Stimulator Lead into Anal Sphincter, Percutaneous Approach */
"0DHR4MZ" = "1" /* Insertion of Stimulator Lead into Anal Sphincter, Percutaneous Endoscopic Approach */
"0DJ00ZZ" = "1" /* Inspection of Upper Intestinal Tract, Open Approach */
"0DJ04ZZ" = "1" /* Inspection of Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DJ60ZZ" = "1" /* Inspection of Stomach, Open Approach */
"0DJ64ZZ" = "1" /* Inspection of Stomach, Percutaneous Endoscopic Approach */
"0DJD0ZZ" = "1" /* Inspection of Lower Intestinal Tract, Open Approach */
"0DJD4ZZ" = "1" /* Inspection of Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DJU0ZZ" = "1" /* Inspection of Omentum, Open Approach */
"0DJU4ZZ" = "1" /* Inspection of Omentum, Percutaneous Endoscopic Approach */
"0DJV0ZZ" = "1" /* Inspection of Mesentery, Open Approach */
"0DJV4ZZ" = "1" /* Inspection of Mesentery, Percutaneous Endoscopic Approach */
"0DJW0ZZ" = "1" /* Inspection of Peritoneum, Open Approach */
"0DJW4ZZ" = "1" /* Inspection of Peritoneum, Percutaneous Endoscopic Approach */
"0DL60CZ" = "1" /* Occlusion of Stomach with Extraluminal Device, Open Approach */
"0DL60DZ" = "1" /* Occlusion of Stomach with Intraluminal Device, Open Approach */
"0DL60ZZ" = "1" /* Occlusion of Stomach, Open Approach */
"0DL63CZ" = "1" /* Occlusion of Stomach with Extraluminal Device, Percutaneous Approach */
"0DL63DZ" = "1" /* Occlusion of Stomach with Intraluminal Device, Percutaneous Approach */
"0DL63ZZ" = "1" /* Occlusion of Stomach, Percutaneous Approach */
"0DL64CZ" = "1" /* Occlusion of Stomach with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DL64DZ" = "1" /* Occlusion of Stomach with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DL64ZZ" = "1" /* Occlusion of Stomach, Percutaneous Endoscopic Approach */
"0DL67DZ" = "1" /* Occlusion of Stomach with Intraluminal Device, Via Natural or Artificial Opening */
"0DL67ZZ" = "1" /* Occlusion of Stomach, Via Natural or Artificial Opening */
"0DL68DZ" = "1" /* Occlusion of Stomach with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DL68ZZ" = "1" /* Occlusion of Stomach, Via Natural or Artificial Opening Endoscopic */
"0DL70CZ" = "1" /* Occlusion of Stomach, Pylorus with Extraluminal Device, Open Approach */
"0DL70DZ" = "1" /* Occlusion of Stomach, Pylorus with Intraluminal Device, Open Approach */
"0DL70ZZ" = "1" /* Occlusion of Stomach, Pylorus, Open Approach */
"0DL73CZ" = "1" /* Occlusion of Stomach, Pylorus with Extraluminal Device, Percutaneous Approach */
"0DL73DZ" = "1" /* Occlusion of Stomach, Pylorus with Intraluminal Device, Percutaneous Approach */
"0DL73ZZ" = "1" /* Occlusion of Stomach, Pylorus, Percutaneous Approach */
"0DL74CZ" = "1" /* Occlusion of Stomach, Pylorus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DL74DZ" = "1" /* Occlusion of Stomach, Pylorus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DL74ZZ" = "1" /* Occlusion of Stomach, Pylorus, Percutaneous Endoscopic Approach */
"0DL77DZ" = "1" /* Occlusion of Stomach, Pylorus with Intraluminal Device, Via Natural or Artificial Opening */
"0DL77ZZ" = "1" /* Occlusion of Stomach, Pylorus, Via Natural or Artificial Opening */
"0DL78DZ" = "1" /* Occlusion of Stomach, Pylorus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DL78ZZ" = "1" /* Occlusion of Stomach, Pylorus, Via Natural or Artificial Opening Endoscopic */
"0DL80CZ" = "1" /* Occlusion of Small Intestine with Extraluminal Device, Open Approach */
"0DL80DZ" = "1" /* Occlusion of Small Intestine with Intraluminal Device, Open Approach */
"0DL80ZZ" = "1" /* Occlusion of Small Intestine, Open Approach */
"0DL83CZ" = "1" /* Occlusion of Small Intestine with Extraluminal Device, Percutaneous Approach */
"0DL83DZ" = "1" /* Occlusion of Small Intestine with Intraluminal Device, Percutaneous Approach */
"0DL83ZZ" = "1" /* Occlusion of Small Intestine, Percutaneous Approach */
"0DL84CZ" = "1" /* Occlusion of Small Intestine with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DL84DZ" = "1" /* Occlusion of Small Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DL84ZZ" = "1" /* Occlusion of Small Intestine, Percutaneous Endoscopic Approach */
"0DL87DZ" = "1" /* Occlusion of Small Intestine with Intraluminal Device, Via Natural or Artificial Opening */
"0DL87ZZ" = "1" /* Occlusion of Small Intestine, Via Natural or Artificial Opening */
"0DL88DZ" = "1" /* Occlusion of Small Intestine with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DL88ZZ" = "1" /* Occlusion of Small Intestine, Via Natural or Artificial Opening Endoscopic */
"0DL90CZ" = "1" /* Occlusion of Duodenum with Extraluminal Device, Open Approach */
"0DL90DZ" = "1" /* Occlusion of Duodenum with Intraluminal Device, Open Approach */
"0DL90ZZ" = "1" /* Occlusion of Duodenum, Open Approach */
"0DL93CZ" = "1" /* Occlusion of Duodenum with Extraluminal Device, Percutaneous Approach */
"0DL93DZ" = "1" /* Occlusion of Duodenum with Intraluminal Device, Percutaneous Approach */
"0DL93ZZ" = "1" /* Occlusion of Duodenum, Percutaneous Approach */
"0DL94CZ" = "1" /* Occlusion of Duodenum with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DL94DZ" = "1" /* Occlusion of Duodenum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DL94ZZ" = "1" /* Occlusion of Duodenum, Percutaneous Endoscopic Approach */
"0DL97DZ" = "1" /* Occlusion of Duodenum with Intraluminal Device, Via Natural or Artificial Opening */
"0DL97ZZ" = "1" /* Occlusion of Duodenum, Via Natural or Artificial Opening */
"0DL98DZ" = "1" /* Occlusion of Duodenum with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DL98ZZ" = "1" /* Occlusion of Duodenum, Via Natural or Artificial Opening Endoscopic */
"0DLA0CZ" = "1" /* Occlusion of Jejunum with Extraluminal Device, Open Approach */
"0DLA0DZ" = "1" /* Occlusion of Jejunum with Intraluminal Device, Open Approach */
"0DLA0ZZ" = "1" /* Occlusion of Jejunum, Open Approach */
"0DLA3CZ" = "1" /* Occlusion of Jejunum with Extraluminal Device, Percutaneous Approach */
"0DLA3DZ" = "1" /* Occlusion of Jejunum with Intraluminal Device, Percutaneous Approach */
"0DLA3ZZ" = "1" /* Occlusion of Jejunum, Percutaneous Approach */
"0DLA4CZ" = "1" /* Occlusion of Jejunum with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLA4DZ" = "1" /* Occlusion of Jejunum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLA4ZZ" = "1" /* Occlusion of Jejunum, Percutaneous Endoscopic Approach */
"0DLA7DZ" = "1" /* Occlusion of Jejunum with Intraluminal Device, Via Natural or Artificial Opening */
"0DLA7ZZ" = "1" /* Occlusion of Jejunum, Via Natural or Artificial Opening */
"0DLA8DZ" = "1" /* Occlusion of Jejunum with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DLA8ZZ" = "1" /* Occlusion of Jejunum, Via Natural or Artificial Opening Endoscopic */
"0DLB0CZ" = "1" /* Occlusion of Ileum with Extraluminal Device, Open Approach */
"0DLB0DZ" = "1" /* Occlusion of Ileum with Intraluminal Device, Open Approach */
"0DLB0ZZ" = "1" /* Occlusion of Ileum, Open Approach */
"0DLB3CZ" = "1" /* Occlusion of Ileum with Extraluminal Device, Percutaneous Approach */
"0DLB3DZ" = "1" /* Occlusion of Ileum with Intraluminal Device, Percutaneous Approach */
"0DLB3ZZ" = "1" /* Occlusion of Ileum, Percutaneous Approach */
"0DLB4CZ" = "1" /* Occlusion of Ileum with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLB4DZ" = "1" /* Occlusion of Ileum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLB4ZZ" = "1" /* Occlusion of Ileum, Percutaneous Endoscopic Approach */
"0DLB7DZ" = "1" /* Occlusion of Ileum with Intraluminal Device, Via Natural or Artificial Opening */
"0DLB7ZZ" = "1" /* Occlusion of Ileum, Via Natural or Artificial Opening */
"0DLB8DZ" = "1" /* Occlusion of Ileum with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DLB8ZZ" = "1" /* Occlusion of Ileum, Via Natural or Artificial Opening Endoscopic */
"0DLC0CZ" = "1" /* Occlusion of Ileocecal Valve with Extraluminal Device, Open Approach */
"0DLC0DZ" = "1" /* Occlusion of Ileocecal Valve with Intraluminal Device, Open Approach */
"0DLC0ZZ" = "1" /* Occlusion of Ileocecal Valve, Open Approach */
"0DLC3CZ" = "1" /* Occlusion of Ileocecal Valve with Extraluminal Device, Percutaneous Approach */
"0DLC3DZ" = "1" /* Occlusion of Ileocecal Valve with Intraluminal Device, Percutaneous Approach */
"0DLC3ZZ" = "1" /* Occlusion of Ileocecal Valve, Percutaneous Approach */
"0DLC4CZ" = "1" /* Occlusion of Ileocecal Valve with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLC4DZ" = "1" /* Occlusion of Ileocecal Valve with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLC4ZZ" = "1" /* Occlusion of Ileocecal Valve, Percutaneous Endoscopic Approach */
"0DLC7DZ" = "1" /* Occlusion of Ileocecal Valve with Intraluminal Device, Via Natural or Artificial Opening */
"0DLC7ZZ" = "1" /* Occlusion of Ileocecal Valve, Via Natural or Artificial Opening */
"0DLC8DZ" = "1" /* Occlusion of Ileocecal Valve with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DLC8ZZ" = "1" /* Occlusion of Ileocecal Valve, Via Natural or Artificial Opening Endoscopic */
"0DLE0CZ" = "1" /* Occlusion of Large Intestine with Extraluminal Device, Open Approach */
"0DLE0DZ" = "1" /* Occlusion of Large Intestine with Intraluminal Device, Open Approach */
"0DLE0ZZ" = "1" /* Occlusion of Large Intestine, Open Approach */
"0DLE3CZ" = "1" /* Occlusion of Large Intestine with Extraluminal Device, Percutaneous Approach */
"0DLE3DZ" = "1" /* Occlusion of Large Intestine with Intraluminal Device, Percutaneous Approach */
"0DLE3ZZ" = "1" /* Occlusion of Large Intestine, Percutaneous Approach */
"0DLE4CZ" = "1" /* Occlusion of Large Intestine with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLE4DZ" = "1" /* Occlusion of Large Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLE4ZZ" = "1" /* Occlusion of Large Intestine, Percutaneous Endoscopic Approach */
"0DLE7DZ" = "1" /* Occlusion of Large Intestine with Intraluminal Device, Via Natural or Artificial Opening */
"0DLE7ZZ" = "1" /* Occlusion of Large Intestine, Via Natural or Artificial Opening */
"0DLE8DZ" = "1" /* Occlusion of Large Intestine with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DLE8ZZ" = "1" /* Occlusion of Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0DLF0CZ" = "1" /* Occlusion of Right Large Intestine with Extraluminal Device, Open Approach */
"0DLF0DZ" = "1" /* Occlusion of Right Large Intestine with Intraluminal Device, Open Approach */
"0DLF0ZZ" = "1" /* Occlusion of Right Large Intestine, Open Approach */
"0DLF3CZ" = "1" /* Occlusion of Right Large Intestine with Extraluminal Device, Percutaneous Approach */
"0DLF3DZ" = "1" /* Occlusion of Right Large Intestine with Intraluminal Device, Percutaneous Approach */
"0DLF3ZZ" = "1" /* Occlusion of Right Large Intestine, Percutaneous Approach */
"0DLF4CZ" = "1" /* Occlusion of Right Large Intestine with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLF4DZ" = "1" /* Occlusion of Right Large Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLF4ZZ" = "1" /* Occlusion of Right Large Intestine, Percutaneous Endoscopic Approach */
"0DLF7DZ" = "1" /* Occlusion of Right Large Intestine with Intraluminal Device, Via Natural or Artificial Opening */
"0DLF7ZZ" = "1" /* Occlusion of Right Large Intestine, Via Natural or Artificial Opening */
"0DLF8DZ" = "1" /* Occlusion of Right Large Intestine with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DLF8ZZ" = "1" /* Occlusion of Right Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0DLG0CZ" = "1" /* Occlusion of Left Large Intestine with Extraluminal Device, Open Approach */
"0DLG0DZ" = "1" /* Occlusion of Left Large Intestine with Intraluminal Device, Open Approach */
"0DLG0ZZ" = "1" /* Occlusion of Left Large Intestine, Open Approach */
"0DLG3CZ" = "1" /* Occlusion of Left Large Intestine with Extraluminal Device, Percutaneous Approach */
"0DLG3DZ" = "1" /* Occlusion of Left Large Intestine with Intraluminal Device, Percutaneous Approach */
"0DLG3ZZ" = "1" /* Occlusion of Left Large Intestine, Percutaneous Approach */
"0DLG4CZ" = "1" /* Occlusion of Left Large Intestine with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLG4DZ" = "1" /* Occlusion of Left Large Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLG4ZZ" = "1" /* Occlusion of Left Large Intestine, Percutaneous Endoscopic Approach */
"0DLG7DZ" = "1" /* Occlusion of Left Large Intestine with Intraluminal Device, Via Natural or Artificial Opening */
"0DLG7ZZ" = "1" /* Occlusion of Left Large Intestine, Via Natural or Artificial Opening */
"0DLG8DZ" = "1" /* Occlusion of Left Large Intestine with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DLG8ZZ" = "1" /* Occlusion of Left Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0DLH0CZ" = "1" /* Occlusion of Cecum with Extraluminal Device, Open Approach */
"0DLH0DZ" = "1" /* Occlusion of Cecum with Intraluminal Device, Open Approach */
"0DLH0ZZ" = "1" /* Occlusion of Cecum, Open Approach */
"0DLH3CZ" = "1" /* Occlusion of Cecum with Extraluminal Device, Percutaneous Approach */
"0DLH3DZ" = "1" /* Occlusion of Cecum with Intraluminal Device, Percutaneous Approach */
"0DLH3ZZ" = "1" /* Occlusion of Cecum, Percutaneous Approach */
"0DLH4CZ" = "1" /* Occlusion of Cecum with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLH4DZ" = "1" /* Occlusion of Cecum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLH4ZZ" = "1" /* Occlusion of Cecum, Percutaneous Endoscopic Approach */
"0DLH7DZ" = "1" /* Occlusion of Cecum with Intraluminal Device, Via Natural or Artificial Opening */
"0DLH7ZZ" = "1" /* Occlusion of Cecum, Via Natural or Artificial Opening */
"0DLH8DZ" = "1" /* Occlusion of Cecum with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DLH8ZZ" = "1" /* Occlusion of Cecum, Via Natural or Artificial Opening Endoscopic */
"0DLK0CZ" = "1" /* Occlusion of Ascending Colon with Extraluminal Device, Open Approach */
"0DLK0DZ" = "1" /* Occlusion of Ascending Colon with Intraluminal Device, Open Approach */
"0DLK0ZZ" = "1" /* Occlusion of Ascending Colon, Open Approach */
"0DLK3CZ" = "1" /* Occlusion of Ascending Colon with Extraluminal Device, Percutaneous Approach */
"0DLK3DZ" = "1" /* Occlusion of Ascending Colon with Intraluminal Device, Percutaneous Approach */
"0DLK3ZZ" = "1" /* Occlusion of Ascending Colon, Percutaneous Approach */
"0DLK4CZ" = "1" /* Occlusion of Ascending Colon with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLK4DZ" = "1" /* Occlusion of Ascending Colon with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLK4ZZ" = "1" /* Occlusion of Ascending Colon, Percutaneous Endoscopic Approach */
"0DLK7DZ" = "1" /* Occlusion of Ascending Colon with Intraluminal Device, Via Natural or Artificial Opening */
"0DLK7ZZ" = "1" /* Occlusion of Ascending Colon, Via Natural or Artificial Opening */
"0DLK8DZ" = "1" /* Occlusion of Ascending Colon with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DLK8ZZ" = "1" /* Occlusion of Ascending Colon, Via Natural or Artificial Opening Endoscopic */
"0DLL0CZ" = "1" /* Occlusion of Transverse Colon with Extraluminal Device, Open Approach */
"0DLL0DZ" = "1" /* Occlusion of Transverse Colon with Intraluminal Device, Open Approach */
"0DLL0ZZ" = "1" /* Occlusion of Transverse Colon, Open Approach */
"0DLL3CZ" = "1" /* Occlusion of Transverse Colon with Extraluminal Device, Percutaneous Approach */
"0DLL3DZ" = "1" /* Occlusion of Transverse Colon with Intraluminal Device, Percutaneous Approach */
"0DLL3ZZ" = "1" /* Occlusion of Transverse Colon, Percutaneous Approach */
"0DLL4CZ" = "1" /* Occlusion of Transverse Colon with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLL4DZ" = "1" /* Occlusion of Transverse Colon with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLL4ZZ" = "1" /* Occlusion of Transverse Colon, Percutaneous Endoscopic Approach */
"0DLL7DZ" = "1" /* Occlusion of Transverse Colon with Intraluminal Device, Via Natural or Artificial Opening */
"0DLL7ZZ" = "1" /* Occlusion of Transverse Colon, Via Natural or Artificial Opening */
"0DLL8DZ" = "1" /* Occlusion of Transverse Colon with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DLL8ZZ" = "1" /* Occlusion of Transverse Colon, Via Natural or Artificial Opening Endoscopic */
"0DLM0CZ" = "1" /* Occlusion of Descending Colon with Extraluminal Device, Open Approach */
"0DLM0DZ" = "1" /* Occlusion of Descending Colon with Intraluminal Device, Open Approach */
"0DLM0ZZ" = "1" /* Occlusion of Descending Colon, Open Approach */
"0DLM3CZ" = "1" /* Occlusion of Descending Colon with Extraluminal Device, Percutaneous Approach */
"0DLM3DZ" = "1" /* Occlusion of Descending Colon with Intraluminal Device, Percutaneous Approach */
"0DLM3ZZ" = "1" /* Occlusion of Descending Colon, Percutaneous Approach */
"0DLM4CZ" = "1" /* Occlusion of Descending Colon with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLM4DZ" = "1" /* Occlusion of Descending Colon with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLM4ZZ" = "1" /* Occlusion of Descending Colon, Percutaneous Endoscopic Approach */
"0DLM7DZ" = "1" /* Occlusion of Descending Colon with Intraluminal Device, Via Natural or Artificial Opening */
"0DLM7ZZ" = "1" /* Occlusion of Descending Colon, Via Natural or Artificial Opening */
"0DLM8DZ" = "1" /* Occlusion of Descending Colon with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DLM8ZZ" = "1" /* Occlusion of Descending Colon, Via Natural or Artificial Opening Endoscopic */
"0DLN0CZ" = "1" /* Occlusion of Sigmoid Colon with Extraluminal Device, Open Approach */
"0DLN0DZ" = "1" /* Occlusion of Sigmoid Colon with Intraluminal Device, Open Approach */
"0DLN0ZZ" = "1" /* Occlusion of Sigmoid Colon, Open Approach */
"0DLN3CZ" = "1" /* Occlusion of Sigmoid Colon with Extraluminal Device, Percutaneous Approach */
"0DLN3DZ" = "1" /* Occlusion of Sigmoid Colon with Intraluminal Device, Percutaneous Approach */
"0DLN3ZZ" = "1" /* Occlusion of Sigmoid Colon, Percutaneous Approach */
"0DLN4CZ" = "1" /* Occlusion of Sigmoid Colon with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLN4DZ" = "1" /* Occlusion of Sigmoid Colon with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLN4ZZ" = "1" /* Occlusion of Sigmoid Colon, Percutaneous Endoscopic Approach */
"0DLN7DZ" = "1" /* Occlusion of Sigmoid Colon with Intraluminal Device, Via Natural or Artificial Opening */
"0DLN7ZZ" = "1" /* Occlusion of Sigmoid Colon, Via Natural or Artificial Opening */
"0DLN8DZ" = "1" /* Occlusion of Sigmoid Colon with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DLN8ZZ" = "1" /* Occlusion of Sigmoid Colon, Via Natural or Artificial Opening Endoscopic */
"0DLP0CZ" = "1" /* Occlusion of Rectum with Extraluminal Device, Open Approach */
"0DLP0DZ" = "1" /* Occlusion of Rectum with Intraluminal Device, Open Approach */
"0DLP0ZZ" = "1" /* Occlusion of Rectum, Open Approach */
"0DLP3CZ" = "1" /* Occlusion of Rectum with Extraluminal Device, Percutaneous Approach */
"0DLP3DZ" = "1" /* Occlusion of Rectum with Intraluminal Device, Percutaneous Approach */
"0DLP3ZZ" = "1" /* Occlusion of Rectum, Percutaneous Approach */
"0DLP4CZ" = "1" /* Occlusion of Rectum with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLP4DZ" = "1" /* Occlusion of Rectum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLP4ZZ" = "1" /* Occlusion of Rectum, Percutaneous Endoscopic Approach */
"0DLP7DZ" = "1" /* Occlusion of Rectum with Intraluminal Device, Via Natural or Artificial Opening */
"0DLP7ZZ" = "1" /* Occlusion of Rectum, Via Natural or Artificial Opening */
"0DLP8DZ" = "1" /* Occlusion of Rectum with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DLP8ZZ" = "1" /* Occlusion of Rectum, Via Natural or Artificial Opening Endoscopic */
"0DLQ0CZ" = "1" /* Occlusion of Anus with Extraluminal Device, Open Approach */
"0DLQ0DZ" = "1" /* Occlusion of Anus with Intraluminal Device, Open Approach */
"0DLQ0ZZ" = "1" /* Occlusion of Anus, Open Approach */
"0DLQ3CZ" = "1" /* Occlusion of Anus with Extraluminal Device, Percutaneous Approach */
"0DLQ3DZ" = "1" /* Occlusion of Anus with Intraluminal Device, Percutaneous Approach */
"0DLQ3ZZ" = "1" /* Occlusion of Anus, Percutaneous Approach */
"0DLQ4CZ" = "1" /* Occlusion of Anus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DLQ4DZ" = "1" /* Occlusion of Anus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DLQ4ZZ" = "1" /* Occlusion of Anus, Percutaneous Endoscopic Approach */
"0DLQ7DZ" = "1" /* Occlusion of Anus with Intraluminal Device, Via Natural or Artificial Opening */
"0DLQ7ZZ" = "1" /* Occlusion of Anus, Via Natural or Artificial Opening */
"0DLQ8DZ" = "1" /* Occlusion of Anus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DLQ8ZZ" = "1" /* Occlusion of Anus, Via Natural or Artificial Opening Endoscopic */
"0DLQXCZ" = "1" /* Occlusion of Anus with Extraluminal Device, External Approach */
"0DLQXDZ" = "1" /* Occlusion of Anus with Intraluminal Device, External Approach */
"0DLQXZZ" = "1" /* Occlusion of Anus, External Approach */
"0DM50ZZ" = "1" /* Reattachment of Esophagus, Open Approach */
"0DM54ZZ" = "1" /* Reattachment of Esophagus, Percutaneous Endoscopic Approach */
"0DM60ZZ" = "1" /* Reattachment of Stomach, Open Approach */
"0DM64ZZ" = "1" /* Reattachment of Stomach, Percutaneous Endoscopic Approach */
"0DM80ZZ" = "1" /* Reattachment of Small Intestine, Open Approach */
"0DM84ZZ" = "1" /* Reattachment of Small Intestine, Percutaneous Endoscopic Approach */
"0DM90ZZ" = "1" /* Reattachment of Duodenum, Open Approach */
"0DM94ZZ" = "1" /* Reattachment of Duodenum, Percutaneous Endoscopic Approach */
"0DMA0ZZ" = "1" /* Reattachment of Jejunum, Open Approach */
"0DMA4ZZ" = "1" /* Reattachment of Jejunum, Percutaneous Endoscopic Approach */
"0DMB0ZZ" = "1" /* Reattachment of Ileum, Open Approach */
"0DMB4ZZ" = "1" /* Reattachment of Ileum, Percutaneous Endoscopic Approach */
"0DME0ZZ" = "1" /* Reattachment of Large Intestine, Open Approach */
"0DME4ZZ" = "1" /* Reattachment of Large Intestine, Percutaneous Endoscopic Approach */
"0DMF0ZZ" = "1" /* Reattachment of Right Large Intestine, Open Approach */
"0DMF4ZZ" = "1" /* Reattachment of Right Large Intestine, Percutaneous Endoscopic Approach */
"0DMG0ZZ" = "1" /* Reattachment of Left Large Intestine, Open Approach */
"0DMG4ZZ" = "1" /* Reattachment of Left Large Intestine, Percutaneous Endoscopic Approach */
"0DMH0ZZ" = "1" /* Reattachment of Cecum, Open Approach */
"0DMH4ZZ" = "1" /* Reattachment of Cecum, Percutaneous Endoscopic Approach */
"0DMK0ZZ" = "1" /* Reattachment of Ascending Colon, Open Approach */
"0DMK4ZZ" = "1" /* Reattachment of Ascending Colon, Percutaneous Endoscopic Approach */
"0DML0ZZ" = "1" /* Reattachment of Transverse Colon, Open Approach */
"0DML4ZZ" = "1" /* Reattachment of Transverse Colon, Percutaneous Endoscopic Approach */
"0DMM0ZZ" = "1" /* Reattachment of Descending Colon, Open Approach */
"0DMM4ZZ" = "1" /* Reattachment of Descending Colon, Percutaneous Endoscopic Approach */
"0DMN0ZZ" = "1" /* Reattachment of Sigmoid Colon, Open Approach */
"0DMN4ZZ" = "1" /* Reattachment of Sigmoid Colon, Percutaneous Endoscopic Approach */
"0DMP0ZZ" = "1" /* Reattachment of Rectum, Open Approach */
"0DMP4ZZ" = "1" /* Reattachment of Rectum, Percutaneous Endoscopic Approach */
"0DN10ZZ" = "1" /* Release Upper Esophagus, Open Approach */
"0DN13ZZ" = "1" /* Release Upper Esophagus, Percutaneous Approach */
"0DN14ZZ" = "1" /* Release Upper Esophagus, Percutaneous Endoscopic Approach */
"0DN17ZZ" = "1" /* Release Upper Esophagus, Via Natural or Artificial Opening */
"0DN18ZZ" = "1" /* Release Upper Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DN20ZZ" = "1" /* Release Middle Esophagus, Open Approach */
"0DN23ZZ" = "1" /* Release Middle Esophagus, Percutaneous Approach */
"0DN24ZZ" = "1" /* Release Middle Esophagus, Percutaneous Endoscopic Approach */
"0DN27ZZ" = "1" /* Release Middle Esophagus, Via Natural or Artificial Opening */
"0DN28ZZ" = "1" /* Release Middle Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DN30ZZ" = "1" /* Release Lower Esophagus, Open Approach */
"0DN33ZZ" = "1" /* Release Lower Esophagus, Percutaneous Approach */
"0DN34ZZ" = "1" /* Release Lower Esophagus, Percutaneous Endoscopic Approach */
"0DN37ZZ" = "1" /* Release Lower Esophagus, Via Natural or Artificial Opening */
"0DN38ZZ" = "1" /* Release Lower Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DN40ZZ" = "1" /* Release Esophagogastric Junction, Open Approach */
"0DN43ZZ" = "1" /* Release Esophagogastric Junction, Percutaneous Approach */
"0DN44ZZ" = "1" /* Release Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0DN47ZZ" = "1" /* Release Esophagogastric Junction, Via Natural or Artificial Opening */
"0DN48ZZ" = "1" /* Release Esophagogastric Junction, Via Natural or Artificial Opening Endoscopic */
"0DN50ZZ" = "1" /* Release Esophagus, Open Approach */
"0DN53ZZ" = "1" /* Release Esophagus, Percutaneous Approach */
"0DN54ZZ" = "1" /* Release Esophagus, Percutaneous Endoscopic Approach */
"0DN57ZZ" = "1" /* Release Esophagus, Via Natural or Artificial Opening */
"0DN58ZZ" = "1" /* Release Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DN60ZZ" = "1" /* Release Stomach, Open Approach */
"0DN63ZZ" = "1" /* Release Stomach, Percutaneous Approach */
"0DN64ZZ" = "1" /* Release Stomach, Percutaneous Endoscopic Approach */
"0DN67ZZ" = "1" /* Release Stomach, Via Natural or Artificial Opening */
"0DN68ZZ" = "1" /* Release Stomach, Via Natural or Artificial Opening Endoscopic */
"0DN70ZZ" = "1" /* Release Stomach, Pylorus, Open Approach */
"0DN73ZZ" = "1" /* Release Stomach, Pylorus, Percutaneous Approach */
"0DN74ZZ" = "1" /* Release Stomach, Pylorus, Percutaneous Endoscopic Approach */
"0DN77ZZ" = "1" /* Release Stomach, Pylorus, Via Natural or Artificial Opening */
"0DN78ZZ" = "1" /* Release Stomach, Pylorus, Via Natural or Artificial Opening Endoscopic */
"0DN80ZZ" = "1" /* Release Small Intestine, Open Approach */
"0DN83ZZ" = "1" /* Release Small Intestine, Percutaneous Approach */
"0DN84ZZ" = "1" /* Release Small Intestine, Percutaneous Endoscopic Approach */
"0DN90ZZ" = "1" /* Release Duodenum, Open Approach */
"0DN93ZZ" = "1" /* Release Duodenum, Percutaneous Approach */
"0DN94ZZ" = "1" /* Release Duodenum, Percutaneous Endoscopic Approach */
"0DNA0ZZ" = "1" /* Release Jejunum, Open Approach */
"0DNA3ZZ" = "1" /* Release Jejunum, Percutaneous Approach */
"0DNA4ZZ" = "1" /* Release Jejunum, Percutaneous Endoscopic Approach */
"0DNB0ZZ" = "1" /* Release Ileum, Open Approach */
"0DNB3ZZ" = "1" /* Release Ileum, Percutaneous Approach */
"0DNB4ZZ" = "1" /* Release Ileum, Percutaneous Endoscopic Approach */
"0DNC0ZZ" = "1" /* Release Ileocecal Valve, Open Approach */
"0DNC3ZZ" = "1" /* Release Ileocecal Valve, Percutaneous Approach */
"0DNC4ZZ" = "1" /* Release Ileocecal Valve, Percutaneous Endoscopic Approach */
"0DNC7ZZ" = "1" /* Release Ileocecal Valve, Via Natural or Artificial Opening */
"0DNC8ZZ" = "1" /* Release Ileocecal Valve, Via Natural or Artificial Opening Endoscopic */
"0DNE0ZZ" = "1" /* Release Large Intestine, Open Approach */
"0DNE3ZZ" = "1" /* Release Large Intestine, Percutaneous Approach */
"0DNE4ZZ" = "1" /* Release Large Intestine, Percutaneous Endoscopic Approach */
"0DNF0ZZ" = "1" /* Release Right Large Intestine, Open Approach */
"0DNF3ZZ" = "1" /* Release Right Large Intestine, Percutaneous Approach */
"0DNF4ZZ" = "1" /* Release Right Large Intestine, Percutaneous Endoscopic Approach */
"0DNG0ZZ" = "1" /* Release Left Large Intestine, Open Approach */
"0DNG3ZZ" = "1" /* Release Left Large Intestine, Percutaneous Approach */
"0DNG4ZZ" = "1" /* Release Left Large Intestine, Percutaneous Endoscopic Approach */
"0DNH0ZZ" = "1" /* Release Cecum, Open Approach */
"0DNH3ZZ" = "1" /* Release Cecum, Percutaneous Approach */
"0DNH4ZZ" = "1" /* Release Cecum, Percutaneous Endoscopic Approach */
"0DNJ0ZZ" = "1" /* Release Appendix, Open Approach */
"0DNJ3ZZ" = "1" /* Release Appendix, Percutaneous Approach */
"0DNJ4ZZ" = "1" /* Release Appendix, Percutaneous Endoscopic Approach */
"0DNJ7ZZ" = "1" /* Release Appendix, Via Natural or Artificial Opening */
"0DNJ8ZZ" = "1" /* Release Appendix, Via Natural or Artificial Opening Endoscopic */
"0DNK0ZZ" = "1" /* Release Ascending Colon, Open Approach */
"0DNK3ZZ" = "1" /* Release Ascending Colon, Percutaneous Approach */
"0DNK4ZZ" = "1" /* Release Ascending Colon, Percutaneous Endoscopic Approach */
"0DNL0ZZ" = "1" /* Release Transverse Colon, Open Approach */
"0DNL3ZZ" = "1" /* Release Transverse Colon, Percutaneous Approach */
"0DNL4ZZ" = "1" /* Release Transverse Colon, Percutaneous Endoscopic Approach */
"0DNM0ZZ" = "1" /* Release Descending Colon, Open Approach */
"0DNM3ZZ" = "1" /* Release Descending Colon, Percutaneous Approach */
"0DNM4ZZ" = "1" /* Release Descending Colon, Percutaneous Endoscopic Approach */
"0DNN0ZZ" = "1" /* Release Sigmoid Colon, Open Approach */
"0DNN3ZZ" = "1" /* Release Sigmoid Colon, Percutaneous Approach */
"0DNN4ZZ" = "1" /* Release Sigmoid Colon, Percutaneous Endoscopic Approach */
"0DNP0ZZ" = "1" /* Release Rectum, Open Approach */
"0DNP3ZZ" = "1" /* Release Rectum, Percutaneous Approach */
"0DNP4ZZ" = "1" /* Release Rectum, Percutaneous Endoscopic Approach */
"0DNP7ZZ" = "1" /* Release Rectum, Via Natural or Artificial Opening */
"0DNP8ZZ" = "1" /* Release Rectum, Via Natural or Artificial Opening Endoscopic */
"0DNQ0ZZ" = "1" /* Release Anus, Open Approach */
"0DNQ3ZZ" = "1" /* Release Anus, Percutaneous Approach */
"0DNQ4ZZ" = "1" /* Release Anus, Percutaneous Endoscopic Approach */
"0DNQ7ZZ" = "1" /* Release Anus, Via Natural or Artificial Opening */
"0DNQ8ZZ" = "1" /* Release Anus, Via Natural or Artificial Opening Endoscopic */
"0DNQXZZ" = "1" /* Release Anus, External Approach */
"0DNR0ZZ" = "1" /* Release Anal Sphincter, Open Approach */
"0DNR3ZZ" = "1" /* Release Anal Sphincter, Percutaneous Approach */
"0DNR4ZZ" = "1" /* Release Anal Sphincter, Percutaneous Endoscopic Approach */
"0DNS0ZZ" = "1" /* Release Greater Omentum, Open Approach */
"0DNS3ZZ" = "1" /* Release Greater Omentum, Percutaneous Approach */
"0DNS4ZZ" = "1" /* Release Greater Omentum, Percutaneous Endoscopic Approach */
"0DNT0ZZ" = "1" /* Release Lesser Omentum, Open Approach */
"0DNT3ZZ" = "1" /* Release Lesser Omentum, Percutaneous Approach */
"0DNT4ZZ" = "1" /* Release Lesser Omentum, Percutaneous Endoscopic Approach */
"0DNV0ZZ" = "1" /* Release Mesentery, Open Approach */
"0DNV3ZZ" = "1" /* Release Mesentery, Percutaneous Approach */
"0DNV4ZZ" = "1" /* Release Mesentery, Percutaneous Endoscopic Approach */
"0DNW0ZZ" = "1" /* Release Peritoneum, Open Approach */
"0DNW3ZZ" = "1" /* Release Peritoneum, Percutaneous Approach */
"0DNW4ZZ" = "1" /* Release Peritoneum, Percutaneous Endoscopic Approach */
"0DP000Z" = "1" /* Removal of Drainage Device from Upper Intestinal Tract, Open Approach */
"0DP002Z" = "1" /* Removal of Monitoring Device from Upper Intestinal Tract, Open Approach */
"0DP003Z" = "1" /* Removal of Infusion Device from Upper Intestinal Tract, Open Approach */
"0DP007Z" = "1" /* Removal of Autologous Tissue Substitute from Upper Intestinal Tract, Open Approach */
"0DP00CZ" = "1" /* Removal of Extraluminal Device from Upper Intestinal Tract, Open Approach */
"0DP00DZ" = "1" /* Removal of Intraluminal Device from Upper Intestinal Tract, Open Approach */
"0DP00JZ" = "1" /* Removal of Synthetic Substitute from Upper Intestinal Tract, Open Approach */
"0DP00KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Upper Intestinal Tract, Open Approach */
"0DP00UZ" = "1" /* Removal of Feeding Device from Upper Intestinal Tract, Open Approach */
"0DP030Z" = "1" /* Removal of Drainage Device from Upper Intestinal Tract, Percutaneous Approach */
"0DP032Z" = "1" /* Removal of Monitoring Device from Upper Intestinal Tract, Percutaneous Approach */
"0DP033Z" = "1" /* Removal of Infusion Device from Upper Intestinal Tract, Percutaneous Approach */
"0DP037Z" = "1" /* Removal of Autologous Tissue Substitute from Upper Intestinal Tract, Percutaneous Approach */
"0DP03CZ" = "1" /* Removal of Extraluminal Device from Upper Intestinal Tract, Percutaneous Approach */
"0DP03DZ" = "1" /* Removal of Intraluminal Device from Upper Intestinal Tract, Percutaneous Approach */
"0DP03JZ" = "1" /* Removal of Synthetic Substitute from Upper Intestinal Tract, Percutaneous Approach */
"0DP03KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Upper Intestinal Tract, Percutaneous Approach */
"0DP03UZ" = "1" /* Removal of Feeding Device from Upper Intestinal Tract, Percutaneous Approach */
"0DP040Z" = "1" /* Removal of Drainage Device from Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DP042Z" = "1" /* Removal of Monitoring Device from Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DP043Z" = "1" /* Removal of Infusion Device from Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DP047Z" = "1" /* Removal of Autologous Tissue Substitute from Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DP04CZ" = "1" /* Removal of Extraluminal Device from Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DP04DZ" = "1" /* Removal of Intraluminal Device from Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DP04JZ" = "1" /* Removal of Synthetic Substitute from Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DP04KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DP04UZ" = "1" /* Removal of Feeding Device from Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DP077Z" = "1" /* Removal of Autologous Tissue Substitute from Upper Intestinal Tract, Via Natural or Artificial Opening */
"0DP07CZ" = "1" /* Removal of Extraluminal Device from Upper Intestinal Tract, Via Natural or Artificial Opening */
"0DP07JZ" = "1" /* Removal of Synthetic Substitute from Upper Intestinal Tract, Via Natural or Artificial Opening */
"0DP07KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Upper Intestinal Tract, Via Natural or Artificial Opening */
"0DP087Z" = "1" /* Removal of Autologous Tissue Substitute from Upper Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DP08CZ" = "1" /* Removal of Extraluminal Device from Upper Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DP08JZ" = "1" /* Removal of Synthetic Substitute from Upper Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DP08KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Upper Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DP501Z" = "1" /* Removal of Radioactive Element from Esophagus, Open Approach */
"0DP502Z" = "1" /* Removal of Monitoring Device from Esophagus, Open Approach */
"0DP503Z" = "1" /* Removal of Infusion Device from Esophagus, Open Approach */
"0DP50UZ" = "1" /* Removal of Feeding Device from Esophagus, Open Approach */
"0DP531Z" = "1" /* Removal of Radioactive Element from Esophagus, Percutaneous Approach */
"0DP532Z" = "1" /* Removal of Monitoring Device from Esophagus, Percutaneous Approach */
"0DP533Z" = "1" /* Removal of Infusion Device from Esophagus, Percutaneous Approach */
"0DP53UZ" = "1" /* Removal of Feeding Device from Esophagus, Percutaneous Approach */
"0DP541Z" = "1" /* Removal of Radioactive Element from Esophagus, Percutaneous Endoscopic Approach */
"0DP542Z" = "1" /* Removal of Monitoring Device from Esophagus, Percutaneous Endoscopic Approach */
"0DP543Z" = "1" /* Removal of Infusion Device from Esophagus, Percutaneous Endoscopic Approach */
"0DP54UZ" = "1" /* Removal of Feeding Device from Esophagus, Percutaneous Endoscopic Approach */
"0DP600Z" = "1" /* Removal of Drainage Device from Stomach, Open Approach */
"0DP602Z" = "1" /* Removal of Monitoring Device from Stomach, Open Approach */
"0DP603Z" = "1" /* Removal of Infusion Device from Stomach, Open Approach */
"0DP607Z" = "1" /* Removal of Autologous Tissue Substitute from Stomach, Open Approach */
"0DP60CZ" = "1" /* Removal of Extraluminal Device from Stomach, Open Approach */
"0DP60DZ" = "1" /* Removal of Intraluminal Device from Stomach, Open Approach */
"0DP60JZ" = "1" /* Removal of Synthetic Substitute from Stomach, Open Approach */
"0DP60KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Stomach, Open Approach */
"0DP60MZ" = "1" /* Removal of Stimulator Lead from Stomach, Open Approach */
"0DP60UZ" = "1" /* Removal of Feeding Device from Stomach, Open Approach */
"0DP630Z" = "1" /* Removal of Drainage Device from Stomach, Percutaneous Approach */
"0DP632Z" = "1" /* Removal of Monitoring Device from Stomach, Percutaneous Approach */
"0DP633Z" = "1" /* Removal of Infusion Device from Stomach, Percutaneous Approach */
"0DP637Z" = "1" /* Removal of Autologous Tissue Substitute from Stomach, Percutaneous Approach */
"0DP63CZ" = "1" /* Removal of Extraluminal Device from Stomach, Percutaneous Approach */
"0DP63DZ" = "1" /* Removal of Intraluminal Device from Stomach, Percutaneous Approach */
"0DP63JZ" = "1" /* Removal of Synthetic Substitute from Stomach, Percutaneous Approach */
"0DP63KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Stomach, Percutaneous Approach */
"0DP63MZ" = "1" /* Removal of Stimulator Lead from Stomach, Percutaneous Approach */
"0DP63UZ" = "1" /* Removal of Feeding Device from Stomach, Percutaneous Approach */
"0DP640Z" = "1" /* Removal of Drainage Device from Stomach, Percutaneous Endoscopic Approach */
"0DP642Z" = "1" /* Removal of Monitoring Device from Stomach, Percutaneous Endoscopic Approach */
"0DP643Z" = "1" /* Removal of Infusion Device from Stomach, Percutaneous Endoscopic Approach */
"0DP647Z" = "1" /* Removal of Autologous Tissue Substitute from Stomach, Percutaneous Endoscopic Approach */
"0DP64CZ" = "1" /* Removal of Extraluminal Device from Stomach, Percutaneous Endoscopic Approach */
"0DP64DZ" = "1" /* Removal of Intraluminal Device from Stomach, Percutaneous Endoscopic Approach */
"0DP64JZ" = "1" /* Removal of Synthetic Substitute from Stomach, Percutaneous Endoscopic Approach */
"0DP64KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Stomach, Percutaneous Endoscopic Approach */
"0DP64MZ" = "1" /* Removal of Stimulator Lead from Stomach, Percutaneous Endoscopic Approach */
"0DP64UZ" = "1" /* Removal of Feeding Device from Stomach, Percutaneous Endoscopic Approach */
"0DP677Z" = "1" /* Removal of Autologous Tissue Substitute from Stomach, Via Natural or Artificial Opening */
"0DP67CZ" = "1" /* Removal of Extraluminal Device from Stomach, Via Natural or Artificial Opening */
"0DP67JZ" = "1" /* Removal of Synthetic Substitute from Stomach, Via Natural or Artificial Opening */
"0DP67KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Stomach, Via Natural or Artificial Opening */
"0DP687Z" = "1" /* Removal of Autologous Tissue Substitute from Stomach, Via Natural or Artificial Opening Endoscopic */
"0DP68CZ" = "1" /* Removal of Extraluminal Device from Stomach, Via Natural or Artificial Opening Endoscopic */
"0DP68JZ" = "1" /* Removal of Synthetic Substitute from Stomach, Via Natural or Artificial Opening Endoscopic */
"0DP68KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Stomach, Via Natural or Artificial Opening Endoscopic */
"0DPD00Z" = "1" /* Removal of Drainage Device from Lower Intestinal Tract, Open Approach */
"0DPD02Z" = "1" /* Removal of Monitoring Device from Lower Intestinal Tract, Open Approach */
"0DPD03Z" = "1" /* Removal of Infusion Device from Lower Intestinal Tract, Open Approach */
"0DPD07Z" = "1" /* Removal of Autologous Tissue Substitute from Lower Intestinal Tract, Open Approach */
"0DPD0CZ" = "1" /* Removal of Extraluminal Device from Lower Intestinal Tract, Open Approach */
"0DPD0DZ" = "1" /* Removal of Intraluminal Device from Lower Intestinal Tract, Open Approach */
"0DPD0JZ" = "1" /* Removal of Synthetic Substitute from Lower Intestinal Tract, Open Approach */
"0DPD0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lower Intestinal Tract, Open Approach */
"0DPD0UZ" = "1" /* Removal of Feeding Device from Lower Intestinal Tract, Open Approach */
"0DPD30Z" = "1" /* Removal of Drainage Device from Lower Intestinal Tract, Percutaneous Approach */
"0DPD32Z" = "1" /* Removal of Monitoring Device from Lower Intestinal Tract, Percutaneous Approach */
"0DPD33Z" = "1" /* Removal of Infusion Device from Lower Intestinal Tract, Percutaneous Approach */
"0DPD37Z" = "1" /* Removal of Autologous Tissue Substitute from Lower Intestinal Tract, Percutaneous Approach */
"0DPD3CZ" = "1" /* Removal of Extraluminal Device from Lower Intestinal Tract, Percutaneous Approach */
"0DPD3DZ" = "1" /* Removal of Intraluminal Device from Lower Intestinal Tract, Percutaneous Approach */
"0DPD3JZ" = "1" /* Removal of Synthetic Substitute from Lower Intestinal Tract, Percutaneous Approach */
"0DPD3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lower Intestinal Tract, Percutaneous Approach */
"0DPD3UZ" = "1" /* Removal of Feeding Device from Lower Intestinal Tract, Percutaneous Approach */
"0DPD40Z" = "1" /* Removal of Drainage Device from Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DPD42Z" = "1" /* Removal of Monitoring Device from Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DPD43Z" = "1" /* Removal of Infusion Device from Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DPD47Z" = "1" /* Removal of Autologous Tissue Substitute from Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DPD4CZ" = "1" /* Removal of Extraluminal Device from Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DPD4DZ" = "1" /* Removal of Intraluminal Device from Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DPD4JZ" = "1" /* Removal of Synthetic Substitute from Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DPD4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DPD4UZ" = "1" /* Removal of Feeding Device from Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DPD77Z" = "1" /* Removal of Autologous Tissue Substitute from Lower Intestinal Tract, Via Natural or Artificial Opening */
"0DPD7CZ" = "1" /* Removal of Extraluminal Device from Lower Intestinal Tract, Via Natural or Artificial Opening */
"0DPD7JZ" = "1" /* Removal of Synthetic Substitute from Lower Intestinal Tract, Via Natural or Artificial Opening */
"0DPD7KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lower Intestinal Tract, Via Natural or Artificial Opening */
"0DPD87Z" = "1" /* Removal of Autologous Tissue Substitute from Lower Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DPD8CZ" = "1" /* Removal of Extraluminal Device from Lower Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DPD8JZ" = "1" /* Removal of Synthetic Substitute from Lower Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DPD8KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lower Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DPP01Z" = "1" /* Removal of Radioactive Element from Rectum, Open Approach */
"0DPP31Z" = "1" /* Removal of Radioactive Element from Rectum, Percutaneous Approach */
"0DPP41Z" = "1" /* Removal of Radioactive Element from Rectum, Percutaneous Endoscopic Approach */
"0DPQ0LZ" = "1" /* Removal of Artificial Sphincter from Anus, Open Approach */
"0DPQ3LZ" = "1" /* Removal of Artificial Sphincter from Anus, Percutaneous Approach */
"0DPQ4LZ" = "1" /* Removal of Artificial Sphincter from Anus, Percutaneous Endoscopic Approach */
"0DPQ7LZ" = "1" /* Removal of Artificial Sphincter from Anus, Via Natural or Artificial Opening */
"0DPQ8LZ" = "1" /* Removal of Artificial Sphincter from Anus, Via Natural or Artificial Opening Endoscopic */
"0DPR0MZ" = "1" /* Removal of Stimulator Lead from Anal Sphincter, Open Approach */
"0DPR3MZ" = "1" /* Removal of Stimulator Lead from Anal Sphincter, Percutaneous Approach */
"0DPR4MZ" = "1" /* Removal of Stimulator Lead from Anal Sphincter, Percutaneous Endoscopic Approach */
"0DPU00Z" = "1" /* Removal of Drainage Device from Omentum, Open Approach */
"0DPU01Z" = "1" /* Removal of Radioactive Element from Omentum, Open Approach */
"0DPU07Z" = "1" /* Removal of Autologous Tissue Substitute from Omentum, Open Approach */
"0DPU0JZ" = "1" /* Removal of Synthetic Substitute from Omentum, Open Approach */
"0DPU0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Omentum, Open Approach */
"0DPU30Z" = "1" /* Removal of Drainage Device from Omentum, Percutaneous Approach */
"0DPU31Z" = "1" /* Removal of Radioactive Element from Omentum, Percutaneous Approach */
"0DPU37Z" = "1" /* Removal of Autologous Tissue Substitute from Omentum, Percutaneous Approach */
"0DPU3JZ" = "1" /* Removal of Synthetic Substitute from Omentum, Percutaneous Approach */
"0DPU3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Omentum, Percutaneous Approach */
"0DPU40Z" = "1" /* Removal of Drainage Device from Omentum, Percutaneous Endoscopic Approach */
"0DPU41Z" = "1" /* Removal of Radioactive Element from Omentum, Percutaneous Endoscopic Approach */
"0DPU47Z" = "1" /* Removal of Autologous Tissue Substitute from Omentum, Percutaneous Endoscopic Approach */
"0DPU4JZ" = "1" /* Removal of Synthetic Substitute from Omentum, Percutaneous Endoscopic Approach */
"0DPU4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Omentum, Percutaneous Endoscopic Approach */
"0DPV00Z" = "1" /* Removal of Drainage Device from Mesentery, Open Approach */
"0DPV01Z" = "1" /* Removal of Radioactive Element from Mesentery, Open Approach */
"0DPV07Z" = "1" /* Removal of Autologous Tissue Substitute from Mesentery, Open Approach */
"0DPV0JZ" = "1" /* Removal of Synthetic Substitute from Mesentery, Open Approach */
"0DPV0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Mesentery, Open Approach */
"0DPV30Z" = "1" /* Removal of Drainage Device from Mesentery, Percutaneous Approach */
"0DPV31Z" = "1" /* Removal of Radioactive Element from Mesentery, Percutaneous Approach */
"0DPV37Z" = "1" /* Removal of Autologous Tissue Substitute from Mesentery, Percutaneous Approach */
"0DPV3JZ" = "1" /* Removal of Synthetic Substitute from Mesentery, Percutaneous Approach */
"0DPV3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Mesentery, Percutaneous Approach */
"0DPV40Z" = "1" /* Removal of Drainage Device from Mesentery, Percutaneous Endoscopic Approach */
"0DPV41Z" = "1" /* Removal of Radioactive Element from Mesentery, Percutaneous Endoscopic Approach */
"0DPV47Z" = "1" /* Removal of Autologous Tissue Substitute from Mesentery, Percutaneous Endoscopic Approach */
"0DPV4JZ" = "1" /* Removal of Synthetic Substitute from Mesentery, Percutaneous Endoscopic Approach */
"0DPV4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Mesentery, Percutaneous Endoscopic Approach */
"0DPW00Z" = "1" /* Removal of Drainage Device from Peritoneum, Open Approach */
"0DPW01Z" = "1" /* Removal of Radioactive Element from Peritoneum, Open Approach */
"0DPW07Z" = "1" /* Removal of Autologous Tissue Substitute from Peritoneum, Open Approach */
"0DPW0JZ" = "1" /* Removal of Synthetic Substitute from Peritoneum, Open Approach */
"0DPW0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Peritoneum, Open Approach */
"0DPW30Z" = "1" /* Removal of Drainage Device from Peritoneum, Percutaneous Approach */
"0DPW31Z" = "1" /* Removal of Radioactive Element from Peritoneum, Percutaneous Approach */
"0DPW37Z" = "1" /* Removal of Autologous Tissue Substitute from Peritoneum, Percutaneous Approach */
"0DPW3JZ" = "1" /* Removal of Synthetic Substitute from Peritoneum, Percutaneous Approach */
"0DPW3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Peritoneum, Percutaneous Approach */
"0DPW40Z" = "1" /* Removal of Drainage Device from Peritoneum, Percutaneous Endoscopic Approach */
"0DPW41Z" = "1" /* Removal of Radioactive Element from Peritoneum, Percutaneous Endoscopic Approach */
"0DPW47Z" = "1" /* Removal of Autologous Tissue Substitute from Peritoneum, Percutaneous Endoscopic Approach */
"0DPW4JZ" = "1" /* Removal of Synthetic Substitute from Peritoneum, Percutaneous Endoscopic Approach */
"0DPW4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Peritoneum, Percutaneous Endoscopic Approach */
"0DQ10ZZ" = "1" /* Repair Upper Esophagus, Open Approach */
"0DQ13ZZ" = "1" /* Repair Upper Esophagus, Percutaneous Approach */
"0DQ14ZZ" = "1" /* Repair Upper Esophagus, Percutaneous Endoscopic Approach */
"0DQ17ZZ" = "1" /* Repair Upper Esophagus, Via Natural or Artificial Opening */
"0DQ18ZZ" = "1" /* Repair Upper Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DQ20ZZ" = "1" /* Repair Middle Esophagus, Open Approach */
"0DQ23ZZ" = "1" /* Repair Middle Esophagus, Percutaneous Approach */
"0DQ24ZZ" = "1" /* Repair Middle Esophagus, Percutaneous Endoscopic Approach */
"0DQ27ZZ" = "1" /* Repair Middle Esophagus, Via Natural or Artificial Opening */
"0DQ28ZZ" = "1" /* Repair Middle Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DQ30ZZ" = "1" /* Repair Lower Esophagus, Open Approach */
"0DQ33ZZ" = "1" /* Repair Lower Esophagus, Percutaneous Approach */
"0DQ34ZZ" = "1" /* Repair Lower Esophagus, Percutaneous Endoscopic Approach */
"0DQ37ZZ" = "1" /* Repair Lower Esophagus, Via Natural or Artificial Opening */
"0DQ38ZZ" = "1" /* Repair Lower Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DQ40ZZ" = "1" /* Repair Esophagogastric Junction, Open Approach */
"0DQ43ZZ" = "1" /* Repair Esophagogastric Junction, Percutaneous Approach */
"0DQ44ZZ" = "1" /* Repair Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0DQ47ZZ" = "1" /* Repair Esophagogastric Junction, Via Natural or Artificial Opening */
"0DQ48ZZ" = "1" /* Repair Esophagogastric Junction, Via Natural or Artificial Opening Endoscopic */
"0DQ50ZZ" = "1" /* Repair Esophagus, Open Approach */
"0DQ53ZZ" = "1" /* Repair Esophagus, Percutaneous Approach */
"0DQ54ZZ" = "1" /* Repair Esophagus, Percutaneous Endoscopic Approach */
"0DQ57ZZ" = "1" /* Repair Esophagus, Via Natural or Artificial Opening */
"0DQ58ZZ" = "1" /* Repair Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DQ60ZZ" = "1" /* Repair Stomach, Open Approach */
"0DQ63ZZ" = "1" /* Repair Stomach, Percutaneous Approach */
"0DQ64ZZ" = "1" /* Repair Stomach, Percutaneous Endoscopic Approach */
"0DQ67ZZ" = "1" /* Repair Stomach, Via Natural or Artificial Opening */
"0DQ68ZZ" = "1" /* Repair Stomach, Via Natural or Artificial Opening Endoscopic */
"0DQ70ZZ" = "1" /* Repair Stomach, Pylorus, Open Approach */
"0DQ73ZZ" = "1" /* Repair Stomach, Pylorus, Percutaneous Approach */
"0DQ74ZZ" = "1" /* Repair Stomach, Pylorus, Percutaneous Endoscopic Approach */
"0DQ77ZZ" = "1" /* Repair Stomach, Pylorus, Via Natural or Artificial Opening */
"0DQ78ZZ" = "1" /* Repair Stomach, Pylorus, Via Natural or Artificial Opening Endoscopic */
"0DQ80ZZ" = "1" /* Repair Small Intestine, Open Approach */
"0DQ83ZZ" = "1" /* Repair Small Intestine, Percutaneous Approach */
"0DQ84ZZ" = "1" /* Repair Small Intestine, Percutaneous Endoscopic Approach */
"0DQ87ZZ" = "1" /* Repair Small Intestine, Via Natural or Artificial Opening */
"0DQ88ZZ" = "1" /* Repair Small Intestine, Via Natural or Artificial Opening Endoscopic */
"0DQ90ZZ" = "1" /* Repair Duodenum, Open Approach */
"0DQ93ZZ" = "1" /* Repair Duodenum, Percutaneous Approach */
"0DQ94ZZ" = "1" /* Repair Duodenum, Percutaneous Endoscopic Approach */
"0DQ97ZZ" = "1" /* Repair Duodenum, Via Natural or Artificial Opening */
"0DQ98ZZ" = "1" /* Repair Duodenum, Via Natural or Artificial Opening Endoscopic */
"0DQA0ZZ" = "1" /* Repair Jejunum, Open Approach */
"0DQA3ZZ" = "1" /* Repair Jejunum, Percutaneous Approach */
"0DQA4ZZ" = "1" /* Repair Jejunum, Percutaneous Endoscopic Approach */
"0DQA7ZZ" = "1" /* Repair Jejunum, Via Natural or Artificial Opening */
"0DQA8ZZ" = "1" /* Repair Jejunum, Via Natural or Artificial Opening Endoscopic */
"0DQB0ZZ" = "1" /* Repair Ileum, Open Approach */
"0DQB3ZZ" = "1" /* Repair Ileum, Percutaneous Approach */
"0DQB4ZZ" = "1" /* Repair Ileum, Percutaneous Endoscopic Approach */
"0DQB7ZZ" = "1" /* Repair Ileum, Via Natural or Artificial Opening */
"0DQB8ZZ" = "1" /* Repair Ileum, Via Natural or Artificial Opening Endoscopic */
"0DQC0ZZ" = "1" /* Repair Ileocecal Valve, Open Approach */
"0DQC3ZZ" = "1" /* Repair Ileocecal Valve, Percutaneous Approach */
"0DQC4ZZ" = "1" /* Repair Ileocecal Valve, Percutaneous Endoscopic Approach */
"0DQC7ZZ" = "1" /* Repair Ileocecal Valve, Via Natural or Artificial Opening */
"0DQC8ZZ" = "1" /* Repair Ileocecal Valve, Via Natural or Artificial Opening Endoscopic */
"0DQE0ZZ" = "1" /* Repair Large Intestine, Open Approach */
"0DQE3ZZ" = "1" /* Repair Large Intestine, Percutaneous Approach */
"0DQE4ZZ" = "1" /* Repair Large Intestine, Percutaneous Endoscopic Approach */
"0DQE7ZZ" = "1" /* Repair Large Intestine, Via Natural or Artificial Opening */
"0DQE8ZZ" = "1" /* Repair Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0DQF0ZZ" = "1" /* Repair Right Large Intestine, Open Approach */
"0DQF3ZZ" = "1" /* Repair Right Large Intestine, Percutaneous Approach */
"0DQF4ZZ" = "1" /* Repair Right Large Intestine, Percutaneous Endoscopic Approach */
"0DQF7ZZ" = "1" /* Repair Right Large Intestine, Via Natural or Artificial Opening */
"0DQF8ZZ" = "1" /* Repair Right Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0DQG0ZZ" = "1" /* Repair Left Large Intestine, Open Approach */
"0DQG3ZZ" = "1" /* Repair Left Large Intestine, Percutaneous Approach */
"0DQG4ZZ" = "1" /* Repair Left Large Intestine, Percutaneous Endoscopic Approach */
"0DQG7ZZ" = "1" /* Repair Left Large Intestine, Via Natural or Artificial Opening */
"0DQG8ZZ" = "1" /* Repair Left Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0DQH0ZZ" = "1" /* Repair Cecum, Open Approach */
"0DQH3ZZ" = "1" /* Repair Cecum, Percutaneous Approach */
"0DQH4ZZ" = "1" /* Repair Cecum, Percutaneous Endoscopic Approach */
"0DQH7ZZ" = "1" /* Repair Cecum, Via Natural or Artificial Opening */
"0DQH8ZZ" = "1" /* Repair Cecum, Via Natural or Artificial Opening Endoscopic */
"0DQJ0ZZ" = "1" /* Repair Appendix, Open Approach */
"0DQJ3ZZ" = "1" /* Repair Appendix, Percutaneous Approach */
"0DQJ4ZZ" = "1" /* Repair Appendix, Percutaneous Endoscopic Approach */
"0DQJ7ZZ" = "1" /* Repair Appendix, Via Natural or Artificial Opening */
"0DQJ8ZZ" = "1" /* Repair Appendix, Via Natural or Artificial Opening Endoscopic */
"0DQK0ZZ" = "1" /* Repair Ascending Colon, Open Approach */
"0DQK3ZZ" = "1" /* Repair Ascending Colon, Percutaneous Approach */
"0DQK4ZZ" = "1" /* Repair Ascending Colon, Percutaneous Endoscopic Approach */
"0DQK7ZZ" = "1" /* Repair Ascending Colon, Via Natural or Artificial Opening */
"0DQK8ZZ" = "1" /* Repair Ascending Colon, Via Natural or Artificial Opening Endoscopic */
"0DQL0ZZ" = "1" /* Repair Transverse Colon, Open Approach */
"0DQL3ZZ" = "1" /* Repair Transverse Colon, Percutaneous Approach */
"0DQL4ZZ" = "1" /* Repair Transverse Colon, Percutaneous Endoscopic Approach */
"0DQL7ZZ" = "1" /* Repair Transverse Colon, Via Natural or Artificial Opening */
"0DQL8ZZ" = "1" /* Repair Transverse Colon, Via Natural or Artificial Opening Endoscopic */
"0DQM0ZZ" = "1" /* Repair Descending Colon, Open Approach */
"0DQM3ZZ" = "1" /* Repair Descending Colon, Percutaneous Approach */
"0DQM4ZZ" = "1" /* Repair Descending Colon, Percutaneous Endoscopic Approach */
"0DQM7ZZ" = "1" /* Repair Descending Colon, Via Natural or Artificial Opening */
"0DQM8ZZ" = "1" /* Repair Descending Colon, Via Natural or Artificial Opening Endoscopic */
"0DQN0ZZ" = "1" /* Repair Sigmoid Colon, Open Approach */
"0DQN3ZZ" = "1" /* Repair Sigmoid Colon, Percutaneous Approach */
"0DQN4ZZ" = "1" /* Repair Sigmoid Colon, Percutaneous Endoscopic Approach */
"0DQN7ZZ" = "1" /* Repair Sigmoid Colon, Via Natural or Artificial Opening */
"0DQN8ZZ" = "1" /* Repair Sigmoid Colon, Via Natural or Artificial Opening Endoscopic */
"0DQP0ZZ" = "1" /* Repair Rectum, Open Approach */
"0DQP3ZZ" = "1" /* Repair Rectum, Percutaneous Approach */
"0DQP4ZZ" = "1" /* Repair Rectum, Percutaneous Endoscopic Approach */
"0DQP7ZZ" = "1" /* Repair Rectum, Via Natural or Artificial Opening */
"0DQP8ZZ" = "1" /* Repair Rectum, Via Natural or Artificial Opening Endoscopic */
"0DQQ0ZZ" = "1" /* Repair Anus, Open Approach */
"0DQQ3ZZ" = "1" /* Repair Anus, Percutaneous Approach */
"0DQQ4ZZ" = "1" /* Repair Anus, Percutaneous Endoscopic Approach */
"0DQQ7ZZ" = "1" /* Repair Anus, Via Natural or Artificial Opening */
"0DQQ8ZZ" = "1" /* Repair Anus, Via Natural or Artificial Opening Endoscopic */
"0DQQXZZ" = "1" /* Repair Anus, External Approach */
"0DQR0ZZ" = "1" /* Repair Anal Sphincter, Open Approach */
"0DQR3ZZ" = "1" /* Repair Anal Sphincter, Percutaneous Approach */
"0DQR4ZZ" = "1" /* Repair Anal Sphincter, Percutaneous Endoscopic Approach */
"0DQS0ZZ" = "1" /* Repair Greater Omentum, Open Approach */
"0DQS3ZZ" = "1" /* Repair Greater Omentum, Percutaneous Approach */
"0DQS4ZZ" = "1" /* Repair Greater Omentum, Percutaneous Endoscopic Approach */
"0DQT0ZZ" = "1" /* Repair Lesser Omentum, Open Approach */
"0DQT3ZZ" = "1" /* Repair Lesser Omentum, Percutaneous Approach */
"0DQT4ZZ" = "1" /* Repair Lesser Omentum, Percutaneous Endoscopic Approach */
"0DQV0ZZ" = "1" /* Repair Mesentery, Open Approach */
"0DQV3ZZ" = "1" /* Repair Mesentery, Percutaneous Approach */
"0DQV4ZZ" = "1" /* Repair Mesentery, Percutaneous Endoscopic Approach */
"0DQW0ZZ" = "1" /* Repair Peritoneum, Open Approach */
"0DQW3ZZ" = "1" /* Repair Peritoneum, Percutaneous Approach */
"0DQW4ZZ" = "1" /* Repair Peritoneum, Percutaneous Endoscopic Approach */
"0DR507Z" = "1" /* Replacement of Esophagus with Autologous Tissue Substitute, Open Approach */
"0DR50JZ" = "1" /* Replacement of Esophagus with Synthetic Substitute, Open Approach */
"0DR50KZ" = "1" /* Replacement of Esophagus with Nonautologous Tissue Substitute, Open Approach */
"0DR547Z" = "1" /* Replacement of Esophagus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DR54JZ" = "1" /* Replacement of Esophagus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DR54KZ" = "1" /* Replacement of Esophagus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DR577Z" = "1" /* Replacement of Esophagus with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DR57JZ" = "1" /* Replacement of Esophagus with Synthetic Substitute, Via Natural or Artificial Opening */
"0DR57KZ" = "1" /* Replacement of Esophagus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DR587Z" = "1" /* Replacement of Esophagus with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DR58JZ" = "1" /* Replacement of Esophagus with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DR58KZ" = "1" /* Replacement of Esophagus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DRR07Z" = "1" /* Replacement of Anal Sphincter with Autologous Tissue Substitute, Open Approach */
"0DRR0JZ" = "1" /* Replacement of Anal Sphincter with Synthetic Substitute, Open Approach */
"0DRR0KZ" = "1" /* Replacement of Anal Sphincter with Nonautologous Tissue Substitute, Open Approach */
"0DRR47Z" = "1" /* Replacement of Anal Sphincter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DRR4JZ" = "1" /* Replacement of Anal Sphincter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DRR4KZ" = "1" /* Replacement of Anal Sphincter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DRS07Z" = "1" /* Replacement of Greater Omentum with Autologous Tissue Substitute, Open Approach */
"0DRS0JZ" = "1" /* Replacement of Greater Omentum with Synthetic Substitute, Open Approach */
"0DRS0KZ" = "1" /* Replacement of Greater Omentum with Nonautologous Tissue Substitute, Open Approach */
"0DRS47Z" = "1" /* Replacement of Greater Omentum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DRS4JZ" = "1" /* Replacement of Greater Omentum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DRS4KZ" = "1" /* Replacement of Greater Omentum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DRT07Z" = "1" /* Replacement of Lesser Omentum with Autologous Tissue Substitute, Open Approach */
"0DRT0JZ" = "1" /* Replacement of Lesser Omentum with Synthetic Substitute, Open Approach */
"0DRT0KZ" = "1" /* Replacement of Lesser Omentum with Nonautologous Tissue Substitute, Open Approach */
"0DRT47Z" = "1" /* Replacement of Lesser Omentum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DRT4JZ" = "1" /* Replacement of Lesser Omentum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DRT4KZ" = "1" /* Replacement of Lesser Omentum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DRV07Z" = "1" /* Replacement of Mesentery with Autologous Tissue Substitute, Open Approach */
"0DRV0JZ" = "1" /* Replacement of Mesentery with Synthetic Substitute, Open Approach */
"0DRV0KZ" = "1" /* Replacement of Mesentery with Nonautologous Tissue Substitute, Open Approach */
"0DRV47Z" = "1" /* Replacement of Mesentery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DRV4JZ" = "1" /* Replacement of Mesentery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DRV4KZ" = "1" /* Replacement of Mesentery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DRW07Z" = "1" /* Replacement of Peritoneum with Autologous Tissue Substitute, Open Approach */
"0DRW0JZ" = "1" /* Replacement of Peritoneum with Synthetic Substitute, Open Approach */
"0DRW0KZ" = "1" /* Replacement of Peritoneum with Nonautologous Tissue Substitute, Open Approach */
"0DRW47Z" = "1" /* Replacement of Peritoneum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DRW4JZ" = "1" /* Replacement of Peritoneum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DRW4KZ" = "1" /* Replacement of Peritoneum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DS50ZZ" = "1" /* Reposition Esophagus, Open Approach */
"0DS54ZZ" = "1" /* Reposition Esophagus, Percutaneous Endoscopic Approach */
"0DS57ZZ" = "1" /* Reposition Esophagus, Via Natural or Artificial Opening */
"0DS58ZZ" = "1" /* Reposition Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DS60ZZ" = "1" /* Reposition Stomach, Open Approach */
"0DS64ZZ" = "1" /* Reposition Stomach, Percutaneous Endoscopic Approach */
"0DS67ZZ" = "1" /* Reposition Stomach, Via Natural or Artificial Opening */
"0DS68ZZ" = "1" /* Reposition Stomach, Via Natural or Artificial Opening Endoscopic */
"0DS90ZZ" = "1" /* Reposition Duodenum, Open Approach */
"0DS94ZZ" = "1" /* Reposition Duodenum, Percutaneous Endoscopic Approach */
"0DS97ZZ" = "1" /* Reposition Duodenum, Via Natural or Artificial Opening */
"0DS98ZZ" = "1" /* Reposition Duodenum, Via Natural or Artificial Opening Endoscopic */
"0DSA0ZZ" = "1" /* Reposition Jejunum, Open Approach */
"0DSA4ZZ" = "1" /* Reposition Jejunum, Percutaneous Endoscopic Approach */
"0DSA7ZZ" = "1" /* Reposition Jejunum, Via Natural or Artificial Opening */
"0DSA8ZZ" = "1" /* Reposition Jejunum, Via Natural or Artificial Opening Endoscopic */
"0DSB0ZZ" = "1" /* Reposition Ileum, Open Approach */
"0DSB4ZZ" = "1" /* Reposition Ileum, Percutaneous Endoscopic Approach */
"0DSB7ZZ" = "1" /* Reposition Ileum, Via Natural or Artificial Opening */
"0DSB8ZZ" = "1" /* Reposition Ileum, Via Natural or Artificial Opening Endoscopic */
"0DSH0ZZ" = "1" /* Reposition Cecum, Open Approach */
"0DSH4ZZ" = "1" /* Reposition Cecum, Percutaneous Endoscopic Approach */
"0DSH7ZZ" = "1" /* Reposition Cecum, Via Natural or Artificial Opening */
"0DSH8ZZ" = "1" /* Reposition Cecum, Via Natural or Artificial Opening Endoscopic */
"0DSK0ZZ" = "1" /* Reposition Ascending Colon, Open Approach */
"0DSK4ZZ" = "1" /* Reposition Ascending Colon, Percutaneous Endoscopic Approach */
"0DSK7ZZ" = "1" /* Reposition Ascending Colon, Via Natural or Artificial Opening */
"0DSK8ZZ" = "1" /* Reposition Ascending Colon, Via Natural or Artificial Opening Endoscopic */
"0DSL0ZZ" = "1" /* Reposition Transverse Colon, Open Approach */
"0DSL4ZZ" = "1" /* Reposition Transverse Colon, Percutaneous Endoscopic Approach */
"0DSL7ZZ" = "1" /* Reposition Transverse Colon, Via Natural or Artificial Opening */
"0DSL8ZZ" = "1" /* Reposition Transverse Colon, Via Natural or Artificial Opening Endoscopic */
"0DSM0ZZ" = "1" /* Reposition Descending Colon, Open Approach */
"0DSM4ZZ" = "1" /* Reposition Descending Colon, Percutaneous Endoscopic Approach */
"0DSM7ZZ" = "1" /* Reposition Descending Colon, Via Natural or Artificial Opening */
"0DSM8ZZ" = "1" /* Reposition Descending Colon, Via Natural or Artificial Opening Endoscopic */
"0DSN0ZZ" = "1" /* Reposition Sigmoid Colon, Open Approach */
"0DSN4ZZ" = "1" /* Reposition Sigmoid Colon, Percutaneous Endoscopic Approach */
"0DSN7ZZ" = "1" /* Reposition Sigmoid Colon, Via Natural or Artificial Opening */
"0DSN8ZZ" = "1" /* Reposition Sigmoid Colon, Via Natural or Artificial Opening Endoscopic */
"0DSP0ZZ" = "1" /* Reposition Rectum, Open Approach */
"0DSP4ZZ" = "1" /* Reposition Rectum, Percutaneous Endoscopic Approach */
"0DSP7ZZ" = "1" /* Reposition Rectum, Via Natural or Artificial Opening */
"0DSP8ZZ" = "1" /* Reposition Rectum, Via Natural or Artificial Opening Endoscopic */
"0DSQ0ZZ" = "1" /* Reposition Anus, Open Approach */
"0DSQ4ZZ" = "1" /* Reposition Anus, Percutaneous Endoscopic Approach */
"0DSQ7ZZ" = "1" /* Reposition Anus, Via Natural or Artificial Opening */
"0DSQ8ZZ" = "1" /* Reposition Anus, Via Natural or Artificial Opening Endoscopic */
"0DT10ZZ" = "1" /* Resection of Upper Esophagus, Open Approach */
"0DT14ZZ" = "1" /* Resection of Upper Esophagus, Percutaneous Endoscopic Approach */
"0DT17ZZ" = "1" /* Resection of Upper Esophagus, Via Natural or Artificial Opening */
"0DT18ZZ" = "1" /* Resection of Upper Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DT20ZZ" = "1" /* Resection of Middle Esophagus, Open Approach */
"0DT24ZZ" = "1" /* Resection of Middle Esophagus, Percutaneous Endoscopic Approach */
"0DT27ZZ" = "1" /* Resection of Middle Esophagus, Via Natural or Artificial Opening */
"0DT28ZZ" = "1" /* Resection of Middle Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DT30ZZ" = "1" /* Resection of Lower Esophagus, Open Approach */
"0DT34ZZ" = "1" /* Resection of Lower Esophagus, Percutaneous Endoscopic Approach */
"0DT37ZZ" = "1" /* Resection of Lower Esophagus, Via Natural or Artificial Opening */
"0DT38ZZ" = "1" /* Resection of Lower Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DT40ZZ" = "1" /* Resection of Esophagogastric Junction, Open Approach */
"0DT44ZZ" = "1" /* Resection of Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0DT47ZZ" = "1" /* Resection of Esophagogastric Junction, Via Natural or Artificial Opening */
"0DT48ZZ" = "1" /* Resection of Esophagogastric Junction, Via Natural or Artificial Opening Endoscopic */
"0DT50ZZ" = "1" /* Resection of Esophagus, Open Approach */
"0DT54ZZ" = "1" /* Resection of Esophagus, Percutaneous Endoscopic Approach */
"0DT57ZZ" = "1" /* Resection of Esophagus, Via Natural or Artificial Opening */
"0DT58ZZ" = "1" /* Resection of Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DT60ZZ" = "1" /* Resection of Stomach, Open Approach */
"0DT64ZZ" = "1" /* Resection of Stomach, Percutaneous Endoscopic Approach */
"0DT67ZZ" = "1" /* Resection of Stomach, Via Natural or Artificial Opening */
"0DT68ZZ" = "1" /* Resection of Stomach, Via Natural or Artificial Opening Endoscopic */
"0DT70ZZ" = "1" /* Resection of Stomach, Pylorus, Open Approach */
"0DT74ZZ" = "1" /* Resection of Stomach, Pylorus, Percutaneous Endoscopic Approach */
"0DT77ZZ" = "1" /* Resection of Stomach, Pylorus, Via Natural or Artificial Opening */
"0DT78ZZ" = "1" /* Resection of Stomach, Pylorus, Via Natural or Artificial Opening Endoscopic */
"0DT80ZZ" = "1" /* Resection of Small Intestine, Open Approach */
"0DT84ZZ" = "1" /* Resection of Small Intestine, Percutaneous Endoscopic Approach */
"0DT87ZZ" = "1" /* Resection of Small Intestine, Via Natural or Artificial Opening */
"0DT88ZZ" = "1" /* Resection of Small Intestine, Via Natural or Artificial Opening Endoscopic */
"0DT90ZZ" = "1" /* Resection of Duodenum, Open Approach */
"0DT94ZZ" = "1" /* Resection of Duodenum, Percutaneous Endoscopic Approach */
"0DT97ZZ" = "1" /* Resection of Duodenum, Via Natural or Artificial Opening */
"0DT98ZZ" = "1" /* Resection of Duodenum, Via Natural or Artificial Opening Endoscopic */
"0DTA0ZZ" = "1" /* Resection of Jejunum, Open Approach */
"0DTA4ZZ" = "1" /* Resection of Jejunum, Percutaneous Endoscopic Approach */
"0DTA7ZZ" = "1" /* Resection of Jejunum, Via Natural or Artificial Opening */
"0DTA8ZZ" = "1" /* Resection of Jejunum, Via Natural or Artificial Opening Endoscopic */
"0DTB0ZZ" = "1" /* Resection of Ileum, Open Approach */
"0DTB4ZZ" = "1" /* Resection of Ileum, Percutaneous Endoscopic Approach */
"0DTB7ZZ" = "1" /* Resection of Ileum, Via Natural or Artificial Opening */
"0DTB8ZZ" = "1" /* Resection of Ileum, Via Natural or Artificial Opening Endoscopic */
"0DTC0ZZ" = "1" /* Resection of Ileocecal Valve, Open Approach */
"0DTC4ZZ" = "1" /* Resection of Ileocecal Valve, Percutaneous Endoscopic Approach */
"0DTC7ZZ" = "1" /* Resection of Ileocecal Valve, Via Natural or Artificial Opening */
"0DTC8ZZ" = "1" /* Resection of Ileocecal Valve, Via Natural or Artificial Opening Endoscopic */
"0DTE0ZZ" = "1" /* Resection of Large Intestine, Open Approach */
"0DTE4ZZ" = "1" /* Resection of Large Intestine, Percutaneous Endoscopic Approach */
"0DTE7ZZ" = "1" /* Resection of Large Intestine, Via Natural or Artificial Opening */
"0DTE8ZZ" = "1" /* Resection of Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0DTF0ZZ" = "1" /* Resection of Right Large Intestine, Open Approach */
"0DTF4ZZ" = "1" /* Resection of Right Large Intestine, Percutaneous Endoscopic Approach */
"0DTF7ZZ" = "1" /* Resection of Right Large Intestine, Via Natural or Artificial Opening */
"0DTF8ZZ" = "1" /* Resection of Right Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0DTG0ZZ" = "1" /* Resection of Left Large Intestine, Open Approach */
"0DTG4ZZ" = "1" /* Resection of Left Large Intestine, Percutaneous Endoscopic Approach */
"0DTG7ZZ" = "1" /* Resection of Left Large Intestine, Via Natural or Artificial Opening */
"0DTG8ZZ" = "1" /* Resection of Left Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0DTH0ZZ" = "1" /* Resection of Cecum, Open Approach */
"0DTH4ZZ" = "1" /* Resection of Cecum, Percutaneous Endoscopic Approach */
"0DTH7ZZ" = "1" /* Resection of Cecum, Via Natural or Artificial Opening */
"0DTH8ZZ" = "1" /* Resection of Cecum, Via Natural or Artificial Opening Endoscopic */
"0DTJ0ZZ" = "1" /* Resection of Appendix, Open Approach */
"0DTJ4ZZ" = "1" /* Resection of Appendix, Percutaneous Endoscopic Approach */
"0DTJ7ZZ" = "1" /* Resection of Appendix, Via Natural or Artificial Opening */
"0DTJ8ZZ" = "1" /* Resection of Appendix, Via Natural or Artificial Opening Endoscopic */
"0DTK0ZZ" = "1" /* Resection of Ascending Colon, Open Approach */
"0DTK4ZZ" = "1" /* Resection of Ascending Colon, Percutaneous Endoscopic Approach */
"0DTK7ZZ" = "1" /* Resection of Ascending Colon, Via Natural or Artificial Opening */
"0DTK8ZZ" = "1" /* Resection of Ascending Colon, Via Natural or Artificial Opening Endoscopic */
"0DTL0ZZ" = "1" /* Resection of Transverse Colon, Open Approach */
"0DTL4ZZ" = "1" /* Resection of Transverse Colon, Percutaneous Endoscopic Approach */
"0DTL7ZZ" = "1" /* Resection of Transverse Colon, Via Natural or Artificial Opening */
"0DTL8ZZ" = "1" /* Resection of Transverse Colon, Via Natural or Artificial Opening Endoscopic */
"0DTM0ZZ" = "1" /* Resection of Descending Colon, Open Approach */
"0DTM4ZZ" = "1" /* Resection of Descending Colon, Percutaneous Endoscopic Approach */
"0DTM7ZZ" = "1" /* Resection of Descending Colon, Via Natural or Artificial Opening */
"0DTM8ZZ" = "1" /* Resection of Descending Colon, Via Natural or Artificial Opening Endoscopic */
"0DTN0ZZ" = "1" /* Resection of Sigmoid Colon, Open Approach */
"0DTN4ZZ" = "1" /* Resection of Sigmoid Colon, Percutaneous Endoscopic Approach */
"0DTN7ZZ" = "1" /* Resection of Sigmoid Colon, Via Natural or Artificial Opening */
"0DTN8ZZ" = "1" /* Resection of Sigmoid Colon, Via Natural or Artificial Opening Endoscopic */
"0DTP0ZZ" = "1" /* Resection of Rectum, Open Approach */
"0DTP4ZZ" = "1" /* Resection of Rectum, Percutaneous Endoscopic Approach */
"0DTP7ZZ" = "1" /* Resection of Rectum, Via Natural or Artificial Opening */
"0DTP8ZZ" = "1" /* Resection of Rectum, Via Natural or Artificial Opening Endoscopic */
"0DTQ0ZZ" = "1" /* Resection of Anus, Open Approach */
"0DTQ4ZZ" = "1" /* Resection of Anus, Percutaneous Endoscopic Approach */
"0DTQ7ZZ" = "1" /* Resection of Anus, Via Natural or Artificial Opening */
"0DTQ8ZZ" = "1" /* Resection of Anus, Via Natural or Artificial Opening Endoscopic */
"0DTR0ZZ" = "1" /* Resection of Anal Sphincter, Open Approach */
"0DTR4ZZ" = "1" /* Resection of Anal Sphincter, Percutaneous Endoscopic Approach */
"0DTS0ZZ" = "1" /* Resection of Greater Omentum, Open Approach */
"0DTS4ZZ" = "1" /* Resection of Greater Omentum, Percutaneous Endoscopic Approach */
"0DTT0ZZ" = "1" /* Resection of Lesser Omentum, Open Approach */
"0DTT4ZZ" = "1" /* Resection of Lesser Omentum, Percutaneous Endoscopic Approach */
"0DU107Z" = "1" /* Supplement Upper Esophagus with Autologous Tissue Substitute, Open Approach */
"0DU10JZ" = "1" /* Supplement Upper Esophagus with Synthetic Substitute, Open Approach */
"0DU10KZ" = "1" /* Supplement Upper Esophagus with Nonautologous Tissue Substitute, Open Approach */
"0DU147Z" = "1" /* Supplement Upper Esophagus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU14JZ" = "1" /* Supplement Upper Esophagus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DU14KZ" = "1" /* Supplement Upper Esophagus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU177Z" = "1" /* Supplement Upper Esophagus with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU17JZ" = "1" /* Supplement Upper Esophagus with Synthetic Substitute, Via Natural or Artificial Opening */
"0DU17KZ" = "1" /* Supplement Upper Esophagus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU187Z" = "1" /* Supplement Upper Esophagus with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU18JZ" = "1" /* Supplement Upper Esophagus with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU18KZ" = "1" /* Supplement Upper Esophagus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU207Z" = "1" /* Supplement Middle Esophagus with Autologous Tissue Substitute, Open Approach */
"0DU20JZ" = "1" /* Supplement Middle Esophagus with Synthetic Substitute, Open Approach */
"0DU20KZ" = "1" /* Supplement Middle Esophagus with Nonautologous Tissue Substitute, Open Approach */
"0DU247Z" = "1" /* Supplement Middle Esophagus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU24JZ" = "1" /* Supplement Middle Esophagus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DU24KZ" = "1" /* Supplement Middle Esophagus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU277Z" = "1" /* Supplement Middle Esophagus with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU27JZ" = "1" /* Supplement Middle Esophagus with Synthetic Substitute, Via Natural or Artificial Opening */
"0DU27KZ" = "1" /* Supplement Middle Esophagus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU287Z" = "1" /* Supplement Middle Esophagus with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU28JZ" = "1" /* Supplement Middle Esophagus with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU28KZ" = "1" /* Supplement Middle Esophagus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU307Z" = "1" /* Supplement Lower Esophagus with Autologous Tissue Substitute, Open Approach */
"0DU30JZ" = "1" /* Supplement Lower Esophagus with Synthetic Substitute, Open Approach */
"0DU30KZ" = "1" /* Supplement Lower Esophagus with Nonautologous Tissue Substitute, Open Approach */
"0DU347Z" = "1" /* Supplement Lower Esophagus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU34JZ" = "1" /* Supplement Lower Esophagus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DU34KZ" = "1" /* Supplement Lower Esophagus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU377Z" = "1" /* Supplement Lower Esophagus with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU37JZ" = "1" /* Supplement Lower Esophagus with Synthetic Substitute, Via Natural or Artificial Opening */
"0DU37KZ" = "1" /* Supplement Lower Esophagus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU387Z" = "1" /* Supplement Lower Esophagus with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU38JZ" = "1" /* Supplement Lower Esophagus with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU38KZ" = "1" /* Supplement Lower Esophagus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU407Z" = "1" /* Supplement Esophagogastric Junction with Autologous Tissue Substitute, Open Approach */
"0DU40JZ" = "1" /* Supplement Esophagogastric Junction with Synthetic Substitute, Open Approach */
"0DU40KZ" = "1" /* Supplement Esophagogastric Junction with Nonautologous Tissue Substitute, Open Approach */
"0DU447Z" = "1" /* Supplement Esophagogastric Junction with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU44JZ" = "1" /* Supplement Esophagogastric Junction with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DU44KZ" = "1" /* Supplement Esophagogastric Junction with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU477Z" = "1" /* Supplement Esophagogastric Junction with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU47JZ" = "1" /* Supplement Esophagogastric Junction with Synthetic Substitute, Via Natural or Artificial Opening */
"0DU47KZ" = "1" /* Supplement Esophagogastric Junction with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU487Z" = "1" /* Supplement Esophagogastric Junction with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU48JZ" = "1" /* Supplement Esophagogastric Junction with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU48KZ" = "1" /* Supplement Esophagogastric Junction with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU507Z" = "1" /* Supplement Esophagus with Autologous Tissue Substitute, Open Approach */
"0DU50JZ" = "1" /* Supplement Esophagus with Synthetic Substitute, Open Approach */
"0DU50KZ" = "1" /* Supplement Esophagus with Nonautologous Tissue Substitute, Open Approach */
"0DU547Z" = "1" /* Supplement Esophagus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU54JZ" = "1" /* Supplement Esophagus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DU54KZ" = "1" /* Supplement Esophagus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU577Z" = "1" /* Supplement Esophagus with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU57JZ" = "1" /* Supplement Esophagus with Synthetic Substitute, Via Natural or Artificial Opening */
"0DU57KZ" = "1" /* Supplement Esophagus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU587Z" = "1" /* Supplement Esophagus with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU58JZ" = "1" /* Supplement Esophagus with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU58KZ" = "1" /* Supplement Esophagus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU607Z" = "1" /* Supplement Stomach with Autologous Tissue Substitute, Open Approach */
"0DU60JZ" = "1" /* Supplement Stomach with Synthetic Substitute, Open Approach */
"0DU60KZ" = "1" /* Supplement Stomach with Nonautologous Tissue Substitute, Open Approach */
"0DU647Z" = "1" /* Supplement Stomach with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU64JZ" = "1" /* Supplement Stomach with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DU64KZ" = "1" /* Supplement Stomach with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU677Z" = "1" /* Supplement Stomach with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU67JZ" = "1" /* Supplement Stomach with Synthetic Substitute, Via Natural or Artificial Opening */
"0DU67KZ" = "1" /* Supplement Stomach with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU687Z" = "1" /* Supplement Stomach with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU68JZ" = "1" /* Supplement Stomach with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU68KZ" = "1" /* Supplement Stomach with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU707Z" = "1" /* Supplement Stomach, Pylorus with Autologous Tissue Substitute, Open Approach */
"0DU70JZ" = "1" /* Supplement Stomach, Pylorus with Synthetic Substitute, Open Approach */
"0DU70KZ" = "1" /* Supplement Stomach, Pylorus with Nonautologous Tissue Substitute, Open Approach */
"0DU747Z" = "1" /* Supplement Stomach, Pylorus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU74JZ" = "1" /* Supplement Stomach, Pylorus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DU74KZ" = "1" /* Supplement Stomach, Pylorus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU777Z" = "1" /* Supplement Stomach, Pylorus with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU77JZ" = "1" /* Supplement Stomach, Pylorus with Synthetic Substitute, Via Natural or Artificial Opening */
"0DU77KZ" = "1" /* Supplement Stomach, Pylorus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU787Z" = "1" /* Supplement Stomach, Pylorus with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU78JZ" = "1" /* Supplement Stomach, Pylorus with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU78KZ" = "1" /* Supplement Stomach, Pylorus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU807Z" = "1" /* Supplement Small Intestine with Autologous Tissue Substitute, Open Approach */
"0DU80JZ" = "1" /* Supplement Small Intestine with Synthetic Substitute, Open Approach */
"0DU80KZ" = "1" /* Supplement Small Intestine with Nonautologous Tissue Substitute, Open Approach */
"0DU847Z" = "1" /* Supplement Small Intestine with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU84JZ" = "1" /* Supplement Small Intestine with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DU84KZ" = "1" /* Supplement Small Intestine with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU877Z" = "1" /* Supplement Small Intestine with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU87JZ" = "1" /* Supplement Small Intestine with Synthetic Substitute, Via Natural or Artificial Opening */
"0DU87KZ" = "1" /* Supplement Small Intestine with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU887Z" = "1" /* Supplement Small Intestine with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU88JZ" = "1" /* Supplement Small Intestine with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU88KZ" = "1" /* Supplement Small Intestine with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU907Z" = "1" /* Supplement Duodenum with Autologous Tissue Substitute, Open Approach */
"0DU90JZ" = "1" /* Supplement Duodenum with Synthetic Substitute, Open Approach */
"0DU90KZ" = "1" /* Supplement Duodenum with Nonautologous Tissue Substitute, Open Approach */
"0DU947Z" = "1" /* Supplement Duodenum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU94JZ" = "1" /* Supplement Duodenum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DU94KZ" = "1" /* Supplement Duodenum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU977Z" = "1" /* Supplement Duodenum with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU97JZ" = "1" /* Supplement Duodenum with Synthetic Substitute, Via Natural or Artificial Opening */
"0DU97KZ" = "1" /* Supplement Duodenum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU987Z" = "1" /* Supplement Duodenum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU98JZ" = "1" /* Supplement Duodenum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU98KZ" = "1" /* Supplement Duodenum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUA07Z" = "1" /* Supplement Jejunum with Autologous Tissue Substitute, Open Approach */
"0DUA0JZ" = "1" /* Supplement Jejunum with Synthetic Substitute, Open Approach */
"0DUA0KZ" = "1" /* Supplement Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0DUA47Z" = "1" /* Supplement Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUA4JZ" = "1" /* Supplement Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUA4KZ" = "1" /* Supplement Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUA77Z" = "1" /* Supplement Jejunum with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUA7JZ" = "1" /* Supplement Jejunum with Synthetic Substitute, Via Natural or Artificial Opening */
"0DUA7KZ" = "1" /* Supplement Jejunum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUA87Z" = "1" /* Supplement Jejunum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUA8JZ" = "1" /* Supplement Jejunum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUA8KZ" = "1" /* Supplement Jejunum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUB07Z" = "1" /* Supplement Ileum with Autologous Tissue Substitute, Open Approach */
"0DUB0JZ" = "1" /* Supplement Ileum with Synthetic Substitute, Open Approach */
"0DUB0KZ" = "1" /* Supplement Ileum with Nonautologous Tissue Substitute, Open Approach */
"0DUB47Z" = "1" /* Supplement Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUB4JZ" = "1" /* Supplement Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUB4KZ" = "1" /* Supplement Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUB77Z" = "1" /* Supplement Ileum with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUB7JZ" = "1" /* Supplement Ileum with Synthetic Substitute, Via Natural or Artificial Opening */
"0DUB7KZ" = "1" /* Supplement Ileum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUB87Z" = "1" /* Supplement Ileum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUB8JZ" = "1" /* Supplement Ileum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUB8KZ" = "1" /* Supplement Ileum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUC07Z" = "1" /* Supplement Ileocecal Valve with Autologous Tissue Substitute, Open Approach */
"0DUC0JZ" = "1" /* Supplement Ileocecal Valve with Synthetic Substitute, Open Approach */
"0DUC0KZ" = "1" /* Supplement Ileocecal Valve with Nonautologous Tissue Substitute, Open Approach */
"0DUC47Z" = "1" /* Supplement Ileocecal Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUC4JZ" = "1" /* Supplement Ileocecal Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUC4KZ" = "1" /* Supplement Ileocecal Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUC77Z" = "1" /* Supplement Ileocecal Valve with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUC7JZ" = "1" /* Supplement Ileocecal Valve with Synthetic Substitute, Via Natural or Artificial Opening */
"0DUC7KZ" = "1" /* Supplement Ileocecal Valve with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUC87Z" = "1" /* Supplement Ileocecal Valve with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUC8JZ" = "1" /* Supplement Ileocecal Valve with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUC8KZ" = "1" /* Supplement Ileocecal Valve with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUE07Z" = "1" /* Supplement Large Intestine with Autologous Tissue Substitute, Open Approach */
"0DUE0JZ" = "1" /* Supplement Large Intestine with Synthetic Substitute, Open Approach */
"0DUE0KZ" = "1" /* Supplement Large Intestine with Nonautologous Tissue Substitute, Open Approach */
"0DUE47Z" = "1" /* Supplement Large Intestine with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUE4JZ" = "1" /* Supplement Large Intestine with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUE4KZ" = "1" /* Supplement Large Intestine with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUE77Z" = "1" /* Supplement Large Intestine with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUE7JZ" = "1" /* Supplement Large Intestine with Synthetic Substitute, Via Natural or Artificial Opening */
"0DUE7KZ" = "1" /* Supplement Large Intestine with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUE87Z" = "1" /* Supplement Large Intestine with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUE8JZ" = "1" /* Supplement Large Intestine with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUE8KZ" = "1" /* Supplement Large Intestine with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUF07Z" = "1" /* Supplement Right Large Intestine with Autologous Tissue Substitute, Open Approach */
"0DUF0JZ" = "1" /* Supplement Right Large Intestine with Synthetic Substitute, Open Approach */
"0DUF0KZ" = "1" /* Supplement Right Large Intestine with Nonautologous Tissue Substitute, Open Approach */
"0DUF47Z" = "1" /* Supplement Right Large Intestine with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUF4JZ" = "1" /* Supplement Right Large Intestine with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUF4KZ" = "1" /* Supplement Right Large Intestine with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUF77Z" = "1" /* Supplement Right Large Intestine with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUF7JZ" = "1" /* Supplement Right Large Intestine with Synthetic Substitute, Via Natural or Artificial Opening */
"0DUF7KZ" = "1" /* Supplement Right Large Intestine with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUF87Z" = "1" /* Supplement Right Large Intestine with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUF8JZ" = "1" /* Supplement Right Large Intestine with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUF8KZ" = "1" /* Supplement Right Large Intestine with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUG07Z" = "1" /* Supplement Left Large Intestine with Autologous Tissue Substitute, Open Approach */
"0DUG0JZ" = "1" /* Supplement Left Large Intestine with Synthetic Substitute, Open Approach */
"0DUG0KZ" = "1" /* Supplement Left Large Intestine with Nonautologous Tissue Substitute, Open Approach */
"0DUG47Z" = "1" /* Supplement Left Large Intestine with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUG4JZ" = "1" /* Supplement Left Large Intestine with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUG4KZ" = "1" /* Supplement Left Large Intestine with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUG77Z" = "1" /* Supplement Left Large Intestine with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUG7JZ" = "1" /* Supplement Left Large Intestine with Synthetic Substitute, Via Natural or Artificial Opening */
"0DUG7KZ" = "1" /* Supplement Left Large Intestine with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUG87Z" = "1" /* Supplement Left Large Intestine with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUG8JZ" = "1" /* Supplement Left Large Intestine with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUG8KZ" = "1" /* Supplement Left Large Intestine with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUH07Z" = "1" /* Supplement Cecum with Autologous Tissue Substitute, Open Approach */
"0DUH0JZ" = "1" /* Supplement Cecum with Synthetic Substitute, Open Approach */
"0DUH0KZ" = "1" /* Supplement Cecum with Nonautologous Tissue Substitute, Open Approach */
"0DUH47Z" = "1" /* Supplement Cecum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUH4JZ" = "1" /* Supplement Cecum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUH4KZ" = "1" /* Supplement Cecum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUH77Z" = "1" /* Supplement Cecum with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUH7JZ" = "1" /* Supplement Cecum with Synthetic Substitute, Via Natural or Artificial Opening */
"0DUH7KZ" = "1" /* Supplement Cecum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUH87Z" = "1" /* Supplement Cecum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUH8JZ" = "1" /* Supplement Cecum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUH8KZ" = "1" /* Supplement Cecum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUK07Z" = "1" /* Supplement Ascending Colon with Autologous Tissue Substitute, Open Approach */
"0DUK0JZ" = "1" /* Supplement Ascending Colon with Synthetic Substitute, Open Approach */
"0DUK0KZ" = "1" /* Supplement Ascending Colon with Nonautologous Tissue Substitute, Open Approach */
"0DUK47Z" = "1" /* Supplement Ascending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUK4JZ" = "1" /* Supplement Ascending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUK4KZ" = "1" /* Supplement Ascending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUK77Z" = "1" /* Supplement Ascending Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUK7JZ" = "1" /* Supplement Ascending Colon with Synthetic Substitute, Via Natural or Artificial Opening */
"0DUK7KZ" = "1" /* Supplement Ascending Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUK87Z" = "1" /* Supplement Ascending Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUK8JZ" = "1" /* Supplement Ascending Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUK8KZ" = "1" /* Supplement Ascending Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUL07Z" = "1" /* Supplement Transverse Colon with Autologous Tissue Substitute, Open Approach */
"0DUL0JZ" = "1" /* Supplement Transverse Colon with Synthetic Substitute, Open Approach */
"0DUL0KZ" = "1" /* Supplement Transverse Colon with Nonautologous Tissue Substitute, Open Approach */
"0DUL47Z" = "1" /* Supplement Transverse Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUL4JZ" = "1" /* Supplement Transverse Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUL4KZ" = "1" /* Supplement Transverse Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUL77Z" = "1" /* Supplement Transverse Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUL7JZ" = "1" /* Supplement Transverse Colon with Synthetic Substitute, Via Natural or Artificial Opening */
"0DUL7KZ" = "1" /* Supplement Transverse Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUL87Z" = "1" /* Supplement Transverse Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUL8JZ" = "1" /* Supplement Transverse Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUL8KZ" = "1" /* Supplement Transverse Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUM07Z" = "1" /* Supplement Descending Colon with Autologous Tissue Substitute, Open Approach */
"0DUM0JZ" = "1" /* Supplement Descending Colon with Synthetic Substitute, Open Approach */
"0DUM0KZ" = "1" /* Supplement Descending Colon with Nonautologous Tissue Substitute, Open Approach */
"0DUM47Z" = "1" /* Supplement Descending Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUM4JZ" = "1" /* Supplement Descending Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUM4KZ" = "1" /* Supplement Descending Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUM77Z" = "1" /* Supplement Descending Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUM7JZ" = "1" /* Supplement Descending Colon with Synthetic Substitute, Via Natural or Artificial Opening */
"0DUM7KZ" = "1" /* Supplement Descending Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUM87Z" = "1" /* Supplement Descending Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUM8JZ" = "1" /* Supplement Descending Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUM8KZ" = "1" /* Supplement Descending Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUN07Z" = "1" /* Supplement Sigmoid Colon with Autologous Tissue Substitute, Open Approach */
"0DUN0JZ" = "1" /* Supplement Sigmoid Colon with Synthetic Substitute, Open Approach */
"0DUN0KZ" = "1" /* Supplement Sigmoid Colon with Nonautologous Tissue Substitute, Open Approach */
"0DUN47Z" = "1" /* Supplement Sigmoid Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUN4JZ" = "1" /* Supplement Sigmoid Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUN4KZ" = "1" /* Supplement Sigmoid Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUN77Z" = "1" /* Supplement Sigmoid Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUN7JZ" = "1" /* Supplement Sigmoid Colon with Synthetic Substitute, Via Natural or Artificial Opening */
"0DUN7KZ" = "1" /* Supplement Sigmoid Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUN87Z" = "1" /* Supplement Sigmoid Colon with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUN8JZ" = "1" /* Supplement Sigmoid Colon with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUN8KZ" = "1" /* Supplement Sigmoid Colon with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUP07Z" = "1" /* Supplement Rectum with Autologous Tissue Substitute, Open Approach */
"0DUP0JZ" = "1" /* Supplement Rectum with Synthetic Substitute, Open Approach */
"0DUP0KZ" = "1" /* Supplement Rectum with Nonautologous Tissue Substitute, Open Approach */
"0DUP47Z" = "1" /* Supplement Rectum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUP4JZ" = "1" /* Supplement Rectum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUP4KZ" = "1" /* Supplement Rectum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUP77Z" = "1" /* Supplement Rectum with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUP7JZ" = "1" /* Supplement Rectum with Synthetic Substitute, Via Natural or Artificial Opening */
"0DUP7KZ" = "1" /* Supplement Rectum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUP87Z" = "1" /* Supplement Rectum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUP8JZ" = "1" /* Supplement Rectum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUP8KZ" = "1" /* Supplement Rectum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUQ07Z" = "1" /* Supplement Anus with Autologous Tissue Substitute, Open Approach */
"0DUQ0JZ" = "1" /* Supplement Anus with Synthetic Substitute, Open Approach */
"0DUQ0KZ" = "1" /* Supplement Anus with Nonautologous Tissue Substitute, Open Approach */
"0DUQ47Z" = "1" /* Supplement Anus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUQ4JZ" = "1" /* Supplement Anus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUQ4KZ" = "1" /* Supplement Anus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUQ77Z" = "1" /* Supplement Anus with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUQ7JZ" = "1" /* Supplement Anus with Synthetic Substitute, Via Natural or Artificial Opening */
"0DUQ7KZ" = "1" /* Supplement Anus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DUQ87Z" = "1" /* Supplement Anus with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUQ8JZ" = "1" /* Supplement Anus with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUQ8KZ" = "1" /* Supplement Anus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DUQX7Z" = "1" /* Supplement Anus with Autologous Tissue Substitute, External Approach */
"0DUQXJZ" = "1" /* Supplement Anus with Synthetic Substitute, External Approach */
"0DUQXKZ" = "1" /* Supplement Anus with Nonautologous Tissue Substitute, External Approach */
"0DUR07Z" = "1" /* Supplement Anal Sphincter with Autologous Tissue Substitute, Open Approach */
"0DUR0JZ" = "1" /* Supplement Anal Sphincter with Synthetic Substitute, Open Approach */
"0DUR0KZ" = "1" /* Supplement Anal Sphincter with Nonautologous Tissue Substitute, Open Approach */
"0DUR47Z" = "1" /* Supplement Anal Sphincter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUR4JZ" = "1" /* Supplement Anal Sphincter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUR4KZ" = "1" /* Supplement Anal Sphincter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUS07Z" = "1" /* Supplement Greater Omentum with Autologous Tissue Substitute, Open Approach */
"0DUS0JZ" = "1" /* Supplement Greater Omentum with Synthetic Substitute, Open Approach */
"0DUS0KZ" = "1" /* Supplement Greater Omentum with Nonautologous Tissue Substitute, Open Approach */
"0DUS47Z" = "1" /* Supplement Greater Omentum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUS4JZ" = "1" /* Supplement Greater Omentum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUS4KZ" = "1" /* Supplement Greater Omentum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUT07Z" = "1" /* Supplement Lesser Omentum with Autologous Tissue Substitute, Open Approach */
"0DUT0JZ" = "1" /* Supplement Lesser Omentum with Synthetic Substitute, Open Approach */
"0DUT0KZ" = "1" /* Supplement Lesser Omentum with Nonautologous Tissue Substitute, Open Approach */
"0DUT47Z" = "1" /* Supplement Lesser Omentum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUT4JZ" = "1" /* Supplement Lesser Omentum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUT4KZ" = "1" /* Supplement Lesser Omentum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUV07Z" = "1" /* Supplement Mesentery with Autologous Tissue Substitute, Open Approach */
"0DUV0JZ" = "1" /* Supplement Mesentery with Synthetic Substitute, Open Approach */
"0DUV0KZ" = "1" /* Supplement Mesentery with Nonautologous Tissue Substitute, Open Approach */
"0DUV47Z" = "1" /* Supplement Mesentery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUV4JZ" = "1" /* Supplement Mesentery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUV4KZ" = "1" /* Supplement Mesentery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUW07Z" = "1" /* Supplement Peritoneum with Autologous Tissue Substitute, Open Approach */
"0DUW0JZ" = "1" /* Supplement Peritoneum with Synthetic Substitute, Open Approach */
"0DUW0KZ" = "1" /* Supplement Peritoneum with Nonautologous Tissue Substitute, Open Approach */
"0DUW47Z" = "1" /* Supplement Peritoneum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DUW4JZ" = "1" /* Supplement Peritoneum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DUW4KZ" = "1" /* Supplement Peritoneum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DV10CZ" = "1" /* Restriction of Upper Esophagus with Extraluminal Device, Open Approach */
"0DV10DZ" = "1" /* Restriction of Upper Esophagus with Intraluminal Device, Open Approach */
"0DV10ZZ" = "1" /* Restriction of Upper Esophagus, Open Approach */
"0DV13CZ" = "1" /* Restriction of Upper Esophagus with Extraluminal Device, Percutaneous Approach */
"0DV13DZ" = "1" /* Restriction of Upper Esophagus with Intraluminal Device, Percutaneous Approach */
"0DV13ZZ" = "1" /* Restriction of Upper Esophagus, Percutaneous Approach */
"0DV14CZ" = "1" /* Restriction of Upper Esophagus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DV14DZ" = "1" /* Restriction of Upper Esophagus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DV14ZZ" = "1" /* Restriction of Upper Esophagus, Percutaneous Endoscopic Approach */
"0DV17DZ" = "1" /* Restriction of Upper Esophagus with Intraluminal Device, Via Natural or Artificial Opening */
"0DV17ZZ" = "1" /* Restriction of Upper Esophagus, Via Natural or Artificial Opening */
"0DV18DZ" = "1" /* Restriction of Upper Esophagus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DV18ZZ" = "1" /* Restriction of Upper Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DV20CZ" = "1" /* Restriction of Middle Esophagus with Extraluminal Device, Open Approach */
"0DV20DZ" = "1" /* Restriction of Middle Esophagus with Intraluminal Device, Open Approach */
"0DV20ZZ" = "1" /* Restriction of Middle Esophagus, Open Approach */
"0DV23CZ" = "1" /* Restriction of Middle Esophagus with Extraluminal Device, Percutaneous Approach */
"0DV23DZ" = "1" /* Restriction of Middle Esophagus with Intraluminal Device, Percutaneous Approach */
"0DV23ZZ" = "1" /* Restriction of Middle Esophagus, Percutaneous Approach */
"0DV24CZ" = "1" /* Restriction of Middle Esophagus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DV24DZ" = "1" /* Restriction of Middle Esophagus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DV24ZZ" = "1" /* Restriction of Middle Esophagus, Percutaneous Endoscopic Approach */
"0DV27DZ" = "1" /* Restriction of Middle Esophagus with Intraluminal Device, Via Natural or Artificial Opening */
"0DV27ZZ" = "1" /* Restriction of Middle Esophagus, Via Natural or Artificial Opening */
"0DV28DZ" = "1" /* Restriction of Middle Esophagus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DV28ZZ" = "1" /* Restriction of Middle Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DV30CZ" = "1" /* Restriction of Lower Esophagus with Extraluminal Device, Open Approach */
"0DV30DZ" = "1" /* Restriction of Lower Esophagus with Intraluminal Device, Open Approach */
"0DV30ZZ" = "1" /* Restriction of Lower Esophagus, Open Approach */
"0DV33CZ" = "1" /* Restriction of Lower Esophagus with Extraluminal Device, Percutaneous Approach */
"0DV33DZ" = "1" /* Restriction of Lower Esophagus with Intraluminal Device, Percutaneous Approach */
"0DV33ZZ" = "1" /* Restriction of Lower Esophagus, Percutaneous Approach */
"0DV34CZ" = "1" /* Restriction of Lower Esophagus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DV34DZ" = "1" /* Restriction of Lower Esophagus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DV34ZZ" = "1" /* Restriction of Lower Esophagus, Percutaneous Endoscopic Approach */
"0DV37DZ" = "1" /* Restriction of Lower Esophagus with Intraluminal Device, Via Natural or Artificial Opening */
"0DV37ZZ" = "1" /* Restriction of Lower Esophagus, Via Natural or Artificial Opening */
"0DV38DZ" = "1" /* Restriction of Lower Esophagus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DV38ZZ" = "1" /* Restriction of Lower Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DV40CZ" = "1" /* Restriction of Esophagogastric Junction with Extraluminal Device, Open Approach */
"0DV40DZ" = "1" /* Restriction of Esophagogastric Junction with Intraluminal Device, Open Approach */
"0DV40ZZ" = "1" /* Restriction of Esophagogastric Junction, Open Approach */
"0DV43CZ" = "1" /* Restriction of Esophagogastric Junction with Extraluminal Device, Percutaneous Approach */
"0DV43DZ" = "1" /* Restriction of Esophagogastric Junction with Intraluminal Device, Percutaneous Approach */
"0DV43ZZ" = "1" /* Restriction of Esophagogastric Junction, Percutaneous Approach */
"0DV44CZ" = "1" /* Restriction of Esophagogastric Junction with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DV44DZ" = "1" /* Restriction of Esophagogastric Junction with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DV44ZZ" = "1" /* Restriction of Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0DV47DZ" = "1" /* Restriction of Esophagogastric Junction with Intraluminal Device, Via Natural or Artificial Opening */
"0DV47ZZ" = "1" /* Restriction of Esophagogastric Junction, Via Natural or Artificial Opening */
"0DV48DZ" = "1" /* Restriction of Esophagogastric Junction with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DV48ZZ" = "1" /* Restriction of Esophagogastric Junction, Via Natural or Artificial Opening Endoscopic */
"0DV50CZ" = "1" /* Restriction of Esophagus with Extraluminal Device, Open Approach */
"0DV50DZ" = "1" /* Restriction of Esophagus with Intraluminal Device, Open Approach */
"0DV50ZZ" = "1" /* Restriction of Esophagus, Open Approach */
"0DV53CZ" = "1" /* Restriction of Esophagus with Extraluminal Device, Percutaneous Approach */
"0DV53DZ" = "1" /* Restriction of Esophagus with Intraluminal Device, Percutaneous Approach */
"0DV53ZZ" = "1" /* Restriction of Esophagus, Percutaneous Approach */
"0DV54CZ" = "1" /* Restriction of Esophagus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DV54DZ" = "1" /* Restriction of Esophagus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DV54ZZ" = "1" /* Restriction of Esophagus, Percutaneous Endoscopic Approach */
"0DV57DZ" = "1" /* Restriction of Esophagus with Intraluminal Device, Via Natural or Artificial Opening */
"0DV57ZZ" = "1" /* Restriction of Esophagus, Via Natural or Artificial Opening */
"0DV58DZ" = "1" /* Restriction of Esophagus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DV58ZZ" = "1" /* Restriction of Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DV60CZ" = "1" /* Restriction of Stomach with Extraluminal Device, Open Approach */
"0DV60DZ" = "1" /* Restriction of Stomach with Intraluminal Device, Open Approach */
"0DV60ZZ" = "1" /* Restriction of Stomach, Open Approach */
"0DV63CZ" = "1" /* Restriction of Stomach with Extraluminal Device, Percutaneous Approach */
"0DV63DZ" = "1" /* Restriction of Stomach with Intraluminal Device, Percutaneous Approach */
"0DV63ZZ" = "1" /* Restriction of Stomach, Percutaneous Approach */
"0DV64CZ" = "1" /* Restriction of Stomach with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DV64DZ" = "1" /* Restriction of Stomach with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DV64ZZ" = "1" /* Restriction of Stomach, Percutaneous Endoscopic Approach */
"0DV67ZZ" = "1" /* Restriction of Stomach, Via Natural or Artificial Opening */
"0DV68ZZ" = "1" /* Restriction of Stomach, Via Natural or Artificial Opening Endoscopic */
"0DV70CZ" = "1" /* Restriction of Stomach, Pylorus with Extraluminal Device, Open Approach */
"0DV70DZ" = "1" /* Restriction of Stomach, Pylorus with Intraluminal Device, Open Approach */
"0DV70ZZ" = "1" /* Restriction of Stomach, Pylorus, Open Approach */
"0DV73CZ" = "1" /* Restriction of Stomach, Pylorus with Extraluminal Device, Percutaneous Approach */
"0DV73DZ" = "1" /* Restriction of Stomach, Pylorus with Intraluminal Device, Percutaneous Approach */
"0DV73ZZ" = "1" /* Restriction of Stomach, Pylorus, Percutaneous Approach */
"0DV74CZ" = "1" /* Restriction of Stomach, Pylorus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DV74DZ" = "1" /* Restriction of Stomach, Pylorus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DV74ZZ" = "1" /* Restriction of Stomach, Pylorus, Percutaneous Endoscopic Approach */
"0DV77DZ" = "1" /* Restriction of Stomach, Pylorus with Intraluminal Device, Via Natural or Artificial Opening */
"0DV77ZZ" = "1" /* Restriction of Stomach, Pylorus, Via Natural or Artificial Opening */
"0DV78DZ" = "1" /* Restriction of Stomach, Pylorus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DV78ZZ" = "1" /* Restriction of Stomach, Pylorus, Via Natural or Artificial Opening Endoscopic */
"0DV80CZ" = "1" /* Restriction of Small Intestine with Extraluminal Device, Open Approach */
"0DV80DZ" = "1" /* Restriction of Small Intestine with Intraluminal Device, Open Approach */
"0DV80ZZ" = "1" /* Restriction of Small Intestine, Open Approach */
"0DV83CZ" = "1" /* Restriction of Small Intestine with Extraluminal Device, Percutaneous Approach */
"0DV83DZ" = "1" /* Restriction of Small Intestine with Intraluminal Device, Percutaneous Approach */
"0DV83ZZ" = "1" /* Restriction of Small Intestine, Percutaneous Approach */
"0DV84CZ" = "1" /* Restriction of Small Intestine with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DV84DZ" = "1" /* Restriction of Small Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DV84ZZ" = "1" /* Restriction of Small Intestine, Percutaneous Endoscopic Approach */
"0DV87DZ" = "1" /* Restriction of Small Intestine with Intraluminal Device, Via Natural or Artificial Opening */
"0DV87ZZ" = "1" /* Restriction of Small Intestine, Via Natural or Artificial Opening */
"0DV88DZ" = "1" /* Restriction of Small Intestine with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DV88ZZ" = "1" /* Restriction of Small Intestine, Via Natural or Artificial Opening Endoscopic */
"0DV90CZ" = "1" /* Restriction of Duodenum with Extraluminal Device, Open Approach */
"0DV90DZ" = "1" /* Restriction of Duodenum with Intraluminal Device, Open Approach */
"0DV90ZZ" = "1" /* Restriction of Duodenum, Open Approach */
"0DV93CZ" = "1" /* Restriction of Duodenum with Extraluminal Device, Percutaneous Approach */
"0DV93DZ" = "1" /* Restriction of Duodenum with Intraluminal Device, Percutaneous Approach */
"0DV93ZZ" = "1" /* Restriction of Duodenum, Percutaneous Approach */
"0DV94CZ" = "1" /* Restriction of Duodenum with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DV94DZ" = "1" /* Restriction of Duodenum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DV94ZZ" = "1" /* Restriction of Duodenum, Percutaneous Endoscopic Approach */
"0DV97DZ" = "1" /* Restriction of Duodenum with Intraluminal Device, Via Natural or Artificial Opening */
"0DV97ZZ" = "1" /* Restriction of Duodenum, Via Natural or Artificial Opening */
"0DV98DZ" = "1" /* Restriction of Duodenum with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DV98ZZ" = "1" /* Restriction of Duodenum, Via Natural or Artificial Opening Endoscopic */
"0DVA0CZ" = "1" /* Restriction of Jejunum with Extraluminal Device, Open Approach */
"0DVA0DZ" = "1" /* Restriction of Jejunum with Intraluminal Device, Open Approach */
"0DVA0ZZ" = "1" /* Restriction of Jejunum, Open Approach */
"0DVA3CZ" = "1" /* Restriction of Jejunum with Extraluminal Device, Percutaneous Approach */
"0DVA3DZ" = "1" /* Restriction of Jejunum with Intraluminal Device, Percutaneous Approach */
"0DVA3ZZ" = "1" /* Restriction of Jejunum, Percutaneous Approach */
"0DVA4CZ" = "1" /* Restriction of Jejunum with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVA4DZ" = "1" /* Restriction of Jejunum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVA4ZZ" = "1" /* Restriction of Jejunum, Percutaneous Endoscopic Approach */
"0DVA7DZ" = "1" /* Restriction of Jejunum with Intraluminal Device, Via Natural or Artificial Opening */
"0DVA7ZZ" = "1" /* Restriction of Jejunum, Via Natural or Artificial Opening */
"0DVA8DZ" = "1" /* Restriction of Jejunum with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DVA8ZZ" = "1" /* Restriction of Jejunum, Via Natural or Artificial Opening Endoscopic */
"0DVB0CZ" = "1" /* Restriction of Ileum with Extraluminal Device, Open Approach */
"0DVB0DZ" = "1" /* Restriction of Ileum with Intraluminal Device, Open Approach */
"0DVB0ZZ" = "1" /* Restriction of Ileum, Open Approach */
"0DVB3CZ" = "1" /* Restriction of Ileum with Extraluminal Device, Percutaneous Approach */
"0DVB3DZ" = "1" /* Restriction of Ileum with Intraluminal Device, Percutaneous Approach */
"0DVB3ZZ" = "1" /* Restriction of Ileum, Percutaneous Approach */
"0DVB4CZ" = "1" /* Restriction of Ileum with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVB4DZ" = "1" /* Restriction of Ileum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVB4ZZ" = "1" /* Restriction of Ileum, Percutaneous Endoscopic Approach */
"0DVB7DZ" = "1" /* Restriction of Ileum with Intraluminal Device, Via Natural or Artificial Opening */
"0DVB7ZZ" = "1" /* Restriction of Ileum, Via Natural or Artificial Opening */
"0DVB8DZ" = "1" /* Restriction of Ileum with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DVB8ZZ" = "1" /* Restriction of Ileum, Via Natural or Artificial Opening Endoscopic */
"0DVC0CZ" = "1" /* Restriction of Ileocecal Valve with Extraluminal Device, Open Approach */
"0DVC0DZ" = "1" /* Restriction of Ileocecal Valve with Intraluminal Device, Open Approach */
"0DVC0ZZ" = "1" /* Restriction of Ileocecal Valve, Open Approach */
"0DVC3CZ" = "1" /* Restriction of Ileocecal Valve with Extraluminal Device, Percutaneous Approach */
"0DVC3DZ" = "1" /* Restriction of Ileocecal Valve with Intraluminal Device, Percutaneous Approach */
"0DVC3ZZ" = "1" /* Restriction of Ileocecal Valve, Percutaneous Approach */
"0DVC4CZ" = "1" /* Restriction of Ileocecal Valve with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVC4DZ" = "1" /* Restriction of Ileocecal Valve with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVC4ZZ" = "1" /* Restriction of Ileocecal Valve, Percutaneous Endoscopic Approach */
"0DVC7DZ" = "1" /* Restriction of Ileocecal Valve with Intraluminal Device, Via Natural or Artificial Opening */
"0DVC7ZZ" = "1" /* Restriction of Ileocecal Valve, Via Natural or Artificial Opening */
"0DVC8DZ" = "1" /* Restriction of Ileocecal Valve with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DVC8ZZ" = "1" /* Restriction of Ileocecal Valve, Via Natural or Artificial Opening Endoscopic */
"0DVE0CZ" = "1" /* Restriction of Large Intestine with Extraluminal Device, Open Approach */
"0DVE0DZ" = "1" /* Restriction of Large Intestine with Intraluminal Device, Open Approach */
"0DVE0ZZ" = "1" /* Restriction of Large Intestine, Open Approach */
"0DVE3CZ" = "1" /* Restriction of Large Intestine with Extraluminal Device, Percutaneous Approach */
"0DVE3DZ" = "1" /* Restriction of Large Intestine with Intraluminal Device, Percutaneous Approach */
"0DVE3ZZ" = "1" /* Restriction of Large Intestine, Percutaneous Approach */
"0DVE4CZ" = "1" /* Restriction of Large Intestine with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVE4DZ" = "1" /* Restriction of Large Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVE4ZZ" = "1" /* Restriction of Large Intestine, Percutaneous Endoscopic Approach */
"0DVE7DZ" = "1" /* Restriction of Large Intestine with Intraluminal Device, Via Natural or Artificial Opening */
"0DVE7ZZ" = "1" /* Restriction of Large Intestine, Via Natural or Artificial Opening */
"0DVE8DZ" = "1" /* Restriction of Large Intestine with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DVE8ZZ" = "1" /* Restriction of Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0DVF0CZ" = "1" /* Restriction of Right Large Intestine with Extraluminal Device, Open Approach */
"0DVF0DZ" = "1" /* Restriction of Right Large Intestine with Intraluminal Device, Open Approach */
"0DVF0ZZ" = "1" /* Restriction of Right Large Intestine, Open Approach */
"0DVF3CZ" = "1" /* Restriction of Right Large Intestine with Extraluminal Device, Percutaneous Approach */
"0DVF3DZ" = "1" /* Restriction of Right Large Intestine with Intraluminal Device, Percutaneous Approach */
"0DVF3ZZ" = "1" /* Restriction of Right Large Intestine, Percutaneous Approach */
"0DVF4CZ" = "1" /* Restriction of Right Large Intestine with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVF4DZ" = "1" /* Restriction of Right Large Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVF4ZZ" = "1" /* Restriction of Right Large Intestine, Percutaneous Endoscopic Approach */
"0DVF7DZ" = "1" /* Restriction of Right Large Intestine with Intraluminal Device, Via Natural or Artificial Opening */
"0DVF7ZZ" = "1" /* Restriction of Right Large Intestine, Via Natural or Artificial Opening */
"0DVF8DZ" = "1" /* Restriction of Right Large Intestine with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DVF8ZZ" = "1" /* Restriction of Right Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0DVG0CZ" = "1" /* Restriction of Left Large Intestine with Extraluminal Device, Open Approach */
"0DVG0DZ" = "1" /* Restriction of Left Large Intestine with Intraluminal Device, Open Approach */
"0DVG0ZZ" = "1" /* Restriction of Left Large Intestine, Open Approach */
"0DVG3CZ" = "1" /* Restriction of Left Large Intestine with Extraluminal Device, Percutaneous Approach */
"0DVG3DZ" = "1" /* Restriction of Left Large Intestine with Intraluminal Device, Percutaneous Approach */
"0DVG3ZZ" = "1" /* Restriction of Left Large Intestine, Percutaneous Approach */
"0DVG4CZ" = "1" /* Restriction of Left Large Intestine with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVG4DZ" = "1" /* Restriction of Left Large Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVG4ZZ" = "1" /* Restriction of Left Large Intestine, Percutaneous Endoscopic Approach */
"0DVG7DZ" = "1" /* Restriction of Left Large Intestine with Intraluminal Device, Via Natural or Artificial Opening */
"0DVG7ZZ" = "1" /* Restriction of Left Large Intestine, Via Natural or Artificial Opening */
"0DVG8DZ" = "1" /* Restriction of Left Large Intestine with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DVG8ZZ" = "1" /* Restriction of Left Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0DVH0CZ" = "1" /* Restriction of Cecum with Extraluminal Device, Open Approach */
"0DVH0DZ" = "1" /* Restriction of Cecum with Intraluminal Device, Open Approach */
"0DVH0ZZ" = "1" /* Restriction of Cecum, Open Approach */
"0DVH3CZ" = "1" /* Restriction of Cecum with Extraluminal Device, Percutaneous Approach */
"0DVH3DZ" = "1" /* Restriction of Cecum with Intraluminal Device, Percutaneous Approach */
"0DVH3ZZ" = "1" /* Restriction of Cecum, Percutaneous Approach */
"0DVH4CZ" = "1" /* Restriction of Cecum with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVH4DZ" = "1" /* Restriction of Cecum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVH4ZZ" = "1" /* Restriction of Cecum, Percutaneous Endoscopic Approach */
"0DVH7DZ" = "1" /* Restriction of Cecum with Intraluminal Device, Via Natural or Artificial Opening */
"0DVH7ZZ" = "1" /* Restriction of Cecum, Via Natural or Artificial Opening */
"0DVH8DZ" = "1" /* Restriction of Cecum with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DVH8ZZ" = "1" /* Restriction of Cecum, Via Natural or Artificial Opening Endoscopic */
"0DVK0CZ" = "1" /* Restriction of Ascending Colon with Extraluminal Device, Open Approach */
"0DVK0DZ" = "1" /* Restriction of Ascending Colon with Intraluminal Device, Open Approach */
"0DVK0ZZ" = "1" /* Restriction of Ascending Colon, Open Approach */
"0DVK3CZ" = "1" /* Restriction of Ascending Colon with Extraluminal Device, Percutaneous Approach */
"0DVK3DZ" = "1" /* Restriction of Ascending Colon with Intraluminal Device, Percutaneous Approach */
"0DVK3ZZ" = "1" /* Restriction of Ascending Colon, Percutaneous Approach */
"0DVK4CZ" = "1" /* Restriction of Ascending Colon with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVK4DZ" = "1" /* Restriction of Ascending Colon with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVK4ZZ" = "1" /* Restriction of Ascending Colon, Percutaneous Endoscopic Approach */
"0DVK7DZ" = "1" /* Restriction of Ascending Colon with Intraluminal Device, Via Natural or Artificial Opening */
"0DVK7ZZ" = "1" /* Restriction of Ascending Colon, Via Natural or Artificial Opening */
"0DVK8DZ" = "1" /* Restriction of Ascending Colon with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DVK8ZZ" = "1" /* Restriction of Ascending Colon, Via Natural or Artificial Opening Endoscopic */
"0DVL0CZ" = "1" /* Restriction of Transverse Colon with Extraluminal Device, Open Approach */
"0DVL0DZ" = "1" /* Restriction of Transverse Colon with Intraluminal Device, Open Approach */
"0DVL0ZZ" = "1" /* Restriction of Transverse Colon, Open Approach */
"0DVL3CZ" = "1" /* Restriction of Transverse Colon with Extraluminal Device, Percutaneous Approach */
"0DVL3DZ" = "1" /* Restriction of Transverse Colon with Intraluminal Device, Percutaneous Approach */
"0DVL3ZZ" = "1" /* Restriction of Transverse Colon, Percutaneous Approach */
"0DVL4CZ" = "1" /* Restriction of Transverse Colon with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVL4DZ" = "1" /* Restriction of Transverse Colon with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVL4ZZ" = "1" /* Restriction of Transverse Colon, Percutaneous Endoscopic Approach */
"0DVL7DZ" = "1" /* Restriction of Transverse Colon with Intraluminal Device, Via Natural or Artificial Opening */
"0DVL7ZZ" = "1" /* Restriction of Transverse Colon, Via Natural or Artificial Opening */
"0DVL8DZ" = "1" /* Restriction of Transverse Colon with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DVL8ZZ" = "1" /* Restriction of Transverse Colon, Via Natural or Artificial Opening Endoscopic */
"0DVM0CZ" = "1" /* Restriction of Descending Colon with Extraluminal Device, Open Approach */
"0DVM0DZ" = "1" /* Restriction of Descending Colon with Intraluminal Device, Open Approach */
"0DVM0ZZ" = "1" /* Restriction of Descending Colon, Open Approach */
"0DVM3CZ" = "1" /* Restriction of Descending Colon with Extraluminal Device, Percutaneous Approach */
"0DVM3DZ" = "1" /* Restriction of Descending Colon with Intraluminal Device, Percutaneous Approach */
"0DVM3ZZ" = "1" /* Restriction of Descending Colon, Percutaneous Approach */
"0DVM4CZ" = "1" /* Restriction of Descending Colon with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVM4DZ" = "1" /* Restriction of Descending Colon with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVM4ZZ" = "1" /* Restriction of Descending Colon, Percutaneous Endoscopic Approach */
"0DVM7DZ" = "1" /* Restriction of Descending Colon with Intraluminal Device, Via Natural or Artificial Opening */
"0DVM7ZZ" = "1" /* Restriction of Descending Colon, Via Natural or Artificial Opening */
"0DVM8DZ" = "1" /* Restriction of Descending Colon with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DVM8ZZ" = "1" /* Restriction of Descending Colon, Via Natural or Artificial Opening Endoscopic */
"0DVN0CZ" = "1" /* Restriction of Sigmoid Colon with Extraluminal Device, Open Approach */
"0DVN0DZ" = "1" /* Restriction of Sigmoid Colon with Intraluminal Device, Open Approach */
"0DVN0ZZ" = "1" /* Restriction of Sigmoid Colon, Open Approach */
"0DVN3CZ" = "1" /* Restriction of Sigmoid Colon with Extraluminal Device, Percutaneous Approach */
"0DVN3DZ" = "1" /* Restriction of Sigmoid Colon with Intraluminal Device, Percutaneous Approach */
"0DVN3ZZ" = "1" /* Restriction of Sigmoid Colon, Percutaneous Approach */
"0DVN4CZ" = "1" /* Restriction of Sigmoid Colon with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVN4DZ" = "1" /* Restriction of Sigmoid Colon with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVN4ZZ" = "1" /* Restriction of Sigmoid Colon, Percutaneous Endoscopic Approach */
"0DVN7DZ" = "1" /* Restriction of Sigmoid Colon with Intraluminal Device, Via Natural or Artificial Opening */
"0DVN7ZZ" = "1" /* Restriction of Sigmoid Colon, Via Natural or Artificial Opening */
"0DVN8DZ" = "1" /* Restriction of Sigmoid Colon with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DVN8ZZ" = "1" /* Restriction of Sigmoid Colon, Via Natural or Artificial Opening Endoscopic */
"0DVP0CZ" = "1" /* Restriction of Rectum with Extraluminal Device, Open Approach */
"0DVP0DZ" = "1" /* Restriction of Rectum with Intraluminal Device, Open Approach */
"0DVP0ZZ" = "1" /* Restriction of Rectum, Open Approach */
"0DVP3CZ" = "1" /* Restriction of Rectum with Extraluminal Device, Percutaneous Approach */
"0DVP3DZ" = "1" /* Restriction of Rectum with Intraluminal Device, Percutaneous Approach */
"0DVP3ZZ" = "1" /* Restriction of Rectum, Percutaneous Approach */
"0DVP4CZ" = "1" /* Restriction of Rectum with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVP4DZ" = "1" /* Restriction of Rectum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVP4ZZ" = "1" /* Restriction of Rectum, Percutaneous Endoscopic Approach */
"0DVP7DZ" = "1" /* Restriction of Rectum with Intraluminal Device, Via Natural or Artificial Opening */
"0DVP7ZZ" = "1" /* Restriction of Rectum, Via Natural or Artificial Opening */
"0DVP8DZ" = "1" /* Restriction of Rectum with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DVP8ZZ" = "1" /* Restriction of Rectum, Via Natural or Artificial Opening Endoscopic */
"0DVQ0CZ" = "1" /* Restriction of Anus with Extraluminal Device, Open Approach */
"0DVQ0DZ" = "1" /* Restriction of Anus with Intraluminal Device, Open Approach */
"0DVQ0ZZ" = "1" /* Restriction of Anus, Open Approach */
"0DVQ3CZ" = "1" /* Restriction of Anus with Extraluminal Device, Percutaneous Approach */
"0DVQ3DZ" = "1" /* Restriction of Anus with Intraluminal Device, Percutaneous Approach */
"0DVQ3ZZ" = "1" /* Restriction of Anus, Percutaneous Approach */
"0DVQ4CZ" = "1" /* Restriction of Anus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DVQ4DZ" = "1" /* Restriction of Anus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DVQ4ZZ" = "1" /* Restriction of Anus, Percutaneous Endoscopic Approach */
"0DVQ7DZ" = "1" /* Restriction of Anus with Intraluminal Device, Via Natural or Artificial Opening */
"0DVQ7ZZ" = "1" /* Restriction of Anus, Via Natural or Artificial Opening */
"0DVQ8DZ" = "1" /* Restriction of Anus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DVQ8ZZ" = "1" /* Restriction of Anus, Via Natural or Artificial Opening Endoscopic */
"0DVQXCZ" = "1" /* Restriction of Anus with Extraluminal Device, External Approach */
"0DVQXDZ" = "1" /* Restriction of Anus with Intraluminal Device, External Approach */
"0DVQXZZ" = "1" /* Restriction of Anus, External Approach */
"0DW000Z" = "1" /* Revision of Drainage Device in Upper Intestinal Tract, Open Approach */
"0DW002Z" = "1" /* Revision of Monitoring Device in Upper Intestinal Tract, Open Approach */
"0DW003Z" = "1" /* Revision of Infusion Device in Upper Intestinal Tract, Open Approach */
"0DW007Z" = "1" /* Revision of Autologous Tissue Substitute in Upper Intestinal Tract, Open Approach */
"0DW00CZ" = "1" /* Revision of Extraluminal Device in Upper Intestinal Tract, Open Approach */
"0DW00DZ" = "1" /* Revision of Intraluminal Device in Upper Intestinal Tract, Open Approach */
"0DW00JZ" = "1" /* Revision of Synthetic Substitute in Upper Intestinal Tract, Open Approach */
"0DW00KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Intestinal Tract, Open Approach */
"0DW00UZ" = "1" /* Revision of Feeding Device in Upper Intestinal Tract, Open Approach */
"0DW030Z" = "1" /* Revision of Drainage Device in Upper Intestinal Tract, Percutaneous Approach */
"0DW032Z" = "1" /* Revision of Monitoring Device in Upper Intestinal Tract, Percutaneous Approach */
"0DW033Z" = "1" /* Revision of Infusion Device in Upper Intestinal Tract, Percutaneous Approach */
"0DW037Z" = "1" /* Revision of Autologous Tissue Substitute in Upper Intestinal Tract, Percutaneous Approach */
"0DW03CZ" = "1" /* Revision of Extraluminal Device in Upper Intestinal Tract, Percutaneous Approach */
"0DW03DZ" = "1" /* Revision of Intraluminal Device in Upper Intestinal Tract, Percutaneous Approach */
"0DW03JZ" = "1" /* Revision of Synthetic Substitute in Upper Intestinal Tract, Percutaneous Approach */
"0DW03KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Intestinal Tract, Percutaneous Approach */
"0DW03UZ" = "1" /* Revision of Feeding Device in Upper Intestinal Tract, Percutaneous Approach */
"0DW040Z" = "1" /* Revision of Drainage Device in Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DW042Z" = "1" /* Revision of Monitoring Device in Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DW043Z" = "1" /* Revision of Infusion Device in Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DW047Z" = "1" /* Revision of Autologous Tissue Substitute in Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DW04CZ" = "1" /* Revision of Extraluminal Device in Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DW04DZ" = "1" /* Revision of Intraluminal Device in Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DW04JZ" = "1" /* Revision of Synthetic Substitute in Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DW04KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DW04UZ" = "1" /* Revision of Feeding Device in Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DW070Z" = "1" /* Revision of Drainage Device in Upper Intestinal Tract, Via Natural or Artificial Opening */
"0DW072Z" = "1" /* Revision of Monitoring Device in Upper Intestinal Tract, Via Natural or Artificial Opening */
"0DW073Z" = "1" /* Revision of Infusion Device in Upper Intestinal Tract, Via Natural or Artificial Opening */
"0DW077Z" = "1" /* Revision of Autologous Tissue Substitute in Upper Intestinal Tract, Via Natural or Artificial Opening */
"0DW07CZ" = "1" /* Revision of Extraluminal Device in Upper Intestinal Tract, Via Natural or Artificial Opening */
"0DW07DZ" = "1" /* Revision of Intraluminal Device in Upper Intestinal Tract, Via Natural or Artificial Opening */
"0DW07JZ" = "1" /* Revision of Synthetic Substitute in Upper Intestinal Tract, Via Natural or Artificial Opening */
"0DW07KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Intestinal Tract, Via Natural or Artificial Opening */
"0DW07UZ" = "1" /* Revision of Feeding Device in Upper Intestinal Tract, Via Natural or Artificial Opening */
"0DW080Z" = "1" /* Revision of Drainage Device in Upper Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DW082Z" = "1" /* Revision of Monitoring Device in Upper Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DW083Z" = "1" /* Revision of Infusion Device in Upper Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DW087Z" = "1" /* Revision of Autologous Tissue Substitute in Upper Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DW08CZ" = "1" /* Revision of Extraluminal Device in Upper Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DW08DZ" = "1" /* Revision of Intraluminal Device in Upper Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DW08JZ" = "1" /* Revision of Synthetic Substitute in Upper Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DW08KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DW08UZ" = "1" /* Revision of Feeding Device in Upper Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DW57DZ" = "1" /* Revision of Intraluminal Device in Esophagus, Via Natural or Artificial Opening */
"0DW58DZ" = "1" /* Revision of Intraluminal Device in Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DW600Z" = "1" /* Revision of Drainage Device in Stomach, Open Approach */
"0DW602Z" = "1" /* Revision of Monitoring Device in Stomach, Open Approach */
"0DW603Z" = "1" /* Revision of Infusion Device in Stomach, Open Approach */
"0DW607Z" = "1" /* Revision of Autologous Tissue Substitute in Stomach, Open Approach */
"0DW60CZ" = "1" /* Revision of Extraluminal Device in Stomach, Open Approach */
"0DW60DZ" = "1" /* Revision of Intraluminal Device in Stomach, Open Approach */
"0DW60JZ" = "1" /* Revision of Synthetic Substitute in Stomach, Open Approach */
"0DW60KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Stomach, Open Approach */
"0DW60MZ" = "1" /* Revision of Stimulator Lead in Stomach, Open Approach */
"0DW60UZ" = "1" /* Revision of Feeding Device in Stomach, Open Approach */
"0DW630Z" = "1" /* Revision of Drainage Device in Stomach, Percutaneous Approach */
"0DW632Z" = "1" /* Revision of Monitoring Device in Stomach, Percutaneous Approach */
"0DW633Z" = "1" /* Revision of Infusion Device in Stomach, Percutaneous Approach */
"0DW637Z" = "1" /* Revision of Autologous Tissue Substitute in Stomach, Percutaneous Approach */
"0DW63CZ" = "1" /* Revision of Extraluminal Device in Stomach, Percutaneous Approach */
"0DW63DZ" = "1" /* Revision of Intraluminal Device in Stomach, Percutaneous Approach */
"0DW63JZ" = "1" /* Revision of Synthetic Substitute in Stomach, Percutaneous Approach */
"0DW63KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Stomach, Percutaneous Approach */
"0DW63MZ" = "1" /* Revision of Stimulator Lead in Stomach, Percutaneous Approach */
"0DW63UZ" = "1" /* Revision of Feeding Device in Stomach, Percutaneous Approach */
"0DW640Z" = "1" /* Revision of Drainage Device in Stomach, Percutaneous Endoscopic Approach */
"0DW642Z" = "1" /* Revision of Monitoring Device in Stomach, Percutaneous Endoscopic Approach */
"0DW643Z" = "1" /* Revision of Infusion Device in Stomach, Percutaneous Endoscopic Approach */
"0DW647Z" = "1" /* Revision of Autologous Tissue Substitute in Stomach, Percutaneous Endoscopic Approach */
"0DW64CZ" = "1" /* Revision of Extraluminal Device in Stomach, Percutaneous Endoscopic Approach */
"0DW64DZ" = "1" /* Revision of Intraluminal Device in Stomach, Percutaneous Endoscopic Approach */
"0DW64JZ" = "1" /* Revision of Synthetic Substitute in Stomach, Percutaneous Endoscopic Approach */
"0DW64KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Stomach, Percutaneous Endoscopic Approach */
"0DW64MZ" = "1" /* Revision of Stimulator Lead in Stomach, Percutaneous Endoscopic Approach */
"0DW64UZ" = "1" /* Revision of Feeding Device in Stomach, Percutaneous Endoscopic Approach */
"0DW670Z" = "1" /* Revision of Drainage Device in Stomach, Via Natural or Artificial Opening */
"0DW672Z" = "1" /* Revision of Monitoring Device in Stomach, Via Natural or Artificial Opening */
"0DW673Z" = "1" /* Revision of Infusion Device in Stomach, Via Natural or Artificial Opening */
"0DW677Z" = "1" /* Revision of Autologous Tissue Substitute in Stomach, Via Natural or Artificial Opening */
"0DW67CZ" = "1" /* Revision of Extraluminal Device in Stomach, Via Natural or Artificial Opening */
"0DW67DZ" = "1" /* Revision of Intraluminal Device in Stomach, Via Natural or Artificial Opening */
"0DW67JZ" = "1" /* Revision of Synthetic Substitute in Stomach, Via Natural or Artificial Opening */
"0DW67KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Stomach, Via Natural or Artificial Opening */
"0DW67UZ" = "1" /* Revision of Feeding Device in Stomach, Via Natural or Artificial Opening */
"0DW680Z" = "1" /* Revision of Drainage Device in Stomach, Via Natural or Artificial Opening Endoscopic */
"0DW682Z" = "1" /* Revision of Monitoring Device in Stomach, Via Natural or Artificial Opening Endoscopic */
"0DW683Z" = "1" /* Revision of Infusion Device in Stomach, Via Natural or Artificial Opening Endoscopic */
"0DW687Z" = "1" /* Revision of Autologous Tissue Substitute in Stomach, Via Natural or Artificial Opening Endoscopic */
"0DW68CZ" = "1" /* Revision of Extraluminal Device in Stomach, Via Natural or Artificial Opening Endoscopic */
"0DW68DZ" = "1" /* Revision of Intraluminal Device in Stomach, Via Natural or Artificial Opening Endoscopic */
"0DW68JZ" = "1" /* Revision of Synthetic Substitute in Stomach, Via Natural or Artificial Opening Endoscopic */
"0DW68KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Stomach, Via Natural or Artificial Opening Endoscopic */
"0DW68UZ" = "1" /* Revision of Feeding Device in Stomach, Via Natural or Artificial Opening Endoscopic */
"0DW807Z" = "1" /* Revision of Autologous Tissue Substitute in Small Intestine, Open Approach */
"0DW80JZ" = "1" /* Revision of Synthetic Substitute in Small Intestine, Open Approach */
"0DW80KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Small Intestine, Open Approach */
"0DW847Z" = "1" /* Revision of Autologous Tissue Substitute in Small Intestine, Percutaneous Endoscopic Approach */
"0DW84JZ" = "1" /* Revision of Synthetic Substitute in Small Intestine, Percutaneous Endoscopic Approach */
"0DW84KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Small Intestine, Percutaneous Endoscopic Approach */
"0DW877Z" = "1" /* Revision of Autologous Tissue Substitute in Small Intestine, Via Natural or Artificial Opening */
"0DW87JZ" = "1" /* Revision of Synthetic Substitute in Small Intestine, Via Natural or Artificial Opening */
"0DW87KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Small Intestine, Via Natural or Artificial Opening */
"0DW887Z" = "1" /* Revision of Autologous Tissue Substitute in Small Intestine, Via Natural or Artificial Opening Endoscopic */
"0DW88JZ" = "1" /* Revision of Synthetic Substitute in Small Intestine, Via Natural or Artificial Opening Endoscopic */
"0DW88KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Small Intestine, Via Natural or Artificial Opening Endoscopic */
"0DWD00Z" = "1" /* Revision of Drainage Device in Lower Intestinal Tract, Open Approach */
"0DWD02Z" = "1" /* Revision of Monitoring Device in Lower Intestinal Tract, Open Approach */
"0DWD03Z" = "1" /* Revision of Infusion Device in Lower Intestinal Tract, Open Approach */
"0DWD07Z" = "1" /* Revision of Autologous Tissue Substitute in Lower Intestinal Tract, Open Approach */
"0DWD0CZ" = "1" /* Revision of Extraluminal Device in Lower Intestinal Tract, Open Approach */
"0DWD0DZ" = "1" /* Revision of Intraluminal Device in Lower Intestinal Tract, Open Approach */
"0DWD0JZ" = "1" /* Revision of Synthetic Substitute in Lower Intestinal Tract, Open Approach */
"0DWD0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Intestinal Tract, Open Approach */
"0DWD0UZ" = "1" /* Revision of Feeding Device in Lower Intestinal Tract, Open Approach */
"0DWD30Z" = "1" /* Revision of Drainage Device in Lower Intestinal Tract, Percutaneous Approach */
"0DWD32Z" = "1" /* Revision of Monitoring Device in Lower Intestinal Tract, Percutaneous Approach */
"0DWD33Z" = "1" /* Revision of Infusion Device in Lower Intestinal Tract, Percutaneous Approach */
"0DWD37Z" = "1" /* Revision of Autologous Tissue Substitute in Lower Intestinal Tract, Percutaneous Approach */
"0DWD3CZ" = "1" /* Revision of Extraluminal Device in Lower Intestinal Tract, Percutaneous Approach */
"0DWD3DZ" = "1" /* Revision of Intraluminal Device in Lower Intestinal Tract, Percutaneous Approach */
"0DWD3JZ" = "1" /* Revision of Synthetic Substitute in Lower Intestinal Tract, Percutaneous Approach */
"0DWD3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Intestinal Tract, Percutaneous Approach */
"0DWD3UZ" = "1" /* Revision of Feeding Device in Lower Intestinal Tract, Percutaneous Approach */
"0DWD40Z" = "1" /* Revision of Drainage Device in Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DWD42Z" = "1" /* Revision of Monitoring Device in Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DWD43Z" = "1" /* Revision of Infusion Device in Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DWD47Z" = "1" /* Revision of Autologous Tissue Substitute in Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DWD4CZ" = "1" /* Revision of Extraluminal Device in Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DWD4DZ" = "1" /* Revision of Intraluminal Device in Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DWD4JZ" = "1" /* Revision of Synthetic Substitute in Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DWD4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DWD4UZ" = "1" /* Revision of Feeding Device in Lower Intestinal Tract, Percutaneous Endoscopic Approach */
"0DWD70Z" = "1" /* Revision of Drainage Device in Lower Intestinal Tract, Via Natural or Artificial Opening */
"0DWD72Z" = "1" /* Revision of Monitoring Device in Lower Intestinal Tract, Via Natural or Artificial Opening */
"0DWD73Z" = "1" /* Revision of Infusion Device in Lower Intestinal Tract, Via Natural or Artificial Opening */
"0DWD77Z" = "1" /* Revision of Autologous Tissue Substitute in Lower Intestinal Tract, Via Natural or Artificial Opening */
"0DWD7CZ" = "1" /* Revision of Extraluminal Device in Lower Intestinal Tract, Via Natural or Artificial Opening */
"0DWD7DZ" = "1" /* Revision of Intraluminal Device in Lower Intestinal Tract, Via Natural or Artificial Opening */
"0DWD7JZ" = "1" /* Revision of Synthetic Substitute in Lower Intestinal Tract, Via Natural or Artificial Opening */
"0DWD7KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Intestinal Tract, Via Natural or Artificial Opening */
"0DWD7UZ" = "1" /* Revision of Feeding Device in Lower Intestinal Tract, Via Natural or Artificial Opening */
"0DWD80Z" = "1" /* Revision of Drainage Device in Lower Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DWD82Z" = "1" /* Revision of Monitoring Device in Lower Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DWD83Z" = "1" /* Revision of Infusion Device in Lower Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DWD87Z" = "1" /* Revision of Autologous Tissue Substitute in Lower Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DWD8CZ" = "1" /* Revision of Extraluminal Device in Lower Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DWD8DZ" = "1" /* Revision of Intraluminal Device in Lower Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DWD8JZ" = "1" /* Revision of Synthetic Substitute in Lower Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DWD8KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DWD8UZ" = "1" /* Revision of Feeding Device in Lower Intestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0DWE07Z" = "1" /* Revision of Autologous Tissue Substitute in Large Intestine, Open Approach */
"0DWE0JZ" = "1" /* Revision of Synthetic Substitute in Large Intestine, Open Approach */
"0DWE0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Large Intestine, Open Approach */
"0DWE47Z" = "1" /* Revision of Autologous Tissue Substitute in Large Intestine, Percutaneous Endoscopic Approach */
"0DWE4JZ" = "1" /* Revision of Synthetic Substitute in Large Intestine, Percutaneous Endoscopic Approach */
"0DWE4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Large Intestine, Percutaneous Endoscopic Approach */
"0DWE77Z" = "1" /* Revision of Autologous Tissue Substitute in Large Intestine, Via Natural or Artificial Opening */
"0DWE7JZ" = "1" /* Revision of Synthetic Substitute in Large Intestine, Via Natural or Artificial Opening */
"0DWE7KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Large Intestine, Via Natural or Artificial Opening */
"0DWE87Z" = "1" /* Revision of Autologous Tissue Substitute in Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0DWE8JZ" = "1" /* Revision of Synthetic Substitute in Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0DWE8KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Large Intestine, Via Natural or Artificial Opening Endoscopic */
"0DWQ0LZ" = "1" /* Revision of Artificial Sphincter in Anus, Open Approach */
"0DWQ3LZ" = "1" /* Revision of Artificial Sphincter in Anus, Percutaneous Approach */
"0DWQ4LZ" = "1" /* Revision of Artificial Sphincter in Anus, Percutaneous Endoscopic Approach */
"0DWQ7LZ" = "1" /* Revision of Artificial Sphincter in Anus, Via Natural or Artificial Opening */
"0DWQ8LZ" = "1" /* Revision of Artificial Sphincter in Anus, Via Natural or Artificial Opening Endoscopic */
"0DWR0MZ" = "1" /* Revision of Stimulator Lead in Anal Sphincter, Open Approach */
"0DWR3MZ" = "1" /* Revision of Stimulator Lead in Anal Sphincter, Percutaneous Approach */
"0DWR4MZ" = "1" /* Revision of Stimulator Lead in Anal Sphincter, Percutaneous Endoscopic Approach */
"0DWU07Z" = "1" /* Revision of Autologous Tissue Substitute in Omentum, Open Approach */
"0DWU0JZ" = "1" /* Revision of Synthetic Substitute in Omentum, Open Approach */
"0DWU0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Omentum, Open Approach */
"0DWU37Z" = "1" /* Revision of Autologous Tissue Substitute in Omentum, Percutaneous Approach */
"0DWU3JZ" = "1" /* Revision of Synthetic Substitute in Omentum, Percutaneous Approach */
"0DWU3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Omentum, Percutaneous Approach */
"0DWU47Z" = "1" /* Revision of Autologous Tissue Substitute in Omentum, Percutaneous Endoscopic Approach */
"0DWU4JZ" = "1" /* Revision of Synthetic Substitute in Omentum, Percutaneous Endoscopic Approach */
"0DWU4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Omentum, Percutaneous Endoscopic Approach */
"0DWV07Z" = "1" /* Revision of Autologous Tissue Substitute in Mesentery, Open Approach */
"0DWV0JZ" = "1" /* Revision of Synthetic Substitute in Mesentery, Open Approach */
"0DWV0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mesentery, Open Approach */
"0DWV37Z" = "1" /* Revision of Autologous Tissue Substitute in Mesentery, Percutaneous Approach */
"0DWV3JZ" = "1" /* Revision of Synthetic Substitute in Mesentery, Percutaneous Approach */
"0DWV3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mesentery, Percutaneous Approach */
"0DWV47Z" = "1" /* Revision of Autologous Tissue Substitute in Mesentery, Percutaneous Endoscopic Approach */
"0DWV4JZ" = "1" /* Revision of Synthetic Substitute in Mesentery, Percutaneous Endoscopic Approach */
"0DWV4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mesentery, Percutaneous Endoscopic Approach */
"0DWW07Z" = "1" /* Revision of Autologous Tissue Substitute in Peritoneum, Open Approach */
"0DWW0JZ" = "1" /* Revision of Synthetic Substitute in Peritoneum, Open Approach */
"0DWW0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Peritoneum, Open Approach */
"0DWW37Z" = "1" /* Revision of Autologous Tissue Substitute in Peritoneum, Percutaneous Approach */
"0DWW3JZ" = "1" /* Revision of Synthetic Substitute in Peritoneum, Percutaneous Approach */
"0DWW3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Peritoneum, Percutaneous Approach */
"0DWW47Z" = "1" /* Revision of Autologous Tissue Substitute in Peritoneum, Percutaneous Endoscopic Approach */
"0DWW4JZ" = "1" /* Revision of Synthetic Substitute in Peritoneum, Percutaneous Endoscopic Approach */
"0DWW4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Peritoneum, Percutaneous Endoscopic Approach */
"0DX60Z5" = "1" /* Transfer Stomach to Esophagus, Open Approach */
"0DX64Z5" = "1" /* Transfer Stomach to Esophagus, Percutaneous Endoscopic Approach */
"0DX80Z5" = "1" /* Transfer Small Intestine to Esophagus, Open Approach */
"0DX84Z5" = "1" /* Transfer Small Intestine to Esophagus, Percutaneous Endoscopic Approach */
"0DXE0Z5" = "1" /* Transfer Large Intestine to Esophagus, Open Approach */
"0DXE4Z5" = "1" /* Transfer Large Intestine to Esophagus, Percutaneous Endoscopic Approach */
"0DY60Z0" = "1" /* Transplantation of Stomach, Allogeneic, Open Approach */
"0DY60Z1" = "1" /* Transplantation of Stomach, Syngeneic, Open Approach */
"0DY60Z2" = "1" /* Transplantation of Stomach, Zooplastic, Open Approach */
"0DY80Z0" = "1" /* Transplantation of Small Intestine, Allogeneic, Open Approach */
"0DY80Z1" = "1" /* Transplantation of Small Intestine, Syngeneic, Open Approach */
"0DY80Z2" = "1" /* Transplantation of Small Intestine, Zooplastic, Open Approach */
"0DYE0Z0" = "1" /* Transplantation of Large Intestine, Allogeneic, Open Approach */
"0DYE0Z1" = "1" /* Transplantation of Large Intestine, Syngeneic, Open Approach */
"0DYE0Z2" = "1" /* Transplantation of Large Intestine, Zooplastic, Open Approach */
"0F140D3" = "1" /* Bypass Gallbladder to Duodenum with Intraluminal Device, Open Approach */
"0F140D4" = "1" /* Bypass Gallbladder to Stomach with Intraluminal Device, Open Approach */
"0F140D5" = "1" /* Bypass Gallbladder to Right Hepatic Duct with Intraluminal Device, Open Approach */
"0F140D6" = "1" /* Bypass Gallbladder to Left Hepatic Duct with Intraluminal Device, Open Approach */
"0F140D7" = "1" /* Bypass Gallbladder to Caudate Hepatic Duct with Intraluminal Device, Open Approach */
"0F140D8" = "1" /* Bypass Gallbladder to Cystic Duct with Intraluminal Device, Open Approach */
"0F140D9" = "1" /* Bypass Gallbladder to Common Bile Duct with Intraluminal Device, Open Approach */
"0F140DB" = "1" /* Bypass Gallbladder to Small Intestine with Intraluminal Device, Open Approach */
"0F140Z3" = "1" /* Bypass Gallbladder to Duodenum, Open Approach */
"0F140Z4" = "1" /* Bypass Gallbladder to Stomach, Open Approach */
"0F140Z5" = "1" /* Bypass Gallbladder to Right Hepatic Duct, Open Approach */
"0F140Z6" = "1" /* Bypass Gallbladder to Left Hepatic Duct, Open Approach */
"0F140Z7" = "1" /* Bypass Gallbladder to Caudate Hepatic Duct, Open Approach */
"0F140Z8" = "1" /* Bypass Gallbladder to Cystic Duct, Open Approach */
"0F140Z9" = "1" /* Bypass Gallbladder to Common Bile Duct, Open Approach */
"0F140ZB" = "1" /* Bypass Gallbladder to Small Intestine, Open Approach */
"0F144D3" = "1" /* Bypass Gallbladder to Duodenum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F144D4" = "1" /* Bypass Gallbladder to Stomach with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F144D5" = "1" /* Bypass Gallbladder to Right Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F144D6" = "1" /* Bypass Gallbladder to Left Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F144D7" = "1" /* Bypass Gallbladder to Caudate Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F144D8" = "1" /* Bypass Gallbladder to Cystic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F144D9" = "1" /* Bypass Gallbladder to Common Bile Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F144DB" = "1" /* Bypass Gallbladder to Small Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F144Z3" = "1" /* Bypass Gallbladder to Duodenum, Percutaneous Endoscopic Approach */
"0F144Z4" = "1" /* Bypass Gallbladder to Stomach, Percutaneous Endoscopic Approach */
"0F144Z5" = "1" /* Bypass Gallbladder to Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0F144Z6" = "1" /* Bypass Gallbladder to Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0F144Z7" = "1" /* Bypass Gallbladder to Caudate Hepatic Duct, Percutaneous Endoscopic Approach */
"0F144Z8" = "1" /* Bypass Gallbladder to Cystic Duct, Percutaneous Endoscopic Approach */
"0F144Z9" = "1" /* Bypass Gallbladder to Common Bile Duct, Percutaneous Endoscopic Approach */
"0F144ZB" = "1" /* Bypass Gallbladder to Small Intestine, Percutaneous Endoscopic Approach */
"0F150D3" = "1" /* Bypass Right Hepatic Duct to Duodenum with Intraluminal Device, Open Approach */
"0F150D4" = "1" /* Bypass Right Hepatic Duct to Stomach with Intraluminal Device, Open Approach */
"0F150D5" = "1" /* Bypass Right Hepatic Duct to Right Hepatic Duct with Intraluminal Device, Open Approach */
"0F150D6" = "1" /* Bypass Right Hepatic Duct to Left Hepatic Duct with Intraluminal Device, Open Approach */
"0F150D7" = "1" /* Bypass Right Hepatic Duct to Caudate Hepatic Duct with Intraluminal Device, Open Approach */
"0F150D8" = "1" /* Bypass Right Hepatic Duct to Cystic Duct with Intraluminal Device, Open Approach */
"0F150D9" = "1" /* Bypass Right Hepatic Duct to Common Bile Duct with Intraluminal Device, Open Approach */
"0F150DB" = "1" /* Bypass Right Hepatic Duct to Small Intestine with Intraluminal Device, Open Approach */
"0F150Z3" = "1" /* Bypass Right Hepatic Duct to Duodenum, Open Approach */
"0F150Z4" = "1" /* Bypass Right Hepatic Duct to Stomach, Open Approach */
"0F150Z5" = "1" /* Bypass Right Hepatic Duct to Right Hepatic Duct, Open Approach */
"0F150Z6" = "1" /* Bypass Right Hepatic Duct to Left Hepatic Duct, Open Approach */
"0F150Z7" = "1" /* Bypass Right Hepatic Duct to Caudate Hepatic Duct, Open Approach */
"0F150Z8" = "1" /* Bypass Right Hepatic Duct to Cystic Duct, Open Approach */
"0F150Z9" = "1" /* Bypass Right Hepatic Duct to Common Bile Duct, Open Approach */
"0F150ZB" = "1" /* Bypass Right Hepatic Duct to Small Intestine, Open Approach */
"0F154D3" = "1" /* Bypass Right Hepatic Duct to Duodenum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F154D4" = "1" /* Bypass Right Hepatic Duct to Stomach with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F154D5" = "1" /* Bypass Right Hepatic Duct to Right Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F154D6" = "1" /* Bypass Right Hepatic Duct to Left Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F154D7" = "1" /* Bypass Right Hepatic Duct to Caudate Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F154D8" = "1" /* Bypass Right Hepatic Duct to Cystic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F154D9" = "1" /* Bypass Right Hepatic Duct to Common Bile Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F154DB" = "1" /* Bypass Right Hepatic Duct to Small Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F154Z3" = "1" /* Bypass Right Hepatic Duct to Duodenum, Percutaneous Endoscopic Approach */
"0F154Z4" = "1" /* Bypass Right Hepatic Duct to Stomach, Percutaneous Endoscopic Approach */
"0F154Z5" = "1" /* Bypass Right Hepatic Duct to Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0F154Z6" = "1" /* Bypass Right Hepatic Duct to Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0F154Z7" = "1" /* Bypass Right Hepatic Duct to Caudate Hepatic Duct, Percutaneous Endoscopic Approach */
"0F154Z8" = "1" /* Bypass Right Hepatic Duct to Cystic Duct, Percutaneous Endoscopic Approach */
"0F154Z9" = "1" /* Bypass Right Hepatic Duct to Common Bile Duct, Percutaneous Endoscopic Approach */
"0F154ZB" = "1" /* Bypass Right Hepatic Duct to Small Intestine, Percutaneous Endoscopic Approach */
"0F160D3" = "1" /* Bypass Left Hepatic Duct to Duodenum with Intraluminal Device, Open Approach */
"0F160D4" = "1" /* Bypass Left Hepatic Duct to Stomach with Intraluminal Device, Open Approach */
"0F160D5" = "1" /* Bypass Left Hepatic Duct to Right Hepatic Duct with Intraluminal Device, Open Approach */
"0F160D6" = "1" /* Bypass Left Hepatic Duct to Left Hepatic Duct with Intraluminal Device, Open Approach */
"0F160D7" = "1" /* Bypass Left Hepatic Duct to Caudate Hepatic Duct with Intraluminal Device, Open Approach */
"0F160D8" = "1" /* Bypass Left Hepatic Duct to Cystic Duct with Intraluminal Device, Open Approach */
"0F160D9" = "1" /* Bypass Left Hepatic Duct to Common Bile Duct with Intraluminal Device, Open Approach */
"0F160DB" = "1" /* Bypass Left Hepatic Duct to Small Intestine with Intraluminal Device, Open Approach */
"0F160Z3" = "1" /* Bypass Left Hepatic Duct to Duodenum, Open Approach */
"0F160Z4" = "1" /* Bypass Left Hepatic Duct to Stomach, Open Approach */
"0F160Z5" = "1" /* Bypass Left Hepatic Duct to Right Hepatic Duct, Open Approach */
"0F160Z6" = "1" /* Bypass Left Hepatic Duct to Left Hepatic Duct, Open Approach */
"0F160Z7" = "1" /* Bypass Left Hepatic Duct to Caudate Hepatic Duct, Open Approach */
"0F160Z8" = "1" /* Bypass Left Hepatic Duct to Cystic Duct, Open Approach */
"0F160Z9" = "1" /* Bypass Left Hepatic Duct to Common Bile Duct, Open Approach */
"0F160ZB" = "1" /* Bypass Left Hepatic Duct to Small Intestine, Open Approach */
"0F164D3" = "1" /* Bypass Left Hepatic Duct to Duodenum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F164D4" = "1" /* Bypass Left Hepatic Duct to Stomach with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F164D5" = "1" /* Bypass Left Hepatic Duct to Right Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F164D6" = "1" /* Bypass Left Hepatic Duct to Left Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F164D7" = "1" /* Bypass Left Hepatic Duct to Caudate Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F164D8" = "1" /* Bypass Left Hepatic Duct to Cystic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F164D9" = "1" /* Bypass Left Hepatic Duct to Common Bile Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F164DB" = "1" /* Bypass Left Hepatic Duct to Small Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F164Z3" = "1" /* Bypass Left Hepatic Duct to Duodenum, Percutaneous Endoscopic Approach */
"0F164Z4" = "1" /* Bypass Left Hepatic Duct to Stomach, Percutaneous Endoscopic Approach */
"0F164Z5" = "1" /* Bypass Left Hepatic Duct to Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0F164Z6" = "1" /* Bypass Left Hepatic Duct to Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0F164Z7" = "1" /* Bypass Left Hepatic Duct to Caudate Hepatic Duct, Percutaneous Endoscopic Approach */
"0F164Z8" = "1" /* Bypass Left Hepatic Duct to Cystic Duct, Percutaneous Endoscopic Approach */
"0F164Z9" = "1" /* Bypass Left Hepatic Duct to Common Bile Duct, Percutaneous Endoscopic Approach */
"0F164ZB" = "1" /* Bypass Left Hepatic Duct to Small Intestine, Percutaneous Endoscopic Approach */
"0F180D3" = "1" /* Bypass Cystic Duct to Duodenum with Intraluminal Device, Open Approach */
"0F180D4" = "1" /* Bypass Cystic Duct to Stomach with Intraluminal Device, Open Approach */
"0F180D5" = "1" /* Bypass Cystic Duct to Right Hepatic Duct with Intraluminal Device, Open Approach */
"0F180D6" = "1" /* Bypass Cystic Duct to Left Hepatic Duct with Intraluminal Device, Open Approach */
"0F180D7" = "1" /* Bypass Cystic Duct to Caudate Hepatic Duct with Intraluminal Device, Open Approach */
"0F180D8" = "1" /* Bypass Cystic Duct to Cystic Duct with Intraluminal Device, Open Approach */
"0F180D9" = "1" /* Bypass Cystic Duct to Common Bile Duct with Intraluminal Device, Open Approach */
"0F180DB" = "1" /* Bypass Cystic Duct to Small Intestine with Intraluminal Device, Open Approach */
"0F180Z3" = "1" /* Bypass Cystic Duct to Duodenum, Open Approach */
"0F180Z4" = "1" /* Bypass Cystic Duct to Stomach, Open Approach */
"0F180Z5" = "1" /* Bypass Cystic Duct to Right Hepatic Duct, Open Approach */
"0F180Z6" = "1" /* Bypass Cystic Duct to Left Hepatic Duct, Open Approach */
"0F180Z7" = "1" /* Bypass Cystic Duct to Caudate Hepatic Duct, Open Approach */
"0F180Z8" = "1" /* Bypass Cystic Duct to Cystic Duct, Open Approach */
"0F180Z9" = "1" /* Bypass Cystic Duct to Common Bile Duct, Open Approach */
"0F180ZB" = "1" /* Bypass Cystic Duct to Small Intestine, Open Approach */
"0F184D3" = "1" /* Bypass Cystic Duct to Duodenum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F184D4" = "1" /* Bypass Cystic Duct to Stomach with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F184D5" = "1" /* Bypass Cystic Duct to Right Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F184D6" = "1" /* Bypass Cystic Duct to Left Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F184D7" = "1" /* Bypass Cystic Duct to Caudate Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F184D8" = "1" /* Bypass Cystic Duct to Cystic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F184D9" = "1" /* Bypass Cystic Duct to Common Bile Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F184DB" = "1" /* Bypass Cystic Duct to Small Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F184Z3" = "1" /* Bypass Cystic Duct to Duodenum, Percutaneous Endoscopic Approach */
"0F184Z4" = "1" /* Bypass Cystic Duct to Stomach, Percutaneous Endoscopic Approach */
"0F184Z5" = "1" /* Bypass Cystic Duct to Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0F184Z6" = "1" /* Bypass Cystic Duct to Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0F184Z7" = "1" /* Bypass Cystic Duct to Caudate Hepatic Duct, Percutaneous Endoscopic Approach */
"0F184Z8" = "1" /* Bypass Cystic Duct to Cystic Duct, Percutaneous Endoscopic Approach */
"0F184Z9" = "1" /* Bypass Cystic Duct to Common Bile Duct, Percutaneous Endoscopic Approach */
"0F184ZB" = "1" /* Bypass Cystic Duct to Small Intestine, Percutaneous Endoscopic Approach */
"0F190D3" = "1" /* Bypass Common Bile Duct to Duodenum with Intraluminal Device, Open Approach */
"0F190D4" = "1" /* Bypass Common Bile Duct to Stomach with Intraluminal Device, Open Approach */
"0F190D5" = "1" /* Bypass Common Bile Duct to Right Hepatic Duct with Intraluminal Device, Open Approach */
"0F190D6" = "1" /* Bypass Common Bile Duct to Left Hepatic Duct with Intraluminal Device, Open Approach */
"0F190D7" = "1" /* Bypass Common Bile Duct to Caudate Hepatic Duct with Intraluminal Device, Open Approach */
"0F190D8" = "1" /* Bypass Common Bile Duct to Cystic Duct with Intraluminal Device, Open Approach */
"0F190D9" = "1" /* Bypass Common Bile Duct to Common Bile Duct with Intraluminal Device, Open Approach */
"0F190DB" = "1" /* Bypass Common Bile Duct to Small Intestine with Intraluminal Device, Open Approach */
"0F190Z3" = "1" /* Bypass Common Bile Duct to Duodenum, Open Approach */
"0F190Z4" = "1" /* Bypass Common Bile Duct to Stomach, Open Approach */
"0F190Z5" = "1" /* Bypass Common Bile Duct to Right Hepatic Duct, Open Approach */
"0F190Z6" = "1" /* Bypass Common Bile Duct to Left Hepatic Duct, Open Approach */
"0F190Z7" = "1" /* Bypass Common Bile Duct to Caudate Hepatic Duct, Open Approach */
"0F190Z8" = "1" /* Bypass Common Bile Duct to Cystic Duct, Open Approach */
"0F190Z9" = "1" /* Bypass Common Bile Duct to Common Bile Duct, Open Approach */
"0F190ZB" = "1" /* Bypass Common Bile Duct to Small Intestine, Open Approach */
"0F194D3" = "1" /* Bypass Common Bile Duct to Duodenum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F194D4" = "1" /* Bypass Common Bile Duct to Stomach with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F194D5" = "1" /* Bypass Common Bile Duct to Right Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F194D6" = "1" /* Bypass Common Bile Duct to Left Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F194D7" = "1" /* Bypass Common Bile Duct to Caudate Hepatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F194D8" = "1" /* Bypass Common Bile Duct to Cystic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F194D9" = "1" /* Bypass Common Bile Duct to Common Bile Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F194DB" = "1" /* Bypass Common Bile Duct to Small Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F194Z3" = "1" /* Bypass Common Bile Duct to Duodenum, Percutaneous Endoscopic Approach */
"0F194Z4" = "1" /* Bypass Common Bile Duct to Stomach, Percutaneous Endoscopic Approach */
"0F194Z5" = "1" /* Bypass Common Bile Duct to Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0F194Z6" = "1" /* Bypass Common Bile Duct to Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0F194Z7" = "1" /* Bypass Common Bile Duct to Caudate Hepatic Duct, Percutaneous Endoscopic Approach */
"0F194Z8" = "1" /* Bypass Common Bile Duct to Cystic Duct, Percutaneous Endoscopic Approach */
"0F194Z9" = "1" /* Bypass Common Bile Duct to Common Bile Duct, Percutaneous Endoscopic Approach */
"0F194ZB" = "1" /* Bypass Common Bile Duct to Small Intestine, Percutaneous Endoscopic Approach */
"0F1D0D3" = "1" /* Bypass Pancreatic Duct to Duodenum with Intraluminal Device, Open Approach */
"0F1D0DB" = "1" /* Bypass Pancreatic Duct to Small Intestine with Intraluminal Device, Open Approach */
"0F1D0DC" = "1" /* Bypass Pancreatic Duct to Large Intestine with Intraluminal Device, Open Approach */
"0F1D0Z3" = "1" /* Bypass Pancreatic Duct to Duodenum, Open Approach */
"0F1D0ZB" = "1" /* Bypass Pancreatic Duct to Small Intestine, Open Approach */
"0F1D0ZC" = "1" /* Bypass Pancreatic Duct to Large Intestine, Open Approach */
"0F1D4D3" = "1" /* Bypass Pancreatic Duct to Duodenum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F1D4DB" = "1" /* Bypass Pancreatic Duct to Small Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F1D4DC" = "1" /* Bypass Pancreatic Duct to Large Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F1D4Z3" = "1" /* Bypass Pancreatic Duct to Duodenum, Percutaneous Endoscopic Approach */
"0F1D4ZB" = "1" /* Bypass Pancreatic Duct to Small Intestine, Percutaneous Endoscopic Approach */
"0F1D4ZC" = "1" /* Bypass Pancreatic Duct to Large Intestine, Percutaneous Endoscopic Approach */
"0F1F0D3" = "1" /* Bypass Accessory Pancreatic Duct to Duodenum with Intraluminal Device, Open Approach */
"0F1F0DB" = "1" /* Bypass Accessory Pancreatic Duct to Small Intestine with Intraluminal Device, Open Approach */
"0F1F0DC" = "1" /* Bypass Accessory Pancreatic Duct to Large Intestine with Intraluminal Device, Open Approach */
"0F1F0Z3" = "1" /* Bypass Accessory Pancreatic Duct to Duodenum, Open Approach */
"0F1F0ZB" = "1" /* Bypass Accessory Pancreatic Duct to Small Intestine, Open Approach */
"0F1F0ZC" = "1" /* Bypass Accessory Pancreatic Duct to Large Intestine, Open Approach */
"0F1F4D3" = "1" /* Bypass Accessory Pancreatic Duct to Duodenum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F1F4DB" = "1" /* Bypass Accessory Pancreatic Duct to Small Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F1F4DC" = "1" /* Bypass Accessory Pancreatic Duct to Large Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F1F4Z3" = "1" /* Bypass Accessory Pancreatic Duct to Duodenum, Percutaneous Endoscopic Approach */
"0F1F4ZB" = "1" /* Bypass Accessory Pancreatic Duct to Small Intestine, Percutaneous Endoscopic Approach */
"0F1F4ZC" = "1" /* Bypass Accessory Pancreatic Duct to Large Intestine, Percutaneous Endoscopic Approach */
"0F1G0D3" = "1" /* Bypass Pancreas to Duodenum with Intraluminal Device, Open Approach */
"0F1G0DB" = "1" /* Bypass Pancreas to Small Intestine with Intraluminal Device, Open Approach */
"0F1G0DC" = "1" /* Bypass Pancreas to Large Intestine with Intraluminal Device, Open Approach */
"0F1G0Z3" = "1" /* Bypass Pancreas to Duodenum, Open Approach */
"0F1G0ZB" = "1" /* Bypass Pancreas to Small Intestine, Open Approach */
"0F1G0ZC" = "1" /* Bypass Pancreas to Large Intestine, Open Approach */
"0F1G4D3" = "1" /* Bypass Pancreas to Duodenum with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F1G4DB" = "1" /* Bypass Pancreas to Small Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F1G4DC" = "1" /* Bypass Pancreas to Large Intestine with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F1G4Z3" = "1" /* Bypass Pancreas to Duodenum, Percutaneous Endoscopic Approach */
"0F1G4ZB" = "1" /* Bypass Pancreas to Small Intestine, Percutaneous Endoscopic Approach */
"0F1G4ZC" = "1" /* Bypass Pancreas to Large Intestine, Percutaneous Endoscopic Approach */
"0F500ZZ" = "1" /* Destruction of Liver, Open Approach */
"0F503ZZ" = "1" /* Destruction of Liver, Percutaneous Approach */
"0F504ZZ" = "1" /* Destruction of Liver, Percutaneous Endoscopic Approach */
"0F510ZZ" = "1" /* Destruction of Right Lobe Liver, Open Approach */
"0F513ZZ" = "1" /* Destruction of Right Lobe Liver, Percutaneous Approach */
"0F514ZZ" = "1" /* Destruction of Right Lobe Liver, Percutaneous Endoscopic Approach */
"0F520ZZ" = "1" /* Destruction of Left Lobe Liver, Open Approach */
"0F523ZZ" = "1" /* Destruction of Left Lobe Liver, Percutaneous Approach */
"0F524ZZ" = "1" /* Destruction of Left Lobe Liver, Percutaneous Endoscopic Approach */
"0F540ZZ" = "1" /* Destruction of Gallbladder, Open Approach */
"0F543ZZ" = "1" /* Destruction of Gallbladder, Percutaneous Approach */
"0F544ZZ" = "1" /* Destruction of Gallbladder, Percutaneous Endoscopic Approach */
"0F550ZZ" = "1" /* Destruction of Right Hepatic Duct, Open Approach */
"0F553ZZ" = "1" /* Destruction of Right Hepatic Duct, Percutaneous Approach */
"0F557ZZ" = "1" /* Destruction of Right Hepatic Duct, Via Natural or Artificial Opening */
"0F560ZZ" = "1" /* Destruction of Left Hepatic Duct, Open Approach */
"0F563ZZ" = "1" /* Destruction of Left Hepatic Duct, Percutaneous Approach */
"0F567ZZ" = "1" /* Destruction of Left Hepatic Duct, Via Natural or Artificial Opening */
"0F580ZZ" = "1" /* Destruction of Cystic Duct, Open Approach */
"0F583ZZ" = "1" /* Destruction of Cystic Duct, Percutaneous Approach */
"0F587ZZ" = "1" /* Destruction of Cystic Duct, Via Natural or Artificial Opening */
"0F590ZZ" = "1" /* Destruction of Common Bile Duct, Open Approach */
"0F593ZZ" = "1" /* Destruction of Common Bile Duct, Percutaneous Approach */
"0F597ZZ" = "1" /* Destruction of Common Bile Duct, Via Natural or Artificial Opening */
"0F5C0ZZ" = "1" /* Destruction of Ampulla of Vater, Open Approach */
"0F5C3ZZ" = "1" /* Destruction of Ampulla of Vater, Percutaneous Approach */
"0F5C7ZZ" = "1" /* Destruction of Ampulla of Vater, Via Natural or Artificial Opening */
"0F5D0ZZ" = "1" /* Destruction of Pancreatic Duct, Open Approach */
"0F5D3ZZ" = "1" /* Destruction of Pancreatic Duct, Percutaneous Approach */
"0F5D7ZZ" = "1" /* Destruction of Pancreatic Duct, Via Natural or Artificial Opening */
"0F5F0ZZ" = "1" /* Destruction of Accessory Pancreatic Duct, Open Approach */
"0F5F3ZZ" = "1" /* Destruction of Accessory Pancreatic Duct, Percutaneous Approach */
"0F5F7ZZ" = "1" /* Destruction of Accessory Pancreatic Duct, Via Natural or Artificial Opening */
"0F5G0ZZ" = "1" /* Destruction of Pancreas, Open Approach */
"0F5G3ZZ" = "1" /* Destruction of Pancreas, Percutaneous Approach */
"0F750DZ" = "1" /* Dilation of Right Hepatic Duct with Intraluminal Device, Open Approach */
"0F750ZZ" = "1" /* Dilation of Right Hepatic Duct, Open Approach */
"0F757ZZ" = "1" /* Dilation of Right Hepatic Duct, Via Natural or Artificial Opening */
"0F760DZ" = "1" /* Dilation of Left Hepatic Duct with Intraluminal Device, Open Approach */
"0F760ZZ" = "1" /* Dilation of Left Hepatic Duct, Open Approach */
"0F767ZZ" = "1" /* Dilation of Left Hepatic Duct, Via Natural or Artificial Opening */
"0F780DZ" = "1" /* Dilation of Cystic Duct with Intraluminal Device, Open Approach */
"0F780ZZ" = "1" /* Dilation of Cystic Duct, Open Approach */
"0F787ZZ" = "1" /* Dilation of Cystic Duct, Via Natural or Artificial Opening */
"0F790DZ" = "1" /* Dilation of Common Bile Duct with Intraluminal Device, Open Approach */
"0F790ZZ" = "1" /* Dilation of Common Bile Duct, Open Approach */
"0F797ZZ" = "1" /* Dilation of Common Bile Duct, Via Natural or Artificial Opening */
"0F7C0DZ" = "1" /* Dilation of Ampulla of Vater with Intraluminal Device, Open Approach */
"0F7C0ZZ" = "1" /* Dilation of Ampulla of Vater, Open Approach */
"0F7C3DZ" = "1" /* Dilation of Ampulla of Vater with Intraluminal Device, Percutaneous Approach */
"0F7C3ZZ" = "1" /* Dilation of Ampulla of Vater, Percutaneous Approach */
"0F7C4DZ" = "1" /* Dilation of Ampulla of Vater with Intraluminal Device, Percutaneous Endoscopic Approach */
"0F7C4ZZ" = "1" /* Dilation of Ampulla of Vater, Percutaneous Endoscopic Approach */
"0F7C7DZ" = "1" /* Dilation of Ampulla of Vater with Intraluminal Device, Via Natural or Artificial Opening */
"0F7C7ZZ" = "1" /* Dilation of Ampulla of Vater, Via Natural or Artificial Opening */
"0F7D0DZ" = "1" /* Dilation of Pancreatic Duct with Intraluminal Device, Open Approach */
"0F7D0ZZ" = "1" /* Dilation of Pancreatic Duct, Open Approach */
"0F7D3DZ" = "1" /* Dilation of Pancreatic Duct with Intraluminal Device, Percutaneous Approach */
"0F7D3ZZ" = "1" /* Dilation of Pancreatic Duct, Percutaneous Approach */
"0F7D7ZZ" = "1" /* Dilation of Pancreatic Duct, Via Natural or Artificial Opening */
"0F7F0DZ" = "1" /* Dilation of Accessory Pancreatic Duct with Intraluminal Device, Open Approach */
"0F7F0ZZ" = "1" /* Dilation of Accessory Pancreatic Duct, Open Approach */
"0F7F3DZ" = "1" /* Dilation of Accessory Pancreatic Duct with Intraluminal Device, Percutaneous Approach */
"0F7F3ZZ" = "1" /* Dilation of Accessory Pancreatic Duct, Percutaneous Approach */
"0F7F7DZ" = "1" /* Dilation of Accessory Pancreatic Duct with Intraluminal Device, Via Natural or Artificial Opening */
"0F7F7ZZ" = "1" /* Dilation of Accessory Pancreatic Duct, Via Natural or Artificial Opening */
"0F8G0ZZ" = "1" /* Division of Pancreas, Open Approach */
"0F8G3ZZ" = "1" /* Division of Pancreas, Percutaneous Approach */
"0F8G4ZZ" = "1" /* Division of Pancreas, Percutaneous Endoscopic Approach */
"0F9000Z" = "1" /* Drainage of Liver with Drainage Device, Open Approach */
"0F900ZX" = "1" /* Drainage of Liver, Open Approach, Diagnostic */
"0F900ZZ" = "1" /* Drainage of Liver, Open Approach */
"0F9100Z" = "1" /* Drainage of Right Lobe Liver with Drainage Device, Open Approach */
"0F910ZX" = "1" /* Drainage of Right Lobe Liver, Open Approach, Diagnostic */
"0F910ZZ" = "1" /* Drainage of Right Lobe Liver, Open Approach */
"0F9200Z" = "1" /* Drainage of Left Lobe Liver with Drainage Device, Open Approach */
"0F920ZX" = "1" /* Drainage of Left Lobe Liver, Open Approach, Diagnostic */
"0F920ZZ" = "1" /* Drainage of Left Lobe Liver, Open Approach */
"0F9400Z" = "1" /* Drainage of Gallbladder with Drainage Device, Open Approach */
"0F940ZX" = "1" /* Drainage of Gallbladder, Open Approach, Diagnostic */
"0F940ZZ" = "1" /* Drainage of Gallbladder, Open Approach */
"0F9500Z" = "1" /* Drainage of Right Hepatic Duct with Drainage Device, Open Approach */
"0F950ZX" = "1" /* Drainage of Right Hepatic Duct, Open Approach, Diagnostic */
"0F950ZZ" = "1" /* Drainage of Right Hepatic Duct, Open Approach */
"0F9540Z" = "1" /* Drainage of Right Hepatic Duct with Drainage Device, Percutaneous Endoscopic Approach */
"0F954ZZ" = "1" /* Drainage of Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0F9570Z" = "1" /* Drainage of Right Hepatic Duct with Drainage Device, Via Natural or Artificial Opening */
"0F957ZZ" = "1" /* Drainage of Right Hepatic Duct, Via Natural or Artificial Opening */
"0F9600Z" = "1" /* Drainage of Left Hepatic Duct with Drainage Device, Open Approach */
"0F960ZX" = "1" /* Drainage of Left Hepatic Duct, Open Approach, Diagnostic */
"0F960ZZ" = "1" /* Drainage of Left Hepatic Duct, Open Approach */
"0F9640Z" = "1" /* Drainage of Left Hepatic Duct with Drainage Device, Percutaneous Endoscopic Approach */
"0F964ZZ" = "1" /* Drainage of Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0F9670Z" = "1" /* Drainage of Left Hepatic Duct with Drainage Device, Via Natural or Artificial Opening */
"0F967ZZ" = "1" /* Drainage of Left Hepatic Duct, Via Natural or Artificial Opening */
"0F9800Z" = "1" /* Drainage of Cystic Duct with Drainage Device, Open Approach */
"0F980ZX" = "1" /* Drainage of Cystic Duct, Open Approach, Diagnostic */
"0F980ZZ" = "1" /* Drainage of Cystic Duct, Open Approach */
"0F9840Z" = "1" /* Drainage of Cystic Duct with Drainage Device, Percutaneous Endoscopic Approach */
"0F984ZZ" = "1" /* Drainage of Cystic Duct, Percutaneous Endoscopic Approach */
"0F9870Z" = "1" /* Drainage of Cystic Duct with Drainage Device, Via Natural or Artificial Opening */
"0F987ZZ" = "1" /* Drainage of Cystic Duct, Via Natural or Artificial Opening */
"0F9900Z" = "1" /* Drainage of Common Bile Duct with Drainage Device, Open Approach */
"0F990ZX" = "1" /* Drainage of Common Bile Duct, Open Approach, Diagnostic */
"0F990ZZ" = "1" /* Drainage of Common Bile Duct, Open Approach */
"0F9940Z" = "1" /* Drainage of Common Bile Duct with Drainage Device, Percutaneous Endoscopic Approach */
"0F9970Z" = "1" /* Drainage of Common Bile Duct with Drainage Device, Via Natural or Artificial Opening */
"0F9C00Z" = "1" /* Drainage of Ampulla of Vater with Drainage Device, Open Approach */
"0F9C0ZX" = "1" /* Drainage of Ampulla of Vater, Open Approach, Diagnostic */
"0F9C0ZZ" = "1" /* Drainage of Ampulla of Vater, Open Approach */
"0F9C70Z" = "1" /* Drainage of Ampulla of Vater with Drainage Device, Via Natural or Artificial Opening */
"0F9C7ZZ" = "1" /* Drainage of Ampulla of Vater, Via Natural or Artificial Opening */
"0F9D00Z" = "1" /* Drainage of Pancreatic Duct with Drainage Device, Open Approach */
"0F9D0ZX" = "1" /* Drainage of Pancreatic Duct, Open Approach, Diagnostic */
"0F9D0ZZ" = "1" /* Drainage of Pancreatic Duct, Open Approach */
"0F9D40Z" = "1" /* Drainage of Pancreatic Duct with Drainage Device, Percutaneous Endoscopic Approach */
"0F9D4ZZ" = "1" /* Drainage of Pancreatic Duct, Percutaneous Endoscopic Approach */
"0F9D70Z" = "1" /* Drainage of Pancreatic Duct with Drainage Device, Via Natural or Artificial Opening */
"0F9D7ZZ" = "1" /* Drainage of Pancreatic Duct, Via Natural or Artificial Opening */
"0F9F00Z" = "1" /* Drainage of Accessory Pancreatic Duct with Drainage Device, Open Approach */
"0F9F0ZX" = "1" /* Drainage of Accessory Pancreatic Duct, Open Approach, Diagnostic */
"0F9F0ZZ" = "1" /* Drainage of Accessory Pancreatic Duct, Open Approach */
"0F9F40Z" = "1" /* Drainage of Accessory Pancreatic Duct with Drainage Device, Percutaneous Endoscopic Approach */
"0F9F4ZZ" = "1" /* Drainage of Accessory Pancreatic Duct, Percutaneous Endoscopic Approach */
"0F9F70Z" = "1" /* Drainage of Accessory Pancreatic Duct with Drainage Device, Via Natural or Artificial Opening */
"0F9F7ZZ" = "1" /* Drainage of Accessory Pancreatic Duct, Via Natural or Artificial Opening */
"0F9G00Z" = "1" /* Drainage of Pancreas with Drainage Device, Open Approach */
"0F9G0ZX" = "1" /* Drainage of Pancreas, Open Approach, Diagnostic */
"0F9G0ZZ" = "1" /* Drainage of Pancreas, Open Approach */
"0F9G40Z" = "1" /* Drainage of Pancreas with Drainage Device, Percutaneous Endoscopic Approach */
"0F9G4ZZ" = "1" /* Drainage of Pancreas, Percutaneous Endoscopic Approach */
"0FB00ZX" = "1" /* Excision of Liver, Open Approach, Diagnostic */
"0FB00ZZ" = "1" /* Excision of Liver, Open Approach */
"0FB03ZZ" = "1" /* Excision of Liver, Percutaneous Approach */
"0FB04ZX" = "1" /* Excision of Liver, Percutaneous Endoscopic Approach, Diagnostic */
"0FB04ZZ" = "1" /* Excision of Liver, Percutaneous Endoscopic Approach */
"0FB10ZX" = "1" /* Excision of Right Lobe Liver, Open Approach, Diagnostic */
"0FB10ZZ" = "1" /* Excision of Right Lobe Liver, Open Approach */
"0FB13ZZ" = "1" /* Excision of Right Lobe Liver, Percutaneous Approach */
"0FB14ZX" = "1" /* Excision of Right Lobe Liver, Percutaneous Endoscopic Approach, Diagnostic */
"0FB14ZZ" = "1" /* Excision of Right Lobe Liver, Percutaneous Endoscopic Approach */
"0FB20ZX" = "1" /* Excision of Left Lobe Liver, Open Approach, Diagnostic */
"0FB20ZZ" = "1" /* Excision of Left Lobe Liver, Open Approach */
"0FB23ZZ" = "1" /* Excision of Left Lobe Liver, Percutaneous Approach */
"0FB24ZX" = "1" /* Excision of Left Lobe Liver, Percutaneous Endoscopic Approach, Diagnostic */
"0FB24ZZ" = "1" /* Excision of Left Lobe Liver, Percutaneous Endoscopic Approach */
"0FB40ZX" = "1" /* Excision of Gallbladder, Open Approach, Diagnostic */
"0FB40ZZ" = "1" /* Excision of Gallbladder, Open Approach */
"0FB43ZZ" = "1" /* Excision of Gallbladder, Percutaneous Approach */
"0FB44ZZ" = "1" /* Excision of Gallbladder, Percutaneous Endoscopic Approach */
"0FB50ZX" = "1" /* Excision of Right Hepatic Duct, Open Approach, Diagnostic */
"0FB50ZZ" = "1" /* Excision of Right Hepatic Duct, Open Approach */
"0FB53ZZ" = "1" /* Excision of Right Hepatic Duct, Percutaneous Approach */
"0FB57ZZ" = "1" /* Excision of Right Hepatic Duct, Via Natural or Artificial Opening */
"0FB60ZX" = "1" /* Excision of Left Hepatic Duct, Open Approach, Diagnostic */
"0FB60ZZ" = "1" /* Excision of Left Hepatic Duct, Open Approach */
"0FB63ZZ" = "1" /* Excision of Left Hepatic Duct, Percutaneous Approach */
"0FB67ZZ" = "1" /* Excision of Left Hepatic Duct, Via Natural or Artificial Opening */
"0FB80ZX" = "1" /* Excision of Cystic Duct, Open Approach, Diagnostic */
"0FB80ZZ" = "1" /* Excision of Cystic Duct, Open Approach */
"0FB83ZZ" = "1" /* Excision of Cystic Duct, Percutaneous Approach */
"0FB87ZZ" = "1" /* Excision of Cystic Duct, Via Natural or Artificial Opening */
"0FB90ZX" = "1" /* Excision of Common Bile Duct, Open Approach, Diagnostic */
"0FB90ZZ" = "1" /* Excision of Common Bile Duct, Open Approach */
"0FB93ZZ" = "1" /* Excision of Common Bile Duct, Percutaneous Approach */
"0FB97ZZ" = "1" /* Excision of Common Bile Duct, Via Natural or Artificial Opening */
"0FBC0ZX" = "1" /* Excision of Ampulla of Vater, Open Approach, Diagnostic */
"0FBC0ZZ" = "1" /* Excision of Ampulla of Vater, Open Approach */
"0FBC3ZZ" = "1" /* Excision of Ampulla of Vater, Percutaneous Approach */
"0FBC7ZZ" = "1" /* Excision of Ampulla of Vater, Via Natural or Artificial Opening */
"0FBD0ZX" = "1" /* Excision of Pancreatic Duct, Open Approach, Diagnostic */
"0FBD0ZZ" = "1" /* Excision of Pancreatic Duct, Open Approach */
"0FBD3ZZ" = "1" /* Excision of Pancreatic Duct, Percutaneous Approach */
"0FBD7ZZ" = "1" /* Excision of Pancreatic Duct, Via Natural or Artificial Opening */
"0FBF0ZX" = "1" /* Excision of Accessory Pancreatic Duct, Open Approach, Diagnostic */
"0FBF0ZZ" = "1" /* Excision of Accessory Pancreatic Duct, Open Approach */
"0FBF3ZZ" = "1" /* Excision of Accessory Pancreatic Duct, Percutaneous Approach */
"0FBF7ZZ" = "1" /* Excision of Accessory Pancreatic Duct, Via Natural or Artificial Opening */
"0FBG0ZX" = "1" /* Excision of Pancreas, Open Approach, Diagnostic */
"0FBG0ZZ" = "1" /* Excision of Pancreas, Open Approach */
"0FBG3ZZ" = "1" /* Excision of Pancreas, Percutaneous Approach */
"0FBG4ZZ" = "1" /* Excision of Pancreas, Percutaneous Endoscopic Approach */
"0FC00ZZ" = "1" /* Extirpation of Matter from Liver, Open Approach */
"0FC03ZZ" = "1" /* Extirpation of Matter from Liver, Percutaneous Approach */
"0FC04ZZ" = "1" /* Extirpation of Matter from Liver, Percutaneous Endoscopic Approach */
"0FC10ZZ" = "1" /* Extirpation of Matter from Right Lobe Liver, Open Approach */
"0FC13ZZ" = "1" /* Extirpation of Matter from Right Lobe Liver, Percutaneous Approach */
"0FC14ZZ" = "1" /* Extirpation of Matter from Right Lobe Liver, Percutaneous Endoscopic Approach */
"0FC20ZZ" = "1" /* Extirpation of Matter from Left Lobe Liver, Open Approach */
"0FC23ZZ" = "1" /* Extirpation of Matter from Left Lobe Liver, Percutaneous Approach */
"0FC24ZZ" = "1" /* Extirpation of Matter from Left Lobe Liver, Percutaneous Endoscopic Approach */
"0FC40ZZ" = "1" /* Extirpation of Matter from Gallbladder, Open Approach */
"0FC43ZZ" = "1" /* Extirpation of Matter from Gallbladder, Percutaneous Approach */
"0FC44ZZ" = "1" /* Extirpation of Matter from Gallbladder, Percutaneous Endoscopic Approach */
"0FC50ZZ" = "1" /* Extirpation of Matter from Right Hepatic Duct, Open Approach */
"0FC60ZZ" = "1" /* Extirpation of Matter from Left Hepatic Duct, Open Approach */
"0FC80ZZ" = "1" /* Extirpation of Matter from Cystic Duct, Open Approach */
"0FC90ZZ" = "1" /* Extirpation of Matter from Common Bile Duct, Open Approach */
"0FCC0ZZ" = "1" /* Extirpation of Matter from Ampulla of Vater, Open Approach */
"0FCC3ZZ" = "1" /* Extirpation of Matter from Ampulla of Vater, Percutaneous Approach */
"0FCC7ZZ" = "1" /* Extirpation of Matter from Ampulla of Vater, Via Natural or Artificial Opening */
"0FCD0ZZ" = "1" /* Extirpation of Matter from Pancreatic Duct, Open Approach */
"0FCD7ZZ" = "1" /* Extirpation of Matter from Pancreatic Duct, Via Natural or Artificial Opening */
"0FCF0ZZ" = "1" /* Extirpation of Matter from Accessory Pancreatic Duct, Open Approach */
"0FCF7ZZ" = "1" /* Extirpation of Matter from Accessory Pancreatic Duct, Via Natural or Artificial Opening */
"0FCG0ZZ" = "1" /* Extirpation of Matter from Pancreas, Open Approach */
"0FCG3ZZ" = "1" /* Extirpation of Matter from Pancreas, Percutaneous Approach */
"0FCG4ZZ" = "1" /* Extirpation of Matter from Pancreas, Percutaneous Endoscopic Approach */
"0FF40ZZ" = "1" /* Fragmentation in Gallbladder, Open Approach */
"0FF43ZZ" = "1" /* Fragmentation in Gallbladder, Percutaneous Approach */
"0FF44ZZ" = "1" /* Fragmentation in Gallbladder, Percutaneous Endoscopic Approach */
"0FF47ZZ" = "1" /* Fragmentation in Gallbladder, Via Natural or Artificial Opening */
"0FF50ZZ" = "1" /* Fragmentation in Right Hepatic Duct, Open Approach */
"0FF53ZZ" = "1" /* Fragmentation in Right Hepatic Duct, Percutaneous Approach */
"0FF54ZZ" = "1" /* Fragmentation in Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0FF57ZZ" = "1" /* Fragmentation in Right Hepatic Duct, Via Natural or Artificial Opening */
"0FF60ZZ" = "1" /* Fragmentation in Left Hepatic Duct, Open Approach */
"0FF63ZZ" = "1" /* Fragmentation in Left Hepatic Duct, Percutaneous Approach */
"0FF64ZZ" = "1" /* Fragmentation in Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0FF67ZZ" = "1" /* Fragmentation in Left Hepatic Duct, Via Natural or Artificial Opening */
"0FF80ZZ" = "1" /* Fragmentation in Cystic Duct, Open Approach */
"0FF83ZZ" = "1" /* Fragmentation in Cystic Duct, Percutaneous Approach */
"0FF84ZZ" = "1" /* Fragmentation in Cystic Duct, Percutaneous Endoscopic Approach */
"0FF87ZZ" = "1" /* Fragmentation in Cystic Duct, Via Natural or Artificial Opening */
"0FF90ZZ" = "1" /* Fragmentation in Common Bile Duct, Open Approach */
"0FF93ZZ" = "1" /* Fragmentation in Common Bile Duct, Percutaneous Approach */
"0FF94ZZ" = "1" /* Fragmentation in Common Bile Duct, Percutaneous Endoscopic Approach */
"0FF97ZZ" = "1" /* Fragmentation in Common Bile Duct, Via Natural or Artificial Opening */
"0FFC0ZZ" = "1" /* Fragmentation in Ampulla of Vater, Open Approach */
"0FFC3ZZ" = "1" /* Fragmentation in Ampulla of Vater, Percutaneous Approach */
"0FFC4ZZ" = "1" /* Fragmentation in Ampulla of Vater, Percutaneous Endoscopic Approach */
"0FFC7ZZ" = "1" /* Fragmentation in Ampulla of Vater, Via Natural or Artificial Opening */
"0FFD0ZZ" = "1" /* Fragmentation in Pancreatic Duct, Open Approach */
"0FFD3ZZ" = "1" /* Fragmentation in Pancreatic Duct, Percutaneous Approach */
"0FFD4ZZ" = "1" /* Fragmentation in Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FFD7ZZ" = "1" /* Fragmentation in Pancreatic Duct, Via Natural or Artificial Opening */
"0FFF0ZZ" = "1" /* Fragmentation in Accessory Pancreatic Duct, Open Approach */
"0FFF3ZZ" = "1" /* Fragmentation in Accessory Pancreatic Duct, Percutaneous Approach */
"0FFF4ZZ" = "1" /* Fragmentation in Accessory Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FFF7ZZ" = "1" /* Fragmentation in Accessory Pancreatic Duct, Via Natural or Artificial Opening */
"0FH002Z" = "1" /* Insertion of Monitoring Device into Liver, Open Approach */
"0FH032Z" = "1" /* Insertion of Monitoring Device into Liver, Percutaneous Approach */
"0FH042Z" = "1" /* Insertion of Monitoring Device into Liver, Percutaneous Endoscopic Approach */
"0FH102Z" = "1" /* Insertion of Monitoring Device into Right Lobe Liver, Open Approach */
"0FH132Z" = "1" /* Insertion of Monitoring Device into Right Lobe Liver, Percutaneous Approach */
"0FH142Z" = "1" /* Insertion of Monitoring Device into Right Lobe Liver, Percutaneous Endoscopic Approach */
"0FH202Z" = "1" /* Insertion of Monitoring Device into Left Lobe Liver, Open Approach */
"0FH232Z" = "1" /* Insertion of Monitoring Device into Left Lobe Liver, Percutaneous Approach */
"0FH242Z" = "1" /* Insertion of Monitoring Device into Left Lobe Liver, Percutaneous Endoscopic Approach */
"0FH402Z" = "1" /* Insertion of Monitoring Device into Gallbladder, Open Approach */
"0FH432Z" = "1" /* Insertion of Monitoring Device into Gallbladder, Percutaneous Approach */
"0FH442Z" = "1" /* Insertion of Monitoring Device into Gallbladder, Percutaneous Endoscopic Approach */
"0FHB01Z" = "1" /* Insertion of Radioactive Element into Hepatobiliary Duct, Open Approach */
"0FHB02Z" = "1" /* Insertion of Monitoring Device into Hepatobiliary Duct, Open Approach */
"0FHB0DZ" = "1" /* Insertion of Intraluminal Device into Hepatobiliary Duct, Open Approach */
"0FHB31Z" = "1" /* Insertion of Radioactive Element into Hepatobiliary Duct, Percutaneous Approach */
"0FHB32Z" = "1" /* Insertion of Monitoring Device into Hepatobiliary Duct, Percutaneous Approach */
"0FHB3DZ" = "1" /* Insertion of Intraluminal Device into Hepatobiliary Duct, Percutaneous Approach */
"0FHB41Z" = "1" /* Insertion of Radioactive Element into Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FHB42Z" = "1" /* Insertion of Monitoring Device into Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FHB71Z" = "1" /* Insertion of Radioactive Element into Hepatobiliary Duct, Via Natural or Artificial Opening */
"0FHB7DZ" = "1" /* Insertion of Intraluminal Device into Hepatobiliary Duct, Via Natural or Artificial Opening */
"0FHB81Z" = "1" /* Insertion of Radioactive Element into Hepatobiliary Duct, Via Natural or Artificial Opening Endoscopic */
"0FHD01Z" = "1" /* Insertion of Radioactive Element into Pancreatic Duct, Open Approach */
"0FHD02Z" = "1" /* Insertion of Monitoring Device into Pancreatic Duct, Open Approach */
"0FHD0DZ" = "1" /* Insertion of Intraluminal Device into Pancreatic Duct, Open Approach */
"0FHD31Z" = "1" /* Insertion of Radioactive Element into Pancreatic Duct, Percutaneous Approach */
"0FHD32Z" = "1" /* Insertion of Monitoring Device into Pancreatic Duct, Percutaneous Approach */
"0FHD3DZ" = "1" /* Insertion of Intraluminal Device into Pancreatic Duct, Percutaneous Approach */
"0FHD41Z" = "1" /* Insertion of Radioactive Element into Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FHD42Z" = "1" /* Insertion of Monitoring Device into Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FHD71Z" = "1" /* Insertion of Radioactive Element into Pancreatic Duct, Via Natural or Artificial Opening */
"0FHD7DZ" = "1" /* Insertion of Intraluminal Device into Pancreatic Duct, Via Natural or Artificial Opening */
"0FHD81Z" = "1" /* Insertion of Radioactive Element into Pancreatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FHG02Z" = "1" /* Insertion of Monitoring Device into Pancreas, Open Approach */
"0FHG32Z" = "1" /* Insertion of Monitoring Device into Pancreas, Percutaneous Approach */
"0FHG42Z" = "1" /* Insertion of Monitoring Device into Pancreas, Percutaneous Endoscopic Approach */
"0FJ00ZZ" = "1" /* Inspection of Liver, Open Approach */
"0FJ04ZZ" = "1" /* Inspection of Liver, Percutaneous Endoscopic Approach */
"0FJ40ZZ" = "1" /* Inspection of Gallbladder, Open Approach */
"0FJ44ZZ" = "1" /* Inspection of Gallbladder, Percutaneous Endoscopic Approach */
"0FJB0ZZ" = "1" /* Inspection of Hepatobiliary Duct, Open Approach */
"0FJB4ZZ" = "1" /* Inspection of Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FJD0ZZ" = "1" /* Inspection of Pancreatic Duct, Open Approach */
"0FJD4ZZ" = "1" /* Inspection of Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FJG0ZZ" = "1" /* Inspection of Pancreas, Open Approach */
"0FJG4ZZ" = "1" /* Inspection of Pancreas, Percutaneous Endoscopic Approach */
"0FL50CZ" = "1" /* Occlusion of Right Hepatic Duct with Extraluminal Device, Open Approach */
"0FL50DZ" = "1" /* Occlusion of Right Hepatic Duct with Intraluminal Device, Open Approach */
"0FL50ZZ" = "1" /* Occlusion of Right Hepatic Duct, Open Approach */
"0FL60CZ" = "1" /* Occlusion of Left Hepatic Duct with Extraluminal Device, Open Approach */
"0FL60DZ" = "1" /* Occlusion of Left Hepatic Duct with Intraluminal Device, Open Approach */
"0FL60ZZ" = "1" /* Occlusion of Left Hepatic Duct, Open Approach */
"0FL80CZ" = "1" /* Occlusion of Cystic Duct with Extraluminal Device, Open Approach */
"0FL80DZ" = "1" /* Occlusion of Cystic Duct with Intraluminal Device, Open Approach */
"0FL80ZZ" = "1" /* Occlusion of Cystic Duct, Open Approach */
"0FL90CZ" = "1" /* Occlusion of Common Bile Duct with Extraluminal Device, Open Approach */
"0FL90DZ" = "1" /* Occlusion of Common Bile Duct with Intraluminal Device, Open Approach */
"0FL90ZZ" = "1" /* Occlusion of Common Bile Duct, Open Approach */
"0FLC0CZ" = "1" /* Occlusion of Ampulla of Vater with Extraluminal Device, Open Approach */
"0FLC0DZ" = "1" /* Occlusion of Ampulla of Vater with Intraluminal Device, Open Approach */
"0FLC0ZZ" = "1" /* Occlusion of Ampulla of Vater, Open Approach */
"0FLC3CZ" = "1" /* Occlusion of Ampulla of Vater with Extraluminal Device, Percutaneous Approach */
"0FLC3DZ" = "1" /* Occlusion of Ampulla of Vater with Intraluminal Device, Percutaneous Approach */
"0FLC3ZZ" = "1" /* Occlusion of Ampulla of Vater, Percutaneous Approach */
"0FLC4CZ" = "1" /* Occlusion of Ampulla of Vater with Extraluminal Device, Percutaneous Endoscopic Approach */
"0FLC4DZ" = "1" /* Occlusion of Ampulla of Vater with Intraluminal Device, Percutaneous Endoscopic Approach */
"0FLC4ZZ" = "1" /* Occlusion of Ampulla of Vater, Percutaneous Endoscopic Approach */
"0FLC7DZ" = "1" /* Occlusion of Ampulla of Vater with Intraluminal Device, Via Natural or Artificial Opening */
"0FLC7ZZ" = "1" /* Occlusion of Ampulla of Vater, Via Natural or Artificial Opening */
"0FLC8DZ" = "1" /* Occlusion of Ampulla of Vater with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0FLC8ZZ" = "1" /* Occlusion of Ampulla of Vater, Via Natural or Artificial Opening Endoscopic */
"0FLD0CZ" = "1" /* Occlusion of Pancreatic Duct with Extraluminal Device, Open Approach */
"0FLD0DZ" = "1" /* Occlusion of Pancreatic Duct with Intraluminal Device, Open Approach */
"0FLD0ZZ" = "1" /* Occlusion of Pancreatic Duct, Open Approach */
"0FLD3CZ" = "1" /* Occlusion of Pancreatic Duct with Extraluminal Device, Percutaneous Approach */
"0FLD3DZ" = "1" /* Occlusion of Pancreatic Duct with Intraluminal Device, Percutaneous Approach */
"0FLD3ZZ" = "1" /* Occlusion of Pancreatic Duct, Percutaneous Approach */
"0FLD4CZ" = "1" /* Occlusion of Pancreatic Duct with Extraluminal Device, Percutaneous Endoscopic Approach */
"0FLD4DZ" = "1" /* Occlusion of Pancreatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0FLD4ZZ" = "1" /* Occlusion of Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FLD7DZ" = "1" /* Occlusion of Pancreatic Duct with Intraluminal Device, Via Natural or Artificial Opening */
"0FLD7ZZ" = "1" /* Occlusion of Pancreatic Duct, Via Natural or Artificial Opening */
"0FLD8DZ" = "1" /* Occlusion of Pancreatic Duct with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0FLD8ZZ" = "1" /* Occlusion of Pancreatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FLF0CZ" = "1" /* Occlusion of Accessory Pancreatic Duct with Extraluminal Device, Open Approach */
"0FLF0DZ" = "1" /* Occlusion of Accessory Pancreatic Duct with Intraluminal Device, Open Approach */
"0FLF0ZZ" = "1" /* Occlusion of Accessory Pancreatic Duct, Open Approach */
"0FLF3CZ" = "1" /* Occlusion of Accessory Pancreatic Duct with Extraluminal Device, Percutaneous Approach */
"0FLF3DZ" = "1" /* Occlusion of Accessory Pancreatic Duct with Intraluminal Device, Percutaneous Approach */
"0FLF3ZZ" = "1" /* Occlusion of Accessory Pancreatic Duct, Percutaneous Approach */
"0FLF4CZ" = "1" /* Occlusion of Accessory Pancreatic Duct with Extraluminal Device, Percutaneous Endoscopic Approach */
"0FLF4DZ" = "1" /* Occlusion of Accessory Pancreatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0FLF4ZZ" = "1" /* Occlusion of Accessory Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FLF7DZ" = "1" /* Occlusion of Accessory Pancreatic Duct with Intraluminal Device, Via Natural or Artificial Opening */
"0FLF7ZZ" = "1" /* Occlusion of Accessory Pancreatic Duct, Via Natural or Artificial Opening */
"0FLF8DZ" = "1" /* Occlusion of Accessory Pancreatic Duct with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0FLF8ZZ" = "1" /* Occlusion of Accessory Pancreatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FM00ZZ" = "1" /* Reattachment of Liver, Open Approach */
"0FM04ZZ" = "1" /* Reattachment of Liver, Percutaneous Endoscopic Approach */
"0FM10ZZ" = "1" /* Reattachment of Right Lobe Liver, Open Approach */
"0FM14ZZ" = "1" /* Reattachment of Right Lobe Liver, Percutaneous Endoscopic Approach */
"0FM20ZZ" = "1" /* Reattachment of Left Lobe Liver, Open Approach */
"0FM24ZZ" = "1" /* Reattachment of Left Lobe Liver, Percutaneous Endoscopic Approach */
"0FM40ZZ" = "1" /* Reattachment of Gallbladder, Open Approach */
"0FM50ZZ" = "1" /* Reattachment of Right Hepatic Duct, Open Approach */
"0FM60ZZ" = "1" /* Reattachment of Left Hepatic Duct, Open Approach */
"0FM80ZZ" = "1" /* Reattachment of Cystic Duct, Open Approach */
"0FM90ZZ" = "1" /* Reattachment of Common Bile Duct, Open Approach */
"0FMC0ZZ" = "1" /* Reattachment of Ampulla of Vater, Open Approach */
"0FMC4ZZ" = "1" /* Reattachment of Ampulla of Vater, Percutaneous Endoscopic Approach */
"0FMD0ZZ" = "1" /* Reattachment of Pancreatic Duct, Open Approach */
"0FMD4ZZ" = "1" /* Reattachment of Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FMF0ZZ" = "1" /* Reattachment of Accessory Pancreatic Duct, Open Approach */
"0FMF4ZZ" = "1" /* Reattachment of Accessory Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FMG0ZZ" = "1" /* Reattachment of Pancreas, Open Approach */
"0FMG4ZZ" = "1" /* Reattachment of Pancreas, Percutaneous Endoscopic Approach */
"0FN00ZZ" = "1" /* Release Liver, Open Approach */
"0FN03ZZ" = "1" /* Release Liver, Percutaneous Approach */
"0FN04ZZ" = "1" /* Release Liver, Percutaneous Endoscopic Approach */
"0FN10ZZ" = "1" /* Release Right Lobe Liver, Open Approach */
"0FN13ZZ" = "1" /* Release Right Lobe Liver, Percutaneous Approach */
"0FN14ZZ" = "1" /* Release Right Lobe Liver, Percutaneous Endoscopic Approach */
"0FN20ZZ" = "1" /* Release Left Lobe Liver, Open Approach */
"0FN23ZZ" = "1" /* Release Left Lobe Liver, Percutaneous Approach */
"0FN24ZZ" = "1" /* Release Left Lobe Liver, Percutaneous Endoscopic Approach */
"0FN40ZZ" = "1" /* Release Gallbladder, Open Approach */
"0FN43ZZ" = "1" /* Release Gallbladder, Percutaneous Approach */
"0FN44ZZ" = "1" /* Release Gallbladder, Percutaneous Endoscopic Approach */
"0FN50ZZ" = "1" /* Release Right Hepatic Duct, Open Approach */
"0FN53ZZ" = "1" /* Release Right Hepatic Duct, Percutaneous Approach */
"0FN54ZZ" = "1" /* Release Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0FN57ZZ" = "1" /* Release Right Hepatic Duct, Via Natural or Artificial Opening */
"0FN58ZZ" = "1" /* Release Right Hepatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FN60ZZ" = "1" /* Release Left Hepatic Duct, Open Approach */
"0FN63ZZ" = "1" /* Release Left Hepatic Duct, Percutaneous Approach */
"0FN64ZZ" = "1" /* Release Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0FN67ZZ" = "1" /* Release Left Hepatic Duct, Via Natural or Artificial Opening */
"0FN68ZZ" = "1" /* Release Left Hepatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FN80ZZ" = "1" /* Release Cystic Duct, Open Approach */
"0FN83ZZ" = "1" /* Release Cystic Duct, Percutaneous Approach */
"0FN84ZZ" = "1" /* Release Cystic Duct, Percutaneous Endoscopic Approach */
"0FN87ZZ" = "1" /* Release Cystic Duct, Via Natural or Artificial Opening */
"0FN88ZZ" = "1" /* Release Cystic Duct, Via Natural or Artificial Opening Endoscopic */
"0FN90ZZ" = "1" /* Release Common Bile Duct, Open Approach */
"0FN93ZZ" = "1" /* Release Common Bile Duct, Percutaneous Approach */
"0FN94ZZ" = "1" /* Release Common Bile Duct, Percutaneous Endoscopic Approach */
"0FN97ZZ" = "1" /* Release Common Bile Duct, Via Natural or Artificial Opening */
"0FN98ZZ" = "1" /* Release Common Bile Duct, Via Natural or Artificial Opening Endoscopic */
"0FNC0ZZ" = "1" /* Release Ampulla of Vater, Open Approach */
"0FNC3ZZ" = "1" /* Release Ampulla of Vater, Percutaneous Approach */
"0FNC4ZZ" = "1" /* Release Ampulla of Vater, Percutaneous Endoscopic Approach */
"0FNC7ZZ" = "1" /* Release Ampulla of Vater, Via Natural or Artificial Opening */
"0FNC8ZZ" = "1" /* Release Ampulla of Vater, Via Natural or Artificial Opening Endoscopic */
"0FND0ZZ" = "1" /* Release Pancreatic Duct, Open Approach */
"0FND3ZZ" = "1" /* Release Pancreatic Duct, Percutaneous Approach */
"0FND4ZZ" = "1" /* Release Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FND7ZZ" = "1" /* Release Pancreatic Duct, Via Natural or Artificial Opening */
"0FND8ZZ" = "1" /* Release Pancreatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FNF0ZZ" = "1" /* Release Accessory Pancreatic Duct, Open Approach */
"0FNF3ZZ" = "1" /* Release Accessory Pancreatic Duct, Percutaneous Approach */
"0FNF4ZZ" = "1" /* Release Accessory Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FNF7ZZ" = "1" /* Release Accessory Pancreatic Duct, Via Natural or Artificial Opening */
"0FNF8ZZ" = "1" /* Release Accessory Pancreatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FNG0ZZ" = "1" /* Release Pancreas, Open Approach */
"0FNG3ZZ" = "1" /* Release Pancreas, Percutaneous Approach */
"0FNG4ZZ" = "1" /* Release Pancreas, Percutaneous Endoscopic Approach */
"0FP000Z" = "1" /* Removal of Drainage Device from Liver, Open Approach */
"0FP002Z" = "1" /* Removal of Monitoring Device from Liver, Open Approach */
"0FP003Z" = "1" /* Removal of Infusion Device from Liver, Open Approach */
"0FP030Z" = "1" /* Removal of Drainage Device from Liver, Percutaneous Approach */
"0FP032Z" = "1" /* Removal of Monitoring Device from Liver, Percutaneous Approach */
"0FP033Z" = "1" /* Removal of Infusion Device from Liver, Percutaneous Approach */
"0FP040Z" = "1" /* Removal of Drainage Device from Liver, Percutaneous Endoscopic Approach */
"0FP042Z" = "1" /* Removal of Monitoring Device from Liver, Percutaneous Endoscopic Approach */
"0FP043Z" = "1" /* Removal of Infusion Device from Liver, Percutaneous Endoscopic Approach */
"0FP400Z" = "1" /* Removal of Drainage Device from Gallbladder, Open Approach */
"0FP402Z" = "1" /* Removal of Monitoring Device from Gallbladder, Open Approach */
"0FP403Z" = "1" /* Removal of Infusion Device from Gallbladder, Open Approach */
"0FP40DZ" = "1" /* Removal of Intraluminal Device from Gallbladder, Open Approach */
"0FP430Z" = "1" /* Removal of Drainage Device from Gallbladder, Percutaneous Approach */
"0FP432Z" = "1" /* Removal of Monitoring Device from Gallbladder, Percutaneous Approach */
"0FP433Z" = "1" /* Removal of Infusion Device from Gallbladder, Percutaneous Approach */
"0FP43DZ" = "1" /* Removal of Intraluminal Device from Gallbladder, Percutaneous Approach */
"0FP440Z" = "1" /* Removal of Drainage Device from Gallbladder, Percutaneous Endoscopic Approach */
"0FP442Z" = "1" /* Removal of Monitoring Device from Gallbladder, Percutaneous Endoscopic Approach */
"0FP443Z" = "1" /* Removal of Infusion Device from Gallbladder, Percutaneous Endoscopic Approach */
"0FP44DZ" = "1" /* Removal of Intraluminal Device from Gallbladder, Percutaneous Endoscopic Approach */
"0FPB00Z" = "1" /* Removal of Drainage Device from Hepatobiliary Duct, Open Approach */
"0FPB01Z" = "1" /* Removal of Radioactive Element from Hepatobiliary Duct, Open Approach */
"0FPB02Z" = "1" /* Removal of Monitoring Device from Hepatobiliary Duct, Open Approach */
"0FPB03Z" = "1" /* Removal of Infusion Device from Hepatobiliary Duct, Open Approach */
"0FPB07Z" = "1" /* Removal of Autologous Tissue Substitute from Hepatobiliary Duct, Open Approach */
"0FPB0CZ" = "1" /* Removal of Extraluminal Device from Hepatobiliary Duct, Open Approach */
"0FPB0DZ" = "1" /* Removal of Intraluminal Device from Hepatobiliary Duct, Open Approach */
"0FPB0JZ" = "1" /* Removal of Synthetic Substitute from Hepatobiliary Duct, Open Approach */
"0FPB0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Hepatobiliary Duct, Open Approach */
"0FPB30Z" = "1" /* Removal of Drainage Device from Hepatobiliary Duct, Percutaneous Approach */
"0FPB31Z" = "1" /* Removal of Radioactive Element from Hepatobiliary Duct, Percutaneous Approach */
"0FPB32Z" = "1" /* Removal of Monitoring Device from Hepatobiliary Duct, Percutaneous Approach */
"0FPB33Z" = "1" /* Removal of Infusion Device from Hepatobiliary Duct, Percutaneous Approach */
"0FPB37Z" = "1" /* Removal of Autologous Tissue Substitute from Hepatobiliary Duct, Percutaneous Approach */
"0FPB3CZ" = "1" /* Removal of Extraluminal Device from Hepatobiliary Duct, Percutaneous Approach */
"0FPB3DZ" = "1" /* Removal of Intraluminal Device from Hepatobiliary Duct, Percutaneous Approach */
"0FPB3JZ" = "1" /* Removal of Synthetic Substitute from Hepatobiliary Duct, Percutaneous Approach */
"0FPB3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Hepatobiliary Duct, Percutaneous Approach */
"0FPB40Z" = "1" /* Removal of Drainage Device from Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FPB41Z" = "1" /* Removal of Radioactive Element from Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FPB42Z" = "1" /* Removal of Monitoring Device from Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FPB43Z" = "1" /* Removal of Infusion Device from Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FPB47Z" = "1" /* Removal of Autologous Tissue Substitute from Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FPB4CZ" = "1" /* Removal of Extraluminal Device from Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FPB4DZ" = "1" /* Removal of Intraluminal Device from Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FPB4JZ" = "1" /* Removal of Synthetic Substitute from Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FPB4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FPB71Z" = "1" /* Removal of Radioactive Element from Hepatobiliary Duct, Via Natural or Artificial Opening */
"0FPB77Z" = "1" /* Removal of Autologous Tissue Substitute from Hepatobiliary Duct, Via Natural or Artificial Opening */
"0FPB7CZ" = "1" /* Removal of Extraluminal Device from Hepatobiliary Duct, Via Natural or Artificial Opening */
"0FPB7JZ" = "1" /* Removal of Synthetic Substitute from Hepatobiliary Duct, Via Natural or Artificial Opening */
"0FPB7KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Hepatobiliary Duct, Via Natural or Artificial Opening */
"0FPB81Z" = "1" /* Removal of Radioactive Element from Hepatobiliary Duct, Via Natural or Artificial Opening Endoscopic */
"0FPB87Z" = "1" /* Removal of Autologous Tissue Substitute from Hepatobiliary Duct, Via Natural or Artificial Opening Endoscopic */
"0FPB8CZ" = "1" /* Removal of Extraluminal Device from Hepatobiliary Duct, Via Natural or Artificial Opening Endoscopic */
"0FPB8JZ" = "1" /* Removal of Synthetic Substitute from Hepatobiliary Duct, Via Natural or Artificial Opening Endoscopic */
"0FPB8KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Hepatobiliary Duct, Via Natural or Artificial Opening Endoscopic */
"0FPD00Z" = "1" /* Removal of Drainage Device from Pancreatic Duct, Open Approach */
"0FPD01Z" = "1" /* Removal of Radioactive Element from Pancreatic Duct, Open Approach */
"0FPD02Z" = "1" /* Removal of Monitoring Device from Pancreatic Duct, Open Approach */
"0FPD03Z" = "1" /* Removal of Infusion Device from Pancreatic Duct, Open Approach */
"0FPD07Z" = "1" /* Removal of Autologous Tissue Substitute from Pancreatic Duct, Open Approach */
"0FPD0CZ" = "1" /* Removal of Extraluminal Device from Pancreatic Duct, Open Approach */
"0FPD0DZ" = "1" /* Removal of Intraluminal Device from Pancreatic Duct, Open Approach */
"0FPD0JZ" = "1" /* Removal of Synthetic Substitute from Pancreatic Duct, Open Approach */
"0FPD0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Pancreatic Duct, Open Approach */
"0FPD30Z" = "1" /* Removal of Drainage Device from Pancreatic Duct, Percutaneous Approach */
"0FPD31Z" = "1" /* Removal of Radioactive Element from Pancreatic Duct, Percutaneous Approach */
"0FPD32Z" = "1" /* Removal of Monitoring Device from Pancreatic Duct, Percutaneous Approach */
"0FPD33Z" = "1" /* Removal of Infusion Device from Pancreatic Duct, Percutaneous Approach */
"0FPD37Z" = "1" /* Removal of Autologous Tissue Substitute from Pancreatic Duct, Percutaneous Approach */
"0FPD3CZ" = "1" /* Removal of Extraluminal Device from Pancreatic Duct, Percutaneous Approach */
"0FPD3DZ" = "1" /* Removal of Intraluminal Device from Pancreatic Duct, Percutaneous Approach */
"0FPD3JZ" = "1" /* Removal of Synthetic Substitute from Pancreatic Duct, Percutaneous Approach */
"0FPD3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Pancreatic Duct, Percutaneous Approach */
"0FPD40Z" = "1" /* Removal of Drainage Device from Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FPD41Z" = "1" /* Removal of Radioactive Element from Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FPD42Z" = "1" /* Removal of Monitoring Device from Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FPD43Z" = "1" /* Removal of Infusion Device from Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FPD47Z" = "1" /* Removal of Autologous Tissue Substitute from Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FPD4CZ" = "1" /* Removal of Extraluminal Device from Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FPD4DZ" = "1" /* Removal of Intraluminal Device from Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FPD4JZ" = "1" /* Removal of Synthetic Substitute from Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FPD4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FPD71Z" = "1" /* Removal of Radioactive Element from Pancreatic Duct, Via Natural or Artificial Opening */
"0FPD77Z" = "1" /* Removal of Autologous Tissue Substitute from Pancreatic Duct, Via Natural or Artificial Opening */
"0FPD7CZ" = "1" /* Removal of Extraluminal Device from Pancreatic Duct, Via Natural or Artificial Opening */
"0FPD7JZ" = "1" /* Removal of Synthetic Substitute from Pancreatic Duct, Via Natural or Artificial Opening */
"0FPD7KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Pancreatic Duct, Via Natural or Artificial Opening */
"0FPD81Z" = "1" /* Removal of Radioactive Element from Pancreatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FPD87Z" = "1" /* Removal of Autologous Tissue Substitute from Pancreatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FPD8CZ" = "1" /* Removal of Extraluminal Device from Pancreatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FPD8JZ" = "1" /* Removal of Synthetic Substitute from Pancreatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FPD8KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Pancreatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FPG00Z" = "1" /* Removal of Drainage Device from Pancreas, Open Approach */
"0FPG02Z" = "1" /* Removal of Monitoring Device from Pancreas, Open Approach */
"0FPG03Z" = "1" /* Removal of Infusion Device from Pancreas, Open Approach */
"0FPG0DZ" = "1" /* Removal of Intraluminal Device from Pancreas, Open Approach */
"0FPG30Z" = "1" /* Removal of Drainage Device from Pancreas, Percutaneous Approach */
"0FPG32Z" = "1" /* Removal of Monitoring Device from Pancreas, Percutaneous Approach */
"0FPG33Z" = "1" /* Removal of Infusion Device from Pancreas, Percutaneous Approach */
"0FPG3DZ" = "1" /* Removal of Intraluminal Device from Pancreas, Percutaneous Approach */
"0FPG40Z" = "1" /* Removal of Drainage Device from Pancreas, Percutaneous Endoscopic Approach */
"0FPG42Z" = "1" /* Removal of Monitoring Device from Pancreas, Percutaneous Endoscopic Approach */
"0FPG43Z" = "1" /* Removal of Infusion Device from Pancreas, Percutaneous Endoscopic Approach */
"0FPG4DZ" = "1" /* Removal of Intraluminal Device from Pancreas, Percutaneous Endoscopic Approach */
"0FPGXDZ" = "1" /* Removal of Intraluminal Device from Pancreas, External Approach */
"0FQ00ZZ" = "1" /* Repair Liver, Open Approach */
"0FQ03ZZ" = "1" /* Repair Liver, Percutaneous Approach */
"0FQ04ZZ" = "1" /* Repair Liver, Percutaneous Endoscopic Approach */
"0FQ10ZZ" = "1" /* Repair Right Lobe Liver, Open Approach */
"0FQ13ZZ" = "1" /* Repair Right Lobe Liver, Percutaneous Approach */
"0FQ14ZZ" = "1" /* Repair Right Lobe Liver, Percutaneous Endoscopic Approach */
"0FQ20ZZ" = "1" /* Repair Left Lobe Liver, Open Approach */
"0FQ23ZZ" = "1" /* Repair Left Lobe Liver, Percutaneous Approach */
"0FQ24ZZ" = "1" /* Repair Left Lobe Liver, Percutaneous Endoscopic Approach */
"0FQ40ZZ" = "1" /* Repair Gallbladder, Open Approach */
"0FQ43ZZ" = "1" /* Repair Gallbladder, Percutaneous Approach */
"0FQ44ZZ" = "1" /* Repair Gallbladder, Percutaneous Endoscopic Approach */
"0FQ50ZZ" = "1" /* Repair Right Hepatic Duct, Open Approach */
"0FQ53ZZ" = "1" /* Repair Right Hepatic Duct, Percutaneous Approach */
"0FQ54ZZ" = "1" /* Repair Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0FQ57ZZ" = "1" /* Repair Right Hepatic Duct, Via Natural or Artificial Opening */
"0FQ58ZZ" = "1" /* Repair Right Hepatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FQ60ZZ" = "1" /* Repair Left Hepatic Duct, Open Approach */
"0FQ63ZZ" = "1" /* Repair Left Hepatic Duct, Percutaneous Approach */
"0FQ64ZZ" = "1" /* Repair Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0FQ67ZZ" = "1" /* Repair Left Hepatic Duct, Via Natural or Artificial Opening */
"0FQ68ZZ" = "1" /* Repair Left Hepatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FQ80ZZ" = "1" /* Repair Cystic Duct, Open Approach */
"0FQ83ZZ" = "1" /* Repair Cystic Duct, Percutaneous Approach */
"0FQ84ZZ" = "1" /* Repair Cystic Duct, Percutaneous Endoscopic Approach */
"0FQ87ZZ" = "1" /* Repair Cystic Duct, Via Natural or Artificial Opening */
"0FQ88ZZ" = "1" /* Repair Cystic Duct, Via Natural or Artificial Opening Endoscopic */
"0FQ90ZZ" = "1" /* Repair Common Bile Duct, Open Approach */
"0FQ93ZZ" = "1" /* Repair Common Bile Duct, Percutaneous Approach */
"0FQ94ZZ" = "1" /* Repair Common Bile Duct, Percutaneous Endoscopic Approach */
"0FQ97ZZ" = "1" /* Repair Common Bile Duct, Via Natural or Artificial Opening */
"0FQ98ZZ" = "1" /* Repair Common Bile Duct, Via Natural or Artificial Opening Endoscopic */
"0FQC0ZZ" = "1" /* Repair Ampulla of Vater, Open Approach */
"0FQC3ZZ" = "1" /* Repair Ampulla of Vater, Percutaneous Approach */
"0FQC4ZZ" = "1" /* Repair Ampulla of Vater, Percutaneous Endoscopic Approach */
"0FQC7ZZ" = "1" /* Repair Ampulla of Vater, Via Natural or Artificial Opening */
"0FQC8ZZ" = "1" /* Repair Ampulla of Vater, Via Natural or Artificial Opening Endoscopic */
"0FQD0ZZ" = "1" /* Repair Pancreatic Duct, Open Approach */
"0FQD3ZZ" = "1" /* Repair Pancreatic Duct, Percutaneous Approach */
"0FQD4ZZ" = "1" /* Repair Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FQD7ZZ" = "1" /* Repair Pancreatic Duct, Via Natural or Artificial Opening */
"0FQD8ZZ" = "1" /* Repair Pancreatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FQF0ZZ" = "1" /* Repair Accessory Pancreatic Duct, Open Approach */
"0FQF3ZZ" = "1" /* Repair Accessory Pancreatic Duct, Percutaneous Approach */
"0FQF4ZZ" = "1" /* Repair Accessory Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FQF7ZZ" = "1" /* Repair Accessory Pancreatic Duct, Via Natural or Artificial Opening */
"0FQF8ZZ" = "1" /* Repair Accessory Pancreatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FQG0ZZ" = "1" /* Repair Pancreas, Open Approach */
"0FQG3ZZ" = "1" /* Repair Pancreas, Percutaneous Approach */
"0FQG4ZZ" = "1" /* Repair Pancreas, Percutaneous Endoscopic Approach */
"0FR507Z" = "1" /* Replacement of Right Hepatic Duct with Autologous Tissue Substitute, Open Approach */
"0FR50JZ" = "1" /* Replacement of Right Hepatic Duct with Synthetic Substitute, Open Approach */
"0FR50KZ" = "1" /* Replacement of Right Hepatic Duct with Nonautologous Tissue Substitute, Open Approach */
"0FR547Z" = "1" /* Replacement of Right Hepatic Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FR54JZ" = "1" /* Replacement of Right Hepatic Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FR54KZ" = "1" /* Replacement of Right Hepatic Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FR607Z" = "1" /* Replacement of Left Hepatic Duct with Autologous Tissue Substitute, Open Approach */
"0FR60JZ" = "1" /* Replacement of Left Hepatic Duct with Synthetic Substitute, Open Approach */
"0FR60KZ" = "1" /* Replacement of Left Hepatic Duct with Nonautologous Tissue Substitute, Open Approach */
"0FR647Z" = "1" /* Replacement of Left Hepatic Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FR64JZ" = "1" /* Replacement of Left Hepatic Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FR64KZ" = "1" /* Replacement of Left Hepatic Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FR807Z" = "1" /* Replacement of Cystic Duct with Autologous Tissue Substitute, Open Approach */
"0FR80JZ" = "1" /* Replacement of Cystic Duct with Synthetic Substitute, Open Approach */
"0FR80KZ" = "1" /* Replacement of Cystic Duct with Nonautologous Tissue Substitute, Open Approach */
"0FR847Z" = "1" /* Replacement of Cystic Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FR84JZ" = "1" /* Replacement of Cystic Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FR84KZ" = "1" /* Replacement of Cystic Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FR907Z" = "1" /* Replacement of Common Bile Duct with Autologous Tissue Substitute, Open Approach */
"0FR90JZ" = "1" /* Replacement of Common Bile Duct with Synthetic Substitute, Open Approach */
"0FR90KZ" = "1" /* Replacement of Common Bile Duct with Nonautologous Tissue Substitute, Open Approach */
"0FR947Z" = "1" /* Replacement of Common Bile Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FR94JZ" = "1" /* Replacement of Common Bile Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FR94KZ" = "1" /* Replacement of Common Bile Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FRC07Z" = "1" /* Replacement of Ampulla of Vater with Autologous Tissue Substitute, Open Approach */
"0FRC0JZ" = "1" /* Replacement of Ampulla of Vater with Synthetic Substitute, Open Approach */
"0FRC0KZ" = "1" /* Replacement of Ampulla of Vater with Nonautologous Tissue Substitute, Open Approach */
"0FRC47Z" = "1" /* Replacement of Ampulla of Vater with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FRC4JZ" = "1" /* Replacement of Ampulla of Vater with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FRC4KZ" = "1" /* Replacement of Ampulla of Vater with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FRD07Z" = "1" /* Replacement of Pancreatic Duct with Autologous Tissue Substitute, Open Approach */
"0FRD0JZ" = "1" /* Replacement of Pancreatic Duct with Synthetic Substitute, Open Approach */
"0FRD0KZ" = "1" /* Replacement of Pancreatic Duct with Nonautologous Tissue Substitute, Open Approach */
"0FRD47Z" = "1" /* Replacement of Pancreatic Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FRD4JZ" = "1" /* Replacement of Pancreatic Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FRD4KZ" = "1" /* Replacement of Pancreatic Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FRF07Z" = "1" /* Replacement of Accessory Pancreatic Duct with Autologous Tissue Substitute, Open Approach */
"0FRF0JZ" = "1" /* Replacement of Accessory Pancreatic Duct with Synthetic Substitute, Open Approach */
"0FRF0KZ" = "1" /* Replacement of Accessory Pancreatic Duct with Nonautologous Tissue Substitute, Open Approach */
"0FRF47Z" = "1" /* Replacement of Accessory Pancreatic Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FRF4JZ" = "1" /* Replacement of Accessory Pancreatic Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FRF4KZ" = "1" /* Replacement of Accessory Pancreatic Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FS00ZZ" = "1" /* Reposition Liver, Open Approach */
"0FS04ZZ" = "1" /* Reposition Liver, Percutaneous Endoscopic Approach */
"0FS40ZZ" = "1" /* Reposition Gallbladder, Open Approach */
"0FS44ZZ" = "1" /* Reposition Gallbladder, Percutaneous Endoscopic Approach */
"0FS50ZZ" = "1" /* Reposition Right Hepatic Duct, Open Approach */
"0FS54ZZ" = "1" /* Reposition Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0FS60ZZ" = "1" /* Reposition Left Hepatic Duct, Open Approach */
"0FS64ZZ" = "1" /* Reposition Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0FS80ZZ" = "1" /* Reposition Cystic Duct, Open Approach */
"0FS84ZZ" = "1" /* Reposition Cystic Duct, Percutaneous Endoscopic Approach */
"0FS90ZZ" = "1" /* Reposition Common Bile Duct, Open Approach */
"0FS94ZZ" = "1" /* Reposition Common Bile Duct, Percutaneous Endoscopic Approach */
"0FSC0ZZ" = "1" /* Reposition Ampulla of Vater, Open Approach */
"0FSC4ZZ" = "1" /* Reposition Ampulla of Vater, Percutaneous Endoscopic Approach */
"0FSD0ZZ" = "1" /* Reposition Pancreatic Duct, Open Approach */
"0FSD4ZZ" = "1" /* Reposition Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FSF0ZZ" = "1" /* Reposition Accessory Pancreatic Duct, Open Approach */
"0FSF4ZZ" = "1" /* Reposition Accessory Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FSG0ZZ" = "1" /* Reposition Pancreas, Open Approach */
"0FSG4ZZ" = "1" /* Reposition Pancreas, Percutaneous Endoscopic Approach */
"0FT00ZZ" = "1" /* Resection of Liver, Open Approach */
"0FT04ZZ" = "1" /* Resection of Liver, Percutaneous Endoscopic Approach */
"0FT10ZZ" = "1" /* Resection of Right Lobe Liver, Open Approach */
"0FT14ZZ" = "1" /* Resection of Right Lobe Liver, Percutaneous Endoscopic Approach */
"0FT20ZZ" = "1" /* Resection of Left Lobe Liver, Open Approach */
"0FT24ZZ" = "1" /* Resection of Left Lobe Liver, Percutaneous Endoscopic Approach */
"0FT40ZZ" = "1" /* Resection of Gallbladder, Open Approach */
"0FT44ZZ" = "1" /* Resection of Gallbladder, Percutaneous Endoscopic Approach */
"0FT50ZZ" = "1" /* Resection of Right Hepatic Duct, Open Approach */
"0FT54ZZ" = "1" /* Resection of Right Hepatic Duct, Percutaneous Endoscopic Approach */
"0FT57ZZ" = "1" /* Resection of Right Hepatic Duct, Via Natural or Artificial Opening */
"0FT58ZZ" = "1" /* Resection of Right Hepatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FT60ZZ" = "1" /* Resection of Left Hepatic Duct, Open Approach */
"0FT64ZZ" = "1" /* Resection of Left Hepatic Duct, Percutaneous Endoscopic Approach */
"0FT67ZZ" = "1" /* Resection of Left Hepatic Duct, Via Natural or Artificial Opening */
"0FT68ZZ" = "1" /* Resection of Left Hepatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FT80ZZ" = "1" /* Resection of Cystic Duct, Open Approach */
"0FT84ZZ" = "1" /* Resection of Cystic Duct, Percutaneous Endoscopic Approach */
"0FT87ZZ" = "1" /* Resection of Cystic Duct, Via Natural or Artificial Opening */
"0FT88ZZ" = "1" /* Resection of Cystic Duct, Via Natural or Artificial Opening Endoscopic */
"0FT90ZZ" = "1" /* Resection of Common Bile Duct, Open Approach */
"0FT94ZZ" = "1" /* Resection of Common Bile Duct, Percutaneous Endoscopic Approach */
"0FT97ZZ" = "1" /* Resection of Common Bile Duct, Via Natural or Artificial Opening */
"0FT98ZZ" = "1" /* Resection of Common Bile Duct, Via Natural or Artificial Opening Endoscopic */
"0FTC0ZZ" = "1" /* Resection of Ampulla of Vater, Open Approach */
"0FTC4ZZ" = "1" /* Resection of Ampulla of Vater, Percutaneous Endoscopic Approach */
"0FTC7ZZ" = "1" /* Resection of Ampulla of Vater, Via Natural or Artificial Opening */
"0FTC8ZZ" = "1" /* Resection of Ampulla of Vater, Via Natural or Artificial Opening Endoscopic */
"0FTD0ZZ" = "1" /* Resection of Pancreatic Duct, Open Approach */
"0FTD7ZZ" = "1" /* Resection of Pancreatic Duct, Via Natural or Artificial Opening */
"0FTF0ZZ" = "1" /* Resection of Accessory Pancreatic Duct, Open Approach */
"0FTF7ZZ" = "1" /* Resection of Accessory Pancreatic Duct, Via Natural or Artificial Opening */
"0FTG0ZZ" = "1" /* Resection of Pancreas, Open Approach */
"0FTG4ZZ" = "1" /* Resection of Pancreas, Percutaneous Endoscopic Approach */
"0FU507Z" = "1" /* Supplement Right Hepatic Duct with Autologous Tissue Substitute, Open Approach */
"0FU50JZ" = "1" /* Supplement Right Hepatic Duct with Synthetic Substitute, Open Approach */
"0FU50KZ" = "1" /* Supplement Right Hepatic Duct with Nonautologous Tissue Substitute, Open Approach */
"0FU537Z" = "1" /* Supplement Right Hepatic Duct with Autologous Tissue Substitute, Percutaneous Approach */
"0FU53JZ" = "1" /* Supplement Right Hepatic Duct with Synthetic Substitute, Percutaneous Approach */
"0FU53KZ" = "1" /* Supplement Right Hepatic Duct with Nonautologous Tissue Substitute, Percutaneous Approach */
"0FU547Z" = "1" /* Supplement Right Hepatic Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FU54JZ" = "1" /* Supplement Right Hepatic Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FU54KZ" = "1" /* Supplement Right Hepatic Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FU607Z" = "1" /* Supplement Left Hepatic Duct with Autologous Tissue Substitute, Open Approach */
"0FU60JZ" = "1" /* Supplement Left Hepatic Duct with Synthetic Substitute, Open Approach */
"0FU60KZ" = "1" /* Supplement Left Hepatic Duct with Nonautologous Tissue Substitute, Open Approach */
"0FU637Z" = "1" /* Supplement Left Hepatic Duct with Autologous Tissue Substitute, Percutaneous Approach */
"0FU63JZ" = "1" /* Supplement Left Hepatic Duct with Synthetic Substitute, Percutaneous Approach */
"0FU63KZ" = "1" /* Supplement Left Hepatic Duct with Nonautologous Tissue Substitute, Percutaneous Approach */
"0FU647Z" = "1" /* Supplement Left Hepatic Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FU64JZ" = "1" /* Supplement Left Hepatic Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FU64KZ" = "1" /* Supplement Left Hepatic Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FU807Z" = "1" /* Supplement Cystic Duct with Autologous Tissue Substitute, Open Approach */
"0FU80JZ" = "1" /* Supplement Cystic Duct with Synthetic Substitute, Open Approach */
"0FU80KZ" = "1" /* Supplement Cystic Duct with Nonautologous Tissue Substitute, Open Approach */
"0FU837Z" = "1" /* Supplement Cystic Duct with Autologous Tissue Substitute, Percutaneous Approach */
"0FU83JZ" = "1" /* Supplement Cystic Duct with Synthetic Substitute, Percutaneous Approach */
"0FU83KZ" = "1" /* Supplement Cystic Duct with Nonautologous Tissue Substitute, Percutaneous Approach */
"0FU847Z" = "1" /* Supplement Cystic Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FU84JZ" = "1" /* Supplement Cystic Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FU84KZ" = "1" /* Supplement Cystic Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FU907Z" = "1" /* Supplement Common Bile Duct with Autologous Tissue Substitute, Open Approach */
"0FU90JZ" = "1" /* Supplement Common Bile Duct with Synthetic Substitute, Open Approach */
"0FU90KZ" = "1" /* Supplement Common Bile Duct with Nonautologous Tissue Substitute, Open Approach */
"0FU937Z" = "1" /* Supplement Common Bile Duct with Autologous Tissue Substitute, Percutaneous Approach */
"0FU93JZ" = "1" /* Supplement Common Bile Duct with Synthetic Substitute, Percutaneous Approach */
"0FU93KZ" = "1" /* Supplement Common Bile Duct with Nonautologous Tissue Substitute, Percutaneous Approach */
"0FU947Z" = "1" /* Supplement Common Bile Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FU94JZ" = "1" /* Supplement Common Bile Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FU94KZ" = "1" /* Supplement Common Bile Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FUC07Z" = "1" /* Supplement Ampulla of Vater with Autologous Tissue Substitute, Open Approach */
"0FUC0JZ" = "1" /* Supplement Ampulla of Vater with Synthetic Substitute, Open Approach */
"0FUC0KZ" = "1" /* Supplement Ampulla of Vater with Nonautologous Tissue Substitute, Open Approach */
"0FUC37Z" = "1" /* Supplement Ampulla of Vater with Autologous Tissue Substitute, Percutaneous Approach */
"0FUC3JZ" = "1" /* Supplement Ampulla of Vater with Synthetic Substitute, Percutaneous Approach */
"0FUC3KZ" = "1" /* Supplement Ampulla of Vater with Nonautologous Tissue Substitute, Percutaneous Approach */
"0FUC47Z" = "1" /* Supplement Ampulla of Vater with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FUC4JZ" = "1" /* Supplement Ampulla of Vater with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FUC4KZ" = "1" /* Supplement Ampulla of Vater with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FUD07Z" = "1" /* Supplement Pancreatic Duct with Autologous Tissue Substitute, Open Approach */
"0FUD0JZ" = "1" /* Supplement Pancreatic Duct with Synthetic Substitute, Open Approach */
"0FUD0KZ" = "1" /* Supplement Pancreatic Duct with Nonautologous Tissue Substitute, Open Approach */
"0FUD37Z" = "1" /* Supplement Pancreatic Duct with Autologous Tissue Substitute, Percutaneous Approach */
"0FUD3JZ" = "1" /* Supplement Pancreatic Duct with Synthetic Substitute, Percutaneous Approach */
"0FUD3KZ" = "1" /* Supplement Pancreatic Duct with Nonautologous Tissue Substitute, Percutaneous Approach */
"0FUD47Z" = "1" /* Supplement Pancreatic Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FUD4JZ" = "1" /* Supplement Pancreatic Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FUD4KZ" = "1" /* Supplement Pancreatic Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FUF07Z" = "1" /* Supplement Accessory Pancreatic Duct with Autologous Tissue Substitute, Open Approach */
"0FUF0JZ" = "1" /* Supplement Accessory Pancreatic Duct with Synthetic Substitute, Open Approach */
"0FUF0KZ" = "1" /* Supplement Accessory Pancreatic Duct with Nonautologous Tissue Substitute, Open Approach */
"0FUF37Z" = "1" /* Supplement Accessory Pancreatic Duct with Autologous Tissue Substitute, Percutaneous Approach */
"0FUF3JZ" = "1" /* Supplement Accessory Pancreatic Duct with Synthetic Substitute, Percutaneous Approach */
"0FUF3KZ" = "1" /* Supplement Accessory Pancreatic Duct with Nonautologous Tissue Substitute, Percutaneous Approach */
"0FUF47Z" = "1" /* Supplement Accessory Pancreatic Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FUF4JZ" = "1" /* Supplement Accessory Pancreatic Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0FUF4KZ" = "1" /* Supplement Accessory Pancreatic Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0FV50CZ" = "1" /* Restriction of Right Hepatic Duct with Extraluminal Device, Open Approach */
"0FV50DZ" = "1" /* Restriction of Right Hepatic Duct with Intraluminal Device, Open Approach */
"0FV50ZZ" = "1" /* Restriction of Right Hepatic Duct, Open Approach */
"0FV60CZ" = "1" /* Restriction of Left Hepatic Duct with Extraluminal Device, Open Approach */
"0FV60DZ" = "1" /* Restriction of Left Hepatic Duct with Intraluminal Device, Open Approach */
"0FV60ZZ" = "1" /* Restriction of Left Hepatic Duct, Open Approach */
"0FV80CZ" = "1" /* Restriction of Cystic Duct with Extraluminal Device, Open Approach */
"0FV80DZ" = "1" /* Restriction of Cystic Duct with Intraluminal Device, Open Approach */
"0FV80ZZ" = "1" /* Restriction of Cystic Duct, Open Approach */
"0FV90CZ" = "1" /* Restriction of Common Bile Duct with Extraluminal Device, Open Approach */
"0FV90DZ" = "1" /* Restriction of Common Bile Duct with Intraluminal Device, Open Approach */
"0FV90ZZ" = "1" /* Restriction of Common Bile Duct, Open Approach */
"0FVC0CZ" = "1" /* Restriction of Ampulla of Vater with Extraluminal Device, Open Approach */
"0FVC0DZ" = "1" /* Restriction of Ampulla of Vater with Intraluminal Device, Open Approach */
"0FVC0ZZ" = "1" /* Restriction of Ampulla of Vater, Open Approach */
"0FVC3CZ" = "1" /* Restriction of Ampulla of Vater with Extraluminal Device, Percutaneous Approach */
"0FVC3DZ" = "1" /* Restriction of Ampulla of Vater with Intraluminal Device, Percutaneous Approach */
"0FVC3ZZ" = "1" /* Restriction of Ampulla of Vater, Percutaneous Approach */
"0FVC4CZ" = "1" /* Restriction of Ampulla of Vater with Extraluminal Device, Percutaneous Endoscopic Approach */
"0FVC4DZ" = "1" /* Restriction of Ampulla of Vater with Intraluminal Device, Percutaneous Endoscopic Approach */
"0FVC4ZZ" = "1" /* Restriction of Ampulla of Vater, Percutaneous Endoscopic Approach */
"0FVC7DZ" = "1" /* Restriction of Ampulla of Vater with Intraluminal Device, Via Natural or Artificial Opening */
"0FVC7ZZ" = "1" /* Restriction of Ampulla of Vater, Via Natural or Artificial Opening */
"0FVC8DZ" = "1" /* Restriction of Ampulla of Vater with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0FVC8ZZ" = "1" /* Restriction of Ampulla of Vater, Via Natural or Artificial Opening Endoscopic */
"0FVD0CZ" = "1" /* Restriction of Pancreatic Duct with Extraluminal Device, Open Approach */
"0FVD0DZ" = "1" /* Restriction of Pancreatic Duct with Intraluminal Device, Open Approach */
"0FVD0ZZ" = "1" /* Restriction of Pancreatic Duct, Open Approach */
"0FVD3CZ" = "1" /* Restriction of Pancreatic Duct with Extraluminal Device, Percutaneous Approach */
"0FVD3DZ" = "1" /* Restriction of Pancreatic Duct with Intraluminal Device, Percutaneous Approach */
"0FVD3ZZ" = "1" /* Restriction of Pancreatic Duct, Percutaneous Approach */
"0FVD4CZ" = "1" /* Restriction of Pancreatic Duct with Extraluminal Device, Percutaneous Endoscopic Approach */
"0FVD4DZ" = "1" /* Restriction of Pancreatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0FVD4ZZ" = "1" /* Restriction of Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FVD7DZ" = "1" /* Restriction of Pancreatic Duct with Intraluminal Device, Via Natural or Artificial Opening */
"0FVD7ZZ" = "1" /* Restriction of Pancreatic Duct, Via Natural or Artificial Opening */
"0FVD8DZ" = "1" /* Restriction of Pancreatic Duct with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0FVD8ZZ" = "1" /* Restriction of Pancreatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FVF0CZ" = "1" /* Restriction of Accessory Pancreatic Duct with Extraluminal Device, Open Approach */
"0FVF0DZ" = "1" /* Restriction of Accessory Pancreatic Duct with Intraluminal Device, Open Approach */
"0FVF0ZZ" = "1" /* Restriction of Accessory Pancreatic Duct, Open Approach */
"0FVF3CZ" = "1" /* Restriction of Accessory Pancreatic Duct with Extraluminal Device, Percutaneous Approach */
"0FVF3DZ" = "1" /* Restriction of Accessory Pancreatic Duct with Intraluminal Device, Percutaneous Approach */
"0FVF3ZZ" = "1" /* Restriction of Accessory Pancreatic Duct, Percutaneous Approach */
"0FVF4CZ" = "1" /* Restriction of Accessory Pancreatic Duct with Extraluminal Device, Percutaneous Endoscopic Approach */
"0FVF4DZ" = "1" /* Restriction of Accessory Pancreatic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"0FVF4ZZ" = "1" /* Restriction of Accessory Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FVF7DZ" = "1" /* Restriction of Accessory Pancreatic Duct with Intraluminal Device, Via Natural or Artificial Opening */
"0FVF7ZZ" = "1" /* Restriction of Accessory Pancreatic Duct, Via Natural or Artificial Opening */
"0FVF8DZ" = "1" /* Restriction of Accessory Pancreatic Duct with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0FVF8ZZ" = "1" /* Restriction of Accessory Pancreatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FW000Z" = "1" /* Revision of Drainage Device in Liver, Open Approach */
"0FW002Z" = "1" /* Revision of Monitoring Device in Liver, Open Approach */
"0FW003Z" = "1" /* Revision of Infusion Device in Liver, Open Approach */
"0FW030Z" = "1" /* Revision of Drainage Device in Liver, Percutaneous Approach */
"0FW032Z" = "1" /* Revision of Monitoring Device in Liver, Percutaneous Approach */
"0FW033Z" = "1" /* Revision of Infusion Device in Liver, Percutaneous Approach */
"0FW040Z" = "1" /* Revision of Drainage Device in Liver, Percutaneous Endoscopic Approach */
"0FW042Z" = "1" /* Revision of Monitoring Device in Liver, Percutaneous Endoscopic Approach */
"0FW043Z" = "1" /* Revision of Infusion Device in Liver, Percutaneous Endoscopic Approach */
"0FW400Z" = "1" /* Revision of Drainage Device in Gallbladder, Open Approach */
"0FW402Z" = "1" /* Revision of Monitoring Device in Gallbladder, Open Approach */
"0FW403Z" = "1" /* Revision of Infusion Device in Gallbladder, Open Approach */
"0FW40DZ" = "1" /* Revision of Intraluminal Device in Gallbladder, Open Approach */
"0FW430Z" = "1" /* Revision of Drainage Device in Gallbladder, Percutaneous Approach */
"0FW432Z" = "1" /* Revision of Monitoring Device in Gallbladder, Percutaneous Approach */
"0FW433Z" = "1" /* Revision of Infusion Device in Gallbladder, Percutaneous Approach */
"0FW43DZ" = "1" /* Revision of Intraluminal Device in Gallbladder, Percutaneous Approach */
"0FW440Z" = "1" /* Revision of Drainage Device in Gallbladder, Percutaneous Endoscopic Approach */
"0FW442Z" = "1" /* Revision of Monitoring Device in Gallbladder, Percutaneous Endoscopic Approach */
"0FW443Z" = "1" /* Revision of Infusion Device in Gallbladder, Percutaneous Endoscopic Approach */
"0FW44DZ" = "1" /* Revision of Intraluminal Device in Gallbladder, Percutaneous Endoscopic Approach */
"0FWB00Z" = "1" /* Revision of Drainage Device in Hepatobiliary Duct, Open Approach */
"0FWB02Z" = "1" /* Revision of Monitoring Device in Hepatobiliary Duct, Open Approach */
"0FWB03Z" = "1" /* Revision of Infusion Device in Hepatobiliary Duct, Open Approach */
"0FWB07Z" = "1" /* Revision of Autologous Tissue Substitute in Hepatobiliary Duct, Open Approach */
"0FWB0CZ" = "1" /* Revision of Extraluminal Device in Hepatobiliary Duct, Open Approach */
"0FWB0DZ" = "1" /* Revision of Intraluminal Device in Hepatobiliary Duct, Open Approach */
"0FWB0JZ" = "1" /* Revision of Synthetic Substitute in Hepatobiliary Duct, Open Approach */
"0FWB0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Hepatobiliary Duct, Open Approach */
"0FWB30Z" = "1" /* Revision of Drainage Device in Hepatobiliary Duct, Percutaneous Approach */
"0FWB32Z" = "1" /* Revision of Monitoring Device in Hepatobiliary Duct, Percutaneous Approach */
"0FWB33Z" = "1" /* Revision of Infusion Device in Hepatobiliary Duct, Percutaneous Approach */
"0FWB37Z" = "1" /* Revision of Autologous Tissue Substitute in Hepatobiliary Duct, Percutaneous Approach */
"0FWB3CZ" = "1" /* Revision of Extraluminal Device in Hepatobiliary Duct, Percutaneous Approach */
"0FWB3DZ" = "1" /* Revision of Intraluminal Device in Hepatobiliary Duct, Percutaneous Approach */
"0FWB3JZ" = "1" /* Revision of Synthetic Substitute in Hepatobiliary Duct, Percutaneous Approach */
"0FWB3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Hepatobiliary Duct, Percutaneous Approach */
"0FWB40Z" = "1" /* Revision of Drainage Device in Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FWB42Z" = "1" /* Revision of Monitoring Device in Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FWB43Z" = "1" /* Revision of Infusion Device in Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FWB47Z" = "1" /* Revision of Autologous Tissue Substitute in Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FWB4CZ" = "1" /* Revision of Extraluminal Device in Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FWB4DZ" = "1" /* Revision of Intraluminal Device in Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FWB4JZ" = "1" /* Revision of Synthetic Substitute in Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FWB4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Hepatobiliary Duct, Percutaneous Endoscopic Approach */
"0FWB70Z" = "1" /* Revision of Drainage Device in Hepatobiliary Duct, Via Natural or Artificial Opening */
"0FWB72Z" = "1" /* Revision of Monitoring Device in Hepatobiliary Duct, Via Natural or Artificial Opening */
"0FWB73Z" = "1" /* Revision of Infusion Device in Hepatobiliary Duct, Via Natural or Artificial Opening */
"0FWB77Z" = "1" /* Revision of Autologous Tissue Substitute in Hepatobiliary Duct, Via Natural or Artificial Opening */
"0FWB7CZ" = "1" /* Revision of Extraluminal Device in Hepatobiliary Duct, Via Natural or Artificial Opening */
"0FWB7DZ" = "1" /* Revision of Intraluminal Device in Hepatobiliary Duct, Via Natural or Artificial Opening */
"0FWB7JZ" = "1" /* Revision of Synthetic Substitute in Hepatobiliary Duct, Via Natural or Artificial Opening */
"0FWB7KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Hepatobiliary Duct, Via Natural or Artificial Opening */
"0FWB83Z" = "1" /* Revision of Infusion Device in Hepatobiliary Duct, Via Natural or Artificial Opening Endoscopic */
"0FWB87Z" = "1" /* Revision of Autologous Tissue Substitute in Hepatobiliary Duct, Via Natural or Artificial Opening Endoscopic */
"0FWB8CZ" = "1" /* Revision of Extraluminal Device in Hepatobiliary Duct, Via Natural or Artificial Opening Endoscopic */
"0FWB8JZ" = "1" /* Revision of Synthetic Substitute in Hepatobiliary Duct, Via Natural or Artificial Opening Endoscopic */
"0FWB8KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Hepatobiliary Duct, Via Natural or Artificial Opening Endoscopic */
"0FWD00Z" = "1" /* Revision of Drainage Device in Pancreatic Duct, Open Approach */
"0FWD02Z" = "1" /* Revision of Monitoring Device in Pancreatic Duct, Open Approach */
"0FWD03Z" = "1" /* Revision of Infusion Device in Pancreatic Duct, Open Approach */
"0FWD07Z" = "1" /* Revision of Autologous Tissue Substitute in Pancreatic Duct, Open Approach */
"0FWD0CZ" = "1" /* Revision of Extraluminal Device in Pancreatic Duct, Open Approach */
"0FWD0DZ" = "1" /* Revision of Intraluminal Device in Pancreatic Duct, Open Approach */
"0FWD0JZ" = "1" /* Revision of Synthetic Substitute in Pancreatic Duct, Open Approach */
"0FWD0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Pancreatic Duct, Open Approach */
"0FWD30Z" = "1" /* Revision of Drainage Device in Pancreatic Duct, Percutaneous Approach */
"0FWD32Z" = "1" /* Revision of Monitoring Device in Pancreatic Duct, Percutaneous Approach */
"0FWD33Z" = "1" /* Revision of Infusion Device in Pancreatic Duct, Percutaneous Approach */
"0FWD37Z" = "1" /* Revision of Autologous Tissue Substitute in Pancreatic Duct, Percutaneous Approach */
"0FWD3CZ" = "1" /* Revision of Extraluminal Device in Pancreatic Duct, Percutaneous Approach */
"0FWD3DZ" = "1" /* Revision of Intraluminal Device in Pancreatic Duct, Percutaneous Approach */
"0FWD3JZ" = "1" /* Revision of Synthetic Substitute in Pancreatic Duct, Percutaneous Approach */
"0FWD3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Pancreatic Duct, Percutaneous Approach */
"0FWD40Z" = "1" /* Revision of Drainage Device in Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FWD42Z" = "1" /* Revision of Monitoring Device in Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FWD43Z" = "1" /* Revision of Infusion Device in Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FWD47Z" = "1" /* Revision of Autologous Tissue Substitute in Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FWD4CZ" = "1" /* Revision of Extraluminal Device in Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FWD4DZ" = "1" /* Revision of Intraluminal Device in Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FWD4JZ" = "1" /* Revision of Synthetic Substitute in Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FWD4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Pancreatic Duct, Percutaneous Endoscopic Approach */
"0FWD70Z" = "1" /* Revision of Drainage Device in Pancreatic Duct, Via Natural or Artificial Opening */
"0FWD72Z" = "1" /* Revision of Monitoring Device in Pancreatic Duct, Via Natural or Artificial Opening */
"0FWD73Z" = "1" /* Revision of Infusion Device in Pancreatic Duct, Via Natural or Artificial Opening */
"0FWD77Z" = "1" /* Revision of Autologous Tissue Substitute in Pancreatic Duct, Via Natural or Artificial Opening */
"0FWD7CZ" = "1" /* Revision of Extraluminal Device in Pancreatic Duct, Via Natural or Artificial Opening */
"0FWD7DZ" = "1" /* Revision of Intraluminal Device in Pancreatic Duct, Via Natural or Artificial Opening */
"0FWD7JZ" = "1" /* Revision of Synthetic Substitute in Pancreatic Duct, Via Natural or Artificial Opening */
"0FWD7KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Pancreatic Duct, Via Natural or Artificial Opening */
"0FWD83Z" = "1" /* Revision of Infusion Device in Pancreatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FWD87Z" = "1" /* Revision of Autologous Tissue Substitute in Pancreatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FWD8CZ" = "1" /* Revision of Extraluminal Device in Pancreatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FWD8JZ" = "1" /* Revision of Synthetic Substitute in Pancreatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FWD8KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Pancreatic Duct, Via Natural or Artificial Opening Endoscopic */
"0FWG00Z" = "1" /* Revision of Drainage Device in Pancreas, Open Approach */
"0FWG02Z" = "1" /* Revision of Monitoring Device in Pancreas, Open Approach */
"0FWG03Z" = "1" /* Revision of Infusion Device in Pancreas, Open Approach */
"0FWG0DZ" = "1" /* Revision of Intraluminal Device in Pancreas, Open Approach */
"0FWG30Z" = "1" /* Revision of Drainage Device in Pancreas, Percutaneous Approach */
"0FWG32Z" = "1" /* Revision of Monitoring Device in Pancreas, Percutaneous Approach */
"0FWG33Z" = "1" /* Revision of Infusion Device in Pancreas, Percutaneous Approach */
"0FWG3DZ" = "1" /* Revision of Intraluminal Device in Pancreas, Percutaneous Approach */
"0FWG40Z" = "1" /* Revision of Drainage Device in Pancreas, Percutaneous Endoscopic Approach */
"0FWG42Z" = "1" /* Revision of Monitoring Device in Pancreas, Percutaneous Endoscopic Approach */
"0FWG43Z" = "1" /* Revision of Infusion Device in Pancreas, Percutaneous Endoscopic Approach */
"0FWG4DZ" = "1" /* Revision of Intraluminal Device in Pancreas, Percutaneous Endoscopic Approach */
"0FY00Z0" = "1" /* Transplantation of Liver, Allogeneic, Open Approach */
"0FY00Z1" = "1" /* Transplantation of Liver, Syngeneic, Open Approach */
"0FY00Z2" = "1" /* Transplantation of Liver, Zooplastic, Open Approach */
"0FYG0Z0" = "1" /* Transplantation of Pancreas, Allogeneic, Open Approach */
"0FYG0Z1" = "1" /* Transplantation of Pancreas, Syngeneic, Open Approach */
"0FYG0Z2" = "1" /* Transplantation of Pancreas, Zooplastic, Open Approach */
"0G500ZZ" = "1" /* Destruction of Pituitary Gland, Open Approach */
"0G503ZZ" = "1" /* Destruction of Pituitary Gland, Percutaneous Approach */
"0G504ZZ" = "1" /* Destruction of Pituitary Gland, Percutaneous Endoscopic Approach */
"0G510ZZ" = "1" /* Destruction of Pineal Body, Open Approach */
"0G513ZZ" = "1" /* Destruction of Pineal Body, Percutaneous Approach */
"0G514ZZ" = "1" /* Destruction of Pineal Body, Percutaneous Endoscopic Approach */
"0G520ZZ" = "1" /* Destruction of Left Adrenal Gland, Open Approach */
"0G523ZZ" = "1" /* Destruction of Left Adrenal Gland, Percutaneous Approach */
"0G524ZZ" = "1" /* Destruction of Left Adrenal Gland, Percutaneous Endoscopic Approach */
"0G530ZZ" = "1" /* Destruction of Right Adrenal Gland, Open Approach */
"0G533ZZ" = "1" /* Destruction of Right Adrenal Gland, Percutaneous Approach */
"0G534ZZ" = "1" /* Destruction of Right Adrenal Gland, Percutaneous Endoscopic Approach */
"0G540ZZ" = "1" /* Destruction of Bilateral Adrenal Glands, Open Approach */
"0G543ZZ" = "1" /* Destruction of Bilateral Adrenal Glands, Percutaneous Approach */
"0G544ZZ" = "1" /* Destruction of Bilateral Adrenal Glands, Percutaneous Endoscopic Approach */
"0G5G0ZZ" = "1" /* Destruction of Left Thyroid Gland Lobe, Open Approach */
"0G5G3ZZ" = "1" /* Destruction of Left Thyroid Gland Lobe, Percutaneous Approach */
"0G5G4ZZ" = "1" /* Destruction of Left Thyroid Gland Lobe, Percutaneous Endoscopic Approach */
"0G5H0ZZ" = "1" /* Destruction of Right Thyroid Gland Lobe, Open Approach */
"0G5H3ZZ" = "1" /* Destruction of Right Thyroid Gland Lobe, Percutaneous Approach */
"0G5H4ZZ" = "1" /* Destruction of Right Thyroid Gland Lobe, Percutaneous Endoscopic Approach */
"0G5K0ZZ" = "1" /* Destruction of Thyroid Gland, Open Approach */
"0G5K3ZZ" = "1" /* Destruction of Thyroid Gland, Percutaneous Approach */
"0G5K4ZZ" = "1" /* Destruction of Thyroid Gland, Percutaneous Endoscopic Approach */
"0G5L0ZZ" = "1" /* Destruction of Right Superior Parathyroid Gland, Open Approach */
"0G5L3ZZ" = "1" /* Destruction of Right Superior Parathyroid Gland, Percutaneous Approach */
"0G5L4ZZ" = "1" /* Destruction of Right Superior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0G5M0ZZ" = "1" /* Destruction of Left Superior Parathyroid Gland, Open Approach */
"0G5M3ZZ" = "1" /* Destruction of Left Superior Parathyroid Gland, Percutaneous Approach */
"0G5M4ZZ" = "1" /* Destruction of Left Superior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0G5N0ZZ" = "1" /* Destruction of Right Inferior Parathyroid Gland, Open Approach */
"0G5N3ZZ" = "1" /* Destruction of Right Inferior Parathyroid Gland, Percutaneous Approach */
"0G5N4ZZ" = "1" /* Destruction of Right Inferior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0G5P0ZZ" = "1" /* Destruction of Left Inferior Parathyroid Gland, Open Approach */
"0G5P3ZZ" = "1" /* Destruction of Left Inferior Parathyroid Gland, Percutaneous Approach */
"0G5P4ZZ" = "1" /* Destruction of Left Inferior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0G5Q0ZZ" = "1" /* Destruction of Multiple Parathyroid Glands, Open Approach */
"0G5Q3ZZ" = "1" /* Destruction of Multiple Parathyroid Glands, Percutaneous Approach */
"0G5Q4ZZ" = "1" /* Destruction of Multiple Parathyroid Glands, Percutaneous Endoscopic Approach */
"0G5R0ZZ" = "1" /* Destruction of Parathyroid Gland, Open Approach */
"0G5R3ZZ" = "1" /* Destruction of Parathyroid Gland, Percutaneous Approach */
"0G5R4ZZ" = "1" /* Destruction of Parathyroid Gland, Percutaneous Endoscopic Approach */
"0G800ZZ" = "1" /* Division of Pituitary Gland, Open Approach */
"0G803ZZ" = "1" /* Division of Pituitary Gland, Percutaneous Approach */
"0G804ZZ" = "1" /* Division of Pituitary Gland, Percutaneous Endoscopic Approach */
"0G8J0ZZ" = "1" /* Division of Thyroid Gland Isthmus, Open Approach */
"0G8J3ZZ" = "1" /* Division of Thyroid Gland Isthmus, Percutaneous Approach */
"0G8J4ZZ" = "1" /* Division of Thyroid Gland Isthmus, Percutaneous Endoscopic Approach */
"0G9000Z" = "1" /* Drainage of Pituitary Gland with Drainage Device, Open Approach */
"0G900ZX" = "1" /* Drainage of Pituitary Gland, Open Approach, Diagnostic */
"0G900ZZ" = "1" /* Drainage of Pituitary Gland, Open Approach */
"0G9040Z" = "1" /* Drainage of Pituitary Gland with Drainage Device, Percutaneous Endoscopic Approach */
"0G904ZX" = "1" /* Drainage of Pituitary Gland, Percutaneous Endoscopic Approach, Diagnostic */
"0G904ZZ" = "1" /* Drainage of Pituitary Gland, Percutaneous Endoscopic Approach */
"0G9100Z" = "1" /* Drainage of Pineal Body with Drainage Device, Open Approach */
"0G910ZX" = "1" /* Drainage of Pineal Body, Open Approach, Diagnostic */
"0G910ZZ" = "1" /* Drainage of Pineal Body, Open Approach */
"0G9140Z" = "1" /* Drainage of Pineal Body with Drainage Device, Percutaneous Endoscopic Approach */
"0G914ZX" = "1" /* Drainage of Pineal Body, Percutaneous Endoscopic Approach, Diagnostic */
"0G914ZZ" = "1" /* Drainage of Pineal Body, Percutaneous Endoscopic Approach */
"0G9200Z" = "1" /* Drainage of Left Adrenal Gland with Drainage Device, Open Approach */
"0G920ZX" = "1" /* Drainage of Left Adrenal Gland, Open Approach, Diagnostic */
"0G920ZZ" = "1" /* Drainage of Left Adrenal Gland, Open Approach */
"0G9240Z" = "1" /* Drainage of Left Adrenal Gland with Drainage Device, Percutaneous Endoscopic Approach */
"0G924ZZ" = "1" /* Drainage of Left Adrenal Gland, Percutaneous Endoscopic Approach */
"0G9300Z" = "1" /* Drainage of Right Adrenal Gland with Drainage Device, Open Approach */
"0G930ZX" = "1" /* Drainage of Right Adrenal Gland, Open Approach, Diagnostic */
"0G930ZZ" = "1" /* Drainage of Right Adrenal Gland, Open Approach */
"0G9340Z" = "1" /* Drainage of Right Adrenal Gland with Drainage Device, Percutaneous Endoscopic Approach */
"0G934ZZ" = "1" /* Drainage of Right Adrenal Gland, Percutaneous Endoscopic Approach */
"0G9400Z" = "1" /* Drainage of Bilateral Adrenal Glands with Drainage Device, Open Approach */
"0G940ZX" = "1" /* Drainage of Bilateral Adrenal Glands, Open Approach, Diagnostic */
"0G940ZZ" = "1" /* Drainage of Bilateral Adrenal Glands, Open Approach */
"0G9440Z" = "1" /* Drainage of Bilateral Adrenal Glands with Drainage Device, Percutaneous Endoscopic Approach */
"0G944ZZ" = "1" /* Drainage of Bilateral Adrenal Glands, Percutaneous Endoscopic Approach */
"0G9G00Z" = "1" /* Drainage of Left Thyroid Gland Lobe with Drainage Device, Open Approach */
"0G9G0ZX" = "1" /* Drainage of Left Thyroid Gland Lobe, Open Approach, Diagnostic */
"0G9G0ZZ" = "1" /* Drainage of Left Thyroid Gland Lobe, Open Approach */
"0G9H00Z" = "1" /* Drainage of Right Thyroid Gland Lobe with Drainage Device, Open Approach */
"0G9H0ZX" = "1" /* Drainage of Right Thyroid Gland Lobe, Open Approach, Diagnostic */
"0G9H0ZZ" = "1" /* Drainage of Right Thyroid Gland Lobe, Open Approach */
"0G9K00Z" = "1" /* Drainage of Thyroid Gland with Drainage Device, Open Approach */
"0G9K0ZX" = "1" /* Drainage of Thyroid Gland, Open Approach, Diagnostic */
"0G9K0ZZ" = "1" /* Drainage of Thyroid Gland, Open Approach */
"0G9L00Z" = "1" /* Drainage of Right Superior Parathyroid Gland with Drainage Device, Open Approach */
"0G9L0ZX" = "1" /* Drainage of Right Superior Parathyroid Gland, Open Approach, Diagnostic */
"0G9L0ZZ" = "1" /* Drainage of Right Superior Parathyroid Gland, Open Approach */
"0G9L4ZX" = "1" /* Drainage of Right Superior Parathyroid Gland, Percutaneous Endoscopic Approach, Diagnostic */
"0G9M00Z" = "1" /* Drainage of Left Superior Parathyroid Gland with Drainage Device, Open Approach */
"0G9M0ZX" = "1" /* Drainage of Left Superior Parathyroid Gland, Open Approach, Diagnostic */
"0G9M0ZZ" = "1" /* Drainage of Left Superior Parathyroid Gland, Open Approach */
"0G9M4ZX" = "1" /* Drainage of Left Superior Parathyroid Gland, Percutaneous Endoscopic Approach, Diagnostic */
"0G9N00Z" = "1" /* Drainage of Right Inferior Parathyroid Gland with Drainage Device, Open Approach */
"0G9N0ZX" = "1" /* Drainage of Right Inferior Parathyroid Gland, Open Approach, Diagnostic */
"0G9N0ZZ" = "1" /* Drainage of Right Inferior Parathyroid Gland, Open Approach */
"0G9N4ZX" = "1" /* Drainage of Right Inferior Parathyroid Gland, Percutaneous Endoscopic Approach, Diagnostic */
"0G9P00Z" = "1" /* Drainage of Left Inferior Parathyroid Gland with Drainage Device, Open Approach */
"0G9P0ZX" = "1" /* Drainage of Left Inferior Parathyroid Gland, Open Approach, Diagnostic */
"0G9P0ZZ" = "1" /* Drainage of Left Inferior Parathyroid Gland, Open Approach */
"0G9P4ZX" = "1" /* Drainage of Left Inferior Parathyroid Gland, Percutaneous Endoscopic Approach, Diagnostic */
"0G9Q00Z" = "1" /* Drainage of Multiple Parathyroid Glands with Drainage Device, Open Approach */
"0G9Q0ZX" = "1" /* Drainage of Multiple Parathyroid Glands, Open Approach, Diagnostic */
"0G9Q0ZZ" = "1" /* Drainage of Multiple Parathyroid Glands, Open Approach */
"0G9Q4ZX" = "1" /* Drainage of Multiple Parathyroid Glands, Percutaneous Endoscopic Approach, Diagnostic */
"0G9R00Z" = "1" /* Drainage of Parathyroid Gland with Drainage Device, Open Approach */
"0G9R0ZX" = "1" /* Drainage of Parathyroid Gland, Open Approach, Diagnostic */
"0G9R0ZZ" = "1" /* Drainage of Parathyroid Gland, Open Approach */
"0G9R4ZX" = "1" /* Drainage of Parathyroid Gland, Percutaneous Endoscopic Approach, Diagnostic */
"0GB00ZX" = "1" /* Excision of Pituitary Gland, Open Approach, Diagnostic */
"0GB00ZZ" = "1" /* Excision of Pituitary Gland, Open Approach */
"0GB03ZX" = "1" /* Excision of Pituitary Gland, Percutaneous Approach, Diagnostic */
"0GB03ZZ" = "1" /* Excision of Pituitary Gland, Percutaneous Approach */
"0GB04ZX" = "1" /* Excision of Pituitary Gland, Percutaneous Endoscopic Approach, Diagnostic */
"0GB04ZZ" = "1" /* Excision of Pituitary Gland, Percutaneous Endoscopic Approach */
"0GB10ZX" = "1" /* Excision of Pineal Body, Open Approach, Diagnostic */
"0GB10ZZ" = "1" /* Excision of Pineal Body, Open Approach */
"0GB13ZX" = "1" /* Excision of Pineal Body, Percutaneous Approach, Diagnostic */
"0GB13ZZ" = "1" /* Excision of Pineal Body, Percutaneous Approach */
"0GB14ZX" = "1" /* Excision of Pineal Body, Percutaneous Endoscopic Approach, Diagnostic */
"0GB14ZZ" = "1" /* Excision of Pineal Body, Percutaneous Endoscopic Approach */
"0GB20ZX" = "1" /* Excision of Left Adrenal Gland, Open Approach, Diagnostic */
"0GB20ZZ" = "1" /* Excision of Left Adrenal Gland, Open Approach */
"0GB23ZZ" = "1" /* Excision of Left Adrenal Gland, Percutaneous Approach */
"0GB24ZZ" = "1" /* Excision of Left Adrenal Gland, Percutaneous Endoscopic Approach */
"0GB30ZX" = "1" /* Excision of Right Adrenal Gland, Open Approach, Diagnostic */
"0GB30ZZ" = "1" /* Excision of Right Adrenal Gland, Open Approach */
"0GB33ZZ" = "1" /* Excision of Right Adrenal Gland, Percutaneous Approach */
"0GB34ZZ" = "1" /* Excision of Right Adrenal Gland, Percutaneous Endoscopic Approach */
"0GB40ZX" = "1" /* Excision of Bilateral Adrenal Glands, Open Approach, Diagnostic */
"0GB40ZZ" = "1" /* Excision of Bilateral Adrenal Glands, Open Approach */
"0GB43ZZ" = "1" /* Excision of Bilateral Adrenal Glands, Percutaneous Approach */
"0GB44ZZ" = "1" /* Excision of Bilateral Adrenal Glands, Percutaneous Endoscopic Approach */
"0GBG0ZX" = "1" /* Excision of Left Thyroid Gland Lobe, Open Approach, Diagnostic */
"0GBG0ZZ" = "1" /* Excision of Left Thyroid Gland Lobe, Open Approach */
"0GBG3ZZ" = "1" /* Excision of Left Thyroid Gland Lobe, Percutaneous Approach */
"0GBG4ZZ" = "1" /* Excision of Left Thyroid Gland Lobe, Percutaneous Endoscopic Approach */
"0GBH0ZX" = "1" /* Excision of Right Thyroid Gland Lobe, Open Approach, Diagnostic */
"0GBH0ZZ" = "1" /* Excision of Right Thyroid Gland Lobe, Open Approach */
"0GBH3ZZ" = "1" /* Excision of Right Thyroid Gland Lobe, Percutaneous Approach */
"0GBH4ZZ" = "1" /* Excision of Right Thyroid Gland Lobe, Percutaneous Endoscopic Approach */
"0GBL0ZX" = "1" /* Excision of Right Superior Parathyroid Gland, Open Approach, Diagnostic */
"0GBL0ZZ" = "1" /* Excision of Right Superior Parathyroid Gland, Open Approach */
"0GBL3ZX" = "1" /* Excision of Right Superior Parathyroid Gland, Percutaneous Approach, Diagnostic */
"0GBL3ZZ" = "1" /* Excision of Right Superior Parathyroid Gland, Percutaneous Approach */
"0GBL4ZX" = "1" /* Excision of Right Superior Parathyroid Gland, Percutaneous Endoscopic Approach, Diagnostic */
"0GBL4ZZ" = "1" /* Excision of Right Superior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GBM0ZX" = "1" /* Excision of Left Superior Parathyroid Gland, Open Approach, Diagnostic */
"0GBM0ZZ" = "1" /* Excision of Left Superior Parathyroid Gland, Open Approach */
"0GBM3ZX" = "1" /* Excision of Left Superior Parathyroid Gland, Percutaneous Approach, Diagnostic */
"0GBM3ZZ" = "1" /* Excision of Left Superior Parathyroid Gland, Percutaneous Approach */
"0GBM4ZX" = "1" /* Excision of Left Superior Parathyroid Gland, Percutaneous Endoscopic Approach, Diagnostic */
"0GBM4ZZ" = "1" /* Excision of Left Superior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GBN0ZX" = "1" /* Excision of Right Inferior Parathyroid Gland, Open Approach, Diagnostic */
"0GBN0ZZ" = "1" /* Excision of Right Inferior Parathyroid Gland, Open Approach */
"0GBN3ZX" = "1" /* Excision of Right Inferior Parathyroid Gland, Percutaneous Approach, Diagnostic */
"0GBN3ZZ" = "1" /* Excision of Right Inferior Parathyroid Gland, Percutaneous Approach */
"0GBN4ZX" = "1" /* Excision of Right Inferior Parathyroid Gland, Percutaneous Endoscopic Approach, Diagnostic */
"0GBN4ZZ" = "1" /* Excision of Right Inferior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GBP0ZX" = "1" /* Excision of Left Inferior Parathyroid Gland, Open Approach, Diagnostic */
"0GBP0ZZ" = "1" /* Excision of Left Inferior Parathyroid Gland, Open Approach */
"0GBP3ZX" = "1" /* Excision of Left Inferior Parathyroid Gland, Percutaneous Approach, Diagnostic */
"0GBP3ZZ" = "1" /* Excision of Left Inferior Parathyroid Gland, Percutaneous Approach */
"0GBP4ZX" = "1" /* Excision of Left Inferior Parathyroid Gland, Percutaneous Endoscopic Approach, Diagnostic */
"0GBP4ZZ" = "1" /* Excision of Left Inferior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GBQ0ZX" = "1" /* Excision of Multiple Parathyroid Glands, Open Approach, Diagnostic */
"0GBQ0ZZ" = "1" /* Excision of Multiple Parathyroid Glands, Open Approach */
"0GBQ3ZX" = "1" /* Excision of Multiple Parathyroid Glands, Percutaneous Approach, Diagnostic */
"0GBQ3ZZ" = "1" /* Excision of Multiple Parathyroid Glands, Percutaneous Approach */
"0GBQ4ZX" = "1" /* Excision of Multiple Parathyroid Glands, Percutaneous Endoscopic Approach, Diagnostic */
"0GBQ4ZZ" = "1" /* Excision of Multiple Parathyroid Glands, Percutaneous Endoscopic Approach */
"0GBR0ZX" = "1" /* Excision of Parathyroid Gland, Open Approach, Diagnostic */
"0GBR0ZZ" = "1" /* Excision of Parathyroid Gland, Open Approach */
"0GBR3ZX" = "1" /* Excision of Parathyroid Gland, Percutaneous Approach, Diagnostic */
"0GBR3ZZ" = "1" /* Excision of Parathyroid Gland, Percutaneous Approach */
"0GBR4ZX" = "1" /* Excision of Parathyroid Gland, Percutaneous Endoscopic Approach, Diagnostic */
"0GBR4ZZ" = "1" /* Excision of Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GC00ZZ" = "1" /* Extirpation of Matter from Pituitary Gland, Open Approach */
"0GC03ZZ" = "1" /* Extirpation of Matter from Pituitary Gland, Percutaneous Approach */
"0GC04ZZ" = "1" /* Extirpation of Matter from Pituitary Gland, Percutaneous Endoscopic Approach */
"0GC10ZZ" = "1" /* Extirpation of Matter from Pineal Body, Open Approach */
"0GC13ZZ" = "1" /* Extirpation of Matter from Pineal Body, Percutaneous Approach */
"0GC14ZZ" = "1" /* Extirpation of Matter from Pineal Body, Percutaneous Endoscopic Approach */
"0GC20ZZ" = "1" /* Extirpation of Matter from Left Adrenal Gland, Open Approach */
"0GC23ZZ" = "1" /* Extirpation of Matter from Left Adrenal Gland, Percutaneous Approach */
"0GC24ZZ" = "1" /* Extirpation of Matter from Left Adrenal Gland, Percutaneous Endoscopic Approach */
"0GC30ZZ" = "1" /* Extirpation of Matter from Right Adrenal Gland, Open Approach */
"0GC33ZZ" = "1" /* Extirpation of Matter from Right Adrenal Gland, Percutaneous Approach */
"0GC34ZZ" = "1" /* Extirpation of Matter from Right Adrenal Gland, Percutaneous Endoscopic Approach */
"0GC40ZZ" = "1" /* Extirpation of Matter from Bilateral Adrenal Glands, Open Approach */
"0GC43ZZ" = "1" /* Extirpation of Matter from Bilateral Adrenal Glands, Percutaneous Approach */
"0GC44ZZ" = "1" /* Extirpation of Matter from Bilateral Adrenal Glands, Percutaneous Endoscopic Approach */
"0GCG0ZZ" = "1" /* Extirpation of Matter from Left Thyroid Gland Lobe, Open Approach */
"0GCG3ZZ" = "1" /* Extirpation of Matter from Left Thyroid Gland Lobe, Percutaneous Approach */
"0GCG4ZZ" = "1" /* Extirpation of Matter from Left Thyroid Gland Lobe, Percutaneous Endoscopic Approach */
"0GCH0ZZ" = "1" /* Extirpation of Matter from Right Thyroid Gland Lobe, Open Approach */
"0GCH3ZZ" = "1" /* Extirpation of Matter from Right Thyroid Gland Lobe, Percutaneous Approach */
"0GCH4ZZ" = "1" /* Extirpation of Matter from Right Thyroid Gland Lobe, Percutaneous Endoscopic Approach */
"0GCK0ZZ" = "1" /* Extirpation of Matter from Thyroid Gland, Open Approach */
"0GCK3ZZ" = "1" /* Extirpation of Matter from Thyroid Gland, Percutaneous Approach */
"0GCK4ZZ" = "1" /* Extirpation of Matter from Thyroid Gland, Percutaneous Endoscopic Approach */
"0GCL0ZZ" = "1" /* Extirpation of Matter from Right Superior Parathyroid Gland, Open Approach */
"0GCL3ZZ" = "1" /* Extirpation of Matter from Right Superior Parathyroid Gland, Percutaneous Approach */
"0GCL4ZZ" = "1" /* Extirpation of Matter from Right Superior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GCM0ZZ" = "1" /* Extirpation of Matter from Left Superior Parathyroid Gland, Open Approach */
"0GCM3ZZ" = "1" /* Extirpation of Matter from Left Superior Parathyroid Gland, Percutaneous Approach */
"0GCM4ZZ" = "1" /* Extirpation of Matter from Left Superior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GCN0ZZ" = "1" /* Extirpation of Matter from Right Inferior Parathyroid Gland, Open Approach */
"0GCN3ZZ" = "1" /* Extirpation of Matter from Right Inferior Parathyroid Gland, Percutaneous Approach */
"0GCN4ZZ" = "1" /* Extirpation of Matter from Right Inferior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GCP0ZZ" = "1" /* Extirpation of Matter from Left Inferior Parathyroid Gland, Open Approach */
"0GCP3ZZ" = "1" /* Extirpation of Matter from Left Inferior Parathyroid Gland, Percutaneous Approach */
"0GCP4ZZ" = "1" /* Extirpation of Matter from Left Inferior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GCQ0ZZ" = "1" /* Extirpation of Matter from Multiple Parathyroid Glands, Open Approach */
"0GCQ3ZZ" = "1" /* Extirpation of Matter from Multiple Parathyroid Glands, Percutaneous Approach */
"0GCQ4ZZ" = "1" /* Extirpation of Matter from Multiple Parathyroid Glands, Percutaneous Endoscopic Approach */
"0GCR0ZZ" = "1" /* Extirpation of Matter from Parathyroid Gland, Open Approach */
"0GCR3ZZ" = "1" /* Extirpation of Matter from Parathyroid Gland, Percutaneous Approach */
"0GCR4ZZ" = "1" /* Extirpation of Matter from Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GHS02Z" = "1" /* Insertion of Monitoring Device into Endocrine Gland, Open Approach */
"0GHS03Z" = "1" /* Insertion of Infusion Device into Endocrine Gland, Open Approach */
"0GHS32Z" = "1" /* Insertion of Monitoring Device into Endocrine Gland, Percutaneous Approach */
"0GHS33Z" = "1" /* Insertion of Infusion Device into Endocrine Gland, Percutaneous Approach */
"0GHS42Z" = "1" /* Insertion of Monitoring Device into Endocrine Gland, Percutaneous Endoscopic Approach */
"0GHS43Z" = "1" /* Insertion of Infusion Device into Endocrine Gland, Percutaneous Endoscopic Approach */
"0GJ00ZZ" = "1" /* Inspection of Pituitary Gland, Open Approach */
"0GJ04ZZ" = "1" /* Inspection of Pituitary Gland, Percutaneous Endoscopic Approach */
"0GJ10ZZ" = "1" /* Inspection of Pineal Body, Open Approach */
"0GJ14ZZ" = "1" /* Inspection of Pineal Body, Percutaneous Endoscopic Approach */
"0GJ50ZZ" = "1" /* Inspection of Adrenal Gland, Open Approach */
"0GJ54ZZ" = "1" /* Inspection of Adrenal Gland, Percutaneous Endoscopic Approach */
"0GJK0ZZ" = "1" /* Inspection of Thyroid Gland, Open Approach */
"0GJK4ZZ" = "1" /* Inspection of Thyroid Gland, Percutaneous Endoscopic Approach */
"0GJR0ZZ" = "1" /* Inspection of Parathyroid Gland, Open Approach */
"0GJR4ZZ" = "1" /* Inspection of Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GJS0ZZ" = "1" /* Inspection of Endocrine Gland, Open Approach */
"0GJS4ZZ" = "1" /* Inspection of Endocrine Gland, Percutaneous Endoscopic Approach */
"0GM20ZZ" = "1" /* Reattachment of Left Adrenal Gland, Open Approach */
"0GM24ZZ" = "1" /* Reattachment of Left Adrenal Gland, Percutaneous Endoscopic Approach */
"0GM30ZZ" = "1" /* Reattachment of Right Adrenal Gland, Open Approach */
"0GM34ZZ" = "1" /* Reattachment of Right Adrenal Gland, Percutaneous Endoscopic Approach */
"0GMG0ZZ" = "1" /* Reattachment of Left Thyroid Gland Lobe, Open Approach */
"0GMG4ZZ" = "1" /* Reattachment of Left Thyroid Gland Lobe, Percutaneous Endoscopic Approach */
"0GMH0ZZ" = "1" /* Reattachment of Right Thyroid Gland Lobe, Open Approach */
"0GMH4ZZ" = "1" /* Reattachment of Right Thyroid Gland Lobe, Percutaneous Endoscopic Approach */
"0GML0ZZ" = "1" /* Reattachment of Right Superior Parathyroid Gland, Open Approach */
"0GML4ZZ" = "1" /* Reattachment of Right Superior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GMM0ZZ" = "1" /* Reattachment of Left Superior Parathyroid Gland, Open Approach */
"0GMM4ZZ" = "1" /* Reattachment of Left Superior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GMN0ZZ" = "1" /* Reattachment of Right Inferior Parathyroid Gland, Open Approach */
"0GMN4ZZ" = "1" /* Reattachment of Right Inferior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GMP0ZZ" = "1" /* Reattachment of Left Inferior Parathyroid Gland, Open Approach */
"0GMP4ZZ" = "1" /* Reattachment of Left Inferior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GMQ0ZZ" = "1" /* Reattachment of Multiple Parathyroid Glands, Open Approach */
"0GMQ4ZZ" = "1" /* Reattachment of Multiple Parathyroid Glands, Percutaneous Endoscopic Approach */
"0GMR0ZZ" = "1" /* Reattachment of Parathyroid Gland, Open Approach */
"0GMR4ZZ" = "1" /* Reattachment of Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GN00ZZ" = "1" /* Release Pituitary Gland, Open Approach */
"0GN03ZZ" = "1" /* Release Pituitary Gland, Percutaneous Approach */
"0GN04ZZ" = "1" /* Release Pituitary Gland, Percutaneous Endoscopic Approach */
"0GN10ZZ" = "1" /* Release Pineal Body, Open Approach */
"0GN13ZZ" = "1" /* Release Pineal Body, Percutaneous Approach */
"0GN14ZZ" = "1" /* Release Pineal Body, Percutaneous Endoscopic Approach */
"0GN20ZZ" = "1" /* Release Left Adrenal Gland, Open Approach */
"0GN23ZZ" = "1" /* Release Left Adrenal Gland, Percutaneous Approach */
"0GN24ZZ" = "1" /* Release Left Adrenal Gland, Percutaneous Endoscopic Approach */
"0GN30ZZ" = "1" /* Release Right Adrenal Gland, Open Approach */
"0GN33ZZ" = "1" /* Release Right Adrenal Gland, Percutaneous Approach */
"0GN34ZZ" = "1" /* Release Right Adrenal Gland, Percutaneous Endoscopic Approach */
"0GN40ZZ" = "1" /* Release Bilateral Adrenal Glands, Open Approach */
"0GN43ZZ" = "1" /* Release Bilateral Adrenal Glands, Percutaneous Approach */
"0GN44ZZ" = "1" /* Release Bilateral Adrenal Glands, Percutaneous Endoscopic Approach */
"0GNG0ZZ" = "1" /* Release Left Thyroid Gland Lobe, Open Approach */
"0GNG3ZZ" = "1" /* Release Left Thyroid Gland Lobe, Percutaneous Approach */
"0GNG4ZZ" = "1" /* Release Left Thyroid Gland Lobe, Percutaneous Endoscopic Approach */
"0GNH0ZZ" = "1" /* Release Right Thyroid Gland Lobe, Open Approach */
"0GNH3ZZ" = "1" /* Release Right Thyroid Gland Lobe, Percutaneous Approach */
"0GNH4ZZ" = "1" /* Release Right Thyroid Gland Lobe, Percutaneous Endoscopic Approach */
"0GNK0ZZ" = "1" /* Release Thyroid Gland, Open Approach */
"0GNK3ZZ" = "1" /* Release Thyroid Gland, Percutaneous Approach */
"0GNK4ZZ" = "1" /* Release Thyroid Gland, Percutaneous Endoscopic Approach */
"0GNL0ZZ" = "1" /* Release Right Superior Parathyroid Gland, Open Approach */
"0GNL3ZZ" = "1" /* Release Right Superior Parathyroid Gland, Percutaneous Approach */
"0GNL4ZZ" = "1" /* Release Right Superior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GNM0ZZ" = "1" /* Release Left Superior Parathyroid Gland, Open Approach */
"0GNM3ZZ" = "1" /* Release Left Superior Parathyroid Gland, Percutaneous Approach */
"0GNM4ZZ" = "1" /* Release Left Superior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GNN0ZZ" = "1" /* Release Right Inferior Parathyroid Gland, Open Approach */
"0GNN3ZZ" = "1" /* Release Right Inferior Parathyroid Gland, Percutaneous Approach */
"0GNN4ZZ" = "1" /* Release Right Inferior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GNP0ZZ" = "1" /* Release Left Inferior Parathyroid Gland, Open Approach */
"0GNP3ZZ" = "1" /* Release Left Inferior Parathyroid Gland, Percutaneous Approach */
"0GNP4ZZ" = "1" /* Release Left Inferior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GNQ0ZZ" = "1" /* Release Multiple Parathyroid Glands, Open Approach */
"0GNQ3ZZ" = "1" /* Release Multiple Parathyroid Glands, Percutaneous Approach */
"0GNQ4ZZ" = "1" /* Release Multiple Parathyroid Glands, Percutaneous Endoscopic Approach */
"0GNR0ZZ" = "1" /* Release Parathyroid Gland, Open Approach */
"0GNR3ZZ" = "1" /* Release Parathyroid Gland, Percutaneous Approach */
"0GNR4ZZ" = "1" /* Release Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GP000Z" = "1" /* Removal of Drainage Device from Pituitary Gland, Open Approach */
"0GP030Z" = "1" /* Removal of Drainage Device from Pituitary Gland, Percutaneous Approach */
"0GP040Z" = "1" /* Removal of Drainage Device from Pituitary Gland, Percutaneous Endoscopic Approach */
"0GP100Z" = "1" /* Removal of Drainage Device from Pineal Body, Open Approach */
"0GP130Z" = "1" /* Removal of Drainage Device from Pineal Body, Percutaneous Approach */
"0GP140Z" = "1" /* Removal of Drainage Device from Pineal Body, Percutaneous Endoscopic Approach */
"0GP500Z" = "1" /* Removal of Drainage Device from Adrenal Gland, Open Approach */
"0GP530Z" = "1" /* Removal of Drainage Device from Adrenal Gland, Percutaneous Approach */
"0GP540Z" = "1" /* Removal of Drainage Device from Adrenal Gland, Percutaneous Endoscopic Approach */
"0GPK00Z" = "1" /* Removal of Drainage Device from Thyroid Gland, Open Approach */
"0GPK30Z" = "1" /* Removal of Drainage Device from Thyroid Gland, Percutaneous Approach */
"0GPK40Z" = "1" /* Removal of Drainage Device from Thyroid Gland, Percutaneous Endoscopic Approach */
"0GPR00Z" = "1" /* Removal of Drainage Device from Parathyroid Gland, Open Approach */
"0GPR30Z" = "1" /* Removal of Drainage Device from Parathyroid Gland, Percutaneous Approach */
"0GPR40Z" = "1" /* Removal of Drainage Device from Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GQ00ZZ" = "1" /* Repair Pituitary Gland, Open Approach */
"0GQ03ZZ" = "1" /* Repair Pituitary Gland, Percutaneous Approach */
"0GQ04ZZ" = "1" /* Repair Pituitary Gland, Percutaneous Endoscopic Approach */
"0GQ10ZZ" = "1" /* Repair Pineal Body, Open Approach */
"0GQ13ZZ" = "1" /* Repair Pineal Body, Percutaneous Approach */
"0GQ14ZZ" = "1" /* Repair Pineal Body, Percutaneous Endoscopic Approach */
"0GQ20ZZ" = "1" /* Repair Left Adrenal Gland, Open Approach */
"0GQ23ZZ" = "1" /* Repair Left Adrenal Gland, Percutaneous Approach */
"0GQ24ZZ" = "1" /* Repair Left Adrenal Gland, Percutaneous Endoscopic Approach */
"0GQ30ZZ" = "1" /* Repair Right Adrenal Gland, Open Approach */
"0GQ33ZZ" = "1" /* Repair Right Adrenal Gland, Percutaneous Approach */
"0GQ34ZZ" = "1" /* Repair Right Adrenal Gland, Percutaneous Endoscopic Approach */
"0GQ40ZZ" = "1" /* Repair Bilateral Adrenal Glands, Open Approach */
"0GQ43ZZ" = "1" /* Repair Bilateral Adrenal Glands, Percutaneous Approach */
"0GQ44ZZ" = "1" /* Repair Bilateral Adrenal Glands, Percutaneous Endoscopic Approach */
"0GQG0ZZ" = "1" /* Repair Left Thyroid Gland Lobe, Open Approach */
"0GQG3ZZ" = "1" /* Repair Left Thyroid Gland Lobe, Percutaneous Approach */
"0GQG4ZZ" = "1" /* Repair Left Thyroid Gland Lobe, Percutaneous Endoscopic Approach */
"0GQH0ZZ" = "1" /* Repair Right Thyroid Gland Lobe, Open Approach */
"0GQH3ZZ" = "1" /* Repair Right Thyroid Gland Lobe, Percutaneous Approach */
"0GQH4ZZ" = "1" /* Repair Right Thyroid Gland Lobe, Percutaneous Endoscopic Approach */
"0GQJ0ZZ" = "1" /* Repair Thyroid Gland Isthmus, Open Approach */
"0GQJ3ZZ" = "1" /* Repair Thyroid Gland Isthmus, Percutaneous Approach */
"0GQJ4ZZ" = "1" /* Repair Thyroid Gland Isthmus, Percutaneous Endoscopic Approach */
"0GQK0ZZ" = "1" /* Repair Thyroid Gland, Open Approach */
"0GQK3ZZ" = "1" /* Repair Thyroid Gland, Percutaneous Approach */
"0GQK4ZZ" = "1" /* Repair Thyroid Gland, Percutaneous Endoscopic Approach */
"0GQL0ZZ" = "1" /* Repair Right Superior Parathyroid Gland, Open Approach */
"0GQL3ZZ" = "1" /* Repair Right Superior Parathyroid Gland, Percutaneous Approach */
"0GQL4ZZ" = "1" /* Repair Right Superior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GQM0ZZ" = "1" /* Repair Left Superior Parathyroid Gland, Open Approach */
"0GQM3ZZ" = "1" /* Repair Left Superior Parathyroid Gland, Percutaneous Approach */
"0GQM4ZZ" = "1" /* Repair Left Superior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GQN0ZZ" = "1" /* Repair Right Inferior Parathyroid Gland, Open Approach */
"0GQN3ZZ" = "1" /* Repair Right Inferior Parathyroid Gland, Percutaneous Approach */
"0GQN4ZZ" = "1" /* Repair Right Inferior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GQP0ZZ" = "1" /* Repair Left Inferior Parathyroid Gland, Open Approach */
"0GQP3ZZ" = "1" /* Repair Left Inferior Parathyroid Gland, Percutaneous Approach */
"0GQP4ZZ" = "1" /* Repair Left Inferior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GQQ0ZZ" = "1" /* Repair Multiple Parathyroid Glands, Open Approach */
"0GQQ3ZZ" = "1" /* Repair Multiple Parathyroid Glands, Percutaneous Approach */
"0GQQ4ZZ" = "1" /* Repair Multiple Parathyroid Glands, Percutaneous Endoscopic Approach */
"0GQR0ZZ" = "1" /* Repair Parathyroid Gland, Open Approach */
"0GQR3ZZ" = "1" /* Repair Parathyroid Gland, Percutaneous Approach */
"0GQR4ZZ" = "1" /* Repair Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GS20ZZ" = "1" /* Reposition Left Adrenal Gland, Open Approach */
"0GS24ZZ" = "1" /* Reposition Left Adrenal Gland, Percutaneous Endoscopic Approach */
"0GS30ZZ" = "1" /* Reposition Right Adrenal Gland, Open Approach */
"0GS34ZZ" = "1" /* Reposition Right Adrenal Gland, Percutaneous Endoscopic Approach */
"0GSG0ZZ" = "1" /* Reposition Left Thyroid Gland Lobe, Open Approach */
"0GSG4ZZ" = "1" /* Reposition Left Thyroid Gland Lobe, Percutaneous Endoscopic Approach */
"0GSH0ZZ" = "1" /* Reposition Right Thyroid Gland Lobe, Open Approach */
"0GSH4ZZ" = "1" /* Reposition Right Thyroid Gland Lobe, Percutaneous Endoscopic Approach */
"0GSL0ZZ" = "1" /* Reposition Right Superior Parathyroid Gland, Open Approach */
"0GSL4ZZ" = "1" /* Reposition Right Superior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GSM0ZZ" = "1" /* Reposition Left Superior Parathyroid Gland, Open Approach */
"0GSM4ZZ" = "1" /* Reposition Left Superior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GSN0ZZ" = "1" /* Reposition Right Inferior Parathyroid Gland, Open Approach */
"0GSN4ZZ" = "1" /* Reposition Right Inferior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GSP0ZZ" = "1" /* Reposition Left Inferior Parathyroid Gland, Open Approach */
"0GSP4ZZ" = "1" /* Reposition Left Inferior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GSQ0ZZ" = "1" /* Reposition Multiple Parathyroid Glands, Open Approach */
"0GSQ4ZZ" = "1" /* Reposition Multiple Parathyroid Glands, Percutaneous Endoscopic Approach */
"0GSR0ZZ" = "1" /* Reposition Parathyroid Gland, Open Approach */
"0GSR4ZZ" = "1" /* Reposition Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GT00ZZ" = "1" /* Resection of Pituitary Gland, Open Approach */
"0GT04ZZ" = "1" /* Resection of Pituitary Gland, Percutaneous Endoscopic Approach */
"0GT10ZZ" = "1" /* Resection of Pineal Body, Open Approach */
"0GT14ZZ" = "1" /* Resection of Pineal Body, Percutaneous Endoscopic Approach */
"0GT20ZZ" = "1" /* Resection of Left Adrenal Gland, Open Approach */
"0GT24ZZ" = "1" /* Resection of Left Adrenal Gland, Percutaneous Endoscopic Approach */
"0GT30ZZ" = "1" /* Resection of Right Adrenal Gland, Open Approach */
"0GT34ZZ" = "1" /* Resection of Right Adrenal Gland, Percutaneous Endoscopic Approach */
"0GT40ZZ" = "1" /* Resection of Bilateral Adrenal Glands, Open Approach */
"0GT44ZZ" = "1" /* Resection of Bilateral Adrenal Glands, Percutaneous Endoscopic Approach */
"0GTG0ZZ" = "1" /* Resection of Left Thyroid Gland Lobe, Open Approach */
"0GTG4ZZ" = "1" /* Resection of Left Thyroid Gland Lobe, Percutaneous Endoscopic Approach */
"0GTH0ZZ" = "1" /* Resection of Right Thyroid Gland Lobe, Open Approach */
"0GTH4ZZ" = "1" /* Resection of Right Thyroid Gland Lobe, Percutaneous Endoscopic Approach */
"0GTK0ZZ" = "1" /* Resection of Thyroid Gland, Open Approach */
"0GTK4ZZ" = "1" /* Resection of Thyroid Gland, Percutaneous Endoscopic Approach */
"0GTL0ZZ" = "1" /* Resection of Right Superior Parathyroid Gland, Open Approach */
"0GTL4ZZ" = "1" /* Resection of Right Superior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GTM0ZZ" = "1" /* Resection of Left Superior Parathyroid Gland, Open Approach */
"0GTM4ZZ" = "1" /* Resection of Left Superior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GTN0ZZ" = "1" /* Resection of Right Inferior Parathyroid Gland, Open Approach */
"0GTN4ZZ" = "1" /* Resection of Right Inferior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GTP0ZZ" = "1" /* Resection of Left Inferior Parathyroid Gland, Open Approach */
"0GTP4ZZ" = "1" /* Resection of Left Inferior Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GTQ0ZZ" = "1" /* Resection of Multiple Parathyroid Glands, Open Approach */
"0GTQ4ZZ" = "1" /* Resection of Multiple Parathyroid Glands, Percutaneous Endoscopic Approach */
"0GTR0ZZ" = "1" /* Resection of Parathyroid Gland, Open Approach */
"0GTR4ZZ" = "1" /* Resection of Parathyroid Gland, Percutaneous Endoscopic Approach */
"0GW000Z" = "1" /* Revision of Drainage Device in Pituitary Gland, Open Approach */
"0GW030Z" = "1" /* Revision of Drainage Device in Pituitary Gland, Percutaneous Approach */
"0GW040Z" = "1" /* Revision of Drainage Device in Pituitary Gland, Percutaneous Endoscopic Approach */
"0GW100Z" = "1" /* Revision of Drainage Device in Pineal Body, Open Approach */
"0GW130Z" = "1" /* Revision of Drainage Device in Pineal Body, Percutaneous Approach */
"0GW140Z" = "1" /* Revision of Drainage Device in Pineal Body, Percutaneous Endoscopic Approach */
"0GW500Z" = "1" /* Revision of Drainage Device in Adrenal Gland, Open Approach */
"0GW530Z" = "1" /* Revision of Drainage Device in Adrenal Gland, Percutaneous Approach */
"0GW540Z" = "1" /* Revision of Drainage Device in Adrenal Gland, Percutaneous Endoscopic Approach */
"0GWK00Z" = "1" /* Revision of Drainage Device in Thyroid Gland, Open Approach */
"0GWK30Z" = "1" /* Revision of Drainage Device in Thyroid Gland, Percutaneous Approach */
"0GWK40Z" = "1" /* Revision of Drainage Device in Thyroid Gland, Percutaneous Endoscopic Approach */
"0GWR00Z" = "1" /* Revision of Drainage Device in Parathyroid Gland, Open Approach */
"0GWR30Z" = "1" /* Revision of Drainage Device in Parathyroid Gland, Percutaneous Approach */
"0GWR40Z" = "1" /* Revision of Drainage Device in Parathyroid Gland, Percutaneous Endoscopic Approach */
"0H0T07Z" = "1" /* Alteration of Right Breast with Autologous Tissue Substitute, Open Approach */
"0H0T0JZ" = "1" /* Alteration of Right Breast with Synthetic Substitute, Open Approach */
"0H0T0KZ" = "1" /* Alteration of Right Breast with Nonautologous Tissue Substitute, Open Approach */
"0H0T0ZZ" = "1" /* Alteration of Right Breast, Open Approach */
"0H0T37Z" = "1" /* Alteration of Right Breast with Autologous Tissue Substitute, Percutaneous Approach */
"0H0T3KZ" = "1" /* Alteration of Right Breast with Nonautologous Tissue Substitute, Percutaneous Approach */
"0H0T3ZZ" = "1" /* Alteration of Right Breast, Percutaneous Approach */
"0H0TX7Z" = "1" /* Alteration of Right Breast with Autologous Tissue Substitute, External Approach */
"0H0TXJZ" = "1" /* Alteration of Right Breast with Synthetic Substitute, External Approach */
"0H0TXKZ" = "1" /* Alteration of Right Breast with Nonautologous Tissue Substitute, External Approach */
"0H0TXZZ" = "1" /* Alteration of Right Breast, External Approach */
"0H0U07Z" = "1" /* Alteration of Left Breast with Autologous Tissue Substitute, Open Approach */
"0H0U0JZ" = "1" /* Alteration of Left Breast with Synthetic Substitute, Open Approach */
"0H0U0KZ" = "1" /* Alteration of Left Breast with Nonautologous Tissue Substitute, Open Approach */
"0H0U0ZZ" = "1" /* Alteration of Left Breast, Open Approach */
"0H0U37Z" = "1" /* Alteration of Left Breast with Autologous Tissue Substitute, Percutaneous Approach */
"0H0U3KZ" = "1" /* Alteration of Left Breast with Nonautologous Tissue Substitute, Percutaneous Approach */
"0H0U3ZZ" = "1" /* Alteration of Left Breast, Percutaneous Approach */
"0H0UX7Z" = "1" /* Alteration of Left Breast with Autologous Tissue Substitute, External Approach */
"0H0UXJZ" = "1" /* Alteration of Left Breast with Synthetic Substitute, External Approach */
"0H0UXKZ" = "1" /* Alteration of Left Breast with Nonautologous Tissue Substitute, External Approach */
"0H0UXZZ" = "1" /* Alteration of Left Breast, External Approach */
"0H0V07Z" = "1" /* Alteration of Bilateral Breast with Autologous Tissue Substitute, Open Approach */
"0H0V0JZ" = "1" /* Alteration of Bilateral Breast with Synthetic Substitute, Open Approach */
"0H0V0KZ" = "1" /* Alteration of Bilateral Breast with Nonautologous Tissue Substitute, Open Approach */
"0H0V0ZZ" = "1" /* Alteration of Bilateral Breast, Open Approach */
"0H0V37Z" = "1" /* Alteration of Bilateral Breast with Autologous Tissue Substitute, Percutaneous Approach */
"0H0V3KZ" = "1" /* Alteration of Bilateral Breast with Nonautologous Tissue Substitute, Percutaneous Approach */
"0H0V3ZZ" = "1" /* Alteration of Bilateral Breast, Percutaneous Approach */
"0H0VX7Z" = "1" /* Alteration of Bilateral Breast with Autologous Tissue Substitute, External Approach */
"0H0VXJZ" = "1" /* Alteration of Bilateral Breast with Synthetic Substitute, External Approach */
"0H0VXKZ" = "1" /* Alteration of Bilateral Breast with Nonautologous Tissue Substitute, External Approach */
"0H0VXZZ" = "1" /* Alteration of Bilateral Breast, External Approach */
"0H5T0ZZ" = "1" /* Destruction of Right Breast, Open Approach */
"0H5T3ZZ" = "1" /* Destruction of Right Breast, Percutaneous Approach */
"0H5T7ZZ" = "1" /* Destruction of Right Breast, Via Natural or Artificial Opening */
"0H5T8ZZ" = "1" /* Destruction of Right Breast, Via Natural or Artificial Opening Endoscopic */
"0H5TXZZ" = "1" /* Destruction of Right Breast, External Approach */
"0H5U0ZZ" = "1" /* Destruction of Left Breast, Open Approach */
"0H5U3ZZ" = "1" /* Destruction of Left Breast, Percutaneous Approach */
"0H5U7ZZ" = "1" /* Destruction of Left Breast, Via Natural or Artificial Opening */
"0H5U8ZZ" = "1" /* Destruction of Left Breast, Via Natural or Artificial Opening Endoscopic */
"0H5UXZZ" = "1" /* Destruction of Left Breast, External Approach */
"0H5V0ZZ" = "1" /* Destruction of Bilateral Breast, Open Approach */
"0H5V3ZZ" = "1" /* Destruction of Bilateral Breast, Percutaneous Approach */
"0H5V7ZZ" = "1" /* Destruction of Bilateral Breast, Via Natural or Artificial Opening */
"0H5V8ZZ" = "1" /* Destruction of Bilateral Breast, Via Natural or Artificial Opening Endoscopic */
"0H5VXZZ" = "1" /* Destruction of Bilateral Breast, External Approach */
"0H5W0ZZ" = "1" /* Destruction of Right Nipple, Open Approach */
"0H5W3ZZ" = "1" /* Destruction of Right Nipple, Percutaneous Approach */
"0H5W7ZZ" = "1" /* Destruction of Right Nipple, Via Natural or Artificial Opening */
"0H5W8ZZ" = "1" /* Destruction of Right Nipple, Via Natural or Artificial Opening Endoscopic */
"0H5WXZZ" = "1" /* Destruction of Right Nipple, External Approach */
"0H5X0ZZ" = "1" /* Destruction of Left Nipple, Open Approach */
"0H5X3ZZ" = "1" /* Destruction of Left Nipple, Percutaneous Approach */
"0H5X7ZZ" = "1" /* Destruction of Left Nipple, Via Natural or Artificial Opening */
"0H5X8ZZ" = "1" /* Destruction of Left Nipple, Via Natural or Artificial Opening Endoscopic */
"0H5XXZZ" = "1" /* Destruction of Left Nipple, External Approach */
"0H99X0Z" = "1" /* Drainage of Perineum Skin with Drainage Device, External Approach */
"0H99XZZ" = "1" /* Drainage of Perineum Skin, External Approach */
"0H9T0ZX" = "1" /* Drainage of Right Breast, Open Approach, Diagnostic */
"0H9U0ZX" = "1" /* Drainage of Left Breast, Open Approach, Diagnostic */
"0H9V0ZX" = "1" /* Drainage of Bilateral Breast, Open Approach, Diagnostic */
"0H9W0ZX" = "1" /* Drainage of Right Nipple, Open Approach, Diagnostic */
"0H9X0ZX" = "1" /* Drainage of Left Nipple, Open Approach, Diagnostic */
"0HBT0ZX" = "1" /* Excision of Right Breast, Open Approach, Diagnostic */
"0HBT0ZZ" = "1" /* Excision of Right Breast, Open Approach */
"0HBT3ZZ" = "1" /* Excision of Right Breast, Percutaneous Approach */
"0HBT7ZZ" = "1" /* Excision of Right Breast, Via Natural or Artificial Opening */
"0HBT8ZZ" = "1" /* Excision of Right Breast, Via Natural or Artificial Opening Endoscopic */
"0HBU0ZX" = "1" /* Excision of Left Breast, Open Approach, Diagnostic */
"0HBU0ZZ" = "1" /* Excision of Left Breast, Open Approach */
"0HBU3ZZ" = "1" /* Excision of Left Breast, Percutaneous Approach */
"0HBU7ZZ" = "1" /* Excision of Left Breast, Via Natural or Artificial Opening */
"0HBU8ZZ" = "1" /* Excision of Left Breast, Via Natural or Artificial Opening Endoscopic */
"0HBV0ZX" = "1" /* Excision of Bilateral Breast, Open Approach, Diagnostic */
"0HBV0ZZ" = "1" /* Excision of Bilateral Breast, Open Approach */
"0HBV3ZZ" = "1" /* Excision of Bilateral Breast, Percutaneous Approach */
"0HBV7ZZ" = "1" /* Excision of Bilateral Breast, Via Natural or Artificial Opening */
"0HBV8ZZ" = "1" /* Excision of Bilateral Breast, Via Natural or Artificial Opening Endoscopic */
"0HBW0ZX" = "1" /* Excision of Right Nipple, Open Approach, Diagnostic */
"0HBW0ZZ" = "1" /* Excision of Right Nipple, Open Approach */
"0HBW3ZZ" = "1" /* Excision of Right Nipple, Percutaneous Approach */
"0HBW7ZZ" = "1" /* Excision of Right Nipple, Via Natural or Artificial Opening */
"0HBW8ZZ" = "1" /* Excision of Right Nipple, Via Natural or Artificial Opening Endoscopic */
"0HBX0ZX" = "1" /* Excision of Left Nipple, Open Approach, Diagnostic */
"0HBX0ZZ" = "1" /* Excision of Left Nipple, Open Approach */
"0HBX3ZZ" = "1" /* Excision of Left Nipple, Percutaneous Approach */
"0HBX7ZZ" = "1" /* Excision of Left Nipple, Via Natural or Artificial Opening */
"0HBX8ZZ" = "1" /* Excision of Left Nipple, Via Natural or Artificial Opening Endoscopic */
"0HBY0ZX" = "1" /* Excision of Supernumerary Breast, Open Approach, Diagnostic */
"0HBY0ZZ" = "1" /* Excision of Supernumerary Breast, Open Approach */
"0HBY3ZZ" = "1" /* Excision of Supernumerary Breast, Percutaneous Approach */
"0HBY7ZZ" = "1" /* Excision of Supernumerary Breast, Via Natural or Artificial Opening */
"0HBY8ZZ" = "1" /* Excision of Supernumerary Breast, Via Natural or Artificial Opening Endoscopic */
"0HHT01Z" = "1" /* Insertion of Radioactive Element into Right Breast, Open Approach */
"0HHT0NZ" = "1" /* Insertion of Tissue Expander into Right Breast, Open Approach */
"0HHT31Z" = "1" /* Insertion of Radioactive Element into Right Breast, Percutaneous Approach */
"0HHT3NZ" = "1" /* Insertion of Tissue Expander into Right Breast, Percutaneous Approach */
"0HHT71Z" = "1" /* Insertion of Radioactive Element into Right Breast, Via Natural or Artificial Opening */
"0HHT7NZ" = "1" /* Insertion of Tissue Expander into Right Breast, Via Natural or Artificial Opening */
"0HHT81Z" = "1" /* Insertion of Radioactive Element into Right Breast, Via Natural or Artificial Opening Endoscopic */
"0HHT8NZ" = "1" /* Insertion of Tissue Expander into Right Breast, Via Natural or Artificial Opening Endoscopic */
"0HHTX1Z" = "1" /* Insertion of Radioactive Element into Right Breast, External Approach */
"0HHU01Z" = "1" /* Insertion of Radioactive Element into Left Breast, Open Approach */
"0HHU0NZ" = "1" /* Insertion of Tissue Expander into Left Breast, Open Approach */
"0HHU31Z" = "1" /* Insertion of Radioactive Element into Left Breast, Percutaneous Approach */
"0HHU3NZ" = "1" /* Insertion of Tissue Expander into Left Breast, Percutaneous Approach */
"0HHU71Z" = "1" /* Insertion of Radioactive Element into Left Breast, Via Natural or Artificial Opening */
"0HHU7NZ" = "1" /* Insertion of Tissue Expander into Left Breast, Via Natural or Artificial Opening */
"0HHU81Z" = "1" /* Insertion of Radioactive Element into Left Breast, Via Natural or Artificial Opening Endoscopic */
"0HHU8NZ" = "1" /* Insertion of Tissue Expander into Left Breast, Via Natural or Artificial Opening Endoscopic */
"0HHUX1Z" = "1" /* Insertion of Radioactive Element into Left Breast, External Approach */
"0HHV01Z" = "1" /* Insertion of Radioactive Element into Bilateral Breast, Open Approach */
"0HHV0NZ" = "1" /* Insertion of Tissue Expander into Bilateral Breast, Open Approach */
"0HHV31Z" = "1" /* Insertion of Radioactive Element into Bilateral Breast, Percutaneous Approach */
"0HHV3NZ" = "1" /* Insertion of Tissue Expander into Bilateral Breast, Percutaneous Approach */
"0HHV71Z" = "1" /* Insertion of Radioactive Element into Bilateral Breast, Via Natural or Artificial Opening */
"0HHV7NZ" = "1" /* Insertion of Tissue Expander into Bilateral Breast, Via Natural or Artificial Opening */
"0HHV81Z" = "1" /* Insertion of Radioactive Element into Bilateral Breast, Via Natural or Artificial Opening Endoscopic */
"0HHV8NZ" = "1" /* Insertion of Tissue Expander into Bilateral Breast, Via Natural or Artificial Opening Endoscopic */
"0HHVX1Z" = "1" /* Insertion of Radioactive Element into Bilateral Breast, External Approach */
"0HHW01Z" = "1" /* Insertion of Radioactive Element into Right Nipple, Open Approach */
"0HHW0NZ" = "1" /* Insertion of Tissue Expander into Right Nipple, Open Approach */
"0HHW31Z" = "1" /* Insertion of Radioactive Element into Right Nipple, Percutaneous Approach */
"0HHW3NZ" = "1" /* Insertion of Tissue Expander into Right Nipple, Percutaneous Approach */
"0HHW71Z" = "1" /* Insertion of Radioactive Element into Right Nipple, Via Natural or Artificial Opening */
"0HHW7NZ" = "1" /* Insertion of Tissue Expander into Right Nipple, Via Natural or Artificial Opening */
"0HHW81Z" = "1" /* Insertion of Radioactive Element into Right Nipple, Via Natural or Artificial Opening Endoscopic */
"0HHW8NZ" = "1" /* Insertion of Tissue Expander into Right Nipple, Via Natural or Artificial Opening Endoscopic */
"0HHWX1Z" = "1" /* Insertion of Radioactive Element into Right Nipple, External Approach */
"0HHX01Z" = "1" /* Insertion of Radioactive Element into Left Nipple, Open Approach */
"0HHX0NZ" = "1" /* Insertion of Tissue Expander into Left Nipple, Open Approach */
"0HHX31Z" = "1" /* Insertion of Radioactive Element into Left Nipple, Percutaneous Approach */
"0HHX3NZ" = "1" /* Insertion of Tissue Expander into Left Nipple, Percutaneous Approach */
"0HHX71Z" = "1" /* Insertion of Radioactive Element into Left Nipple, Via Natural or Artificial Opening */
"0HHX7NZ" = "1" /* Insertion of Tissue Expander into Left Nipple, Via Natural or Artificial Opening */
"0HHX81Z" = "1" /* Insertion of Radioactive Element into Left Nipple, Via Natural or Artificial Opening Endoscopic */
"0HHX8NZ" = "1" /* Insertion of Tissue Expander into Left Nipple, Via Natural or Artificial Opening Endoscopic */
"0HHXX1Z" = "1" /* Insertion of Radioactive Element into Left Nipple, External Approach */
"0HM1XZZ" = "1" /* Reattachment of Face Skin, External Approach */
"0HM2XZZ" = "1" /* Reattachment of Right Ear Skin, External Approach */
"0HM3XZZ" = "1" /* Reattachment of Left Ear Skin, External Approach */
"0HM4XZZ" = "1" /* Reattachment of Neck Skin, External Approach */
"0HM5XZZ" = "1" /* Reattachment of Chest Skin, External Approach */
"0HM6XZZ" = "1" /* Reattachment of Back Skin, External Approach */
"0HM7XZZ" = "1" /* Reattachment of Abdomen Skin, External Approach */
"0HM8XZZ" = "1" /* Reattachment of Buttock Skin, External Approach */
"0HM9XZZ" = "1" /* Reattachment of Perineum Skin, External Approach */
"0HMAXZZ" = "1" /* Reattachment of Genitalia Skin, External Approach */
"0HMBXZZ" = "1" /* Reattachment of Right Upper Arm Skin, External Approach */
"0HMCXZZ" = "1" /* Reattachment of Left Upper Arm Skin, External Approach */
"0HMDXZZ" = "1" /* Reattachment of Right Lower Arm Skin, External Approach */
"0HMEXZZ" = "1" /* Reattachment of Left Lower Arm Skin, External Approach */
"0HMFXZZ" = "1" /* Reattachment of Right Hand Skin, External Approach */
"0HMGXZZ" = "1" /* Reattachment of Left Hand Skin, External Approach */
"0HMHXZZ" = "1" /* Reattachment of Right Upper Leg Skin, External Approach */
"0HMJXZZ" = "1" /* Reattachment of Left Upper Leg Skin, External Approach */
"0HMKXZZ" = "1" /* Reattachment of Right Lower Leg Skin, External Approach */
"0HMLXZZ" = "1" /* Reattachment of Left Lower Leg Skin, External Approach */
"0HMMXZZ" = "1" /* Reattachment of Right Foot Skin, External Approach */
"0HMNXZZ" = "1" /* Reattachment of Left Foot Skin, External Approach */
"0HMTXZZ" = "1" /* Reattachment of Right Breast, External Approach */
"0HMUXZZ" = "1" /* Reattachment of Left Breast, External Approach */
"0HMVXZZ" = "1" /* Reattachment of Bilateral Breast, External Approach */
"0HMWXZZ" = "1" /* Reattachment of Right Nipple, External Approach */
"0HMXXZZ" = "1" /* Reattachment of Left Nipple, External Approach */
"0HN0XZZ" = "1" /* Release Scalp Skin, External Approach */
"0HN1XZZ" = "1" /* Release Face Skin, External Approach */
"0HN2XZZ" = "1" /* Release Right Ear Skin, External Approach */
"0HN3XZZ" = "1" /* Release Left Ear Skin, External Approach */
"0HN4XZZ" = "1" /* Release Neck Skin, External Approach */
"0HN5XZZ" = "1" /* Release Chest Skin, External Approach */
"0HN6XZZ" = "1" /* Release Back Skin, External Approach */
"0HN7XZZ" = "1" /* Release Abdomen Skin, External Approach */
"0HN8XZZ" = "1" /* Release Buttock Skin, External Approach */
"0HN9XZZ" = "1" /* Release Perineum Skin, External Approach */
"0HNAXZZ" = "1" /* Release Genitalia Skin, External Approach */
"0HNBXZZ" = "1" /* Release Right Upper Arm Skin, External Approach */
"0HNCXZZ" = "1" /* Release Left Upper Arm Skin, External Approach */
"0HNDXZZ" = "1" /* Release Right Lower Arm Skin, External Approach */
"0HNEXZZ" = "1" /* Release Left Lower Arm Skin, External Approach */
"0HNFXZZ" = "1" /* Release Right Hand Skin, External Approach */
"0HNGXZZ" = "1" /* Release Left Hand Skin, External Approach */
"0HNHXZZ" = "1" /* Release Right Upper Leg Skin, External Approach */
"0HNJXZZ" = "1" /* Release Left Upper Leg Skin, External Approach */
"0HNKXZZ" = "1" /* Release Right Lower Leg Skin, External Approach */
"0HNLXZZ" = "1" /* Release Left Lower Leg Skin, External Approach */
"0HNMXZZ" = "1" /* Release Right Foot Skin, External Approach */
"0HNNXZZ" = "1" /* Release Left Foot Skin, External Approach */
"0HNQXZZ" = "1" /* Release Finger Nail, External Approach */
"0HNRXZZ" = "1" /* Release Toe Nail, External Approach */
"0HNT0ZZ" = "1" /* Release Right Breast, Open Approach */
"0HNT3ZZ" = "1" /* Release Right Breast, Percutaneous Approach */
"0HNT7ZZ" = "1" /* Release Right Breast, Via Natural or Artificial Opening */
"0HNT8ZZ" = "1" /* Release Right Breast, Via Natural or Artificial Opening Endoscopic */
"0HNTXZZ" = "1" /* Release Right Breast, External Approach */
"0HNU0ZZ" = "1" /* Release Left Breast, Open Approach */
"0HNU3ZZ" = "1" /* Release Left Breast, Percutaneous Approach */
"0HNU7ZZ" = "1" /* Release Left Breast, Via Natural or Artificial Opening */
"0HNU8ZZ" = "1" /* Release Left Breast, Via Natural or Artificial Opening Endoscopic */
"0HNUXZZ" = "1" /* Release Left Breast, External Approach */
"0HNV0ZZ" = "1" /* Release Bilateral Breast, Open Approach */
"0HNV3ZZ" = "1" /* Release Bilateral Breast, Percutaneous Approach */
"0HNV7ZZ" = "1" /* Release Bilateral Breast, Via Natural or Artificial Opening */
"0HNV8ZZ" = "1" /* Release Bilateral Breast, Via Natural or Artificial Opening Endoscopic */
"0HNVXZZ" = "1" /* Release Bilateral Breast, External Approach */
"0HNW0ZZ" = "1" /* Release Right Nipple, Open Approach */
"0HNW3ZZ" = "1" /* Release Right Nipple, Percutaneous Approach */
"0HNW7ZZ" = "1" /* Release Right Nipple, Via Natural or Artificial Opening */
"0HNW8ZZ" = "1" /* Release Right Nipple, Via Natural or Artificial Opening Endoscopic */
"0HNWXZZ" = "1" /* Release Right Nipple, External Approach */
"0HNX0ZZ" = "1" /* Release Left Nipple, Open Approach */
"0HNX3ZZ" = "1" /* Release Left Nipple, Percutaneous Approach */
"0HNX7ZZ" = "1" /* Release Left Nipple, Via Natural or Artificial Opening */
"0HNX8ZZ" = "1" /* Release Left Nipple, Via Natural or Artificial Opening Endoscopic */
"0HNXXZZ" = "1" /* Release Left Nipple, External Approach */
"0HPT0JZ" = "1" /* Removal of Synthetic Substitute from Right Breast, Open Approach */
"0HPT0NZ" = "1" /* Removal of Tissue Expander from Right Breast, Open Approach */
"0HPT3JZ" = "1" /* Removal of Synthetic Substitute from Right Breast, Percutaneous Approach */
"0HPT3NZ" = "1" /* Removal of Tissue Expander from Right Breast, Percutaneous Approach */
"0HPU0JZ" = "1" /* Removal of Synthetic Substitute from Left Breast, Open Approach */
"0HPU0NZ" = "1" /* Removal of Tissue Expander from Left Breast, Open Approach */
"0HPU3JZ" = "1" /* Removal of Synthetic Substitute from Left Breast, Percutaneous Approach */
"0HPU3NZ" = "1" /* Removal of Tissue Expander from Left Breast, Percutaneous Approach */
"0HQQXZZ" = "1" /* Repair Finger Nail, External Approach */
"0HQRXZZ" = "1" /* Repair Toe Nail, External Approach */
"0HQT0ZZ" = "1" /* Repair Right Breast, Open Approach */
"0HQT3ZZ" = "1" /* Repair Right Breast, Percutaneous Approach */
"0HQT7ZZ" = "1" /* Repair Right Breast, Via Natural or Artificial Opening */
"0HQT8ZZ" = "1" /* Repair Right Breast, Via Natural or Artificial Opening Endoscopic */
"0HQU0ZZ" = "1" /* Repair Left Breast, Open Approach */
"0HQU3ZZ" = "1" /* Repair Left Breast, Percutaneous Approach */
"0HQU7ZZ" = "1" /* Repair Left Breast, Via Natural or Artificial Opening */
"0HQU8ZZ" = "1" /* Repair Left Breast, Via Natural or Artificial Opening Endoscopic */
"0HQV0ZZ" = "1" /* Repair Bilateral Breast, Open Approach */
"0HQV3ZZ" = "1" /* Repair Bilateral Breast, Percutaneous Approach */
"0HQV7ZZ" = "1" /* Repair Bilateral Breast, Via Natural or Artificial Opening */
"0HQV8ZZ" = "1" /* Repair Bilateral Breast, Via Natural or Artificial Opening Endoscopic */
"0HQW0ZZ" = "1" /* Repair Right Nipple, Open Approach */
"0HQW3ZZ" = "1" /* Repair Right Nipple, Percutaneous Approach */
"0HQW7ZZ" = "1" /* Repair Right Nipple, Via Natural or Artificial Opening */
"0HQW8ZZ" = "1" /* Repair Right Nipple, Via Natural or Artificial Opening Endoscopic */
"0HQWXZZ" = "1" /* Repair Right Nipple, External Approach */
"0HQX0ZZ" = "1" /* Repair Left Nipple, Open Approach */
"0HQX3ZZ" = "1" /* Repair Left Nipple, Percutaneous Approach */
"0HQX7ZZ" = "1" /* Repair Left Nipple, Via Natural or Artificial Opening */
"0HQX8ZZ" = "1" /* Repair Left Nipple, Via Natural or Artificial Opening Endoscopic */
"0HQXXZZ" = "1" /* Repair Left Nipple, External Approach */
"0HQY0ZZ" = "1" /* Repair Supernumerary Breast, Open Approach */
"0HQY3ZZ" = "1" /* Repair Supernumerary Breast, Percutaneous Approach */
"0HQY7ZZ" = "1" /* Repair Supernumerary Breast, Via Natural or Artificial Opening */
"0HQY8ZZ" = "1" /* Repair Supernumerary Breast, Via Natural or Artificial Opening Endoscopic */
"0HR0X73" = "1" /* Replacement of Scalp Skin with Autologous Tissue Substitute, Full Thickness, External Approach */
"0HR0X74" = "1" /* Replacement of Scalp Skin with Autologous Tissue Substitute, Partial Thickness, External Approach */
"0HR0XJ3" = "1" /* Replacement of Scalp Skin with Synthetic Substitute, Full Thickness, External Approach */
"0HR0XJ4" = "1" /* Replacement of Scalp Skin with Synthetic Substitute, Partial Thickness, External Approach */
"0HR0XJZ" = "1" /* Replacement of Scalp Skin with Synthetic Substitute, External Approach */
"0HR0XK3" = "1" /* Replacement of Scalp Skin with Nonautologous Tissue Substitute, Full Thickness, External Approach */
"0HR0XK4" = "1" /* Replacement of Scalp Skin with Nonautologous Tissue Substitute, Partial Thickness, External Approach */
"0HR1X73" = "1" /* Replacement of Face Skin with Autologous Tissue Substitute, Full Thickness, External Approach */
"0HR1X74" = "1" /* Replacement of Face Skin with Autologous Tissue Substitute, Partial Thickness, External Approach */
"0HR1XJ3" = "1" /* Replacement of Face Skin with Synthetic Substitute, Full Thickness, External Approach */
"0HR1XJ4" = "1" /* Replacement of Face Skin with Synthetic Substitute, Partial Thickness, External Approach */
"0HR1XJZ" = "1" /* Replacement of Face Skin with Synthetic Substitute, External Approach */
"0HR1XK3" = "1" /* Replacement of Face Skin with Nonautologous Tissue Substitute, Full Thickness, External Approach */
"0HR1XK4" = "1" /* Replacement of Face Skin with Nonautologous Tissue Substitute, Partial Thickness, External Approach */
"0HR2X73" = "1" /* Replacement of Right Ear Skin with Autologous Tissue Substitute, Full Thickness, External Approach */
"0HR2X74" = "1" /* Replacement of Right Ear Skin with Autologous Tissue Substitute, Partial Thickness, External Approach */
"0HR2XJ3" = "1" /* Replacement of Right Ear Skin with Synthetic Substitute, Full Thickness, External Approach */
"0HR2XJ4" = "1" /* Replacement of Right Ear Skin with Synthetic Substitute, Partial Thickness, External Approach */
"0HR2XJZ" = "1" /* Replacement of Right Ear Skin with Synthetic Substitute, External Approach */
"0HR2XK3" = "1" /* Replacement of Right Ear Skin with Nonautologous Tissue Substitute, Full Thickness, External Approach */
"0HR2XK4" = "1" /* Replacement of Right Ear Skin with Nonautologous Tissue Substitute, Partial Thickness, External Approach */
"0HR3X73" = "1" /* Replacement of Left Ear Skin with Autologous Tissue Substitute, Full Thickness, External Approach */
"0HR3X74" = "1" /* Replacement of Left Ear Skin with Autologous Tissue Substitute, Partial Thickness, External Approach */
"0HR3XJ3" = "1" /* Replacement of Left Ear Skin with Synthetic Substitute, Full Thickness, External Approach */
"0HR3XJ4" = "1" /* Replacement of Left Ear Skin with Synthetic Substitute, Partial Thickness, External Approach */
"0HR3XJZ" = "1" /* Replacement of Left Ear Skin with Synthetic Substitute, External Approach */
"0HR3XK3" = "1" /* Replacement of Left Ear Skin with Nonautologous Tissue Substitute, Full Thickness, External Approach */
"0HR3XK4" = "1" /* Replacement of Left Ear Skin with Nonautologous Tissue Substitute, Partial Thickness, External Approach */
"0HR4X73" = "1" /* Replacement of Neck Skin with Autologous Tissue Substitute, Full Thickness, External Approach */
"0HR4X74" = "1" /* Replacement of Neck Skin with Autologous Tissue Substitute, Partial Thickness, External Approach */
"0HR4XJ3" = "1" /* Replacement of Neck Skin with Synthetic Substitute, Full Thickness, External Approach */
"0HR4XJ4" = "1" /* Replacement of Neck Skin with Synthetic Substitute, Partial Thickness, External Approach */
"0HR4XJZ" = "1" /* Replacement of Neck Skin with Synthetic Substitute, External Approach */
"0HR4XK3" = "1" /* Replacement of Neck Skin with Nonautologous Tissue Substitute, Full Thickness, External Approach */
"0HR4XK4" = "1" /* Replacement of Neck Skin with Nonautologous Tissue Substitute, Partial Thickness, External Approach */
"0HR5X73" = "1" /* Replacement of Chest Skin with Autologous Tissue Substitute, Full Thickness, External Approach */
"0HR5X74" = "1" /* Replacement of Chest Skin with Autologous Tissue Substitute, Partial Thickness, External Approach */
"0HR5XJ3" = "1" /* Replacement of Chest Skin with Synthetic Substitute, Full Thickness, External Approach */
"0HR5XJ4" = "1" /* Replacement of Chest Skin with Synthetic Substitute, Partial Thickness, External Approach */
"0HR5XJZ" = "1" /* Replacement of Chest Skin with Synthetic Substitute, External Approach */
"0HR5XK3" = "1" /* Replacement of Chest Skin with Nonautologous Tissue Substitute, Full Thickness, External Approach */
"0HR5XK4" = "1" /* Replacement of Chest Skin with Nonautologous Tissue Substitute, Partial Thickness, External Approach */
"0HR6X73" = "1" /* Replacement of Back Skin with Autologous Tissue Substitute, Full Thickness, External Approach */
"0HR6X74" = "1" /* Replacement of Back Skin with Autologous Tissue Substitute, Partial Thickness, External Approach */
"0HR6XJ3" = "1" /* Replacement of Back Skin with Synthetic Substitute, Full Thickness, External Approach */
"0HR6XJ4" = "1" /* Replacement of Back Skin with Synthetic Substitute, Partial Thickness, External Approach */
"0HR6XJZ" = "1" /* Replacement of Back Skin with Synthetic Substitute, External Approach */
"0HR6XK3" = "1" /* Replacement of Back Skin with Nonautologous Tissue Substitute, Full Thickness, External Approach */
"0HR6XK4" = "1" /* Replacement of Back Skin with Nonautologous Tissue Substitute, Partial Thickness, External Approach */
"0HR7X73" = "1" /* Replacement of Abdomen Skin with Autologous Tissue Substitute, Full Thickness, External Approach */
"0HR7X74" = "1" /* Replacement of Abdomen Skin with Autologous Tissue Substitute, Partial Thickness, External Approach */
"0HR7XJ3" = "1" /* Replacement of Abdomen Skin with Synthetic Substitute, Full Thickness, External Approach */
"0HR7XJ4" = "1" /* Replacement of Abdomen Skin with Synthetic Substitute, Partial Thickness, External Approach */
"0HR7XJZ" = "1" /* Replacement of Abdomen Skin with Synthetic Substitute, External Approach */
"0HR7XK3" = "1" /* Replacement of Abdomen Skin with Nonautologous Tissue Substitute, Full Thickness, External Approach */
"0HR7XK4" = "1" /* Replacement of Abdomen Skin with Nonautologous Tissue Substitute, Partial Thickness, External Approach */
"0HR8X73" = "1" /* Replacement of Buttock Skin with Autologous Tissue Substitute, Full Thickness, External Approach */
"0HR8X74" = "1" /* Replacement of Buttock Skin with Autologous Tissue Substitute, Partial Thickness, External Approach */
"0HR8XJ3" = "1" /* Replacement of Buttock Skin with Synthetic Substitute, Full Thickness, External Approach */
"0HR8XJ4" = "1" /* Replacement of Buttock Skin with Synthetic Substitute, Partial Thickness, External Approach */
"0HR8XJZ" = "1" /* Replacement of Buttock Skin with Synthetic Substitute, External Approach */
"0HR8XK3" = "1" /* Replacement of Buttock Skin with Nonautologous Tissue Substitute, Full Thickness, External Approach */
"0HR8XK4" = "1" /* Replacement of Buttock Skin with Nonautologous Tissue Substitute, Partial Thickness, External Approach */
"0HR9X73" = "1" /* Replacement of Perineum Skin with Autologous Tissue Substitute, Full Thickness, External Approach */
"0HR9X74" = "1" /* Replacement of Perineum Skin with Autologous Tissue Substitute, Partial Thickness, External Approach */
"0HR9XJ3" = "1" /* Replacement of Perineum Skin with Synthetic Substitute, Full Thickness, External Approach */
"0HR9XJ4" = "1" /* Replacement of Perineum Skin with Synthetic Substitute, Partial Thickness, External Approach */
"0HR9XJZ" = "1" /* Replacement of Perineum Skin with Synthetic Substitute, External Approach */
"0HR9XK3" = "1" /* Replacement of Perineum Skin with Nonautologous Tissue Substitute, Full Thickness, External Approach */
"0HR9XK4" = "1" /* Replacement of Perineum Skin with Nonautologous Tissue Substitute, Partial Thickness, External Approach */
"0HRAX73" = "1" /* Replacement of Genitalia Skin with Autologous Tissue Substitute, Full Thickness, External Approach */
"0HRAX74" = "1" /* Replacement of Genitalia Skin with Autologous Tissue Substitute, Partial Thickness, External Approach */
"0HRAXJ3" = "1" /* Replacement of Genitalia Skin with Synthetic Substitute, Full Thickness, External Approach */
"0HRAXJ4" = "1" /* Replacement of Genitalia Skin with Synthetic Substitute, Partial Thickness, External Approach */
"0HRAXJZ" = "1" /* Replacement of Genitalia Skin with Synthetic Substitute, External Approach */
"0HRAXK3" = "1" /* Replacement of Genitalia Skin with Nonautologous Tissue Substitute, Full Thickness, External Approach */
"0HRAXK4" = "1" /* Replacement of Genitalia Skin with Nonautologous Tissue Substitute, Partial Thickness, External Approach */
"0HRBX73" = "1" /* Replacement of Right Upper Arm Skin with Autologous Tissue Substitute, Full Thickness, External Approach */
"0HRBX74" = "1" /* Replacement of Right Upper Arm Skin with Autologous Tissue Substitute, Partial Thickness, External Approach */
"0HRBXJ3" = "1" /* Replacement of Right Upper Arm Skin with Synthetic Substitute, Full Thickness, External Approach */
"0HRBXJ4" = "1" /* Replacement of Right Upper Arm Skin with Synthetic Substitute, Partial Thickness, External Approach */
"0HRBXJZ" = "1" /* Replacement of Right Upper Arm Skin with Synthetic Substitute, External Approach */
"0HRBXK3" = "1" /* Replacement of Right Upper Arm Skin with Nonautologous Tissue Substitute, Full Thickness, External Approach */
"0HRBXK4" = "1" /* Replacement of Right Upper Arm Skin with Nonautologous Tissue Substitute, Partial Thickness, External Approach */
"0HRCX73" = "1" /* Replacement of Left Upper Arm Skin with Autologous Tissue Substitute, Full Thickness, External Approach */
"0HRCX74" = "1" /* Replacement of Left Upper Arm Skin with Autologous Tissue Substitute, Partial Thickness, External Approach */
"0HRCXJ3" = "1" /* Replacement of Left Upper Arm Skin with Synthetic Substitute, Full Thickness, External Approach */
"0HRCXJ4" = "1" /* Replacement of Left Upper Arm Skin with Synthetic Substitute, Partial Thickness, External Approach */
"0HRCXJZ" = "1" /* Replacement of Left Upper Arm Skin with Synthetic Substitute, External Approach */
"0HRCXK3" = "1" /* Replacement of Left Upper Arm Skin with Nonautologous Tissue Substitute, Full Thickness, External Approach */
"0HRCXK4" = "1" /* Replacement of Left Upper Arm Skin with Nonautologous Tissue Substitute, Partial Thickness, External Approach */
"0HRDX73" = "1" /* Replacement of Right Lower Arm Skin with Autologous Tissue Substitute, Full Thickness, External Approach */
"0HRDX74" = "1" /* Replacement of Right Lower Arm Skin with Autologous Tissue Substitute, Partial Thickness, External Approach */
"0HRDXJ3" = "1" /* Replacement of Right Lower Arm Skin with Synthetic Substitute, Full Thickness, External Approach */
"0HRDXJ4" = "1" /* Replacement of Right Lower Arm Skin with Synthetic Substitute, Partial Thickness, External Approach */
"0HRDXJZ" = "1" /* Replacement of Right Lower Arm Skin with Synthetic Substitute, External Approach */
"0HRDXK3" = "1" /* Replacement of Right Lower Arm Skin with Nonautologous Tissue Substitute, Full Thickness, External Approach */
"0HRDXK4" = "1" /* Replacement of Right Lower Arm Skin with Nonautologous Tissue Substitute, Partial Thickness, External Approach */
"0HREX73" = "1" /* Replacement of Left Lower Arm Skin with Autologous Tissue Substitute, Full Thickness, External Approach */
"0HREX74" = "1" /* Replacement of Left Lower Arm Skin with Autologous Tissue Substitute, Partial Thickness, External Approach */
"0HREXJ3" = "1" /* Replacement of Left Lower Arm Skin with Synthetic Substitute, Full Thickness, External Approach */
"0HREXJ4" = "1" /* Replacement of Left Lower Arm Skin with Synthetic Substitute, Partial Thickness, External Approach */
"0HREXJZ" = "1" /* Replacement of Left Lower Arm Skin with Synthetic Substitute, External Approach */
"0HREXK3" = "1" /* Replacement of Left Lower Arm Skin with Nonautologous Tissue Substitute, Full Thickness, External Approach */
"0HREXK4" = "1" /* Replacement of Left Lower Arm Skin with Nonautologous Tissue Substitute, Partial Thickness, External Approach */
"0HRFX73" = "1" /* Replacement of Right Hand Skin with Autologous Tissue Substitute, Full Thickness, External Approach */
"0HRFX74" = "1" /* Replacement of Right Hand Skin with Autologous Tissue Substitute, Partial Thickness, External Approach */
"0HRFXJ3" = "1" /* Replacement of Right Hand Skin with Synthetic Substitute, Full Thickness, External Approach */
"0HRFXJ4" = "1" /* Replacement of Right Hand Skin with Synthetic Substitute, Partial Thickness, External Approach */
"0HRFXJZ" = "1" /* Replacement of Right Hand Skin with Synthetic Substitute, External Approach */
"0HRFXK3" = "1" /* Replacement of Right Hand Skin with Nonautologous Tissue Substitute, Full Thickness, External Approach */
"0HRFXK4" = "1" /* Replacement of Right Hand Skin with Nonautologous Tissue Substitute, Partial Thickness, External Approach */
"0HRGX73" = "1" /* Replacement of Left Hand Skin with Autologous Tissue Substitute, Full Thickness, External Approach */
"0HRGX74" = "1" /* Replacement of Left Hand Skin with Autologous Tissue Substitute, Partial Thickness, External Approach */
"0HRGXJ3" = "1" /* Replacement of Left Hand Skin with Synthetic Substitute, Full Thickness, External Approach */
"0HRGXJ4" = "1" /* Replacement of Left Hand Skin with Synthetic Substitute, Partial Thickness, External Approach */
"0HRGXJZ" = "1" /* Replacement of Left Hand Skin with Synthetic Substitute, External Approach */
"0HRGXK3" = "1" /* Replacement of Left Hand Skin with Nonautologous Tissue Substitute, Full Thickness, External Approach */
"0HRGXK4" = "1" /* Replacement of Left Hand Skin with Nonautologous Tissue Substitute, Partial Thickness, External Approach */
"0HRHX73" = "1" /* Replacement of Right Upper Leg Skin with Autologous Tissue Substitute, Full Thickness, External Approach */
"0HRHX74" = "1" /* Replacement of Right Upper Leg Skin with Autologous Tissue Substitute, Partial Thickness, External Approach */
"0HRHXJ3" = "1" /* Replacement of Right Upper Leg Skin with Synthetic Substitute, Full Thickness, External Approach */
"0HRHXJ4" = "1" /* Replacement of Right Upper Leg Skin with Synthetic Substitute, Partial Thickness, External Approach */
"0HRHXJZ" = "1" /* Replacement of Right Upper Leg Skin with Synthetic Substitute, External Approach */
"0HRHXK3" = "1" /* Replacement of Right Upper Leg Skin with Nonautologous Tissue Substitute, Full Thickness, External Approach */
"0HRHXK4" = "1" /* Replacement of Right Upper Leg Skin with Nonautologous Tissue Substitute, Partial Thickness, External Approach */
"0HRJX73" = "1" /* Replacement of Left Upper Leg Skin with Autologous Tissue Substitute, Full Thickness, External Approach */
"0HRJX74" = "1" /* Replacement of Left Upper Leg Skin with Autologous Tissue Substitute, Partial Thickness, External Approach */
"0HRJXJ3" = "1" /* Replacement of Left Upper Leg Skin with Synthetic Substitute, Full Thickness, External Approach */
"0HRJXJ4" = "1" /* Replacement of Left Upper Leg Skin with Synthetic Substitute, Partial Thickness, External Approach */
"0HRJXJZ" = "1" /* Replacement of Left Upper Leg Skin with Synthetic Substitute, External Approach */
"0HRJXK3" = "1" /* Replacement of Left Upper Leg Skin with Nonautologous Tissue Substitute, Full Thickness, External Approach */
"0HRJXK4" = "1" /* Replacement of Left Upper Leg Skin with Nonautologous Tissue Substitute, Partial Thickness, External Approach */
"0HRKX73" = "1" /* Replacement of Right Lower Leg Skin with Autologous Tissue Substitute, Full Thickness, External Approach */
"0HRKX74" = "1" /* Replacement of Right Lower Leg Skin with Autologous Tissue Substitute, Partial Thickness, External Approach */
"0HRKXJ3" = "1" /* Replacement of Right Lower Leg Skin with Synthetic Substitute, Full Thickness, External Approach */
"0HRKXJ4" = "1" /* Replacement of Right Lower Leg Skin with Synthetic Substitute, Partial Thickness, External Approach */
"0HRKXJZ" = "1" /* Replacement of Right Lower Leg Skin with Synthetic Substitute, External Approach */
"0HRKXK3" = "1" /* Replacement of Right Lower Leg Skin with Nonautologous Tissue Substitute, Full Thickness, External Approach */
"0HRKXK4" = "1" /* Replacement of Right Lower Leg Skin with Nonautologous Tissue Substitute, Partial Thickness, External Approach */
"0HRLX73" = "1" /* Replacement of Left Lower Leg Skin with Autologous Tissue Substitute, Full Thickness, External Approach */
"0HRLX74" = "1" /* Replacement of Left Lower Leg Skin with Autologous Tissue Substitute, Partial Thickness, External Approach */
"0HRLXJ3" = "1" /* Replacement of Left Lower Leg Skin with Synthetic Substitute, Full Thickness, External Approach */
"0HRLXJ4" = "1" /* Replacement of Left Lower Leg Skin with Synthetic Substitute, Partial Thickness, External Approach */
"0HRLXJZ" = "1" /* Replacement of Left Lower Leg Skin with Synthetic Substitute, External Approach */
"0HRLXK3" = "1" /* Replacement of Left Lower Leg Skin with Nonautologous Tissue Substitute, Full Thickness, External Approach */
"0HRLXK4" = "1" /* Replacement of Left Lower Leg Skin with Nonautologous Tissue Substitute, Partial Thickness, External Approach */
"0HRMX73" = "1" /* Replacement of Right Foot Skin with Autologous Tissue Substitute, Full Thickness, External Approach */
"0HRMX74" = "1" /* Replacement of Right Foot Skin with Autologous Tissue Substitute, Partial Thickness, External Approach */
"0HRMXJ3" = "1" /* Replacement of Right Foot Skin with Synthetic Substitute, Full Thickness, External Approach */
"0HRMXJ4" = "1" /* Replacement of Right Foot Skin with Synthetic Substitute, Partial Thickness, External Approach */
"0HRMXJZ" = "1" /* Replacement of Right Foot Skin with Synthetic Substitute, External Approach */
"0HRMXK3" = "1" /* Replacement of Right Foot Skin with Nonautologous Tissue Substitute, Full Thickness, External Approach */
"0HRMXK4" = "1" /* Replacement of Right Foot Skin with Nonautologous Tissue Substitute, Partial Thickness, External Approach */
"0HRNX73" = "1" /* Replacement of Left Foot Skin with Autologous Tissue Substitute, Full Thickness, External Approach */
"0HRNX74" = "1" /* Replacement of Left Foot Skin with Autologous Tissue Substitute, Partial Thickness, External Approach */
"0HRNXJ3" = "1" /* Replacement of Left Foot Skin with Synthetic Substitute, Full Thickness, External Approach */
"0HRNXJ4" = "1" /* Replacement of Left Foot Skin with Synthetic Substitute, Partial Thickness, External Approach */
"0HRNXJZ" = "1" /* Replacement of Left Foot Skin with Synthetic Substitute, External Approach */
"0HRNXK3" = "1" /* Replacement of Left Foot Skin with Nonautologous Tissue Substitute, Full Thickness, External Approach */
"0HRNXK4" = "1" /* Replacement of Left Foot Skin with Nonautologous Tissue Substitute, Partial Thickness, External Approach */
"0HRQX7Z" = "1" /* Replacement of Finger Nail with Autologous Tissue Substitute, External Approach */
"0HRQXJZ" = "1" /* Replacement of Finger Nail with Synthetic Substitute, External Approach */
"0HRQXKZ" = "1" /* Replacement of Finger Nail with Nonautologous Tissue Substitute, External Approach */
"0HRRX7Z" = "1" /* Replacement of Toe Nail with Autologous Tissue Substitute, External Approach */
"0HRRXJZ" = "1" /* Replacement of Toe Nail with Synthetic Substitute, External Approach */
"0HRRXKZ" = "1" /* Replacement of Toe Nail with Nonautologous Tissue Substitute, External Approach */
"0HRSXJZ" = "1" /* Replacement of Hair with Synthetic Substitute, External Approach */
"0HRSXKZ" = "1" /* Replacement of Hair with Nonautologous Tissue Substitute, External Approach */
"0HRT075" = "1" /* Replacement of Right Breast using Latissimus Dorsi Myocutaneous Flap, Open Approach */
"0HRT076" = "1" /* Replacement of Right Breast using Transverse Rectus Abdominis Myocutaneous Flap, Open Approach */
"0HRT077" = "1" /* Replacement of Right Breast using Deep Inferior Epigastric Artery Perforator Flap, Open Approach */
"0HRT078" = "1" /* Replacement of Right Breast using Superficial Inferior Epigastric Artery Flap, Open Approach */
"0HRT079" = "1" /* Replacement of Right Breast using Gluteal Artery Perforator Flap, Open Approach */
"0HRT07Z" = "1" /* Replacement of Right Breast with Autologous Tissue Substitute, Open Approach */
"0HRT0JZ" = "1" /* Replacement of Right Breast with Synthetic Substitute, Open Approach */
"0HRT0KZ" = "1" /* Replacement of Right Breast with Nonautologous Tissue Substitute, Open Approach */
"0HRT37Z" = "1" /* Replacement of Right Breast with Autologous Tissue Substitute, Percutaneous Approach */
"0HRT3JZ" = "1" /* Replacement of Right Breast with Synthetic Substitute, Percutaneous Approach */
"0HRT3KZ" = "1" /* Replacement of Right Breast with Nonautologous Tissue Substitute, Percutaneous Approach */
"0HRTX7Z" = "1" /* Replacement of Right Breast with Autologous Tissue Substitute, External Approach */
"0HRTXJZ" = "1" /* Replacement of Right Breast with Synthetic Substitute, External Approach */
"0HRTXKZ" = "1" /* Replacement of Right Breast with Nonautologous Tissue Substitute, External Approach */
"0HRU075" = "1" /* Replacement of Left Breast using Latissimus Dorsi Myocutaneous Flap, Open Approach */
"0HRU076" = "1" /* Replacement of Left Breast using Transverse Rectus Abdominis Myocutaneous Flap, Open Approach */
"0HRU077" = "1" /* Replacement of Left Breast using Deep Inferior Epigastric Artery Perforator Flap, Open Approach */
"0HRU078" = "1" /* Replacement of Left Breast using Superficial Inferior Epigastric Artery Flap, Open Approach */
"0HRU079" = "1" /* Replacement of Left Breast using Gluteal Artery Perforator Flap, Open Approach */
"0HRU07Z" = "1" /* Replacement of Left Breast with Autologous Tissue Substitute, Open Approach */
"0HRU0JZ" = "1" /* Replacement of Left Breast with Synthetic Substitute, Open Approach */
"0HRU0KZ" = "1" /* Replacement of Left Breast with Nonautologous Tissue Substitute, Open Approach */
"0HRU37Z" = "1" /* Replacement of Left Breast with Autologous Tissue Substitute, Percutaneous Approach */
"0HRU3JZ" = "1" /* Replacement of Left Breast with Synthetic Substitute, Percutaneous Approach */
"0HRU3KZ" = "1" /* Replacement of Left Breast with Nonautologous Tissue Substitute, Percutaneous Approach */
"0HRUX7Z" = "1" /* Replacement of Left Breast with Autologous Tissue Substitute, External Approach */
"0HRUXJZ" = "1" /* Replacement of Left Breast with Synthetic Substitute, External Approach */
"0HRUXKZ" = "1" /* Replacement of Left Breast with Nonautologous Tissue Substitute, External Approach */
"0HRV075" = "1" /* Replacement of Bilateral Breast using Latissimus Dorsi Myocutaneous Flap, Open Approach */
"0HRV076" = "1" /* Replacement of Bilateral Breast using Transverse Rectus Abdominis Myocutaneous Flap, Open Approach */
"0HRV077" = "1" /* Replacement of Bilateral Breast using Deep Inferior Epigastric Artery Perforator Flap, Open Approach */
"0HRV078" = "1" /* Replacement of Bilateral Breast using Superficial Inferior Epigastric Artery Flap, Open Approach */
"0HRV079" = "1" /* Replacement of Bilateral Breast using Gluteal Artery Perforator Flap, Open Approach */
"0HRV07Z" = "1" /* Replacement of Bilateral Breast with Autologous Tissue Substitute, Open Approach */
"0HRV0JZ" = "1" /* Replacement of Bilateral Breast with Synthetic Substitute, Open Approach */
"0HRV0KZ" = "1" /* Replacement of Bilateral Breast with Nonautologous Tissue Substitute, Open Approach */
"0HRV37Z" = "1" /* Replacement of Bilateral Breast with Autologous Tissue Substitute, Percutaneous Approach */
"0HRV3JZ" = "1" /* Replacement of Bilateral Breast with Synthetic Substitute, Percutaneous Approach */
"0HRV3KZ" = "1" /* Replacement of Bilateral Breast with Nonautologous Tissue Substitute, Percutaneous Approach */
"0HRVX7Z" = "1" /* Replacement of Bilateral Breast with Autologous Tissue Substitute, External Approach */
"0HRVXJZ" = "1" /* Replacement of Bilateral Breast with Synthetic Substitute, External Approach */
"0HRVXKZ" = "1" /* Replacement of Bilateral Breast with Nonautologous Tissue Substitute, External Approach */
"0HRW07Z" = "1" /* Replacement of Right Nipple with Autologous Tissue Substitute, Open Approach */
"0HRW0JZ" = "1" /* Replacement of Right Nipple with Synthetic Substitute, Open Approach */
"0HRW0KZ" = "1" /* Replacement of Right Nipple with Nonautologous Tissue Substitute, Open Approach */
"0HRW37Z" = "1" /* Replacement of Right Nipple with Autologous Tissue Substitute, Percutaneous Approach */
"0HRW3JZ" = "1" /* Replacement of Right Nipple with Synthetic Substitute, Percutaneous Approach */
"0HRW3KZ" = "1" /* Replacement of Right Nipple with Nonautologous Tissue Substitute, Percutaneous Approach */
"0HRWX7Z" = "1" /* Replacement of Right Nipple with Autologous Tissue Substitute, External Approach */
"0HRWXJZ" = "1" /* Replacement of Right Nipple with Synthetic Substitute, External Approach */
"0HRWXKZ" = "1" /* Replacement of Right Nipple with Nonautologous Tissue Substitute, External Approach */
"0HRX07Z" = "1" /* Replacement of Left Nipple with Autologous Tissue Substitute, Open Approach */
"0HRX0JZ" = "1" /* Replacement of Left Nipple with Synthetic Substitute, Open Approach */
"0HRX0KZ" = "1" /* Replacement of Left Nipple with Nonautologous Tissue Substitute, Open Approach */
"0HRX37Z" = "1" /* Replacement of Left Nipple with Autologous Tissue Substitute, Percutaneous Approach */
"0HRX3JZ" = "1" /* Replacement of Left Nipple with Synthetic Substitute, Percutaneous Approach */
"0HRX3KZ" = "1" /* Replacement of Left Nipple with Nonautologous Tissue Substitute, Percutaneous Approach */
"0HRXX7Z" = "1" /* Replacement of Left Nipple with Autologous Tissue Substitute, External Approach */
"0HRXXJZ" = "1" /* Replacement of Left Nipple with Synthetic Substitute, External Approach */
"0HRXXKZ" = "1" /* Replacement of Left Nipple with Nonautologous Tissue Substitute, External Approach */
"0HST0ZZ" = "1" /* Reposition Right Breast, Open Approach */
"0HSU0ZZ" = "1" /* Reposition Left Breast, Open Approach */
"0HSV0ZZ" = "1" /* Reposition Bilateral Breast, Open Approach */
"0HSWXZZ" = "1" /* Reposition Right Nipple, External Approach */
"0HSXXZZ" = "1" /* Reposition Left Nipple, External Approach */
"0HTT0ZZ" = "1" /* Resection of Right Breast, Open Approach */
"0HTU0ZZ" = "1" /* Resection of Left Breast, Open Approach */
"0HTV0ZZ" = "1" /* Resection of Bilateral Breast, Open Approach */
"0HTWXZZ" = "1" /* Resection of Right Nipple, External Approach */
"0HTXXZZ" = "1" /* Resection of Left Nipple, External Approach */
"0HTY0ZZ" = "1" /* Resection of Supernumerary Breast, Open Approach */
"0HUT07Z" = "1" /* Supplement Right Breast with Autologous Tissue Substitute, Open Approach */
"0HUT0JZ" = "1" /* Supplement Right Breast with Synthetic Substitute, Open Approach */
"0HUT0KZ" = "1" /* Supplement Right Breast with Nonautologous Tissue Substitute, Open Approach */
"0HUT37Z" = "1" /* Supplement Right Breast with Autologous Tissue Substitute, Percutaneous Approach */
"0HUT3KZ" = "1" /* Supplement Right Breast with Nonautologous Tissue Substitute, Percutaneous Approach */
"0HUT77Z" = "1" /* Supplement Right Breast with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0HUT7JZ" = "1" /* Supplement Right Breast with Synthetic Substitute, Via Natural or Artificial Opening */
"0HUT7KZ" = "1" /* Supplement Right Breast with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0HUT87Z" = "1" /* Supplement Right Breast with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0HUT8JZ" = "1" /* Supplement Right Breast with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0HUT8KZ" = "1" /* Supplement Right Breast with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0HUTX7Z" = "1" /* Supplement Right Breast with Autologous Tissue Substitute, External Approach */
"0HUTXJZ" = "1" /* Supplement Right Breast with Synthetic Substitute, External Approach */
"0HUTXKZ" = "1" /* Supplement Right Breast with Nonautologous Tissue Substitute, External Approach */
"0HUU07Z" = "1" /* Supplement Left Breast with Autologous Tissue Substitute, Open Approach */
"0HUU0JZ" = "1" /* Supplement Left Breast with Synthetic Substitute, Open Approach */
"0HUU0KZ" = "1" /* Supplement Left Breast with Nonautologous Tissue Substitute, Open Approach */
"0HUU37Z" = "1" /* Supplement Left Breast with Autologous Tissue Substitute, Percutaneous Approach */
"0HUU3KZ" = "1" /* Supplement Left Breast with Nonautologous Tissue Substitute, Percutaneous Approach */
"0HUU77Z" = "1" /* Supplement Left Breast with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0HUU7JZ" = "1" /* Supplement Left Breast with Synthetic Substitute, Via Natural or Artificial Opening */
"0HUU7KZ" = "1" /* Supplement Left Breast with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0HUU87Z" = "1" /* Supplement Left Breast with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0HUU8JZ" = "1" /* Supplement Left Breast with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0HUU8KZ" = "1" /* Supplement Left Breast with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0HUUX7Z" = "1" /* Supplement Left Breast with Autologous Tissue Substitute, External Approach */
"0HUUXJZ" = "1" /* Supplement Left Breast with Synthetic Substitute, External Approach */
"0HUUXKZ" = "1" /* Supplement Left Breast with Nonautologous Tissue Substitute, External Approach */
"0HUV07Z" = "1" /* Supplement Bilateral Breast with Autologous Tissue Substitute, Open Approach */
"0HUV0JZ" = "1" /* Supplement Bilateral Breast with Synthetic Substitute, Open Approach */
"0HUV0KZ" = "1" /* Supplement Bilateral Breast with Nonautologous Tissue Substitute, Open Approach */
"0HUV37Z" = "1" /* Supplement Bilateral Breast with Autologous Tissue Substitute, Percutaneous Approach */
"0HUV3KZ" = "1" /* Supplement Bilateral Breast with Nonautologous Tissue Substitute, Percutaneous Approach */
"0HUV77Z" = "1" /* Supplement Bilateral Breast with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0HUV7JZ" = "1" /* Supplement Bilateral Breast with Synthetic Substitute, Via Natural or Artificial Opening */
"0HUV7KZ" = "1" /* Supplement Bilateral Breast with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0HUV87Z" = "1" /* Supplement Bilateral Breast with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0HUV8JZ" = "1" /* Supplement Bilateral Breast with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0HUV8KZ" = "1" /* Supplement Bilateral Breast with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0HUVX7Z" = "1" /* Supplement Bilateral Breast with Autologous Tissue Substitute, External Approach */
"0HUVXJZ" = "1" /* Supplement Bilateral Breast with Synthetic Substitute, External Approach */
"0HUVXKZ" = "1" /* Supplement Bilateral Breast with Nonautologous Tissue Substitute, External Approach */
"0HUW07Z" = "1" /* Supplement Right Nipple with Autologous Tissue Substitute, Open Approach */
"0HUW0JZ" = "1" /* Supplement Right Nipple with Synthetic Substitute, Open Approach */
"0HUW0KZ" = "1" /* Supplement Right Nipple with Nonautologous Tissue Substitute, Open Approach */
"0HUW37Z" = "1" /* Supplement Right Nipple with Autologous Tissue Substitute, Percutaneous Approach */
"0HUW3JZ" = "1" /* Supplement Right Nipple with Synthetic Substitute, Percutaneous Approach */
"0HUW3KZ" = "1" /* Supplement Right Nipple with Nonautologous Tissue Substitute, Percutaneous Approach */
"0HUW77Z" = "1" /* Supplement Right Nipple with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0HUW7JZ" = "1" /* Supplement Right Nipple with Synthetic Substitute, Via Natural or Artificial Opening */
"0HUW7KZ" = "1" /* Supplement Right Nipple with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0HUW87Z" = "1" /* Supplement Right Nipple with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0HUW8JZ" = "1" /* Supplement Right Nipple with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0HUW8KZ" = "1" /* Supplement Right Nipple with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0HUWX7Z" = "1" /* Supplement Right Nipple with Autologous Tissue Substitute, External Approach */
"0HUWXJZ" = "1" /* Supplement Right Nipple with Synthetic Substitute, External Approach */
"0HUWXKZ" = "1" /* Supplement Right Nipple with Nonautologous Tissue Substitute, External Approach */
"0HUX07Z" = "1" /* Supplement Left Nipple with Autologous Tissue Substitute, Open Approach */
"0HUX0JZ" = "1" /* Supplement Left Nipple with Synthetic Substitute, Open Approach */
"0HUX0KZ" = "1" /* Supplement Left Nipple with Nonautologous Tissue Substitute, Open Approach */
"0HUX37Z" = "1" /* Supplement Left Nipple with Autologous Tissue Substitute, Percutaneous Approach */
"0HUX3JZ" = "1" /* Supplement Left Nipple with Synthetic Substitute, Percutaneous Approach */
"0HUX3KZ" = "1" /* Supplement Left Nipple with Nonautologous Tissue Substitute, Percutaneous Approach */
"0HUX77Z" = "1" /* Supplement Left Nipple with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0HUX7JZ" = "1" /* Supplement Left Nipple with Synthetic Substitute, Via Natural or Artificial Opening */
"0HUX7KZ" = "1" /* Supplement Left Nipple with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0HUX87Z" = "1" /* Supplement Left Nipple with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0HUX8JZ" = "1" /* Supplement Left Nipple with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0HUX8KZ" = "1" /* Supplement Left Nipple with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0HUXX7Z" = "1" /* Supplement Left Nipple with Autologous Tissue Substitute, External Approach */
"0HUXXJZ" = "1" /* Supplement Left Nipple with Synthetic Substitute, External Approach */
"0HUXXKZ" = "1" /* Supplement Left Nipple with Nonautologous Tissue Substitute, External Approach */
"0HWT0JZ" = "1" /* Revision of Synthetic Substitute in Right Breast, Open Approach */
"0HWT3JZ" = "1" /* Revision of Synthetic Substitute in Right Breast, Percutaneous Approach */
"0HWU0JZ" = "1" /* Revision of Synthetic Substitute in Left Breast, Open Approach */
"0HWU3JZ" = "1" /* Revision of Synthetic Substitute in Left Breast, Percutaneous Approach */
"0HX0XZZ" = "1" /* Transfer Scalp Skin, External Approach */
"0HX1XZZ" = "1" /* Transfer Face Skin, External Approach */
"0HX2XZZ" = "1" /* Transfer Right Ear Skin, External Approach */
"0HX3XZZ" = "1" /* Transfer Left Ear Skin, External Approach */
"0HX4XZZ" = "1" /* Transfer Neck Skin, External Approach */
"0HX5XZZ" = "1" /* Transfer Chest Skin, External Approach */
"0HX6XZZ" = "1" /* Transfer Back Skin, External Approach */
"0HX7XZZ" = "1" /* Transfer Abdomen Skin, External Approach */
"0HX8XZZ" = "1" /* Transfer Buttock Skin, External Approach */
"0HX9XZZ" = "1" /* Transfer Perineum Skin, External Approach */
"0HXAXZZ" = "1" /* Transfer Genitalia Skin, External Approach */
"0HXBXZZ" = "1" /* Transfer Right Upper Arm Skin, External Approach */
"0HXCXZZ" = "1" /* Transfer Left Upper Arm Skin, External Approach */
"0HXDXZZ" = "1" /* Transfer Right Lower Arm Skin, External Approach */
"0HXEXZZ" = "1" /* Transfer Left Lower Arm Skin, External Approach */
"0HXFXZZ" = "1" /* Transfer Right Hand Skin, External Approach */
"0HXGXZZ" = "1" /* Transfer Left Hand Skin, External Approach */
"0HXHXZZ" = "1" /* Transfer Right Upper Leg Skin, External Approach */
"0HXJXZZ" = "1" /* Transfer Left Upper Leg Skin, External Approach */
"0HXKXZZ" = "1" /* Transfer Right Lower Leg Skin, External Approach */
"0HXLXZZ" = "1" /* Transfer Left Lower Leg Skin, External Approach */
"0HXMXZZ" = "1" /* Transfer Right Foot Skin, External Approach */
"0HXNXZZ" = "1" /* Transfer Left Foot Skin, External Approach */
"0J010ZZ" = "1" /* Alteration of Face Subcutaneous Tissue and Fascia, Open Approach */
"0J013ZZ" = "1" /* Alteration of Face Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J040ZZ" = "1" /* Alteration of Anterior Neck Subcutaneous Tissue and Fascia, Open Approach */
"0J043ZZ" = "1" /* Alteration of Anterior Neck Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J050ZZ" = "1" /* Alteration of Posterior Neck Subcutaneous Tissue and Fascia, Open Approach */
"0J053ZZ" = "1" /* Alteration of Posterior Neck Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J060ZZ" = "1" /* Alteration of Chest Subcutaneous Tissue and Fascia, Open Approach */
"0J063ZZ" = "1" /* Alteration of Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J070ZZ" = "1" /* Alteration of Back Subcutaneous Tissue and Fascia, Open Approach */
"0J073ZZ" = "1" /* Alteration of Back Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J080ZZ" = "1" /* Alteration of Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0J083ZZ" = "1" /* Alteration of Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J090ZZ" = "1" /* Alteration of Buttock Subcutaneous Tissue and Fascia, Open Approach */
"0J093ZZ" = "1" /* Alteration of Buttock Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J0D0ZZ" = "1" /* Alteration of Right Upper Arm Subcutaneous Tissue and Fascia, Open Approach */
"0J0D3ZZ" = "1" /* Alteration of Right Upper Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J0F0ZZ" = "1" /* Alteration of Left Upper Arm Subcutaneous Tissue and Fascia, Open Approach */
"0J0F3ZZ" = "1" /* Alteration of Left Upper Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J0G0ZZ" = "1" /* Alteration of Right Lower Arm Subcutaneous Tissue and Fascia, Open Approach */
"0J0G3ZZ" = "1" /* Alteration of Right Lower Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J0H0ZZ" = "1" /* Alteration of Left Lower Arm Subcutaneous Tissue and Fascia, Open Approach */
"0J0H3ZZ" = "1" /* Alteration of Left Lower Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J0L0ZZ" = "1" /* Alteration of Right Upper Leg Subcutaneous Tissue and Fascia, Open Approach */
"0J0L3ZZ" = "1" /* Alteration of Right Upper Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J0M0ZZ" = "1" /* Alteration of Left Upper Leg Subcutaneous Tissue and Fascia, Open Approach */
"0J0M3ZZ" = "1" /* Alteration of Left Upper Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J0N0ZZ" = "1" /* Alteration of Right Lower Leg Subcutaneous Tissue and Fascia, Open Approach */
"0J0N3ZZ" = "1" /* Alteration of Right Lower Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J0P0ZZ" = "1" /* Alteration of Left Lower Leg Subcutaneous Tissue and Fascia, Open Approach */
"0J0P3ZZ" = "1" /* Alteration of Left Lower Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J800ZZ" = "1" /* Division of Scalp Subcutaneous Tissue and Fascia, Open Approach */
"0J803ZZ" = "1" /* Division of Scalp Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J810ZZ" = "1" /* Division of Face Subcutaneous Tissue and Fascia, Open Approach */
"0J813ZZ" = "1" /* Division of Face Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J840ZZ" = "1" /* Division of Anterior Neck Subcutaneous Tissue and Fascia, Open Approach */
"0J843ZZ" = "1" /* Division of Anterior Neck Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J850ZZ" = "1" /* Division of Posterior Neck Subcutaneous Tissue and Fascia, Open Approach */
"0J853ZZ" = "1" /* Division of Posterior Neck Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J860ZZ" = "1" /* Division of Chest Subcutaneous Tissue and Fascia, Open Approach */
"0J863ZZ" = "1" /* Division of Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J870ZZ" = "1" /* Division of Back Subcutaneous Tissue and Fascia, Open Approach */
"0J873ZZ" = "1" /* Division of Back Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J880ZZ" = "1" /* Division of Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0J883ZZ" = "1" /* Division of Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J890ZZ" = "1" /* Division of Buttock Subcutaneous Tissue and Fascia, Open Approach */
"0J893ZZ" = "1" /* Division of Buttock Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J8B0ZZ" = "1" /* Division of Perineum Subcutaneous Tissue and Fascia, Open Approach */
"0J8B3ZZ" = "1" /* Division of Perineum Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J8C0ZZ" = "1" /* Division of Pelvic Region Subcutaneous Tissue and Fascia, Open Approach */
"0J8C3ZZ" = "1" /* Division of Pelvic Region Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J8D0ZZ" = "1" /* Division of Right Upper Arm Subcutaneous Tissue and Fascia, Open Approach */
"0J8D3ZZ" = "1" /* Division of Right Upper Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J8F0ZZ" = "1" /* Division of Left Upper Arm Subcutaneous Tissue and Fascia, Open Approach */
"0J8F3ZZ" = "1" /* Division of Left Upper Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J8G0ZZ" = "1" /* Division of Right Lower Arm Subcutaneous Tissue and Fascia, Open Approach */
"0J8G3ZZ" = "1" /* Division of Right Lower Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J8H0ZZ" = "1" /* Division of Left Lower Arm Subcutaneous Tissue and Fascia, Open Approach */
"0J8H3ZZ" = "1" /* Division of Left Lower Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J8J0ZZ" = "1" /* Division of Right Hand Subcutaneous Tissue and Fascia, Open Approach */
"0J8J3ZZ" = "1" /* Division of Right Hand Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J8K0ZZ" = "1" /* Division of Left Hand Subcutaneous Tissue and Fascia, Open Approach */
"0J8K3ZZ" = "1" /* Division of Left Hand Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J8L0ZZ" = "1" /* Division of Right Upper Leg Subcutaneous Tissue and Fascia, Open Approach */
"0J8L3ZZ" = "1" /* Division of Right Upper Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J8M0ZZ" = "1" /* Division of Left Upper Leg Subcutaneous Tissue and Fascia, Open Approach */
"0J8M3ZZ" = "1" /* Division of Left Upper Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J8N0ZZ" = "1" /* Division of Right Lower Leg Subcutaneous Tissue and Fascia, Open Approach */
"0J8N3ZZ" = "1" /* Division of Right Lower Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J8P0ZZ" = "1" /* Division of Left Lower Leg Subcutaneous Tissue and Fascia, Open Approach */
"0J8P3ZZ" = "1" /* Division of Left Lower Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J8Q0ZZ" = "1" /* Division of Right Foot Subcutaneous Tissue and Fascia, Open Approach */
"0J8Q3ZZ" = "1" /* Division of Right Foot Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J8R0ZZ" = "1" /* Division of Left Foot Subcutaneous Tissue and Fascia, Open Approach */
"0J8R3ZZ" = "1" /* Division of Left Foot Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J8S0ZZ" = "1" /* Division of Head and Neck Subcutaneous Tissue and Fascia, Open Approach */
"0J8S3ZZ" = "1" /* Division of Head and Neck Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J8T0ZZ" = "1" /* Division of Trunk Subcutaneous Tissue and Fascia, Open Approach */
"0J8T3ZZ" = "1" /* Division of Trunk Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J8V0ZZ" = "1" /* Division of Upper Extremity Subcutaneous Tissue and Fascia, Open Approach */
"0J8V3ZZ" = "1" /* Division of Upper Extremity Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0J8W0ZZ" = "1" /* Division of Lower Extremity Subcutaneous Tissue and Fascia, Open Approach */
"0J8W3ZZ" = "1" /* Division of Lower Extremity Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JB00ZZ" = "1" /* Excision of Scalp Subcutaneous Tissue and Fascia, Open Approach */
"0JB10ZZ" = "1" /* Excision of Face Subcutaneous Tissue and Fascia, Open Approach */
"0JB13ZZ" = "1" /* Excision of Face Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JB40ZZ" = "1" /* Excision of Anterior Neck Subcutaneous Tissue and Fascia, Open Approach */
"0JB50ZZ" = "1" /* Excision of Posterior Neck Subcutaneous Tissue and Fascia, Open Approach */
"0JB60ZZ" = "1" /* Excision of Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JB70ZZ" = "1" /* Excision of Back Subcutaneous Tissue and Fascia, Open Approach */
"0JB80ZZ" = "1" /* Excision of Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JB90ZZ" = "1" /* Excision of Buttock Subcutaneous Tissue and Fascia, Open Approach */
"0JBB0ZZ" = "1" /* Excision of Perineum Subcutaneous Tissue and Fascia, Open Approach */
"0JBC0ZZ" = "1" /* Excision of Pelvic Region Subcutaneous Tissue and Fascia, Open Approach */
"0JBD0ZZ" = "1" /* Excision of Right Upper Arm Subcutaneous Tissue and Fascia, Open Approach */
"0JBF0ZZ" = "1" /* Excision of Left Upper Arm Subcutaneous Tissue and Fascia, Open Approach */
"0JBG0ZZ" = "1" /* Excision of Right Lower Arm Subcutaneous Tissue and Fascia, Open Approach */
"0JBH0ZZ" = "1" /* Excision of Left Lower Arm Subcutaneous Tissue and Fascia, Open Approach */
"0JBJ0ZZ" = "1" /* Excision of Right Hand Subcutaneous Tissue and Fascia, Open Approach */
"0JBJ3ZZ" = "1" /* Excision of Right Hand Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JBK0ZZ" = "1" /* Excision of Left Hand Subcutaneous Tissue and Fascia, Open Approach */
"0JBK3ZZ" = "1" /* Excision of Left Hand Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JBL0ZZ" = "1" /* Excision of Right Upper Leg Subcutaneous Tissue and Fascia, Open Approach */
"0JBM0ZZ" = "1" /* Excision of Left Upper Leg Subcutaneous Tissue and Fascia, Open Approach */
"0JBN0ZZ" = "1" /* Excision of Right Lower Leg Subcutaneous Tissue and Fascia, Open Approach */
"0JBP0ZZ" = "1" /* Excision of Left Lower Leg Subcutaneous Tissue and Fascia, Open Approach */
"0JBQ0ZZ" = "1" /* Excision of Right Foot Subcutaneous Tissue and Fascia, Open Approach */
"0JBR0ZZ" = "1" /* Excision of Left Foot Subcutaneous Tissue and Fascia, Open Approach */
"0JH00NZ" = "1" /* Insertion of Tissue Expander into Scalp Subcutaneous Tissue and Fascia, Open Approach */
"0JH03NZ" = "1" /* Insertion of Tissue Expander into Scalp Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH10NZ" = "1" /* Insertion of Tissue Expander into Face Subcutaneous Tissue and Fascia, Open Approach */
"0JH13NZ" = "1" /* Insertion of Tissue Expander into Face Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH40NZ" = "1" /* Insertion of Tissue Expander into Anterior Neck Subcutaneous Tissue and Fascia, Open Approach */
"0JH43NZ" = "1" /* Insertion of Tissue Expander into Anterior Neck Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH50NZ" = "1" /* Insertion of Tissue Expander into Posterior Neck Subcutaneous Tissue and Fascia, Open Approach */
"0JH53NZ" = "1" /* Insertion of Tissue Expander into Posterior Neck Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH600Z" = "1" /* Insertion of Hemodynamic Monitoring Device into Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JH607Z" = "1" /* Insertion of Cardiac Resynchronization Pacemaker Pulse Generator into Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JH608Z" = "1" /* Insertion of Defibrillator Generator into Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JH609Z" = "1" /* Insertion of Cardiac Resynchronization Defibrillator Pulse Generator into Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JH60AZ" = "1" /* Insertion of Contractility Modulation Device into Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JH60BZ" = "1" /* Insertion of Single Array Stimulator Generator into Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JH60CZ" = "1" /* Insertion of Single Array Rechargeable Stimulator Generator into Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JH60DZ" = "1" /* Insertion of Multiple Array Stimulator Generator into Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JH60EZ" = "1" /* Insertion of Multiple Array Rechargeable Stimulator Generator into Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JH60MZ" = "1" /* Insertion of Stimulator Generator into Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JH60NZ" = "1" /* Insertion of Tissue Expander into Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JH60PZ" = "1" /* Insertion of Cardiac Rhythm Related Device into Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JH60VZ" = "1" /* Insertion of Infusion Pump into Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JH630Z" = "1" /* Insertion of Hemodynamic Monitoring Device into Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH637Z" = "1" /* Insertion of Cardiac Resynchronization Pacemaker Pulse Generator into Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH638Z" = "1" /* Insertion of Defibrillator Generator into Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH639Z" = "1" /* Insertion of Cardiac Resynchronization Defibrillator Pulse Generator into Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH63AZ" = "1" /* Insertion of Contractility Modulation Device into Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH63BZ" = "1" /* Insertion of Single Array Stimulator Generator into Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH63CZ" = "1" /* Insertion of Single Array Rechargeable Stimulator Generator into Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH63DZ" = "1" /* Insertion of Multiple Array Stimulator Generator into Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH63EZ" = "1" /* Insertion of Multiple Array Rechargeable Stimulator Generator into Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH63MZ" = "1" /* Insertion of Stimulator Generator into Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH63NZ" = "1" /* Insertion of Tissue Expander into Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH63PZ" = "1" /* Insertion of Cardiac Rhythm Related Device into Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH63VZ" = "1" /* Insertion of Infusion Pump into Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH70BZ" = "1" /* Insertion of Single Array Stimulator Generator into Back Subcutaneous Tissue and Fascia, Open Approach */
"0JH70CZ" = "1" /* Insertion of Single Array Rechargeable Stimulator Generator into Back Subcutaneous Tissue and Fascia, Open Approach */
"0JH70DZ" = "1" /* Insertion of Multiple Array Stimulator Generator into Back Subcutaneous Tissue and Fascia, Open Approach */
"0JH70EZ" = "1" /* Insertion of Multiple Array Rechargeable Stimulator Generator into Back Subcutaneous Tissue and Fascia, Open Approach */
"0JH70MZ" = "1" /* Insertion of Stimulator Generator into Back Subcutaneous Tissue and Fascia, Open Approach */
"0JH70NZ" = "1" /* Insertion of Tissue Expander into Back Subcutaneous Tissue and Fascia, Open Approach */
"0JH70VZ" = "1" /* Insertion of Infusion Pump into Back Subcutaneous Tissue and Fascia, Open Approach */
"0JH73BZ" = "1" /* Insertion of Single Array Stimulator Generator into Back Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH73CZ" = "1" /* Insertion of Single Array Rechargeable Stimulator Generator into Back Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH73DZ" = "1" /* Insertion of Multiple Array Stimulator Generator into Back Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH73EZ" = "1" /* Insertion of Multiple Array Rechargeable Stimulator Generator into Back Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH73MZ" = "1" /* Insertion of Stimulator Generator into Back Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH73NZ" = "1" /* Insertion of Tissue Expander into Back Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH73VZ" = "1" /* Insertion of Infusion Pump into Back Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH800Z" = "1" /* Insertion of Hemodynamic Monitoring Device into Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JH807Z" = "1" /* Insertion of Cardiac Resynchronization Pacemaker Pulse Generator into Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JH808Z" = "1" /* Insertion of Defibrillator Generator into Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JH809Z" = "1" /* Insertion of Cardiac Resynchronization Defibrillator Pulse Generator into Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JH80AZ" = "1" /* Insertion of Contractility Modulation Device into Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JH80BZ" = "1" /* Insertion of Single Array Stimulator Generator into Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JH80CZ" = "1" /* Insertion of Single Array Rechargeable Stimulator Generator into Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JH80DZ" = "1" /* Insertion of Multiple Array Stimulator Generator into Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JH80EZ" = "1" /* Insertion of Multiple Array Rechargeable Stimulator Generator into Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JH80MZ" = "1" /* Insertion of Stimulator Generator into Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JH80NZ" = "1" /* Insertion of Tissue Expander into Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JH80PZ" = "1" /* Insertion of Cardiac Rhythm Related Device into Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JH80VZ" = "1" /* Insertion of Infusion Pump into Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JH830Z" = "1" /* Insertion of Hemodynamic Monitoring Device into Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH837Z" = "1" /* Insertion of Cardiac Resynchronization Pacemaker Pulse Generator into Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH838Z" = "1" /* Insertion of Defibrillator Generator into Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH839Z" = "1" /* Insertion of Cardiac Resynchronization Defibrillator Pulse Generator into Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH83AZ" = "1" /* Insertion of Contractility Modulation Device into Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH83BZ" = "1" /* Insertion of Single Array Stimulator Generator into Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH83CZ" = "1" /* Insertion of Single Array Rechargeable Stimulator Generator into Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH83DZ" = "1" /* Insertion of Multiple Array Stimulator Generator into Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH83EZ" = "1" /* Insertion of Multiple Array Rechargeable Stimulator Generator into Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH83MZ" = "1" /* Insertion of Stimulator Generator into Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH83NZ" = "1" /* Insertion of Tissue Expander into Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH83PZ" = "1" /* Insertion of Cardiac Rhythm Related Device into Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH83VZ" = "1" /* Insertion of Infusion Pump into Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH90NZ" = "1" /* Insertion of Tissue Expander into Buttock Subcutaneous Tissue and Fascia, Open Approach */
"0JH93NZ" = "1" /* Insertion of Tissue Expander into Buttock Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JHB0NZ" = "1" /* Insertion of Tissue Expander into Perineum Subcutaneous Tissue and Fascia, Open Approach */
"0JHB3NZ" = "1" /* Insertion of Tissue Expander into Perineum Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JHC0NZ" = "1" /* Insertion of Tissue Expander into Pelvic Region Subcutaneous Tissue and Fascia, Open Approach */
"0JHC3NZ" = "1" /* Insertion of Tissue Expander into Pelvic Region Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JHD0NZ" = "1" /* Insertion of Tissue Expander into Right Upper Arm Subcutaneous Tissue and Fascia, Open Approach */
"0JHD3NZ" = "1" /* Insertion of Tissue Expander into Right Upper Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JHF0NZ" = "1" /* Insertion of Tissue Expander into Left Upper Arm Subcutaneous Tissue and Fascia, Open Approach */
"0JHF3NZ" = "1" /* Insertion of Tissue Expander into Left Upper Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JHG0NZ" = "1" /* Insertion of Tissue Expander into Right Lower Arm Subcutaneous Tissue and Fascia, Open Approach */
"0JHG3NZ" = "1" /* Insertion of Tissue Expander into Right Lower Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JHH0NZ" = "1" /* Insertion of Tissue Expander into Left Lower Arm Subcutaneous Tissue and Fascia, Open Approach */
"0JHH3NZ" = "1" /* Insertion of Tissue Expander into Left Lower Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JHJ0NZ" = "1" /* Insertion of Tissue Expander into Right Hand Subcutaneous Tissue and Fascia, Open Approach */
"0JHJ3NZ" = "1" /* Insertion of Tissue Expander into Right Hand Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JHK0NZ" = "1" /* Insertion of Tissue Expander into Left Hand Subcutaneous Tissue and Fascia, Open Approach */
"0JHK3NZ" = "1" /* Insertion of Tissue Expander into Left Hand Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JHL0NZ" = "1" /* Insertion of Tissue Expander into Right Upper Leg Subcutaneous Tissue and Fascia, Open Approach */
"0JHL3NZ" = "1" /* Insertion of Tissue Expander into Right Upper Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JHM0NZ" = "1" /* Insertion of Tissue Expander into Left Upper Leg Subcutaneous Tissue and Fascia, Open Approach */
"0JHM3NZ" = "1" /* Insertion of Tissue Expander into Left Upper Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JHN0NZ" = "1" /* Insertion of Tissue Expander into Right Lower Leg Subcutaneous Tissue and Fascia, Open Approach */
"0JHN3NZ" = "1" /* Insertion of Tissue Expander into Right Lower Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JHP0NZ" = "1" /* Insertion of Tissue Expander into Left Lower Leg Subcutaneous Tissue and Fascia, Open Approach */
"0JHP3NZ" = "1" /* Insertion of Tissue Expander into Left Lower Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JHQ0NZ" = "1" /* Insertion of Tissue Expander into Right Foot Subcutaneous Tissue and Fascia, Open Approach */
"0JHQ3NZ" = "1" /* Insertion of Tissue Expander into Right Foot Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JHR0NZ" = "1" /* Insertion of Tissue Expander into Left Foot Subcutaneous Tissue and Fascia, Open Approach */
"0JHR3NZ" = "1" /* Insertion of Tissue Expander into Left Foot Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JHS01Z" = "1" /* Insertion of Radioactive Element into Head and Neck Subcutaneous Tissue and Fascia, Open Approach */
"0JHS31Z" = "1" /* Insertion of Radioactive Element into Head and Neck Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JHT01Z" = "1" /* Insertion of Radioactive Element into Trunk Subcutaneous Tissue and Fascia, Open Approach */
"0JHT0VZ" = "1" /* Insertion of Infusion Pump into Trunk Subcutaneous Tissue and Fascia, Open Approach */
"0JHT31Z" = "1" /* Insertion of Radioactive Element into Trunk Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JHT3VZ" = "1" /* Insertion of Infusion Pump into Trunk Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JHV01Z" = "1" /* Insertion of Radioactive Element into Upper Extremity Subcutaneous Tissue and Fascia, Open Approach */
"0JHV31Z" = "1" /* Insertion of Radioactive Element into Upper Extremity Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JHW01Z" = "1" /* Insertion of Radioactive Element into Lower Extremity Subcutaneous Tissue and Fascia, Open Approach */
"0JHW31Z" = "1" /* Insertion of Radioactive Element into Lower Extremity Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JN00ZZ" = "1" /* Release Scalp Subcutaneous Tissue and Fascia, Open Approach */
"0JN03ZZ" = "1" /* Release Scalp Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JN10ZZ" = "1" /* Release Face Subcutaneous Tissue and Fascia, Open Approach */
"0JN13ZZ" = "1" /* Release Face Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JN40ZZ" = "1" /* Release Anterior Neck Subcutaneous Tissue and Fascia, Open Approach */
"0JN43ZZ" = "1" /* Release Anterior Neck Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JN50ZZ" = "1" /* Release Posterior Neck Subcutaneous Tissue and Fascia, Open Approach */
"0JN53ZZ" = "1" /* Release Posterior Neck Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JN60ZZ" = "1" /* Release Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JN63ZZ" = "1" /* Release Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JN70ZZ" = "1" /* Release Back Subcutaneous Tissue and Fascia, Open Approach */
"0JN73ZZ" = "1" /* Release Back Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JN80ZZ" = "1" /* Release Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JN83ZZ" = "1" /* Release Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JN90ZZ" = "1" /* Release Buttock Subcutaneous Tissue and Fascia, Open Approach */
"0JN93ZZ" = "1" /* Release Buttock Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JNB0ZZ" = "1" /* Release Perineum Subcutaneous Tissue and Fascia, Open Approach */
"0JNB3ZZ" = "1" /* Release Perineum Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JNC0ZZ" = "1" /* Release Pelvic Region Subcutaneous Tissue and Fascia, Open Approach */
"0JNC3ZZ" = "1" /* Release Pelvic Region Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JND0ZZ" = "1" /* Release Right Upper Arm Subcutaneous Tissue and Fascia, Open Approach */
"0JND3ZZ" = "1" /* Release Right Upper Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JNF0ZZ" = "1" /* Release Left Upper Arm Subcutaneous Tissue and Fascia, Open Approach */
"0JNF3ZZ" = "1" /* Release Left Upper Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JNG0ZZ" = "1" /* Release Right Lower Arm Subcutaneous Tissue and Fascia, Open Approach */
"0JNG3ZZ" = "1" /* Release Right Lower Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JNH0ZZ" = "1" /* Release Left Lower Arm Subcutaneous Tissue and Fascia, Open Approach */
"0JNH3ZZ" = "1" /* Release Left Lower Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JNJ0ZZ" = "1" /* Release Right Hand Subcutaneous Tissue and Fascia, Open Approach */
"0JNJ3ZZ" = "1" /* Release Right Hand Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JNK0ZZ" = "1" /* Release Left Hand Subcutaneous Tissue and Fascia, Open Approach */
"0JNK3ZZ" = "1" /* Release Left Hand Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JNL0ZZ" = "1" /* Release Right Upper Leg Subcutaneous Tissue and Fascia, Open Approach */
"0JNL3ZZ" = "1" /* Release Right Upper Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JNM0ZZ" = "1" /* Release Left Upper Leg Subcutaneous Tissue and Fascia, Open Approach */
"0JNM3ZZ" = "1" /* Release Left Upper Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JNN0ZZ" = "1" /* Release Right Lower Leg Subcutaneous Tissue and Fascia, Open Approach */
"0JNN3ZZ" = "1" /* Release Right Lower Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JNP0ZZ" = "1" /* Release Left Lower Leg Subcutaneous Tissue and Fascia, Open Approach */
"0JNP3ZZ" = "1" /* Release Left Lower Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JNQ0ZZ" = "1" /* Release Right Foot Subcutaneous Tissue and Fascia, Open Approach */
"0JNQ3ZZ" = "1" /* Release Right Foot Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JNR0ZZ" = "1" /* Release Left Foot Subcutaneous Tissue and Fascia, Open Approach */
"0JNR3ZZ" = "1" /* Release Left Foot Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JPT0PZ" = "1" /* Removal of Cardiac Rhythm Related Device from Trunk Subcutaneous Tissue and Fascia, Open Approach */
"0JPT3PZ" = "1" /* Removal of Cardiac Rhythm Related Device from Trunk Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JR007Z" = "1" /* Replacement of Scalp Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JR00JZ" = "1" /* Replacement of Scalp Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JR00KZ" = "1" /* Replacement of Scalp Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JR037Z" = "1" /* Replacement of Scalp Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JR03JZ" = "1" /* Replacement of Scalp Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JR03KZ" = "1" /* Replacement of Scalp Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JR107Z" = "1" /* Replacement of Face Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JR10JZ" = "1" /* Replacement of Face Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JR10KZ" = "1" /* Replacement of Face Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JR137Z" = "1" /* Replacement of Face Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JR13JZ" = "1" /* Replacement of Face Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JR13KZ" = "1" /* Replacement of Face Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JR407Z" = "1" /* Replacement of Anterior Neck Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JR40JZ" = "1" /* Replacement of Anterior Neck Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JR40KZ" = "1" /* Replacement of Anterior Neck Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JR437Z" = "1" /* Replacement of Anterior Neck Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JR43JZ" = "1" /* Replacement of Anterior Neck Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JR43KZ" = "1" /* Replacement of Anterior Neck Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JR507Z" = "1" /* Replacement of Posterior Neck Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JR50JZ" = "1" /* Replacement of Posterior Neck Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JR50KZ" = "1" /* Replacement of Posterior Neck Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JR537Z" = "1" /* Replacement of Posterior Neck Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JR53JZ" = "1" /* Replacement of Posterior Neck Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JR53KZ" = "1" /* Replacement of Posterior Neck Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JR607Z" = "1" /* Replacement of Chest Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JR60JZ" = "1" /* Replacement of Chest Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JR60KZ" = "1" /* Replacement of Chest Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JR637Z" = "1" /* Replacement of Chest Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JR63JZ" = "1" /* Replacement of Chest Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JR63KZ" = "1" /* Replacement of Chest Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JR707Z" = "1" /* Replacement of Back Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JR70JZ" = "1" /* Replacement of Back Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JR70KZ" = "1" /* Replacement of Back Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JR737Z" = "1" /* Replacement of Back Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JR73JZ" = "1" /* Replacement of Back Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JR73KZ" = "1" /* Replacement of Back Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JR807Z" = "1" /* Replacement of Abdomen Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JR80JZ" = "1" /* Replacement of Abdomen Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JR80KZ" = "1" /* Replacement of Abdomen Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JR837Z" = "1" /* Replacement of Abdomen Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JR83JZ" = "1" /* Replacement of Abdomen Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JR83KZ" = "1" /* Replacement of Abdomen Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JR907Z" = "1" /* Replacement of Buttock Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JR90JZ" = "1" /* Replacement of Buttock Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JR90KZ" = "1" /* Replacement of Buttock Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JR937Z" = "1" /* Replacement of Buttock Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JR93JZ" = "1" /* Replacement of Buttock Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JR93KZ" = "1" /* Replacement of Buttock Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JRB07Z" = "1" /* Replacement of Perineum Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JRB0JZ" = "1" /* Replacement of Perineum Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JRB0KZ" = "1" /* Replacement of Perineum Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JRB37Z" = "1" /* Replacement of Perineum Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JRB3JZ" = "1" /* Replacement of Perineum Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JRB3KZ" = "1" /* Replacement of Perineum Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JRC07Z" = "1" /* Replacement of Pelvic Region Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JRC0JZ" = "1" /* Replacement of Pelvic Region Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JRC0KZ" = "1" /* Replacement of Pelvic Region Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JRC37Z" = "1" /* Replacement of Pelvic Region Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JRC3JZ" = "1" /* Replacement of Pelvic Region Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JRC3KZ" = "1" /* Replacement of Pelvic Region Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JRD07Z" = "1" /* Replacement of Right Upper Arm Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JRD0JZ" = "1" /* Replacement of Right Upper Arm Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JRD0KZ" = "1" /* Replacement of Right Upper Arm Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JRD37Z" = "1" /* Replacement of Right Upper Arm Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JRD3JZ" = "1" /* Replacement of Right Upper Arm Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JRD3KZ" = "1" /* Replacement of Right Upper Arm Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JRF07Z" = "1" /* Replacement of Left Upper Arm Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JRF0JZ" = "1" /* Replacement of Left Upper Arm Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JRF0KZ" = "1" /* Replacement of Left Upper Arm Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JRF37Z" = "1" /* Replacement of Left Upper Arm Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JRF3JZ" = "1" /* Replacement of Left Upper Arm Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JRF3KZ" = "1" /* Replacement of Left Upper Arm Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JRG07Z" = "1" /* Replacement of Right Lower Arm Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JRG0JZ" = "1" /* Replacement of Right Lower Arm Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JRG0KZ" = "1" /* Replacement of Right Lower Arm Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JRG37Z" = "1" /* Replacement of Right Lower Arm Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JRG3JZ" = "1" /* Replacement of Right Lower Arm Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JRG3KZ" = "1" /* Replacement of Right Lower Arm Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JRH07Z" = "1" /* Replacement of Left Lower Arm Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JRH0JZ" = "1" /* Replacement of Left Lower Arm Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JRH0KZ" = "1" /* Replacement of Left Lower Arm Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JRH37Z" = "1" /* Replacement of Left Lower Arm Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JRH3JZ" = "1" /* Replacement of Left Lower Arm Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JRH3KZ" = "1" /* Replacement of Left Lower Arm Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JRJ07Z" = "1" /* Replacement of Right Hand Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JRJ0JZ" = "1" /* Replacement of Right Hand Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JRJ0KZ" = "1" /* Replacement of Right Hand Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JRJ37Z" = "1" /* Replacement of Right Hand Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JRJ3JZ" = "1" /* Replacement of Right Hand Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JRJ3KZ" = "1" /* Replacement of Right Hand Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JRK07Z" = "1" /* Replacement of Left Hand Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JRK0JZ" = "1" /* Replacement of Left Hand Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JRK0KZ" = "1" /* Replacement of Left Hand Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JRK37Z" = "1" /* Replacement of Left Hand Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JRK3JZ" = "1" /* Replacement of Left Hand Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JRK3KZ" = "1" /* Replacement of Left Hand Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JRL07Z" = "1" /* Replacement of Right Upper Leg Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JRL0JZ" = "1" /* Replacement of Right Upper Leg Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JRL0KZ" = "1" /* Replacement of Right Upper Leg Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JRL37Z" = "1" /* Replacement of Right Upper Leg Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JRL3JZ" = "1" /* Replacement of Right Upper Leg Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JRL3KZ" = "1" /* Replacement of Right Upper Leg Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JRM07Z" = "1" /* Replacement of Left Upper Leg Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JRM0JZ" = "1" /* Replacement of Left Upper Leg Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JRM0KZ" = "1" /* Replacement of Left Upper Leg Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JRM37Z" = "1" /* Replacement of Left Upper Leg Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JRM3JZ" = "1" /* Replacement of Left Upper Leg Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JRM3KZ" = "1" /* Replacement of Left Upper Leg Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JRN07Z" = "1" /* Replacement of Right Lower Leg Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JRN0JZ" = "1" /* Replacement of Right Lower Leg Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JRN0KZ" = "1" /* Replacement of Right Lower Leg Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JRN37Z" = "1" /* Replacement of Right Lower Leg Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JRN3JZ" = "1" /* Replacement of Right Lower Leg Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JRN3KZ" = "1" /* Replacement of Right Lower Leg Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JRP07Z" = "1" /* Replacement of Left Lower Leg Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JRP0JZ" = "1" /* Replacement of Left Lower Leg Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JRP0KZ" = "1" /* Replacement of Left Lower Leg Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JRP37Z" = "1" /* Replacement of Left Lower Leg Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JRP3JZ" = "1" /* Replacement of Left Lower Leg Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JRP3KZ" = "1" /* Replacement of Left Lower Leg Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JRQ07Z" = "1" /* Replacement of Right Foot Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JRQ0JZ" = "1" /* Replacement of Right Foot Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JRQ0KZ" = "1" /* Replacement of Right Foot Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JRQ37Z" = "1" /* Replacement of Right Foot Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JRQ3JZ" = "1" /* Replacement of Right Foot Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JRQ3KZ" = "1" /* Replacement of Right Foot Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JRR07Z" = "1" /* Replacement of Left Foot Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JRR0JZ" = "1" /* Replacement of Left Foot Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JRR0KZ" = "1" /* Replacement of Left Foot Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JRR37Z" = "1" /* Replacement of Left Foot Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JRR3JZ" = "1" /* Replacement of Left Foot Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JRR3KZ" = "1" /* Replacement of Left Foot Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JU007Z" = "1" /* Supplement of Scalp Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JU00JZ" = "1" /* Supplement of Scalp Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JU00KZ" = "1" /* Supplement of Scalp Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JU037Z" = "1" /* Supplement of Scalp Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JU03JZ" = "1" /* Supplement of Scalp Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JU03KZ" = "1" /* Supplement of Scalp Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JU107Z" = "1" /* Supplement of Face Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JU10JZ" = "1" /* Supplement of Face Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JU10KZ" = "1" /* Supplement of Face Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JU137Z" = "1" /* Supplement of Face Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JU13JZ" = "1" /* Supplement of Face Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JU13KZ" = "1" /* Supplement of Face Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JU407Z" = "1" /* Supplement of Anterior Neck Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JU40JZ" = "1" /* Supplement of Anterior Neck Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JU40KZ" = "1" /* Supplement of Anterior Neck Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JU437Z" = "1" /* Supplement of Anterior Neck Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JU43JZ" = "1" /* Supplement of Anterior Neck Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JU43KZ" = "1" /* Supplement of Anterior Neck Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JU507Z" = "1" /* Supplement of Posterior Neck Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JU50JZ" = "1" /* Supplement of Posterior Neck Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JU50KZ" = "1" /* Supplement of Posterior Neck Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JU537Z" = "1" /* Supplement of Posterior Neck Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JU53JZ" = "1" /* Supplement of Posterior Neck Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JU53KZ" = "1" /* Supplement of Posterior Neck Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JU607Z" = "1" /* Supplement of Chest Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JU60JZ" = "1" /* Supplement of Chest Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JU60KZ" = "1" /* Supplement of Chest Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JU637Z" = "1" /* Supplement of Chest Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JU63JZ" = "1" /* Supplement of Chest Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JU63KZ" = "1" /* Supplement of Chest Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JU707Z" = "1" /* Supplement of Back Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JU70JZ" = "1" /* Supplement of Back Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JU70KZ" = "1" /* Supplement of Back Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JU737Z" = "1" /* Supplement of Back Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JU73JZ" = "1" /* Supplement of Back Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JU73KZ" = "1" /* Supplement of Back Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JU807Z" = "1" /* Supplement of Abdomen Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JU80JZ" = "1" /* Supplement of Abdomen Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JU80KZ" = "1" /* Supplement of Abdomen Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JU837Z" = "1" /* Supplement of Abdomen Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JU83JZ" = "1" /* Supplement of Abdomen Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JU83KZ" = "1" /* Supplement of Abdomen Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JU907Z" = "1" /* Supplement of Buttock Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JU90JZ" = "1" /* Supplement of Buttock Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JU90KZ" = "1" /* Supplement of Buttock Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JU937Z" = "1" /* Supplement of Buttock Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JU93JZ" = "1" /* Supplement of Buttock Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JU93KZ" = "1" /* Supplement of Buttock Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JUB07Z" = "1" /* Supplement of Perineum Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JUB0JZ" = "1" /* Supplement of Perineum Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JUB0KZ" = "1" /* Supplement of Perineum Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JUB37Z" = "1" /* Supplement of Perineum Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JUB3JZ" = "1" /* Supplement of Perineum Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JUB3KZ" = "1" /* Supplement of Perineum Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JUC07Z" = "1" /* Supplement of Pelvic Region Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JUC0JZ" = "1" /* Supplement of Pelvic Region Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JUC0KZ" = "1" /* Supplement of Pelvic Region Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JUC37Z" = "1" /* Supplement of Pelvic Region Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JUC3JZ" = "1" /* Supplement of Pelvic Region Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JUC3KZ" = "1" /* Supplement of Pelvic Region Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JUD07Z" = "1" /* Supplement of Right Upper Arm Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JUD0JZ" = "1" /* Supplement of Right Upper Arm Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JUD0KZ" = "1" /* Supplement of Right Upper Arm Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JUD37Z" = "1" /* Supplement of Right Upper Arm Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JUD3JZ" = "1" /* Supplement of Right Upper Arm Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JUD3KZ" = "1" /* Supplement of Right Upper Arm Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JUF07Z" = "1" /* Supplement of Left Upper Arm Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JUF0JZ" = "1" /* Supplement of Left Upper Arm Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JUF0KZ" = "1" /* Supplement of Left Upper Arm Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JUF37Z" = "1" /* Supplement of Left Upper Arm Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JUF3JZ" = "1" /* Supplement of Left Upper Arm Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JUF3KZ" = "1" /* Supplement of Left Upper Arm Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JUG07Z" = "1" /* Supplement of Right Lower Arm Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JUG0JZ" = "1" /* Supplement of Right Lower Arm Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JUG0KZ" = "1" /* Supplement of Right Lower Arm Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JUG37Z" = "1" /* Supplement of Right Lower Arm Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JUG3JZ" = "1" /* Supplement of Right Lower Arm Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JUG3KZ" = "1" /* Supplement of Right Lower Arm Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JUH07Z" = "1" /* Supplement of Left Lower Arm Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JUH0JZ" = "1" /* Supplement of Left Lower Arm Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JUH0KZ" = "1" /* Supplement of Left Lower Arm Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JUH37Z" = "1" /* Supplement of Left Lower Arm Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JUH3JZ" = "1" /* Supplement of Left Lower Arm Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JUH3KZ" = "1" /* Supplement of Left Lower Arm Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JUJ07Z" = "1" /* Supplement of Right Hand Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JUJ0JZ" = "1" /* Supplement of Right Hand Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JUJ0KZ" = "1" /* Supplement of Right Hand Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JUJ37Z" = "1" /* Supplement of Right Hand Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JUJ3JZ" = "1" /* Supplement of Right Hand Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JUJ3KZ" = "1" /* Supplement of Right Hand Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JUK07Z" = "1" /* Supplement of Left Hand Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JUK0JZ" = "1" /* Supplement of Left Hand Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JUK0KZ" = "1" /* Supplement of Left Hand Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JUK37Z" = "1" /* Supplement of Left Hand Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JUK3JZ" = "1" /* Supplement of Left Hand Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JUK3KZ" = "1" /* Supplement of Left Hand Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JUL07Z" = "1" /* Supplement of Right Upper Leg Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JUL0JZ" = "1" /* Supplement of Right Upper Leg Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JUL0KZ" = "1" /* Supplement of Right Upper Leg Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JUL37Z" = "1" /* Supplement of Right Upper Leg Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JUL3JZ" = "1" /* Supplement of Right Upper Leg Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JUL3KZ" = "1" /* Supplement of Right Upper Leg Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JUM07Z" = "1" /* Supplement of Left Upper Leg Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JUM0JZ" = "1" /* Supplement of Left Upper Leg Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JUM0KZ" = "1" /* Supplement of Left Upper Leg Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JUM37Z" = "1" /* Supplement of Left Upper Leg Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JUM3JZ" = "1" /* Supplement of Left Upper Leg Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JUM3KZ" = "1" /* Supplement of Left Upper Leg Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JUN07Z" = "1" /* Supplement of Right Lower Leg Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JUN0JZ" = "1" /* Supplement of Right Lower Leg Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JUN0KZ" = "1" /* Supplement of Right Lower Leg Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JUN37Z" = "1" /* Supplement of Right Lower Leg Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JUN3JZ" = "1" /* Supplement of Right Lower Leg Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JUN3KZ" = "1" /* Supplement of Right Lower Leg Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JUP07Z" = "1" /* Supplement of Left Lower Leg Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JUP0JZ" = "1" /* Supplement of Left Lower Leg Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JUP0KZ" = "1" /* Supplement of Left Lower Leg Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JUP37Z" = "1" /* Supplement of Left Lower Leg Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JUP3JZ" = "1" /* Supplement of Left Lower Leg Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JUP3KZ" = "1" /* Supplement of Left Lower Leg Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JUQ07Z" = "1" /* Supplement of Right Foot Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JUQ0JZ" = "1" /* Supplement of Right Foot Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JUQ0KZ" = "1" /* Supplement of Right Foot Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JUQ37Z" = "1" /* Supplement of Right Foot Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JUQ3JZ" = "1" /* Supplement of Right Foot Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JUQ3KZ" = "1" /* Supplement of Right Foot Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JUR07Z" = "1" /* Supplement of Left Foot Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Open Approach */
"0JUR0JZ" = "1" /* Supplement of Left Foot Subcutaneous Tissue and Fascia with Synthetic Substitute, Open Approach */
"0JUR0KZ" = "1" /* Supplement of Left Foot Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Open Approach */
"0JUR37Z" = "1" /* Supplement of Left Foot Subcutaneous Tissue and Fascia with Autologous Tissue Substitute, Percutaneous Approach */
"0JUR3JZ" = "1" /* Supplement of Left Foot Subcutaneous Tissue and Fascia with Synthetic Substitute, Percutaneous Approach */
"0JUR3KZ" = "1" /* Supplement of Left Foot Subcutaneous Tissue and Fascia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0JWT0MZ" = "1" /* Revision of Stimulator Generator in Trunk Subcutaneous Tissue and Fascia, Open Approach */
"0JWT0PZ" = "1" /* Revision of Cardiac Rhythm Related Device in Trunk Subcutaneous Tissue and Fascia, Open Approach */
"0JWT3MZ" = "1" /* Revision of Stimulator Generator in Trunk Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JWT3PZ" = "1" /* Revision of Cardiac Rhythm Related Device in Trunk Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JWTXMZ" = "1" /* Revision of Stimulator Generator in Trunk Subcutaneous Tissue and Fascia, External Approach */
"0JX00ZB" = "1" /* Transfer Scalp Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Open Approach */
"0JX00ZC" = "1" /* Transfer Scalp Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Open Approach */
"0JX00ZZ" = "1" /* Transfer Scalp Subcutaneous Tissue and Fascia, Open Approach */
"0JX03ZB" = "1" /* Transfer Scalp Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Percutaneous Approach */
"0JX03ZC" = "1" /* Transfer Scalp Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JX03ZZ" = "1" /* Transfer Scalp Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JX10ZB" = "1" /* Transfer Face Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Open Approach */
"0JX10ZC" = "1" /* Transfer Face Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Open Approach */
"0JX10ZZ" = "1" /* Transfer Face Subcutaneous Tissue and Fascia, Open Approach */
"0JX13ZB" = "1" /* Transfer Face Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Percutaneous Approach */
"0JX13ZC" = "1" /* Transfer Face Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JX13ZZ" = "1" /* Transfer Face Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JX40ZB" = "1" /* Transfer Anterior Neck Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Open Approach */
"0JX40ZC" = "1" /* Transfer Anterior Neck Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Open Approach */
"0JX40ZZ" = "1" /* Transfer Anterior Neck Subcutaneous Tissue and Fascia, Open Approach */
"0JX43ZB" = "1" /* Transfer Anterior Neck Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Percutaneous Approach */
"0JX43ZC" = "1" /* Transfer Anterior Neck Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JX43ZZ" = "1" /* Transfer Anterior Neck Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JX50ZB" = "1" /* Transfer Posterior Neck Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Open Approach */
"0JX50ZC" = "1" /* Transfer Posterior Neck Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Open Approach */
"0JX50ZZ" = "1" /* Transfer Posterior Neck Subcutaneous Tissue and Fascia, Open Approach */
"0JX53ZB" = "1" /* Transfer Posterior Neck Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Percutaneous Approach */
"0JX53ZC" = "1" /* Transfer Posterior Neck Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JX53ZZ" = "1" /* Transfer Posterior Neck Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JX60ZB" = "1" /* Transfer Chest Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Open Approach */
"0JX60ZC" = "1" /* Transfer Chest Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Open Approach */
"0JX60ZZ" = "1" /* Transfer Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JX63ZB" = "1" /* Transfer Chest Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Percutaneous Approach */
"0JX63ZC" = "1" /* Transfer Chest Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JX63ZZ" = "1" /* Transfer Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JX70ZB" = "1" /* Transfer Back Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Open Approach */
"0JX70ZC" = "1" /* Transfer Back Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Open Approach */
"0JX70ZZ" = "1" /* Transfer Back Subcutaneous Tissue and Fascia, Open Approach */
"0JX73ZB" = "1" /* Transfer Back Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Percutaneous Approach */
"0JX73ZC" = "1" /* Transfer Back Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JX73ZZ" = "1" /* Transfer Back Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JX80ZB" = "1" /* Transfer Abdomen Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Open Approach */
"0JX80ZC" = "1" /* Transfer Abdomen Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Open Approach */
"0JX80ZZ" = "1" /* Transfer Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JX83ZB" = "1" /* Transfer Abdomen Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Percutaneous Approach */
"0JX83ZC" = "1" /* Transfer Abdomen Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JX83ZZ" = "1" /* Transfer Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JX90ZB" = "1" /* Transfer Buttock Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Open Approach */
"0JX90ZC" = "1" /* Transfer Buttock Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Open Approach */
"0JX90ZZ" = "1" /* Transfer Buttock Subcutaneous Tissue and Fascia, Open Approach */
"0JX93ZB" = "1" /* Transfer Buttock Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Percutaneous Approach */
"0JX93ZC" = "1" /* Transfer Buttock Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JX93ZZ" = "1" /* Transfer Buttock Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXB0ZB" = "1" /* Transfer Perineum Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Open Approach */
"0JXB0ZC" = "1" /* Transfer Perineum Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Open Approach */
"0JXB0ZZ" = "1" /* Transfer Perineum Subcutaneous Tissue and Fascia, Open Approach */
"0JXB3ZB" = "1" /* Transfer Perineum Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Percutaneous Approach */
"0JXB3ZC" = "1" /* Transfer Perineum Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXB3ZZ" = "1" /* Transfer Perineum Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXC0ZB" = "1" /* Transfer Pelvic Region Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Open Approach */
"0JXC0ZC" = "1" /* Transfer Pelvic Region Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Open Approach */
"0JXC0ZZ" = "1" /* Transfer Pelvic Region Subcutaneous Tissue and Fascia, Open Approach */
"0JXC3ZB" = "1" /* Transfer Pelvic Region Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Percutaneous Approach */
"0JXC3ZC" = "1" /* Transfer Pelvic Region Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXC3ZZ" = "1" /* Transfer Pelvic Region Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXD0ZB" = "1" /* Transfer Right Upper Arm Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Open Approach */
"0JXD0ZC" = "1" /* Transfer Right Upper Arm Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Open Approach */
"0JXD0ZZ" = "1" /* Transfer Right Upper Arm Subcutaneous Tissue and Fascia, Open Approach */
"0JXD3ZB" = "1" /* Transfer Right Upper Arm Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Percutaneous Approach */
"0JXD3ZC" = "1" /* Transfer Right Upper Arm Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXD3ZZ" = "1" /* Transfer Right Upper Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXF0ZB" = "1" /* Transfer Left Upper Arm Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Open Approach */
"0JXF0ZC" = "1" /* Transfer Left Upper Arm Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Open Approach */
"0JXF0ZZ" = "1" /* Transfer Left Upper Arm Subcutaneous Tissue and Fascia, Open Approach */
"0JXF3ZB" = "1" /* Transfer Left Upper Arm Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Percutaneous Approach */
"0JXF3ZC" = "1" /* Transfer Left Upper Arm Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXF3ZZ" = "1" /* Transfer Left Upper Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXG0ZB" = "1" /* Transfer Right Lower Arm Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Open Approach */
"0JXG0ZC" = "1" /* Transfer Right Lower Arm Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Open Approach */
"0JXG0ZZ" = "1" /* Transfer Right Lower Arm Subcutaneous Tissue and Fascia, Open Approach */
"0JXG3ZB" = "1" /* Transfer Right Lower Arm Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Percutaneous Approach */
"0JXG3ZC" = "1" /* Transfer Right Lower Arm Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXG3ZZ" = "1" /* Transfer Right Lower Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXH0ZB" = "1" /* Transfer Left Lower Arm Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Open Approach */
"0JXH0ZC" = "1" /* Transfer Left Lower Arm Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Open Approach */
"0JXH0ZZ" = "1" /* Transfer Left Lower Arm Subcutaneous Tissue and Fascia, Open Approach */
"0JXH3ZB" = "1" /* Transfer Left Lower Arm Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Percutaneous Approach */
"0JXH3ZC" = "1" /* Transfer Left Lower Arm Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXH3ZZ" = "1" /* Transfer Left Lower Arm Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXJ0ZB" = "1" /* Transfer Right Hand Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Open Approach */
"0JXJ0ZC" = "1" /* Transfer Right Hand Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Open Approach */
"0JXJ0ZZ" = "1" /* Transfer Right Hand Subcutaneous Tissue and Fascia, Open Approach */
"0JXJ3ZB" = "1" /* Transfer Right Hand Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Percutaneous Approach */
"0JXJ3ZC" = "1" /* Transfer Right Hand Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXJ3ZZ" = "1" /* Transfer Right Hand Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXK0ZB" = "1" /* Transfer Left Hand Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Open Approach */
"0JXK0ZC" = "1" /* Transfer Left Hand Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Open Approach */
"0JXK0ZZ" = "1" /* Transfer Left Hand Subcutaneous Tissue and Fascia, Open Approach */
"0JXK3ZB" = "1" /* Transfer Left Hand Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Percutaneous Approach */
"0JXK3ZC" = "1" /* Transfer Left Hand Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXK3ZZ" = "1" /* Transfer Left Hand Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXL0ZB" = "1" /* Transfer Right Upper Leg Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Open Approach */
"0JXL0ZC" = "1" /* Transfer Right Upper Leg Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Open Approach */
"0JXL0ZZ" = "1" /* Transfer Right Upper Leg Subcutaneous Tissue and Fascia, Open Approach */
"0JXL3ZB" = "1" /* Transfer Right Upper Leg Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Percutaneous Approach */
"0JXL3ZC" = "1" /* Transfer Right Upper Leg Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXL3ZZ" = "1" /* Transfer Right Upper Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXM0ZB" = "1" /* Transfer Left Upper Leg Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Open Approach */
"0JXM0ZC" = "1" /* Transfer Left Upper Leg Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Open Approach */
"0JXM0ZZ" = "1" /* Transfer Left Upper Leg Subcutaneous Tissue and Fascia, Open Approach */
"0JXM3ZB" = "1" /* Transfer Left Upper Leg Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Percutaneous Approach */
"0JXM3ZC" = "1" /* Transfer Left Upper Leg Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXM3ZZ" = "1" /* Transfer Left Upper Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXN0ZB" = "1" /* Transfer Right Lower Leg Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Open Approach */
"0JXN0ZC" = "1" /* Transfer Right Lower Leg Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Open Approach */
"0JXN0ZZ" = "1" /* Transfer Right Lower Leg Subcutaneous Tissue and Fascia, Open Approach */
"0JXN3ZB" = "1" /* Transfer Right Lower Leg Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Percutaneous Approach */
"0JXN3ZC" = "1" /* Transfer Right Lower Leg Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXN3ZZ" = "1" /* Transfer Right Lower Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXP0ZB" = "1" /* Transfer Left Lower Leg Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Open Approach */
"0JXP0ZC" = "1" /* Transfer Left Lower Leg Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Open Approach */
"0JXP0ZZ" = "1" /* Transfer Left Lower Leg Subcutaneous Tissue and Fascia, Open Approach */
"0JXP3ZB" = "1" /* Transfer Left Lower Leg Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Percutaneous Approach */
"0JXP3ZC" = "1" /* Transfer Left Lower Leg Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXP3ZZ" = "1" /* Transfer Left Lower Leg Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXQ0ZB" = "1" /* Transfer Right Foot Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Open Approach */
"0JXQ0ZC" = "1" /* Transfer Right Foot Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Open Approach */
"0JXQ0ZZ" = "1" /* Transfer Right Foot Subcutaneous Tissue and Fascia, Open Approach */
"0JXQ3ZB" = "1" /* Transfer Right Foot Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Percutaneous Approach */
"0JXQ3ZC" = "1" /* Transfer Right Foot Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXQ3ZZ" = "1" /* Transfer Right Foot Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXR0ZB" = "1" /* Transfer Left Foot Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Open Approach */
"0JXR0ZC" = "1" /* Transfer Left Foot Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Open Approach */
"0JXR0ZZ" = "1" /* Transfer Left Foot Subcutaneous Tissue and Fascia, Open Approach */
"0JXR3ZB" = "1" /* Transfer Left Foot Subcutaneous Tissue and Fascia with Skin and Subcutaneous Tissue, Percutaneous Approach */
"0JXR3ZC" = "1" /* Transfer Left Foot Subcutaneous Tissue and Fascia with Skin, Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JXR3ZZ" = "1" /* Transfer Left Foot Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0K500ZZ" = "1" /* Destruction of Head Muscle, Open Approach */
"0K503ZZ" = "1" /* Destruction of Head Muscle, Percutaneous Approach */
"0K504ZZ" = "1" /* Destruction of Head Muscle, Percutaneous Endoscopic Approach */
"0K510ZZ" = "1" /* Destruction of Facial Muscle, Open Approach */
"0K513ZZ" = "1" /* Destruction of Facial Muscle, Percutaneous Approach */
"0K514ZZ" = "1" /* Destruction of Facial Muscle, Percutaneous Endoscopic Approach */
"0K520ZZ" = "1" /* Destruction of Right Neck Muscle, Open Approach */
"0K523ZZ" = "1" /* Destruction of Right Neck Muscle, Percutaneous Approach */
"0K524ZZ" = "1" /* Destruction of Right Neck Muscle, Percutaneous Endoscopic Approach */
"0K530ZZ" = "1" /* Destruction of Left Neck Muscle, Open Approach */
"0K533ZZ" = "1" /* Destruction of Left Neck Muscle, Percutaneous Approach */
"0K534ZZ" = "1" /* Destruction of Left Neck Muscle, Percutaneous Endoscopic Approach */
"0K540ZZ" = "1" /* Destruction of Tongue, Palate, Pharynx Muscle, Open Approach */
"0K543ZZ" = "1" /* Destruction of Tongue, Palate, Pharynx Muscle, Percutaneous Approach */
"0K544ZZ" = "1" /* Destruction of Tongue, Palate, Pharynx Muscle, Percutaneous Endoscopic Approach */
"0K550ZZ" = "1" /* Destruction of Right Shoulder Muscle, Open Approach */
"0K553ZZ" = "1" /* Destruction of Right Shoulder Muscle, Percutaneous Approach */
"0K554ZZ" = "1" /* Destruction of Right Shoulder Muscle, Percutaneous Endoscopic Approach */
"0K560ZZ" = "1" /* Destruction of Left Shoulder Muscle, Open Approach */
"0K563ZZ" = "1" /* Destruction of Left Shoulder Muscle, Percutaneous Approach */
"0K564ZZ" = "1" /* Destruction of Left Shoulder Muscle, Percutaneous Endoscopic Approach */
"0K570ZZ" = "1" /* Destruction of Right Upper Arm Muscle, Open Approach */
"0K573ZZ" = "1" /* Destruction of Right Upper Arm Muscle, Percutaneous Approach */
"0K574ZZ" = "1" /* Destruction of Right Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0K580ZZ" = "1" /* Destruction of Left Upper Arm Muscle, Open Approach */
"0K583ZZ" = "1" /* Destruction of Left Upper Arm Muscle, Percutaneous Approach */
"0K584ZZ" = "1" /* Destruction of Left Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0K590ZZ" = "1" /* Destruction of Right Lower Arm and Wrist Muscle, Open Approach */
"0K593ZZ" = "1" /* Destruction of Right Lower Arm and Wrist Muscle, Percutaneous Approach */
"0K594ZZ" = "1" /* Destruction of Right Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0K5B0ZZ" = "1" /* Destruction of Left Lower Arm and Wrist Muscle, Open Approach */
"0K5B3ZZ" = "1" /* Destruction of Left Lower Arm and Wrist Muscle, Percutaneous Approach */
"0K5B4ZZ" = "1" /* Destruction of Left Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0K5C0ZZ" = "1" /* Destruction of Right Hand Muscle, Open Approach */
"0K5C3ZZ" = "1" /* Destruction of Right Hand Muscle, Percutaneous Approach */
"0K5C4ZZ" = "1" /* Destruction of Right Hand Muscle, Percutaneous Endoscopic Approach */
"0K5D0ZZ" = "1" /* Destruction of Left Hand Muscle, Open Approach */
"0K5D3ZZ" = "1" /* Destruction of Left Hand Muscle, Percutaneous Approach */
"0K5D4ZZ" = "1" /* Destruction of Left Hand Muscle, Percutaneous Endoscopic Approach */
"0K5F0ZZ" = "1" /* Destruction of Right Trunk Muscle, Open Approach */
"0K5F3ZZ" = "1" /* Destruction of Right Trunk Muscle, Percutaneous Approach */
"0K5F4ZZ" = "1" /* Destruction of Right Trunk Muscle, Percutaneous Endoscopic Approach */
"0K5G0ZZ" = "1" /* Destruction of Left Trunk Muscle, Open Approach */
"0K5G3ZZ" = "1" /* Destruction of Left Trunk Muscle, Percutaneous Approach */
"0K5G4ZZ" = "1" /* Destruction of Left Trunk Muscle, Percutaneous Endoscopic Approach */
"0K5H0ZZ" = "1" /* Destruction of Right Thorax Muscle, Open Approach */
"0K5H3ZZ" = "1" /* Destruction of Right Thorax Muscle, Percutaneous Approach */
"0K5H4ZZ" = "1" /* Destruction of Right Thorax Muscle, Percutaneous Endoscopic Approach */
"0K5J0ZZ" = "1" /* Destruction of Left Thorax Muscle, Open Approach */
"0K5J3ZZ" = "1" /* Destruction of Left Thorax Muscle, Percutaneous Approach */
"0K5J4ZZ" = "1" /* Destruction of Left Thorax Muscle, Percutaneous Endoscopic Approach */
"0K5K0ZZ" = "1" /* Destruction of Right Abdomen Muscle, Open Approach */
"0K5K3ZZ" = "1" /* Destruction of Right Abdomen Muscle, Percutaneous Approach */
"0K5K4ZZ" = "1" /* Destruction of Right Abdomen Muscle, Percutaneous Endoscopic Approach */
"0K5L0ZZ" = "1" /* Destruction of Left Abdomen Muscle, Open Approach */
"0K5L3ZZ" = "1" /* Destruction of Left Abdomen Muscle, Percutaneous Approach */
"0K5L4ZZ" = "1" /* Destruction of Left Abdomen Muscle, Percutaneous Endoscopic Approach */
"0K5M0ZZ" = "1" /* Destruction of Perineum Muscle, Open Approach */
"0K5M3ZZ" = "1" /* Destruction of Perineum Muscle, Percutaneous Approach */
"0K5M4ZZ" = "1" /* Destruction of Perineum Muscle, Percutaneous Endoscopic Approach */
"0K5N0ZZ" = "1" /* Destruction of Right Hip Muscle, Open Approach */
"0K5N3ZZ" = "1" /* Destruction of Right Hip Muscle, Percutaneous Approach */
"0K5N4ZZ" = "1" /* Destruction of Right Hip Muscle, Percutaneous Endoscopic Approach */
"0K5P0ZZ" = "1" /* Destruction of Left Hip Muscle, Open Approach */
"0K5P3ZZ" = "1" /* Destruction of Left Hip Muscle, Percutaneous Approach */
"0K5P4ZZ" = "1" /* Destruction of Left Hip Muscle, Percutaneous Endoscopic Approach */
"0K5Q0ZZ" = "1" /* Destruction of Right Upper Leg Muscle, Open Approach */
"0K5Q3ZZ" = "1" /* Destruction of Right Upper Leg Muscle, Percutaneous Approach */
"0K5Q4ZZ" = "1" /* Destruction of Right Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0K5R0ZZ" = "1" /* Destruction of Left Upper Leg Muscle, Open Approach */
"0K5R3ZZ" = "1" /* Destruction of Left Upper Leg Muscle, Percutaneous Approach */
"0K5R4ZZ" = "1" /* Destruction of Left Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0K5S0ZZ" = "1" /* Destruction of Right Lower Leg Muscle, Open Approach */
"0K5S3ZZ" = "1" /* Destruction of Right Lower Leg Muscle, Percutaneous Approach */
"0K5S4ZZ" = "1" /* Destruction of Right Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0K5T0ZZ" = "1" /* Destruction of Left Lower Leg Muscle, Open Approach */
"0K5T3ZZ" = "1" /* Destruction of Left Lower Leg Muscle, Percutaneous Approach */
"0K5T4ZZ" = "1" /* Destruction of Left Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0K5V0ZZ" = "1" /* Destruction of Right Foot Muscle, Open Approach */
"0K5V3ZZ" = "1" /* Destruction of Right Foot Muscle, Percutaneous Approach */
"0K5V4ZZ" = "1" /* Destruction of Right Foot Muscle, Percutaneous Endoscopic Approach */
"0K5W0ZZ" = "1" /* Destruction of Left Foot Muscle, Open Approach */
"0K5W3ZZ" = "1" /* Destruction of Left Foot Muscle, Percutaneous Approach */
"0K5W4ZZ" = "1" /* Destruction of Left Foot Muscle, Percutaneous Endoscopic Approach */
"0K800ZZ" = "1" /* Division of Head Muscle, Open Approach */
"0K803ZZ" = "1" /* Division of Head Muscle, Percutaneous Approach */
"0K804ZZ" = "1" /* Division of Head Muscle, Percutaneous Endoscopic Approach */
"0K810ZZ" = "1" /* Division of Facial Muscle, Open Approach */
"0K813ZZ" = "1" /* Division of Facial Muscle, Percutaneous Approach */
"0K814ZZ" = "1" /* Division of Facial Muscle, Percutaneous Endoscopic Approach */
"0K820ZZ" = "1" /* Division of Right Neck Muscle, Open Approach */
"0K823ZZ" = "1" /* Division of Right Neck Muscle, Percutaneous Approach */
"0K824ZZ" = "1" /* Division of Right Neck Muscle, Percutaneous Endoscopic Approach */
"0K830ZZ" = "1" /* Division of Left Neck Muscle, Open Approach */
"0K833ZZ" = "1" /* Division of Left Neck Muscle, Percutaneous Approach */
"0K834ZZ" = "1" /* Division of Left Neck Muscle, Percutaneous Endoscopic Approach */
"0K840ZZ" = "1" /* Division of Tongue, Palate, Pharynx Muscle, Open Approach */
"0K843ZZ" = "1" /* Division of Tongue, Palate, Pharynx Muscle, Percutaneous Approach */
"0K844ZZ" = "1" /* Division of Tongue, Palate, Pharynx Muscle, Percutaneous Endoscopic Approach */
"0K850ZZ" = "1" /* Division of Right Shoulder Muscle, Open Approach */
"0K853ZZ" = "1" /* Division of Right Shoulder Muscle, Percutaneous Approach */
"0K854ZZ" = "1" /* Division of Right Shoulder Muscle, Percutaneous Endoscopic Approach */
"0K860ZZ" = "1" /* Division of Left Shoulder Muscle, Open Approach */
"0K863ZZ" = "1" /* Division of Left Shoulder Muscle, Percutaneous Approach */
"0K864ZZ" = "1" /* Division of Left Shoulder Muscle, Percutaneous Endoscopic Approach */
"0K870ZZ" = "1" /* Division of Right Upper Arm Muscle, Open Approach */
"0K873ZZ" = "1" /* Division of Right Upper Arm Muscle, Percutaneous Approach */
"0K874ZZ" = "1" /* Division of Right Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0K880ZZ" = "1" /* Division of Left Upper Arm Muscle, Open Approach */
"0K883ZZ" = "1" /* Division of Left Upper Arm Muscle, Percutaneous Approach */
"0K884ZZ" = "1" /* Division of Left Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0K890ZZ" = "1" /* Division of Right Lower Arm and Wrist Muscle, Open Approach */
"0K893ZZ" = "1" /* Division of Right Lower Arm and Wrist Muscle, Percutaneous Approach */
"0K894ZZ" = "1" /* Division of Right Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0K8B0ZZ" = "1" /* Division of Left Lower Arm and Wrist Muscle, Open Approach */
"0K8B3ZZ" = "1" /* Division of Left Lower Arm and Wrist Muscle, Percutaneous Approach */
"0K8B4ZZ" = "1" /* Division of Left Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0K8C0ZZ" = "1" /* Division of Right Hand Muscle, Open Approach */
"0K8C3ZZ" = "1" /* Division of Right Hand Muscle, Percutaneous Approach */
"0K8C4ZZ" = "1" /* Division of Right Hand Muscle, Percutaneous Endoscopic Approach */
"0K8D0ZZ" = "1" /* Division of Left Hand Muscle, Open Approach */
"0K8D3ZZ" = "1" /* Division of Left Hand Muscle, Percutaneous Approach */
"0K8D4ZZ" = "1" /* Division of Left Hand Muscle, Percutaneous Endoscopic Approach */
"0K8F0ZZ" = "1" /* Division of Right Trunk Muscle, Open Approach */
"0K8F3ZZ" = "1" /* Division of Right Trunk Muscle, Percutaneous Approach */
"0K8F4ZZ" = "1" /* Division of Right Trunk Muscle, Percutaneous Endoscopic Approach */
"0K8G0ZZ" = "1" /* Division of Left Trunk Muscle, Open Approach */
"0K8G3ZZ" = "1" /* Division of Left Trunk Muscle, Percutaneous Approach */
"0K8G4ZZ" = "1" /* Division of Left Trunk Muscle, Percutaneous Endoscopic Approach */
"0K8H0ZZ" = "1" /* Division of Right Thorax Muscle, Open Approach */
"0K8H3ZZ" = "1" /* Division of Right Thorax Muscle, Percutaneous Approach */
"0K8H4ZZ" = "1" /* Division of Right Thorax Muscle, Percutaneous Endoscopic Approach */
"0K8J0ZZ" = "1" /* Division of Left Thorax Muscle, Open Approach */
"0K8J3ZZ" = "1" /* Division of Left Thorax Muscle, Percutaneous Approach */
"0K8J4ZZ" = "1" /* Division of Left Thorax Muscle, Percutaneous Endoscopic Approach */
"0K8K0ZZ" = "1" /* Division of Right Abdomen Muscle, Open Approach */
"0K8K3ZZ" = "1" /* Division of Right Abdomen Muscle, Percutaneous Approach */
"0K8K4ZZ" = "1" /* Division of Right Abdomen Muscle, Percutaneous Endoscopic Approach */
"0K8L0ZZ" = "1" /* Division of Left Abdomen Muscle, Open Approach */
"0K8L3ZZ" = "1" /* Division of Left Abdomen Muscle, Percutaneous Approach */
"0K8L4ZZ" = "1" /* Division of Left Abdomen Muscle, Percutaneous Endoscopic Approach */
"0K8M0ZZ" = "1" /* Division of Perineum Muscle, Open Approach */
"0K8M3ZZ" = "1" /* Division of Perineum Muscle, Percutaneous Approach */
"0K8M4ZZ" = "1" /* Division of Perineum Muscle, Percutaneous Endoscopic Approach */
"0K8N0ZZ" = "1" /* Division of Right Hip Muscle, Open Approach */
"0K8N3ZZ" = "1" /* Division of Right Hip Muscle, Percutaneous Approach */
"0K8N4ZZ" = "1" /* Division of Right Hip Muscle, Percutaneous Endoscopic Approach */
"0K8P0ZZ" = "1" /* Division of Left Hip Muscle, Open Approach */
"0K8P3ZZ" = "1" /* Division of Left Hip Muscle, Percutaneous Approach */
"0K8P4ZZ" = "1" /* Division of Left Hip Muscle, Percutaneous Endoscopic Approach */
"0K8Q0ZZ" = "1" /* Division of Right Upper Leg Muscle, Open Approach */
"0K8Q3ZZ" = "1" /* Division of Right Upper Leg Muscle, Percutaneous Approach */
"0K8Q4ZZ" = "1" /* Division of Right Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0K8R0ZZ" = "1" /* Division of Left Upper Leg Muscle, Open Approach */
"0K8R3ZZ" = "1" /* Division of Left Upper Leg Muscle, Percutaneous Approach */
"0K8R4ZZ" = "1" /* Division of Left Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0K8S0ZZ" = "1" /* Division of Right Lower Leg Muscle, Open Approach */
"0K8S3ZZ" = "1" /* Division of Right Lower Leg Muscle, Percutaneous Approach */
"0K8S4ZZ" = "1" /* Division of Right Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0K8T0ZZ" = "1" /* Division of Left Lower Leg Muscle, Open Approach */
"0K8T3ZZ" = "1" /* Division of Left Lower Leg Muscle, Percutaneous Approach */
"0K8T4ZZ" = "1" /* Division of Left Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0K8V0ZZ" = "1" /* Division of Right Foot Muscle, Open Approach */
"0K8V3ZZ" = "1" /* Division of Right Foot Muscle, Percutaneous Approach */
"0K8V4ZZ" = "1" /* Division of Right Foot Muscle, Percutaneous Endoscopic Approach */
"0K8W0ZZ" = "1" /* Division of Left Foot Muscle, Open Approach */
"0K8W3ZZ" = "1" /* Division of Left Foot Muscle, Percutaneous Approach */
"0K8W4ZZ" = "1" /* Division of Left Foot Muscle, Percutaneous Endoscopic Approach */
"0K9000Z" = "1" /* Drainage of Head Muscle with Drainage Device, Open Approach */
"0K900ZX" = "1" /* Drainage of Head Muscle, Open Approach, Diagnostic */
"0K900ZZ" = "1" /* Drainage of Head Muscle, Open Approach */
"0K9040Z" = "1" /* Drainage of Head Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K904ZX" = "1" /* Drainage of Head Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K904ZZ" = "1" /* Drainage of Head Muscle, Percutaneous Endoscopic Approach */
"0K9100Z" = "1" /* Drainage of Facial Muscle with Drainage Device, Open Approach */
"0K910ZX" = "1" /* Drainage of Facial Muscle, Open Approach, Diagnostic */
"0K910ZZ" = "1" /* Drainage of Facial Muscle, Open Approach */
"0K9140Z" = "1" /* Drainage of Facial Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K914ZX" = "1" /* Drainage of Facial Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K914ZZ" = "1" /* Drainage of Facial Muscle, Percutaneous Endoscopic Approach */
"0K9200Z" = "1" /* Drainage of Right Neck Muscle with Drainage Device, Open Approach */
"0K920ZX" = "1" /* Drainage of Right Neck Muscle, Open Approach, Diagnostic */
"0K920ZZ" = "1" /* Drainage of Right Neck Muscle, Open Approach */
"0K9240Z" = "1" /* Drainage of Right Neck Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K924ZX" = "1" /* Drainage of Right Neck Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K924ZZ" = "1" /* Drainage of Right Neck Muscle, Percutaneous Endoscopic Approach */
"0K9300Z" = "1" /* Drainage of Left Neck Muscle with Drainage Device, Open Approach */
"0K930ZX" = "1" /* Drainage of Left Neck Muscle, Open Approach, Diagnostic */
"0K930ZZ" = "1" /* Drainage of Left Neck Muscle, Open Approach */
"0K9340Z" = "1" /* Drainage of Left Neck Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K934ZX" = "1" /* Drainage of Left Neck Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K934ZZ" = "1" /* Drainage of Left Neck Muscle, Percutaneous Endoscopic Approach */
"0K9400Z" = "1" /* Drainage of Tongue, Palate, Pharynx Muscle with Drainage Device, Open Approach */
"0K940ZX" = "1" /* Drainage of Tongue, Palate, Pharynx Muscle, Open Approach, Diagnostic */
"0K940ZZ" = "1" /* Drainage of Tongue, Palate, Pharynx Muscle, Open Approach */
"0K9440Z" = "1" /* Drainage of Tongue, Palate, Pharynx Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K944ZX" = "1" /* Drainage of Tongue, Palate, Pharynx Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K944ZZ" = "1" /* Drainage of Tongue, Palate, Pharynx Muscle, Percutaneous Endoscopic Approach */
"0K9500Z" = "1" /* Drainage of Right Shoulder Muscle with Drainage Device, Open Approach */
"0K950ZX" = "1" /* Drainage of Right Shoulder Muscle, Open Approach, Diagnostic */
"0K950ZZ" = "1" /* Drainage of Right Shoulder Muscle, Open Approach */
"0K9540Z" = "1" /* Drainage of Right Shoulder Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K954ZX" = "1" /* Drainage of Right Shoulder Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K954ZZ" = "1" /* Drainage of Right Shoulder Muscle, Percutaneous Endoscopic Approach */
"0K9600Z" = "1" /* Drainage of Left Shoulder Muscle with Drainage Device, Open Approach */
"0K960ZX" = "1" /* Drainage of Left Shoulder Muscle, Open Approach, Diagnostic */
"0K960ZZ" = "1" /* Drainage of Left Shoulder Muscle, Open Approach */
"0K9640Z" = "1" /* Drainage of Left Shoulder Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K964ZX" = "1" /* Drainage of Left Shoulder Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K964ZZ" = "1" /* Drainage of Left Shoulder Muscle, Percutaneous Endoscopic Approach */
"0K9700Z" = "1" /* Drainage of Right Upper Arm Muscle with Drainage Device, Open Approach */
"0K970ZX" = "1" /* Drainage of Right Upper Arm Muscle, Open Approach, Diagnostic */
"0K970ZZ" = "1" /* Drainage of Right Upper Arm Muscle, Open Approach */
"0K9740Z" = "1" /* Drainage of Right Upper Arm Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K974ZX" = "1" /* Drainage of Right Upper Arm Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K974ZZ" = "1" /* Drainage of Right Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0K9800Z" = "1" /* Drainage of Left Upper Arm Muscle with Drainage Device, Open Approach */
"0K980ZX" = "1" /* Drainage of Left Upper Arm Muscle, Open Approach, Diagnostic */
"0K980ZZ" = "1" /* Drainage of Left Upper Arm Muscle, Open Approach */
"0K9840Z" = "1" /* Drainage of Left Upper Arm Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K984ZX" = "1" /* Drainage of Left Upper Arm Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K984ZZ" = "1" /* Drainage of Left Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0K9900Z" = "1" /* Drainage of Right Lower Arm and Wrist Muscle with Drainage Device, Open Approach */
"0K990ZX" = "1" /* Drainage of Right Lower Arm and Wrist Muscle, Open Approach, Diagnostic */
"0K990ZZ" = "1" /* Drainage of Right Lower Arm and Wrist Muscle, Open Approach */
"0K9940Z" = "1" /* Drainage of Right Lower Arm and Wrist Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K994ZX" = "1" /* Drainage of Right Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K994ZZ" = "1" /* Drainage of Right Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0K9B00Z" = "1" /* Drainage of Left Lower Arm and Wrist Muscle with Drainage Device, Open Approach */
"0K9B0ZX" = "1" /* Drainage of Left Lower Arm and Wrist Muscle, Open Approach, Diagnostic */
"0K9B0ZZ" = "1" /* Drainage of Left Lower Arm and Wrist Muscle, Open Approach */
"0K9B40Z" = "1" /* Drainage of Left Lower Arm and Wrist Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9B4ZX" = "1" /* Drainage of Left Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K9B4ZZ" = "1" /* Drainage of Left Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0K9C00Z" = "1" /* Drainage of Right Hand Muscle with Drainage Device, Open Approach */
"0K9C0ZX" = "1" /* Drainage of Right Hand Muscle, Open Approach, Diagnostic */
"0K9C0ZZ" = "1" /* Drainage of Right Hand Muscle, Open Approach */
"0K9C40Z" = "1" /* Drainage of Right Hand Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9C4ZX" = "1" /* Drainage of Right Hand Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K9D00Z" = "1" /* Drainage of Left Hand Muscle with Drainage Device, Open Approach */
"0K9D0ZX" = "1" /* Drainage of Left Hand Muscle, Open Approach, Diagnostic */
"0K9D0ZZ" = "1" /* Drainage of Left Hand Muscle, Open Approach */
"0K9D40Z" = "1" /* Drainage of Left Hand Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9D4ZX" = "1" /* Drainage of Left Hand Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K9F00Z" = "1" /* Drainage of Right Trunk Muscle with Drainage Device, Open Approach */
"0K9F0ZX" = "1" /* Drainage of Right Trunk Muscle, Open Approach, Diagnostic */
"0K9F0ZZ" = "1" /* Drainage of Right Trunk Muscle, Open Approach */
"0K9F40Z" = "1" /* Drainage of Right Trunk Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9F4ZX" = "1" /* Drainage of Right Trunk Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K9F4ZZ" = "1" /* Drainage of Right Trunk Muscle, Percutaneous Endoscopic Approach */
"0K9G00Z" = "1" /* Drainage of Left Trunk Muscle with Drainage Device, Open Approach */
"0K9G0ZX" = "1" /* Drainage of Left Trunk Muscle, Open Approach, Diagnostic */
"0K9G0ZZ" = "1" /* Drainage of Left Trunk Muscle, Open Approach */
"0K9G40Z" = "1" /* Drainage of Left Trunk Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9G4ZX" = "1" /* Drainage of Left Trunk Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K9G4ZZ" = "1" /* Drainage of Left Trunk Muscle, Percutaneous Endoscopic Approach */
"0K9H00Z" = "1" /* Drainage of Right Thorax Muscle with Drainage Device, Open Approach */
"0K9H0ZX" = "1" /* Drainage of Right Thorax Muscle, Open Approach, Diagnostic */
"0K9H0ZZ" = "1" /* Drainage of Right Thorax Muscle, Open Approach */
"0K9H40Z" = "1" /* Drainage of Right Thorax Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9H4ZX" = "1" /* Drainage of Right Thorax Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K9H4ZZ" = "1" /* Drainage of Right Thorax Muscle, Percutaneous Endoscopic Approach */
"0K9J00Z" = "1" /* Drainage of Left Thorax Muscle with Drainage Device, Open Approach */
"0K9J0ZX" = "1" /* Drainage of Left Thorax Muscle, Open Approach, Diagnostic */
"0K9J0ZZ" = "1" /* Drainage of Left Thorax Muscle, Open Approach */
"0K9J40Z" = "1" /* Drainage of Left Thorax Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9J4ZX" = "1" /* Drainage of Left Thorax Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K9J4ZZ" = "1" /* Drainage of Left Thorax Muscle, Percutaneous Endoscopic Approach */
"0K9K00Z" = "1" /* Drainage of Right Abdomen Muscle with Drainage Device, Open Approach */
"0K9K0ZX" = "1" /* Drainage of Right Abdomen Muscle, Open Approach, Diagnostic */
"0K9K0ZZ" = "1" /* Drainage of Right Abdomen Muscle, Open Approach */
"0K9K40Z" = "1" /* Drainage of Right Abdomen Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9K4ZX" = "1" /* Drainage of Right Abdomen Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K9K4ZZ" = "1" /* Drainage of Right Abdomen Muscle, Percutaneous Endoscopic Approach */
"0K9L00Z" = "1" /* Drainage of Left Abdomen Muscle with Drainage Device, Open Approach */
"0K9L0ZX" = "1" /* Drainage of Left Abdomen Muscle, Open Approach, Diagnostic */
"0K9L0ZZ" = "1" /* Drainage of Left Abdomen Muscle, Open Approach */
"0K9L40Z" = "1" /* Drainage of Left Abdomen Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9L4ZX" = "1" /* Drainage of Left Abdomen Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K9L4ZZ" = "1" /* Drainage of Left Abdomen Muscle, Percutaneous Endoscopic Approach */
"0K9M00Z" = "1" /* Drainage of Perineum Muscle with Drainage Device, Open Approach */
"0K9M0ZX" = "1" /* Drainage of Perineum Muscle, Open Approach, Diagnostic */
"0K9M0ZZ" = "1" /* Drainage of Perineum Muscle, Open Approach */
"0K9M40Z" = "1" /* Drainage of Perineum Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9M4ZX" = "1" /* Drainage of Perineum Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K9M4ZZ" = "1" /* Drainage of Perineum Muscle, Percutaneous Endoscopic Approach */
"0K9N00Z" = "1" /* Drainage of Right Hip Muscle with Drainage Device, Open Approach */
"0K9N0ZX" = "1" /* Drainage of Right Hip Muscle, Open Approach, Diagnostic */
"0K9N0ZZ" = "1" /* Drainage of Right Hip Muscle, Open Approach */
"0K9N40Z" = "1" /* Drainage of Right Hip Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9N4ZX" = "1" /* Drainage of Right Hip Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K9N4ZZ" = "1" /* Drainage of Right Hip Muscle, Percutaneous Endoscopic Approach */
"0K9P00Z" = "1" /* Drainage of Left Hip Muscle with Drainage Device, Open Approach */
"0K9P0ZX" = "1" /* Drainage of Left Hip Muscle, Open Approach, Diagnostic */
"0K9P0ZZ" = "1" /* Drainage of Left Hip Muscle, Open Approach */
"0K9P40Z" = "1" /* Drainage of Left Hip Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9P4ZX" = "1" /* Drainage of Left Hip Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K9P4ZZ" = "1" /* Drainage of Left Hip Muscle, Percutaneous Endoscopic Approach */
"0K9Q00Z" = "1" /* Drainage of Right Upper Leg Muscle with Drainage Device, Open Approach */
"0K9Q0ZX" = "1" /* Drainage of Right Upper Leg Muscle, Open Approach, Diagnostic */
"0K9Q0ZZ" = "1" /* Drainage of Right Upper Leg Muscle, Open Approach */
"0K9Q40Z" = "1" /* Drainage of Right Upper Leg Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9Q4ZX" = "1" /* Drainage of Right Upper Leg Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K9Q4ZZ" = "1" /* Drainage of Right Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0K9R00Z" = "1" /* Drainage of Left Upper Leg Muscle with Drainage Device, Open Approach */
"0K9R0ZX" = "1" /* Drainage of Left Upper Leg Muscle, Open Approach, Diagnostic */
"0K9R0ZZ" = "1" /* Drainage of Left Upper Leg Muscle, Open Approach */
"0K9R40Z" = "1" /* Drainage of Left Upper Leg Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9R4ZX" = "1" /* Drainage of Left Upper Leg Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K9R4ZZ" = "1" /* Drainage of Left Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0K9S00Z" = "1" /* Drainage of Right Lower Leg Muscle with Drainage Device, Open Approach */
"0K9S0ZX" = "1" /* Drainage of Right Lower Leg Muscle, Open Approach, Diagnostic */
"0K9S0ZZ" = "1" /* Drainage of Right Lower Leg Muscle, Open Approach */
"0K9S40Z" = "1" /* Drainage of Right Lower Leg Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9S4ZX" = "1" /* Drainage of Right Lower Leg Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K9S4ZZ" = "1" /* Drainage of Right Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0K9T00Z" = "1" /* Drainage of Left Lower Leg Muscle with Drainage Device, Open Approach */
"0K9T0ZX" = "1" /* Drainage of Left Lower Leg Muscle, Open Approach, Diagnostic */
"0K9T0ZZ" = "1" /* Drainage of Left Lower Leg Muscle, Open Approach */
"0K9T40Z" = "1" /* Drainage of Left Lower Leg Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9T4ZX" = "1" /* Drainage of Left Lower Leg Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K9T4ZZ" = "1" /* Drainage of Left Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0K9V00Z" = "1" /* Drainage of Right Foot Muscle with Drainage Device, Open Approach */
"0K9V0ZX" = "1" /* Drainage of Right Foot Muscle, Open Approach, Diagnostic */
"0K9V0ZZ" = "1" /* Drainage of Right Foot Muscle, Open Approach */
"0K9V40Z" = "1" /* Drainage of Right Foot Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9V4ZX" = "1" /* Drainage of Right Foot Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K9V4ZZ" = "1" /* Drainage of Right Foot Muscle, Percutaneous Endoscopic Approach */
"0K9W00Z" = "1" /* Drainage of Left Foot Muscle with Drainage Device, Open Approach */
"0K9W0ZX" = "1" /* Drainage of Left Foot Muscle, Open Approach, Diagnostic */
"0K9W0ZZ" = "1" /* Drainage of Left Foot Muscle, Open Approach */
"0K9W40Z" = "1" /* Drainage of Left Foot Muscle with Drainage Device, Percutaneous Endoscopic Approach */
"0K9W4ZX" = "1" /* Drainage of Left Foot Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0K9W4ZZ" = "1" /* Drainage of Left Foot Muscle, Percutaneous Endoscopic Approach */
"0KB00ZX" = "1" /* Excision of Head Muscle, Open Approach, Diagnostic */
"0KB00ZZ" = "1" /* Excision of Head Muscle, Open Approach */
"0KB03ZX" = "1" /* Excision of Head Muscle, Percutaneous Approach, Diagnostic */
"0KB03ZZ" = "1" /* Excision of Head Muscle, Percutaneous Approach */
"0KB04ZX" = "1" /* Excision of Head Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KB04ZZ" = "1" /* Excision of Head Muscle, Percutaneous Endoscopic Approach */
"0KB10ZX" = "1" /* Excision of Facial Muscle, Open Approach, Diagnostic */
"0KB10ZZ" = "1" /* Excision of Facial Muscle, Open Approach */
"0KB13ZX" = "1" /* Excision of Facial Muscle, Percutaneous Approach, Diagnostic */
"0KB13ZZ" = "1" /* Excision of Facial Muscle, Percutaneous Approach */
"0KB14ZX" = "1" /* Excision of Facial Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KB14ZZ" = "1" /* Excision of Facial Muscle, Percutaneous Endoscopic Approach */
"0KB20ZX" = "1" /* Excision of Right Neck Muscle, Open Approach, Diagnostic */
"0KB20ZZ" = "1" /* Excision of Right Neck Muscle, Open Approach */
"0KB23ZX" = "1" /* Excision of Right Neck Muscle, Percutaneous Approach, Diagnostic */
"0KB23ZZ" = "1" /* Excision of Right Neck Muscle, Percutaneous Approach */
"0KB24ZX" = "1" /* Excision of Right Neck Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KB24ZZ" = "1" /* Excision of Right Neck Muscle, Percutaneous Endoscopic Approach */
"0KB30ZX" = "1" /* Excision of Left Neck Muscle, Open Approach, Diagnostic */
"0KB30ZZ" = "1" /* Excision of Left Neck Muscle, Open Approach */
"0KB33ZX" = "1" /* Excision of Left Neck Muscle, Percutaneous Approach, Diagnostic */
"0KB33ZZ" = "1" /* Excision of Left Neck Muscle, Percutaneous Approach */
"0KB34ZX" = "1" /* Excision of Left Neck Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KB34ZZ" = "1" /* Excision of Left Neck Muscle, Percutaneous Endoscopic Approach */
"0KB40ZX" = "1" /* Excision of Tongue, Palate, Pharynx Muscle, Open Approach, Diagnostic */
"0KB40ZZ" = "1" /* Excision of Tongue, Palate, Pharynx Muscle, Open Approach */
"0KB43ZX" = "1" /* Excision of Tongue, Palate, Pharynx Muscle, Percutaneous Approach, Diagnostic */
"0KB43ZZ" = "1" /* Excision of Tongue, Palate, Pharynx Muscle, Percutaneous Approach */
"0KB44ZX" = "1" /* Excision of Tongue, Palate, Pharynx Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KB44ZZ" = "1" /* Excision of Tongue, Palate, Pharynx Muscle, Percutaneous Endoscopic Approach */
"0KB50ZX" = "1" /* Excision of Right Shoulder Muscle, Open Approach, Diagnostic */
"0KB50ZZ" = "1" /* Excision of Right Shoulder Muscle, Open Approach */
"0KB53ZX" = "1" /* Excision of Right Shoulder Muscle, Percutaneous Approach, Diagnostic */
"0KB53ZZ" = "1" /* Excision of Right Shoulder Muscle, Percutaneous Approach */
"0KB54ZX" = "1" /* Excision of Right Shoulder Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KB54ZZ" = "1" /* Excision of Right Shoulder Muscle, Percutaneous Endoscopic Approach */
"0KB60ZX" = "1" /* Excision of Left Shoulder Muscle, Open Approach, Diagnostic */
"0KB60ZZ" = "1" /* Excision of Left Shoulder Muscle, Open Approach */
"0KB63ZX" = "1" /* Excision of Left Shoulder Muscle, Percutaneous Approach, Diagnostic */
"0KB63ZZ" = "1" /* Excision of Left Shoulder Muscle, Percutaneous Approach */
"0KB64ZX" = "1" /* Excision of Left Shoulder Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KB64ZZ" = "1" /* Excision of Left Shoulder Muscle, Percutaneous Endoscopic Approach */
"0KB70ZX" = "1" /* Excision of Right Upper Arm Muscle, Open Approach, Diagnostic */
"0KB70ZZ" = "1" /* Excision of Right Upper Arm Muscle, Open Approach */
"0KB73ZX" = "1" /* Excision of Right Upper Arm Muscle, Percutaneous Approach, Diagnostic */
"0KB73ZZ" = "1" /* Excision of Right Upper Arm Muscle, Percutaneous Approach */
"0KB74ZX" = "1" /* Excision of Right Upper Arm Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KB74ZZ" = "1" /* Excision of Right Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0KB80ZX" = "1" /* Excision of Left Upper Arm Muscle, Open Approach, Diagnostic */
"0KB80ZZ" = "1" /* Excision of Left Upper Arm Muscle, Open Approach */
"0KB83ZX" = "1" /* Excision of Left Upper Arm Muscle, Percutaneous Approach, Diagnostic */
"0KB83ZZ" = "1" /* Excision of Left Upper Arm Muscle, Percutaneous Approach */
"0KB84ZX" = "1" /* Excision of Left Upper Arm Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KB84ZZ" = "1" /* Excision of Left Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0KB90ZX" = "1" /* Excision of Right Lower Arm and Wrist Muscle, Open Approach, Diagnostic */
"0KB90ZZ" = "1" /* Excision of Right Lower Arm and Wrist Muscle, Open Approach */
"0KB93ZX" = "1" /* Excision of Right Lower Arm and Wrist Muscle, Percutaneous Approach, Diagnostic */
"0KB93ZZ" = "1" /* Excision of Right Lower Arm and Wrist Muscle, Percutaneous Approach */
"0KB94ZX" = "1" /* Excision of Right Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KB94ZZ" = "1" /* Excision of Right Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0KBB0ZX" = "1" /* Excision of Left Lower Arm and Wrist Muscle, Open Approach, Diagnostic */
"0KBB0ZZ" = "1" /* Excision of Left Lower Arm and Wrist Muscle, Open Approach */
"0KBB3ZX" = "1" /* Excision of Left Lower Arm and Wrist Muscle, Percutaneous Approach, Diagnostic */
"0KBB3ZZ" = "1" /* Excision of Left Lower Arm and Wrist Muscle, Percutaneous Approach */
"0KBB4ZX" = "1" /* Excision of Left Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KBB4ZZ" = "1" /* Excision of Left Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0KBC0ZX" = "1" /* Excision of Right Hand Muscle, Open Approach, Diagnostic */
"0KBC0ZZ" = "1" /* Excision of Right Hand Muscle, Open Approach */
"0KBC3ZX" = "1" /* Excision of Right Hand Muscle, Percutaneous Approach, Diagnostic */
"0KBC3ZZ" = "1" /* Excision of Right Hand Muscle, Percutaneous Approach */
"0KBC4ZX" = "1" /* Excision of Right Hand Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KBC4ZZ" = "1" /* Excision of Right Hand Muscle, Percutaneous Endoscopic Approach */
"0KBD0ZX" = "1" /* Excision of Left Hand Muscle, Open Approach, Diagnostic */
"0KBD0ZZ" = "1" /* Excision of Left Hand Muscle, Open Approach */
"0KBD3ZX" = "1" /* Excision of Left Hand Muscle, Percutaneous Approach, Diagnostic */
"0KBD3ZZ" = "1" /* Excision of Left Hand Muscle, Percutaneous Approach */
"0KBD4ZX" = "1" /* Excision of Left Hand Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KBD4ZZ" = "1" /* Excision of Left Hand Muscle, Percutaneous Endoscopic Approach */
"0KBF0ZX" = "1" /* Excision of Right Trunk Muscle, Open Approach, Diagnostic */
"0KBF0ZZ" = "1" /* Excision of Right Trunk Muscle, Open Approach */
"0KBF3ZX" = "1" /* Excision of Right Trunk Muscle, Percutaneous Approach, Diagnostic */
"0KBF3ZZ" = "1" /* Excision of Right Trunk Muscle, Percutaneous Approach */
"0KBF4ZX" = "1" /* Excision of Right Trunk Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KBF4ZZ" = "1" /* Excision of Right Trunk Muscle, Percutaneous Endoscopic Approach */
"0KBG0ZX" = "1" /* Excision of Left Trunk Muscle, Open Approach, Diagnostic */
"0KBG0ZZ" = "1" /* Excision of Left Trunk Muscle, Open Approach */
"0KBG3ZX" = "1" /* Excision of Left Trunk Muscle, Percutaneous Approach, Diagnostic */
"0KBG3ZZ" = "1" /* Excision of Left Trunk Muscle, Percutaneous Approach */
"0KBG4ZX" = "1" /* Excision of Left Trunk Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KBG4ZZ" = "1" /* Excision of Left Trunk Muscle, Percutaneous Endoscopic Approach */
"0KBH0ZX" = "1" /* Excision of Right Thorax Muscle, Open Approach, Diagnostic */
"0KBH0ZZ" = "1" /* Excision of Right Thorax Muscle, Open Approach */
"0KBH3ZX" = "1" /* Excision of Right Thorax Muscle, Percutaneous Approach, Diagnostic */
"0KBH3ZZ" = "1" /* Excision of Right Thorax Muscle, Percutaneous Approach */
"0KBH4ZX" = "1" /* Excision of Right Thorax Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KBH4ZZ" = "1" /* Excision of Right Thorax Muscle, Percutaneous Endoscopic Approach */
"0KBJ0ZX" = "1" /* Excision of Left Thorax Muscle, Open Approach, Diagnostic */
"0KBJ0ZZ" = "1" /* Excision of Left Thorax Muscle, Open Approach */
"0KBJ3ZX" = "1" /* Excision of Left Thorax Muscle, Percutaneous Approach, Diagnostic */
"0KBJ3ZZ" = "1" /* Excision of Left Thorax Muscle, Percutaneous Approach */
"0KBJ4ZX" = "1" /* Excision of Left Thorax Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KBJ4ZZ" = "1" /* Excision of Left Thorax Muscle, Percutaneous Endoscopic Approach */
"0KBK0ZX" = "1" /* Excision of Right Abdomen Muscle, Open Approach, Diagnostic */
"0KBK0ZZ" = "1" /* Excision of Right Abdomen Muscle, Open Approach */
"0KBK3ZX" = "1" /* Excision of Right Abdomen Muscle, Percutaneous Approach, Diagnostic */
"0KBK3ZZ" = "1" /* Excision of Right Abdomen Muscle, Percutaneous Approach */
"0KBK4ZX" = "1" /* Excision of Right Abdomen Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KBK4ZZ" = "1" /* Excision of Right Abdomen Muscle, Percutaneous Endoscopic Approach */
"0KBL0ZX" = "1" /* Excision of Left Abdomen Muscle, Open Approach, Diagnostic */
"0KBL0ZZ" = "1" /* Excision of Left Abdomen Muscle, Open Approach */
"0KBL3ZX" = "1" /* Excision of Left Abdomen Muscle, Percutaneous Approach, Diagnostic */
"0KBL3ZZ" = "1" /* Excision of Left Abdomen Muscle, Percutaneous Approach */
"0KBL4ZX" = "1" /* Excision of Left Abdomen Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KBL4ZZ" = "1" /* Excision of Left Abdomen Muscle, Percutaneous Endoscopic Approach */
"0KBM0ZX" = "1" /* Excision of Perineum Muscle, Open Approach, Diagnostic */
"0KBM0ZZ" = "1" /* Excision of Perineum Muscle, Open Approach */
"0KBM3ZX" = "1" /* Excision of Perineum Muscle, Percutaneous Approach, Diagnostic */
"0KBM3ZZ" = "1" /* Excision of Perineum Muscle, Percutaneous Approach */
"0KBM4ZX" = "1" /* Excision of Perineum Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KBM4ZZ" = "1" /* Excision of Perineum Muscle, Percutaneous Endoscopic Approach */
"0KBN0ZX" = "1" /* Excision of Right Hip Muscle, Open Approach, Diagnostic */
"0KBN0ZZ" = "1" /* Excision of Right Hip Muscle, Open Approach */
"0KBN3ZX" = "1" /* Excision of Right Hip Muscle, Percutaneous Approach, Diagnostic */
"0KBN3ZZ" = "1" /* Excision of Right Hip Muscle, Percutaneous Approach */
"0KBN4ZX" = "1" /* Excision of Right Hip Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KBN4ZZ" = "1" /* Excision of Right Hip Muscle, Percutaneous Endoscopic Approach */
"0KBP0ZX" = "1" /* Excision of Left Hip Muscle, Open Approach, Diagnostic */
"0KBP0ZZ" = "1" /* Excision of Left Hip Muscle, Open Approach */
"0KBP3ZX" = "1" /* Excision of Left Hip Muscle, Percutaneous Approach, Diagnostic */
"0KBP3ZZ" = "1" /* Excision of Left Hip Muscle, Percutaneous Approach */
"0KBP4ZX" = "1" /* Excision of Left Hip Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KBP4ZZ" = "1" /* Excision of Left Hip Muscle, Percutaneous Endoscopic Approach */
"0KBQ0ZX" = "1" /* Excision of Right Upper Leg Muscle, Open Approach, Diagnostic */
"0KBQ0ZZ" = "1" /* Excision of Right Upper Leg Muscle, Open Approach */
"0KBQ3ZX" = "1" /* Excision of Right Upper Leg Muscle, Percutaneous Approach, Diagnostic */
"0KBQ3ZZ" = "1" /* Excision of Right Upper Leg Muscle, Percutaneous Approach */
"0KBQ4ZX" = "1" /* Excision of Right Upper Leg Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KBQ4ZZ" = "1" /* Excision of Right Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0KBR0ZX" = "1" /* Excision of Left Upper Leg Muscle, Open Approach, Diagnostic */
"0KBR0ZZ" = "1" /* Excision of Left Upper Leg Muscle, Open Approach */
"0KBR3ZX" = "1" /* Excision of Left Upper Leg Muscle, Percutaneous Approach, Diagnostic */
"0KBR3ZZ" = "1" /* Excision of Left Upper Leg Muscle, Percutaneous Approach */
"0KBR4ZX" = "1" /* Excision of Left Upper Leg Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KBR4ZZ" = "1" /* Excision of Left Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0KBS0ZX" = "1" /* Excision of Right Lower Leg Muscle, Open Approach, Diagnostic */
"0KBS0ZZ" = "1" /* Excision of Right Lower Leg Muscle, Open Approach */
"0KBS3ZX" = "1" /* Excision of Right Lower Leg Muscle, Percutaneous Approach, Diagnostic */
"0KBS3ZZ" = "1" /* Excision of Right Lower Leg Muscle, Percutaneous Approach */
"0KBS4ZX" = "1" /* Excision of Right Lower Leg Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KBS4ZZ" = "1" /* Excision of Right Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0KBT0ZX" = "1" /* Excision of Left Lower Leg Muscle, Open Approach, Diagnostic */
"0KBT0ZZ" = "1" /* Excision of Left Lower Leg Muscle, Open Approach */
"0KBT3ZX" = "1" /* Excision of Left Lower Leg Muscle, Percutaneous Approach, Diagnostic */
"0KBT3ZZ" = "1" /* Excision of Left Lower Leg Muscle, Percutaneous Approach */
"0KBT4ZX" = "1" /* Excision of Left Lower Leg Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KBT4ZZ" = "1" /* Excision of Left Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0KBV0ZX" = "1" /* Excision of Right Foot Muscle, Open Approach, Diagnostic */
"0KBV0ZZ" = "1" /* Excision of Right Foot Muscle, Open Approach */
"0KBV3ZX" = "1" /* Excision of Right Foot Muscle, Percutaneous Approach, Diagnostic */
"0KBV3ZZ" = "1" /* Excision of Right Foot Muscle, Percutaneous Approach */
"0KBV4ZX" = "1" /* Excision of Right Foot Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KBV4ZZ" = "1" /* Excision of Right Foot Muscle, Percutaneous Endoscopic Approach */
"0KBW0ZX" = "1" /* Excision of Left Foot Muscle, Open Approach, Diagnostic */
"0KBW0ZZ" = "1" /* Excision of Left Foot Muscle, Open Approach */
"0KBW3ZX" = "1" /* Excision of Left Foot Muscle, Percutaneous Approach, Diagnostic */
"0KBW3ZZ" = "1" /* Excision of Left Foot Muscle, Percutaneous Approach */
"0KBW4ZX" = "1" /* Excision of Left Foot Muscle, Percutaneous Endoscopic Approach, Diagnostic */
"0KBW4ZZ" = "1" /* Excision of Left Foot Muscle, Percutaneous Endoscopic Approach */
"0KC00ZZ" = "1" /* Extirpation of Matter from Head Muscle, Open Approach */
"0KC03ZZ" = "1" /* Extirpation of Matter from Head Muscle, Percutaneous Approach */
"0KC04ZZ" = "1" /* Extirpation of Matter from Head Muscle, Percutaneous Endoscopic Approach */
"0KC10ZZ" = "1" /* Extirpation of Matter from Facial Muscle, Open Approach */
"0KC13ZZ" = "1" /* Extirpation of Matter from Facial Muscle, Percutaneous Approach */
"0KC14ZZ" = "1" /* Extirpation of Matter from Facial Muscle, Percutaneous Endoscopic Approach */
"0KC20ZZ" = "1" /* Extirpation of Matter from Right Neck Muscle, Open Approach */
"0KC23ZZ" = "1" /* Extirpation of Matter from Right Neck Muscle, Percutaneous Approach */
"0KC24ZZ" = "1" /* Extirpation of Matter from Right Neck Muscle, Percutaneous Endoscopic Approach */
"0KC30ZZ" = "1" /* Extirpation of Matter from Left Neck Muscle, Open Approach */
"0KC33ZZ" = "1" /* Extirpation of Matter from Left Neck Muscle, Percutaneous Approach */
"0KC34ZZ" = "1" /* Extirpation of Matter from Left Neck Muscle, Percutaneous Endoscopic Approach */
"0KC40ZZ" = "1" /* Extirpation of Matter from Tongue, Palate, Pharynx Muscle, Open Approach */
"0KC43ZZ" = "1" /* Extirpation of Matter from Tongue, Palate, Pharynx Muscle, Percutaneous Approach */
"0KC44ZZ" = "1" /* Extirpation of Matter from Tongue, Palate, Pharynx Muscle, Percutaneous Endoscopic Approach */
"0KC50ZZ" = "1" /* Extirpation of Matter from Right Shoulder Muscle, Open Approach */
"0KC53ZZ" = "1" /* Extirpation of Matter from Right Shoulder Muscle, Percutaneous Approach */
"0KC54ZZ" = "1" /* Extirpation of Matter from Right Shoulder Muscle, Percutaneous Endoscopic Approach */
"0KC60ZZ" = "1" /* Extirpation of Matter from Left Shoulder Muscle, Open Approach */
"0KC63ZZ" = "1" /* Extirpation of Matter from Left Shoulder Muscle, Percutaneous Approach */
"0KC64ZZ" = "1" /* Extirpation of Matter from Left Shoulder Muscle, Percutaneous Endoscopic Approach */
"0KC70ZZ" = "1" /* Extirpation of Matter from Right Upper Arm Muscle, Open Approach */
"0KC73ZZ" = "1" /* Extirpation of Matter from Right Upper Arm Muscle, Percutaneous Approach */
"0KC74ZZ" = "1" /* Extirpation of Matter from Right Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0KC80ZZ" = "1" /* Extirpation of Matter from Left Upper Arm Muscle, Open Approach */
"0KC83ZZ" = "1" /* Extirpation of Matter from Left Upper Arm Muscle, Percutaneous Approach */
"0KC84ZZ" = "1" /* Extirpation of Matter from Left Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0KC90ZZ" = "1" /* Extirpation of Matter from Right Lower Arm and Wrist Muscle, Open Approach */
"0KC93ZZ" = "1" /* Extirpation of Matter from Right Lower Arm and Wrist Muscle, Percutaneous Approach */
"0KC94ZZ" = "1" /* Extirpation of Matter from Right Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0KCB0ZZ" = "1" /* Extirpation of Matter from Left Lower Arm and Wrist Muscle, Open Approach */
"0KCB3ZZ" = "1" /* Extirpation of Matter from Left Lower Arm and Wrist Muscle, Percutaneous Approach */
"0KCB4ZZ" = "1" /* Extirpation of Matter from Left Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0KCC0ZZ" = "1" /* Extirpation of Matter from Right Hand Muscle, Open Approach */
"0KCC3ZZ" = "1" /* Extirpation of Matter from Right Hand Muscle, Percutaneous Approach */
"0KCC4ZZ" = "1" /* Extirpation of Matter from Right Hand Muscle, Percutaneous Endoscopic Approach */
"0KCD0ZZ" = "1" /* Extirpation of Matter from Left Hand Muscle, Open Approach */
"0KCD3ZZ" = "1" /* Extirpation of Matter from Left Hand Muscle, Percutaneous Approach */
"0KCD4ZZ" = "1" /* Extirpation of Matter from Left Hand Muscle, Percutaneous Endoscopic Approach */
"0KCF0ZZ" = "1" /* Extirpation of Matter from Right Trunk Muscle, Open Approach */
"0KCF3ZZ" = "1" /* Extirpation of Matter from Right Trunk Muscle, Percutaneous Approach */
"0KCF4ZZ" = "1" /* Extirpation of Matter from Right Trunk Muscle, Percutaneous Endoscopic Approach */
"0KCG0ZZ" = "1" /* Extirpation of Matter from Left Trunk Muscle, Open Approach */
"0KCG3ZZ" = "1" /* Extirpation of Matter from Left Trunk Muscle, Percutaneous Approach */
"0KCG4ZZ" = "1" /* Extirpation of Matter from Left Trunk Muscle, Percutaneous Endoscopic Approach */
"0KCH0ZZ" = "1" /* Extirpation of Matter from Right Thorax Muscle, Open Approach */
"0KCH3ZZ" = "1" /* Extirpation of Matter from Right Thorax Muscle, Percutaneous Approach */
"0KCH4ZZ" = "1" /* Extirpation of Matter from Right Thorax Muscle, Percutaneous Endoscopic Approach */
"0KCJ0ZZ" = "1" /* Extirpation of Matter from Left Thorax Muscle, Open Approach */
"0KCJ3ZZ" = "1" /* Extirpation of Matter from Left Thorax Muscle, Percutaneous Approach */
"0KCJ4ZZ" = "1" /* Extirpation of Matter from Left Thorax Muscle, Percutaneous Endoscopic Approach */
"0KCK0ZZ" = "1" /* Extirpation of Matter from Right Abdomen Muscle, Open Approach */
"0KCK3ZZ" = "1" /* Extirpation of Matter from Right Abdomen Muscle, Percutaneous Approach */
"0KCK4ZZ" = "1" /* Extirpation of Matter from Right Abdomen Muscle, Percutaneous Endoscopic Approach */
"0KCL0ZZ" = "1" /* Extirpation of Matter from Left Abdomen Muscle, Open Approach */
"0KCL3ZZ" = "1" /* Extirpation of Matter from Left Abdomen Muscle, Percutaneous Approach */
"0KCL4ZZ" = "1" /* Extirpation of Matter from Left Abdomen Muscle, Percutaneous Endoscopic Approach */
"0KCM0ZZ" = "1" /* Extirpation of Matter from Perineum Muscle, Open Approach */
"0KCM3ZZ" = "1" /* Extirpation of Matter from Perineum Muscle, Percutaneous Approach */
"0KCM4ZZ" = "1" /* Extirpation of Matter from Perineum Muscle, Percutaneous Endoscopic Approach */
"0KCN0ZZ" = "1" /* Extirpation of Matter from Right Hip Muscle, Open Approach */
"0KCN3ZZ" = "1" /* Extirpation of Matter from Right Hip Muscle, Percutaneous Approach */
"0KCN4ZZ" = "1" /* Extirpation of Matter from Right Hip Muscle, Percutaneous Endoscopic Approach */
"0KCP0ZZ" = "1" /* Extirpation of Matter from Left Hip Muscle, Open Approach */
"0KCP3ZZ" = "1" /* Extirpation of Matter from Left Hip Muscle, Percutaneous Approach */
"0KCP4ZZ" = "1" /* Extirpation of Matter from Left Hip Muscle, Percutaneous Endoscopic Approach */
"0KCQ0ZZ" = "1" /* Extirpation of Matter from Right Upper Leg Muscle, Open Approach */
"0KCQ3ZZ" = "1" /* Extirpation of Matter from Right Upper Leg Muscle, Percutaneous Approach */
"0KCQ4ZZ" = "1" /* Extirpation of Matter from Right Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0KCR0ZZ" = "1" /* Extirpation of Matter from Left Upper Leg Muscle, Open Approach */
"0KCR3ZZ" = "1" /* Extirpation of Matter from Left Upper Leg Muscle, Percutaneous Approach */
"0KCR4ZZ" = "1" /* Extirpation of Matter from Left Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0KCS0ZZ" = "1" /* Extirpation of Matter from Right Lower Leg Muscle, Open Approach */
"0KCS3ZZ" = "1" /* Extirpation of Matter from Right Lower Leg Muscle, Percutaneous Approach */
"0KCS4ZZ" = "1" /* Extirpation of Matter from Right Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0KCT0ZZ" = "1" /* Extirpation of Matter from Left Lower Leg Muscle, Open Approach */
"0KCT3ZZ" = "1" /* Extirpation of Matter from Left Lower Leg Muscle, Percutaneous Approach */
"0KCT4ZZ" = "1" /* Extirpation of Matter from Left Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0KCV0ZZ" = "1" /* Extirpation of Matter from Right Foot Muscle, Open Approach */
"0KCV3ZZ" = "1" /* Extirpation of Matter from Right Foot Muscle, Percutaneous Approach */
"0KCV4ZZ" = "1" /* Extirpation of Matter from Right Foot Muscle, Percutaneous Endoscopic Approach */
"0KCW0ZZ" = "1" /* Extirpation of Matter from Left Foot Muscle, Open Approach */
"0KCW3ZZ" = "1" /* Extirpation of Matter from Left Foot Muscle, Percutaneous Approach */
"0KCW4ZZ" = "1" /* Extirpation of Matter from Left Foot Muscle, Percutaneous Endoscopic Approach */
"0KHX0MZ" = "1" /* Insertion of Stimulator Lead into Upper Muscle, Open Approach */
"0KHX3MZ" = "1" /* Insertion of Stimulator Lead into Upper Muscle, Percutaneous Approach */
"0KHX4MZ" = "1" /* Insertion of Stimulator Lead into Upper Muscle, Percutaneous Endoscopic Approach */
"0KHY0MZ" = "1" /* Insertion of Stimulator Lead into Lower Muscle, Open Approach */
"0KHY3MZ" = "1" /* Insertion of Stimulator Lead into Lower Muscle, Percutaneous Approach */
"0KHY4MZ" = "1" /* Insertion of Stimulator Lead into Lower Muscle, Percutaneous Endoscopic Approach */
"0KJX0ZZ" = "1" /* Inspection of Upper Muscle, Open Approach */
"0KJX4ZZ" = "1" /* Inspection of Upper Muscle, Percutaneous Endoscopic Approach */
"0KJY0ZZ" = "1" /* Inspection of Lower Muscle, Open Approach */
"0KJY4ZZ" = "1" /* Inspection of Lower Muscle, Percutaneous Endoscopic Approach */
"0KM00ZZ" = "1" /* Reattachment of Head Muscle, Open Approach */
"0KM04ZZ" = "1" /* Reattachment of Head Muscle, Percutaneous Endoscopic Approach */
"0KM10ZZ" = "1" /* Reattachment of Facial Muscle, Open Approach */
"0KM14ZZ" = "1" /* Reattachment of Facial Muscle, Percutaneous Endoscopic Approach */
"0KM20ZZ" = "1" /* Reattachment of Right Neck Muscle, Open Approach */
"0KM24ZZ" = "1" /* Reattachment of Right Neck Muscle, Percutaneous Endoscopic Approach */
"0KM30ZZ" = "1" /* Reattachment of Left Neck Muscle, Open Approach */
"0KM34ZZ" = "1" /* Reattachment of Left Neck Muscle, Percutaneous Endoscopic Approach */
"0KM40ZZ" = "1" /* Reattachment of Tongue, Palate, Pharynx Muscle, Open Approach */
"0KM44ZZ" = "1" /* Reattachment of Tongue, Palate, Pharynx Muscle, Percutaneous Endoscopic Approach */
"0KM50ZZ" = "1" /* Reattachment of Right Shoulder Muscle, Open Approach */
"0KM54ZZ" = "1" /* Reattachment of Right Shoulder Muscle, Percutaneous Endoscopic Approach */
"0KM60ZZ" = "1" /* Reattachment of Left Shoulder Muscle, Open Approach */
"0KM64ZZ" = "1" /* Reattachment of Left Shoulder Muscle, Percutaneous Endoscopic Approach */
"0KM70ZZ" = "1" /* Reattachment of Right Upper Arm Muscle, Open Approach */
"0KM74ZZ" = "1" /* Reattachment of Right Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0KM80ZZ" = "1" /* Reattachment of Left Upper Arm Muscle, Open Approach */
"0KM84ZZ" = "1" /* Reattachment of Left Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0KM90ZZ" = "1" /* Reattachment of Right Lower Arm and Wrist Muscle, Open Approach */
"0KM94ZZ" = "1" /* Reattachment of Right Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0KMB0ZZ" = "1" /* Reattachment of Left Lower Arm and Wrist Muscle, Open Approach */
"0KMB4ZZ" = "1" /* Reattachment of Left Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0KMC0ZZ" = "1" /* Reattachment of Right Hand Muscle, Open Approach */
"0KMC4ZZ" = "1" /* Reattachment of Right Hand Muscle, Percutaneous Endoscopic Approach */
"0KMD0ZZ" = "1" /* Reattachment of Left Hand Muscle, Open Approach */
"0KMD4ZZ" = "1" /* Reattachment of Left Hand Muscle, Percutaneous Endoscopic Approach */
"0KMF0ZZ" = "1" /* Reattachment of Right Trunk Muscle, Open Approach */
"0KMF4ZZ" = "1" /* Reattachment of Right Trunk Muscle, Percutaneous Endoscopic Approach */
"0KMG0ZZ" = "1" /* Reattachment of Left Trunk Muscle, Open Approach */
"0KMG4ZZ" = "1" /* Reattachment of Left Trunk Muscle, Percutaneous Endoscopic Approach */
"0KMH0ZZ" = "1" /* Reattachment of Right Thorax Muscle, Open Approach */
"0KMH4ZZ" = "1" /* Reattachment of Right Thorax Muscle, Percutaneous Endoscopic Approach */
"0KMJ0ZZ" = "1" /* Reattachment of Left Thorax Muscle, Open Approach */
"0KMJ4ZZ" = "1" /* Reattachment of Left Thorax Muscle, Percutaneous Endoscopic Approach */
"0KMK0ZZ" = "1" /* Reattachment of Right Abdomen Muscle, Open Approach */
"0KMK4ZZ" = "1" /* Reattachment of Right Abdomen Muscle, Percutaneous Endoscopic Approach */
"0KML0ZZ" = "1" /* Reattachment of Left Abdomen Muscle, Open Approach */
"0KML4ZZ" = "1" /* Reattachment of Left Abdomen Muscle, Percutaneous Endoscopic Approach */
"0KMM0ZZ" = "1" /* Reattachment of Perineum Muscle, Open Approach */
"0KMM4ZZ" = "1" /* Reattachment of Perineum Muscle, Percutaneous Endoscopic Approach */
"0KMN0ZZ" = "1" /* Reattachment of Right Hip Muscle, Open Approach */
"0KMN4ZZ" = "1" /* Reattachment of Right Hip Muscle, Percutaneous Endoscopic Approach */
"0KMP0ZZ" = "1" /* Reattachment of Left Hip Muscle, Open Approach */
"0KMP4ZZ" = "1" /* Reattachment of Left Hip Muscle, Percutaneous Endoscopic Approach */
"0KMQ0ZZ" = "1" /* Reattachment of Right Upper Leg Muscle, Open Approach */
"0KMQ4ZZ" = "1" /* Reattachment of Right Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0KMR0ZZ" = "1" /* Reattachment of Left Upper Leg Muscle, Open Approach */
"0KMR4ZZ" = "1" /* Reattachment of Left Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0KMS0ZZ" = "1" /* Reattachment of Right Lower Leg Muscle, Open Approach */
"0KMS4ZZ" = "1" /* Reattachment of Right Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0KMT0ZZ" = "1" /* Reattachment of Left Lower Leg Muscle, Open Approach */
"0KMT4ZZ" = "1" /* Reattachment of Left Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0KMV0ZZ" = "1" /* Reattachment of Right Foot Muscle, Open Approach */
"0KMV4ZZ" = "1" /* Reattachment of Right Foot Muscle, Percutaneous Endoscopic Approach */
"0KMW0ZZ" = "1" /* Reattachment of Left Foot Muscle, Open Approach */
"0KMW4ZZ" = "1" /* Reattachment of Left Foot Muscle, Percutaneous Endoscopic Approach */
"0KN00ZZ" = "1" /* Release Head Muscle, Open Approach */
"0KN03ZZ" = "1" /* Release Head Muscle, Percutaneous Approach */
"0KN04ZZ" = "1" /* Release Head Muscle, Percutaneous Endoscopic Approach */
"0KN10ZZ" = "1" /* Release Facial Muscle, Open Approach */
"0KN13ZZ" = "1" /* Release Facial Muscle, Percutaneous Approach */
"0KN14ZZ" = "1" /* Release Facial Muscle, Percutaneous Endoscopic Approach */
"0KN20ZZ" = "1" /* Release Right Neck Muscle, Open Approach */
"0KN23ZZ" = "1" /* Release Right Neck Muscle, Percutaneous Approach */
"0KN24ZZ" = "1" /* Release Right Neck Muscle, Percutaneous Endoscopic Approach */
"0KN30ZZ" = "1" /* Release Left Neck Muscle, Open Approach */
"0KN33ZZ" = "1" /* Release Left Neck Muscle, Percutaneous Approach */
"0KN34ZZ" = "1" /* Release Left Neck Muscle, Percutaneous Endoscopic Approach */
"0KN40ZZ" = "1" /* Release Tongue, Palate, Pharynx Muscle, Open Approach */
"0KN43ZZ" = "1" /* Release Tongue, Palate, Pharynx Muscle, Percutaneous Approach */
"0KN44ZZ" = "1" /* Release Tongue, Palate, Pharynx Muscle, Percutaneous Endoscopic Approach */
"0KN50ZZ" = "1" /* Release Right Shoulder Muscle, Open Approach */
"0KN53ZZ" = "1" /* Release Right Shoulder Muscle, Percutaneous Approach */
"0KN54ZZ" = "1" /* Release Right Shoulder Muscle, Percutaneous Endoscopic Approach */
"0KN60ZZ" = "1" /* Release Left Shoulder Muscle, Open Approach */
"0KN63ZZ" = "1" /* Release Left Shoulder Muscle, Percutaneous Approach */
"0KN64ZZ" = "1" /* Release Left Shoulder Muscle, Percutaneous Endoscopic Approach */
"0KN70ZZ" = "1" /* Release Right Upper Arm Muscle, Open Approach */
"0KN73ZZ" = "1" /* Release Right Upper Arm Muscle, Percutaneous Approach */
"0KN74ZZ" = "1" /* Release Right Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0KN80ZZ" = "1" /* Release Left Upper Arm Muscle, Open Approach */
"0KN83ZZ" = "1" /* Release Left Upper Arm Muscle, Percutaneous Approach */
"0KN84ZZ" = "1" /* Release Left Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0KN90ZZ" = "1" /* Release Right Lower Arm and Wrist Muscle, Open Approach */
"0KN93ZZ" = "1" /* Release Right Lower Arm and Wrist Muscle, Percutaneous Approach */
"0KN94ZZ" = "1" /* Release Right Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0KNB0ZZ" = "1" /* Release Left Lower Arm and Wrist Muscle, Open Approach */
"0KNB3ZZ" = "1" /* Release Left Lower Arm and Wrist Muscle, Percutaneous Approach */
"0KNB4ZZ" = "1" /* Release Left Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0KNC0ZZ" = "1" /* Release Right Hand Muscle, Open Approach */
"0KNC3ZZ" = "1" /* Release Right Hand Muscle, Percutaneous Approach */
"0KNC4ZZ" = "1" /* Release Right Hand Muscle, Percutaneous Endoscopic Approach */
"0KND0ZZ" = "1" /* Release Left Hand Muscle, Open Approach */
"0KND3ZZ" = "1" /* Release Left Hand Muscle, Percutaneous Approach */
"0KND4ZZ" = "1" /* Release Left Hand Muscle, Percutaneous Endoscopic Approach */
"0KNF0ZZ" = "1" /* Release Right Trunk Muscle, Open Approach */
"0KNF3ZZ" = "1" /* Release Right Trunk Muscle, Percutaneous Approach */
"0KNF4ZZ" = "1" /* Release Right Trunk Muscle, Percutaneous Endoscopic Approach */
"0KNG0ZZ" = "1" /* Release Left Trunk Muscle, Open Approach */
"0KNG3ZZ" = "1" /* Release Left Trunk Muscle, Percutaneous Approach */
"0KNG4ZZ" = "1" /* Release Left Trunk Muscle, Percutaneous Endoscopic Approach */
"0KNH0ZZ" = "1" /* Release Right Thorax Muscle, Open Approach */
"0KNH3ZZ" = "1" /* Release Right Thorax Muscle, Percutaneous Approach */
"0KNH4ZZ" = "1" /* Release Right Thorax Muscle, Percutaneous Endoscopic Approach */
"0KNJ0ZZ" = "1" /* Release Left Thorax Muscle, Open Approach */
"0KNJ3ZZ" = "1" /* Release Left Thorax Muscle, Percutaneous Approach */
"0KNJ4ZZ" = "1" /* Release Left Thorax Muscle, Percutaneous Endoscopic Approach */
"0KNK0ZZ" = "1" /* Release Right Abdomen Muscle, Open Approach */
"0KNK3ZZ" = "1" /* Release Right Abdomen Muscle, Percutaneous Approach */
"0KNK4ZZ" = "1" /* Release Right Abdomen Muscle, Percutaneous Endoscopic Approach */
"0KNL0ZZ" = "1" /* Release Left Abdomen Muscle, Open Approach */
"0KNL3ZZ" = "1" /* Release Left Abdomen Muscle, Percutaneous Approach */
"0KNL4ZZ" = "1" /* Release Left Abdomen Muscle, Percutaneous Endoscopic Approach */
"0KNM0ZZ" = "1" /* Release Perineum Muscle, Open Approach */
"0KNM3ZZ" = "1" /* Release Perineum Muscle, Percutaneous Approach */
"0KNM4ZZ" = "1" /* Release Perineum Muscle, Percutaneous Endoscopic Approach */
"0KNN0ZZ" = "1" /* Release Right Hip Muscle, Open Approach */
"0KNN3ZZ" = "1" /* Release Right Hip Muscle, Percutaneous Approach */
"0KNN4ZZ" = "1" /* Release Right Hip Muscle, Percutaneous Endoscopic Approach */
"0KNP0ZZ" = "1" /* Release Left Hip Muscle, Open Approach */
"0KNP3ZZ" = "1" /* Release Left Hip Muscle, Percutaneous Approach */
"0KNP4ZZ" = "1" /* Release Left Hip Muscle, Percutaneous Endoscopic Approach */
"0KNQ0ZZ" = "1" /* Release Right Upper Leg Muscle, Open Approach */
"0KNQ3ZZ" = "1" /* Release Right Upper Leg Muscle, Percutaneous Approach */
"0KNQ4ZZ" = "1" /* Release Right Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0KNR0ZZ" = "1" /* Release Left Upper Leg Muscle, Open Approach */
"0KNR3ZZ" = "1" /* Release Left Upper Leg Muscle, Percutaneous Approach */
"0KNR4ZZ" = "1" /* Release Left Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0KNS0ZZ" = "1" /* Release Right Lower Leg Muscle, Open Approach */
"0KNS3ZZ" = "1" /* Release Right Lower Leg Muscle, Percutaneous Approach */
"0KNS4ZZ" = "1" /* Release Right Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0KNT0ZZ" = "1" /* Release Left Lower Leg Muscle, Open Approach */
"0KNT3ZZ" = "1" /* Release Left Lower Leg Muscle, Percutaneous Approach */
"0KNT4ZZ" = "1" /* Release Left Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0KNV0ZZ" = "1" /* Release Right Foot Muscle, Open Approach */
"0KNV3ZZ" = "1" /* Release Right Foot Muscle, Percutaneous Approach */
"0KNV4ZZ" = "1" /* Release Right Foot Muscle, Percutaneous Endoscopic Approach */
"0KNW0ZZ" = "1" /* Release Left Foot Muscle, Open Approach */
"0KNW3ZZ" = "1" /* Release Left Foot Muscle, Percutaneous Approach */
"0KNW4ZZ" = "1" /* Release Left Foot Muscle, Percutaneous Endoscopic Approach */
"0KPX00Z" = "1" /* Removal of Drainage Device from Upper Muscle, Open Approach */
"0KPX07Z" = "1" /* Removal of Autologous Tissue Substitute from Upper Muscle, Open Approach */
"0KPX0JZ" = "1" /* Removal of Synthetic Substitute from Upper Muscle, Open Approach */
"0KPX0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Upper Muscle, Open Approach */
"0KPX0MZ" = "1" /* Removal of Stimulator Lead from Upper Muscle, Open Approach */
"0KPX30Z" = "1" /* Removal of Drainage Device from Upper Muscle, Percutaneous Approach */
"0KPX37Z" = "1" /* Removal of Autologous Tissue Substitute from Upper Muscle, Percutaneous Approach */
"0KPX3JZ" = "1" /* Removal of Synthetic Substitute from Upper Muscle, Percutaneous Approach */
"0KPX3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Upper Muscle, Percutaneous Approach */
"0KPX3MZ" = "1" /* Removal of Stimulator Lead from Upper Muscle, Percutaneous Approach */
"0KPX40Z" = "1" /* Removal of Drainage Device from Upper Muscle, Percutaneous Endoscopic Approach */
"0KPX47Z" = "1" /* Removal of Autologous Tissue Substitute from Upper Muscle, Percutaneous Endoscopic Approach */
"0KPX4JZ" = "1" /* Removal of Synthetic Substitute from Upper Muscle, Percutaneous Endoscopic Approach */
"0KPX4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Upper Muscle, Percutaneous Endoscopic Approach */
"0KPX4MZ" = "1" /* Removal of Stimulator Lead from Upper Muscle, Percutaneous Endoscopic Approach */
"0KPY00Z" = "1" /* Removal of Drainage Device from Lower Muscle, Open Approach */
"0KPY07Z" = "1" /* Removal of Autologous Tissue Substitute from Lower Muscle, Open Approach */
"0KPY0JZ" = "1" /* Removal of Synthetic Substitute from Lower Muscle, Open Approach */
"0KPY0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lower Muscle, Open Approach */
"0KPY0MZ" = "1" /* Removal of Stimulator Lead from Lower Muscle, Open Approach */
"0KPY30Z" = "1" /* Removal of Drainage Device from Lower Muscle, Percutaneous Approach */
"0KPY37Z" = "1" /* Removal of Autologous Tissue Substitute from Lower Muscle, Percutaneous Approach */
"0KPY3JZ" = "1" /* Removal of Synthetic Substitute from Lower Muscle, Percutaneous Approach */
"0KPY3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lower Muscle, Percutaneous Approach */
"0KPY3MZ" = "1" /* Removal of Stimulator Lead from Lower Muscle, Percutaneous Approach */
"0KPY40Z" = "1" /* Removal of Drainage Device from Lower Muscle, Percutaneous Endoscopic Approach */
"0KPY47Z" = "1" /* Removal of Autologous Tissue Substitute from Lower Muscle, Percutaneous Endoscopic Approach */
"0KPY4JZ" = "1" /* Removal of Synthetic Substitute from Lower Muscle, Percutaneous Endoscopic Approach */
"0KPY4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lower Muscle, Percutaneous Endoscopic Approach */
"0KPY4MZ" = "1" /* Removal of Stimulator Lead from Lower Muscle, Percutaneous Endoscopic Approach */
"0KQ00ZZ" = "1" /* Repair Head Muscle, Open Approach */
"0KQ03ZZ" = "1" /* Repair Head Muscle, Percutaneous Approach */
"0KQ04ZZ" = "1" /* Repair Head Muscle, Percutaneous Endoscopic Approach */
"0KQ10ZZ" = "1" /* Repair Facial Muscle, Open Approach */
"0KQ13ZZ" = "1" /* Repair Facial Muscle, Percutaneous Approach */
"0KQ14ZZ" = "1" /* Repair Facial Muscle, Percutaneous Endoscopic Approach */
"0KQ20ZZ" = "1" /* Repair Right Neck Muscle, Open Approach */
"0KQ23ZZ" = "1" /* Repair Right Neck Muscle, Percutaneous Approach */
"0KQ24ZZ" = "1" /* Repair Right Neck Muscle, Percutaneous Endoscopic Approach */
"0KQ30ZZ" = "1" /* Repair Left Neck Muscle, Open Approach */
"0KQ33ZZ" = "1" /* Repair Left Neck Muscle, Percutaneous Approach */
"0KQ34ZZ" = "1" /* Repair Left Neck Muscle, Percutaneous Endoscopic Approach */
"0KQ40ZZ" = "1" /* Repair Tongue, Palate, Pharynx Muscle, Open Approach */
"0KQ43ZZ" = "1" /* Repair Tongue, Palate, Pharynx Muscle, Percutaneous Approach */
"0KQ44ZZ" = "1" /* Repair Tongue, Palate, Pharynx Muscle, Percutaneous Endoscopic Approach */
"0KQ50ZZ" = "1" /* Repair Right Shoulder Muscle, Open Approach */
"0KQ53ZZ" = "1" /* Repair Right Shoulder Muscle, Percutaneous Approach */
"0KQ54ZZ" = "1" /* Repair Right Shoulder Muscle, Percutaneous Endoscopic Approach */
"0KQ60ZZ" = "1" /* Repair Left Shoulder Muscle, Open Approach */
"0KQ63ZZ" = "1" /* Repair Left Shoulder Muscle, Percutaneous Approach */
"0KQ64ZZ" = "1" /* Repair Left Shoulder Muscle, Percutaneous Endoscopic Approach */
"0KQ70ZZ" = "1" /* Repair Right Upper Arm Muscle, Open Approach */
"0KQ73ZZ" = "1" /* Repair Right Upper Arm Muscle, Percutaneous Approach */
"0KQ74ZZ" = "1" /* Repair Right Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0KQ80ZZ" = "1" /* Repair Left Upper Arm Muscle, Open Approach */
"0KQ83ZZ" = "1" /* Repair Left Upper Arm Muscle, Percutaneous Approach */
"0KQ84ZZ" = "1" /* Repair Left Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0KQ90ZZ" = "1" /* Repair Right Lower Arm and Wrist Muscle, Open Approach */
"0KQ93ZZ" = "1" /* Repair Right Lower Arm and Wrist Muscle, Percutaneous Approach */
"0KQ94ZZ" = "1" /* Repair Right Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0KQB0ZZ" = "1" /* Repair Left Lower Arm and Wrist Muscle, Open Approach */
"0KQB3ZZ" = "1" /* Repair Left Lower Arm and Wrist Muscle, Percutaneous Approach */
"0KQB4ZZ" = "1" /* Repair Left Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0KQC0ZZ" = "1" /* Repair Right Hand Muscle, Open Approach */
"0KQC3ZZ" = "1" /* Repair Right Hand Muscle, Percutaneous Approach */
"0KQC4ZZ" = "1" /* Repair Right Hand Muscle, Percutaneous Endoscopic Approach */
"0KQD0ZZ" = "1" /* Repair Left Hand Muscle, Open Approach */
"0KQD3ZZ" = "1" /* Repair Left Hand Muscle, Percutaneous Approach */
"0KQD4ZZ" = "1" /* Repair Left Hand Muscle, Percutaneous Endoscopic Approach */
"0KQF0ZZ" = "1" /* Repair Right Trunk Muscle, Open Approach */
"0KQF3ZZ" = "1" /* Repair Right Trunk Muscle, Percutaneous Approach */
"0KQF4ZZ" = "1" /* Repair Right Trunk Muscle, Percutaneous Endoscopic Approach */
"0KQG0ZZ" = "1" /* Repair Left Trunk Muscle, Open Approach */
"0KQG3ZZ" = "1" /* Repair Left Trunk Muscle, Percutaneous Approach */
"0KQG4ZZ" = "1" /* Repair Left Trunk Muscle, Percutaneous Endoscopic Approach */
"0KQH0ZZ" = "1" /* Repair Right Thorax Muscle, Open Approach */
"0KQH3ZZ" = "1" /* Repair Right Thorax Muscle, Percutaneous Approach */
"0KQH4ZZ" = "1" /* Repair Right Thorax Muscle, Percutaneous Endoscopic Approach */
"0KQJ0ZZ" = "1" /* Repair Left Thorax Muscle, Open Approach */
"0KQJ3ZZ" = "1" /* Repair Left Thorax Muscle, Percutaneous Approach */
"0KQJ4ZZ" = "1" /* Repair Left Thorax Muscle, Percutaneous Endoscopic Approach */
"0KQK0ZZ" = "1" /* Repair Right Abdomen Muscle, Open Approach */
"0KQK3ZZ" = "1" /* Repair Right Abdomen Muscle, Percutaneous Approach */
"0KQK4ZZ" = "1" /* Repair Right Abdomen Muscle, Percutaneous Endoscopic Approach */
"0KQL0ZZ" = "1" /* Repair Left Abdomen Muscle, Open Approach */
"0KQL3ZZ" = "1" /* Repair Left Abdomen Muscle, Percutaneous Approach */
"0KQL4ZZ" = "1" /* Repair Left Abdomen Muscle, Percutaneous Endoscopic Approach */
"0KQM0ZZ" = "1" /* Repair Perineum Muscle, Open Approach */
"0KQM3ZZ" = "1" /* Repair Perineum Muscle, Percutaneous Approach */
"0KQM4ZZ" = "1" /* Repair Perineum Muscle, Percutaneous Endoscopic Approach */
"0KQN0ZZ" = "1" /* Repair Right Hip Muscle, Open Approach */
"0KQN3ZZ" = "1" /* Repair Right Hip Muscle, Percutaneous Approach */
"0KQN4ZZ" = "1" /* Repair Right Hip Muscle, Percutaneous Endoscopic Approach */
"0KQP0ZZ" = "1" /* Repair Left Hip Muscle, Open Approach */
"0KQP3ZZ" = "1" /* Repair Left Hip Muscle, Percutaneous Approach */
"0KQP4ZZ" = "1" /* Repair Left Hip Muscle, Percutaneous Endoscopic Approach */
"0KQQ0ZZ" = "1" /* Repair Right Upper Leg Muscle, Open Approach */
"0KQQ3ZZ" = "1" /* Repair Right Upper Leg Muscle, Percutaneous Approach */
"0KQQ4ZZ" = "1" /* Repair Right Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0KQR0ZZ" = "1" /* Repair Left Upper Leg Muscle, Open Approach */
"0KQR3ZZ" = "1" /* Repair Left Upper Leg Muscle, Percutaneous Approach */
"0KQR4ZZ" = "1" /* Repair Left Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0KQS0ZZ" = "1" /* Repair Right Lower Leg Muscle, Open Approach */
"0KQS3ZZ" = "1" /* Repair Right Lower Leg Muscle, Percutaneous Approach */
"0KQS4ZZ" = "1" /* Repair Right Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0KQT0ZZ" = "1" /* Repair Left Lower Leg Muscle, Open Approach */
"0KQT3ZZ" = "1" /* Repair Left Lower Leg Muscle, Percutaneous Approach */
"0KQT4ZZ" = "1" /* Repair Left Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0KQV0ZZ" = "1" /* Repair Right Foot Muscle, Open Approach */
"0KQV3ZZ" = "1" /* Repair Right Foot Muscle, Percutaneous Approach */
"0KQV4ZZ" = "1" /* Repair Right Foot Muscle, Percutaneous Endoscopic Approach */
"0KQW0ZZ" = "1" /* Repair Left Foot Muscle, Open Approach */
"0KQW3ZZ" = "1" /* Repair Left Foot Muscle, Percutaneous Approach */
"0KQW4ZZ" = "1" /* Repair Left Foot Muscle, Percutaneous Endoscopic Approach */
"0KS00ZZ" = "1" /* Reposition Head Muscle, Open Approach */
"0KS04ZZ" = "1" /* Reposition Head Muscle, Percutaneous Endoscopic Approach */
"0KS10ZZ" = "1" /* Reposition Facial Muscle, Open Approach */
"0KS14ZZ" = "1" /* Reposition Facial Muscle, Percutaneous Endoscopic Approach */
"0KS20ZZ" = "1" /* Reposition Right Neck Muscle, Open Approach */
"0KS24ZZ" = "1" /* Reposition Right Neck Muscle, Percutaneous Endoscopic Approach */
"0KS30ZZ" = "1" /* Reposition Left Neck Muscle, Open Approach */
"0KS34ZZ" = "1" /* Reposition Left Neck Muscle, Percutaneous Endoscopic Approach */
"0KS40ZZ" = "1" /* Reposition Tongue, Palate, Pharynx Muscle, Open Approach */
"0KS44ZZ" = "1" /* Reposition Tongue, Palate, Pharynx Muscle, Percutaneous Endoscopic Approach */
"0KS50ZZ" = "1" /* Reposition Right Shoulder Muscle, Open Approach */
"0KS54ZZ" = "1" /* Reposition Right Shoulder Muscle, Percutaneous Endoscopic Approach */
"0KS60ZZ" = "1" /* Reposition Left Shoulder Muscle, Open Approach */
"0KS64ZZ" = "1" /* Reposition Left Shoulder Muscle, Percutaneous Endoscopic Approach */
"0KS70ZZ" = "1" /* Reposition Right Upper Arm Muscle, Open Approach */
"0KS74ZZ" = "1" /* Reposition Right Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0KS80ZZ" = "1" /* Reposition Left Upper Arm Muscle, Open Approach */
"0KS84ZZ" = "1" /* Reposition Left Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0KS90ZZ" = "1" /* Reposition Right Lower Arm and Wrist Muscle, Open Approach */
"0KS94ZZ" = "1" /* Reposition Right Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0KSB0ZZ" = "1" /* Reposition Left Lower Arm and Wrist Muscle, Open Approach */
"0KSB4ZZ" = "1" /* Reposition Left Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0KSC0ZZ" = "1" /* Reposition Right Hand Muscle, Open Approach */
"0KSC4ZZ" = "1" /* Reposition Right Hand Muscle, Percutaneous Endoscopic Approach */
"0KSD0ZZ" = "1" /* Reposition Left Hand Muscle, Open Approach */
"0KSD4ZZ" = "1" /* Reposition Left Hand Muscle, Percutaneous Endoscopic Approach */
"0KSF0ZZ" = "1" /* Reposition Right Trunk Muscle, Open Approach */
"0KSF4ZZ" = "1" /* Reposition Right Trunk Muscle, Percutaneous Endoscopic Approach */
"0KSG0ZZ" = "1" /* Reposition Left Trunk Muscle, Open Approach */
"0KSG4ZZ" = "1" /* Reposition Left Trunk Muscle, Percutaneous Endoscopic Approach */
"0KSH0ZZ" = "1" /* Reposition Right Thorax Muscle, Open Approach */
"0KSH4ZZ" = "1" /* Reposition Right Thorax Muscle, Percutaneous Endoscopic Approach */
"0KSJ0ZZ" = "1" /* Reposition Left Thorax Muscle, Open Approach */
"0KSJ4ZZ" = "1" /* Reposition Left Thorax Muscle, Percutaneous Endoscopic Approach */
"0KSK0ZZ" = "1" /* Reposition Right Abdomen Muscle, Open Approach */
"0KSK4ZZ" = "1" /* Reposition Right Abdomen Muscle, Percutaneous Endoscopic Approach */
"0KSL0ZZ" = "1" /* Reposition Left Abdomen Muscle, Open Approach */
"0KSL4ZZ" = "1" /* Reposition Left Abdomen Muscle, Percutaneous Endoscopic Approach */
"0KSM0ZZ" = "1" /* Reposition Perineum Muscle, Open Approach */
"0KSM4ZZ" = "1" /* Reposition Perineum Muscle, Percutaneous Endoscopic Approach */
"0KSN0ZZ" = "1" /* Reposition Right Hip Muscle, Open Approach */
"0KSN4ZZ" = "1" /* Reposition Right Hip Muscle, Percutaneous Endoscopic Approach */
"0KSP0ZZ" = "1" /* Reposition Left Hip Muscle, Open Approach */
"0KSP4ZZ" = "1" /* Reposition Left Hip Muscle, Percutaneous Endoscopic Approach */
"0KSQ0ZZ" = "1" /* Reposition Right Upper Leg Muscle, Open Approach */
"0KSQ4ZZ" = "1" /* Reposition Right Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0KSR0ZZ" = "1" /* Reposition Left Upper Leg Muscle, Open Approach */
"0KSR4ZZ" = "1" /* Reposition Left Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0KSS0ZZ" = "1" /* Reposition Right Lower Leg Muscle, Open Approach */
"0KSS4ZZ" = "1" /* Reposition Right Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0KST0ZZ" = "1" /* Reposition Left Lower Leg Muscle, Open Approach */
"0KST4ZZ" = "1" /* Reposition Left Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0KSV0ZZ" = "1" /* Reposition Right Foot Muscle, Open Approach */
"0KSV4ZZ" = "1" /* Reposition Right Foot Muscle, Percutaneous Endoscopic Approach */
"0KSW0ZZ" = "1" /* Reposition Left Foot Muscle, Open Approach */
"0KSW4ZZ" = "1" /* Reposition Left Foot Muscle, Percutaneous Endoscopic Approach */
"0KT00ZZ" = "1" /* Resection of Head Muscle, Open Approach */
"0KT04ZZ" = "1" /* Resection of Head Muscle, Percutaneous Endoscopic Approach */
"0KT10ZZ" = "1" /* Resection of Facial Muscle, Open Approach */
"0KT14ZZ" = "1" /* Resection of Facial Muscle, Percutaneous Endoscopic Approach */
"0KT20ZZ" = "1" /* Resection of Right Neck Muscle, Open Approach */
"0KT24ZZ" = "1" /* Resection of Right Neck Muscle, Percutaneous Endoscopic Approach */
"0KT30ZZ" = "1" /* Resection of Left Neck Muscle, Open Approach */
"0KT34ZZ" = "1" /* Resection of Left Neck Muscle, Percutaneous Endoscopic Approach */
"0KT40ZZ" = "1" /* Resection of Tongue, Palate, Pharynx Muscle, Open Approach */
"0KT44ZZ" = "1" /* Resection of Tongue, Palate, Pharynx Muscle, Percutaneous Endoscopic Approach */
"0KT50ZZ" = "1" /* Resection of Right Shoulder Muscle, Open Approach */
"0KT54ZZ" = "1" /* Resection of Right Shoulder Muscle, Percutaneous Endoscopic Approach */
"0KT60ZZ" = "1" /* Resection of Left Shoulder Muscle, Open Approach */
"0KT64ZZ" = "1" /* Resection of Left Shoulder Muscle, Percutaneous Endoscopic Approach */
"0KT70ZZ" = "1" /* Resection of Right Upper Arm Muscle, Open Approach */
"0KT74ZZ" = "1" /* Resection of Right Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0KT80ZZ" = "1" /* Resection of Left Upper Arm Muscle, Open Approach */
"0KT84ZZ" = "1" /* Resection of Left Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0KT90ZZ" = "1" /* Resection of Right Lower Arm and Wrist Muscle, Open Approach */
"0KT94ZZ" = "1" /* Resection of Right Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0KTB0ZZ" = "1" /* Resection of Left Lower Arm and Wrist Muscle, Open Approach */
"0KTB4ZZ" = "1" /* Resection of Left Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0KTC0ZZ" = "1" /* Resection of Right Hand Muscle, Open Approach */
"0KTC4ZZ" = "1" /* Resection of Right Hand Muscle, Percutaneous Endoscopic Approach */
"0KTD0ZZ" = "1" /* Resection of Left Hand Muscle, Open Approach */
"0KTD4ZZ" = "1" /* Resection of Left Hand Muscle, Percutaneous Endoscopic Approach */
"0KTF0ZZ" = "1" /* Resection of Right Trunk Muscle, Open Approach */
"0KTF4ZZ" = "1" /* Resection of Right Trunk Muscle, Percutaneous Endoscopic Approach */
"0KTG0ZZ" = "1" /* Resection of Left Trunk Muscle, Open Approach */
"0KTG4ZZ" = "1" /* Resection of Left Trunk Muscle, Percutaneous Endoscopic Approach */
"0KTH0ZZ" = "1" /* Resection of Right Thorax Muscle, Open Approach */
"0KTH4ZZ" = "1" /* Resection of Right Thorax Muscle, Percutaneous Endoscopic Approach */
"0KTJ0ZZ" = "1" /* Resection of Left Thorax Muscle, Open Approach */
"0KTJ4ZZ" = "1" /* Resection of Left Thorax Muscle, Percutaneous Endoscopic Approach */
"0KTK0ZZ" = "1" /* Resection of Right Abdomen Muscle, Open Approach */
"0KTK4ZZ" = "1" /* Resection of Right Abdomen Muscle, Percutaneous Endoscopic Approach */
"0KTL0ZZ" = "1" /* Resection of Left Abdomen Muscle, Open Approach */
"0KTL4ZZ" = "1" /* Resection of Left Abdomen Muscle, Percutaneous Endoscopic Approach */
"0KTM0ZZ" = "1" /* Resection of Perineum Muscle, Open Approach */
"0KTM4ZZ" = "1" /* Resection of Perineum Muscle, Percutaneous Endoscopic Approach */
"0KTN0ZZ" = "1" /* Resection of Right Hip Muscle, Open Approach */
"0KTN4ZZ" = "1" /* Resection of Right Hip Muscle, Percutaneous Endoscopic Approach */
"0KTP0ZZ" = "1" /* Resection of Left Hip Muscle, Open Approach */
"0KTP4ZZ" = "1" /* Resection of Left Hip Muscle, Percutaneous Endoscopic Approach */
"0KTQ0ZZ" = "1" /* Resection of Right Upper Leg Muscle, Open Approach */
"0KTQ4ZZ" = "1" /* Resection of Right Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0KTR0ZZ" = "1" /* Resection of Left Upper Leg Muscle, Open Approach */
"0KTR4ZZ" = "1" /* Resection of Left Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0KTS0ZZ" = "1" /* Resection of Right Lower Leg Muscle, Open Approach */
"0KTS4ZZ" = "1" /* Resection of Right Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0KTT0ZZ" = "1" /* Resection of Left Lower Leg Muscle, Open Approach */
"0KTT4ZZ" = "1" /* Resection of Left Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0KTV0ZZ" = "1" /* Resection of Right Foot Muscle, Open Approach */
"0KTV4ZZ" = "1" /* Resection of Right Foot Muscle, Percutaneous Endoscopic Approach */
"0KTW0ZZ" = "1" /* Resection of Left Foot Muscle, Open Approach */
"0KTW4ZZ" = "1" /* Resection of Left Foot Muscle, Percutaneous Endoscopic Approach */
"0KU007Z" = "1" /* Supplement Head Muscle with Autologous Tissue Substitute, Open Approach */
"0KU00JZ" = "1" /* Supplement Head Muscle with Synthetic Substitute, Open Approach */
"0KU00KZ" = "1" /* Supplement Head Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KU047Z" = "1" /* Supplement Head Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KU04JZ" = "1" /* Supplement Head Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KU04KZ" = "1" /* Supplement Head Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KU107Z" = "1" /* Supplement Facial Muscle with Autologous Tissue Substitute, Open Approach */
"0KU10JZ" = "1" /* Supplement Facial Muscle with Synthetic Substitute, Open Approach */
"0KU10KZ" = "1" /* Supplement Facial Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KU147Z" = "1" /* Supplement Facial Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KU14JZ" = "1" /* Supplement Facial Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KU14KZ" = "1" /* Supplement Facial Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KU207Z" = "1" /* Supplement Right Neck Muscle with Autologous Tissue Substitute, Open Approach */
"0KU20JZ" = "1" /* Supplement Right Neck Muscle with Synthetic Substitute, Open Approach */
"0KU20KZ" = "1" /* Supplement Right Neck Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KU247Z" = "1" /* Supplement Right Neck Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KU24JZ" = "1" /* Supplement Right Neck Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KU24KZ" = "1" /* Supplement Right Neck Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KU307Z" = "1" /* Supplement Left Neck Muscle with Autologous Tissue Substitute, Open Approach */
"0KU30JZ" = "1" /* Supplement Left Neck Muscle with Synthetic Substitute, Open Approach */
"0KU30KZ" = "1" /* Supplement Left Neck Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KU347Z" = "1" /* Supplement Left Neck Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KU34JZ" = "1" /* Supplement Left Neck Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KU34KZ" = "1" /* Supplement Left Neck Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KU407Z" = "1" /* Supplement Tongue, Palate, Pharynx Muscle with Autologous Tissue Substitute, Open Approach */
"0KU40JZ" = "1" /* Supplement Tongue, Palate, Pharynx Muscle with Synthetic Substitute, Open Approach */
"0KU40KZ" = "1" /* Supplement Tongue, Palate, Pharynx Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KU447Z" = "1" /* Supplement Tongue, Palate, Pharynx Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KU44JZ" = "1" /* Supplement Tongue, Palate, Pharynx Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KU44KZ" = "1" /* Supplement Tongue, Palate, Pharynx Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KU507Z" = "1" /* Supplement Right Shoulder Muscle with Autologous Tissue Substitute, Open Approach */
"0KU50JZ" = "1" /* Supplement Right Shoulder Muscle with Synthetic Substitute, Open Approach */
"0KU50KZ" = "1" /* Supplement Right Shoulder Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KU547Z" = "1" /* Supplement Right Shoulder Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KU54JZ" = "1" /* Supplement Right Shoulder Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KU54KZ" = "1" /* Supplement Right Shoulder Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KU607Z" = "1" /* Supplement Left Shoulder Muscle with Autologous Tissue Substitute, Open Approach */
"0KU60JZ" = "1" /* Supplement Left Shoulder Muscle with Synthetic Substitute, Open Approach */
"0KU60KZ" = "1" /* Supplement Left Shoulder Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KU647Z" = "1" /* Supplement Left Shoulder Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KU64JZ" = "1" /* Supplement Left Shoulder Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KU64KZ" = "1" /* Supplement Left Shoulder Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KU707Z" = "1" /* Supplement Right Upper Arm Muscle with Autologous Tissue Substitute, Open Approach */
"0KU70JZ" = "1" /* Supplement Right Upper Arm Muscle with Synthetic Substitute, Open Approach */
"0KU70KZ" = "1" /* Supplement Right Upper Arm Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KU747Z" = "1" /* Supplement Right Upper Arm Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KU74JZ" = "1" /* Supplement Right Upper Arm Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KU74KZ" = "1" /* Supplement Right Upper Arm Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KU807Z" = "1" /* Supplement Left Upper Arm Muscle with Autologous Tissue Substitute, Open Approach */
"0KU80JZ" = "1" /* Supplement Left Upper Arm Muscle with Synthetic Substitute, Open Approach */
"0KU80KZ" = "1" /* Supplement Left Upper Arm Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KU847Z" = "1" /* Supplement Left Upper Arm Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KU84JZ" = "1" /* Supplement Left Upper Arm Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KU84KZ" = "1" /* Supplement Left Upper Arm Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KU907Z" = "1" /* Supplement Right Lower Arm and Wrist Muscle with Autologous Tissue Substitute, Open Approach */
"0KU90JZ" = "1" /* Supplement Right Lower Arm and Wrist Muscle with Synthetic Substitute, Open Approach */
"0KU90KZ" = "1" /* Supplement Right Lower Arm and Wrist Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KU947Z" = "1" /* Supplement Right Lower Arm and Wrist Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KU94JZ" = "1" /* Supplement Right Lower Arm and Wrist Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KU94KZ" = "1" /* Supplement Right Lower Arm and Wrist Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUB07Z" = "1" /* Supplement Left Lower Arm and Wrist Muscle with Autologous Tissue Substitute, Open Approach */
"0KUB0JZ" = "1" /* Supplement Left Lower Arm and Wrist Muscle with Synthetic Substitute, Open Approach */
"0KUB0KZ" = "1" /* Supplement Left Lower Arm and Wrist Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KUB47Z" = "1" /* Supplement Left Lower Arm and Wrist Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUB4JZ" = "1" /* Supplement Left Lower Arm and Wrist Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KUB4KZ" = "1" /* Supplement Left Lower Arm and Wrist Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUC07Z" = "1" /* Supplement Right Hand Muscle with Autologous Tissue Substitute, Open Approach */
"0KUC0JZ" = "1" /* Supplement Right Hand Muscle with Synthetic Substitute, Open Approach */
"0KUC0KZ" = "1" /* Supplement Right Hand Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KUC47Z" = "1" /* Supplement Right Hand Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUC4JZ" = "1" /* Supplement Right Hand Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KUC4KZ" = "1" /* Supplement Right Hand Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUD07Z" = "1" /* Supplement Left Hand Muscle with Autologous Tissue Substitute, Open Approach */
"0KUD0JZ" = "1" /* Supplement Left Hand Muscle with Synthetic Substitute, Open Approach */
"0KUD0KZ" = "1" /* Supplement Left Hand Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KUD47Z" = "1" /* Supplement Left Hand Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUD4JZ" = "1" /* Supplement Left Hand Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KUD4KZ" = "1" /* Supplement Left Hand Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUF07Z" = "1" /* Supplement Right Trunk Muscle with Autologous Tissue Substitute, Open Approach */
"0KUF0JZ" = "1" /* Supplement Right Trunk Muscle with Synthetic Substitute, Open Approach */
"0KUF0KZ" = "1" /* Supplement Right Trunk Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KUF47Z" = "1" /* Supplement Right Trunk Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUF4JZ" = "1" /* Supplement Right Trunk Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KUF4KZ" = "1" /* Supplement Right Trunk Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUG07Z" = "1" /* Supplement Left Trunk Muscle with Autologous Tissue Substitute, Open Approach */
"0KUG0JZ" = "1" /* Supplement Left Trunk Muscle with Synthetic Substitute, Open Approach */
"0KUG0KZ" = "1" /* Supplement Left Trunk Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KUG47Z" = "1" /* Supplement Left Trunk Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUG4JZ" = "1" /* Supplement Left Trunk Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KUG4KZ" = "1" /* Supplement Left Trunk Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUH07Z" = "1" /* Supplement Right Thorax Muscle with Autologous Tissue Substitute, Open Approach */
"0KUH0JZ" = "1" /* Supplement Right Thorax Muscle with Synthetic Substitute, Open Approach */
"0KUH0KZ" = "1" /* Supplement Right Thorax Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KUH47Z" = "1" /* Supplement Right Thorax Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUH4JZ" = "1" /* Supplement Right Thorax Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KUH4KZ" = "1" /* Supplement Right Thorax Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUJ07Z" = "1" /* Supplement Left Thorax Muscle with Autologous Tissue Substitute, Open Approach */
"0KUJ0JZ" = "1" /* Supplement Left Thorax Muscle with Synthetic Substitute, Open Approach */
"0KUJ0KZ" = "1" /* Supplement Left Thorax Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KUJ47Z" = "1" /* Supplement Left Thorax Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUJ4JZ" = "1" /* Supplement Left Thorax Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KUJ4KZ" = "1" /* Supplement Left Thorax Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUK07Z" = "1" /* Supplement Right Abdomen Muscle with Autologous Tissue Substitute, Open Approach */
"0KUK0JZ" = "1" /* Supplement Right Abdomen Muscle with Synthetic Substitute, Open Approach */
"0KUK0KZ" = "1" /* Supplement Right Abdomen Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KUK47Z" = "1" /* Supplement Right Abdomen Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUK4JZ" = "1" /* Supplement Right Abdomen Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KUK4KZ" = "1" /* Supplement Right Abdomen Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUL07Z" = "1" /* Supplement Left Abdomen Muscle with Autologous Tissue Substitute, Open Approach */
"0KUL0JZ" = "1" /* Supplement Left Abdomen Muscle with Synthetic Substitute, Open Approach */
"0KUL0KZ" = "1" /* Supplement Left Abdomen Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KUL47Z" = "1" /* Supplement Left Abdomen Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUL4JZ" = "1" /* Supplement Left Abdomen Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KUL4KZ" = "1" /* Supplement Left Abdomen Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUM07Z" = "1" /* Supplement Perineum Muscle with Autologous Tissue Substitute, Open Approach */
"0KUM0JZ" = "1" /* Supplement Perineum Muscle with Synthetic Substitute, Open Approach */
"0KUM0KZ" = "1" /* Supplement Perineum Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KUM47Z" = "1" /* Supplement Perineum Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUM4JZ" = "1" /* Supplement Perineum Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KUM4KZ" = "1" /* Supplement Perineum Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUN07Z" = "1" /* Supplement Right Hip Muscle with Autologous Tissue Substitute, Open Approach */
"0KUN0JZ" = "1" /* Supplement Right Hip Muscle with Synthetic Substitute, Open Approach */
"0KUN0KZ" = "1" /* Supplement Right Hip Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KUN47Z" = "1" /* Supplement Right Hip Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUN4JZ" = "1" /* Supplement Right Hip Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KUN4KZ" = "1" /* Supplement Right Hip Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUP07Z" = "1" /* Supplement Left Hip Muscle with Autologous Tissue Substitute, Open Approach */
"0KUP0JZ" = "1" /* Supplement Left Hip Muscle with Synthetic Substitute, Open Approach */
"0KUP0KZ" = "1" /* Supplement Left Hip Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KUP47Z" = "1" /* Supplement Left Hip Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUP4JZ" = "1" /* Supplement Left Hip Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KUP4KZ" = "1" /* Supplement Left Hip Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUQ07Z" = "1" /* Supplement Right Upper Leg Muscle with Autologous Tissue Substitute, Open Approach */
"0KUQ0JZ" = "1" /* Supplement Right Upper Leg Muscle with Synthetic Substitute, Open Approach */
"0KUQ0KZ" = "1" /* Supplement Right Upper Leg Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KUQ47Z" = "1" /* Supplement Right Upper Leg Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUQ4JZ" = "1" /* Supplement Right Upper Leg Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KUQ4KZ" = "1" /* Supplement Right Upper Leg Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUR07Z" = "1" /* Supplement Left Upper Leg Muscle with Autologous Tissue Substitute, Open Approach */
"0KUR0JZ" = "1" /* Supplement Left Upper Leg Muscle with Synthetic Substitute, Open Approach */
"0KUR0KZ" = "1" /* Supplement Left Upper Leg Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KUR47Z" = "1" /* Supplement Left Upper Leg Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUR4JZ" = "1" /* Supplement Left Upper Leg Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KUR4KZ" = "1" /* Supplement Left Upper Leg Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUS07Z" = "1" /* Supplement Right Lower Leg Muscle with Autologous Tissue Substitute, Open Approach */
"0KUS0JZ" = "1" /* Supplement Right Lower Leg Muscle with Synthetic Substitute, Open Approach */
"0KUS0KZ" = "1" /* Supplement Right Lower Leg Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KUS47Z" = "1" /* Supplement Right Lower Leg Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUS4JZ" = "1" /* Supplement Right Lower Leg Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KUS4KZ" = "1" /* Supplement Right Lower Leg Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUT07Z" = "1" /* Supplement Left Lower Leg Muscle with Autologous Tissue Substitute, Open Approach */
"0KUT0JZ" = "1" /* Supplement Left Lower Leg Muscle with Synthetic Substitute, Open Approach */
"0KUT0KZ" = "1" /* Supplement Left Lower Leg Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KUT47Z" = "1" /* Supplement Left Lower Leg Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUT4JZ" = "1" /* Supplement Left Lower Leg Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KUT4KZ" = "1" /* Supplement Left Lower Leg Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUV07Z" = "1" /* Supplement Right Foot Muscle with Autologous Tissue Substitute, Open Approach */
"0KUV0JZ" = "1" /* Supplement Right Foot Muscle with Synthetic Substitute, Open Approach */
"0KUV0KZ" = "1" /* Supplement Right Foot Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KUV47Z" = "1" /* Supplement Right Foot Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUV4JZ" = "1" /* Supplement Right Foot Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KUV4KZ" = "1" /* Supplement Right Foot Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUW07Z" = "1" /* Supplement Left Foot Muscle with Autologous Tissue Substitute, Open Approach */
"0KUW0JZ" = "1" /* Supplement Left Foot Muscle with Synthetic Substitute, Open Approach */
"0KUW0KZ" = "1" /* Supplement Left Foot Muscle with Nonautologous Tissue Substitute, Open Approach */
"0KUW47Z" = "1" /* Supplement Left Foot Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KUW4JZ" = "1" /* Supplement Left Foot Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0KUW4KZ" = "1" /* Supplement Left Foot Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0KWX00Z" = "1" /* Revision of Drainage Device in Upper Muscle, Open Approach */
"0KWX07Z" = "1" /* Revision of Autologous Tissue Substitute in Upper Muscle, Open Approach */
"0KWX0JZ" = "1" /* Revision of Synthetic Substitute in Upper Muscle, Open Approach */
"0KWX0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Muscle, Open Approach */
"0KWX0MZ" = "1" /* Revision of Stimulator Lead in Upper Muscle, Open Approach */
"0KWX30Z" = "1" /* Revision of Drainage Device in Upper Muscle, Percutaneous Approach */
"0KWX37Z" = "1" /* Revision of Autologous Tissue Substitute in Upper Muscle, Percutaneous Approach */
"0KWX3JZ" = "1" /* Revision of Synthetic Substitute in Upper Muscle, Percutaneous Approach */
"0KWX3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Muscle, Percutaneous Approach */
"0KWX3MZ" = "1" /* Revision of Stimulator Lead in Upper Muscle, Percutaneous Approach */
"0KWX40Z" = "1" /* Revision of Drainage Device in Upper Muscle, Percutaneous Endoscopic Approach */
"0KWX47Z" = "1" /* Revision of Autologous Tissue Substitute in Upper Muscle, Percutaneous Endoscopic Approach */
"0KWX4JZ" = "1" /* Revision of Synthetic Substitute in Upper Muscle, Percutaneous Endoscopic Approach */
"0KWX4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Muscle, Percutaneous Endoscopic Approach */
"0KWX4MZ" = "1" /* Revision of Stimulator Lead in Upper Muscle, Percutaneous Endoscopic Approach */
"0KWY00Z" = "1" /* Revision of Drainage Device in Lower Muscle, Open Approach */
"0KWY07Z" = "1" /* Revision of Autologous Tissue Substitute in Lower Muscle, Open Approach */
"0KWY0JZ" = "1" /* Revision of Synthetic Substitute in Lower Muscle, Open Approach */
"0KWY0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Muscle, Open Approach */
"0KWY0MZ" = "1" /* Revision of Stimulator Lead in Lower Muscle, Open Approach */
"0KWY30Z" = "1" /* Revision of Drainage Device in Lower Muscle, Percutaneous Approach */
"0KWY37Z" = "1" /* Revision of Autologous Tissue Substitute in Lower Muscle, Percutaneous Approach */
"0KWY3JZ" = "1" /* Revision of Synthetic Substitute in Lower Muscle, Percutaneous Approach */
"0KWY3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Muscle, Percutaneous Approach */
"0KWY3MZ" = "1" /* Revision of Stimulator Lead in Lower Muscle, Percutaneous Approach */
"0KWY40Z" = "1" /* Revision of Drainage Device in Lower Muscle, Percutaneous Endoscopic Approach */
"0KWY47Z" = "1" /* Revision of Autologous Tissue Substitute in Lower Muscle, Percutaneous Endoscopic Approach */
"0KWY4JZ" = "1" /* Revision of Synthetic Substitute in Lower Muscle, Percutaneous Endoscopic Approach */
"0KWY4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Muscle, Percutaneous Endoscopic Approach */
"0KWY4MZ" = "1" /* Revision of Stimulator Lead in Lower Muscle, Percutaneous Endoscopic Approach */
"0KX00Z0" = "1" /* Transfer Head Muscle with Skin, Open Approach */
"0KX00Z1" = "1" /* Transfer Head Muscle with Subcutaneous Tissue, Open Approach */
"0KX00Z2" = "1" /* Transfer Head Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KX00ZZ" = "1" /* Transfer Head Muscle, Open Approach */
"0KX04Z0" = "1" /* Transfer Head Muscle with Skin, Percutaneous Endoscopic Approach */
"0KX04Z1" = "1" /* Transfer Head Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KX04Z2" = "1" /* Transfer Head Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KX04ZZ" = "1" /* Transfer Head Muscle, Percutaneous Endoscopic Approach */
"0KX10Z0" = "1" /* Transfer Facial Muscle with Skin, Open Approach */
"0KX10Z1" = "1" /* Transfer Facial Muscle with Subcutaneous Tissue, Open Approach */
"0KX10Z2" = "1" /* Transfer Facial Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KX10ZZ" = "1" /* Transfer Facial Muscle, Open Approach */
"0KX14Z0" = "1" /* Transfer Facial Muscle with Skin, Percutaneous Endoscopic Approach */
"0KX14Z1" = "1" /* Transfer Facial Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KX14Z2" = "1" /* Transfer Facial Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KX14ZZ" = "1" /* Transfer Facial Muscle, Percutaneous Endoscopic Approach */
"0KX20Z0" = "1" /* Transfer Right Neck Muscle with Skin, Open Approach */
"0KX20Z1" = "1" /* Transfer Right Neck Muscle with Subcutaneous Tissue, Open Approach */
"0KX20Z2" = "1" /* Transfer Right Neck Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KX20ZZ" = "1" /* Transfer Right Neck Muscle, Open Approach */
"0KX24Z0" = "1" /* Transfer Right Neck Muscle with Skin, Percutaneous Endoscopic Approach */
"0KX24Z1" = "1" /* Transfer Right Neck Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KX24Z2" = "1" /* Transfer Right Neck Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KX24ZZ" = "1" /* Transfer Right Neck Muscle, Percutaneous Endoscopic Approach */
"0KX30Z0" = "1" /* Transfer Left Neck Muscle with Skin, Open Approach */
"0KX30Z1" = "1" /* Transfer Left Neck Muscle with Subcutaneous Tissue, Open Approach */
"0KX30Z2" = "1" /* Transfer Left Neck Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KX30ZZ" = "1" /* Transfer Left Neck Muscle, Open Approach */
"0KX34Z0" = "1" /* Transfer Left Neck Muscle with Skin, Percutaneous Endoscopic Approach */
"0KX34Z1" = "1" /* Transfer Left Neck Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KX34Z2" = "1" /* Transfer Left Neck Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KX34ZZ" = "1" /* Transfer Left Neck Muscle, Percutaneous Endoscopic Approach */
"0KX40Z0" = "1" /* Transfer Tongue, Palate, Pharynx Muscle with Skin, Open Approach */
"0KX40Z1" = "1" /* Transfer Tongue, Palate, Pharynx Muscle with Subcutaneous Tissue, Open Approach */
"0KX40Z2" = "1" /* Transfer Tongue, Palate, Pharynx Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KX40ZZ" = "1" /* Transfer Tongue, Palate, Pharynx Muscle, Open Approach */
"0KX44Z0" = "1" /* Transfer Tongue, Palate, Pharynx Muscle with Skin, Percutaneous Endoscopic Approach */
"0KX44Z1" = "1" /* Transfer Tongue, Palate, Pharynx Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KX44Z2" = "1" /* Transfer Tongue, Palate, Pharynx Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KX44ZZ" = "1" /* Transfer Tongue, Palate, Pharynx Muscle, Percutaneous Endoscopic Approach */
"0KX50Z0" = "1" /* Transfer Right Shoulder Muscle with Skin, Open Approach */
"0KX50Z1" = "1" /* Transfer Right Shoulder Muscle with Subcutaneous Tissue, Open Approach */
"0KX50Z2" = "1" /* Transfer Right Shoulder Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KX50ZZ" = "1" /* Transfer Right Shoulder Muscle, Open Approach */
"0KX54Z0" = "1" /* Transfer Right Shoulder Muscle with Skin, Percutaneous Endoscopic Approach */
"0KX54Z1" = "1" /* Transfer Right Shoulder Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KX54Z2" = "1" /* Transfer Right Shoulder Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KX54ZZ" = "1" /* Transfer Right Shoulder Muscle, Percutaneous Endoscopic Approach */
"0KX60Z0" = "1" /* Transfer Left Shoulder Muscle with Skin, Open Approach */
"0KX60Z1" = "1" /* Transfer Left Shoulder Muscle with Subcutaneous Tissue, Open Approach */
"0KX60Z2" = "1" /* Transfer Left Shoulder Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KX60ZZ" = "1" /* Transfer Left Shoulder Muscle, Open Approach */
"0KX64Z0" = "1" /* Transfer Left Shoulder Muscle with Skin, Percutaneous Endoscopic Approach */
"0KX64Z1" = "1" /* Transfer Left Shoulder Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KX64Z2" = "1" /* Transfer Left Shoulder Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KX64ZZ" = "1" /* Transfer Left Shoulder Muscle, Percutaneous Endoscopic Approach */
"0KX70Z0" = "1" /* Transfer Right Upper Arm Muscle with Skin, Open Approach */
"0KX70Z1" = "1" /* Transfer Right Upper Arm Muscle with Subcutaneous Tissue, Open Approach */
"0KX70Z2" = "1" /* Transfer Right Upper Arm Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KX70ZZ" = "1" /* Transfer Right Upper Arm Muscle, Open Approach */
"0KX74Z0" = "1" /* Transfer Right Upper Arm Muscle with Skin, Percutaneous Endoscopic Approach */
"0KX74Z1" = "1" /* Transfer Right Upper Arm Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KX74Z2" = "1" /* Transfer Right Upper Arm Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KX74ZZ" = "1" /* Transfer Right Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0KX80Z0" = "1" /* Transfer Left Upper Arm Muscle with Skin, Open Approach */
"0KX80Z1" = "1" /* Transfer Left Upper Arm Muscle with Subcutaneous Tissue, Open Approach */
"0KX80Z2" = "1" /* Transfer Left Upper Arm Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KX80ZZ" = "1" /* Transfer Left Upper Arm Muscle, Open Approach */
"0KX84Z0" = "1" /* Transfer Left Upper Arm Muscle with Skin, Percutaneous Endoscopic Approach */
"0KX84Z1" = "1" /* Transfer Left Upper Arm Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KX84Z2" = "1" /* Transfer Left Upper Arm Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KX84ZZ" = "1" /* Transfer Left Upper Arm Muscle, Percutaneous Endoscopic Approach */
"0KX90Z0" = "1" /* Transfer Right Lower Arm and Wrist Muscle with Skin, Open Approach */
"0KX90Z1" = "1" /* Transfer Right Lower Arm and Wrist Muscle with Subcutaneous Tissue, Open Approach */
"0KX90Z2" = "1" /* Transfer Right Lower Arm and Wrist Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KX90ZZ" = "1" /* Transfer Right Lower Arm and Wrist Muscle, Open Approach */
"0KX94Z0" = "1" /* Transfer Right Lower Arm and Wrist Muscle with Skin, Percutaneous Endoscopic Approach */
"0KX94Z1" = "1" /* Transfer Right Lower Arm and Wrist Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KX94Z2" = "1" /* Transfer Right Lower Arm and Wrist Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KX94ZZ" = "1" /* Transfer Right Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0KXB0Z0" = "1" /* Transfer Left Lower Arm and Wrist Muscle with Skin, Open Approach */
"0KXB0Z1" = "1" /* Transfer Left Lower Arm and Wrist Muscle with Subcutaneous Tissue, Open Approach */
"0KXB0Z2" = "1" /* Transfer Left Lower Arm and Wrist Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KXB0ZZ" = "1" /* Transfer Left Lower Arm and Wrist Muscle, Open Approach */
"0KXB4Z0" = "1" /* Transfer Left Lower Arm and Wrist Muscle with Skin, Percutaneous Endoscopic Approach */
"0KXB4Z1" = "1" /* Transfer Left Lower Arm and Wrist Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXB4Z2" = "1" /* Transfer Left Lower Arm and Wrist Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXB4ZZ" = "1" /* Transfer Left Lower Arm and Wrist Muscle, Percutaneous Endoscopic Approach */
"0KXC0Z0" = "1" /* Transfer Right Hand Muscle with Skin, Open Approach */
"0KXC0Z1" = "1" /* Transfer Right Hand Muscle with Subcutaneous Tissue, Open Approach */
"0KXC0Z2" = "1" /* Transfer Right Hand Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KXC0ZZ" = "1" /* Transfer Right Hand Muscle, Open Approach */
"0KXC4Z0" = "1" /* Transfer Right Hand Muscle with Skin, Percutaneous Endoscopic Approach */
"0KXC4Z1" = "1" /* Transfer Right Hand Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXC4Z2" = "1" /* Transfer Right Hand Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXC4ZZ" = "1" /* Transfer Right Hand Muscle, Percutaneous Endoscopic Approach */
"0KXD0Z0" = "1" /* Transfer Left Hand Muscle with Skin, Open Approach */
"0KXD0Z1" = "1" /* Transfer Left Hand Muscle with Subcutaneous Tissue, Open Approach */
"0KXD0Z2" = "1" /* Transfer Left Hand Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KXD0ZZ" = "1" /* Transfer Left Hand Muscle, Open Approach */
"0KXD4Z0" = "1" /* Transfer Left Hand Muscle with Skin, Percutaneous Endoscopic Approach */
"0KXD4Z1" = "1" /* Transfer Left Hand Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXD4Z2" = "1" /* Transfer Left Hand Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXD4ZZ" = "1" /* Transfer Left Hand Muscle, Percutaneous Endoscopic Approach */
"0KXF0Z0" = "1" /* Transfer Right Trunk Muscle with Skin, Open Approach */
"0KXF0Z1" = "1" /* Transfer Right Trunk Muscle with Subcutaneous Tissue, Open Approach */
"0KXF0Z2" = "1" /* Transfer Right Trunk Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KXF0ZZ" = "1" /* Transfer Right Trunk Muscle, Open Approach */
"0KXF4Z0" = "1" /* Transfer Right Trunk Muscle with Skin, Percutaneous Endoscopic Approach */
"0KXF4Z1" = "1" /* Transfer Right Trunk Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXF4Z2" = "1" /* Transfer Right Trunk Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXF4ZZ" = "1" /* Transfer Right Trunk Muscle, Percutaneous Endoscopic Approach */
"0KXG0Z0" = "1" /* Transfer Left Trunk Muscle with Skin, Open Approach */
"0KXG0Z1" = "1" /* Transfer Left Trunk Muscle with Subcutaneous Tissue, Open Approach */
"0KXG0Z2" = "1" /* Transfer Left Trunk Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KXG0ZZ" = "1" /* Transfer Left Trunk Muscle, Open Approach */
"0KXG4Z0" = "1" /* Transfer Left Trunk Muscle with Skin, Percutaneous Endoscopic Approach */
"0KXG4Z1" = "1" /* Transfer Left Trunk Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXG4Z2" = "1" /* Transfer Left Trunk Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXG4ZZ" = "1" /* Transfer Left Trunk Muscle, Percutaneous Endoscopic Approach */
"0KXH0Z0" = "1" /* Transfer Right Thorax Muscle with Skin, Open Approach */
"0KXH0Z1" = "1" /* Transfer Right Thorax Muscle with Subcutaneous Tissue, Open Approach */
"0KXH0Z2" = "1" /* Transfer Right Thorax Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KXH0ZZ" = "1" /* Transfer Right Thorax Muscle, Open Approach */
"0KXH4Z0" = "1" /* Transfer Right Thorax Muscle with Skin, Percutaneous Endoscopic Approach */
"0KXH4Z1" = "1" /* Transfer Right Thorax Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXH4Z2" = "1" /* Transfer Right Thorax Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXH4ZZ" = "1" /* Transfer Right Thorax Muscle, Percutaneous Endoscopic Approach */
"0KXJ0Z0" = "1" /* Transfer Left Thorax Muscle with Skin, Open Approach */
"0KXJ0Z1" = "1" /* Transfer Left Thorax Muscle with Subcutaneous Tissue, Open Approach */
"0KXJ0Z2" = "1" /* Transfer Left Thorax Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KXJ0ZZ" = "1" /* Transfer Left Thorax Muscle, Open Approach */
"0KXJ4Z0" = "1" /* Transfer Left Thorax Muscle with Skin, Percutaneous Endoscopic Approach */
"0KXJ4Z1" = "1" /* Transfer Left Thorax Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXJ4Z2" = "1" /* Transfer Left Thorax Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXJ4ZZ" = "1" /* Transfer Left Thorax Muscle, Percutaneous Endoscopic Approach */
"0KXK0Z0" = "1" /* Transfer Right Abdomen Muscle with Skin, Open Approach */
"0KXK0Z1" = "1" /* Transfer Right Abdomen Muscle with Subcutaneous Tissue, Open Approach */
"0KXK0Z2" = "1" /* Transfer Right Abdomen Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KXK0Z6" = "1" /* Transfer Right Abdomen Muscle, Transverse Rectus Abdominis Myocutaneous Flap, Open Approach */
"0KXK0ZZ" = "1" /* Transfer Right Abdomen Muscle, Open Approach */
"0KXK4Z0" = "1" /* Transfer Right Abdomen Muscle with Skin, Percutaneous Endoscopic Approach */
"0KXK4Z1" = "1" /* Transfer Right Abdomen Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXK4Z2" = "1" /* Transfer Right Abdomen Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXK4Z6" = "1" /* Transfer Right Abdomen Muscle, Transverse Rectus Abdominis Myocutaneous Flap, Percutaneous Endoscopic Approach */
"0KXK4ZZ" = "1" /* Transfer Right Abdomen Muscle, Percutaneous Endoscopic Approach */
"0KXL0Z0" = "1" /* Transfer Left Abdomen Muscle with Skin, Open Approach */
"0KXL0Z1" = "1" /* Transfer Left Abdomen Muscle with Subcutaneous Tissue, Open Approach */
"0KXL0Z2" = "1" /* Transfer Left Abdomen Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KXL0Z6" = "1" /* Transfer Left Abdomen Muscle, Transverse Rectus Abdominis Myocutaneous Flap, Open Approach */
"0KXL0ZZ" = "1" /* Transfer Left Abdomen Muscle, Open Approach */
"0KXL4Z0" = "1" /* Transfer Left Abdomen Muscle with Skin, Percutaneous Endoscopic Approach */
"0KXL4Z1" = "1" /* Transfer Left Abdomen Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXL4Z2" = "1" /* Transfer Left Abdomen Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXL4Z6" = "1" /* Transfer Left Abdomen Muscle, Transverse Rectus Abdominis Myocutaneous Flap, Percutaneous Endoscopic Approach */
"0KXL4ZZ" = "1" /* Transfer Left Abdomen Muscle, Percutaneous Endoscopic Approach */
"0KXM0Z0" = "1" /* Transfer Perineum Muscle with Skin, Open Approach */
"0KXM0Z1" = "1" /* Transfer Perineum Muscle with Subcutaneous Tissue, Open Approach */
"0KXM0Z2" = "1" /* Transfer Perineum Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KXM0ZZ" = "1" /* Transfer Perineum Muscle, Open Approach */
"0KXM4Z0" = "1" /* Transfer Perineum Muscle with Skin, Percutaneous Endoscopic Approach */
"0KXM4Z1" = "1" /* Transfer Perineum Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXM4Z2" = "1" /* Transfer Perineum Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXM4ZZ" = "1" /* Transfer Perineum Muscle, Percutaneous Endoscopic Approach */
"0KXN0Z0" = "1" /* Transfer Right Hip Muscle with Skin, Open Approach */
"0KXN0Z1" = "1" /* Transfer Right Hip Muscle with Subcutaneous Tissue, Open Approach */
"0KXN0Z2" = "1" /* Transfer Right Hip Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KXN0ZZ" = "1" /* Transfer Right Hip Muscle, Open Approach */
"0KXN4Z0" = "1" /* Transfer Right Hip Muscle with Skin, Percutaneous Endoscopic Approach */
"0KXN4Z1" = "1" /* Transfer Right Hip Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXN4Z2" = "1" /* Transfer Right Hip Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXN4ZZ" = "1" /* Transfer Right Hip Muscle, Percutaneous Endoscopic Approach */
"0KXP0Z0" = "1" /* Transfer Left Hip Muscle with Skin, Open Approach */
"0KXP0Z1" = "1" /* Transfer Left Hip Muscle with Subcutaneous Tissue, Open Approach */
"0KXP0Z2" = "1" /* Transfer Left Hip Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KXP0ZZ" = "1" /* Transfer Left Hip Muscle, Open Approach */
"0KXP4Z0" = "1" /* Transfer Left Hip Muscle with Skin, Percutaneous Endoscopic Approach */
"0KXP4Z1" = "1" /* Transfer Left Hip Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXP4Z2" = "1" /* Transfer Left Hip Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXP4ZZ" = "1" /* Transfer Left Hip Muscle, Percutaneous Endoscopic Approach */
"0KXQ0Z0" = "1" /* Transfer Right Upper Leg Muscle with Skin, Open Approach */
"0KXQ0Z1" = "1" /* Transfer Right Upper Leg Muscle with Subcutaneous Tissue, Open Approach */
"0KXQ0Z2" = "1" /* Transfer Right Upper Leg Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KXQ0ZZ" = "1" /* Transfer Right Upper Leg Muscle, Open Approach */
"0KXQ4Z0" = "1" /* Transfer Right Upper Leg Muscle with Skin, Percutaneous Endoscopic Approach */
"0KXQ4Z1" = "1" /* Transfer Right Upper Leg Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXQ4Z2" = "1" /* Transfer Right Upper Leg Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXQ4ZZ" = "1" /* Transfer Right Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0KXR0Z0" = "1" /* Transfer Left Upper Leg Muscle with Skin, Open Approach */
"0KXR0Z1" = "1" /* Transfer Left Upper Leg Muscle with Subcutaneous Tissue, Open Approach */
"0KXR0Z2" = "1" /* Transfer Left Upper Leg Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KXR0ZZ" = "1" /* Transfer Left Upper Leg Muscle, Open Approach */
"0KXR4Z0" = "1" /* Transfer Left Upper Leg Muscle with Skin, Percutaneous Endoscopic Approach */
"0KXR4Z1" = "1" /* Transfer Left Upper Leg Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXR4Z2" = "1" /* Transfer Left Upper Leg Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXR4ZZ" = "1" /* Transfer Left Upper Leg Muscle, Percutaneous Endoscopic Approach */
"0KXS0Z0" = "1" /* Transfer Right Lower Leg Muscle with Skin, Open Approach */
"0KXS0Z1" = "1" /* Transfer Right Lower Leg Muscle with Subcutaneous Tissue, Open Approach */
"0KXS0Z2" = "1" /* Transfer Right Lower Leg Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KXS0ZZ" = "1" /* Transfer Right Lower Leg Muscle, Open Approach */
"0KXS4Z0" = "1" /* Transfer Right Lower Leg Muscle with Skin, Percutaneous Endoscopic Approach */
"0KXS4Z1" = "1" /* Transfer Right Lower Leg Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXS4Z2" = "1" /* Transfer Right Lower Leg Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXS4ZZ" = "1" /* Transfer Right Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0KXT0Z0" = "1" /* Transfer Left Lower Leg Muscle with Skin, Open Approach */
"0KXT0Z1" = "1" /* Transfer Left Lower Leg Muscle with Subcutaneous Tissue, Open Approach */
"0KXT0Z2" = "1" /* Transfer Left Lower Leg Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KXT0ZZ" = "1" /* Transfer Left Lower Leg Muscle, Open Approach */
"0KXT4Z0" = "1" /* Transfer Left Lower Leg Muscle with Skin, Percutaneous Endoscopic Approach */
"0KXT4Z1" = "1" /* Transfer Left Lower Leg Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXT4Z2" = "1" /* Transfer Left Lower Leg Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXT4ZZ" = "1" /* Transfer Left Lower Leg Muscle, Percutaneous Endoscopic Approach */
"0KXV0Z0" = "1" /* Transfer Right Foot Muscle with Skin, Open Approach */
"0KXV0Z1" = "1" /* Transfer Right Foot Muscle with Subcutaneous Tissue, Open Approach */
"0KXV0Z2" = "1" /* Transfer Right Foot Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KXV0ZZ" = "1" /* Transfer Right Foot Muscle, Open Approach */
"0KXV4Z0" = "1" /* Transfer Right Foot Muscle with Skin, Percutaneous Endoscopic Approach */
"0KXV4Z1" = "1" /* Transfer Right Foot Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXV4Z2" = "1" /* Transfer Right Foot Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXV4ZZ" = "1" /* Transfer Right Foot Muscle, Percutaneous Endoscopic Approach */
"0KXW0Z0" = "1" /* Transfer Left Foot Muscle with Skin, Open Approach */
"0KXW0Z1" = "1" /* Transfer Left Foot Muscle with Subcutaneous Tissue, Open Approach */
"0KXW0Z2" = "1" /* Transfer Left Foot Muscle with Skin and Subcutaneous Tissue, Open Approach */
"0KXW0ZZ" = "1" /* Transfer Left Foot Muscle, Open Approach */
"0KXW4Z0" = "1" /* Transfer Left Foot Muscle with Skin, Percutaneous Endoscopic Approach */
"0KXW4Z1" = "1" /* Transfer Left Foot Muscle with Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXW4Z2" = "1" /* Transfer Left Foot Muscle with Skin and Subcutaneous Tissue, Percutaneous Endoscopic Approach */
"0KXW4ZZ" = "1" /* Transfer Left Foot Muscle, Percutaneous Endoscopic Approach */
"0L500ZZ" = "1" /* Destruction of Head and Neck Tendon, Open Approach */
"0L503ZZ" = "1" /* Destruction of Head and Neck Tendon, Percutaneous Approach */
"0L504ZZ" = "1" /* Destruction of Head and Neck Tendon, Percutaneous Endoscopic Approach */
"0L510ZZ" = "1" /* Destruction of Right Shoulder Tendon, Open Approach */
"0L513ZZ" = "1" /* Destruction of Right Shoulder Tendon, Percutaneous Approach */
"0L514ZZ" = "1" /* Destruction of Right Shoulder Tendon, Percutaneous Endoscopic Approach */
"0L520ZZ" = "1" /* Destruction of Left Shoulder Tendon, Open Approach */
"0L523ZZ" = "1" /* Destruction of Left Shoulder Tendon, Percutaneous Approach */
"0L524ZZ" = "1" /* Destruction of Left Shoulder Tendon, Percutaneous Endoscopic Approach */
"0L530ZZ" = "1" /* Destruction of Right Upper Arm Tendon, Open Approach */
"0L533ZZ" = "1" /* Destruction of Right Upper Arm Tendon, Percutaneous Approach */
"0L534ZZ" = "1" /* Destruction of Right Upper Arm Tendon, Percutaneous Endoscopic Approach */
"0L540ZZ" = "1" /* Destruction of Left Upper Arm Tendon, Open Approach */
"0L543ZZ" = "1" /* Destruction of Left Upper Arm Tendon, Percutaneous Approach */
"0L544ZZ" = "1" /* Destruction of Left Upper Arm Tendon, Percutaneous Endoscopic Approach */
"0L550ZZ" = "1" /* Destruction of Right Lower Arm and Wrist Tendon, Open Approach */
"0L553ZZ" = "1" /* Destruction of Right Lower Arm and Wrist Tendon, Percutaneous Approach */
"0L554ZZ" = "1" /* Destruction of Right Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach */
"0L560ZZ" = "1" /* Destruction of Left Lower Arm and Wrist Tendon, Open Approach */
"0L563ZZ" = "1" /* Destruction of Left Lower Arm and Wrist Tendon, Percutaneous Approach */
"0L564ZZ" = "1" /* Destruction of Left Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach */
"0L570ZZ" = "1" /* Destruction of Right Hand Tendon, Open Approach */
"0L573ZZ" = "1" /* Destruction of Right Hand Tendon, Percutaneous Approach */
"0L574ZZ" = "1" /* Destruction of Right Hand Tendon, Percutaneous Endoscopic Approach */
"0L580ZZ" = "1" /* Destruction of Left Hand Tendon, Open Approach */
"0L583ZZ" = "1" /* Destruction of Left Hand Tendon, Percutaneous Approach */
"0L584ZZ" = "1" /* Destruction of Left Hand Tendon, Percutaneous Endoscopic Approach */
"0L590ZZ" = "1" /* Destruction of Right Trunk Tendon, Open Approach */
"0L593ZZ" = "1" /* Destruction of Right Trunk Tendon, Percutaneous Approach */
"0L594ZZ" = "1" /* Destruction of Right Trunk Tendon, Percutaneous Endoscopic Approach */
"0L5B0ZZ" = "1" /* Destruction of Left Trunk Tendon, Open Approach */
"0L5B3ZZ" = "1" /* Destruction of Left Trunk Tendon, Percutaneous Approach */
"0L5B4ZZ" = "1" /* Destruction of Left Trunk Tendon, Percutaneous Endoscopic Approach */
"0L5C0ZZ" = "1" /* Destruction of Right Thorax Tendon, Open Approach */
"0L5C3ZZ" = "1" /* Destruction of Right Thorax Tendon, Percutaneous Approach */
"0L5C4ZZ" = "1" /* Destruction of Right Thorax Tendon, Percutaneous Endoscopic Approach */
"0L5D0ZZ" = "1" /* Destruction of Left Thorax Tendon, Open Approach */
"0L5D3ZZ" = "1" /* Destruction of Left Thorax Tendon, Percutaneous Approach */
"0L5D4ZZ" = "1" /* Destruction of Left Thorax Tendon, Percutaneous Endoscopic Approach */
"0L5F0ZZ" = "1" /* Destruction of Right Abdomen Tendon, Open Approach */
"0L5F3ZZ" = "1" /* Destruction of Right Abdomen Tendon, Percutaneous Approach */
"0L5F4ZZ" = "1" /* Destruction of Right Abdomen Tendon, Percutaneous Endoscopic Approach */
"0L5G0ZZ" = "1" /* Destruction of Left Abdomen Tendon, Open Approach */
"0L5G3ZZ" = "1" /* Destruction of Left Abdomen Tendon, Percutaneous Approach */
"0L5G4ZZ" = "1" /* Destruction of Left Abdomen Tendon, Percutaneous Endoscopic Approach */
"0L5H0ZZ" = "1" /* Destruction of Perineum Tendon, Open Approach */
"0L5H3ZZ" = "1" /* Destruction of Perineum Tendon, Percutaneous Approach */
"0L5H4ZZ" = "1" /* Destruction of Perineum Tendon, Percutaneous Endoscopic Approach */
"0L5J0ZZ" = "1" /* Destruction of Right Hip Tendon, Open Approach */
"0L5J3ZZ" = "1" /* Destruction of Right Hip Tendon, Percutaneous Approach */
"0L5J4ZZ" = "1" /* Destruction of Right Hip Tendon, Percutaneous Endoscopic Approach */
"0L5K0ZZ" = "1" /* Destruction of Left Hip Tendon, Open Approach */
"0L5K3ZZ" = "1" /* Destruction of Left Hip Tendon, Percutaneous Approach */
"0L5K4ZZ" = "1" /* Destruction of Left Hip Tendon, Percutaneous Endoscopic Approach */
"0L5L0ZZ" = "1" /* Destruction of Right Upper Leg Tendon, Open Approach */
"0L5L3ZZ" = "1" /* Destruction of Right Upper Leg Tendon, Percutaneous Approach */
"0L5L4ZZ" = "1" /* Destruction of Right Upper Leg Tendon, Percutaneous Endoscopic Approach */
"0L5M0ZZ" = "1" /* Destruction of Left Upper Leg Tendon, Open Approach */
"0L5M3ZZ" = "1" /* Destruction of Left Upper Leg Tendon, Percutaneous Approach */
"0L5M4ZZ" = "1" /* Destruction of Left Upper Leg Tendon, Percutaneous Endoscopic Approach */
"0L5N0ZZ" = "1" /* Destruction of Right Lower Leg Tendon, Open Approach */
"0L5N3ZZ" = "1" /* Destruction of Right Lower Leg Tendon, Percutaneous Approach */
"0L5N4ZZ" = "1" /* Destruction of Right Lower Leg Tendon, Percutaneous Endoscopic Approach */
"0L5P0ZZ" = "1" /* Destruction of Left Lower Leg Tendon, Open Approach */
"0L5P3ZZ" = "1" /* Destruction of Left Lower Leg Tendon, Percutaneous Approach */
"0L5P4ZZ" = "1" /* Destruction of Left Lower Leg Tendon, Percutaneous Endoscopic Approach */
"0L5Q0ZZ" = "1" /* Destruction of Right Knee Tendon, Open Approach */
"0L5Q3ZZ" = "1" /* Destruction of Right Knee Tendon, Percutaneous Approach */
"0L5Q4ZZ" = "1" /* Destruction of Right Knee Tendon, Percutaneous Endoscopic Approach */
"0L5R0ZZ" = "1" /* Destruction of Left Knee Tendon, Open Approach */
"0L5R3ZZ" = "1" /* Destruction of Left Knee Tendon, Percutaneous Approach */
"0L5R4ZZ" = "1" /* Destruction of Left Knee Tendon, Percutaneous Endoscopic Approach */
"0L5S0ZZ" = "1" /* Destruction of Right Ankle Tendon, Open Approach */
"0L5S3ZZ" = "1" /* Destruction of Right Ankle Tendon, Percutaneous Approach */
"0L5S4ZZ" = "1" /* Destruction of Right Ankle Tendon, Percutaneous Endoscopic Approach */
"0L5T0ZZ" = "1" /* Destruction of Left Ankle Tendon, Open Approach */
"0L5T3ZZ" = "1" /* Destruction of Left Ankle Tendon, Percutaneous Approach */
"0L5T4ZZ" = "1" /* Destruction of Left Ankle Tendon, Percutaneous Endoscopic Approach */
"0L5V0ZZ" = "1" /* Destruction of Right Foot Tendon, Open Approach */
"0L5V3ZZ" = "1" /* Destruction of Right Foot Tendon, Percutaneous Approach */
"0L5V4ZZ" = "1" /* Destruction of Right Foot Tendon, Percutaneous Endoscopic Approach */
"0L5W0ZZ" = "1" /* Destruction of Left Foot Tendon, Open Approach */
"0L5W3ZZ" = "1" /* Destruction of Left Foot Tendon, Percutaneous Approach */
"0L5W4ZZ" = "1" /* Destruction of Left Foot Tendon, Percutaneous Endoscopic Approach */
"0L800ZZ" = "1" /* Division of Head and Neck Tendon, Open Approach */
"0L803ZZ" = "1" /* Division of Head and Neck Tendon, Percutaneous Approach */
"0L804ZZ" = "1" /* Division of Head and Neck Tendon, Percutaneous Endoscopic Approach */
"0L810ZZ" = "1" /* Division of Right Shoulder Tendon, Open Approach */
"0L813ZZ" = "1" /* Division of Right Shoulder Tendon, Percutaneous Approach */
"0L814ZZ" = "1" /* Division of Right Shoulder Tendon, Percutaneous Endoscopic Approach */
"0L820ZZ" = "1" /* Division of Left Shoulder Tendon, Open Approach */
"0L823ZZ" = "1" /* Division of Left Shoulder Tendon, Percutaneous Approach */
"0L824ZZ" = "1" /* Division of Left Shoulder Tendon, Percutaneous Endoscopic Approach */
"0L830ZZ" = "1" /* Division of Right Upper Arm Tendon, Open Approach */
"0L833ZZ" = "1" /* Division of Right Upper Arm Tendon, Percutaneous Approach */
"0L834ZZ" = "1" /* Division of Right Upper Arm Tendon, Percutaneous Endoscopic Approach */
"0L840ZZ" = "1" /* Division of Left Upper Arm Tendon, Open Approach */
"0L843ZZ" = "1" /* Division of Left Upper Arm Tendon, Percutaneous Approach */
"0L844ZZ" = "1" /* Division of Left Upper Arm Tendon, Percutaneous Endoscopic Approach */
"0L850ZZ" = "1" /* Division of Right Lower Arm and Wrist Tendon, Open Approach */
"0L853ZZ" = "1" /* Division of Right Lower Arm and Wrist Tendon, Percutaneous Approach */
"0L854ZZ" = "1" /* Division of Right Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach */
"0L860ZZ" = "1" /* Division of Left Lower Arm and Wrist Tendon, Open Approach */
"0L863ZZ" = "1" /* Division of Left Lower Arm and Wrist Tendon, Percutaneous Approach */
"0L864ZZ" = "1" /* Division of Left Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach */
"0L870ZZ" = "1" /* Division of Right Hand Tendon, Open Approach */
"0L873ZZ" = "1" /* Division of Right Hand Tendon, Percutaneous Approach */
"0L874ZZ" = "1" /* Division of Right Hand Tendon, Percutaneous Endoscopic Approach */
"0L880ZZ" = "1" /* Division of Left Hand Tendon, Open Approach */
"0L883ZZ" = "1" /* Division of Left Hand Tendon, Percutaneous Approach */
"0L884ZZ" = "1" /* Division of Left Hand Tendon, Percutaneous Endoscopic Approach */
"0L890ZZ" = "1" /* Division of Right Trunk Tendon, Open Approach */
"0L893ZZ" = "1" /* Division of Right Trunk Tendon, Percutaneous Approach */
"0L894ZZ" = "1" /* Division of Right Trunk Tendon, Percutaneous Endoscopic Approach */
"0L8B0ZZ" = "1" /* Division of Left Trunk Tendon, Open Approach */
"0L8B3ZZ" = "1" /* Division of Left Trunk Tendon, Percutaneous Approach */
"0L8B4ZZ" = "1" /* Division of Left Trunk Tendon, Percutaneous Endoscopic Approach */
"0L8C0ZZ" = "1" /* Division of Right Thorax Tendon, Open Approach */
"0L8C3ZZ" = "1" /* Division of Right Thorax Tendon, Percutaneous Approach */
"0L8C4ZZ" = "1" /* Division of Right Thorax Tendon, Percutaneous Endoscopic Approach */
"0L8D0ZZ" = "1" /* Division of Left Thorax Tendon, Open Approach */
"0L8D3ZZ" = "1" /* Division of Left Thorax Tendon, Percutaneous Approach */
"0L8D4ZZ" = "1" /* Division of Left Thorax Tendon, Percutaneous Endoscopic Approach */
"0L8F0ZZ" = "1" /* Division of Right Abdomen Tendon, Open Approach */
"0L8F3ZZ" = "1" /* Division of Right Abdomen Tendon, Percutaneous Approach */
"0L8F4ZZ" = "1" /* Division of Right Abdomen Tendon, Percutaneous Endoscopic Approach */
"0L8G0ZZ" = "1" /* Division of Left Abdomen Tendon, Open Approach */
"0L8G3ZZ" = "1" /* Division of Left Abdomen Tendon, Percutaneous Approach */
"0L8G4ZZ" = "1" /* Division of Left Abdomen Tendon, Percutaneous Endoscopic Approach */
"0L8H0ZZ" = "1" /* Division of Perineum Tendon, Open Approach */
"0L8H3ZZ" = "1" /* Division of Perineum Tendon, Percutaneous Approach */
"0L8H4ZZ" = "1" /* Division of Perineum Tendon, Percutaneous Endoscopic Approach */
"0L8J0ZZ" = "1" /* Division of Right Hip Tendon, Open Approach */
"0L8J3ZZ" = "1" /* Division of Right Hip Tendon, Percutaneous Approach */
"0L8J4ZZ" = "1" /* Division of Right Hip Tendon, Percutaneous Endoscopic Approach */
"0L8K0ZZ" = "1" /* Division of Left Hip Tendon, Open Approach */
"0L8K3ZZ" = "1" /* Division of Left Hip Tendon, Percutaneous Approach */
"0L8K4ZZ" = "1" /* Division of Left Hip Tendon, Percutaneous Endoscopic Approach */
"0L8L0ZZ" = "1" /* Division of Right Upper Leg Tendon, Open Approach */
"0L8L3ZZ" = "1" /* Division of Right Upper Leg Tendon, Percutaneous Approach */
"0L8L4ZZ" = "1" /* Division of Right Upper Leg Tendon, Percutaneous Endoscopic Approach */
"0L8M0ZZ" = "1" /* Division of Left Upper Leg Tendon, Open Approach */
"0L8M3ZZ" = "1" /* Division of Left Upper Leg Tendon, Percutaneous Approach */
"0L8M4ZZ" = "1" /* Division of Left Upper Leg Tendon, Percutaneous Endoscopic Approach */
"0L8N0ZZ" = "1" /* Division of Right Lower Leg Tendon, Open Approach */
"0L8N3ZZ" = "1" /* Division of Right Lower Leg Tendon, Percutaneous Approach */
"0L8N4ZZ" = "1" /* Division of Right Lower Leg Tendon, Percutaneous Endoscopic Approach */
"0L8P0ZZ" = "1" /* Division of Left Lower Leg Tendon, Open Approach */
"0L8P3ZZ" = "1" /* Division of Left Lower Leg Tendon, Percutaneous Approach */
"0L8P4ZZ" = "1" /* Division of Left Lower Leg Tendon, Percutaneous Endoscopic Approach */
"0L8Q0ZZ" = "1" /* Division of Right Knee Tendon, Open Approach */
"0L8Q3ZZ" = "1" /* Division of Right Knee Tendon, Percutaneous Approach */
"0L8Q4ZZ" = "1" /* Division of Right Knee Tendon, Percutaneous Endoscopic Approach */
"0L8R0ZZ" = "1" /* Division of Left Knee Tendon, Open Approach */
"0L8R3ZZ" = "1" /* Division of Left Knee Tendon, Percutaneous Approach */
"0L8R4ZZ" = "1" /* Division of Left Knee Tendon, Percutaneous Endoscopic Approach */
"0L8S0ZZ" = "1" /* Division of Right Ankle Tendon, Open Approach */
"0L8S3ZZ" = "1" /* Division of Right Ankle Tendon, Percutaneous Approach */
"0L8S4ZZ" = "1" /* Division of Right Ankle Tendon, Percutaneous Endoscopic Approach */
"0L8T0ZZ" = "1" /* Division of Left Ankle Tendon, Open Approach */
"0L8T3ZZ" = "1" /* Division of Left Ankle Tendon, Percutaneous Approach */
"0L8T4ZZ" = "1" /* Division of Left Ankle Tendon, Percutaneous Endoscopic Approach */
"0L8V0ZZ" = "1" /* Division of Right Foot Tendon, Open Approach */
"0L8V3ZZ" = "1" /* Division of Right Foot Tendon, Percutaneous Approach */
"0L8V4ZZ" = "1" /* Division of Right Foot Tendon, Percutaneous Endoscopic Approach */
"0L8W0ZZ" = "1" /* Division of Left Foot Tendon, Open Approach */
"0L8W3ZZ" = "1" /* Division of Left Foot Tendon, Percutaneous Approach */
"0L8W4ZZ" = "1" /* Division of Left Foot Tendon, Percutaneous Endoscopic Approach */
"0L9000Z" = "1" /* Drainage of Head and Neck Tendon with Drainage Device, Open Approach */
"0L900ZX" = "1" /* Drainage of Head and Neck Tendon, Open Approach, Diagnostic */
"0L900ZZ" = "1" /* Drainage of Head and Neck Tendon, Open Approach */
"0L9040Z" = "1" /* Drainage of Head and Neck Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L904ZX" = "1" /* Drainage of Head and Neck Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L904ZZ" = "1" /* Drainage of Head and Neck Tendon, Percutaneous Endoscopic Approach */
"0L9100Z" = "1" /* Drainage of Right Shoulder Tendon with Drainage Device, Open Approach */
"0L910ZX" = "1" /* Drainage of Right Shoulder Tendon, Open Approach, Diagnostic */
"0L910ZZ" = "1" /* Drainage of Right Shoulder Tendon, Open Approach */
"0L9140Z" = "1" /* Drainage of Right Shoulder Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L914ZX" = "1" /* Drainage of Right Shoulder Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L914ZZ" = "1" /* Drainage of Right Shoulder Tendon, Percutaneous Endoscopic Approach */
"0L9200Z" = "1" /* Drainage of Left Shoulder Tendon with Drainage Device, Open Approach */
"0L920ZX" = "1" /* Drainage of Left Shoulder Tendon, Open Approach, Diagnostic */
"0L920ZZ" = "1" /* Drainage of Left Shoulder Tendon, Open Approach */
"0L9240Z" = "1" /* Drainage of Left Shoulder Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L924ZX" = "1" /* Drainage of Left Shoulder Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L924ZZ" = "1" /* Drainage of Left Shoulder Tendon, Percutaneous Endoscopic Approach */
"0L9300Z" = "1" /* Drainage of Right Upper Arm Tendon with Drainage Device, Open Approach */
"0L930ZX" = "1" /* Drainage of Right Upper Arm Tendon, Open Approach, Diagnostic */
"0L930ZZ" = "1" /* Drainage of Right Upper Arm Tendon, Open Approach */
"0L9340Z" = "1" /* Drainage of Right Upper Arm Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L934ZX" = "1" /* Drainage of Right Upper Arm Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L934ZZ" = "1" /* Drainage of Right Upper Arm Tendon, Percutaneous Endoscopic Approach */
"0L9400Z" = "1" /* Drainage of Left Upper Arm Tendon with Drainage Device, Open Approach */
"0L940ZX" = "1" /* Drainage of Left Upper Arm Tendon, Open Approach, Diagnostic */
"0L940ZZ" = "1" /* Drainage of Left Upper Arm Tendon, Open Approach */
"0L9440Z" = "1" /* Drainage of Left Upper Arm Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L944ZX" = "1" /* Drainage of Left Upper Arm Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L944ZZ" = "1" /* Drainage of Left Upper Arm Tendon, Percutaneous Endoscopic Approach */
"0L9500Z" = "1" /* Drainage of Right Lower Arm and Wrist Tendon with Drainage Device, Open Approach */
"0L950ZX" = "1" /* Drainage of Right Lower Arm and Wrist Tendon, Open Approach, Diagnostic */
"0L950ZZ" = "1" /* Drainage of Right Lower Arm and Wrist Tendon, Open Approach */
"0L9540Z" = "1" /* Drainage of Right Lower Arm and Wrist Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L954ZX" = "1" /* Drainage of Right Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L954ZZ" = "1" /* Drainage of Right Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach */
"0L9600Z" = "1" /* Drainage of Left Lower Arm and Wrist Tendon with Drainage Device, Open Approach */
"0L960ZX" = "1" /* Drainage of Left Lower Arm and Wrist Tendon, Open Approach, Diagnostic */
"0L960ZZ" = "1" /* Drainage of Left Lower Arm and Wrist Tendon, Open Approach */
"0L9640Z" = "1" /* Drainage of Left Lower Arm and Wrist Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L964ZX" = "1" /* Drainage of Left Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L964ZZ" = "1" /* Drainage of Left Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach */
"0L9700Z" = "1" /* Drainage of Right Hand Tendon with Drainage Device, Open Approach */
"0L970ZX" = "1" /* Drainage of Right Hand Tendon, Open Approach, Diagnostic */
"0L970ZZ" = "1" /* Drainage of Right Hand Tendon, Open Approach */
"0L9740Z" = "1" /* Drainage of Right Hand Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L974ZX" = "1" /* Drainage of Right Hand Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L9800Z" = "1" /* Drainage of Left Hand Tendon with Drainage Device, Open Approach */
"0L980ZX" = "1" /* Drainage of Left Hand Tendon, Open Approach, Diagnostic */
"0L980ZZ" = "1" /* Drainage of Left Hand Tendon, Open Approach */
"0L9840Z" = "1" /* Drainage of Left Hand Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L984ZX" = "1" /* Drainage of Left Hand Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L9900Z" = "1" /* Drainage of Right Trunk Tendon with Drainage Device, Open Approach */
"0L990ZX" = "1" /* Drainage of Right Trunk Tendon, Open Approach, Diagnostic */
"0L990ZZ" = "1" /* Drainage of Right Trunk Tendon, Open Approach */
"0L9940Z" = "1" /* Drainage of Right Trunk Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L994ZX" = "1" /* Drainage of Right Trunk Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L994ZZ" = "1" /* Drainage of Right Trunk Tendon, Percutaneous Endoscopic Approach */
"0L9B00Z" = "1" /* Drainage of Left Trunk Tendon with Drainage Device, Open Approach */
"0L9B0ZX" = "1" /* Drainage of Left Trunk Tendon, Open Approach, Diagnostic */
"0L9B0ZZ" = "1" /* Drainage of Left Trunk Tendon, Open Approach */
"0L9B40Z" = "1" /* Drainage of Left Trunk Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L9B4ZX" = "1" /* Drainage of Left Trunk Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L9B4ZZ" = "1" /* Drainage of Left Trunk Tendon, Percutaneous Endoscopic Approach */
"0L9C00Z" = "1" /* Drainage of Right Thorax Tendon with Drainage Device, Open Approach */
"0L9C0ZX" = "1" /* Drainage of Right Thorax Tendon, Open Approach, Diagnostic */
"0L9C0ZZ" = "1" /* Drainage of Right Thorax Tendon, Open Approach */
"0L9C40Z" = "1" /* Drainage of Right Thorax Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L9C4ZX" = "1" /* Drainage of Right Thorax Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L9C4ZZ" = "1" /* Drainage of Right Thorax Tendon, Percutaneous Endoscopic Approach */
"0L9D00Z" = "1" /* Drainage of Left Thorax Tendon with Drainage Device, Open Approach */
"0L9D0ZX" = "1" /* Drainage of Left Thorax Tendon, Open Approach, Diagnostic */
"0L9D0ZZ" = "1" /* Drainage of Left Thorax Tendon, Open Approach */
"0L9D40Z" = "1" /* Drainage of Left Thorax Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L9D4ZX" = "1" /* Drainage of Left Thorax Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L9D4ZZ" = "1" /* Drainage of Left Thorax Tendon, Percutaneous Endoscopic Approach */
"0L9F00Z" = "1" /* Drainage of Right Abdomen Tendon with Drainage Device, Open Approach */
"0L9F0ZX" = "1" /* Drainage of Right Abdomen Tendon, Open Approach, Diagnostic */
"0L9F0ZZ" = "1" /* Drainage of Right Abdomen Tendon, Open Approach */
"0L9F40Z" = "1" /* Drainage of Right Abdomen Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L9F4ZX" = "1" /* Drainage of Right Abdomen Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L9F4ZZ" = "1" /* Drainage of Right Abdomen Tendon, Percutaneous Endoscopic Approach */
"0L9G00Z" = "1" /* Drainage of Left Abdomen Tendon with Drainage Device, Open Approach */
"0L9G0ZX" = "1" /* Drainage of Left Abdomen Tendon, Open Approach, Diagnostic */
"0L9G0ZZ" = "1" /* Drainage of Left Abdomen Tendon, Open Approach */
"0L9G40Z" = "1" /* Drainage of Left Abdomen Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L9G4ZX" = "1" /* Drainage of Left Abdomen Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L9G4ZZ" = "1" /* Drainage of Left Abdomen Tendon, Percutaneous Endoscopic Approach */
"0L9H00Z" = "1" /* Drainage of Perineum Tendon with Drainage Device, Open Approach */
"0L9H0ZX" = "1" /* Drainage of Perineum Tendon, Open Approach, Diagnostic */
"0L9H0ZZ" = "1" /* Drainage of Perineum Tendon, Open Approach */
"0L9H40Z" = "1" /* Drainage of Perineum Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L9H4ZX" = "1" /* Drainage of Perineum Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L9H4ZZ" = "1" /* Drainage of Perineum Tendon, Percutaneous Endoscopic Approach */
"0L9J00Z" = "1" /* Drainage of Right Hip Tendon with Drainage Device, Open Approach */
"0L9J0ZX" = "1" /* Drainage of Right Hip Tendon, Open Approach, Diagnostic */
"0L9J0ZZ" = "1" /* Drainage of Right Hip Tendon, Open Approach */
"0L9J40Z" = "1" /* Drainage of Right Hip Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L9J4ZX" = "1" /* Drainage of Right Hip Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L9J4ZZ" = "1" /* Drainage of Right Hip Tendon, Percutaneous Endoscopic Approach */
"0L9K00Z" = "1" /* Drainage of Left Hip Tendon with Drainage Device, Open Approach */
"0L9K0ZX" = "1" /* Drainage of Left Hip Tendon, Open Approach, Diagnostic */
"0L9K0ZZ" = "1" /* Drainage of Left Hip Tendon, Open Approach */
"0L9K40Z" = "1" /* Drainage of Left Hip Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L9K4ZX" = "1" /* Drainage of Left Hip Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L9K4ZZ" = "1" /* Drainage of Left Hip Tendon, Percutaneous Endoscopic Approach */
"0L9L00Z" = "1" /* Drainage of Right Upper Leg Tendon with Drainage Device, Open Approach */
"0L9L0ZX" = "1" /* Drainage of Right Upper Leg Tendon, Open Approach, Diagnostic */
"0L9L0ZZ" = "1" /* Drainage of Right Upper Leg Tendon, Open Approach */
"0L9L40Z" = "1" /* Drainage of Right Upper Leg Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L9L4ZX" = "1" /* Drainage of Right Upper Leg Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L9L4ZZ" = "1" /* Drainage of Right Upper Leg Tendon, Percutaneous Endoscopic Approach */
"0L9M00Z" = "1" /* Drainage of Left Upper Leg Tendon with Drainage Device, Open Approach */
"0L9M0ZX" = "1" /* Drainage of Left Upper Leg Tendon, Open Approach, Diagnostic */
"0L9M0ZZ" = "1" /* Drainage of Left Upper Leg Tendon, Open Approach */
"0L9M40Z" = "1" /* Drainage of Left Upper Leg Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L9M4ZX" = "1" /* Drainage of Left Upper Leg Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L9M4ZZ" = "1" /* Drainage of Left Upper Leg Tendon, Percutaneous Endoscopic Approach */
"0L9N00Z" = "1" /* Drainage of Right Lower Leg Tendon with Drainage Device, Open Approach */
"0L9N0ZX" = "1" /* Drainage of Right Lower Leg Tendon, Open Approach, Diagnostic */
"0L9N0ZZ" = "1" /* Drainage of Right Lower Leg Tendon, Open Approach */
"0L9N40Z" = "1" /* Drainage of Right Lower Leg Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L9N4ZX" = "1" /* Drainage of Right Lower Leg Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L9N4ZZ" = "1" /* Drainage of Right Lower Leg Tendon, Percutaneous Endoscopic Approach */
"0L9P00Z" = "1" /* Drainage of Left Lower Leg Tendon with Drainage Device, Open Approach */
"0L9P0ZX" = "1" /* Drainage of Left Lower Leg Tendon, Open Approach, Diagnostic */
"0L9P0ZZ" = "1" /* Drainage of Left Lower Leg Tendon, Open Approach */
"0L9P40Z" = "1" /* Drainage of Left Lower Leg Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L9P4ZX" = "1" /* Drainage of Left Lower Leg Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L9P4ZZ" = "1" /* Drainage of Left Lower Leg Tendon, Percutaneous Endoscopic Approach */
"0L9Q00Z" = "1" /* Drainage of Right Knee Tendon with Drainage Device, Open Approach */
"0L9Q0ZX" = "1" /* Drainage of Right Knee Tendon, Open Approach, Diagnostic */
"0L9Q0ZZ" = "1" /* Drainage of Right Knee Tendon, Open Approach */
"0L9Q40Z" = "1" /* Drainage of Right Knee Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L9Q4ZX" = "1" /* Drainage of Right Knee Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L9Q4ZZ" = "1" /* Drainage of Right Knee Tendon, Percutaneous Endoscopic Approach */
"0L9R00Z" = "1" /* Drainage of Left Knee Tendon with Drainage Device, Open Approach */
"0L9R0ZX" = "1" /* Drainage of Left Knee Tendon, Open Approach, Diagnostic */
"0L9R0ZZ" = "1" /* Drainage of Left Knee Tendon, Open Approach */
"0L9R40Z" = "1" /* Drainage of Left Knee Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L9R4ZX" = "1" /* Drainage of Left Knee Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L9R4ZZ" = "1" /* Drainage of Left Knee Tendon, Percutaneous Endoscopic Approach */
"0L9S00Z" = "1" /* Drainage of Right Ankle Tendon with Drainage Device, Open Approach */
"0L9S0ZX" = "1" /* Drainage of Right Ankle Tendon, Open Approach, Diagnostic */
"0L9S0ZZ" = "1" /* Drainage of Right Ankle Tendon, Open Approach */
"0L9S40Z" = "1" /* Drainage of Right Ankle Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L9S4ZX" = "1" /* Drainage of Right Ankle Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L9S4ZZ" = "1" /* Drainage of Right Ankle Tendon, Percutaneous Endoscopic Approach */
"0L9T00Z" = "1" /* Drainage of Left Ankle Tendon with Drainage Device, Open Approach */
"0L9T0ZX" = "1" /* Drainage of Left Ankle Tendon, Open Approach, Diagnostic */
"0L9T0ZZ" = "1" /* Drainage of Left Ankle Tendon, Open Approach */
"0L9T40Z" = "1" /* Drainage of Left Ankle Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L9T4ZX" = "1" /* Drainage of Left Ankle Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L9T4ZZ" = "1" /* Drainage of Left Ankle Tendon, Percutaneous Endoscopic Approach */
"0L9V00Z" = "1" /* Drainage of Right Foot Tendon with Drainage Device, Open Approach */
"0L9V0ZX" = "1" /* Drainage of Right Foot Tendon, Open Approach, Diagnostic */
"0L9V0ZZ" = "1" /* Drainage of Right Foot Tendon, Open Approach */
"0L9V40Z" = "1" /* Drainage of Right Foot Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L9V4ZX" = "1" /* Drainage of Right Foot Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L9V4ZZ" = "1" /* Drainage of Right Foot Tendon, Percutaneous Endoscopic Approach */
"0L9W00Z" = "1" /* Drainage of Left Foot Tendon with Drainage Device, Open Approach */
"0L9W0ZX" = "1" /* Drainage of Left Foot Tendon, Open Approach, Diagnostic */
"0L9W0ZZ" = "1" /* Drainage of Left Foot Tendon, Open Approach */
"0L9W40Z" = "1" /* Drainage of Left Foot Tendon with Drainage Device, Percutaneous Endoscopic Approach */
"0L9W4ZX" = "1" /* Drainage of Left Foot Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0L9W4ZZ" = "1" /* Drainage of Left Foot Tendon, Percutaneous Endoscopic Approach */
"0LB00ZX" = "1" /* Excision of Head and Neck Tendon, Open Approach, Diagnostic */
"0LB00ZZ" = "1" /* Excision of Head and Neck Tendon, Open Approach */
"0LB03ZX" = "1" /* Excision of Head and Neck Tendon, Percutaneous Approach, Diagnostic */
"0LB03ZZ" = "1" /* Excision of Head and Neck Tendon, Percutaneous Approach */
"0LB04ZX" = "1" /* Excision of Head and Neck Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LB04ZZ" = "1" /* Excision of Head and Neck Tendon, Percutaneous Endoscopic Approach */
"0LB10ZX" = "1" /* Excision of Right Shoulder Tendon, Open Approach, Diagnostic */
"0LB10ZZ" = "1" /* Excision of Right Shoulder Tendon, Open Approach */
"0LB13ZX" = "1" /* Excision of Right Shoulder Tendon, Percutaneous Approach, Diagnostic */
"0LB13ZZ" = "1" /* Excision of Right Shoulder Tendon, Percutaneous Approach */
"0LB14ZX" = "1" /* Excision of Right Shoulder Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LB14ZZ" = "1" /* Excision of Right Shoulder Tendon, Percutaneous Endoscopic Approach */
"0LB20ZX" = "1" /* Excision of Left Shoulder Tendon, Open Approach, Diagnostic */
"0LB20ZZ" = "1" /* Excision of Left Shoulder Tendon, Open Approach */
"0LB23ZX" = "1" /* Excision of Left Shoulder Tendon, Percutaneous Approach, Diagnostic */
"0LB23ZZ" = "1" /* Excision of Left Shoulder Tendon, Percutaneous Approach */
"0LB24ZX" = "1" /* Excision of Left Shoulder Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LB24ZZ" = "1" /* Excision of Left Shoulder Tendon, Percutaneous Endoscopic Approach */
"0LB30ZX" = "1" /* Excision of Right Upper Arm Tendon, Open Approach, Diagnostic */
"0LB30ZZ" = "1" /* Excision of Right Upper Arm Tendon, Open Approach */
"0LB33ZX" = "1" /* Excision of Right Upper Arm Tendon, Percutaneous Approach, Diagnostic */
"0LB33ZZ" = "1" /* Excision of Right Upper Arm Tendon, Percutaneous Approach */
"0LB34ZX" = "1" /* Excision of Right Upper Arm Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LB34ZZ" = "1" /* Excision of Right Upper Arm Tendon, Percutaneous Endoscopic Approach */
"0LB40ZX" = "1" /* Excision of Left Upper Arm Tendon, Open Approach, Diagnostic */
"0LB40ZZ" = "1" /* Excision of Left Upper Arm Tendon, Open Approach */
"0LB43ZX" = "1" /* Excision of Left Upper Arm Tendon, Percutaneous Approach, Diagnostic */
"0LB43ZZ" = "1" /* Excision of Left Upper Arm Tendon, Percutaneous Approach */
"0LB44ZX" = "1" /* Excision of Left Upper Arm Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LB44ZZ" = "1" /* Excision of Left Upper Arm Tendon, Percutaneous Endoscopic Approach */
"0LB50ZX" = "1" /* Excision of Right Lower Arm and Wrist Tendon, Open Approach, Diagnostic */
"0LB50ZZ" = "1" /* Excision of Right Lower Arm and Wrist Tendon, Open Approach */
"0LB53ZX" = "1" /* Excision of Right Lower Arm and Wrist Tendon, Percutaneous Approach, Diagnostic */
"0LB53ZZ" = "1" /* Excision of Right Lower Arm and Wrist Tendon, Percutaneous Approach */
"0LB54ZX" = "1" /* Excision of Right Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LB54ZZ" = "1" /* Excision of Right Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach */
"0LB60ZX" = "1" /* Excision of Left Lower Arm and Wrist Tendon, Open Approach, Diagnostic */
"0LB60ZZ" = "1" /* Excision of Left Lower Arm and Wrist Tendon, Open Approach */
"0LB63ZX" = "1" /* Excision of Left Lower Arm and Wrist Tendon, Percutaneous Approach, Diagnostic */
"0LB63ZZ" = "1" /* Excision of Left Lower Arm and Wrist Tendon, Percutaneous Approach */
"0LB64ZX" = "1" /* Excision of Left Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LB64ZZ" = "1" /* Excision of Left Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach */
"0LB70ZX" = "1" /* Excision of Right Hand Tendon, Open Approach, Diagnostic */
"0LB70ZZ" = "1" /* Excision of Right Hand Tendon, Open Approach */
"0LB73ZX" = "1" /* Excision of Right Hand Tendon, Percutaneous Approach, Diagnostic */
"0LB73ZZ" = "1" /* Excision of Right Hand Tendon, Percutaneous Approach */
"0LB74ZX" = "1" /* Excision of Right Hand Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LB74ZZ" = "1" /* Excision of Right Hand Tendon, Percutaneous Endoscopic Approach */
"0LB80ZX" = "1" /* Excision of Left Hand Tendon, Open Approach, Diagnostic */
"0LB80ZZ" = "1" /* Excision of Left Hand Tendon, Open Approach */
"0LB83ZX" = "1" /* Excision of Left Hand Tendon, Percutaneous Approach, Diagnostic */
"0LB83ZZ" = "1" /* Excision of Left Hand Tendon, Percutaneous Approach */
"0LB84ZX" = "1" /* Excision of Left Hand Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LB84ZZ" = "1" /* Excision of Left Hand Tendon, Percutaneous Endoscopic Approach */
"0LB90ZX" = "1" /* Excision of Right Trunk Tendon, Open Approach, Diagnostic */
"0LB90ZZ" = "1" /* Excision of Right Trunk Tendon, Open Approach */
"0LB93ZX" = "1" /* Excision of Right Trunk Tendon, Percutaneous Approach, Diagnostic */
"0LB93ZZ" = "1" /* Excision of Right Trunk Tendon, Percutaneous Approach */
"0LB94ZX" = "1" /* Excision of Right Trunk Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LB94ZZ" = "1" /* Excision of Right Trunk Tendon, Percutaneous Endoscopic Approach */
"0LBB0ZX" = "1" /* Excision of Left Trunk Tendon, Open Approach, Diagnostic */
"0LBB0ZZ" = "1" /* Excision of Left Trunk Tendon, Open Approach */
"0LBB3ZX" = "1" /* Excision of Left Trunk Tendon, Percutaneous Approach, Diagnostic */
"0LBB3ZZ" = "1" /* Excision of Left Trunk Tendon, Percutaneous Approach */
"0LBB4ZX" = "1" /* Excision of Left Trunk Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LBB4ZZ" = "1" /* Excision of Left Trunk Tendon, Percutaneous Endoscopic Approach */
"0LBC0ZX" = "1" /* Excision of Right Thorax Tendon, Open Approach, Diagnostic */
"0LBC0ZZ" = "1" /* Excision of Right Thorax Tendon, Open Approach */
"0LBC3ZX" = "1" /* Excision of Right Thorax Tendon, Percutaneous Approach, Diagnostic */
"0LBC3ZZ" = "1" /* Excision of Right Thorax Tendon, Percutaneous Approach */
"0LBC4ZX" = "1" /* Excision of Right Thorax Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LBC4ZZ" = "1" /* Excision of Right Thorax Tendon, Percutaneous Endoscopic Approach */
"0LBD0ZX" = "1" /* Excision of Left Thorax Tendon, Open Approach, Diagnostic */
"0LBD0ZZ" = "1" /* Excision of Left Thorax Tendon, Open Approach */
"0LBD3ZX" = "1" /* Excision of Left Thorax Tendon, Percutaneous Approach, Diagnostic */
"0LBD3ZZ" = "1" /* Excision of Left Thorax Tendon, Percutaneous Approach */
"0LBD4ZX" = "1" /* Excision of Left Thorax Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LBD4ZZ" = "1" /* Excision of Left Thorax Tendon, Percutaneous Endoscopic Approach */
"0LBF0ZX" = "1" /* Excision of Right Abdomen Tendon, Open Approach, Diagnostic */
"0LBF0ZZ" = "1" /* Excision of Right Abdomen Tendon, Open Approach */
"0LBF3ZX" = "1" /* Excision of Right Abdomen Tendon, Percutaneous Approach, Diagnostic */
"0LBF3ZZ" = "1" /* Excision of Right Abdomen Tendon, Percutaneous Approach */
"0LBF4ZX" = "1" /* Excision of Right Abdomen Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LBF4ZZ" = "1" /* Excision of Right Abdomen Tendon, Percutaneous Endoscopic Approach */
"0LBG0ZX" = "1" /* Excision of Left Abdomen Tendon, Open Approach, Diagnostic */
"0LBG0ZZ" = "1" /* Excision of Left Abdomen Tendon, Open Approach */
"0LBG3ZX" = "1" /* Excision of Left Abdomen Tendon, Percutaneous Approach, Diagnostic */
"0LBG3ZZ" = "1" /* Excision of Left Abdomen Tendon, Percutaneous Approach */
"0LBG4ZX" = "1" /* Excision of Left Abdomen Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LBG4ZZ" = "1" /* Excision of Left Abdomen Tendon, Percutaneous Endoscopic Approach */
"0LBH0ZX" = "1" /* Excision of Perineum Tendon, Open Approach, Diagnostic */
"0LBH0ZZ" = "1" /* Excision of Perineum Tendon, Open Approach */
"0LBH3ZX" = "1" /* Excision of Perineum Tendon, Percutaneous Approach, Diagnostic */
"0LBH3ZZ" = "1" /* Excision of Perineum Tendon, Percutaneous Approach */
"0LBH4ZX" = "1" /* Excision of Perineum Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LBH4ZZ" = "1" /* Excision of Perineum Tendon, Percutaneous Endoscopic Approach */
"0LBJ0ZX" = "1" /* Excision of Right Hip Tendon, Open Approach, Diagnostic */
"0LBJ0ZZ" = "1" /* Excision of Right Hip Tendon, Open Approach */
"0LBJ3ZX" = "1" /* Excision of Right Hip Tendon, Percutaneous Approach, Diagnostic */
"0LBJ3ZZ" = "1" /* Excision of Right Hip Tendon, Percutaneous Approach */
"0LBJ4ZX" = "1" /* Excision of Right Hip Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LBJ4ZZ" = "1" /* Excision of Right Hip Tendon, Percutaneous Endoscopic Approach */
"0LBK0ZX" = "1" /* Excision of Left Hip Tendon, Open Approach, Diagnostic */
"0LBK0ZZ" = "1" /* Excision of Left Hip Tendon, Open Approach */
"0LBK3ZX" = "1" /* Excision of Left Hip Tendon, Percutaneous Approach, Diagnostic */
"0LBK3ZZ" = "1" /* Excision of Left Hip Tendon, Percutaneous Approach */
"0LBK4ZX" = "1" /* Excision of Left Hip Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LBK4ZZ" = "1" /* Excision of Left Hip Tendon, Percutaneous Endoscopic Approach */
"0LBL0ZX" = "1" /* Excision of Right Upper Leg Tendon, Open Approach, Diagnostic */
"0LBL0ZZ" = "1" /* Excision of Right Upper Leg Tendon, Open Approach */
"0LBL3ZX" = "1" /* Excision of Right Upper Leg Tendon, Percutaneous Approach, Diagnostic */
"0LBL3ZZ" = "1" /* Excision of Right Upper Leg Tendon, Percutaneous Approach */
"0LBL4ZX" = "1" /* Excision of Right Upper Leg Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LBL4ZZ" = "1" /* Excision of Right Upper Leg Tendon, Percutaneous Endoscopic Approach */
"0LBM0ZX" = "1" /* Excision of Left Upper Leg Tendon, Open Approach, Diagnostic */
"0LBM0ZZ" = "1" /* Excision of Left Upper Leg Tendon, Open Approach */
"0LBM3ZX" = "1" /* Excision of Left Upper Leg Tendon, Percutaneous Approach, Diagnostic */
"0LBM3ZZ" = "1" /* Excision of Left Upper Leg Tendon, Percutaneous Approach */
"0LBM4ZX" = "1" /* Excision of Left Upper Leg Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LBM4ZZ" = "1" /* Excision of Left Upper Leg Tendon, Percutaneous Endoscopic Approach */
"0LBN0ZX" = "1" /* Excision of Right Lower Leg Tendon, Open Approach, Diagnostic */
"0LBN0ZZ" = "1" /* Excision of Right Lower Leg Tendon, Open Approach */
"0LBN3ZX" = "1" /* Excision of Right Lower Leg Tendon, Percutaneous Approach, Diagnostic */
"0LBN3ZZ" = "1" /* Excision of Right Lower Leg Tendon, Percutaneous Approach */
"0LBN4ZX" = "1" /* Excision of Right Lower Leg Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LBN4ZZ" = "1" /* Excision of Right Lower Leg Tendon, Percutaneous Endoscopic Approach */
"0LBP0ZX" = "1" /* Excision of Left Lower Leg Tendon, Open Approach, Diagnostic */
"0LBP0ZZ" = "1" /* Excision of Left Lower Leg Tendon, Open Approach */
"0LBP3ZX" = "1" /* Excision of Left Lower Leg Tendon, Percutaneous Approach, Diagnostic */
"0LBP3ZZ" = "1" /* Excision of Left Lower Leg Tendon, Percutaneous Approach */
"0LBP4ZX" = "1" /* Excision of Left Lower Leg Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LBP4ZZ" = "1" /* Excision of Left Lower Leg Tendon, Percutaneous Endoscopic Approach */
"0LBQ0ZX" = "1" /* Excision of Right Knee Tendon, Open Approach, Diagnostic */
"0LBQ0ZZ" = "1" /* Excision of Right Knee Tendon, Open Approach */
"0LBQ3ZX" = "1" /* Excision of Right Knee Tendon, Percutaneous Approach, Diagnostic */
"0LBQ3ZZ" = "1" /* Excision of Right Knee Tendon, Percutaneous Approach */
"0LBQ4ZX" = "1" /* Excision of Right Knee Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LBQ4ZZ" = "1" /* Excision of Right Knee Tendon, Percutaneous Endoscopic Approach */
"0LBR0ZX" = "1" /* Excision of Left Knee Tendon, Open Approach, Diagnostic */
"0LBR0ZZ" = "1" /* Excision of Left Knee Tendon, Open Approach */
"0LBR3ZX" = "1" /* Excision of Left Knee Tendon, Percutaneous Approach, Diagnostic */
"0LBR3ZZ" = "1" /* Excision of Left Knee Tendon, Percutaneous Approach */
"0LBR4ZX" = "1" /* Excision of Left Knee Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LBR4ZZ" = "1" /* Excision of Left Knee Tendon, Percutaneous Endoscopic Approach */
"0LBS0ZX" = "1" /* Excision of Right Ankle Tendon, Open Approach, Diagnostic */
"0LBS0ZZ" = "1" /* Excision of Right Ankle Tendon, Open Approach */
"0LBS3ZX" = "1" /* Excision of Right Ankle Tendon, Percutaneous Approach, Diagnostic */
"0LBS3ZZ" = "1" /* Excision of Right Ankle Tendon, Percutaneous Approach */
"0LBS4ZX" = "1" /* Excision of Right Ankle Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LBS4ZZ" = "1" /* Excision of Right Ankle Tendon, Percutaneous Endoscopic Approach */
"0LBT0ZX" = "1" /* Excision of Left Ankle Tendon, Open Approach, Diagnostic */
"0LBT0ZZ" = "1" /* Excision of Left Ankle Tendon, Open Approach */
"0LBT3ZX" = "1" /* Excision of Left Ankle Tendon, Percutaneous Approach, Diagnostic */
"0LBT3ZZ" = "1" /* Excision of Left Ankle Tendon, Percutaneous Approach */
"0LBT4ZX" = "1" /* Excision of Left Ankle Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LBT4ZZ" = "1" /* Excision of Left Ankle Tendon, Percutaneous Endoscopic Approach */
"0LBV0ZX" = "1" /* Excision of Right Foot Tendon, Open Approach, Diagnostic */
"0LBV0ZZ" = "1" /* Excision of Right Foot Tendon, Open Approach */
"0LBV3ZX" = "1" /* Excision of Right Foot Tendon, Percutaneous Approach, Diagnostic */
"0LBV3ZZ" = "1" /* Excision of Right Foot Tendon, Percutaneous Approach */
"0LBV4ZX" = "1" /* Excision of Right Foot Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LBV4ZZ" = "1" /* Excision of Right Foot Tendon, Percutaneous Endoscopic Approach */
"0LBW0ZX" = "1" /* Excision of Left Foot Tendon, Open Approach, Diagnostic */
"0LBW0ZZ" = "1" /* Excision of Left Foot Tendon, Open Approach */
"0LBW3ZX" = "1" /* Excision of Left Foot Tendon, Percutaneous Approach, Diagnostic */
"0LBW3ZZ" = "1" /* Excision of Left Foot Tendon, Percutaneous Approach */
"0LBW4ZX" = "1" /* Excision of Left Foot Tendon, Percutaneous Endoscopic Approach, Diagnostic */
"0LBW4ZZ" = "1" /* Excision of Left Foot Tendon, Percutaneous Endoscopic Approach */
"0LC00ZZ" = "1" /* Extirpation of Matter from Head and Neck Tendon, Open Approach */
"0LC03ZZ" = "1" /* Extirpation of Matter from Head and Neck Tendon, Percutaneous Approach */
"0LC04ZZ" = "1" /* Extirpation of Matter from Head and Neck Tendon, Percutaneous Endoscopic Approach */
"0LC10ZZ" = "1" /* Extirpation of Matter from Right Shoulder Tendon, Open Approach */
"0LC13ZZ" = "1" /* Extirpation of Matter from Right Shoulder Tendon, Percutaneous Approach */
"0LC14ZZ" = "1" /* Extirpation of Matter from Right Shoulder Tendon, Percutaneous Endoscopic Approach */
"0LC20ZZ" = "1" /* Extirpation of Matter from Left Shoulder Tendon, Open Approach */
"0LC23ZZ" = "1" /* Extirpation of Matter from Left Shoulder Tendon, Percutaneous Approach */
"0LC24ZZ" = "1" /* Extirpation of Matter from Left Shoulder Tendon, Percutaneous Endoscopic Approach */
"0LC30ZZ" = "1" /* Extirpation of Matter from Right Upper Arm Tendon, Open Approach */
"0LC33ZZ" = "1" /* Extirpation of Matter from Right Upper Arm Tendon, Percutaneous Approach */
"0LC34ZZ" = "1" /* Extirpation of Matter from Right Upper Arm Tendon, Percutaneous Endoscopic Approach */
"0LC40ZZ" = "1" /* Extirpation of Matter from Left Upper Arm Tendon, Open Approach */
"0LC43ZZ" = "1" /* Extirpation of Matter from Left Upper Arm Tendon, Percutaneous Approach */
"0LC44ZZ" = "1" /* Extirpation of Matter from Left Upper Arm Tendon, Percutaneous Endoscopic Approach */
"0LC50ZZ" = "1" /* Extirpation of Matter from Right Lower Arm and Wrist Tendon, Open Approach */
"0LC53ZZ" = "1" /* Extirpation of Matter from Right Lower Arm and Wrist Tendon, Percutaneous Approach */
"0LC54ZZ" = "1" /* Extirpation of Matter from Right Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach */
"0LC60ZZ" = "1" /* Extirpation of Matter from Left Lower Arm and Wrist Tendon, Open Approach */
"0LC63ZZ" = "1" /* Extirpation of Matter from Left Lower Arm and Wrist Tendon, Percutaneous Approach */
"0LC64ZZ" = "1" /* Extirpation of Matter from Left Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach */
"0LC70ZZ" = "1" /* Extirpation of Matter from Right Hand Tendon, Open Approach */
"0LC73ZZ" = "1" /* Extirpation of Matter from Right Hand Tendon, Percutaneous Approach */
"0LC74ZZ" = "1" /* Extirpation of Matter from Right Hand Tendon, Percutaneous Endoscopic Approach */
"0LC80ZZ" = "1" /* Extirpation of Matter from Left Hand Tendon, Open Approach */
"0LC83ZZ" = "1" /* Extirpation of Matter from Left Hand Tendon, Percutaneous Approach */
"0LC84ZZ" = "1" /* Extirpation of Matter from Left Hand Tendon, Percutaneous Endoscopic Approach */
"0LC90ZZ" = "1" /* Extirpation of Matter from Right Trunk Tendon, Open Approach */
"0LC93ZZ" = "1" /* Extirpation of Matter from Right Trunk Tendon, Percutaneous Approach */
"0LC94ZZ" = "1" /* Extirpation of Matter from Right Trunk Tendon, Percutaneous Endoscopic Approach */
"0LCB0ZZ" = "1" /* Extirpation of Matter from Left Trunk Tendon, Open Approach */
"0LCB3ZZ" = "1" /* Extirpation of Matter from Left Trunk Tendon, Percutaneous Approach */
"0LCB4ZZ" = "1" /* Extirpation of Matter from Left Trunk Tendon, Percutaneous Endoscopic Approach */
"0LCC0ZZ" = "1" /* Extirpation of Matter from Right Thorax Tendon, Open Approach */
"0LCC3ZZ" = "1" /* Extirpation of Matter from Right Thorax Tendon, Percutaneous Approach */
"0LCC4ZZ" = "1" /* Extirpation of Matter from Right Thorax Tendon, Percutaneous Endoscopic Approach */
"0LCD0ZZ" = "1" /* Extirpation of Matter from Left Thorax Tendon, Open Approach */
"0LCD3ZZ" = "1" /* Extirpation of Matter from Left Thorax Tendon, Percutaneous Approach */
"0LCD4ZZ" = "1" /* Extirpation of Matter from Left Thorax Tendon, Percutaneous Endoscopic Approach */
"0LCF0ZZ" = "1" /* Extirpation of Matter from Right Abdomen Tendon, Open Approach */
"0LCF3ZZ" = "1" /* Extirpation of Matter from Right Abdomen Tendon, Percutaneous Approach */
"0LCF4ZZ" = "1" /* Extirpation of Matter from Right Abdomen Tendon, Percutaneous Endoscopic Approach */
"0LCG0ZZ" = "1" /* Extirpation of Matter from Left Abdomen Tendon, Open Approach */
"0LCG3ZZ" = "1" /* Extirpation of Matter from Left Abdomen Tendon, Percutaneous Approach */
"0LCG4ZZ" = "1" /* Extirpation of Matter from Left Abdomen Tendon, Percutaneous Endoscopic Approach */
"0LCH0ZZ" = "1" /* Extirpation of Matter from Perineum Tendon, Open Approach */
"0LCH3ZZ" = "1" /* Extirpation of Matter from Perineum Tendon, Percutaneous Approach */
"0LCH4ZZ" = "1" /* Extirpation of Matter from Perineum Tendon, Percutaneous Endoscopic Approach */
"0LCJ0ZZ" = "1" /* Extirpation of Matter from Right Hip Tendon, Open Approach */
"0LCJ3ZZ" = "1" /* Extirpation of Matter from Right Hip Tendon, Percutaneous Approach */
"0LCJ4ZZ" = "1" /* Extirpation of Matter from Right Hip Tendon, Percutaneous Endoscopic Approach */
"0LCK0ZZ" = "1" /* Extirpation of Matter from Left Hip Tendon, Open Approach */
"0LCK3ZZ" = "1" /* Extirpation of Matter from Left Hip Tendon, Percutaneous Approach */
"0LCK4ZZ" = "1" /* Extirpation of Matter from Left Hip Tendon, Percutaneous Endoscopic Approach */
"0LCL0ZZ" = "1" /* Extirpation of Matter from Right Upper Leg Tendon, Open Approach */
"0LCL3ZZ" = "1" /* Extirpation of Matter from Right Upper Leg Tendon, Percutaneous Approach */
"0LCL4ZZ" = "1" /* Extirpation of Matter from Right Upper Leg Tendon, Percutaneous Endoscopic Approach */
"0LCM0ZZ" = "1" /* Extirpation of Matter from Left Upper Leg Tendon, Open Approach */
"0LCM3ZZ" = "1" /* Extirpation of Matter from Left Upper Leg Tendon, Percutaneous Approach */
"0LCM4ZZ" = "1" /* Extirpation of Matter from Left Upper Leg Tendon, Percutaneous Endoscopic Approach */
"0LCN0ZZ" = "1" /* Extirpation of Matter from Right Lower Leg Tendon, Open Approach */
"0LCN3ZZ" = "1" /* Extirpation of Matter from Right Lower Leg Tendon, Percutaneous Approach */
"0LCN4ZZ" = "1" /* Extirpation of Matter from Right Lower Leg Tendon, Percutaneous Endoscopic Approach */
"0LCP0ZZ" = "1" /* Extirpation of Matter from Left Lower Leg Tendon, Open Approach */
"0LCP3ZZ" = "1" /* Extirpation of Matter from Left Lower Leg Tendon, Percutaneous Approach */
"0LCP4ZZ" = "1" /* Extirpation of Matter from Left Lower Leg Tendon, Percutaneous Endoscopic Approach */
"0LCQ0ZZ" = "1" /* Extirpation of Matter from Right Knee Tendon, Open Approach */
"0LCQ3ZZ" = "1" /* Extirpation of Matter from Right Knee Tendon, Percutaneous Approach */
"0LCQ4ZZ" = "1" /* Extirpation of Matter from Right Knee Tendon, Percutaneous Endoscopic Approach */
"0LCR0ZZ" = "1" /* Extirpation of Matter from Left Knee Tendon, Open Approach */
"0LCR3ZZ" = "1" /* Extirpation of Matter from Left Knee Tendon, Percutaneous Approach */
"0LCR4ZZ" = "1" /* Extirpation of Matter from Left Knee Tendon, Percutaneous Endoscopic Approach */
"0LCS0ZZ" = "1" /* Extirpation of Matter from Right Ankle Tendon, Open Approach */
"0LCS3ZZ" = "1" /* Extirpation of Matter from Right Ankle Tendon, Percutaneous Approach */
"0LCS4ZZ" = "1" /* Extirpation of Matter from Right Ankle Tendon, Percutaneous Endoscopic Approach */
"0LCT0ZZ" = "1" /* Extirpation of Matter from Left Ankle Tendon, Open Approach */
"0LCT3ZZ" = "1" /* Extirpation of Matter from Left Ankle Tendon, Percutaneous Approach */
"0LCT4ZZ" = "1" /* Extirpation of Matter from Left Ankle Tendon, Percutaneous Endoscopic Approach */
"0LCV0ZZ" = "1" /* Extirpation of Matter from Right Foot Tendon, Open Approach */
"0LCV3ZZ" = "1" /* Extirpation of Matter from Right Foot Tendon, Percutaneous Approach */
"0LCV4ZZ" = "1" /* Extirpation of Matter from Right Foot Tendon, Percutaneous Endoscopic Approach */
"0LCW0ZZ" = "1" /* Extirpation of Matter from Left Foot Tendon, Open Approach */
"0LCW3ZZ" = "1" /* Extirpation of Matter from Left Foot Tendon, Percutaneous Approach */
"0LCW4ZZ" = "1" /* Extirpation of Matter from Left Foot Tendon, Percutaneous Endoscopic Approach */
"0LJX0ZZ" = "1" /* Inspection of Upper Tendon, Open Approach */
"0LJX4ZZ" = "1" /* Inspection of Upper Tendon, Percutaneous Endoscopic Approach */
"0LJY0ZZ" = "1" /* Inspection of Lower Tendon, Open Approach */
"0LJY4ZZ" = "1" /* Inspection of Lower Tendon, Percutaneous Endoscopic Approach */
"0LM00ZZ" = "1" /* Reattachment of Head and Neck Tendon, Open Approach */
"0LM04ZZ" = "1" /* Reattachment of Head and Neck Tendon, Percutaneous Endoscopic Approach */
"0LM10ZZ" = "1" /* Reattachment of Right Shoulder Tendon, Open Approach */
"0LM14ZZ" = "1" /* Reattachment of Right Shoulder Tendon, Percutaneous Endoscopic Approach */
"0LM20ZZ" = "1" /* Reattachment of Left Shoulder Tendon, Open Approach */
"0LM24ZZ" = "1" /* Reattachment of Left Shoulder Tendon, Percutaneous Endoscopic Approach */
"0LM30ZZ" = "1" /* Reattachment of Right Upper Arm Tendon, Open Approach */
"0LM34ZZ" = "1" /* Reattachment of Right Upper Arm Tendon, Percutaneous Endoscopic Approach */
"0LM40ZZ" = "1" /* Reattachment of Left Upper Arm Tendon, Open Approach */
"0LM44ZZ" = "1" /* Reattachment of Left Upper Arm Tendon, Percutaneous Endoscopic Approach */
"0LM50ZZ" = "1" /* Reattachment of Right Lower Arm and Wrist Tendon, Open Approach */
"0LM54ZZ" = "1" /* Reattachment of Right Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach */
"0LM60ZZ" = "1" /* Reattachment of Left Lower Arm and Wrist Tendon, Open Approach */
"0LM64ZZ" = "1" /* Reattachment of Left Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach */
"0LM70ZZ" = "1" /* Reattachment of Right Hand Tendon, Open Approach */
"0LM74ZZ" = "1" /* Reattachment of Right Hand Tendon, Percutaneous Endoscopic Approach */
"0LM80ZZ" = "1" /* Reattachment of Left Hand Tendon, Open Approach */
"0LM84ZZ" = "1" /* Reattachment of Left Hand Tendon, Percutaneous Endoscopic Approach */
"0LM90ZZ" = "1" /* Reattachment of Right Trunk Tendon, Open Approach */
"0LM94ZZ" = "1" /* Reattachment of Right Trunk Tendon, Percutaneous Endoscopic Approach */
"0LMB0ZZ" = "1" /* Reattachment of Left Trunk Tendon, Open Approach */
"0LMB4ZZ" = "1" /* Reattachment of Left Trunk Tendon, Percutaneous Endoscopic Approach */
"0LMC0ZZ" = "1" /* Reattachment of Right Thorax Tendon, Open Approach */
"0LMC4ZZ" = "1" /* Reattachment of Right Thorax Tendon, Percutaneous Endoscopic Approach */
"0LMD0ZZ" = "1" /* Reattachment of Left Thorax Tendon, Open Approach */
"0LMD4ZZ" = "1" /* Reattachment of Left Thorax Tendon, Percutaneous Endoscopic Approach */
"0LMF0ZZ" = "1" /* Reattachment of Right Abdomen Tendon, Open Approach */
"0LMF4ZZ" = "1" /* Reattachment of Right Abdomen Tendon, Percutaneous Endoscopic Approach */
"0LMG0ZZ" = "1" /* Reattachment of Left Abdomen Tendon, Open Approach */
"0LMG4ZZ" = "1" /* Reattachment of Left Abdomen Tendon, Percutaneous Endoscopic Approach */
"0LMH0ZZ" = "1" /* Reattachment of Perineum Tendon, Open Approach */
"0LMH4ZZ" = "1" /* Reattachment of Perineum Tendon, Percutaneous Endoscopic Approach */
"0LMJ0ZZ" = "1" /* Reattachment of Right Hip Tendon, Open Approach */
"0LMJ4ZZ" = "1" /* Reattachment of Right Hip Tendon, Percutaneous Endoscopic Approach */
"0LMK0ZZ" = "1" /* Reattachment of Left Hip Tendon, Open Approach */
"0LMK4ZZ" = "1" /* Reattachment of Left Hip Tendon, Percutaneous Endoscopic Approach */
"0LML0ZZ" = "1" /* Reattachment of Right Upper Leg Tendon, Open Approach */
"0LML4ZZ" = "1" /* Reattachment of Right Upper Leg Tendon, Percutaneous Endoscopic Approach */
"0LMM0ZZ" = "1" /* Reattachment of Left Upper Leg Tendon, Open Approach */
"0LMM4ZZ" = "1" /* Reattachment of Left Upper Leg Tendon, Percutaneous Endoscopic Approach */
"0LMN0ZZ" = "1" /* Reattachment of Right Lower Leg Tendon, Open Approach */
"0LMN4ZZ" = "1" /* Reattachment of Right Lower Leg Tendon, Percutaneous Endoscopic Approach */
"0LMP0ZZ" = "1" /* Reattachment of Left Lower Leg Tendon, Open Approach */
"0LMP4ZZ" = "1" /* Reattachment of Left Lower Leg Tendon, Percutaneous Endoscopic Approach */
"0LMQ0ZZ" = "1" /* Reattachment of Right Knee Tendon, Open Approach */
"0LMQ4ZZ" = "1" /* Reattachment of Right Knee Tendon, Percutaneous Endoscopic Approach */
"0LMR0ZZ" = "1" /* Reattachment of Left Knee Tendon, Open Approach */
"0LMR4ZZ" = "1" /* Reattachment of Left Knee Tendon, Percutaneous Endoscopic Approach */
"0LMS0ZZ" = "1" /* Reattachment of Right Ankle Tendon, Open Approach */
"0LMS4ZZ" = "1" /* Reattachment of Right Ankle Tendon, Percutaneous Endoscopic Approach */
"0LMT0ZZ" = "1" /* Reattachment of Left Ankle Tendon, Open Approach */
"0LMT4ZZ" = "1" /* Reattachment of Left Ankle Tendon, Percutaneous Endoscopic Approach */
"0LMV0ZZ" = "1" /* Reattachment of Right Foot Tendon, Open Approach */
"0LMV4ZZ" = "1" /* Reattachment of Right Foot Tendon, Percutaneous Endoscopic Approach */
"0LMW0ZZ" = "1" /* Reattachment of Left Foot Tendon, Open Approach */
"0LMW4ZZ" = "1" /* Reattachment of Left Foot Tendon, Percutaneous Endoscopic Approach */
"0LN00ZZ" = "1" /* Release Head and Neck Tendon, Open Approach */
"0LN03ZZ" = "1" /* Release Head and Neck Tendon, Percutaneous Approach */
"0LN04ZZ" = "1" /* Release Head and Neck Tendon, Percutaneous Endoscopic Approach */
"0LN10ZZ" = "1" /* Release Right Shoulder Tendon, Open Approach */
"0LN13ZZ" = "1" /* Release Right Shoulder Tendon, Percutaneous Approach */
"0LN14ZZ" = "1" /* Release Right Shoulder Tendon, Percutaneous Endoscopic Approach */
"0LN20ZZ" = "1" /* Release Left Shoulder Tendon, Open Approach */
"0LN23ZZ" = "1" /* Release Left Shoulder Tendon, Percutaneous Approach */
"0LN24ZZ" = "1" /* Release Left Shoulder Tendon, Percutaneous Endoscopic Approach */
"0LN30ZZ" = "1" /* Release Right Upper Arm Tendon, Open Approach */
"0LN33ZZ" = "1" /* Release Right Upper Arm Tendon, Percutaneous Approach */
"0LN34ZZ" = "1" /* Release Right Upper Arm Tendon, Percutaneous Endoscopic Approach */
"0LN40ZZ" = "1" /* Release Left Upper Arm Tendon, Open Approach */
"0LN43ZZ" = "1" /* Release Left Upper Arm Tendon, Percutaneous Approach */
"0LN44ZZ" = "1" /* Release Left Upper Arm Tendon, Percutaneous Endoscopic Approach */
"0LN50ZZ" = "1" /* Release Right Lower Arm and Wrist Tendon, Open Approach */
"0LN53ZZ" = "1" /* Release Right Lower Arm and Wrist Tendon, Percutaneous Approach */
"0LN54ZZ" = "1" /* Release Right Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach */
"0LN60ZZ" = "1" /* Release Left Lower Arm and Wrist Tendon, Open Approach */
"0LN63ZZ" = "1" /* Release Left Lower Arm and Wrist Tendon, Percutaneous Approach */
"0LN64ZZ" = "1" /* Release Left Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach */
"0LN70ZZ" = "1" /* Release Right Hand Tendon, Open Approach */
"0LN73ZZ" = "1" /* Release Right Hand Tendon, Percutaneous Approach */
"0LN74ZZ" = "1" /* Release Right Hand Tendon, Percutaneous Endoscopic Approach */
"0LN80ZZ" = "1" /* Release Left Hand Tendon, Open Approach */
"0LN83ZZ" = "1" /* Release Left Hand Tendon, Percutaneous Approach */
"0LN84ZZ" = "1" /* Release Left Hand Tendon, Percutaneous Endoscopic Approach */
"0LN90ZZ" = "1" /* Release Right Trunk Tendon, Open Approach */
"0LN93ZZ" = "1" /* Release Right Trunk Tendon, Percutaneous Approach */
"0LN94ZZ" = "1" /* Release Right Trunk Tendon, Percutaneous Endoscopic Approach */
"0LNB0ZZ" = "1" /* Release Left Trunk Tendon, Open Approach */
"0LNB3ZZ" = "1" /* Release Left Trunk Tendon, Percutaneous Approach */
"0LNB4ZZ" = "1" /* Release Left Trunk Tendon, Percutaneous Endoscopic Approach */
"0LNC0ZZ" = "1" /* Release Right Thorax Tendon, Open Approach */
"0LNC3ZZ" = "1" /* Release Right Thorax Tendon, Percutaneous Approach */
"0LNC4ZZ" = "1" /* Release Right Thorax Tendon, Percutaneous Endoscopic Approach */
"0LND0ZZ" = "1" /* Release Left Thorax Tendon, Open Approach */
"0LND3ZZ" = "1" /* Release Left Thorax Tendon, Percutaneous Approach */
"0LND4ZZ" = "1" /* Release Left Thorax Tendon, Percutaneous Endoscopic Approach */
"0LNF0ZZ" = "1" /* Release Right Abdomen Tendon, Open Approach */
"0LNF3ZZ" = "1" /* Release Right Abdomen Tendon, Percutaneous Approach */
"0LNF4ZZ" = "1" /* Release Right Abdomen Tendon, Percutaneous Endoscopic Approach */
"0LNG0ZZ" = "1" /* Release Left Abdomen Tendon, Open Approach */
"0LNG3ZZ" = "1" /* Release Left Abdomen Tendon, Percutaneous Approach */
"0LNG4ZZ" = "1" /* Release Left Abdomen Tendon, Percutaneous Endoscopic Approach */
"0LNH0ZZ" = "1" /* Release Perineum Tendon, Open Approach */
"0LNH3ZZ" = "1" /* Release Perineum Tendon, Percutaneous Approach */
"0LNH4ZZ" = "1" /* Release Perineum Tendon, Percutaneous Endoscopic Approach */
"0LNJ0ZZ" = "1" /* Release Right Hip Tendon, Open Approach */
"0LNJ3ZZ" = "1" /* Release Right Hip Tendon, Percutaneous Approach */
"0LNJ4ZZ" = "1" /* Release Right Hip Tendon, Percutaneous Endoscopic Approach */
"0LNK0ZZ" = "1" /* Release Left Hip Tendon, Open Approach */
"0LNK3ZZ" = "1" /* Release Left Hip Tendon, Percutaneous Approach */
"0LNK4ZZ" = "1" /* Release Left Hip Tendon, Percutaneous Endoscopic Approach */
"0LNL0ZZ" = "1" /* Release Right Upper Leg Tendon, Open Approach */
"0LNL3ZZ" = "1" /* Release Right Upper Leg Tendon, Percutaneous Approach */
"0LNL4ZZ" = "1" /* Release Right Upper Leg Tendon, Percutaneous Endoscopic Approach */
"0LNM0ZZ" = "1" /* Release Left Upper Leg Tendon, Open Approach */
"0LNM3ZZ" = "1" /* Release Left Upper Leg Tendon, Percutaneous Approach */
"0LNM4ZZ" = "1" /* Release Left Upper Leg Tendon, Percutaneous Endoscopic Approach */
"0LNN0ZZ" = "1" /* Release Right Lower Leg Tendon, Open Approach */
"0LNN3ZZ" = "1" /* Release Right Lower Leg Tendon, Percutaneous Approach */
"0LNN4ZZ" = "1" /* Release Right Lower Leg Tendon, Percutaneous Endoscopic Approach */
"0LNP0ZZ" = "1" /* Release Left Lower Leg Tendon, Open Approach */
"0LNP3ZZ" = "1" /* Release Left Lower Leg Tendon, Percutaneous Approach */
"0LNP4ZZ" = "1" /* Release Left Lower Leg Tendon, Percutaneous Endoscopic Approach */
"0LNQ0ZZ" = "1" /* Release Right Knee Tendon, Open Approach */
"0LNQ3ZZ" = "1" /* Release Right Knee Tendon, Percutaneous Approach */
"0LNQ4ZZ" = "1" /* Release Right Knee Tendon, Percutaneous Endoscopic Approach */
"0LNR0ZZ" = "1" /* Release Left Knee Tendon, Open Approach */
"0LNR3ZZ" = "1" /* Release Left Knee Tendon, Percutaneous Approach */
"0LNR4ZZ" = "1" /* Release Left Knee Tendon, Percutaneous Endoscopic Approach */
"0LNS0ZZ" = "1" /* Release Right Ankle Tendon, Open Approach */
"0LNS3ZZ" = "1" /* Release Right Ankle Tendon, Percutaneous Approach */
"0LNS4ZZ" = "1" /* Release Right Ankle Tendon, Percutaneous Endoscopic Approach */
"0LNT0ZZ" = "1" /* Release Left Ankle Tendon, Open Approach */
"0LNT3ZZ" = "1" /* Release Left Ankle Tendon, Percutaneous Approach */
"0LNT4ZZ" = "1" /* Release Left Ankle Tendon, Percutaneous Endoscopic Approach */
"0LNV0ZZ" = "1" /* Release Right Foot Tendon, Open Approach */
"0LNV3ZZ" = "1" /* Release Right Foot Tendon, Percutaneous Approach */
"0LNV4ZZ" = "1" /* Release Right Foot Tendon, Percutaneous Endoscopic Approach */
"0LNW0ZZ" = "1" /* Release Left Foot Tendon, Open Approach */
"0LNW3ZZ" = "1" /* Release Left Foot Tendon, Percutaneous Approach */
"0LNW4ZZ" = "1" /* Release Left Foot Tendon, Percutaneous Endoscopic Approach */
"0LPX00Z" = "1" /* Removal of Drainage Device from Upper Tendon, Open Approach */
"0LPX07Z" = "1" /* Removal of Autologous Tissue Substitute from Upper Tendon, Open Approach */
"0LPX0JZ" = "1" /* Removal of Synthetic Substitute from Upper Tendon, Open Approach */
"0LPX0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Upper Tendon, Open Approach */
"0LPX37Z" = "1" /* Removal of Autologous Tissue Substitute from Upper Tendon, Percutaneous Approach */
"0LPX3JZ" = "1" /* Removal of Synthetic Substitute from Upper Tendon, Percutaneous Approach */
"0LPX3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Upper Tendon, Percutaneous Approach */
"0LPX40Z" = "1" /* Removal of Drainage Device from Upper Tendon, Percutaneous Endoscopic Approach */
"0LPX47Z" = "1" /* Removal of Autologous Tissue Substitute from Upper Tendon, Percutaneous Endoscopic Approach */
"0LPX4JZ" = "1" /* Removal of Synthetic Substitute from Upper Tendon, Percutaneous Endoscopic Approach */
"0LPX4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Upper Tendon, Percutaneous Endoscopic Approach */
"0LPY00Z" = "1" /* Removal of Drainage Device from Lower Tendon, Open Approach */
"0LPY07Z" = "1" /* Removal of Autologous Tissue Substitute from Lower Tendon, Open Approach */
"0LPY0JZ" = "1" /* Removal of Synthetic Substitute from Lower Tendon, Open Approach */
"0LPY0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lower Tendon, Open Approach */
"0LPY37Z" = "1" /* Removal of Autologous Tissue Substitute from Lower Tendon, Percutaneous Approach */
"0LPY3JZ" = "1" /* Removal of Synthetic Substitute from Lower Tendon, Percutaneous Approach */
"0LPY3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lower Tendon, Percutaneous Approach */
"0LPY40Z" = "1" /* Removal of Drainage Device from Lower Tendon, Percutaneous Endoscopic Approach */
"0LPY47Z" = "1" /* Removal of Autologous Tissue Substitute from Lower Tendon, Percutaneous Endoscopic Approach */
"0LPY4JZ" = "1" /* Removal of Synthetic Substitute from Lower Tendon, Percutaneous Endoscopic Approach */
"0LPY4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lower Tendon, Percutaneous Endoscopic Approach */
"0LQ00ZZ" = "1" /* Repair Head and Neck Tendon, Open Approach */
"0LQ03ZZ" = "1" /* Repair Head and Neck Tendon, Percutaneous Approach */
"0LQ04ZZ" = "1" /* Repair Head and Neck Tendon, Percutaneous Endoscopic Approach */
"0LQ10ZZ" = "1" /* Repair Right Shoulder Tendon, Open Approach */
"0LQ13ZZ" = "1" /* Repair Right Shoulder Tendon, Percutaneous Approach */
"0LQ14ZZ" = "1" /* Repair Right Shoulder Tendon, Percutaneous Endoscopic Approach */
"0LQ20ZZ" = "1" /* Repair Left Shoulder Tendon, Open Approach */
"0LQ23ZZ" = "1" /* Repair Left Shoulder Tendon, Percutaneous Approach */
"0LQ24ZZ" = "1" /* Repair Left Shoulder Tendon, Percutaneous Endoscopic Approach */
"0LQ30ZZ" = "1" /* Repair Right Upper Arm Tendon, Open Approach */
"0LQ33ZZ" = "1" /* Repair Right Upper Arm Tendon, Percutaneous Approach */
"0LQ34ZZ" = "1" /* Repair Right Upper Arm Tendon, Percutaneous Endoscopic Approach */
"0LQ40ZZ" = "1" /* Repair Left Upper Arm Tendon, Open Approach */
"0LQ43ZZ" = "1" /* Repair Left Upper Arm Tendon, Percutaneous Approach */
"0LQ44ZZ" = "1" /* Repair Left Upper Arm Tendon, Percutaneous Endoscopic Approach */
"0LQ50ZZ" = "1" /* Repair Right Lower Arm and Wrist Tendon, Open Approach */
"0LQ53ZZ" = "1" /* Repair Right Lower Arm and Wrist Tendon, Percutaneous Approach */
"0LQ54ZZ" = "1" /* Repair Right Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach */
"0LQ60ZZ" = "1" /* Repair Left Lower Arm and Wrist Tendon, Open Approach */
"0LQ63ZZ" = "1" /* Repair Left Lower Arm and Wrist Tendon, Percutaneous Approach */
"0LQ64ZZ" = "1" /* Repair Left Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach */
"0LQ70ZZ" = "1" /* Repair Right Hand Tendon, Open Approach */
"0LQ73ZZ" = "1" /* Repair Right Hand Tendon, Percutaneous Approach */
"0LQ74ZZ" = "1" /* Repair Right Hand Tendon, Percutaneous Endoscopic Approach */
"0LQ80ZZ" = "1" /* Repair Left Hand Tendon, Open Approach */
"0LQ83ZZ" = "1" /* Repair Left Hand Tendon, Percutaneous Approach */
"0LQ84ZZ" = "1" /* Repair Left Hand Tendon, Percutaneous Endoscopic Approach */
"0LQ90ZZ" = "1" /* Repair Right Trunk Tendon, Open Approach */
"0LQ93ZZ" = "1" /* Repair Right Trunk Tendon, Percutaneous Approach */
"0LQ94ZZ" = "1" /* Repair Right Trunk Tendon, Percutaneous Endoscopic Approach */
"0LQB0ZZ" = "1" /* Repair Left Trunk Tendon, Open Approach */
"0LQB3ZZ" = "1" /* Repair Left Trunk Tendon, Percutaneous Approach */
"0LQB4ZZ" = "1" /* Repair Left Trunk Tendon, Percutaneous Endoscopic Approach */
"0LQC0ZZ" = "1" /* Repair Right Thorax Tendon, Open Approach */
"0LQC3ZZ" = "1" /* Repair Right Thorax Tendon, Percutaneous Approach */
"0LQC4ZZ" = "1" /* Repair Right Thorax Tendon, Percutaneous Endoscopic Approach */
"0LQD0ZZ" = "1" /* Repair Left Thorax Tendon, Open Approach */
"0LQD3ZZ" = "1" /* Repair Left Thorax Tendon, Percutaneous Approach */
"0LQD4ZZ" = "1" /* Repair Left Thorax Tendon, Percutaneous Endoscopic Approach */
"0LQF0ZZ" = "1" /* Repair Right Abdomen Tendon, Open Approach */
"0LQF3ZZ" = "1" /* Repair Right Abdomen Tendon, Percutaneous Approach */
"0LQF4ZZ" = "1" /* Repair Right Abdomen Tendon, Percutaneous Endoscopic Approach */
"0LQG0ZZ" = "1" /* Repair Left Abdomen Tendon, Open Approach */
"0LQG3ZZ" = "1" /* Repair Left Abdomen Tendon, Percutaneous Approach */
"0LQG4ZZ" = "1" /* Repair Left Abdomen Tendon, Percutaneous Endoscopic Approach */
"0LQH0ZZ" = "1" /* Repair Perineum Tendon, Open Approach */
"0LQH3ZZ" = "1" /* Repair Perineum Tendon, Percutaneous Approach */
"0LQH4ZZ" = "1" /* Repair Perineum Tendon, Percutaneous Endoscopic Approach */
"0LQJ0ZZ" = "1" /* Repair Right Hip Tendon, Open Approach */
"0LQJ3ZZ" = "1" /* Repair Right Hip Tendon, Percutaneous Approach */
"0LQJ4ZZ" = "1" /* Repair Right Hip Tendon, Percutaneous Endoscopic Approach */
"0LQK0ZZ" = "1" /* Repair Left Hip Tendon, Open Approach */
"0LQK3ZZ" = "1" /* Repair Left Hip Tendon, Percutaneous Approach */
"0LQK4ZZ" = "1" /* Repair Left Hip Tendon, Percutaneous Endoscopic Approach */
"0LQL0ZZ" = "1" /* Repair Right Upper Leg Tendon, Open Approach */
"0LQL3ZZ" = "1" /* Repair Right Upper Leg Tendon, Percutaneous Approach */
"0LQL4ZZ" = "1" /* Repair Right Upper Leg Tendon, Percutaneous Endoscopic Approach */
"0LQM0ZZ" = "1" /* Repair Left Upper Leg Tendon, Open Approach */
"0LQM3ZZ" = "1" /* Repair Left Upper Leg Tendon, Percutaneous Approach */
"0LQM4ZZ" = "1" /* Repair Left Upper Leg Tendon, Percutaneous Endoscopic Approach */
"0LQN0ZZ" = "1" /* Repair Right Lower Leg Tendon, Open Approach */
"0LQN3ZZ" = "1" /* Repair Right Lower Leg Tendon, Percutaneous Approach */
"0LQN4ZZ" = "1" /* Repair Right Lower Leg Tendon, Percutaneous Endoscopic Approach */
"0LQP0ZZ" = "1" /* Repair Left Lower Leg Tendon, Open Approach */
"0LQP3ZZ" = "1" /* Repair Left Lower Leg Tendon, Percutaneous Approach */
"0LQP4ZZ" = "1" /* Repair Left Lower Leg Tendon, Percutaneous Endoscopic Approach */
"0LQQ0ZZ" = "1" /* Repair Right Knee Tendon, Open Approach */
"0LQQ3ZZ" = "1" /* Repair Right Knee Tendon, Percutaneous Approach */
"0LQQ4ZZ" = "1" /* Repair Right Knee Tendon, Percutaneous Endoscopic Approach */
"0LQR0ZZ" = "1" /* Repair Left Knee Tendon, Open Approach */
"0LQR3ZZ" = "1" /* Repair Left Knee Tendon, Percutaneous Approach */
"0LQR4ZZ" = "1" /* Repair Left Knee Tendon, Percutaneous Endoscopic Approach */
"0LQS0ZZ" = "1" /* Repair Right Ankle Tendon, Open Approach */
"0LQS3ZZ" = "1" /* Repair Right Ankle Tendon, Percutaneous Approach */
"0LQS4ZZ" = "1" /* Repair Right Ankle Tendon, Percutaneous Endoscopic Approach */
"0LQT0ZZ" = "1" /* Repair Left Ankle Tendon, Open Approach */
"0LQT3ZZ" = "1" /* Repair Left Ankle Tendon, Percutaneous Approach */
"0LQT4ZZ" = "1" /* Repair Left Ankle Tendon, Percutaneous Endoscopic Approach */
"0LQV0ZZ" = "1" /* Repair Right Foot Tendon, Open Approach */
"0LQV3ZZ" = "1" /* Repair Right Foot Tendon, Percutaneous Approach */
"0LQV4ZZ" = "1" /* Repair Right Foot Tendon, Percutaneous Endoscopic Approach */
"0LQW0ZZ" = "1" /* Repair Left Foot Tendon, Open Approach */
"0LQW3ZZ" = "1" /* Repair Left Foot Tendon, Percutaneous Approach */
"0LQW4ZZ" = "1" /* Repair Left Foot Tendon, Percutaneous Endoscopic Approach */
"0LR007Z" = "1" /* Replacement of Head and Neck Tendon with Autologous Tissue Substitute, Open Approach */
"0LR00JZ" = "1" /* Replacement of Head and Neck Tendon with Synthetic Substitute, Open Approach */
"0LR00KZ" = "1" /* Replacement of Head and Neck Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LR047Z" = "1" /* Replacement of Head and Neck Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LR04JZ" = "1" /* Replacement of Head and Neck Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LR04KZ" = "1" /* Replacement of Head and Neck Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LR107Z" = "1" /* Replacement of Right Shoulder Tendon with Autologous Tissue Substitute, Open Approach */
"0LR10JZ" = "1" /* Replacement of Right Shoulder Tendon with Synthetic Substitute, Open Approach */
"0LR10KZ" = "1" /* Replacement of Right Shoulder Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LR147Z" = "1" /* Replacement of Right Shoulder Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LR14JZ" = "1" /* Replacement of Right Shoulder Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LR14KZ" = "1" /* Replacement of Right Shoulder Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LR207Z" = "1" /* Replacement of Left Shoulder Tendon with Autologous Tissue Substitute, Open Approach */
"0LR20JZ" = "1" /* Replacement of Left Shoulder Tendon with Synthetic Substitute, Open Approach */
"0LR20KZ" = "1" /* Replacement of Left Shoulder Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LR247Z" = "1" /* Replacement of Left Shoulder Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LR24JZ" = "1" /* Replacement of Left Shoulder Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LR24KZ" = "1" /* Replacement of Left Shoulder Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LR307Z" = "1" /* Replacement of Right Upper Arm Tendon with Autologous Tissue Substitute, Open Approach */
"0LR30JZ" = "1" /* Replacement of Right Upper Arm Tendon with Synthetic Substitute, Open Approach */
"0LR30KZ" = "1" /* Replacement of Right Upper Arm Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LR347Z" = "1" /* Replacement of Right Upper Arm Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LR34JZ" = "1" /* Replacement of Right Upper Arm Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LR34KZ" = "1" /* Replacement of Right Upper Arm Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LR407Z" = "1" /* Replacement of Left Upper Arm Tendon with Autologous Tissue Substitute, Open Approach */
"0LR40JZ" = "1" /* Replacement of Left Upper Arm Tendon with Synthetic Substitute, Open Approach */
"0LR40KZ" = "1" /* Replacement of Left Upper Arm Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LR447Z" = "1" /* Replacement of Left Upper Arm Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LR44JZ" = "1" /* Replacement of Left Upper Arm Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LR44KZ" = "1" /* Replacement of Left Upper Arm Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LR507Z" = "1" /* Replacement of Right Lower Arm and Wrist Tendon with Autologous Tissue Substitute, Open Approach */
"0LR50JZ" = "1" /* Replacement of Right Lower Arm and Wrist Tendon with Synthetic Substitute, Open Approach */
"0LR50KZ" = "1" /* Replacement of Right Lower Arm and Wrist Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LR547Z" = "1" /* Replacement of Right Lower Arm and Wrist Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LR54JZ" = "1" /* Replacement of Right Lower Arm and Wrist Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LR54KZ" = "1" /* Replacement of Right Lower Arm and Wrist Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LR607Z" = "1" /* Replacement of Left Lower Arm and Wrist Tendon with Autologous Tissue Substitute, Open Approach */
"0LR60JZ" = "1" /* Replacement of Left Lower Arm and Wrist Tendon with Synthetic Substitute, Open Approach */
"0LR60KZ" = "1" /* Replacement of Left Lower Arm and Wrist Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LR647Z" = "1" /* Replacement of Left Lower Arm and Wrist Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LR64JZ" = "1" /* Replacement of Left Lower Arm and Wrist Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LR64KZ" = "1" /* Replacement of Left Lower Arm and Wrist Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LR707Z" = "1" /* Replacement of Right Hand Tendon with Autologous Tissue Substitute, Open Approach */
"0LR70JZ" = "1" /* Replacement of Right Hand Tendon with Synthetic Substitute, Open Approach */
"0LR70KZ" = "1" /* Replacement of Right Hand Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LR747Z" = "1" /* Replacement of Right Hand Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LR74JZ" = "1" /* Replacement of Right Hand Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LR74KZ" = "1" /* Replacement of Right Hand Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LR807Z" = "1" /* Replacement of Left Hand Tendon with Autologous Tissue Substitute, Open Approach */
"0LR80JZ" = "1" /* Replacement of Left Hand Tendon with Synthetic Substitute, Open Approach */
"0LR80KZ" = "1" /* Replacement of Left Hand Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LR847Z" = "1" /* Replacement of Left Hand Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LR84JZ" = "1" /* Replacement of Left Hand Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LR84KZ" = "1" /* Replacement of Left Hand Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LR907Z" = "1" /* Replacement of Right Trunk Tendon with Autologous Tissue Substitute, Open Approach */
"0LR90JZ" = "1" /* Replacement of Right Trunk Tendon with Synthetic Substitute, Open Approach */
"0LR90KZ" = "1" /* Replacement of Right Trunk Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LR947Z" = "1" /* Replacement of Right Trunk Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LR94JZ" = "1" /* Replacement of Right Trunk Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LR94KZ" = "1" /* Replacement of Right Trunk Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRB07Z" = "1" /* Replacement of Left Trunk Tendon with Autologous Tissue Substitute, Open Approach */
"0LRB0JZ" = "1" /* Replacement of Left Trunk Tendon with Synthetic Substitute, Open Approach */
"0LRB0KZ" = "1" /* Replacement of Left Trunk Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LRB47Z" = "1" /* Replacement of Left Trunk Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRB4JZ" = "1" /* Replacement of Left Trunk Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LRB4KZ" = "1" /* Replacement of Left Trunk Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRC07Z" = "1" /* Replacement of Right Thorax Tendon with Autologous Tissue Substitute, Open Approach */
"0LRC0JZ" = "1" /* Replacement of Right Thorax Tendon with Synthetic Substitute, Open Approach */
"0LRC0KZ" = "1" /* Replacement of Right Thorax Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LRC47Z" = "1" /* Replacement of Right Thorax Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRC4JZ" = "1" /* Replacement of Right Thorax Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LRC4KZ" = "1" /* Replacement of Right Thorax Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRD07Z" = "1" /* Replacement of Left Thorax Tendon with Autologous Tissue Substitute, Open Approach */
"0LRD0JZ" = "1" /* Replacement of Left Thorax Tendon with Synthetic Substitute, Open Approach */
"0LRD0KZ" = "1" /* Replacement of Left Thorax Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LRD47Z" = "1" /* Replacement of Left Thorax Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRD4JZ" = "1" /* Replacement of Left Thorax Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LRD4KZ" = "1" /* Replacement of Left Thorax Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRF07Z" = "1" /* Replacement of Right Abdomen Tendon with Autologous Tissue Substitute, Open Approach */
"0LRF0JZ" = "1" /* Replacement of Right Abdomen Tendon with Synthetic Substitute, Open Approach */
"0LRF0KZ" = "1" /* Replacement of Right Abdomen Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LRF47Z" = "1" /* Replacement of Right Abdomen Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRF4JZ" = "1" /* Replacement of Right Abdomen Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LRF4KZ" = "1" /* Replacement of Right Abdomen Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRG07Z" = "1" /* Replacement of Left Abdomen Tendon with Autologous Tissue Substitute, Open Approach */
"0LRG0JZ" = "1" /* Replacement of Left Abdomen Tendon with Synthetic Substitute, Open Approach */
"0LRG0KZ" = "1" /* Replacement of Left Abdomen Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LRG47Z" = "1" /* Replacement of Left Abdomen Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRG4JZ" = "1" /* Replacement of Left Abdomen Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LRG4KZ" = "1" /* Replacement of Left Abdomen Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRH07Z" = "1" /* Replacement of Perineum Tendon with Autologous Tissue Substitute, Open Approach */
"0LRH0JZ" = "1" /* Replacement of Perineum Tendon with Synthetic Substitute, Open Approach */
"0LRH0KZ" = "1" /* Replacement of Perineum Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LRH47Z" = "1" /* Replacement of Perineum Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRH4JZ" = "1" /* Replacement of Perineum Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LRH4KZ" = "1" /* Replacement of Perineum Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRJ07Z" = "1" /* Replacement of Right Hip Tendon with Autologous Tissue Substitute, Open Approach */
"0LRJ0JZ" = "1" /* Replacement of Right Hip Tendon with Synthetic Substitute, Open Approach */
"0LRJ0KZ" = "1" /* Replacement of Right Hip Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LRJ47Z" = "1" /* Replacement of Right Hip Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRJ4JZ" = "1" /* Replacement of Right Hip Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LRJ4KZ" = "1" /* Replacement of Right Hip Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRK07Z" = "1" /* Replacement of Left Hip Tendon with Autologous Tissue Substitute, Open Approach */
"0LRK0JZ" = "1" /* Replacement of Left Hip Tendon with Synthetic Substitute, Open Approach */
"0LRK0KZ" = "1" /* Replacement of Left Hip Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LRK47Z" = "1" /* Replacement of Left Hip Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRK4JZ" = "1" /* Replacement of Left Hip Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LRK4KZ" = "1" /* Replacement of Left Hip Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRL07Z" = "1" /* Replacement of Right Upper Leg Tendon with Autologous Tissue Substitute, Open Approach */
"0LRL0JZ" = "1" /* Replacement of Right Upper Leg Tendon with Synthetic Substitute, Open Approach */
"0LRL0KZ" = "1" /* Replacement of Right Upper Leg Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LRL47Z" = "1" /* Replacement of Right Upper Leg Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRL4JZ" = "1" /* Replacement of Right Upper Leg Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LRL4KZ" = "1" /* Replacement of Right Upper Leg Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRM07Z" = "1" /* Replacement of Left Upper Leg Tendon with Autologous Tissue Substitute, Open Approach */
"0LRM0JZ" = "1" /* Replacement of Left Upper Leg Tendon with Synthetic Substitute, Open Approach */
"0LRM0KZ" = "1" /* Replacement of Left Upper Leg Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LRM47Z" = "1" /* Replacement of Left Upper Leg Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRM4JZ" = "1" /* Replacement of Left Upper Leg Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LRM4KZ" = "1" /* Replacement of Left Upper Leg Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRN07Z" = "1" /* Replacement of Right Lower Leg Tendon with Autologous Tissue Substitute, Open Approach */
"0LRN0JZ" = "1" /* Replacement of Right Lower Leg Tendon with Synthetic Substitute, Open Approach */
"0LRN0KZ" = "1" /* Replacement of Right Lower Leg Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LRN47Z" = "1" /* Replacement of Right Lower Leg Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRN4JZ" = "1" /* Replacement of Right Lower Leg Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LRN4KZ" = "1" /* Replacement of Right Lower Leg Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRP07Z" = "1" /* Replacement of Left Lower Leg Tendon with Autologous Tissue Substitute, Open Approach */
"0LRP0JZ" = "1" /* Replacement of Left Lower Leg Tendon with Synthetic Substitute, Open Approach */
"0LRP0KZ" = "1" /* Replacement of Left Lower Leg Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LRP47Z" = "1" /* Replacement of Left Lower Leg Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRP4JZ" = "1" /* Replacement of Left Lower Leg Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LRP4KZ" = "1" /* Replacement of Left Lower Leg Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRQ07Z" = "1" /* Replacement of Right Knee Tendon with Autologous Tissue Substitute, Open Approach */
"0LRQ0JZ" = "1" /* Replacement of Right Knee Tendon with Synthetic Substitute, Open Approach */
"0LRQ0KZ" = "1" /* Replacement of Right Knee Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LRQ47Z" = "1" /* Replacement of Right Knee Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRQ4JZ" = "1" /* Replacement of Right Knee Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LRQ4KZ" = "1" /* Replacement of Right Knee Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRR07Z" = "1" /* Replacement of Left Knee Tendon with Autologous Tissue Substitute, Open Approach */
"0LRR0JZ" = "1" /* Replacement of Left Knee Tendon with Synthetic Substitute, Open Approach */
"0LRR0KZ" = "1" /* Replacement of Left Knee Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LRR47Z" = "1" /* Replacement of Left Knee Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRR4JZ" = "1" /* Replacement of Left Knee Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LRR4KZ" = "1" /* Replacement of Left Knee Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRS07Z" = "1" /* Replacement of Right Ankle Tendon with Autologous Tissue Substitute, Open Approach */
"0LRS0JZ" = "1" /* Replacement of Right Ankle Tendon with Synthetic Substitute, Open Approach */
"0LRS0KZ" = "1" /* Replacement of Right Ankle Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LRS47Z" = "1" /* Replacement of Right Ankle Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRS4JZ" = "1" /* Replacement of Right Ankle Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LRS4KZ" = "1" /* Replacement of Right Ankle Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRT07Z" = "1" /* Replacement of Left Ankle Tendon with Autologous Tissue Substitute, Open Approach */
"0LRT0JZ" = "1" /* Replacement of Left Ankle Tendon with Synthetic Substitute, Open Approach */
"0LRT0KZ" = "1" /* Replacement of Left Ankle Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LRT47Z" = "1" /* Replacement of Left Ankle Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRT4JZ" = "1" /* Replacement of Left Ankle Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LRT4KZ" = "1" /* Replacement of Left Ankle Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRV07Z" = "1" /* Replacement of Right Foot Tendon with Autologous Tissue Substitute, Open Approach */
"0LRV0JZ" = "1" /* Replacement of Right Foot Tendon with Synthetic Substitute, Open Approach */
"0LRV0KZ" = "1" /* Replacement of Right Foot Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LRV47Z" = "1" /* Replacement of Right Foot Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRV4JZ" = "1" /* Replacement of Right Foot Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LRV4KZ" = "1" /* Replacement of Right Foot Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRW07Z" = "1" /* Replacement of Left Foot Tendon with Autologous Tissue Substitute, Open Approach */
"0LRW0JZ" = "1" /* Replacement of Left Foot Tendon with Synthetic Substitute, Open Approach */
"0LRW0KZ" = "1" /* Replacement of Left Foot Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LRW47Z" = "1" /* Replacement of Left Foot Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LRW4JZ" = "1" /* Replacement of Left Foot Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LRW4KZ" = "1" /* Replacement of Left Foot Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LS00ZZ" = "1" /* Reposition Head and Neck Tendon, Open Approach */
"0LS04ZZ" = "1" /* Reposition Head and Neck Tendon, Percutaneous Endoscopic Approach */
"0LS10ZZ" = "1" /* Reposition Right Shoulder Tendon, Open Approach */
"0LS14ZZ" = "1" /* Reposition Right Shoulder Tendon, Percutaneous Endoscopic Approach */
"0LS20ZZ" = "1" /* Reposition Left Shoulder Tendon, Open Approach */
"0LS24ZZ" = "1" /* Reposition Left Shoulder Tendon, Percutaneous Endoscopic Approach */
"0LS30ZZ" = "1" /* Reposition Right Upper Arm Tendon, Open Approach */
"0LS34ZZ" = "1" /* Reposition Right Upper Arm Tendon, Percutaneous Endoscopic Approach */
"0LS40ZZ" = "1" /* Reposition Left Upper Arm Tendon, Open Approach */
"0LS44ZZ" = "1" /* Reposition Left Upper Arm Tendon, Percutaneous Endoscopic Approach */
"0LS50ZZ" = "1" /* Reposition Right Lower Arm and Wrist Tendon, Open Approach */
"0LS54ZZ" = "1" /* Reposition Right Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach */
"0LS60ZZ" = "1" /* Reposition Left Lower Arm and Wrist Tendon, Open Approach */
"0LS64ZZ" = "1" /* Reposition Left Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach */
"0LS70ZZ" = "1" /* Reposition Right Hand Tendon, Open Approach */
"0LS74ZZ" = "1" /* Reposition Right Hand Tendon, Percutaneous Endoscopic Approach */
"0LS80ZZ" = "1" /* Reposition Left Hand Tendon, Open Approach */
"0LS84ZZ" = "1" /* Reposition Left Hand Tendon, Percutaneous Endoscopic Approach */
"0LS90ZZ" = "1" /* Reposition Right Trunk Tendon, Open Approach */
"0LS94ZZ" = "1" /* Reposition Right Trunk Tendon, Percutaneous Endoscopic Approach */
"0LSB0ZZ" = "1" /* Reposition Left Trunk Tendon, Open Approach */
"0LSB4ZZ" = "1" /* Reposition Left Trunk Tendon, Percutaneous Endoscopic Approach */
"0LSC0ZZ" = "1" /* Reposition Right Thorax Tendon, Open Approach */
"0LSC4ZZ" = "1" /* Reposition Right Thorax Tendon, Percutaneous Endoscopic Approach */
"0LSD0ZZ" = "1" /* Reposition Left Thorax Tendon, Open Approach */
"0LSD4ZZ" = "1" /* Reposition Left Thorax Tendon, Percutaneous Endoscopic Approach */
"0LSF0ZZ" = "1" /* Reposition Right Abdomen Tendon, Open Approach */
"0LSF4ZZ" = "1" /* Reposition Right Abdomen Tendon, Percutaneous Endoscopic Approach */
"0LSG0ZZ" = "1" /* Reposition Left Abdomen Tendon, Open Approach */
"0LSG4ZZ" = "1" /* Reposition Left Abdomen Tendon, Percutaneous Endoscopic Approach */
"0LSH0ZZ" = "1" /* Reposition Perineum Tendon, Open Approach */
"0LSH4ZZ" = "1" /* Reposition Perineum Tendon, Percutaneous Endoscopic Approach */
"0LSJ0ZZ" = "1" /* Reposition Right Hip Tendon, Open Approach */
"0LSJ4ZZ" = "1" /* Reposition Right Hip Tendon, Percutaneous Endoscopic Approach */
"0LSK0ZZ" = "1" /* Reposition Left Hip Tendon, Open Approach */
"0LSK4ZZ" = "1" /* Reposition Left Hip Tendon, Percutaneous Endoscopic Approach */
"0LSL0ZZ" = "1" /* Reposition Right Upper Leg Tendon, Open Approach */
"0LSL4ZZ" = "1" /* Reposition Right Upper Leg Tendon, Percutaneous Endoscopic Approach */
"0LSM0ZZ" = "1" /* Reposition Left Upper Leg Tendon, Open Approach */
"0LSM4ZZ" = "1" /* Reposition Left Upper Leg Tendon, Percutaneous Endoscopic Approach */
"0LSN0ZZ" = "1" /* Reposition Right Lower Leg Tendon, Open Approach */
"0LSN4ZZ" = "1" /* Reposition Right Lower Leg Tendon, Percutaneous Endoscopic Approach */
"0LSP0ZZ" = "1" /* Reposition Left Lower Leg Tendon, Open Approach */
"0LSP4ZZ" = "1" /* Reposition Left Lower Leg Tendon, Percutaneous Endoscopic Approach */
"0LSQ0ZZ" = "1" /* Reposition Right Knee Tendon, Open Approach */
"0LSQ4ZZ" = "1" /* Reposition Right Knee Tendon, Percutaneous Endoscopic Approach */
"0LSR0ZZ" = "1" /* Reposition Left Knee Tendon, Open Approach */
"0LSR4ZZ" = "1" /* Reposition Left Knee Tendon, Percutaneous Endoscopic Approach */
"0LSS0ZZ" = "1" /* Reposition Right Ankle Tendon, Open Approach */
"0LSS4ZZ" = "1" /* Reposition Right Ankle Tendon, Percutaneous Endoscopic Approach */
"0LST0ZZ" = "1" /* Reposition Left Ankle Tendon, Open Approach */
"0LST4ZZ" = "1" /* Reposition Left Ankle Tendon, Percutaneous Endoscopic Approach */
"0LSV0ZZ" = "1" /* Reposition Right Foot Tendon, Open Approach */
"0LSV4ZZ" = "1" /* Reposition Right Foot Tendon, Percutaneous Endoscopic Approach */
"0LSW0ZZ" = "1" /* Reposition Left Foot Tendon, Open Approach */
"0LSW4ZZ" = "1" /* Reposition Left Foot Tendon, Percutaneous Endoscopic Approach */
"0LT00ZZ" = "1" /* Resection of Head and Neck Tendon, Open Approach */
"0LT04ZZ" = "1" /* Resection of Head and Neck Tendon, Percutaneous Endoscopic Approach */
"0LT10ZZ" = "1" /* Resection of Right Shoulder Tendon, Open Approach */
"0LT14ZZ" = "1" /* Resection of Right Shoulder Tendon, Percutaneous Endoscopic Approach */
"0LT20ZZ" = "1" /* Resection of Left Shoulder Tendon, Open Approach */
"0LT24ZZ" = "1" /* Resection of Left Shoulder Tendon, Percutaneous Endoscopic Approach */
"0LT30ZZ" = "1" /* Resection of Right Upper Arm Tendon, Open Approach */
"0LT34ZZ" = "1" /* Resection of Right Upper Arm Tendon, Percutaneous Endoscopic Approach */
"0LT40ZZ" = "1" /* Resection of Left Upper Arm Tendon, Open Approach */
"0LT44ZZ" = "1" /* Resection of Left Upper Arm Tendon, Percutaneous Endoscopic Approach */
"0LT50ZZ" = "1" /* Resection of Right Lower Arm and Wrist Tendon, Open Approach */
"0LT54ZZ" = "1" /* Resection of Right Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach */
"0LT60ZZ" = "1" /* Resection of Left Lower Arm and Wrist Tendon, Open Approach */
"0LT64ZZ" = "1" /* Resection of Left Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach */
"0LT70ZZ" = "1" /* Resection of Right Hand Tendon, Open Approach */
"0LT74ZZ" = "1" /* Resection of Right Hand Tendon, Percutaneous Endoscopic Approach */
"0LT80ZZ" = "1" /* Resection of Left Hand Tendon, Open Approach */
"0LT84ZZ" = "1" /* Resection of Left Hand Tendon, Percutaneous Endoscopic Approach */
"0LT90ZZ" = "1" /* Resection of Right Trunk Tendon, Open Approach */
"0LT94ZZ" = "1" /* Resection of Right Trunk Tendon, Percutaneous Endoscopic Approach */
"0LTB0ZZ" = "1" /* Resection of Left Trunk Tendon, Open Approach */
"0LTB4ZZ" = "1" /* Resection of Left Trunk Tendon, Percutaneous Endoscopic Approach */
"0LTC0ZZ" = "1" /* Resection of Right Thorax Tendon, Open Approach */
"0LTC4ZZ" = "1" /* Resection of Right Thorax Tendon, Percutaneous Endoscopic Approach */
"0LTD0ZZ" = "1" /* Resection of Left Thorax Tendon, Open Approach */
"0LTD4ZZ" = "1" /* Resection of Left Thorax Tendon, Percutaneous Endoscopic Approach */
"0LTF0ZZ" = "1" /* Resection of Right Abdomen Tendon, Open Approach */
"0LTF4ZZ" = "1" /* Resection of Right Abdomen Tendon, Percutaneous Endoscopic Approach */
"0LTG0ZZ" = "1" /* Resection of Left Abdomen Tendon, Open Approach */
"0LTG4ZZ" = "1" /* Resection of Left Abdomen Tendon, Percutaneous Endoscopic Approach */
"0LTH0ZZ" = "1" /* Resection of Perineum Tendon, Open Approach */
"0LTH4ZZ" = "1" /* Resection of Perineum Tendon, Percutaneous Endoscopic Approach */
"0LTJ0ZZ" = "1" /* Resection of Right Hip Tendon, Open Approach */
"0LTJ4ZZ" = "1" /* Resection of Right Hip Tendon, Percutaneous Endoscopic Approach */
"0LTK0ZZ" = "1" /* Resection of Left Hip Tendon, Open Approach */
"0LTK4ZZ" = "1" /* Resection of Left Hip Tendon, Percutaneous Endoscopic Approach */
"0LTL0ZZ" = "1" /* Resection of Right Upper Leg Tendon, Open Approach */
"0LTL4ZZ" = "1" /* Resection of Right Upper Leg Tendon, Percutaneous Endoscopic Approach */
"0LTM0ZZ" = "1" /* Resection of Left Upper Leg Tendon, Open Approach */
"0LTM4ZZ" = "1" /* Resection of Left Upper Leg Tendon, Percutaneous Endoscopic Approach */
"0LTN0ZZ" = "1" /* Resection of Right Lower Leg Tendon, Open Approach */
"0LTN4ZZ" = "1" /* Resection of Right Lower Leg Tendon, Percutaneous Endoscopic Approach */
"0LTP0ZZ" = "1" /* Resection of Left Lower Leg Tendon, Open Approach */
"0LTP4ZZ" = "1" /* Resection of Left Lower Leg Tendon, Percutaneous Endoscopic Approach */
"0LTQ0ZZ" = "1" /* Resection of Right Knee Tendon, Open Approach */
"0LTQ4ZZ" = "1" /* Resection of Right Knee Tendon, Percutaneous Endoscopic Approach */
"0LTR0ZZ" = "1" /* Resection of Left Knee Tendon, Open Approach */
"0LTR4ZZ" = "1" /* Resection of Left Knee Tendon, Percutaneous Endoscopic Approach */
"0LTS0ZZ" = "1" /* Resection of Right Ankle Tendon, Open Approach */
"0LTS4ZZ" = "1" /* Resection of Right Ankle Tendon, Percutaneous Endoscopic Approach */
"0LTT0ZZ" = "1" /* Resection of Left Ankle Tendon, Open Approach */
"0LTT4ZZ" = "1" /* Resection of Left Ankle Tendon, Percutaneous Endoscopic Approach */
"0LTV0ZZ" = "1" /* Resection of Right Foot Tendon, Open Approach */
"0LTV4ZZ" = "1" /* Resection of Right Foot Tendon, Percutaneous Endoscopic Approach */
"0LTW0ZZ" = "1" /* Resection of Left Foot Tendon, Open Approach */
"0LTW4ZZ" = "1" /* Resection of Left Foot Tendon, Percutaneous Endoscopic Approach */
"0LU007Z" = "1" /* Supplement Head and Neck Tendon with Autologous Tissue Substitute, Open Approach */
"0LU00JZ" = "1" /* Supplement Head and Neck Tendon with Synthetic Substitute, Open Approach */
"0LU00KZ" = "1" /* Supplement Head and Neck Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LU047Z" = "1" /* Supplement Head and Neck Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LU04JZ" = "1" /* Supplement Head and Neck Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LU04KZ" = "1" /* Supplement Head and Neck Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LU107Z" = "1" /* Supplement Right Shoulder Tendon with Autologous Tissue Substitute, Open Approach */
"0LU10JZ" = "1" /* Supplement Right Shoulder Tendon with Synthetic Substitute, Open Approach */
"0LU10KZ" = "1" /* Supplement Right Shoulder Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LU147Z" = "1" /* Supplement Right Shoulder Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LU14JZ" = "1" /* Supplement Right Shoulder Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LU14KZ" = "1" /* Supplement Right Shoulder Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LU207Z" = "1" /* Supplement Left Shoulder Tendon with Autologous Tissue Substitute, Open Approach */
"0LU20JZ" = "1" /* Supplement Left Shoulder Tendon with Synthetic Substitute, Open Approach */
"0LU20KZ" = "1" /* Supplement Left Shoulder Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LU247Z" = "1" /* Supplement Left Shoulder Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LU24JZ" = "1" /* Supplement Left Shoulder Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LU24KZ" = "1" /* Supplement Left Shoulder Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LU307Z" = "1" /* Supplement Right Upper Arm Tendon with Autologous Tissue Substitute, Open Approach */
"0LU30JZ" = "1" /* Supplement Right Upper Arm Tendon with Synthetic Substitute, Open Approach */
"0LU30KZ" = "1" /* Supplement Right Upper Arm Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LU347Z" = "1" /* Supplement Right Upper Arm Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LU34JZ" = "1" /* Supplement Right Upper Arm Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LU34KZ" = "1" /* Supplement Right Upper Arm Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LU407Z" = "1" /* Supplement Left Upper Arm Tendon with Autologous Tissue Substitute, Open Approach */
"0LU40JZ" = "1" /* Supplement Left Upper Arm Tendon with Synthetic Substitute, Open Approach */
"0LU40KZ" = "1" /* Supplement Left Upper Arm Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LU447Z" = "1" /* Supplement Left Upper Arm Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LU44JZ" = "1" /* Supplement Left Upper Arm Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LU44KZ" = "1" /* Supplement Left Upper Arm Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LU507Z" = "1" /* Supplement Right Lower Arm and Wrist Tendon with Autologous Tissue Substitute, Open Approach */
"0LU50JZ" = "1" /* Supplement Right Lower Arm and Wrist Tendon with Synthetic Substitute, Open Approach */
"0LU50KZ" = "1" /* Supplement Right Lower Arm and Wrist Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LU547Z" = "1" /* Supplement Right Lower Arm and Wrist Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LU54JZ" = "1" /* Supplement Right Lower Arm and Wrist Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LU54KZ" = "1" /* Supplement Right Lower Arm and Wrist Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LU607Z" = "1" /* Supplement Left Lower Arm and Wrist Tendon with Autologous Tissue Substitute, Open Approach */
"0LU60JZ" = "1" /* Supplement Left Lower Arm and Wrist Tendon with Synthetic Substitute, Open Approach */
"0LU60KZ" = "1" /* Supplement Left Lower Arm and Wrist Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LU647Z" = "1" /* Supplement Left Lower Arm and Wrist Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LU64JZ" = "1" /* Supplement Left Lower Arm and Wrist Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LU64KZ" = "1" /* Supplement Left Lower Arm and Wrist Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LU707Z" = "1" /* Supplement Right Hand Tendon with Autologous Tissue Substitute, Open Approach */
"0LU70JZ" = "1" /* Supplement Right Hand Tendon with Synthetic Substitute, Open Approach */
"0LU70KZ" = "1" /* Supplement Right Hand Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LU747Z" = "1" /* Supplement Right Hand Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LU74JZ" = "1" /* Supplement Right Hand Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LU74KZ" = "1" /* Supplement Right Hand Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LU807Z" = "1" /* Supplement Left Hand Tendon with Autologous Tissue Substitute, Open Approach */
"0LU80JZ" = "1" /* Supplement Left Hand Tendon with Synthetic Substitute, Open Approach */
"0LU80KZ" = "1" /* Supplement Left Hand Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LU847Z" = "1" /* Supplement Left Hand Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LU84JZ" = "1" /* Supplement Left Hand Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LU84KZ" = "1" /* Supplement Left Hand Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LU907Z" = "1" /* Supplement Right Trunk Tendon with Autologous Tissue Substitute, Open Approach */
"0LU90JZ" = "1" /* Supplement Right Trunk Tendon with Synthetic Substitute, Open Approach */
"0LU90KZ" = "1" /* Supplement Right Trunk Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LU947Z" = "1" /* Supplement Right Trunk Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LU94JZ" = "1" /* Supplement Right Trunk Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LU94KZ" = "1" /* Supplement Right Trunk Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUB07Z" = "1" /* Supplement Left Trunk Tendon with Autologous Tissue Substitute, Open Approach */
"0LUB0JZ" = "1" /* Supplement Left Trunk Tendon with Synthetic Substitute, Open Approach */
"0LUB0KZ" = "1" /* Supplement Left Trunk Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LUB47Z" = "1" /* Supplement Left Trunk Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUB4JZ" = "1" /* Supplement Left Trunk Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LUB4KZ" = "1" /* Supplement Left Trunk Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUC07Z" = "1" /* Supplement Right Thorax Tendon with Autologous Tissue Substitute, Open Approach */
"0LUC0JZ" = "1" /* Supplement Right Thorax Tendon with Synthetic Substitute, Open Approach */
"0LUC0KZ" = "1" /* Supplement Right Thorax Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LUC47Z" = "1" /* Supplement Right Thorax Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUC4JZ" = "1" /* Supplement Right Thorax Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LUC4KZ" = "1" /* Supplement Right Thorax Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUD07Z" = "1" /* Supplement Left Thorax Tendon with Autologous Tissue Substitute, Open Approach */
"0LUD0JZ" = "1" /* Supplement Left Thorax Tendon with Synthetic Substitute, Open Approach */
"0LUD0KZ" = "1" /* Supplement Left Thorax Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LUD47Z" = "1" /* Supplement Left Thorax Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUD4JZ" = "1" /* Supplement Left Thorax Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LUD4KZ" = "1" /* Supplement Left Thorax Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUF07Z" = "1" /* Supplement Right Abdomen Tendon with Autologous Tissue Substitute, Open Approach */
"0LUF0JZ" = "1" /* Supplement Right Abdomen Tendon with Synthetic Substitute, Open Approach */
"0LUF0KZ" = "1" /* Supplement Right Abdomen Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LUF47Z" = "1" /* Supplement Right Abdomen Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUF4JZ" = "1" /* Supplement Right Abdomen Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LUF4KZ" = "1" /* Supplement Right Abdomen Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUG07Z" = "1" /* Supplement Left Abdomen Tendon with Autologous Tissue Substitute, Open Approach */
"0LUG0JZ" = "1" /* Supplement Left Abdomen Tendon with Synthetic Substitute, Open Approach */
"0LUG0KZ" = "1" /* Supplement Left Abdomen Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LUG47Z" = "1" /* Supplement Left Abdomen Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUG4JZ" = "1" /* Supplement Left Abdomen Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LUG4KZ" = "1" /* Supplement Left Abdomen Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUH07Z" = "1" /* Supplement Perineum Tendon with Autologous Tissue Substitute, Open Approach */
"0LUH0JZ" = "1" /* Supplement Perineum Tendon with Synthetic Substitute, Open Approach */
"0LUH0KZ" = "1" /* Supplement Perineum Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LUH47Z" = "1" /* Supplement Perineum Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUH4JZ" = "1" /* Supplement Perineum Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LUH4KZ" = "1" /* Supplement Perineum Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUJ07Z" = "1" /* Supplement Right Hip Tendon with Autologous Tissue Substitute, Open Approach */
"0LUJ0JZ" = "1" /* Supplement Right Hip Tendon with Synthetic Substitute, Open Approach */
"0LUJ0KZ" = "1" /* Supplement Right Hip Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LUJ47Z" = "1" /* Supplement Right Hip Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUJ4JZ" = "1" /* Supplement Right Hip Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LUJ4KZ" = "1" /* Supplement Right Hip Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUK07Z" = "1" /* Supplement Left Hip Tendon with Autologous Tissue Substitute, Open Approach */
"0LUK0JZ" = "1" /* Supplement Left Hip Tendon with Synthetic Substitute, Open Approach */
"0LUK0KZ" = "1" /* Supplement Left Hip Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LUK47Z" = "1" /* Supplement Left Hip Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUK4JZ" = "1" /* Supplement Left Hip Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LUK4KZ" = "1" /* Supplement Left Hip Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUL07Z" = "1" /* Supplement Right Upper Leg Tendon with Autologous Tissue Substitute, Open Approach */
"0LUL0JZ" = "1" /* Supplement Right Upper Leg Tendon with Synthetic Substitute, Open Approach */
"0LUL0KZ" = "1" /* Supplement Right Upper Leg Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LUL47Z" = "1" /* Supplement Right Upper Leg Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUL4JZ" = "1" /* Supplement Right Upper Leg Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LUL4KZ" = "1" /* Supplement Right Upper Leg Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUM07Z" = "1" /* Supplement Left Upper Leg Tendon with Autologous Tissue Substitute, Open Approach */
"0LUM0JZ" = "1" /* Supplement Left Upper Leg Tendon with Synthetic Substitute, Open Approach */
"0LUM0KZ" = "1" /* Supplement Left Upper Leg Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LUM47Z" = "1" /* Supplement Left Upper Leg Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUM4JZ" = "1" /* Supplement Left Upper Leg Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LUM4KZ" = "1" /* Supplement Left Upper Leg Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUN07Z" = "1" /* Supplement Right Lower Leg Tendon with Autologous Tissue Substitute, Open Approach */
"0LUN0JZ" = "1" /* Supplement Right Lower Leg Tendon with Synthetic Substitute, Open Approach */
"0LUN0KZ" = "1" /* Supplement Right Lower Leg Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LUN47Z" = "1" /* Supplement Right Lower Leg Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUN4JZ" = "1" /* Supplement Right Lower Leg Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LUN4KZ" = "1" /* Supplement Right Lower Leg Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUP07Z" = "1" /* Supplement Left Lower Leg Tendon with Autologous Tissue Substitute, Open Approach */
"0LUP0JZ" = "1" /* Supplement Left Lower Leg Tendon with Synthetic Substitute, Open Approach */
"0LUP0KZ" = "1" /* Supplement Left Lower Leg Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LUP47Z" = "1" /* Supplement Left Lower Leg Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUP4JZ" = "1" /* Supplement Left Lower Leg Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LUP4KZ" = "1" /* Supplement Left Lower Leg Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUQ07Z" = "1" /* Supplement Right Knee Tendon with Autologous Tissue Substitute, Open Approach */
"0LUQ0JZ" = "1" /* Supplement Right Knee Tendon with Synthetic Substitute, Open Approach */
"0LUQ0KZ" = "1" /* Supplement Right Knee Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LUQ47Z" = "1" /* Supplement Right Knee Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUQ4JZ" = "1" /* Supplement Right Knee Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LUQ4KZ" = "1" /* Supplement Right Knee Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUR07Z" = "1" /* Supplement Left Knee Tendon with Autologous Tissue Substitute, Open Approach */
"0LUR0JZ" = "1" /* Supplement Left Knee Tendon with Synthetic Substitute, Open Approach */
"0LUR0KZ" = "1" /* Supplement Left Knee Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LUR47Z" = "1" /* Supplement Left Knee Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUR4JZ" = "1" /* Supplement Left Knee Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LUR4KZ" = "1" /* Supplement Left Knee Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUS07Z" = "1" /* Supplement Right Ankle Tendon with Autologous Tissue Substitute, Open Approach */
"0LUS0JZ" = "1" /* Supplement Right Ankle Tendon with Synthetic Substitute, Open Approach */
"0LUS0KZ" = "1" /* Supplement Right Ankle Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LUS47Z" = "1" /* Supplement Right Ankle Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUS4JZ" = "1" /* Supplement Right Ankle Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LUS4KZ" = "1" /* Supplement Right Ankle Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUT07Z" = "1" /* Supplement Left Ankle Tendon with Autologous Tissue Substitute, Open Approach */
"0LUT0JZ" = "1" /* Supplement Left Ankle Tendon with Synthetic Substitute, Open Approach */
"0LUT0KZ" = "1" /* Supplement Left Ankle Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LUT47Z" = "1" /* Supplement Left Ankle Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUT4JZ" = "1" /* Supplement Left Ankle Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LUT4KZ" = "1" /* Supplement Left Ankle Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUV07Z" = "1" /* Supplement Right Foot Tendon with Autologous Tissue Substitute, Open Approach */
"0LUV0JZ" = "1" /* Supplement Right Foot Tendon with Synthetic Substitute, Open Approach */
"0LUV0KZ" = "1" /* Supplement Right Foot Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LUV47Z" = "1" /* Supplement Right Foot Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUV4JZ" = "1" /* Supplement Right Foot Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LUV4KZ" = "1" /* Supplement Right Foot Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUW07Z" = "1" /* Supplement Left Foot Tendon with Autologous Tissue Substitute, Open Approach */
"0LUW0JZ" = "1" /* Supplement Left Foot Tendon with Synthetic Substitute, Open Approach */
"0LUW0KZ" = "1" /* Supplement Left Foot Tendon with Nonautologous Tissue Substitute, Open Approach */
"0LUW47Z" = "1" /* Supplement Left Foot Tendon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LUW4JZ" = "1" /* Supplement Left Foot Tendon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0LUW4KZ" = "1" /* Supplement Left Foot Tendon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0LWX00Z" = "1" /* Revision of Drainage Device in Upper Tendon, Open Approach */
"0LWX07Z" = "1" /* Revision of Autologous Tissue Substitute in Upper Tendon, Open Approach */
"0LWX0JZ" = "1" /* Revision of Synthetic Substitute in Upper Tendon, Open Approach */
"0LWX0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Tendon, Open Approach */
"0LWX30Z" = "1" /* Revision of Drainage Device in Upper Tendon, Percutaneous Approach */
"0LWX37Z" = "1" /* Revision of Autologous Tissue Substitute in Upper Tendon, Percutaneous Approach */
"0LWX3JZ" = "1" /* Revision of Synthetic Substitute in Upper Tendon, Percutaneous Approach */
"0LWX3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Tendon, Percutaneous Approach */
"0LWX40Z" = "1" /* Revision of Drainage Device in Upper Tendon, Percutaneous Endoscopic Approach */
"0LWX47Z" = "1" /* Revision of Autologous Tissue Substitute in Upper Tendon, Percutaneous Endoscopic Approach */
"0LWX4JZ" = "1" /* Revision of Synthetic Substitute in Upper Tendon, Percutaneous Endoscopic Approach */
"0LWX4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Tendon, Percutaneous Endoscopic Approach */
"0LWY00Z" = "1" /* Revision of Drainage Device in Lower Tendon, Open Approach */
"0LWY07Z" = "1" /* Revision of Autologous Tissue Substitute in Lower Tendon, Open Approach */
"0LWY0JZ" = "1" /* Revision of Synthetic Substitute in Lower Tendon, Open Approach */
"0LWY0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Tendon, Open Approach */
"0LWY30Z" = "1" /* Revision of Drainage Device in Lower Tendon, Percutaneous Approach */
"0LWY37Z" = "1" /* Revision of Autologous Tissue Substitute in Lower Tendon, Percutaneous Approach */
"0LWY3JZ" = "1" /* Revision of Synthetic Substitute in Lower Tendon, Percutaneous Approach */
"0LWY3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Tendon, Percutaneous Approach */
"0LWY40Z" = "1" /* Revision of Drainage Device in Lower Tendon, Percutaneous Endoscopic Approach */
"0LWY47Z" = "1" /* Revision of Autologous Tissue Substitute in Lower Tendon, Percutaneous Endoscopic Approach */
"0LWY4JZ" = "1" /* Revision of Synthetic Substitute in Lower Tendon, Percutaneous Endoscopic Approach */
"0LWY4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Tendon, Percutaneous Endoscopic Approach */
"0LX00ZZ" = "1" /* Transfer Head and Neck Tendon, Open Approach */
"0LX04ZZ" = "1" /* Transfer Head and Neck Tendon, Percutaneous Endoscopic Approach */
"0LX10ZZ" = "1" /* Transfer Right Shoulder Tendon, Open Approach */
"0LX14ZZ" = "1" /* Transfer Right Shoulder Tendon, Percutaneous Endoscopic Approach */
"0LX20ZZ" = "1" /* Transfer Left Shoulder Tendon, Open Approach */
"0LX24ZZ" = "1" /* Transfer Left Shoulder Tendon, Percutaneous Endoscopic Approach */
"0LX30ZZ" = "1" /* Transfer Right Upper Arm Tendon, Open Approach */
"0LX34ZZ" = "1" /* Transfer Right Upper Arm Tendon, Percutaneous Endoscopic Approach */
"0LX40ZZ" = "1" /* Transfer Left Upper Arm Tendon, Open Approach */
"0LX44ZZ" = "1" /* Transfer Left Upper Arm Tendon, Percutaneous Endoscopic Approach */
"0LX50ZZ" = "1" /* Transfer Right Lower Arm and Wrist Tendon, Open Approach */
"0LX54ZZ" = "1" /* Transfer Right Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach */
"0LX60ZZ" = "1" /* Transfer Left Lower Arm and Wrist Tendon, Open Approach */
"0LX64ZZ" = "1" /* Transfer Left Lower Arm and Wrist Tendon, Percutaneous Endoscopic Approach */
"0LX70ZZ" = "1" /* Transfer Right Hand Tendon, Open Approach */
"0LX74ZZ" = "1" /* Transfer Right Hand Tendon, Percutaneous Endoscopic Approach */
"0LX80ZZ" = "1" /* Transfer Left Hand Tendon, Open Approach */
"0LX84ZZ" = "1" /* Transfer Left Hand Tendon, Percutaneous Endoscopic Approach */
"0LX90ZZ" = "1" /* Transfer Right Trunk Tendon, Open Approach */
"0LX94ZZ" = "1" /* Transfer Right Trunk Tendon, Percutaneous Endoscopic Approach */
"0LXB0ZZ" = "1" /* Transfer Left Trunk Tendon, Open Approach */
"0LXB4ZZ" = "1" /* Transfer Left Trunk Tendon, Percutaneous Endoscopic Approach */
"0LXC0ZZ" = "1" /* Transfer Right Thorax Tendon, Open Approach */
"0LXC4ZZ" = "1" /* Transfer Right Thorax Tendon, Percutaneous Endoscopic Approach */
"0LXD0ZZ" = "1" /* Transfer Left Thorax Tendon, Open Approach */
"0LXD4ZZ" = "1" /* Transfer Left Thorax Tendon, Percutaneous Endoscopic Approach */
"0LXF0ZZ" = "1" /* Transfer Right Abdomen Tendon, Open Approach */
"0LXF4ZZ" = "1" /* Transfer Right Abdomen Tendon, Percutaneous Endoscopic Approach */
"0LXG0ZZ" = "1" /* Transfer Left Abdomen Tendon, Open Approach */
"0LXG4ZZ" = "1" /* Transfer Left Abdomen Tendon, Percutaneous Endoscopic Approach */
"0LXH0ZZ" = "1" /* Transfer Perineum Tendon, Open Approach */
"0LXH4ZZ" = "1" /* Transfer Perineum Tendon, Percutaneous Endoscopic Approach */
"0LXJ0ZZ" = "1" /* Transfer Right Hip Tendon, Open Approach */
"0LXJ4ZZ" = "1" /* Transfer Right Hip Tendon, Percutaneous Endoscopic Approach */
"0LXK0ZZ" = "1" /* Transfer Left Hip Tendon, Open Approach */
"0LXK4ZZ" = "1" /* Transfer Left Hip Tendon, Percutaneous Endoscopic Approach */
"0LXL0ZZ" = "1" /* Transfer Right Upper Leg Tendon, Open Approach */
"0LXL4ZZ" = "1" /* Transfer Right Upper Leg Tendon, Percutaneous Endoscopic Approach */
"0LXM0ZZ" = "1" /* Transfer Left Upper Leg Tendon, Open Approach */
"0LXM4ZZ" = "1" /* Transfer Left Upper Leg Tendon, Percutaneous Endoscopic Approach */
"0LXN0ZZ" = "1" /* Transfer Right Lower Leg Tendon, Open Approach */
"0LXN4ZZ" = "1" /* Transfer Right Lower Leg Tendon, Percutaneous Endoscopic Approach */
"0LXP0ZZ" = "1" /* Transfer Left Lower Leg Tendon, Open Approach */
"0LXP4ZZ" = "1" /* Transfer Left Lower Leg Tendon, Percutaneous Endoscopic Approach */
"0LXQ0ZZ" = "1" /* Transfer Right Knee Tendon, Open Approach */
"0LXQ4ZZ" = "1" /* Transfer Right Knee Tendon, Percutaneous Endoscopic Approach */
"0LXR0ZZ" = "1" /* Transfer Left Knee Tendon, Open Approach */
"0LXR4ZZ" = "1" /* Transfer Left Knee Tendon, Percutaneous Endoscopic Approach */
"0LXS0ZZ" = "1" /* Transfer Right Ankle Tendon, Open Approach */
"0LXS4ZZ" = "1" /* Transfer Right Ankle Tendon, Percutaneous Endoscopic Approach */
"0LXT0ZZ" = "1" /* Transfer Left Ankle Tendon, Open Approach */
"0LXT4ZZ" = "1" /* Transfer Left Ankle Tendon, Percutaneous Endoscopic Approach */
"0LXV0ZZ" = "1" /* Transfer Right Foot Tendon, Open Approach */
"0LXV4ZZ" = "1" /* Transfer Right Foot Tendon, Percutaneous Endoscopic Approach */
"0LXW0ZZ" = "1" /* Transfer Left Foot Tendon, Open Approach */
"0LXW4ZZ" = "1" /* Transfer Left Foot Tendon, Percutaneous Endoscopic Approach */
"0M500ZZ" = "1" /* Destruction of Head and Neck Bursa and Ligament, Open Approach */
"0M503ZZ" = "1" /* Destruction of Head and Neck Bursa and Ligament, Percutaneous Approach */
"0M504ZZ" = "1" /* Destruction of Head and Neck Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M510ZZ" = "1" /* Destruction of Right Shoulder Bursa and Ligament, Open Approach */
"0M513ZZ" = "1" /* Destruction of Right Shoulder Bursa and Ligament, Percutaneous Approach */
"0M514ZZ" = "1" /* Destruction of Right Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M520ZZ" = "1" /* Destruction of Left Shoulder Bursa and Ligament, Open Approach */
"0M523ZZ" = "1" /* Destruction of Left Shoulder Bursa and Ligament, Percutaneous Approach */
"0M524ZZ" = "1" /* Destruction of Left Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M530ZZ" = "1" /* Destruction of Right Elbow Bursa and Ligament, Open Approach */
"0M533ZZ" = "1" /* Destruction of Right Elbow Bursa and Ligament, Percutaneous Approach */
"0M534ZZ" = "1" /* Destruction of Right Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M540ZZ" = "1" /* Destruction of Left Elbow Bursa and Ligament, Open Approach */
"0M543ZZ" = "1" /* Destruction of Left Elbow Bursa and Ligament, Percutaneous Approach */
"0M544ZZ" = "1" /* Destruction of Left Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M550ZZ" = "1" /* Destruction of Right Wrist Bursa and Ligament, Open Approach */
"0M553ZZ" = "1" /* Destruction of Right Wrist Bursa and Ligament, Percutaneous Approach */
"0M554ZZ" = "1" /* Destruction of Right Wrist Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M560ZZ" = "1" /* Destruction of Left Wrist Bursa and Ligament, Open Approach */
"0M563ZZ" = "1" /* Destruction of Left Wrist Bursa and Ligament, Percutaneous Approach */
"0M564ZZ" = "1" /* Destruction of Left Wrist Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M570ZZ" = "1" /* Destruction of Right Hand Bursa and Ligament, Open Approach */
"0M573ZZ" = "1" /* Destruction of Right Hand Bursa and Ligament, Percutaneous Approach */
"0M574ZZ" = "1" /* Destruction of Right Hand Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M580ZZ" = "1" /* Destruction of Left Hand Bursa and Ligament, Open Approach */
"0M583ZZ" = "1" /* Destruction of Left Hand Bursa and Ligament, Percutaneous Approach */
"0M584ZZ" = "1" /* Destruction of Left Hand Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M590ZZ" = "1" /* Destruction of Right Upper Extremity Bursa and Ligament, Open Approach */
"0M593ZZ" = "1" /* Destruction of Right Upper Extremity Bursa and Ligament, Percutaneous Approach */
"0M594ZZ" = "1" /* Destruction of Right Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M5B0ZZ" = "1" /* Destruction of Left Upper Extremity Bursa and Ligament, Open Approach */
"0M5B3ZZ" = "1" /* Destruction of Left Upper Extremity Bursa and Ligament, Percutaneous Approach */
"0M5B4ZZ" = "1" /* Destruction of Left Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M5C0ZZ" = "1" /* Destruction of Right Trunk Bursa and Ligament, Open Approach */
"0M5C3ZZ" = "1" /* Destruction of Right Trunk Bursa and Ligament, Percutaneous Approach */
"0M5C4ZZ" = "1" /* Destruction of Right Trunk Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M5D0ZZ" = "1" /* Destruction of Left Trunk Bursa and Ligament, Open Approach */
"0M5D3ZZ" = "1" /* Destruction of Left Trunk Bursa and Ligament, Percutaneous Approach */
"0M5D4ZZ" = "1" /* Destruction of Left Trunk Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M5F0ZZ" = "1" /* Destruction of Right Thorax Bursa and Ligament, Open Approach */
"0M5F3ZZ" = "1" /* Destruction of Right Thorax Bursa and Ligament, Percutaneous Approach */
"0M5F4ZZ" = "1" /* Destruction of Right Thorax Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M5G0ZZ" = "1" /* Destruction of Left Thorax Bursa and Ligament, Open Approach */
"0M5G3ZZ" = "1" /* Destruction of Left Thorax Bursa and Ligament, Percutaneous Approach */
"0M5G4ZZ" = "1" /* Destruction of Left Thorax Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M5H0ZZ" = "1" /* Destruction of Right Abdomen Bursa and Ligament, Open Approach */
"0M5H3ZZ" = "1" /* Destruction of Right Abdomen Bursa and Ligament, Percutaneous Approach */
"0M5H4ZZ" = "1" /* Destruction of Right Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M5J0ZZ" = "1" /* Destruction of Left Abdomen Bursa and Ligament, Open Approach */
"0M5J3ZZ" = "1" /* Destruction of Left Abdomen Bursa and Ligament, Percutaneous Approach */
"0M5J4ZZ" = "1" /* Destruction of Left Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M5K0ZZ" = "1" /* Destruction of Perineum Bursa and Ligament, Open Approach */
"0M5K3ZZ" = "1" /* Destruction of Perineum Bursa and Ligament, Percutaneous Approach */
"0M5K4ZZ" = "1" /* Destruction of Perineum Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M5L0ZZ" = "1" /* Destruction of Right Hip Bursa and Ligament, Open Approach */
"0M5L3ZZ" = "1" /* Destruction of Right Hip Bursa and Ligament, Percutaneous Approach */
"0M5L4ZZ" = "1" /* Destruction of Right Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M5M0ZZ" = "1" /* Destruction of Left Hip Bursa and Ligament, Open Approach */
"0M5M3ZZ" = "1" /* Destruction of Left Hip Bursa and Ligament, Percutaneous Approach */
"0M5M4ZZ" = "1" /* Destruction of Left Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M5N0ZZ" = "1" /* Destruction of Right Knee Bursa and Ligament, Open Approach */
"0M5N3ZZ" = "1" /* Destruction of Right Knee Bursa and Ligament, Percutaneous Approach */
"0M5N4ZZ" = "1" /* Destruction of Right Knee Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M5P0ZZ" = "1" /* Destruction of Left Knee Bursa and Ligament, Open Approach */
"0M5P3ZZ" = "1" /* Destruction of Left Knee Bursa and Ligament, Percutaneous Approach */
"0M5P4ZZ" = "1" /* Destruction of Left Knee Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M5Q0ZZ" = "1" /* Destruction of Right Ankle Bursa and Ligament, Open Approach */
"0M5Q3ZZ" = "1" /* Destruction of Right Ankle Bursa and Ligament, Percutaneous Approach */
"0M5Q4ZZ" = "1" /* Destruction of Right Ankle Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M5R0ZZ" = "1" /* Destruction of Left Ankle Bursa and Ligament, Open Approach */
"0M5R3ZZ" = "1" /* Destruction of Left Ankle Bursa and Ligament, Percutaneous Approach */
"0M5R4ZZ" = "1" /* Destruction of Left Ankle Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M5S0ZZ" = "1" /* Destruction of Right Foot Bursa and Ligament, Open Approach */
"0M5S3ZZ" = "1" /* Destruction of Right Foot Bursa and Ligament, Percutaneous Approach */
"0M5S4ZZ" = "1" /* Destruction of Right Foot Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M5T0ZZ" = "1" /* Destruction of Left Foot Bursa and Ligament, Open Approach */
"0M5T3ZZ" = "1" /* Destruction of Left Foot Bursa and Ligament, Percutaneous Approach */
"0M5T4ZZ" = "1" /* Destruction of Left Foot Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M5V0ZZ" = "1" /* Destruction of Right Lower Extremity Bursa and Ligament, Open Approach */
"0M5V3ZZ" = "1" /* Destruction of Right Lower Extremity Bursa and Ligament, Percutaneous Approach */
"0M5V4ZZ" = "1" /* Destruction of Right Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M5W0ZZ" = "1" /* Destruction of Left Lower Extremity Bursa and Ligament, Open Approach */
"0M5W3ZZ" = "1" /* Destruction of Left Lower Extremity Bursa and Ligament, Percutaneous Approach */
"0M5W4ZZ" = "1" /* Destruction of Left Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M800ZZ" = "1" /* Division of Head and Neck Bursa and Ligament, Open Approach */
"0M803ZZ" = "1" /* Division of Head and Neck Bursa and Ligament, Percutaneous Approach */
"0M804ZZ" = "1" /* Division of Head and Neck Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M810ZZ" = "1" /* Division of Right Shoulder Bursa and Ligament, Open Approach */
"0M813ZZ" = "1" /* Division of Right Shoulder Bursa and Ligament, Percutaneous Approach */
"0M814ZZ" = "1" /* Division of Right Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M820ZZ" = "1" /* Division of Left Shoulder Bursa and Ligament, Open Approach */
"0M823ZZ" = "1" /* Division of Left Shoulder Bursa and Ligament, Percutaneous Approach */
"0M824ZZ" = "1" /* Division of Left Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M830ZZ" = "1" /* Division of Right Elbow Bursa and Ligament, Open Approach */
"0M833ZZ" = "1" /* Division of Right Elbow Bursa and Ligament, Percutaneous Approach */
"0M834ZZ" = "1" /* Division of Right Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M840ZZ" = "1" /* Division of Left Elbow Bursa and Ligament, Open Approach */
"0M843ZZ" = "1" /* Division of Left Elbow Bursa and Ligament, Percutaneous Approach */
"0M844ZZ" = "1" /* Division of Left Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M870ZZ" = "1" /* Division of Right Hand Bursa and Ligament, Open Approach */
"0M873ZZ" = "1" /* Division of Right Hand Bursa and Ligament, Percutaneous Approach */
"0M874ZZ" = "1" /* Division of Right Hand Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M880ZZ" = "1" /* Division of Left Hand Bursa and Ligament, Open Approach */
"0M883ZZ" = "1" /* Division of Left Hand Bursa and Ligament, Percutaneous Approach */
"0M884ZZ" = "1" /* Division of Left Hand Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M890ZZ" = "1" /* Division of Right Upper Extremity Bursa and Ligament, Open Approach */
"0M893ZZ" = "1" /* Division of Right Upper Extremity Bursa and Ligament, Percutaneous Approach */
"0M894ZZ" = "1" /* Division of Right Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M8B0ZZ" = "1" /* Division of Left Upper Extremity Bursa and Ligament, Open Approach */
"0M8B3ZZ" = "1" /* Division of Left Upper Extremity Bursa and Ligament, Percutaneous Approach */
"0M8B4ZZ" = "1" /* Division of Left Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M8C0ZZ" = "1" /* Division of Right Trunk Bursa and Ligament, Open Approach */
"0M8C3ZZ" = "1" /* Division of Right Trunk Bursa and Ligament, Percutaneous Approach */
"0M8C4ZZ" = "1" /* Division of Right Trunk Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M8D0ZZ" = "1" /* Division of Left Trunk Bursa and Ligament, Open Approach */
"0M8D3ZZ" = "1" /* Division of Left Trunk Bursa and Ligament, Percutaneous Approach */
"0M8D4ZZ" = "1" /* Division of Left Trunk Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M8F0ZZ" = "1" /* Division of Right Thorax Bursa and Ligament, Open Approach */
"0M8F3ZZ" = "1" /* Division of Right Thorax Bursa and Ligament, Percutaneous Approach */
"0M8F4ZZ" = "1" /* Division of Right Thorax Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M8G0ZZ" = "1" /* Division of Left Thorax Bursa and Ligament, Open Approach */
"0M8G3ZZ" = "1" /* Division of Left Thorax Bursa and Ligament, Percutaneous Approach */
"0M8G4ZZ" = "1" /* Division of Left Thorax Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M8H0ZZ" = "1" /* Division of Right Abdomen Bursa and Ligament, Open Approach */
"0M8H3ZZ" = "1" /* Division of Right Abdomen Bursa and Ligament, Percutaneous Approach */
"0M8H4ZZ" = "1" /* Division of Right Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M8J0ZZ" = "1" /* Division of Left Abdomen Bursa and Ligament, Open Approach */
"0M8J3ZZ" = "1" /* Division of Left Abdomen Bursa and Ligament, Percutaneous Approach */
"0M8J4ZZ" = "1" /* Division of Left Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M8K0ZZ" = "1" /* Division of Perineum Bursa and Ligament, Open Approach */
"0M8K3ZZ" = "1" /* Division of Perineum Bursa and Ligament, Percutaneous Approach */
"0M8K4ZZ" = "1" /* Division of Perineum Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M8L0ZZ" = "1" /* Division of Right Hip Bursa and Ligament, Open Approach */
"0M8L3ZZ" = "1" /* Division of Right Hip Bursa and Ligament, Percutaneous Approach */
"0M8L4ZZ" = "1" /* Division of Right Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M8M0ZZ" = "1" /* Division of Left Hip Bursa and Ligament, Open Approach */
"0M8M3ZZ" = "1" /* Division of Left Hip Bursa and Ligament, Percutaneous Approach */
"0M8M4ZZ" = "1" /* Division of Left Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M8N0ZZ" = "1" /* Division of Right Knee Bursa and Ligament, Open Approach */
"0M8N3ZZ" = "1" /* Division of Right Knee Bursa and Ligament, Percutaneous Approach */
"0M8N4ZZ" = "1" /* Division of Right Knee Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M8P0ZZ" = "1" /* Division of Left Knee Bursa and Ligament, Open Approach */
"0M8P3ZZ" = "1" /* Division of Left Knee Bursa and Ligament, Percutaneous Approach */
"0M8P4ZZ" = "1" /* Division of Left Knee Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M8Q0ZZ" = "1" /* Division of Right Ankle Bursa and Ligament, Open Approach */
"0M8Q3ZZ" = "1" /* Division of Right Ankle Bursa and Ligament, Percutaneous Approach */
"0M8Q4ZZ" = "1" /* Division of Right Ankle Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M8R0ZZ" = "1" /* Division of Left Ankle Bursa and Ligament, Open Approach */
"0M8R3ZZ" = "1" /* Division of Left Ankle Bursa and Ligament, Percutaneous Approach */
"0M8R4ZZ" = "1" /* Division of Left Ankle Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M8S0ZZ" = "1" /* Division of Right Foot Bursa and Ligament, Open Approach */
"0M8S3ZZ" = "1" /* Division of Right Foot Bursa and Ligament, Percutaneous Approach */
"0M8S4ZZ" = "1" /* Division of Right Foot Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M8T0ZZ" = "1" /* Division of Left Foot Bursa and Ligament, Open Approach */
"0M8T3ZZ" = "1" /* Division of Left Foot Bursa and Ligament, Percutaneous Approach */
"0M8T4ZZ" = "1" /* Division of Left Foot Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M8V0ZZ" = "1" /* Division of Right Lower Extremity Bursa and Ligament, Open Approach */
"0M8V3ZZ" = "1" /* Division of Right Lower Extremity Bursa and Ligament, Percutaneous Approach */
"0M8V4ZZ" = "1" /* Division of Right Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M8W0ZZ" = "1" /* Division of Left Lower Extremity Bursa and Ligament, Open Approach */
"0M8W3ZZ" = "1" /* Division of Left Lower Extremity Bursa and Ligament, Percutaneous Approach */
"0M8W4ZZ" = "1" /* Division of Left Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M9000Z" = "1" /* Drainage of Head and Neck Bursa and Ligament with Drainage Device, Open Approach */
"0M900ZZ" = "1" /* Drainage of Head and Neck Bursa and Ligament, Open Approach */
"0M9040Z" = "1" /* Drainage of Head and Neck Bursa and Ligament with Drainage Device, Percutaneous Endoscopic Approach */
"0M9100Z" = "1" /* Drainage of Right Shoulder Bursa and Ligament with Drainage Device, Open Approach */
"0M910ZZ" = "1" /* Drainage of Right Shoulder Bursa and Ligament, Open Approach */
"0M914ZZ" = "1" /* Drainage of Right Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M9200Z" = "1" /* Drainage of Left Shoulder Bursa and Ligament with Drainage Device, Open Approach */
"0M920ZZ" = "1" /* Drainage of Left Shoulder Bursa and Ligament, Open Approach */
"0M924ZZ" = "1" /* Drainage of Left Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M9300Z" = "1" /* Drainage of Right Elbow Bursa and Ligament with Drainage Device, Open Approach */
"0M930ZZ" = "1" /* Drainage of Right Elbow Bursa and Ligament, Open Approach */
"0M934ZZ" = "1" /* Drainage of Right Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M9400Z" = "1" /* Drainage of Left Elbow Bursa and Ligament with Drainage Device, Open Approach */
"0M940ZZ" = "1" /* Drainage of Left Elbow Bursa and Ligament, Open Approach */
"0M944ZZ" = "1" /* Drainage of Left Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M9500Z" = "1" /* Drainage of Right Wrist Bursa and Ligament with Drainage Device, Open Approach */
"0M950ZZ" = "1" /* Drainage of Right Wrist Bursa and Ligament, Open Approach */
"0M9540Z" = "1" /* Drainage of Right Wrist Bursa and Ligament with Drainage Device, Percutaneous Endoscopic Approach */
"0M9600Z" = "1" /* Drainage of Left Wrist Bursa and Ligament with Drainage Device, Open Approach */
"0M960ZZ" = "1" /* Drainage of Left Wrist Bursa and Ligament, Open Approach */
"0M9640Z" = "1" /* Drainage of Left Wrist Bursa and Ligament with Drainage Device, Percutaneous Endoscopic Approach */
"0M9700Z" = "1" /* Drainage of Right Hand Bursa and Ligament with Drainage Device, Open Approach */
"0M970ZZ" = "1" /* Drainage of Right Hand Bursa and Ligament, Open Approach */
"0M9800Z" = "1" /* Drainage of Left Hand Bursa and Ligament with Drainage Device, Open Approach */
"0M980ZZ" = "1" /* Drainage of Left Hand Bursa and Ligament, Open Approach */
"0M9900Z" = "1" /* Drainage of Right Upper Extremity Bursa and Ligament with Drainage Device, Open Approach */
"0M990ZX" = "1" /* Drainage of Right Upper Extremity Bursa and Ligament, Open Approach, Diagnostic */
"0M990ZZ" = "1" /* Drainage of Right Upper Extremity Bursa and Ligament, Open Approach */
"0M994ZX" = "1" /* Drainage of Right Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach, Diagnostic */
"0M9B00Z" = "1" /* Drainage of Left Upper Extremity Bursa and Ligament with Drainage Device, Open Approach */
"0M9B0ZX" = "1" /* Drainage of Left Upper Extremity Bursa and Ligament, Open Approach, Diagnostic */
"0M9B0ZZ" = "1" /* Drainage of Left Upper Extremity Bursa and Ligament, Open Approach */
"0M9B4ZX" = "1" /* Drainage of Left Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach, Diagnostic */
"0M9C00Z" = "1" /* Drainage of Right Trunk Bursa and Ligament with Drainage Device, Open Approach */
"0M9C0ZZ" = "1" /* Drainage of Right Trunk Bursa and Ligament, Open Approach */
"0M9D00Z" = "1" /* Drainage of Left Trunk Bursa and Ligament with Drainage Device, Open Approach */
"0M9D0ZZ" = "1" /* Drainage of Left Trunk Bursa and Ligament, Open Approach */
"0M9F00Z" = "1" /* Drainage of Right Thorax Bursa and Ligament with Drainage Device, Open Approach */
"0M9F0ZZ" = "1" /* Drainage of Right Thorax Bursa and Ligament, Open Approach */
"0M9G00Z" = "1" /* Drainage of Left Thorax Bursa and Ligament with Drainage Device, Open Approach */
"0M9G0ZZ" = "1" /* Drainage of Left Thorax Bursa and Ligament, Open Approach */
"0M9H00Z" = "1" /* Drainage of Right Abdomen Bursa and Ligament with Drainage Device, Open Approach */
"0M9H0ZX" = "1" /* Drainage of Right Abdomen Bursa and Ligament, Open Approach, Diagnostic */
"0M9H0ZZ" = "1" /* Drainage of Right Abdomen Bursa and Ligament, Open Approach */
"0M9H4ZX" = "1" /* Drainage of Right Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach, Diagnostic */
"0M9J00Z" = "1" /* Drainage of Left Abdomen Bursa and Ligament with Drainage Device, Open Approach */
"0M9J0ZX" = "1" /* Drainage of Left Abdomen Bursa and Ligament, Open Approach, Diagnostic */
"0M9J0ZZ" = "1" /* Drainage of Left Abdomen Bursa and Ligament, Open Approach */
"0M9J4ZX" = "1" /* Drainage of Left Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach, Diagnostic */
"0M9K00Z" = "1" /* Drainage of Perineum Bursa and Ligament with Drainage Device, Open Approach */
"0M9K0ZX" = "1" /* Drainage of Perineum Bursa and Ligament, Open Approach, Diagnostic */
"0M9K0ZZ" = "1" /* Drainage of Perineum Bursa and Ligament, Open Approach */
"0M9K4ZX" = "1" /* Drainage of Perineum Bursa and Ligament, Percutaneous Endoscopic Approach, Diagnostic */
"0M9L00Z" = "1" /* Drainage of Right Hip Bursa and Ligament with Drainage Device, Open Approach */
"0M9L0ZZ" = "1" /* Drainage of Right Hip Bursa and Ligament, Open Approach */
"0M9L4ZZ" = "1" /* Drainage of Right Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M9M00Z" = "1" /* Drainage of Left Hip Bursa and Ligament with Drainage Device, Open Approach */
"0M9M0ZZ" = "1" /* Drainage of Left Hip Bursa and Ligament, Open Approach */
"0M9M4ZZ" = "1" /* Drainage of Left Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0M9N00Z" = "1" /* Drainage of Right Knee Bursa and Ligament with Drainage Device, Open Approach */
"0M9N0ZZ" = "1" /* Drainage of Right Knee Bursa and Ligament, Open Approach */
"0M9N40Z" = "1" /* Drainage of Right Knee Bursa and Ligament with Drainage Device, Percutaneous Endoscopic Approach */
"0M9P00Z" = "1" /* Drainage of Left Knee Bursa and Ligament with Drainage Device, Open Approach */
"0M9P0ZZ" = "1" /* Drainage of Left Knee Bursa and Ligament, Open Approach */
"0M9P40Z" = "1" /* Drainage of Left Knee Bursa and Ligament with Drainage Device, Percutaneous Endoscopic Approach */
"0M9Q00Z" = "1" /* Drainage of Right Ankle Bursa and Ligament with Drainage Device, Open Approach */
"0M9Q0ZZ" = "1" /* Drainage of Right Ankle Bursa and Ligament, Open Approach */
"0M9Q40Z" = "1" /* Drainage of Right Ankle Bursa and Ligament with Drainage Device, Percutaneous Endoscopic Approach */
"0M9R00Z" = "1" /* Drainage of Left Ankle Bursa and Ligament with Drainage Device, Open Approach */
"0M9R0ZZ" = "1" /* Drainage of Left Ankle Bursa and Ligament, Open Approach */
"0M9R40Z" = "1" /* Drainage of Left Ankle Bursa and Ligament with Drainage Device, Percutaneous Endoscopic Approach */
"0M9S00Z" = "1" /* Drainage of Right Foot Bursa and Ligament with Drainage Device, Open Approach */
"0M9S0ZZ" = "1" /* Drainage of Right Foot Bursa and Ligament, Open Approach */
"0M9S40Z" = "1" /* Drainage of Right Foot Bursa and Ligament with Drainage Device, Percutaneous Endoscopic Approach */
"0M9T00Z" = "1" /* Drainage of Left Foot Bursa and Ligament with Drainage Device, Open Approach */
"0M9T0ZZ" = "1" /* Drainage of Left Foot Bursa and Ligament, Open Approach */
"0M9T40Z" = "1" /* Drainage of Left Foot Bursa and Ligament with Drainage Device, Percutaneous Endoscopic Approach */
"0M9V00Z" = "1" /* Drainage of Right Lower Extremity Bursa and Ligament with Drainage Device, Open Approach */
"0M9V0ZX" = "1" /* Drainage of Right Lower Extremity Bursa and Ligament, Open Approach, Diagnostic */
"0M9V0ZZ" = "1" /* Drainage of Right Lower Extremity Bursa and Ligament, Open Approach */
"0M9V4ZX" = "1" /* Drainage of Right Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach, Diagnostic */
"0M9W00Z" = "1" /* Drainage of Left Lower Extremity Bursa and Ligament with Drainage Device, Open Approach */
"0M9W0ZX" = "1" /* Drainage of Left Lower Extremity Bursa and Ligament, Open Approach, Diagnostic */
"0M9W0ZZ" = "1" /* Drainage of Left Lower Extremity Bursa and Ligament, Open Approach */
"0M9W4ZX" = "1" /* Drainage of Left Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach, Diagnostic */
"0MB00ZZ" = "1" /* Excision of Head and Neck Bursa and Ligament, Open Approach */
"0MB03ZZ" = "1" /* Excision of Head and Neck Bursa and Ligament, Percutaneous Approach */
"0MB04ZZ" = "1" /* Excision of Head and Neck Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MB10ZZ" = "1" /* Excision of Right Shoulder Bursa and Ligament, Open Approach */
"0MB13ZZ" = "1" /* Excision of Right Shoulder Bursa and Ligament, Percutaneous Approach */
"0MB14ZZ" = "1" /* Excision of Right Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MB20ZZ" = "1" /* Excision of Left Shoulder Bursa and Ligament, Open Approach */
"0MB23ZZ" = "1" /* Excision of Left Shoulder Bursa and Ligament, Percutaneous Approach */
"0MB24ZZ" = "1" /* Excision of Left Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MB30ZZ" = "1" /* Excision of Right Elbow Bursa and Ligament, Open Approach */
"0MB33ZZ" = "1" /* Excision of Right Elbow Bursa and Ligament, Percutaneous Approach */
"0MB34ZZ" = "1" /* Excision of Right Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MB40ZZ" = "1" /* Excision of Left Elbow Bursa and Ligament, Open Approach */
"0MB43ZZ" = "1" /* Excision of Left Elbow Bursa and Ligament, Percutaneous Approach */
"0MB44ZZ" = "1" /* Excision of Left Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MB50ZZ" = "1" /* Excision of Right Wrist Bursa and Ligament, Open Approach */
"0MB53ZZ" = "1" /* Excision of Right Wrist Bursa and Ligament, Percutaneous Approach */
"0MB54ZZ" = "1" /* Excision of Right Wrist Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MB60ZZ" = "1" /* Excision of Left Wrist Bursa and Ligament, Open Approach */
"0MB63ZZ" = "1" /* Excision of Left Wrist Bursa and Ligament, Percutaneous Approach */
"0MB64ZZ" = "1" /* Excision of Left Wrist Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MB70ZZ" = "1" /* Excision of Right Hand Bursa and Ligament, Open Approach */
"0MB73ZZ" = "1" /* Excision of Right Hand Bursa and Ligament, Percutaneous Approach */
"0MB74ZZ" = "1" /* Excision of Right Hand Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MB80ZZ" = "1" /* Excision of Left Hand Bursa and Ligament, Open Approach */
"0MB83ZZ" = "1" /* Excision of Left Hand Bursa and Ligament, Percutaneous Approach */
"0MB84ZZ" = "1" /* Excision of Left Hand Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MB90ZX" = "1" /* Excision of Right Upper Extremity Bursa and Ligament, Open Approach, Diagnostic */
"0MB90ZZ" = "1" /* Excision of Right Upper Extremity Bursa and Ligament, Open Approach */
"0MB93ZX" = "1" /* Excision of Right Upper Extremity Bursa and Ligament, Percutaneous Approach, Diagnostic */
"0MB93ZZ" = "1" /* Excision of Right Upper Extremity Bursa and Ligament, Percutaneous Approach */
"0MB94ZZ" = "1" /* Excision of Right Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MBB0ZZ" = "1" /* Excision of Left Upper Extremity Bursa and Ligament, Open Approach */
"0MBB3ZZ" = "1" /* Excision of Left Upper Extremity Bursa and Ligament, Percutaneous Approach */
"0MBB4ZZ" = "1" /* Excision of Left Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MBC0ZZ" = "1" /* Excision of Right Trunk Bursa and Ligament, Open Approach */
"0MBC3ZZ" = "1" /* Excision of Right Trunk Bursa and Ligament, Percutaneous Approach */
"0MBC4ZZ" = "1" /* Excision of Right Trunk Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MBD0ZZ" = "1" /* Excision of Left Trunk Bursa and Ligament, Open Approach */
"0MBD3ZZ" = "1" /* Excision of Left Trunk Bursa and Ligament, Percutaneous Approach */
"0MBD4ZZ" = "1" /* Excision of Left Trunk Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MBF0ZZ" = "1" /* Excision of Right Thorax Bursa and Ligament, Open Approach */
"0MBF3ZZ" = "1" /* Excision of Right Thorax Bursa and Ligament, Percutaneous Approach */
"0MBF4ZZ" = "1" /* Excision of Right Thorax Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MBG0ZZ" = "1" /* Excision of Left Thorax Bursa and Ligament, Open Approach */
"0MBG3ZZ" = "1" /* Excision of Left Thorax Bursa and Ligament, Percutaneous Approach */
"0MBG4ZZ" = "1" /* Excision of Left Thorax Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MBH0ZX" = "1" /* Excision of Right Abdomen Bursa and Ligament, Open Approach, Diagnostic */
"0MBH0ZZ" = "1" /* Excision of Right Abdomen Bursa and Ligament, Open Approach */
"0MBH3ZX" = "1" /* Excision of Right Abdomen Bursa and Ligament, Percutaneous Approach, Diagnostic */
"0MBH3ZZ" = "1" /* Excision of Right Abdomen Bursa and Ligament, Percutaneous Approach */
"0MBH4ZX" = "1" /* Excision of Right Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach, Diagnostic */
"0MBH4ZZ" = "1" /* Excision of Right Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MBJ0ZX" = "1" /* Excision of Left Abdomen Bursa and Ligament, Open Approach, Diagnostic */
"0MBJ0ZZ" = "1" /* Excision of Left Abdomen Bursa and Ligament, Open Approach */
"0MBJ3ZX" = "1" /* Excision of Left Abdomen Bursa and Ligament, Percutaneous Approach, Diagnostic */
"0MBJ3ZZ" = "1" /* Excision of Left Abdomen Bursa and Ligament, Percutaneous Approach */
"0MBJ4ZX" = "1" /* Excision of Left Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach, Diagnostic */
"0MBJ4ZZ" = "1" /* Excision of Left Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MBK0ZX" = "1" /* Excision of Perineum Bursa and Ligament, Open Approach, Diagnostic */
"0MBK0ZZ" = "1" /* Excision of Perineum Bursa and Ligament, Open Approach */
"0MBK3ZX" = "1" /* Excision of Perineum Bursa and Ligament, Percutaneous Approach, Diagnostic */
"0MBK3ZZ" = "1" /* Excision of Perineum Bursa and Ligament, Percutaneous Approach */
"0MBK4ZX" = "1" /* Excision of Perineum Bursa and Ligament, Percutaneous Endoscopic Approach, Diagnostic */
"0MBK4ZZ" = "1" /* Excision of Perineum Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MBL0ZZ" = "1" /* Excision of Right Hip Bursa and Ligament, Open Approach */
"0MBL3ZZ" = "1" /* Excision of Right Hip Bursa and Ligament, Percutaneous Approach */
"0MBL4ZZ" = "1" /* Excision of Right Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MBM0ZZ" = "1" /* Excision of Left Hip Bursa and Ligament, Open Approach */
"0MBM3ZZ" = "1" /* Excision of Left Hip Bursa and Ligament, Percutaneous Approach */
"0MBM4ZZ" = "1" /* Excision of Left Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MBN0ZZ" = "1" /* Excision of Right Knee Bursa and Ligament, Open Approach */
"0MBN3ZZ" = "1" /* Excision of Right Knee Bursa and Ligament, Percutaneous Approach */
"0MBN4ZZ" = "1" /* Excision of Right Knee Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MBP0ZZ" = "1" /* Excision of Left Knee Bursa and Ligament, Open Approach */
"0MBP3ZZ" = "1" /* Excision of Left Knee Bursa and Ligament, Percutaneous Approach */
"0MBP4ZZ" = "1" /* Excision of Left Knee Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MBQ0ZZ" = "1" /* Excision of Right Ankle Bursa and Ligament, Open Approach */
"0MBQ3ZZ" = "1" /* Excision of Right Ankle Bursa and Ligament, Percutaneous Approach */
"0MBQ4ZZ" = "1" /* Excision of Right Ankle Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MBR0ZZ" = "1" /* Excision of Left Ankle Bursa and Ligament, Open Approach */
"0MBR3ZZ" = "1" /* Excision of Left Ankle Bursa and Ligament, Percutaneous Approach */
"0MBR4ZZ" = "1" /* Excision of Left Ankle Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MBS0ZZ" = "1" /* Excision of Right Foot Bursa and Ligament, Open Approach */
"0MBS3ZZ" = "1" /* Excision of Right Foot Bursa and Ligament, Percutaneous Approach */
"0MBS4ZZ" = "1" /* Excision of Right Foot Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MBT0ZZ" = "1" /* Excision of Left Foot Bursa and Ligament, Open Approach */
"0MBT3ZZ" = "1" /* Excision of Left Foot Bursa and Ligament, Percutaneous Approach */
"0MBT4ZZ" = "1" /* Excision of Left Foot Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MBV0ZX" = "1" /* Excision of Right Lower Extremity Bursa and Ligament, Open Approach, Diagnostic */
"0MBV0ZZ" = "1" /* Excision of Right Lower Extremity Bursa and Ligament, Open Approach */
"0MBV3ZX" = "1" /* Excision of Right Lower Extremity Bursa and Ligament, Percutaneous Approach, Diagnostic */
"0MBV3ZZ" = "1" /* Excision of Right Lower Extremity Bursa and Ligament, Percutaneous Approach */
"0MBV4ZX" = "1" /* Excision of Right Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach, Diagnostic */
"0MBV4ZZ" = "1" /* Excision of Right Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MBW0ZX" = "1" /* Excision of Left Lower Extremity Bursa and Ligament, Open Approach, Diagnostic */
"0MBW0ZZ" = "1" /* Excision of Left Lower Extremity Bursa and Ligament, Open Approach */
"0MBW3ZX" = "1" /* Excision of Left Lower Extremity Bursa and Ligament, Percutaneous Approach, Diagnostic */
"0MBW3ZZ" = "1" /* Excision of Left Lower Extremity Bursa and Ligament, Percutaneous Approach */
"0MBW4ZX" = "1" /* Excision of Left Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach, Diagnostic */
"0MBW4ZZ" = "1" /* Excision of Left Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MC00ZZ" = "1" /* Extirpation of Matter from Head and Neck Bursa and Ligament, Open Approach */
"0MC03ZZ" = "1" /* Extirpation of Matter from Head and Neck Bursa and Ligament, Percutaneous Approach */
"0MC04ZZ" = "1" /* Extirpation of Matter from Head and Neck Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MC10ZZ" = "1" /* Extirpation of Matter from Right Shoulder Bursa and Ligament, Open Approach */
"0MC13ZZ" = "1" /* Extirpation of Matter from Right Shoulder Bursa and Ligament, Percutaneous Approach */
"0MC14ZZ" = "1" /* Extirpation of Matter from Right Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MC20ZZ" = "1" /* Extirpation of Matter from Left Shoulder Bursa and Ligament, Open Approach */
"0MC23ZZ" = "1" /* Extirpation of Matter from Left Shoulder Bursa and Ligament, Percutaneous Approach */
"0MC24ZZ" = "1" /* Extirpation of Matter from Left Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MC30ZZ" = "1" /* Extirpation of Matter from Right Elbow Bursa and Ligament, Open Approach */
"0MC33ZZ" = "1" /* Extirpation of Matter from Right Elbow Bursa and Ligament, Percutaneous Approach */
"0MC34ZZ" = "1" /* Extirpation of Matter from Right Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MC40ZZ" = "1" /* Extirpation of Matter from Left Elbow Bursa and Ligament, Open Approach */
"0MC43ZZ" = "1" /* Extirpation of Matter from Left Elbow Bursa and Ligament, Percutaneous Approach */
"0MC44ZZ" = "1" /* Extirpation of Matter from Left Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MC50ZZ" = "1" /* Extirpation of Matter from Right Wrist Bursa and Ligament, Open Approach */
"0MC53ZZ" = "1" /* Extirpation of Matter from Right Wrist Bursa and Ligament, Percutaneous Approach */
"0MC54ZZ" = "1" /* Extirpation of Matter from Right Wrist Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MC60ZZ" = "1" /* Extirpation of Matter from Left Wrist Bursa and Ligament, Open Approach */
"0MC63ZZ" = "1" /* Extirpation of Matter from Left Wrist Bursa and Ligament, Percutaneous Approach */
"0MC64ZZ" = "1" /* Extirpation of Matter from Left Wrist Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MC70ZZ" = "1" /* Extirpation of Matter from Right Hand Bursa and Ligament, Open Approach */
"0MC73ZZ" = "1" /* Extirpation of Matter from Right Hand Bursa and Ligament, Percutaneous Approach */
"0MC74ZZ" = "1" /* Extirpation of Matter from Right Hand Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MC80ZZ" = "1" /* Extirpation of Matter from Left Hand Bursa and Ligament, Open Approach */
"0MC83ZZ" = "1" /* Extirpation of Matter from Left Hand Bursa and Ligament, Percutaneous Approach */
"0MC84ZZ" = "1" /* Extirpation of Matter from Left Hand Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MC90ZZ" = "1" /* Extirpation of Matter from Right Upper Extremity Bursa and Ligament, Open Approach */
"0MC93ZZ" = "1" /* Extirpation of Matter from Right Upper Extremity Bursa and Ligament, Percutaneous Approach */
"0MC94ZZ" = "1" /* Extirpation of Matter from Right Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MCB0ZZ" = "1" /* Extirpation of Matter from Left Upper Extremity Bursa and Ligament, Open Approach */
"0MCB3ZZ" = "1" /* Extirpation of Matter from Left Upper Extremity Bursa and Ligament, Percutaneous Approach */
"0MCB4ZZ" = "1" /* Extirpation of Matter from Left Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MCC0ZZ" = "1" /* Extirpation of Matter from Right Trunk Bursa and Ligament, Open Approach */
"0MCC3ZZ" = "1" /* Extirpation of Matter from Right Trunk Bursa and Ligament, Percutaneous Approach */
"0MCC4ZZ" = "1" /* Extirpation of Matter from Right Trunk Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MCD0ZZ" = "1" /* Extirpation of Matter from Left Trunk Bursa and Ligament, Open Approach */
"0MCD3ZZ" = "1" /* Extirpation of Matter from Left Trunk Bursa and Ligament, Percutaneous Approach */
"0MCD4ZZ" = "1" /* Extirpation of Matter from Left Trunk Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MCF0ZZ" = "1" /* Extirpation of Matter from Right Thorax Bursa and Ligament, Open Approach */
"0MCF3ZZ" = "1" /* Extirpation of Matter from Right Thorax Bursa and Ligament, Percutaneous Approach */
"0MCF4ZZ" = "1" /* Extirpation of Matter from Right Thorax Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MCG0ZZ" = "1" /* Extirpation of Matter from Left Thorax Bursa and Ligament, Open Approach */
"0MCG3ZZ" = "1" /* Extirpation of Matter from Left Thorax Bursa and Ligament, Percutaneous Approach */
"0MCG4ZZ" = "1" /* Extirpation of Matter from Left Thorax Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MCH0ZZ" = "1" /* Extirpation of Matter from Right Abdomen Bursa and Ligament, Open Approach */
"0MCH3ZZ" = "1" /* Extirpation of Matter from Right Abdomen Bursa and Ligament, Percutaneous Approach */
"0MCH4ZZ" = "1" /* Extirpation of Matter from Right Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MCJ0ZZ" = "1" /* Extirpation of Matter from Left Abdomen Bursa and Ligament, Open Approach */
"0MCJ3ZZ" = "1" /* Extirpation of Matter from Left Abdomen Bursa and Ligament, Percutaneous Approach */
"0MCJ4ZZ" = "1" /* Extirpation of Matter from Left Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MCK0ZZ" = "1" /* Extirpation of Matter from Perineum Bursa and Ligament, Open Approach */
"0MCK3ZZ" = "1" /* Extirpation of Matter from Perineum Bursa and Ligament, Percutaneous Approach */
"0MCK4ZZ" = "1" /* Extirpation of Matter from Perineum Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MCL0ZZ" = "1" /* Extirpation of Matter from Right Hip Bursa and Ligament, Open Approach */
"0MCL3ZZ" = "1" /* Extirpation of Matter from Right Hip Bursa and Ligament, Percutaneous Approach */
"0MCL4ZZ" = "1" /* Extirpation of Matter from Right Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MCM0ZZ" = "1" /* Extirpation of Matter from Left Hip Bursa and Ligament, Open Approach */
"0MCM3ZZ" = "1" /* Extirpation of Matter from Left Hip Bursa and Ligament, Percutaneous Approach */
"0MCM4ZZ" = "1" /* Extirpation of Matter from Left Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MCN0ZZ" = "1" /* Extirpation of Matter from Right Knee Bursa and Ligament, Open Approach */
"0MCN3ZZ" = "1" /* Extirpation of Matter from Right Knee Bursa and Ligament, Percutaneous Approach */
"0MCN4ZZ" = "1" /* Extirpation of Matter from Right Knee Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MCP0ZZ" = "1" /* Extirpation of Matter from Left Knee Bursa and Ligament, Open Approach */
"0MCP3ZZ" = "1" /* Extirpation of Matter from Left Knee Bursa and Ligament, Percutaneous Approach */
"0MCP4ZZ" = "1" /* Extirpation of Matter from Left Knee Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MCQ0ZZ" = "1" /* Extirpation of Matter from Right Ankle Bursa and Ligament, Open Approach */
"0MCQ3ZZ" = "1" /* Extirpation of Matter from Right Ankle Bursa and Ligament, Percutaneous Approach */
"0MCQ4ZZ" = "1" /* Extirpation of Matter from Right Ankle Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MCR0ZZ" = "1" /* Extirpation of Matter from Left Ankle Bursa and Ligament, Open Approach */
"0MCR3ZZ" = "1" /* Extirpation of Matter from Left Ankle Bursa and Ligament, Percutaneous Approach */
"0MCR4ZZ" = "1" /* Extirpation of Matter from Left Ankle Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MCS0ZZ" = "1" /* Extirpation of Matter from Right Foot Bursa and Ligament, Open Approach */
"0MCS3ZZ" = "1" /* Extirpation of Matter from Right Foot Bursa and Ligament, Percutaneous Approach */
"0MCS4ZZ" = "1" /* Extirpation of Matter from Right Foot Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MCT0ZZ" = "1" /* Extirpation of Matter from Left Foot Bursa and Ligament, Open Approach */
"0MCT3ZZ" = "1" /* Extirpation of Matter from Left Foot Bursa and Ligament, Percutaneous Approach */
"0MCT4ZZ" = "1" /* Extirpation of Matter from Left Foot Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MCV0ZZ" = "1" /* Extirpation of Matter from Right Lower Extremity Bursa and Ligament, Open Approach */
"0MCV3ZZ" = "1" /* Extirpation of Matter from Right Lower Extremity Bursa and Ligament, Percutaneous Approach */
"0MCV4ZZ" = "1" /* Extirpation of Matter from Right Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MCW0ZZ" = "1" /* Extirpation of Matter from Left Lower Extremity Bursa and Ligament, Open Approach */
"0MCW3ZZ" = "1" /* Extirpation of Matter from Left Lower Extremity Bursa and Ligament, Percutaneous Approach */
"0MCW4ZZ" = "1" /* Extirpation of Matter from Left Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MD00ZZ" = "1" /* Extraction of Head and Neck Bursa and Ligament, Open Approach */
"0MD03ZZ" = "1" /* Extraction of Head and Neck Bursa and Ligament, Percutaneous Approach */
"0MD04ZZ" = "1" /* Extraction of Head and Neck Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MD10ZZ" = "1" /* Extraction of Right Shoulder Bursa and Ligament, Open Approach */
"0MD13ZZ" = "1" /* Extraction of Right Shoulder Bursa and Ligament, Percutaneous Approach */
"0MD14ZZ" = "1" /* Extraction of Right Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MD20ZZ" = "1" /* Extraction of Left Shoulder Bursa and Ligament, Open Approach */
"0MD23ZZ" = "1" /* Extraction of Left Shoulder Bursa and Ligament, Percutaneous Approach */
"0MD24ZZ" = "1" /* Extraction of Left Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MD30ZZ" = "1" /* Extraction of Right Elbow Bursa and Ligament, Open Approach */
"0MD33ZZ" = "1" /* Extraction of Right Elbow Bursa and Ligament, Percutaneous Approach */
"0MD34ZZ" = "1" /* Extraction of Right Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MD40ZZ" = "1" /* Extraction of Left Elbow Bursa and Ligament, Open Approach */
"0MD43ZZ" = "1" /* Extraction of Left Elbow Bursa and Ligament, Percutaneous Approach */
"0MD44ZZ" = "1" /* Extraction of Left Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MD50ZZ" = "1" /* Extraction of Right Wrist Bursa and Ligament, Open Approach */
"0MD53ZZ" = "1" /* Extraction of Right Wrist Bursa and Ligament, Percutaneous Approach */
"0MD54ZZ" = "1" /* Extraction of Right Wrist Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MD60ZZ" = "1" /* Extraction of Left Wrist Bursa and Ligament, Open Approach */
"0MD63ZZ" = "1" /* Extraction of Left Wrist Bursa and Ligament, Percutaneous Approach */
"0MD64ZZ" = "1" /* Extraction of Left Wrist Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MD70ZZ" = "1" /* Extraction of Right Hand Bursa and Ligament, Open Approach */
"0MD73ZZ" = "1" /* Extraction of Right Hand Bursa and Ligament, Percutaneous Approach */
"0MD74ZZ" = "1" /* Extraction of Right Hand Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MD80ZZ" = "1" /* Extraction of Left Hand Bursa and Ligament, Open Approach */
"0MD83ZZ" = "1" /* Extraction of Left Hand Bursa and Ligament, Percutaneous Approach */
"0MD84ZZ" = "1" /* Extraction of Left Hand Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MD90ZZ" = "1" /* Extraction of Right Upper Extremity Bursa and Ligament, Open Approach */
"0MD93ZZ" = "1" /* Extraction of Right Upper Extremity Bursa and Ligament, Percutaneous Approach */
"0MD94ZZ" = "1" /* Extraction of Right Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MDB0ZZ" = "1" /* Extraction of Left Upper Extremity Bursa and Ligament, Open Approach */
"0MDB3ZZ" = "1" /* Extraction of Left Upper Extremity Bursa and Ligament, Percutaneous Approach */
"0MDB4ZZ" = "1" /* Extraction of Left Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MDC0ZZ" = "1" /* Extraction of Right Trunk Bursa and Ligament, Open Approach */
"0MDC3ZZ" = "1" /* Extraction of Right Trunk Bursa and Ligament, Percutaneous Approach */
"0MDC4ZZ" = "1" /* Extraction of Right Trunk Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MDD0ZZ" = "1" /* Extraction of Left Trunk Bursa and Ligament, Open Approach */
"0MDD3ZZ" = "1" /* Extraction of Left Trunk Bursa and Ligament, Percutaneous Approach */
"0MDD4ZZ" = "1" /* Extraction of Left Trunk Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MDF0ZZ" = "1" /* Extraction of Right Thorax Bursa and Ligament, Open Approach */
"0MDF3ZZ" = "1" /* Extraction of Right Thorax Bursa and Ligament, Percutaneous Approach */
"0MDF4ZZ" = "1" /* Extraction of Right Thorax Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MDG0ZZ" = "1" /* Extraction of Left Thorax Bursa and Ligament, Open Approach */
"0MDG3ZZ" = "1" /* Extraction of Left Thorax Bursa and Ligament, Percutaneous Approach */
"0MDG4ZZ" = "1" /* Extraction of Left Thorax Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MDH0ZZ" = "1" /* Extraction of Right Abdomen Bursa and Ligament, Open Approach */
"0MDH3ZZ" = "1" /* Extraction of Right Abdomen Bursa and Ligament, Percutaneous Approach */
"0MDH4ZZ" = "1" /* Extraction of Right Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MDJ0ZZ" = "1" /* Extraction of Left Abdomen Bursa and Ligament, Open Approach */
"0MDJ3ZZ" = "1" /* Extraction of Left Abdomen Bursa and Ligament, Percutaneous Approach */
"0MDJ4ZZ" = "1" /* Extraction of Left Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MDK0ZZ" = "1" /* Extraction of Perineum Bursa and Ligament, Open Approach */
"0MDK3ZZ" = "1" /* Extraction of Perineum Bursa and Ligament, Percutaneous Approach */
"0MDK4ZZ" = "1" /* Extraction of Perineum Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MDL0ZZ" = "1" /* Extraction of Right Hip Bursa and Ligament, Open Approach */
"0MDL3ZZ" = "1" /* Extraction of Right Hip Bursa and Ligament, Percutaneous Approach */
"0MDL4ZZ" = "1" /* Extraction of Right Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MDM0ZZ" = "1" /* Extraction of Left Hip Bursa and Ligament, Open Approach */
"0MDM3ZZ" = "1" /* Extraction of Left Hip Bursa and Ligament, Percutaneous Approach */
"0MDM4ZZ" = "1" /* Extraction of Left Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MDN0ZZ" = "1" /* Extraction of Right Knee Bursa and Ligament, Open Approach */
"0MDN3ZZ" = "1" /* Extraction of Right Knee Bursa and Ligament, Percutaneous Approach */
"0MDN4ZZ" = "1" /* Extraction of Right Knee Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MDP0ZZ" = "1" /* Extraction of Left Knee Bursa and Ligament, Open Approach */
"0MDP3ZZ" = "1" /* Extraction of Left Knee Bursa and Ligament, Percutaneous Approach */
"0MDP4ZZ" = "1" /* Extraction of Left Knee Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MDQ0ZZ" = "1" /* Extraction of Right Ankle Bursa and Ligament, Open Approach */
"0MDQ3ZZ" = "1" /* Extraction of Right Ankle Bursa and Ligament, Percutaneous Approach */
"0MDQ4ZZ" = "1" /* Extraction of Right Ankle Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MDR0ZZ" = "1" /* Extraction of Left Ankle Bursa and Ligament, Open Approach */
"0MDR3ZZ" = "1" /* Extraction of Left Ankle Bursa and Ligament, Percutaneous Approach */
"0MDR4ZZ" = "1" /* Extraction of Left Ankle Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MDS0ZZ" = "1" /* Extraction of Right Foot Bursa and Ligament, Open Approach */
"0MDS3ZZ" = "1" /* Extraction of Right Foot Bursa and Ligament, Percutaneous Approach */
"0MDS4ZZ" = "1" /* Extraction of Right Foot Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MDT0ZZ" = "1" /* Extraction of Left Foot Bursa and Ligament, Open Approach */
"0MDT3ZZ" = "1" /* Extraction of Left Foot Bursa and Ligament, Percutaneous Approach */
"0MDT4ZZ" = "1" /* Extraction of Left Foot Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MDV0ZZ" = "1" /* Extraction of Right Lower Extremity Bursa and Ligament, Open Approach */
"0MDV3ZZ" = "1" /* Extraction of Right Lower Extremity Bursa and Ligament, Percutaneous Approach */
"0MDV4ZZ" = "1" /* Extraction of Right Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MDW0ZZ" = "1" /* Extraction of Left Lower Extremity Bursa and Ligament, Open Approach */
"0MDW3ZZ" = "1" /* Extraction of Left Lower Extremity Bursa and Ligament, Percutaneous Approach */
"0MDW4ZZ" = "1" /* Extraction of Left Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MJX0ZZ" = "1" /* Inspection of Upper Bursa and Ligament, Open Approach */
"0MJX4ZZ" = "1" /* Inspection of Upper Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MJY0ZZ" = "1" /* Inspection of Lower Bursa and Ligament, Open Approach */
"0MJY4ZZ" = "1" /* Inspection of Lower Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MM00ZZ" = "1" /* Reattachment of Head and Neck Bursa and Ligament, Open Approach */
"0MM04ZZ" = "1" /* Reattachment of Head and Neck Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MM10ZZ" = "1" /* Reattachment of Right Shoulder Bursa and Ligament, Open Approach */
"0MM14ZZ" = "1" /* Reattachment of Right Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MM20ZZ" = "1" /* Reattachment of Left Shoulder Bursa and Ligament, Open Approach */
"0MM24ZZ" = "1" /* Reattachment of Left Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MM30ZZ" = "1" /* Reattachment of Right Elbow Bursa and Ligament, Open Approach */
"0MM34ZZ" = "1" /* Reattachment of Right Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MM40ZZ" = "1" /* Reattachment of Left Elbow Bursa and Ligament, Open Approach */
"0MM44ZZ" = "1" /* Reattachment of Left Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MM50ZZ" = "1" /* Reattachment of Right Wrist Bursa and Ligament, Open Approach */
"0MM54ZZ" = "1" /* Reattachment of Right Wrist Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MM60ZZ" = "1" /* Reattachment of Left Wrist Bursa and Ligament, Open Approach */
"0MM64ZZ" = "1" /* Reattachment of Left Wrist Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MM70ZZ" = "1" /* Reattachment of Right Hand Bursa and Ligament, Open Approach */
"0MM74ZZ" = "1" /* Reattachment of Right Hand Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MM80ZZ" = "1" /* Reattachment of Left Hand Bursa and Ligament, Open Approach */
"0MM84ZZ" = "1" /* Reattachment of Left Hand Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MM90ZZ" = "1" /* Reattachment of Right Upper Extremity Bursa and Ligament, Open Approach */
"0MM94ZZ" = "1" /* Reattachment of Right Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MMB0ZZ" = "1" /* Reattachment of Left Upper Extremity Bursa and Ligament, Open Approach */
"0MMB4ZZ" = "1" /* Reattachment of Left Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MMC0ZZ" = "1" /* Reattachment of Right Trunk Bursa and Ligament, Open Approach */
"0MMC4ZZ" = "1" /* Reattachment of Right Trunk Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MMD0ZZ" = "1" /* Reattachment of Left Trunk Bursa and Ligament, Open Approach */
"0MMD4ZZ" = "1" /* Reattachment of Left Trunk Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MMF0ZZ" = "1" /* Reattachment of Right Thorax Bursa and Ligament, Open Approach */
"0MMF4ZZ" = "1" /* Reattachment of Right Thorax Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MMG0ZZ" = "1" /* Reattachment of Left Thorax Bursa and Ligament, Open Approach */
"0MMG4ZZ" = "1" /* Reattachment of Left Thorax Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MMH0ZZ" = "1" /* Reattachment of Right Abdomen Bursa and Ligament, Open Approach */
"0MMH4ZZ" = "1" /* Reattachment of Right Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MMJ0ZZ" = "1" /* Reattachment of Left Abdomen Bursa and Ligament, Open Approach */
"0MMJ4ZZ" = "1" /* Reattachment of Left Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MMK0ZZ" = "1" /* Reattachment of Perineum Bursa and Ligament, Open Approach */
"0MMK4ZZ" = "1" /* Reattachment of Perineum Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MML0ZZ" = "1" /* Reattachment of Right Hip Bursa and Ligament, Open Approach */
"0MML4ZZ" = "1" /* Reattachment of Right Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MMM0ZZ" = "1" /* Reattachment of Left Hip Bursa and Ligament, Open Approach */
"0MMM4ZZ" = "1" /* Reattachment of Left Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MMN0ZZ" = "1" /* Reattachment of Right Knee Bursa and Ligament, Open Approach */
"0MMN4ZZ" = "1" /* Reattachment of Right Knee Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MMP0ZZ" = "1" /* Reattachment of Left Knee Bursa and Ligament, Open Approach */
"0MMP4ZZ" = "1" /* Reattachment of Left Knee Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MMQ0ZZ" = "1" /* Reattachment of Right Ankle Bursa and Ligament, Open Approach */
"0MMQ4ZZ" = "1" /* Reattachment of Right Ankle Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MMR0ZZ" = "1" /* Reattachment of Left Ankle Bursa and Ligament, Open Approach */
"0MMR4ZZ" = "1" /* Reattachment of Left Ankle Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MMS0ZZ" = "1" /* Reattachment of Right Foot Bursa and Ligament, Open Approach */
"0MMS4ZZ" = "1" /* Reattachment of Right Foot Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MMT0ZZ" = "1" /* Reattachment of Left Foot Bursa and Ligament, Open Approach */
"0MMT4ZZ" = "1" /* Reattachment of Left Foot Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MMV0ZZ" = "1" /* Reattachment of Right Lower Extremity Bursa and Ligament, Open Approach */
"0MMV4ZZ" = "1" /* Reattachment of Right Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MMW0ZZ" = "1" /* Reattachment of Left Lower Extremity Bursa and Ligament, Open Approach */
"0MMW4ZZ" = "1" /* Reattachment of Left Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MN00ZZ" = "1" /* Release Head and Neck Bursa and Ligament, Open Approach */
"0MN03ZZ" = "1" /* Release Head and Neck Bursa and Ligament, Percutaneous Approach */
"0MN04ZZ" = "1" /* Release Head and Neck Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MN10ZZ" = "1" /* Release Right Shoulder Bursa and Ligament, Open Approach */
"0MN13ZZ" = "1" /* Release Right Shoulder Bursa and Ligament, Percutaneous Approach */
"0MN14ZZ" = "1" /* Release Right Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MN20ZZ" = "1" /* Release Left Shoulder Bursa and Ligament, Open Approach */
"0MN23ZZ" = "1" /* Release Left Shoulder Bursa and Ligament, Percutaneous Approach */
"0MN24ZZ" = "1" /* Release Left Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MN30ZZ" = "1" /* Release Right Elbow Bursa and Ligament, Open Approach */
"0MN33ZZ" = "1" /* Release Right Elbow Bursa and Ligament, Percutaneous Approach */
"0MN34ZZ" = "1" /* Release Right Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MN40ZZ" = "1" /* Release Left Elbow Bursa and Ligament, Open Approach */
"0MN43ZZ" = "1" /* Release Left Elbow Bursa and Ligament, Percutaneous Approach */
"0MN44ZZ" = "1" /* Release Left Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MN50ZZ" = "1" /* Release Right Wrist Bursa and Ligament, Open Approach */
"0MN53ZZ" = "1" /* Release Right Wrist Bursa and Ligament, Percutaneous Approach */
"0MN54ZZ" = "1" /* Release Right Wrist Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MN60ZZ" = "1" /* Release Left Wrist Bursa and Ligament, Open Approach */
"0MN63ZZ" = "1" /* Release Left Wrist Bursa and Ligament, Percutaneous Approach */
"0MN64ZZ" = "1" /* Release Left Wrist Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MN70ZZ" = "1" /* Release Right Hand Bursa and Ligament, Open Approach */
"0MN73ZZ" = "1" /* Release Right Hand Bursa and Ligament, Percutaneous Approach */
"0MN74ZZ" = "1" /* Release Right Hand Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MN80ZZ" = "1" /* Release Left Hand Bursa and Ligament, Open Approach */
"0MN83ZZ" = "1" /* Release Left Hand Bursa and Ligament, Percutaneous Approach */
"0MN84ZZ" = "1" /* Release Left Hand Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MN90ZZ" = "1" /* Release Right Upper Extremity Bursa and Ligament, Open Approach */
"0MN93ZZ" = "1" /* Release Right Upper Extremity Bursa and Ligament, Percutaneous Approach */
"0MN94ZZ" = "1" /* Release Right Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MNB0ZZ" = "1" /* Release Left Upper Extremity Bursa and Ligament, Open Approach */
"0MNB3ZZ" = "1" /* Release Left Upper Extremity Bursa and Ligament, Percutaneous Approach */
"0MNB4ZZ" = "1" /* Release Left Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MNC0ZZ" = "1" /* Release Right Trunk Bursa and Ligament, Open Approach */
"0MNC3ZZ" = "1" /* Release Right Trunk Bursa and Ligament, Percutaneous Approach */
"0MNC4ZZ" = "1" /* Release Right Trunk Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MND0ZZ" = "1" /* Release Left Trunk Bursa and Ligament, Open Approach */
"0MND3ZZ" = "1" /* Release Left Trunk Bursa and Ligament, Percutaneous Approach */
"0MND4ZZ" = "1" /* Release Left Trunk Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MNF0ZZ" = "1" /* Release Right Thorax Bursa and Ligament, Open Approach */
"0MNF3ZZ" = "1" /* Release Right Thorax Bursa and Ligament, Percutaneous Approach */
"0MNF4ZZ" = "1" /* Release Right Thorax Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MNG0ZZ" = "1" /* Release Left Thorax Bursa and Ligament, Open Approach */
"0MNG3ZZ" = "1" /* Release Left Thorax Bursa and Ligament, Percutaneous Approach */
"0MNG4ZZ" = "1" /* Release Left Thorax Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MNH0ZZ" = "1" /* Release Right Abdomen Bursa and Ligament, Open Approach */
"0MNH3ZZ" = "1" /* Release Right Abdomen Bursa and Ligament, Percutaneous Approach */
"0MNH4ZZ" = "1" /* Release Right Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MNJ0ZZ" = "1" /* Release Left Abdomen Bursa and Ligament, Open Approach */
"0MNJ3ZZ" = "1" /* Release Left Abdomen Bursa and Ligament, Percutaneous Approach */
"0MNJ4ZZ" = "1" /* Release Left Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MNK0ZZ" = "1" /* Release Perineum Bursa and Ligament, Open Approach */
"0MNK3ZZ" = "1" /* Release Perineum Bursa and Ligament, Percutaneous Approach */
"0MNK4ZZ" = "1" /* Release Perineum Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MNL0ZZ" = "1" /* Release Right Hip Bursa and Ligament, Open Approach */
"0MNL3ZZ" = "1" /* Release Right Hip Bursa and Ligament, Percutaneous Approach */
"0MNL4ZZ" = "1" /* Release Right Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MNM0ZZ" = "1" /* Release Left Hip Bursa and Ligament, Open Approach */
"0MNM3ZZ" = "1" /* Release Left Hip Bursa and Ligament, Percutaneous Approach */
"0MNM4ZZ" = "1" /* Release Left Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MNN0ZZ" = "1" /* Release Right Knee Bursa and Ligament, Open Approach */
"0MNN3ZZ" = "1" /* Release Right Knee Bursa and Ligament, Percutaneous Approach */
"0MNN4ZZ" = "1" /* Release Right Knee Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MNP0ZZ" = "1" /* Release Left Knee Bursa and Ligament, Open Approach */
"0MNP3ZZ" = "1" /* Release Left Knee Bursa and Ligament, Percutaneous Approach */
"0MNP4ZZ" = "1" /* Release Left Knee Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MNQ0ZZ" = "1" /* Release Right Ankle Bursa and Ligament, Open Approach */
"0MNQ3ZZ" = "1" /* Release Right Ankle Bursa and Ligament, Percutaneous Approach */
"0MNQ4ZZ" = "1" /* Release Right Ankle Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MNR0ZZ" = "1" /* Release Left Ankle Bursa and Ligament, Open Approach */
"0MNR3ZZ" = "1" /* Release Left Ankle Bursa and Ligament, Percutaneous Approach */
"0MNR4ZZ" = "1" /* Release Left Ankle Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MNS0ZZ" = "1" /* Release Right Foot Bursa and Ligament, Open Approach */
"0MNS3ZZ" = "1" /* Release Right Foot Bursa and Ligament, Percutaneous Approach */
"0MNS4ZZ" = "1" /* Release Right Foot Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MNT0ZZ" = "1" /* Release Left Foot Bursa and Ligament, Open Approach */
"0MNT3ZZ" = "1" /* Release Left Foot Bursa and Ligament, Percutaneous Approach */
"0MNT4ZZ" = "1" /* Release Left Foot Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MNV0ZZ" = "1" /* Release Right Lower Extremity Bursa and Ligament, Open Approach */
"0MNV3ZZ" = "1" /* Release Right Lower Extremity Bursa and Ligament, Percutaneous Approach */
"0MNV4ZZ" = "1" /* Release Right Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MNW0ZZ" = "1" /* Release Left Lower Extremity Bursa and Ligament, Open Approach */
"0MNW3ZZ" = "1" /* Release Left Lower Extremity Bursa and Ligament, Percutaneous Approach */
"0MNW4ZZ" = "1" /* Release Left Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MPX00Z" = "1" /* Removal of Drainage Device from Upper Bursa and Ligament, Open Approach */
"0MPX07Z" = "1" /* Removal of Autologous Tissue Substitute from Upper Bursa and Ligament, Open Approach */
"0MPX0JZ" = "1" /* Removal of Synthetic Substitute from Upper Bursa and Ligament, Open Approach */
"0MPX0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Upper Bursa and Ligament, Open Approach */
"0MPX37Z" = "1" /* Removal of Autologous Tissue Substitute from Upper Bursa and Ligament, Percutaneous Approach */
"0MPX3JZ" = "1" /* Removal of Synthetic Substitute from Upper Bursa and Ligament, Percutaneous Approach */
"0MPX3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Upper Bursa and Ligament, Percutaneous Approach */
"0MPX40Z" = "1" /* Removal of Drainage Device from Upper Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MPX47Z" = "1" /* Removal of Autologous Tissue Substitute from Upper Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MPX4JZ" = "1" /* Removal of Synthetic Substitute from Upper Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MPX4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Upper Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MPY00Z" = "1" /* Removal of Drainage Device from Lower Bursa and Ligament, Open Approach */
"0MPY07Z" = "1" /* Removal of Autologous Tissue Substitute from Lower Bursa and Ligament, Open Approach */
"0MPY0JZ" = "1" /* Removal of Synthetic Substitute from Lower Bursa and Ligament, Open Approach */
"0MPY0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lower Bursa and Ligament, Open Approach */
"0MPY37Z" = "1" /* Removal of Autologous Tissue Substitute from Lower Bursa and Ligament, Percutaneous Approach */
"0MPY3JZ" = "1" /* Removal of Synthetic Substitute from Lower Bursa and Ligament, Percutaneous Approach */
"0MPY3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lower Bursa and Ligament, Percutaneous Approach */
"0MPY40Z" = "1" /* Removal of Drainage Device from Lower Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MPY47Z" = "1" /* Removal of Autologous Tissue Substitute from Lower Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MPY4JZ" = "1" /* Removal of Synthetic Substitute from Lower Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MPY4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lower Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQ00ZZ" = "1" /* Repair Head and Neck Bursa and Ligament, Open Approach */
"0MQ03ZZ" = "1" /* Repair Head and Neck Bursa and Ligament, Percutaneous Approach */
"0MQ04ZZ" = "1" /* Repair Head and Neck Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQ10ZZ" = "1" /* Repair Right Shoulder Bursa and Ligament, Open Approach */
"0MQ13ZZ" = "1" /* Repair Right Shoulder Bursa and Ligament, Percutaneous Approach */
"0MQ14ZZ" = "1" /* Repair Right Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQ20ZZ" = "1" /* Repair Left Shoulder Bursa and Ligament, Open Approach */
"0MQ23ZZ" = "1" /* Repair Left Shoulder Bursa and Ligament, Percutaneous Approach */
"0MQ24ZZ" = "1" /* Repair Left Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQ30ZZ" = "1" /* Repair Right Elbow Bursa and Ligament, Open Approach */
"0MQ33ZZ" = "1" /* Repair Right Elbow Bursa and Ligament, Percutaneous Approach */
"0MQ34ZZ" = "1" /* Repair Right Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQ40ZZ" = "1" /* Repair Left Elbow Bursa and Ligament, Open Approach */
"0MQ43ZZ" = "1" /* Repair Left Elbow Bursa and Ligament, Percutaneous Approach */
"0MQ44ZZ" = "1" /* Repair Left Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQ50ZZ" = "1" /* Repair Right Wrist Bursa and Ligament, Open Approach */
"0MQ53ZZ" = "1" /* Repair Right Wrist Bursa and Ligament, Percutaneous Approach */
"0MQ54ZZ" = "1" /* Repair Right Wrist Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQ60ZZ" = "1" /* Repair Left Wrist Bursa and Ligament, Open Approach */
"0MQ63ZZ" = "1" /* Repair Left Wrist Bursa and Ligament, Percutaneous Approach */
"0MQ64ZZ" = "1" /* Repair Left Wrist Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQ70ZZ" = "1" /* Repair Right Hand Bursa and Ligament, Open Approach */
"0MQ73ZZ" = "1" /* Repair Right Hand Bursa and Ligament, Percutaneous Approach */
"0MQ74ZZ" = "1" /* Repair Right Hand Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQ80ZZ" = "1" /* Repair Left Hand Bursa and Ligament, Open Approach */
"0MQ83ZZ" = "1" /* Repair Left Hand Bursa and Ligament, Percutaneous Approach */
"0MQ84ZZ" = "1" /* Repair Left Hand Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQ90ZZ" = "1" /* Repair Right Upper Extremity Bursa and Ligament, Open Approach */
"0MQ93ZZ" = "1" /* Repair Right Upper Extremity Bursa and Ligament, Percutaneous Approach */
"0MQ94ZZ" = "1" /* Repair Right Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQB0ZZ" = "1" /* Repair Left Upper Extremity Bursa and Ligament, Open Approach */
"0MQB3ZZ" = "1" /* Repair Left Upper Extremity Bursa and Ligament, Percutaneous Approach */
"0MQB4ZZ" = "1" /* Repair Left Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQC0ZZ" = "1" /* Repair Right Trunk Bursa and Ligament, Open Approach */
"0MQC3ZZ" = "1" /* Repair Right Trunk Bursa and Ligament, Percutaneous Approach */
"0MQC4ZZ" = "1" /* Repair Right Trunk Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQD0ZZ" = "1" /* Repair Left Trunk Bursa and Ligament, Open Approach */
"0MQD3ZZ" = "1" /* Repair Left Trunk Bursa and Ligament, Percutaneous Approach */
"0MQD4ZZ" = "1" /* Repair Left Trunk Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQF0ZZ" = "1" /* Repair Right Thorax Bursa and Ligament, Open Approach */
"0MQF3ZZ" = "1" /* Repair Right Thorax Bursa and Ligament, Percutaneous Approach */
"0MQF4ZZ" = "1" /* Repair Right Thorax Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQG0ZZ" = "1" /* Repair Left Thorax Bursa and Ligament, Open Approach */
"0MQG3ZZ" = "1" /* Repair Left Thorax Bursa and Ligament, Percutaneous Approach */
"0MQG4ZZ" = "1" /* Repair Left Thorax Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQH0ZZ" = "1" /* Repair Right Abdomen Bursa and Ligament, Open Approach */
"0MQH3ZZ" = "1" /* Repair Right Abdomen Bursa and Ligament, Percutaneous Approach */
"0MQH4ZZ" = "1" /* Repair Right Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQJ0ZZ" = "1" /* Repair Left Abdomen Bursa and Ligament, Open Approach */
"0MQJ3ZZ" = "1" /* Repair Left Abdomen Bursa and Ligament, Percutaneous Approach */
"0MQJ4ZZ" = "1" /* Repair Left Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQK0ZZ" = "1" /* Repair Perineum Bursa and Ligament, Open Approach */
"0MQK3ZZ" = "1" /* Repair Perineum Bursa and Ligament, Percutaneous Approach */
"0MQK4ZZ" = "1" /* Repair Perineum Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQL0ZZ" = "1" /* Repair Right Hip Bursa and Ligament, Open Approach */
"0MQL3ZZ" = "1" /* Repair Right Hip Bursa and Ligament, Percutaneous Approach */
"0MQL4ZZ" = "1" /* Repair Right Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQM0ZZ" = "1" /* Repair Left Hip Bursa and Ligament, Open Approach */
"0MQM3ZZ" = "1" /* Repair Left Hip Bursa and Ligament, Percutaneous Approach */
"0MQM4ZZ" = "1" /* Repair Left Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQN0ZZ" = "1" /* Repair Right Knee Bursa and Ligament, Open Approach */
"0MQN3ZZ" = "1" /* Repair Right Knee Bursa and Ligament, Percutaneous Approach */
"0MQN4ZZ" = "1" /* Repair Right Knee Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQP0ZZ" = "1" /* Repair Left Knee Bursa and Ligament, Open Approach */
"0MQP3ZZ" = "1" /* Repair Left Knee Bursa and Ligament, Percutaneous Approach */
"0MQP4ZZ" = "1" /* Repair Left Knee Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQQ0ZZ" = "1" /* Repair Right Ankle Bursa and Ligament, Open Approach */
"0MQQ3ZZ" = "1" /* Repair Right Ankle Bursa and Ligament, Percutaneous Approach */
"0MQQ4ZZ" = "1" /* Repair Right Ankle Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQR0ZZ" = "1" /* Repair Left Ankle Bursa and Ligament, Open Approach */
"0MQR3ZZ" = "1" /* Repair Left Ankle Bursa and Ligament, Percutaneous Approach */
"0MQR4ZZ" = "1" /* Repair Left Ankle Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQS0ZZ" = "1" /* Repair Right Foot Bursa and Ligament, Open Approach */
"0MQS3ZZ" = "1" /* Repair Right Foot Bursa and Ligament, Percutaneous Approach */
"0MQS4ZZ" = "1" /* Repair Right Foot Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQT0ZZ" = "1" /* Repair Left Foot Bursa and Ligament, Open Approach */
"0MQT3ZZ" = "1" /* Repair Left Foot Bursa and Ligament, Percutaneous Approach */
"0MQT4ZZ" = "1" /* Repair Left Foot Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQV0ZZ" = "1" /* Repair Right Lower Extremity Bursa and Ligament, Open Approach */
"0MQV3ZZ" = "1" /* Repair Right Lower Extremity Bursa and Ligament, Percutaneous Approach */
"0MQV4ZZ" = "1" /* Repair Right Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MQW0ZZ" = "1" /* Repair Left Lower Extremity Bursa and Ligament, Open Approach */
"0MQW3ZZ" = "1" /* Repair Left Lower Extremity Bursa and Ligament, Percutaneous Approach */
"0MQW4ZZ" = "1" /* Repair Left Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MS00ZZ" = "1" /* Reposition Head and Neck Bursa and Ligament, Open Approach */
"0MS04ZZ" = "1" /* Reposition Head and Neck Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MS10ZZ" = "1" /* Reposition Right Shoulder Bursa and Ligament, Open Approach */
"0MS14ZZ" = "1" /* Reposition Right Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MS20ZZ" = "1" /* Reposition Left Shoulder Bursa and Ligament, Open Approach */
"0MS24ZZ" = "1" /* Reposition Left Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MS30ZZ" = "1" /* Reposition Right Elbow Bursa and Ligament, Open Approach */
"0MS34ZZ" = "1" /* Reposition Right Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MS40ZZ" = "1" /* Reposition Left Elbow Bursa and Ligament, Open Approach */
"0MS44ZZ" = "1" /* Reposition Left Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MS50ZZ" = "1" /* Reposition Right Wrist Bursa and Ligament, Open Approach */
"0MS54ZZ" = "1" /* Reposition Right Wrist Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MS60ZZ" = "1" /* Reposition Left Wrist Bursa and Ligament, Open Approach */
"0MS64ZZ" = "1" /* Reposition Left Wrist Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MS70ZZ" = "1" /* Reposition Right Hand Bursa and Ligament, Open Approach */
"0MS74ZZ" = "1" /* Reposition Right Hand Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MS80ZZ" = "1" /* Reposition Left Hand Bursa and Ligament, Open Approach */
"0MS84ZZ" = "1" /* Reposition Left Hand Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MS90ZZ" = "1" /* Reposition Right Upper Extremity Bursa and Ligament, Open Approach */
"0MS94ZZ" = "1" /* Reposition Right Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MSB0ZZ" = "1" /* Reposition Left Upper Extremity Bursa and Ligament, Open Approach */
"0MSB4ZZ" = "1" /* Reposition Left Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MSC0ZZ" = "1" /* Reposition Right Trunk Bursa and Ligament, Open Approach */
"0MSC4ZZ" = "1" /* Reposition Right Trunk Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MSD0ZZ" = "1" /* Reposition Left Trunk Bursa and Ligament, Open Approach */
"0MSD4ZZ" = "1" /* Reposition Left Trunk Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MSF0ZZ" = "1" /* Reposition Right Thorax Bursa and Ligament, Open Approach */
"0MSF4ZZ" = "1" /* Reposition Right Thorax Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MSG0ZZ" = "1" /* Reposition Left Thorax Bursa and Ligament, Open Approach */
"0MSG4ZZ" = "1" /* Reposition Left Thorax Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MSH0ZZ" = "1" /* Reposition Right Abdomen Bursa and Ligament, Open Approach */
"0MSH4ZZ" = "1" /* Reposition Right Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MSJ0ZZ" = "1" /* Reposition Left Abdomen Bursa and Ligament, Open Approach */
"0MSJ4ZZ" = "1" /* Reposition Left Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MSK0ZZ" = "1" /* Reposition Perineum Bursa and Ligament, Open Approach */
"0MSK4ZZ" = "1" /* Reposition Perineum Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MSL0ZZ" = "1" /* Reposition Right Hip Bursa and Ligament, Open Approach */
"0MSL4ZZ" = "1" /* Reposition Right Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MSM0ZZ" = "1" /* Reposition Left Hip Bursa and Ligament, Open Approach */
"0MSM4ZZ" = "1" /* Reposition Left Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MSN0ZZ" = "1" /* Reposition Right Knee Bursa and Ligament, Open Approach */
"0MSN4ZZ" = "1" /* Reposition Right Knee Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MSP0ZZ" = "1" /* Reposition Left Knee Bursa and Ligament, Open Approach */
"0MSP4ZZ" = "1" /* Reposition Left Knee Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MSQ0ZZ" = "1" /* Reposition Right Ankle Bursa and Ligament, Open Approach */
"0MSQ4ZZ" = "1" /* Reposition Right Ankle Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MSR0ZZ" = "1" /* Reposition Left Ankle Bursa and Ligament, Open Approach */
"0MSR4ZZ" = "1" /* Reposition Left Ankle Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MSS0ZZ" = "1" /* Reposition Right Foot Bursa and Ligament, Open Approach */
"0MSS4ZZ" = "1" /* Reposition Right Foot Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MST0ZZ" = "1" /* Reposition Left Foot Bursa and Ligament, Open Approach */
"0MST4ZZ" = "1" /* Reposition Left Foot Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MSV0ZZ" = "1" /* Reposition Right Lower Extremity Bursa and Ligament, Open Approach */
"0MSV4ZZ" = "1" /* Reposition Right Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MSW0ZZ" = "1" /* Reposition Left Lower Extremity Bursa and Ligament, Open Approach */
"0MSW4ZZ" = "1" /* Reposition Left Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MT00ZZ" = "1" /* Resection of Head and Neck Bursa and Ligament, Open Approach */
"0MT04ZZ" = "1" /* Resection of Head and Neck Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MT10ZZ" = "1" /* Resection of Right Shoulder Bursa and Ligament, Open Approach */
"0MT14ZZ" = "1" /* Resection of Right Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MT20ZZ" = "1" /* Resection of Left Shoulder Bursa and Ligament, Open Approach */
"0MT24ZZ" = "1" /* Resection of Left Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MT30ZZ" = "1" /* Resection of Right Elbow Bursa and Ligament, Open Approach */
"0MT34ZZ" = "1" /* Resection of Right Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MT40ZZ" = "1" /* Resection of Left Elbow Bursa and Ligament, Open Approach */
"0MT44ZZ" = "1" /* Resection of Left Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MT50ZZ" = "1" /* Resection of Right Wrist Bursa and Ligament, Open Approach */
"0MT54ZZ" = "1" /* Resection of Right Wrist Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MT60ZZ" = "1" /* Resection of Left Wrist Bursa and Ligament, Open Approach */
"0MT64ZZ" = "1" /* Resection of Left Wrist Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MT70ZZ" = "1" /* Resection of Right Hand Bursa and Ligament, Open Approach */
"0MT74ZZ" = "1" /* Resection of Right Hand Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MT80ZZ" = "1" /* Resection of Left Hand Bursa and Ligament, Open Approach */
"0MT84ZZ" = "1" /* Resection of Left Hand Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MT90ZZ" = "1" /* Resection of Right Upper Extremity Bursa and Ligament, Open Approach */
"0MT94ZZ" = "1" /* Resection of Right Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MTB0ZZ" = "1" /* Resection of Left Upper Extremity Bursa and Ligament, Open Approach */
"0MTB4ZZ" = "1" /* Resection of Left Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MTC0ZZ" = "1" /* Resection of Right Trunk Bursa and Ligament, Open Approach */
"0MTC4ZZ" = "1" /* Resection of Right Trunk Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MTD0ZZ" = "1" /* Resection of Left Trunk Bursa and Ligament, Open Approach */
"0MTD4ZZ" = "1" /* Resection of Left Trunk Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MTF0ZZ" = "1" /* Resection of Right Thorax Bursa and Ligament, Open Approach */
"0MTF4ZZ" = "1" /* Resection of Right Thorax Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MTG0ZZ" = "1" /* Resection of Left Thorax Bursa and Ligament, Open Approach */
"0MTG4ZZ" = "1" /* Resection of Left Thorax Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MTH0ZZ" = "1" /* Resection of Right Abdomen Bursa and Ligament, Open Approach */
"0MTH4ZZ" = "1" /* Resection of Right Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MTJ0ZZ" = "1" /* Resection of Left Abdomen Bursa and Ligament, Open Approach */
"0MTJ4ZZ" = "1" /* Resection of Left Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MTK0ZZ" = "1" /* Resection of Perineum Bursa and Ligament, Open Approach */
"0MTK4ZZ" = "1" /* Resection of Perineum Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MTL0ZZ" = "1" /* Resection of Right Hip Bursa and Ligament, Open Approach */
"0MTL4ZZ" = "1" /* Resection of Right Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MTM0ZZ" = "1" /* Resection of Left Hip Bursa and Ligament, Open Approach */
"0MTM4ZZ" = "1" /* Resection of Left Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MTN0ZZ" = "1" /* Resection of Right Knee Bursa and Ligament, Open Approach */
"0MTN4ZZ" = "1" /* Resection of Right Knee Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MTP0ZZ" = "1" /* Resection of Left Knee Bursa and Ligament, Open Approach */
"0MTP4ZZ" = "1" /* Resection of Left Knee Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MTQ0ZZ" = "1" /* Resection of Right Ankle Bursa and Ligament, Open Approach */
"0MTQ4ZZ" = "1" /* Resection of Right Ankle Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MTR0ZZ" = "1" /* Resection of Left Ankle Bursa and Ligament, Open Approach */
"0MTR4ZZ" = "1" /* Resection of Left Ankle Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MTS0ZZ" = "1" /* Resection of Right Foot Bursa and Ligament, Open Approach */
"0MTS4ZZ" = "1" /* Resection of Right Foot Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MTT0ZZ" = "1" /* Resection of Left Foot Bursa and Ligament, Open Approach */
"0MTT4ZZ" = "1" /* Resection of Left Foot Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MTV0ZZ" = "1" /* Resection of Right Lower Extremity Bursa and Ligament, Open Approach */
"0MTV4ZZ" = "1" /* Resection of Right Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MTW0ZZ" = "1" /* Resection of Left Lower Extremity Bursa and Ligament, Open Approach */
"0MTW4ZZ" = "1" /* Resection of Left Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MU007Z" = "1" /* Supplement Head and Neck Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MU00JZ" = "1" /* Supplement Head and Neck Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MU00KZ" = "1" /* Supplement Head and Neck Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MU047Z" = "1" /* Supplement Head and Neck Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MU04JZ" = "1" /* Supplement Head and Neck Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MU04KZ" = "1" /* Supplement Head and Neck Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MU107Z" = "1" /* Supplement Right Shoulder Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MU10JZ" = "1" /* Supplement Right Shoulder Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MU10KZ" = "1" /* Supplement Right Shoulder Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MU147Z" = "1" /* Supplement Right Shoulder Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MU14JZ" = "1" /* Supplement Right Shoulder Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MU14KZ" = "1" /* Supplement Right Shoulder Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MU207Z" = "1" /* Supplement Left Shoulder Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MU20JZ" = "1" /* Supplement Left Shoulder Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MU20KZ" = "1" /* Supplement Left Shoulder Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MU247Z" = "1" /* Supplement Left Shoulder Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MU24JZ" = "1" /* Supplement Left Shoulder Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MU24KZ" = "1" /* Supplement Left Shoulder Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MU307Z" = "1" /* Supplement Right Elbow Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MU30JZ" = "1" /* Supplement Right Elbow Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MU30KZ" = "1" /* Supplement Right Elbow Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MU347Z" = "1" /* Supplement Right Elbow Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MU34JZ" = "1" /* Supplement Right Elbow Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MU34KZ" = "1" /* Supplement Right Elbow Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MU407Z" = "1" /* Supplement Left Elbow Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MU40JZ" = "1" /* Supplement Left Elbow Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MU40KZ" = "1" /* Supplement Left Elbow Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MU447Z" = "1" /* Supplement Left Elbow Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MU44JZ" = "1" /* Supplement Left Elbow Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MU44KZ" = "1" /* Supplement Left Elbow Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MU507Z" = "1" /* Supplement Right Wrist Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MU50JZ" = "1" /* Supplement Right Wrist Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MU50KZ" = "1" /* Supplement Right Wrist Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MU547Z" = "1" /* Supplement Right Wrist Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MU54JZ" = "1" /* Supplement Right Wrist Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MU54KZ" = "1" /* Supplement Right Wrist Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MU607Z" = "1" /* Supplement Left Wrist Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MU60JZ" = "1" /* Supplement Left Wrist Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MU60KZ" = "1" /* Supplement Left Wrist Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MU647Z" = "1" /* Supplement Left Wrist Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MU64JZ" = "1" /* Supplement Left Wrist Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MU64KZ" = "1" /* Supplement Left Wrist Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MU707Z" = "1" /* Supplement Right Hand Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MU70JZ" = "1" /* Supplement Right Hand Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MU70KZ" = "1" /* Supplement Right Hand Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MU747Z" = "1" /* Supplement Right Hand Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MU74JZ" = "1" /* Supplement Right Hand Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MU74KZ" = "1" /* Supplement Right Hand Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MU807Z" = "1" /* Supplement Left Hand Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MU80JZ" = "1" /* Supplement Left Hand Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MU80KZ" = "1" /* Supplement Left Hand Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MU847Z" = "1" /* Supplement Left Hand Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MU84JZ" = "1" /* Supplement Left Hand Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MU84KZ" = "1" /* Supplement Left Hand Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MU907Z" = "1" /* Supplement Right Upper Extremity Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MU90JZ" = "1" /* Supplement Right Upper Extremity Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MU90KZ" = "1" /* Supplement Right Upper Extremity Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MU947Z" = "1" /* Supplement Right Upper Extremity Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MU94JZ" = "1" /* Supplement Right Upper Extremity Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MU94KZ" = "1" /* Supplement Right Upper Extremity Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUB07Z" = "1" /* Supplement Left Upper Extremity Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MUB0JZ" = "1" /* Supplement Left Upper Extremity Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MUB0KZ" = "1" /* Supplement Left Upper Extremity Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MUB47Z" = "1" /* Supplement Left Upper Extremity Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUB4JZ" = "1" /* Supplement Left Upper Extremity Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MUB4KZ" = "1" /* Supplement Left Upper Extremity Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUC07Z" = "1" /* Supplement Right Trunk Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MUC0JZ" = "1" /* Supplement Right Trunk Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MUC0KZ" = "1" /* Supplement Right Trunk Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MUC47Z" = "1" /* Supplement Right Trunk Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUC4JZ" = "1" /* Supplement Right Trunk Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MUC4KZ" = "1" /* Supplement Right Trunk Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUD07Z" = "1" /* Supplement Left Trunk Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MUD0JZ" = "1" /* Supplement Left Trunk Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MUD0KZ" = "1" /* Supplement Left Trunk Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MUD47Z" = "1" /* Supplement Left Trunk Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUD4JZ" = "1" /* Supplement Left Trunk Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MUD4KZ" = "1" /* Supplement Left Trunk Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUF07Z" = "1" /* Supplement Right Thorax Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MUF0JZ" = "1" /* Supplement Right Thorax Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MUF0KZ" = "1" /* Supplement Right Thorax Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MUF47Z" = "1" /* Supplement Right Thorax Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUF4JZ" = "1" /* Supplement Right Thorax Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MUF4KZ" = "1" /* Supplement Right Thorax Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUG07Z" = "1" /* Supplement Left Thorax Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MUG0JZ" = "1" /* Supplement Left Thorax Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MUG0KZ" = "1" /* Supplement Left Thorax Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MUG47Z" = "1" /* Supplement Left Thorax Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUG4JZ" = "1" /* Supplement Left Thorax Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MUG4KZ" = "1" /* Supplement Left Thorax Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUH07Z" = "1" /* Supplement Right Abdomen Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MUH0JZ" = "1" /* Supplement Right Abdomen Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MUH0KZ" = "1" /* Supplement Right Abdomen Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MUH47Z" = "1" /* Supplement Right Abdomen Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUH4JZ" = "1" /* Supplement Right Abdomen Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MUH4KZ" = "1" /* Supplement Right Abdomen Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUJ07Z" = "1" /* Supplement Left Abdomen Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MUJ0JZ" = "1" /* Supplement Left Abdomen Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MUJ0KZ" = "1" /* Supplement Left Abdomen Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MUJ47Z" = "1" /* Supplement Left Abdomen Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUJ4JZ" = "1" /* Supplement Left Abdomen Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MUJ4KZ" = "1" /* Supplement Left Abdomen Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUK07Z" = "1" /* Supplement Perineum Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MUK0JZ" = "1" /* Supplement Perineum Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MUK0KZ" = "1" /* Supplement Perineum Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MUK47Z" = "1" /* Supplement Perineum Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUK4JZ" = "1" /* Supplement Perineum Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MUK4KZ" = "1" /* Supplement Perineum Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUL07Z" = "1" /* Supplement Right Hip Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MUL0JZ" = "1" /* Supplement Right Hip Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MUL0KZ" = "1" /* Supplement Right Hip Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MUL47Z" = "1" /* Supplement Right Hip Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUL4JZ" = "1" /* Supplement Right Hip Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MUL4KZ" = "1" /* Supplement Right Hip Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUM07Z" = "1" /* Supplement Left Hip Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MUM0JZ" = "1" /* Supplement Left Hip Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MUM0KZ" = "1" /* Supplement Left Hip Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MUM47Z" = "1" /* Supplement Left Hip Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUM4JZ" = "1" /* Supplement Left Hip Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MUM4KZ" = "1" /* Supplement Left Hip Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUN07Z" = "1" /* Supplement Right Knee Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MUN0JZ" = "1" /* Supplement Right Knee Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MUN0KZ" = "1" /* Supplement Right Knee Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MUN47Z" = "1" /* Supplement Right Knee Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUN4JZ" = "1" /* Supplement Right Knee Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MUN4KZ" = "1" /* Supplement Right Knee Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUP07Z" = "1" /* Supplement Left Knee Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MUP0JZ" = "1" /* Supplement Left Knee Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MUP0KZ" = "1" /* Supplement Left Knee Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MUP47Z" = "1" /* Supplement Left Knee Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUP4JZ" = "1" /* Supplement Left Knee Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MUP4KZ" = "1" /* Supplement Left Knee Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUQ07Z" = "1" /* Supplement Right Ankle Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MUQ0JZ" = "1" /* Supplement Right Ankle Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MUQ0KZ" = "1" /* Supplement Right Ankle Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MUQ47Z" = "1" /* Supplement Right Ankle Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUQ4JZ" = "1" /* Supplement Right Ankle Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MUQ4KZ" = "1" /* Supplement Right Ankle Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUR07Z" = "1" /* Supplement Left Ankle Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MUR0JZ" = "1" /* Supplement Left Ankle Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MUR0KZ" = "1" /* Supplement Left Ankle Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MUR47Z" = "1" /* Supplement Left Ankle Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUR4JZ" = "1" /* Supplement Left Ankle Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MUR4KZ" = "1" /* Supplement Left Ankle Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUS07Z" = "1" /* Supplement Right Foot Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MUS0JZ" = "1" /* Supplement Right Foot Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MUS0KZ" = "1" /* Supplement Right Foot Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MUS47Z" = "1" /* Supplement Right Foot Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUS4JZ" = "1" /* Supplement Right Foot Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MUS4KZ" = "1" /* Supplement Right Foot Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUT07Z" = "1" /* Supplement Left Foot Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MUT0JZ" = "1" /* Supplement Left Foot Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MUT0KZ" = "1" /* Supplement Left Foot Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MUT47Z" = "1" /* Supplement Left Foot Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUT4JZ" = "1" /* Supplement Left Foot Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MUT4KZ" = "1" /* Supplement Left Foot Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUV07Z" = "1" /* Supplement Right Lower Extremity Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MUV0JZ" = "1" /* Supplement Right Lower Extremity Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MUV0KZ" = "1" /* Supplement Right Lower Extremity Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MUV47Z" = "1" /* Supplement Right Lower Extremity Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUV4JZ" = "1" /* Supplement Right Lower Extremity Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MUV4KZ" = "1" /* Supplement Right Lower Extremity Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUW07Z" = "1" /* Supplement Left Lower Extremity Bursa and Ligament with Autologous Tissue Substitute, Open Approach */
"0MUW0JZ" = "1" /* Supplement Left Lower Extremity Bursa and Ligament with Synthetic Substitute, Open Approach */
"0MUW0KZ" = "1" /* Supplement Left Lower Extremity Bursa and Ligament with Nonautologous Tissue Substitute, Open Approach */
"0MUW47Z" = "1" /* Supplement Left Lower Extremity Bursa and Ligament with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MUW4JZ" = "1" /* Supplement Left Lower Extremity Bursa and Ligament with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0MUW4KZ" = "1" /* Supplement Left Lower Extremity Bursa and Ligament with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0MWX00Z" = "1" /* Revision of Drainage Device in Upper Bursa and Ligament, Open Approach */
"0MWX07Z" = "1" /* Revision of Autologous Tissue Substitute in Upper Bursa and Ligament, Open Approach */
"0MWX0JZ" = "1" /* Revision of Synthetic Substitute in Upper Bursa and Ligament, Open Approach */
"0MWX0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Bursa and Ligament, Open Approach */
"0MWX30Z" = "1" /* Revision of Drainage Device in Upper Bursa and Ligament, Percutaneous Approach */
"0MWX37Z" = "1" /* Revision of Autologous Tissue Substitute in Upper Bursa and Ligament, Percutaneous Approach */
"0MWX3JZ" = "1" /* Revision of Synthetic Substitute in Upper Bursa and Ligament, Percutaneous Approach */
"0MWX3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Bursa and Ligament, Percutaneous Approach */
"0MWX40Z" = "1" /* Revision of Drainage Device in Upper Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MWX47Z" = "1" /* Revision of Autologous Tissue Substitute in Upper Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MWX4JZ" = "1" /* Revision of Synthetic Substitute in Upper Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MWX4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Upper Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MWY00Z" = "1" /* Revision of Drainage Device in Lower Bursa and Ligament, Open Approach */
"0MWY07Z" = "1" /* Revision of Autologous Tissue Substitute in Lower Bursa and Ligament, Open Approach */
"0MWY0JZ" = "1" /* Revision of Synthetic Substitute in Lower Bursa and Ligament, Open Approach */
"0MWY0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Bursa and Ligament, Open Approach */
"0MWY30Z" = "1" /* Revision of Drainage Device in Lower Bursa and Ligament, Percutaneous Approach */
"0MWY37Z" = "1" /* Revision of Autologous Tissue Substitute in Lower Bursa and Ligament, Percutaneous Approach */
"0MWY3JZ" = "1" /* Revision of Synthetic Substitute in Lower Bursa and Ligament, Percutaneous Approach */
"0MWY3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Bursa and Ligament, Percutaneous Approach */
"0MWY40Z" = "1" /* Revision of Drainage Device in Lower Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MWY47Z" = "1" /* Revision of Autologous Tissue Substitute in Lower Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MWY4JZ" = "1" /* Revision of Synthetic Substitute in Lower Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MWY4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lower Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MX00ZZ" = "1" /* Transfer Head and Neck Bursa and Ligament, Open Approach */
"0MX04ZZ" = "1" /* Transfer Head and Neck Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MX10ZZ" = "1" /* Transfer Right Shoulder Bursa and Ligament, Open Approach */
"0MX14ZZ" = "1" /* Transfer Right Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MX20ZZ" = "1" /* Transfer Left Shoulder Bursa and Ligament, Open Approach */
"0MX24ZZ" = "1" /* Transfer Left Shoulder Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MX30ZZ" = "1" /* Transfer Right Elbow Bursa and Ligament, Open Approach */
"0MX34ZZ" = "1" /* Transfer Right Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MX40ZZ" = "1" /* Transfer Left Elbow Bursa and Ligament, Open Approach */
"0MX44ZZ" = "1" /* Transfer Left Elbow Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MX50ZZ" = "1" /* Transfer Right Wrist Bursa and Ligament, Open Approach */
"0MX54ZZ" = "1" /* Transfer Right Wrist Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MX60ZZ" = "1" /* Transfer Left Wrist Bursa and Ligament, Open Approach */
"0MX64ZZ" = "1" /* Transfer Left Wrist Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MX70ZZ" = "1" /* Transfer Right Hand Bursa and Ligament, Open Approach */
"0MX74ZZ" = "1" /* Transfer Right Hand Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MX80ZZ" = "1" /* Transfer Left Hand Bursa and Ligament, Open Approach */
"0MX84ZZ" = "1" /* Transfer Left Hand Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MX90ZZ" = "1" /* Transfer Right Upper Extremity Bursa and Ligament, Open Approach */
"0MX94ZZ" = "1" /* Transfer Right Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MXB0ZZ" = "1" /* Transfer Left Upper Extremity Bursa and Ligament, Open Approach */
"0MXB4ZZ" = "1" /* Transfer Left Upper Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MXC0ZZ" = "1" /* Transfer Right Trunk Bursa and Ligament, Open Approach */
"0MXC4ZZ" = "1" /* Transfer Right Trunk Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MXD0ZZ" = "1" /* Transfer Left Trunk Bursa and Ligament, Open Approach */
"0MXD4ZZ" = "1" /* Transfer Left Trunk Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MXF0ZZ" = "1" /* Transfer Right Thorax Bursa and Ligament, Open Approach */
"0MXF4ZZ" = "1" /* Transfer Right Thorax Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MXG0ZZ" = "1" /* Transfer Left Thorax Bursa and Ligament, Open Approach */
"0MXG4ZZ" = "1" /* Transfer Left Thorax Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MXH0ZZ" = "1" /* Transfer Right Abdomen Bursa and Ligament, Open Approach */
"0MXH4ZZ" = "1" /* Transfer Right Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MXJ0ZZ" = "1" /* Transfer Left Abdomen Bursa and Ligament, Open Approach */
"0MXJ4ZZ" = "1" /* Transfer Left Abdomen Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MXK0ZZ" = "1" /* Transfer Perineum Bursa and Ligament, Open Approach */
"0MXK4ZZ" = "1" /* Transfer Perineum Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MXL0ZZ" = "1" /* Transfer Right Hip Bursa and Ligament, Open Approach */
"0MXL4ZZ" = "1" /* Transfer Right Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MXM0ZZ" = "1" /* Transfer Left Hip Bursa and Ligament, Open Approach */
"0MXM4ZZ" = "1" /* Transfer Left Hip Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MXN0ZZ" = "1" /* Transfer Right Knee Bursa and Ligament, Open Approach */
"0MXN4ZZ" = "1" /* Transfer Right Knee Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MXP0ZZ" = "1" /* Transfer Left Knee Bursa and Ligament, Open Approach */
"0MXP4ZZ" = "1" /* Transfer Left Knee Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MXQ0ZZ" = "1" /* Transfer Right Ankle Bursa and Ligament, Open Approach */
"0MXQ4ZZ" = "1" /* Transfer Right Ankle Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MXR0ZZ" = "1" /* Transfer Left Ankle Bursa and Ligament, Open Approach */
"0MXR4ZZ" = "1" /* Transfer Left Ankle Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MXS0ZZ" = "1" /* Transfer Right Foot Bursa and Ligament, Open Approach */
"0MXS4ZZ" = "1" /* Transfer Right Foot Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MXT0ZZ" = "1" /* Transfer Left Foot Bursa and Ligament, Open Approach */
"0MXT4ZZ" = "1" /* Transfer Left Foot Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MXV0ZZ" = "1" /* Transfer Right Lower Extremity Bursa and Ligament, Open Approach */
"0MXV4ZZ" = "1" /* Transfer Right Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0MXW0ZZ" = "1" /* Transfer Left Lower Extremity Bursa and Ligament, Open Approach */
"0MXW4ZZ" = "1" /* Transfer Left Lower Extremity Bursa and Ligament, Percutaneous Endoscopic Approach */
"0N500ZZ" = "1" /* Destruction of Skull, Open Approach */
"0N503ZZ" = "1" /* Destruction of Skull, Percutaneous Approach */
"0N504ZZ" = "1" /* Destruction of Skull, Percutaneous Endoscopic Approach */
"0N510ZZ" = "1" /* Destruction of Right Frontal Bone, Open Approach */
"0N513ZZ" = "1" /* Destruction of Right Frontal Bone, Percutaneous Approach */
"0N514ZZ" = "1" /* Destruction of Right Frontal Bone, Percutaneous Endoscopic Approach */
"0N520ZZ" = "1" /* Destruction of Left Frontal Bone, Open Approach */
"0N523ZZ" = "1" /* Destruction of Left Frontal Bone, Percutaneous Approach */
"0N524ZZ" = "1" /* Destruction of Left Frontal Bone, Percutaneous Endoscopic Approach */
"0N530ZZ" = "1" /* Destruction of Right Parietal Bone, Open Approach */
"0N533ZZ" = "1" /* Destruction of Right Parietal Bone, Percutaneous Approach */
"0N534ZZ" = "1" /* Destruction of Right Parietal Bone, Percutaneous Endoscopic Approach */
"0N540ZZ" = "1" /* Destruction of Left Parietal Bone, Open Approach */
"0N543ZZ" = "1" /* Destruction of Left Parietal Bone, Percutaneous Approach */
"0N544ZZ" = "1" /* Destruction of Left Parietal Bone, Percutaneous Endoscopic Approach */
"0N550ZZ" = "1" /* Destruction of Right Temporal Bone, Open Approach */
"0N553ZZ" = "1" /* Destruction of Right Temporal Bone, Percutaneous Approach */
"0N554ZZ" = "1" /* Destruction of Right Temporal Bone, Percutaneous Endoscopic Approach */
"0N560ZZ" = "1" /* Destruction of Left Temporal Bone, Open Approach */
"0N563ZZ" = "1" /* Destruction of Left Temporal Bone, Percutaneous Approach */
"0N564ZZ" = "1" /* Destruction of Left Temporal Bone, Percutaneous Endoscopic Approach */
"0N570ZZ" = "1" /* Destruction of Right Occipital Bone, Open Approach */
"0N573ZZ" = "1" /* Destruction of Right Occipital Bone, Percutaneous Approach */
"0N574ZZ" = "1" /* Destruction of Right Occipital Bone, Percutaneous Endoscopic Approach */
"0N580ZZ" = "1" /* Destruction of Left Occipital Bone, Open Approach */
"0N583ZZ" = "1" /* Destruction of Left Occipital Bone, Percutaneous Approach */
"0N584ZZ" = "1" /* Destruction of Left Occipital Bone, Percutaneous Endoscopic Approach */
"0N5B0ZZ" = "1" /* Destruction of Nasal Bone, Open Approach */
"0N5B3ZZ" = "1" /* Destruction of Nasal Bone, Percutaneous Approach */
"0N5B4ZZ" = "1" /* Destruction of Nasal Bone, Percutaneous Endoscopic Approach */
"0N5C0ZZ" = "1" /* Destruction of Right Sphenoid Bone, Open Approach */
"0N5C3ZZ" = "1" /* Destruction of Right Sphenoid Bone, Percutaneous Approach */
"0N5C4ZZ" = "1" /* Destruction of Right Sphenoid Bone, Percutaneous Endoscopic Approach */
"0N5D0ZZ" = "1" /* Destruction of Left Sphenoid Bone, Open Approach */
"0N5D3ZZ" = "1" /* Destruction of Left Sphenoid Bone, Percutaneous Approach */
"0N5D4ZZ" = "1" /* Destruction of Left Sphenoid Bone, Percutaneous Endoscopic Approach */
"0N5F0ZZ" = "1" /* Destruction of Right Ethmoid Bone, Open Approach */
"0N5F3ZZ" = "1" /* Destruction of Right Ethmoid Bone, Percutaneous Approach */
"0N5F4ZZ" = "1" /* Destruction of Right Ethmoid Bone, Percutaneous Endoscopic Approach */
"0N5G0ZZ" = "1" /* Destruction of Left Ethmoid Bone, Open Approach */
"0N5G3ZZ" = "1" /* Destruction of Left Ethmoid Bone, Percutaneous Approach */
"0N5G4ZZ" = "1" /* Destruction of Left Ethmoid Bone, Percutaneous Endoscopic Approach */
"0N5H0ZZ" = "1" /* Destruction of Right Lacrimal Bone, Open Approach */
"0N5H3ZZ" = "1" /* Destruction of Right Lacrimal Bone, Percutaneous Approach */
"0N5H4ZZ" = "1" /* Destruction of Right Lacrimal Bone, Percutaneous Endoscopic Approach */
"0N5J0ZZ" = "1" /* Destruction of Left Lacrimal Bone, Open Approach */
"0N5J3ZZ" = "1" /* Destruction of Left Lacrimal Bone, Percutaneous Approach */
"0N5J4ZZ" = "1" /* Destruction of Left Lacrimal Bone, Percutaneous Endoscopic Approach */
"0N5K0ZZ" = "1" /* Destruction of Right Palatine Bone, Open Approach */
"0N5K3ZZ" = "1" /* Destruction of Right Palatine Bone, Percutaneous Approach */
"0N5K4ZZ" = "1" /* Destruction of Right Palatine Bone, Percutaneous Endoscopic Approach */
"0N5L0ZZ" = "1" /* Destruction of Left Palatine Bone, Open Approach */
"0N5L3ZZ" = "1" /* Destruction of Left Palatine Bone, Percutaneous Approach */
"0N5L4ZZ" = "1" /* Destruction of Left Palatine Bone, Percutaneous Endoscopic Approach */
"0N5M0ZZ" = "1" /* Destruction of Right Zygomatic Bone, Open Approach */
"0N5M3ZZ" = "1" /* Destruction of Right Zygomatic Bone, Percutaneous Approach */
"0N5M4ZZ" = "1" /* Destruction of Right Zygomatic Bone, Percutaneous Endoscopic Approach */
"0N5N0ZZ" = "1" /* Destruction of Left Zygomatic Bone, Open Approach */
"0N5N3ZZ" = "1" /* Destruction of Left Zygomatic Bone, Percutaneous Approach */
"0N5N4ZZ" = "1" /* Destruction of Left Zygomatic Bone, Percutaneous Endoscopic Approach */
"0N5P0ZZ" = "1" /* Destruction of Right Orbit, Open Approach */
"0N5P3ZZ" = "1" /* Destruction of Right Orbit, Percutaneous Approach */
"0N5P4ZZ" = "1" /* Destruction of Right Orbit, Percutaneous Endoscopic Approach */
"0N5Q0ZZ" = "1" /* Destruction of Left Orbit, Open Approach */
"0N5Q3ZZ" = "1" /* Destruction of Left Orbit, Percutaneous Approach */
"0N5Q4ZZ" = "1" /* Destruction of Left Orbit, Percutaneous Endoscopic Approach */
"0N5R0ZZ" = "1" /* Destruction of Right Maxilla, Open Approach */
"0N5R3ZZ" = "1" /* Destruction of Right Maxilla, Percutaneous Approach */
"0N5R4ZZ" = "1" /* Destruction of Right Maxilla, Percutaneous Endoscopic Approach */
"0N5S0ZZ" = "1" /* Destruction of Left Maxilla, Open Approach */
"0N5S3ZZ" = "1" /* Destruction of Left Maxilla, Percutaneous Approach */
"0N5S4ZZ" = "1" /* Destruction of Left Maxilla, Percutaneous Endoscopic Approach */
"0N5T0ZZ" = "1" /* Destruction of Right Mandible, Open Approach */
"0N5T3ZZ" = "1" /* Destruction of Right Mandible, Percutaneous Approach */
"0N5T4ZZ" = "1" /* Destruction of Right Mandible, Percutaneous Endoscopic Approach */
"0N5V0ZZ" = "1" /* Destruction of Left Mandible, Open Approach */
"0N5V3ZZ" = "1" /* Destruction of Left Mandible, Percutaneous Approach */
"0N5V4ZZ" = "1" /* Destruction of Left Mandible, Percutaneous Endoscopic Approach */
"0N5X0ZZ" = "1" /* Destruction of Hyoid Bone, Open Approach */
"0N5X3ZZ" = "1" /* Destruction of Hyoid Bone, Percutaneous Approach */
"0N5X4ZZ" = "1" /* Destruction of Hyoid Bone, Percutaneous Endoscopic Approach */
"0N800ZZ" = "1" /* Division of Skull, Open Approach */
"0N803ZZ" = "1" /* Division of Skull, Percutaneous Approach */
"0N804ZZ" = "1" /* Division of Skull, Percutaneous Endoscopic Approach */
"0N810ZZ" = "1" /* Division of Right Frontal Bone, Open Approach */
"0N813ZZ" = "1" /* Division of Right Frontal Bone, Percutaneous Approach */
"0N814ZZ" = "1" /* Division of Right Frontal Bone, Percutaneous Endoscopic Approach */
"0N820ZZ" = "1" /* Division of Left Frontal Bone, Open Approach */
"0N823ZZ" = "1" /* Division of Left Frontal Bone, Percutaneous Approach */
"0N824ZZ" = "1" /* Division of Left Frontal Bone, Percutaneous Endoscopic Approach */
"0N830ZZ" = "1" /* Division of Right Parietal Bone, Open Approach */
"0N833ZZ" = "1" /* Division of Right Parietal Bone, Percutaneous Approach */
"0N834ZZ" = "1" /* Division of Right Parietal Bone, Percutaneous Endoscopic Approach */
"0N840ZZ" = "1" /* Division of Left Parietal Bone, Open Approach */
"0N843ZZ" = "1" /* Division of Left Parietal Bone, Percutaneous Approach */
"0N844ZZ" = "1" /* Division of Left Parietal Bone, Percutaneous Endoscopic Approach */
"0N850ZZ" = "1" /* Division of Right Temporal Bone, Open Approach */
"0N853ZZ" = "1" /* Division of Right Temporal Bone, Percutaneous Approach */
"0N854ZZ" = "1" /* Division of Right Temporal Bone, Percutaneous Endoscopic Approach */
"0N860ZZ" = "1" /* Division of Left Temporal Bone, Open Approach */
"0N863ZZ" = "1" /* Division of Left Temporal Bone, Percutaneous Approach */
"0N864ZZ" = "1" /* Division of Left Temporal Bone, Percutaneous Endoscopic Approach */
"0N870ZZ" = "1" /* Division of Right Occipital Bone, Open Approach */
"0N873ZZ" = "1" /* Division of Right Occipital Bone, Percutaneous Approach */
"0N874ZZ" = "1" /* Division of Right Occipital Bone, Percutaneous Endoscopic Approach */
"0N880ZZ" = "1" /* Division of Left Occipital Bone, Open Approach */
"0N883ZZ" = "1" /* Division of Left Occipital Bone, Percutaneous Approach */
"0N884ZZ" = "1" /* Division of Left Occipital Bone, Percutaneous Endoscopic Approach */
"0N8C0ZZ" = "1" /* Division of Right Sphenoid Bone, Open Approach */
"0N8C3ZZ" = "1" /* Division of Right Sphenoid Bone, Percutaneous Approach */
"0N8C4ZZ" = "1" /* Division of Right Sphenoid Bone, Percutaneous Endoscopic Approach */
"0N8D0ZZ" = "1" /* Division of Left Sphenoid Bone, Open Approach */
"0N8D3ZZ" = "1" /* Division of Left Sphenoid Bone, Percutaneous Approach */
"0N8D4ZZ" = "1" /* Division of Left Sphenoid Bone, Percutaneous Endoscopic Approach */
"0N8F0ZZ" = "1" /* Division of Right Ethmoid Bone, Open Approach */
"0N8F3ZZ" = "1" /* Division of Right Ethmoid Bone, Percutaneous Approach */
"0N8F4ZZ" = "1" /* Division of Right Ethmoid Bone, Percutaneous Endoscopic Approach */
"0N8G0ZZ" = "1" /* Division of Left Ethmoid Bone, Open Approach */
"0N8G3ZZ" = "1" /* Division of Left Ethmoid Bone, Percutaneous Approach */
"0N8G4ZZ" = "1" /* Division of Left Ethmoid Bone, Percutaneous Endoscopic Approach */
"0N8H0ZZ" = "1" /* Division of Right Lacrimal Bone, Open Approach */
"0N8H3ZZ" = "1" /* Division of Right Lacrimal Bone, Percutaneous Approach */
"0N8H4ZZ" = "1" /* Division of Right Lacrimal Bone, Percutaneous Endoscopic Approach */
"0N8J0ZZ" = "1" /* Division of Left Lacrimal Bone, Open Approach */
"0N8J3ZZ" = "1" /* Division of Left Lacrimal Bone, Percutaneous Approach */
"0N8J4ZZ" = "1" /* Division of Left Lacrimal Bone, Percutaneous Endoscopic Approach */
"0N8K0ZZ" = "1" /* Division of Right Palatine Bone, Open Approach */
"0N8K3ZZ" = "1" /* Division of Right Palatine Bone, Percutaneous Approach */
"0N8K4ZZ" = "1" /* Division of Right Palatine Bone, Percutaneous Endoscopic Approach */
"0N8L0ZZ" = "1" /* Division of Left Palatine Bone, Open Approach */
"0N8L3ZZ" = "1" /* Division of Left Palatine Bone, Percutaneous Approach */
"0N8L4ZZ" = "1" /* Division of Left Palatine Bone, Percutaneous Endoscopic Approach */
"0N8M0ZZ" = "1" /* Division of Right Zygomatic Bone, Open Approach */
"0N8M3ZZ" = "1" /* Division of Right Zygomatic Bone, Percutaneous Approach */
"0N8M4ZZ" = "1" /* Division of Right Zygomatic Bone, Percutaneous Endoscopic Approach */
"0N8N0ZZ" = "1" /* Division of Left Zygomatic Bone, Open Approach */
"0N8N3ZZ" = "1" /* Division of Left Zygomatic Bone, Percutaneous Approach */
"0N8N4ZZ" = "1" /* Division of Left Zygomatic Bone, Percutaneous Endoscopic Approach */
"0N8P0ZZ" = "1" /* Division of Right Orbit, Open Approach */
"0N8P3ZZ" = "1" /* Division of Right Orbit, Percutaneous Approach */
"0N8P4ZZ" = "1" /* Division of Right Orbit, Percutaneous Endoscopic Approach */
"0N8Q0ZZ" = "1" /* Division of Left Orbit, Open Approach */
"0N8Q3ZZ" = "1" /* Division of Left Orbit, Percutaneous Approach */
"0N8Q4ZZ" = "1" /* Division of Left Orbit, Percutaneous Endoscopic Approach */
"0N8R0ZZ" = "1" /* Division of Right Maxilla, Open Approach */
"0N8R3ZZ" = "1" /* Division of Right Maxilla, Percutaneous Approach */
"0N8R4ZZ" = "1" /* Division of Right Maxilla, Percutaneous Endoscopic Approach */
"0N8S0ZZ" = "1" /* Division of Left Maxilla, Open Approach */
"0N8S3ZZ" = "1" /* Division of Left Maxilla, Percutaneous Approach */
"0N8S4ZZ" = "1" /* Division of Left Maxilla, Percutaneous Endoscopic Approach */
"0N8T0ZZ" = "1" /* Division of Right Mandible, Open Approach */
"0N8T3ZZ" = "1" /* Division of Right Mandible, Percutaneous Approach */
"0N8T4ZZ" = "1" /* Division of Right Mandible, Percutaneous Endoscopic Approach */
"0N8V0ZZ" = "1" /* Division of Left Mandible, Open Approach */
"0N8V3ZZ" = "1" /* Division of Left Mandible, Percutaneous Approach */
"0N8V4ZZ" = "1" /* Division of Left Mandible, Percutaneous Endoscopic Approach */
"0N8X0ZZ" = "1" /* Division of Hyoid Bone, Open Approach */
"0N8X3ZZ" = "1" /* Division of Hyoid Bone, Percutaneous Approach */
"0N8X4ZZ" = "1" /* Division of Hyoid Bone, Percutaneous Endoscopic Approach */
"0N9000Z" = "1" /* Drainage of Skull with Drainage Device, Open Approach */
"0N900ZX" = "1" /* Drainage of Skull, Open Approach, Diagnostic */
"0N900ZZ" = "1" /* Drainage of Skull, Open Approach */
"0N9040Z" = "1" /* Drainage of Skull with Drainage Device, Percutaneous Endoscopic Approach */
"0N904ZX" = "1" /* Drainage of Skull, Percutaneous Endoscopic Approach, Diagnostic */
"0N904ZZ" = "1" /* Drainage of Skull, Percutaneous Endoscopic Approach */
"0N9100Z" = "1" /* Drainage of Right Frontal Bone with Drainage Device, Open Approach */
"0N910ZX" = "1" /* Drainage of Right Frontal Bone, Open Approach, Diagnostic */
"0N910ZZ" = "1" /* Drainage of Right Frontal Bone, Open Approach */
"0N9140Z" = "1" /* Drainage of Right Frontal Bone with Drainage Device, Percutaneous Endoscopic Approach */
"0N914ZX" = "1" /* Drainage of Right Frontal Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0N914ZZ" = "1" /* Drainage of Right Frontal Bone, Percutaneous Endoscopic Approach */
"0N9200Z" = "1" /* Drainage of Left Frontal Bone with Drainage Device, Open Approach */
"0N920ZX" = "1" /* Drainage of Left Frontal Bone, Open Approach, Diagnostic */
"0N920ZZ" = "1" /* Drainage of Left Frontal Bone, Open Approach */
"0N9240Z" = "1" /* Drainage of Left Frontal Bone with Drainage Device, Percutaneous Endoscopic Approach */
"0N924ZX" = "1" /* Drainage of Left Frontal Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0N924ZZ" = "1" /* Drainage of Left Frontal Bone, Percutaneous Endoscopic Approach */
"0N9300Z" = "1" /* Drainage of Right Parietal Bone with Drainage Device, Open Approach */
"0N930ZX" = "1" /* Drainage of Right Parietal Bone, Open Approach, Diagnostic */
"0N930ZZ" = "1" /* Drainage of Right Parietal Bone, Open Approach */
"0N9340Z" = "1" /* Drainage of Right Parietal Bone with Drainage Device, Percutaneous Endoscopic Approach */
"0N934ZX" = "1" /* Drainage of Right Parietal Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0N934ZZ" = "1" /* Drainage of Right Parietal Bone, Percutaneous Endoscopic Approach */
"0N9400Z" = "1" /* Drainage of Left Parietal Bone with Drainage Device, Open Approach */
"0N940ZX" = "1" /* Drainage of Left Parietal Bone, Open Approach, Diagnostic */
"0N940ZZ" = "1" /* Drainage of Left Parietal Bone, Open Approach */
"0N9440Z" = "1" /* Drainage of Left Parietal Bone with Drainage Device, Percutaneous Endoscopic Approach */
"0N944ZX" = "1" /* Drainage of Left Parietal Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0N944ZZ" = "1" /* Drainage of Left Parietal Bone, Percutaneous Endoscopic Approach */
"0N9500Z" = "1" /* Drainage of Right Temporal Bone with Drainage Device, Open Approach */
"0N950ZX" = "1" /* Drainage of Right Temporal Bone, Open Approach, Diagnostic */
"0N950ZZ" = "1" /* Drainage of Right Temporal Bone, Open Approach */
"0N9540Z" = "1" /* Drainage of Right Temporal Bone with Drainage Device, Percutaneous Endoscopic Approach */
"0N954ZX" = "1" /* Drainage of Right Temporal Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0N954ZZ" = "1" /* Drainage of Right Temporal Bone, Percutaneous Endoscopic Approach */
"0N9600Z" = "1" /* Drainage of Left Temporal Bone with Drainage Device, Open Approach */
"0N960ZX" = "1" /* Drainage of Left Temporal Bone, Open Approach, Diagnostic */
"0N960ZZ" = "1" /* Drainage of Left Temporal Bone, Open Approach */
"0N9640Z" = "1" /* Drainage of Left Temporal Bone with Drainage Device, Percutaneous Endoscopic Approach */
"0N964ZX" = "1" /* Drainage of Left Temporal Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0N964ZZ" = "1" /* Drainage of Left Temporal Bone, Percutaneous Endoscopic Approach */
"0N9700Z" = "1" /* Drainage of Right Occipital Bone with Drainage Device, Open Approach */
"0N970ZX" = "1" /* Drainage of Right Occipital Bone, Open Approach, Diagnostic */
"0N970ZZ" = "1" /* Drainage of Right Occipital Bone, Open Approach */
"0N9740Z" = "1" /* Drainage of Right Occipital Bone with Drainage Device, Percutaneous Endoscopic Approach */
"0N974ZX" = "1" /* Drainage of Right Occipital Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0N974ZZ" = "1" /* Drainage of Right Occipital Bone, Percutaneous Endoscopic Approach */
"0N9800Z" = "1" /* Drainage of Left Occipital Bone with Drainage Device, Open Approach */
"0N980ZX" = "1" /* Drainage of Left Occipital Bone, Open Approach, Diagnostic */
"0N980ZZ" = "1" /* Drainage of Left Occipital Bone, Open Approach */
"0N9840Z" = "1" /* Drainage of Left Occipital Bone with Drainage Device, Percutaneous Endoscopic Approach */
"0N984ZX" = "1" /* Drainage of Left Occipital Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0N984ZZ" = "1" /* Drainage of Left Occipital Bone, Percutaneous Endoscopic Approach */
"0N9C00Z" = "1" /* Drainage of Right Sphenoid Bone with Drainage Device, Open Approach */
"0N9C0ZX" = "1" /* Drainage of Right Sphenoid Bone, Open Approach, Diagnostic */
"0N9C0ZZ" = "1" /* Drainage of Right Sphenoid Bone, Open Approach */
"0N9C40Z" = "1" /* Drainage of Right Sphenoid Bone with Drainage Device, Percutaneous Endoscopic Approach */
"0N9C4ZX" = "1" /* Drainage of Right Sphenoid Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0N9C4ZZ" = "1" /* Drainage of Right Sphenoid Bone, Percutaneous Endoscopic Approach */
"0N9D00Z" = "1" /* Drainage of Left Sphenoid Bone with Drainage Device, Open Approach */
"0N9D0ZX" = "1" /* Drainage of Left Sphenoid Bone, Open Approach, Diagnostic */
"0N9D0ZZ" = "1" /* Drainage of Left Sphenoid Bone, Open Approach */
"0N9D40Z" = "1" /* Drainage of Left Sphenoid Bone with Drainage Device, Percutaneous Endoscopic Approach */
"0N9D4ZX" = "1" /* Drainage of Left Sphenoid Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0N9D4ZZ" = "1" /* Drainage of Left Sphenoid Bone, Percutaneous Endoscopic Approach */
"0N9F00Z" = "1" /* Drainage of Right Ethmoid Bone with Drainage Device, Open Approach */
"0N9F0ZX" = "1" /* Drainage of Right Ethmoid Bone, Open Approach, Diagnostic */
"0N9F0ZZ" = "1" /* Drainage of Right Ethmoid Bone, Open Approach */
"0N9F40Z" = "1" /* Drainage of Right Ethmoid Bone with Drainage Device, Percutaneous Endoscopic Approach */
"0N9F4ZX" = "1" /* Drainage of Right Ethmoid Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0N9F4ZZ" = "1" /* Drainage of Right Ethmoid Bone, Percutaneous Endoscopic Approach */
"0N9G00Z" = "1" /* Drainage of Left Ethmoid Bone with Drainage Device, Open Approach */
"0N9G0ZX" = "1" /* Drainage of Left Ethmoid Bone, Open Approach, Diagnostic */
"0N9G0ZZ" = "1" /* Drainage of Left Ethmoid Bone, Open Approach */
"0N9G40Z" = "1" /* Drainage of Left Ethmoid Bone with Drainage Device, Percutaneous Endoscopic Approach */
"0N9G4ZX" = "1" /* Drainage of Left Ethmoid Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0N9G4ZZ" = "1" /* Drainage of Left Ethmoid Bone, Percutaneous Endoscopic Approach */
"0N9H00Z" = "1" /* Drainage of Right Lacrimal Bone with Drainage Device, Open Approach */
"0N9H0ZX" = "1" /* Drainage of Right Lacrimal Bone, Open Approach, Diagnostic */
"0N9H0ZZ" = "1" /* Drainage of Right Lacrimal Bone, Open Approach */
"0N9H40Z" = "1" /* Drainage of Right Lacrimal Bone with Drainage Device, Percutaneous Endoscopic Approach */
"0N9H4ZX" = "1" /* Drainage of Right Lacrimal Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0N9H4ZZ" = "1" /* Drainage of Right Lacrimal Bone, Percutaneous Endoscopic Approach */
"0N9J00Z" = "1" /* Drainage of Left Lacrimal Bone with Drainage Device, Open Approach */
"0N9J0ZX" = "1" /* Drainage of Left Lacrimal Bone, Open Approach, Diagnostic */
"0N9J0ZZ" = "1" /* Drainage of Left Lacrimal Bone, Open Approach */
"0N9J40Z" = "1" /* Drainage of Left Lacrimal Bone with Drainage Device, Percutaneous Endoscopic Approach */
"0N9J4ZX" = "1" /* Drainage of Left Lacrimal Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0N9J4ZZ" = "1" /* Drainage of Left Lacrimal Bone, Percutaneous Endoscopic Approach */
"0N9K00Z" = "1" /* Drainage of Right Palatine Bone with Drainage Device, Open Approach */
"0N9K0ZX" = "1" /* Drainage of Right Palatine Bone, Open Approach, Diagnostic */
"0N9K0ZZ" = "1" /* Drainage of Right Palatine Bone, Open Approach */
"0N9K40Z" = "1" /* Drainage of Right Palatine Bone with Drainage Device, Percutaneous Endoscopic Approach */
"0N9K4ZX" = "1" /* Drainage of Right Palatine Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0N9K4ZZ" = "1" /* Drainage of Right Palatine Bone, Percutaneous Endoscopic Approach */
"0N9L00Z" = "1" /* Drainage of Left Palatine Bone with Drainage Device, Open Approach */
"0N9L0ZX" = "1" /* Drainage of Left Palatine Bone, Open Approach, Diagnostic */
"0N9L0ZZ" = "1" /* Drainage of Left Palatine Bone, Open Approach */
"0N9L40Z" = "1" /* Drainage of Left Palatine Bone with Drainage Device, Percutaneous Endoscopic Approach */
"0N9L4ZX" = "1" /* Drainage of Left Palatine Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0N9L4ZZ" = "1" /* Drainage of Left Palatine Bone, Percutaneous Endoscopic Approach */
"0N9M00Z" = "1" /* Drainage of Right Zygomatic Bone with Drainage Device, Open Approach */
"0N9M0ZX" = "1" /* Drainage of Right Zygomatic Bone, Open Approach, Diagnostic */
"0N9M0ZZ" = "1" /* Drainage of Right Zygomatic Bone, Open Approach */
"0N9M40Z" = "1" /* Drainage of Right Zygomatic Bone with Drainage Device, Percutaneous Endoscopic Approach */
"0N9M4ZX" = "1" /* Drainage of Right Zygomatic Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0N9M4ZZ" = "1" /* Drainage of Right Zygomatic Bone, Percutaneous Endoscopic Approach */
"0N9N00Z" = "1" /* Drainage of Left Zygomatic Bone with Drainage Device, Open Approach */
"0N9N0ZX" = "1" /* Drainage of Left Zygomatic Bone, Open Approach, Diagnostic */
"0N9N0ZZ" = "1" /* Drainage of Left Zygomatic Bone, Open Approach */
"0N9N40Z" = "1" /* Drainage of Left Zygomatic Bone with Drainage Device, Percutaneous Endoscopic Approach */
"0N9N4ZX" = "1" /* Drainage of Left Zygomatic Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0N9N4ZZ" = "1" /* Drainage of Left Zygomatic Bone, Percutaneous Endoscopic Approach */
"0N9P00Z" = "1" /* Drainage of Right Orbit with Drainage Device, Open Approach */
"0N9P0ZX" = "1" /* Drainage of Right Orbit, Open Approach, Diagnostic */
"0N9P0ZZ" = "1" /* Drainage of Right Orbit, Open Approach */
"0N9P40Z" = "1" /* Drainage of Right Orbit with Drainage Device, Percutaneous Endoscopic Approach */
"0N9P4ZX" = "1" /* Drainage of Right Orbit, Percutaneous Endoscopic Approach, Diagnostic */
"0N9P4ZZ" = "1" /* Drainage of Right Orbit, Percutaneous Endoscopic Approach */
"0N9Q00Z" = "1" /* Drainage of Left Orbit with Drainage Device, Open Approach */
"0N9Q0ZX" = "1" /* Drainage of Left Orbit, Open Approach, Diagnostic */
"0N9Q0ZZ" = "1" /* Drainage of Left Orbit, Open Approach */
"0N9Q40Z" = "1" /* Drainage of Left Orbit with Drainage Device, Percutaneous Endoscopic Approach */
"0N9Q4ZX" = "1" /* Drainage of Left Orbit, Percutaneous Endoscopic Approach, Diagnostic */
"0N9Q4ZZ" = "1" /* Drainage of Left Orbit, Percutaneous Endoscopic Approach */
"0N9R0ZX" = "1" /* Drainage of Right Maxilla, Open Approach, Diagnostic */
"0N9R4ZX" = "1" /* Drainage of Right Maxilla, Percutaneous Endoscopic Approach, Diagnostic */
"0N9S0ZX" = "1" /* Drainage of Left Maxilla, Open Approach, Diagnostic */
"0N9S4ZX" = "1" /* Drainage of Left Maxilla, Percutaneous Endoscopic Approach, Diagnostic */
"0N9T0ZX" = "1" /* Drainage of Right Mandible, Open Approach, Diagnostic */
"0N9T4ZX" = "1" /* Drainage of Right Mandible, Percutaneous Endoscopic Approach, Diagnostic */
"0N9V0ZX" = "1" /* Drainage of Left Mandible, Open Approach, Diagnostic */
"0N9V4ZX" = "1" /* Drainage of Left Mandible, Percutaneous Endoscopic Approach, Diagnostic */
"0N9X00Z" = "1" /* Drainage of Hyoid Bone with Drainage Device, Open Approach */
"0N9X0ZX" = "1" /* Drainage of Hyoid Bone, Open Approach, Diagnostic */
"0N9X0ZZ" = "1" /* Drainage of Hyoid Bone, Open Approach */
"0N9X40Z" = "1" /* Drainage of Hyoid Bone with Drainage Device, Percutaneous Endoscopic Approach */
"0N9X4ZX" = "1" /* Drainage of Hyoid Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0N9X4ZZ" = "1" /* Drainage of Hyoid Bone, Percutaneous Endoscopic Approach */
"0NB00ZX" = "1" /* Excision of Skull, Open Approach, Diagnostic */
"0NB00ZZ" = "1" /* Excision of Skull, Open Approach */
"0NB03ZX" = "1" /* Excision of Skull, Percutaneous Approach, Diagnostic */
"0NB03ZZ" = "1" /* Excision of Skull, Percutaneous Approach */
"0NB04ZX" = "1" /* Excision of Skull, Percutaneous Endoscopic Approach, Diagnostic */
"0NB04ZZ" = "1" /* Excision of Skull, Percutaneous Endoscopic Approach */
"0NB10ZX" = "1" /* Excision of Right Frontal Bone, Open Approach, Diagnostic */
"0NB10ZZ" = "1" /* Excision of Right Frontal Bone, Open Approach */
"0NB13ZX" = "1" /* Excision of Right Frontal Bone, Percutaneous Approach, Diagnostic */
"0NB13ZZ" = "1" /* Excision of Right Frontal Bone, Percutaneous Approach */
"0NB14ZX" = "1" /* Excision of Right Frontal Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0NB14ZZ" = "1" /* Excision of Right Frontal Bone, Percutaneous Endoscopic Approach */
"0NB20ZX" = "1" /* Excision of Left Frontal Bone, Open Approach, Diagnostic */
"0NB20ZZ" = "1" /* Excision of Left Frontal Bone, Open Approach */
"0NB23ZX" = "1" /* Excision of Left Frontal Bone, Percutaneous Approach, Diagnostic */
"0NB23ZZ" = "1" /* Excision of Left Frontal Bone, Percutaneous Approach */
"0NB24ZX" = "1" /* Excision of Left Frontal Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0NB24ZZ" = "1" /* Excision of Left Frontal Bone, Percutaneous Endoscopic Approach */
"0NB30ZX" = "1" /* Excision of Right Parietal Bone, Open Approach, Diagnostic */
"0NB30ZZ" = "1" /* Excision of Right Parietal Bone, Open Approach */
"0NB33ZX" = "1" /* Excision of Right Parietal Bone, Percutaneous Approach, Diagnostic */
"0NB33ZZ" = "1" /* Excision of Right Parietal Bone, Percutaneous Approach */
"0NB34ZX" = "1" /* Excision of Right Parietal Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0NB34ZZ" = "1" /* Excision of Right Parietal Bone, Percutaneous Endoscopic Approach */
"0NB40ZX" = "1" /* Excision of Left Parietal Bone, Open Approach, Diagnostic */
"0NB40ZZ" = "1" /* Excision of Left Parietal Bone, Open Approach */
"0NB43ZX" = "1" /* Excision of Left Parietal Bone, Percutaneous Approach, Diagnostic */
"0NB43ZZ" = "1" /* Excision of Left Parietal Bone, Percutaneous Approach */
"0NB44ZX" = "1" /* Excision of Left Parietal Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0NB44ZZ" = "1" /* Excision of Left Parietal Bone, Percutaneous Endoscopic Approach */
"0NB50ZX" = "1" /* Excision of Right Temporal Bone, Open Approach, Diagnostic */
"0NB50ZZ" = "1" /* Excision of Right Temporal Bone, Open Approach */
"0NB53ZX" = "1" /* Excision of Right Temporal Bone, Percutaneous Approach, Diagnostic */
"0NB53ZZ" = "1" /* Excision of Right Temporal Bone, Percutaneous Approach */
"0NB54ZX" = "1" /* Excision of Right Temporal Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0NB54ZZ" = "1" /* Excision of Right Temporal Bone, Percutaneous Endoscopic Approach */
"0NB60ZX" = "1" /* Excision of Left Temporal Bone, Open Approach, Diagnostic */
"0NB60ZZ" = "1" /* Excision of Left Temporal Bone, Open Approach */
"0NB63ZX" = "1" /* Excision of Left Temporal Bone, Percutaneous Approach, Diagnostic */
"0NB63ZZ" = "1" /* Excision of Left Temporal Bone, Percutaneous Approach */
"0NB64ZX" = "1" /* Excision of Left Temporal Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0NB64ZZ" = "1" /* Excision of Left Temporal Bone, Percutaneous Endoscopic Approach */
"0NB70ZX" = "1" /* Excision of Right Occipital Bone, Open Approach, Diagnostic */
"0NB70ZZ" = "1" /* Excision of Right Occipital Bone, Open Approach */
"0NB73ZX" = "1" /* Excision of Right Occipital Bone, Percutaneous Approach, Diagnostic */
"0NB73ZZ" = "1" /* Excision of Right Occipital Bone, Percutaneous Approach */
"0NB74ZX" = "1" /* Excision of Right Occipital Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0NB74ZZ" = "1" /* Excision of Right Occipital Bone, Percutaneous Endoscopic Approach */
"0NB80ZX" = "1" /* Excision of Left Occipital Bone, Open Approach, Diagnostic */
"0NB80ZZ" = "1" /* Excision of Left Occipital Bone, Open Approach */
"0NB83ZX" = "1" /* Excision of Left Occipital Bone, Percutaneous Approach, Diagnostic */
"0NB83ZZ" = "1" /* Excision of Left Occipital Bone, Percutaneous Approach */
"0NB84ZX" = "1" /* Excision of Left Occipital Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0NB84ZZ" = "1" /* Excision of Left Occipital Bone, Percutaneous Endoscopic Approach */
"0NBB0ZZ" = "1" /* Excision of Nasal Bone, Open Approach */
"0NBB3ZZ" = "1" /* Excision of Nasal Bone, Percutaneous Approach */
"0NBB4ZZ" = "1" /* Excision of Nasal Bone, Percutaneous Endoscopic Approach */
"0NBC0ZX" = "1" /* Excision of Right Sphenoid Bone, Open Approach, Diagnostic */
"0NBC0ZZ" = "1" /* Excision of Right Sphenoid Bone, Open Approach */
"0NBC3ZX" = "1" /* Excision of Right Sphenoid Bone, Percutaneous Approach, Diagnostic */
"0NBC3ZZ" = "1" /* Excision of Right Sphenoid Bone, Percutaneous Approach */
"0NBC4ZX" = "1" /* Excision of Right Sphenoid Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0NBC4ZZ" = "1" /* Excision of Right Sphenoid Bone, Percutaneous Endoscopic Approach */
"0NBD0ZX" = "1" /* Excision of Left Sphenoid Bone, Open Approach, Diagnostic */
"0NBD0ZZ" = "1" /* Excision of Left Sphenoid Bone, Open Approach */
"0NBD3ZX" = "1" /* Excision of Left Sphenoid Bone, Percutaneous Approach, Diagnostic */
"0NBD3ZZ" = "1" /* Excision of Left Sphenoid Bone, Percutaneous Approach */
"0NBD4ZX" = "1" /* Excision of Left Sphenoid Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0NBD4ZZ" = "1" /* Excision of Left Sphenoid Bone, Percutaneous Endoscopic Approach */
"0NBF0ZX" = "1" /* Excision of Right Ethmoid Bone, Open Approach, Diagnostic */
"0NBF0ZZ" = "1" /* Excision of Right Ethmoid Bone, Open Approach */
"0NBF3ZX" = "1" /* Excision of Right Ethmoid Bone, Percutaneous Approach, Diagnostic */
"0NBF3ZZ" = "1" /* Excision of Right Ethmoid Bone, Percutaneous Approach */
"0NBF4ZX" = "1" /* Excision of Right Ethmoid Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0NBF4ZZ" = "1" /* Excision of Right Ethmoid Bone, Percutaneous Endoscopic Approach */
"0NBG0ZX" = "1" /* Excision of Left Ethmoid Bone, Open Approach, Diagnostic */
"0NBG0ZZ" = "1" /* Excision of Left Ethmoid Bone, Open Approach */
"0NBG3ZX" = "1" /* Excision of Left Ethmoid Bone, Percutaneous Approach, Diagnostic */
"0NBG3ZZ" = "1" /* Excision of Left Ethmoid Bone, Percutaneous Approach */
"0NBG4ZX" = "1" /* Excision of Left Ethmoid Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0NBG4ZZ" = "1" /* Excision of Left Ethmoid Bone, Percutaneous Endoscopic Approach */
"0NBH0ZX" = "1" /* Excision of Right Lacrimal Bone, Open Approach, Diagnostic */
"0NBH0ZZ" = "1" /* Excision of Right Lacrimal Bone, Open Approach */
"0NBH3ZX" = "1" /* Excision of Right Lacrimal Bone, Percutaneous Approach, Diagnostic */
"0NBH3ZZ" = "1" /* Excision of Right Lacrimal Bone, Percutaneous Approach */
"0NBH4ZX" = "1" /* Excision of Right Lacrimal Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0NBH4ZZ" = "1" /* Excision of Right Lacrimal Bone, Percutaneous Endoscopic Approach */
"0NBJ0ZX" = "1" /* Excision of Left Lacrimal Bone, Open Approach, Diagnostic */
"0NBJ0ZZ" = "1" /* Excision of Left Lacrimal Bone, Open Approach */
"0NBJ3ZX" = "1" /* Excision of Left Lacrimal Bone, Percutaneous Approach, Diagnostic */
"0NBJ3ZZ" = "1" /* Excision of Left Lacrimal Bone, Percutaneous Approach */
"0NBJ4ZX" = "1" /* Excision of Left Lacrimal Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0NBJ4ZZ" = "1" /* Excision of Left Lacrimal Bone, Percutaneous Endoscopic Approach */
"0NBK0ZX" = "1" /* Excision of Right Palatine Bone, Open Approach, Diagnostic */
"0NBK0ZZ" = "1" /* Excision of Right Palatine Bone, Open Approach */
"0NBK3ZX" = "1" /* Excision of Right Palatine Bone, Percutaneous Approach, Diagnostic */
"0NBK3ZZ" = "1" /* Excision of Right Palatine Bone, Percutaneous Approach */
"0NBK4ZX" = "1" /* Excision of Right Palatine Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0NBK4ZZ" = "1" /* Excision of Right Palatine Bone, Percutaneous Endoscopic Approach */
"0NBL0ZX" = "1" /* Excision of Left Palatine Bone, Open Approach, Diagnostic */
"0NBL0ZZ" = "1" /* Excision of Left Palatine Bone, Open Approach */
"0NBL3ZX" = "1" /* Excision of Left Palatine Bone, Percutaneous Approach, Diagnostic */
"0NBL3ZZ" = "1" /* Excision of Left Palatine Bone, Percutaneous Approach */
"0NBL4ZX" = "1" /* Excision of Left Palatine Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0NBL4ZZ" = "1" /* Excision of Left Palatine Bone, Percutaneous Endoscopic Approach */
"0NBM0ZX" = "1" /* Excision of Right Zygomatic Bone, Open Approach, Diagnostic */
"0NBM0ZZ" = "1" /* Excision of Right Zygomatic Bone, Open Approach */
"0NBM3ZX" = "1" /* Excision of Right Zygomatic Bone, Percutaneous Approach, Diagnostic */
"0NBM3ZZ" = "1" /* Excision of Right Zygomatic Bone, Percutaneous Approach */
"0NBM4ZX" = "1" /* Excision of Right Zygomatic Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0NBM4ZZ" = "1" /* Excision of Right Zygomatic Bone, Percutaneous Endoscopic Approach */
"0NBN0ZX" = "1" /* Excision of Left Zygomatic Bone, Open Approach, Diagnostic */
"0NBN0ZZ" = "1" /* Excision of Left Zygomatic Bone, Open Approach */
"0NBN3ZX" = "1" /* Excision of Left Zygomatic Bone, Percutaneous Approach, Diagnostic */
"0NBN3ZZ" = "1" /* Excision of Left Zygomatic Bone, Percutaneous Approach */
"0NBN4ZX" = "1" /* Excision of Left Zygomatic Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0NBN4ZZ" = "1" /* Excision of Left Zygomatic Bone, Percutaneous Endoscopic Approach */
"0NBP0ZX" = "1" /* Excision of Right Orbit, Open Approach, Diagnostic */
"0NBP0ZZ" = "1" /* Excision of Right Orbit, Open Approach */
"0NBP3ZX" = "1" /* Excision of Right Orbit, Percutaneous Approach, Diagnostic */
"0NBP3ZZ" = "1" /* Excision of Right Orbit, Percutaneous Approach */
"0NBP4ZX" = "1" /* Excision of Right Orbit, Percutaneous Endoscopic Approach, Diagnostic */
"0NBP4ZZ" = "1" /* Excision of Right Orbit, Percutaneous Endoscopic Approach */
"0NBQ0ZX" = "1" /* Excision of Left Orbit, Open Approach, Diagnostic */
"0NBQ0ZZ" = "1" /* Excision of Left Orbit, Open Approach */
"0NBQ3ZX" = "1" /* Excision of Left Orbit, Percutaneous Approach, Diagnostic */
"0NBQ3ZZ" = "1" /* Excision of Left Orbit, Percutaneous Approach */
"0NBQ4ZX" = "1" /* Excision of Left Orbit, Percutaneous Endoscopic Approach, Diagnostic */
"0NBQ4ZZ" = "1" /* Excision of Left Orbit, Percutaneous Endoscopic Approach */
"0NBR0ZZ" = "1" /* Excision of Right Maxilla, Open Approach */
"0NBR3ZZ" = "1" /* Excision of Right Maxilla, Percutaneous Approach */
"0NBR4ZZ" = "1" /* Excision of Right Maxilla, Percutaneous Endoscopic Approach */
"0NBS0ZZ" = "1" /* Excision of Left Maxilla, Open Approach */
"0NBS3ZZ" = "1" /* Excision of Left Maxilla, Percutaneous Approach */
"0NBS4ZZ" = "1" /* Excision of Left Maxilla, Percutaneous Endoscopic Approach */
"0NBT0ZZ" = "1" /* Excision of Right Mandible, Open Approach */
"0NBT3ZZ" = "1" /* Excision of Right Mandible, Percutaneous Approach */
"0NBT4ZZ" = "1" /* Excision of Right Mandible, Percutaneous Endoscopic Approach */
"0NBV0ZZ" = "1" /* Excision of Left Mandible, Open Approach */
"0NBV3ZZ" = "1" /* Excision of Left Mandible, Percutaneous Approach */
"0NBV4ZZ" = "1" /* Excision of Left Mandible, Percutaneous Endoscopic Approach */
"0NBX0ZX" = "1" /* Excision of Hyoid Bone, Open Approach, Diagnostic */
"0NBX0ZZ" = "1" /* Excision of Hyoid Bone, Open Approach */
"0NBX3ZX" = "1" /* Excision of Hyoid Bone, Percutaneous Approach, Diagnostic */
"0NBX3ZZ" = "1" /* Excision of Hyoid Bone, Percutaneous Approach */
"0NBX4ZX" = "1" /* Excision of Hyoid Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0NBX4ZZ" = "1" /* Excision of Hyoid Bone, Percutaneous Endoscopic Approach */
"0NC10ZZ" = "1" /* Extirpation of Matter from Right Frontal Bone, Open Approach */
"0NC13ZZ" = "1" /* Extirpation of Matter from Right Frontal Bone, Percutaneous Approach */
"0NC14ZZ" = "1" /* Extirpation of Matter from Right Frontal Bone, Percutaneous Endoscopic Approach */
"0NC20ZZ" = "1" /* Extirpation of Matter from Left Frontal Bone, Open Approach */
"0NC23ZZ" = "1" /* Extirpation of Matter from Left Frontal Bone, Percutaneous Approach */
"0NC24ZZ" = "1" /* Extirpation of Matter from Left Frontal Bone, Percutaneous Endoscopic Approach */
"0NC30ZZ" = "1" /* Extirpation of Matter from Right Parietal Bone, Open Approach */
"0NC33ZZ" = "1" /* Extirpation of Matter from Right Parietal Bone, Percutaneous Approach */
"0NC34ZZ" = "1" /* Extirpation of Matter from Right Parietal Bone, Percutaneous Endoscopic Approach */
"0NC40ZZ" = "1" /* Extirpation of Matter from Left Parietal Bone, Open Approach */
"0NC43ZZ" = "1" /* Extirpation of Matter from Left Parietal Bone, Percutaneous Approach */
"0NC44ZZ" = "1" /* Extirpation of Matter from Left Parietal Bone, Percutaneous Endoscopic Approach */
"0NC50ZZ" = "1" /* Extirpation of Matter from Right Temporal Bone, Open Approach */
"0NC53ZZ" = "1" /* Extirpation of Matter from Right Temporal Bone, Percutaneous Approach */
"0NC54ZZ" = "1" /* Extirpation of Matter from Right Temporal Bone, Percutaneous Endoscopic Approach */
"0NC60ZZ" = "1" /* Extirpation of Matter from Left Temporal Bone, Open Approach */
"0NC63ZZ" = "1" /* Extirpation of Matter from Left Temporal Bone, Percutaneous Approach */
"0NC64ZZ" = "1" /* Extirpation of Matter from Left Temporal Bone, Percutaneous Endoscopic Approach */
"0NC70ZZ" = "1" /* Extirpation of Matter from Right Occipital Bone, Open Approach */
"0NC73ZZ" = "1" /* Extirpation of Matter from Right Occipital Bone, Percutaneous Approach */
"0NC74ZZ" = "1" /* Extirpation of Matter from Right Occipital Bone, Percutaneous Endoscopic Approach */
"0NC80ZZ" = "1" /* Extirpation of Matter from Left Occipital Bone, Open Approach */
"0NC83ZZ" = "1" /* Extirpation of Matter from Left Occipital Bone, Percutaneous Approach */
"0NC84ZZ" = "1" /* Extirpation of Matter from Left Occipital Bone, Percutaneous Endoscopic Approach */
"0NCC0ZZ" = "1" /* Extirpation of Matter from Right Sphenoid Bone, Open Approach */
"0NCC3ZZ" = "1" /* Extirpation of Matter from Right Sphenoid Bone, Percutaneous Approach */
"0NCC4ZZ" = "1" /* Extirpation of Matter from Right Sphenoid Bone, Percutaneous Endoscopic Approach */
"0NCD0ZZ" = "1" /* Extirpation of Matter from Left Sphenoid Bone, Open Approach */
"0NCD3ZZ" = "1" /* Extirpation of Matter from Left Sphenoid Bone, Percutaneous Approach */
"0NCD4ZZ" = "1" /* Extirpation of Matter from Left Sphenoid Bone, Percutaneous Endoscopic Approach */
"0NCF0ZZ" = "1" /* Extirpation of Matter from Right Ethmoid Bone, Open Approach */
"0NCF3ZZ" = "1" /* Extirpation of Matter from Right Ethmoid Bone, Percutaneous Approach */
"0NCF4ZZ" = "1" /* Extirpation of Matter from Right Ethmoid Bone, Percutaneous Endoscopic Approach */
"0NCG0ZZ" = "1" /* Extirpation of Matter from Left Ethmoid Bone, Open Approach */
"0NCG3ZZ" = "1" /* Extirpation of Matter from Left Ethmoid Bone, Percutaneous Approach */
"0NCG4ZZ" = "1" /* Extirpation of Matter from Left Ethmoid Bone, Percutaneous Endoscopic Approach */
"0NCH0ZZ" = "1" /* Extirpation of Matter from Right Lacrimal Bone, Open Approach */
"0NCH3ZZ" = "1" /* Extirpation of Matter from Right Lacrimal Bone, Percutaneous Approach */
"0NCH4ZZ" = "1" /* Extirpation of Matter from Right Lacrimal Bone, Percutaneous Endoscopic Approach */
"0NCJ0ZZ" = "1" /* Extirpation of Matter from Left Lacrimal Bone, Open Approach */
"0NCJ3ZZ" = "1" /* Extirpation of Matter from Left Lacrimal Bone, Percutaneous Approach */
"0NCJ4ZZ" = "1" /* Extirpation of Matter from Left Lacrimal Bone, Percutaneous Endoscopic Approach */
"0NCK0ZZ" = "1" /* Extirpation of Matter from Right Palatine Bone, Open Approach */
"0NCK3ZZ" = "1" /* Extirpation of Matter from Right Palatine Bone, Percutaneous Approach */
"0NCK4ZZ" = "1" /* Extirpation of Matter from Right Palatine Bone, Percutaneous Endoscopic Approach */
"0NCL0ZZ" = "1" /* Extirpation of Matter from Left Palatine Bone, Open Approach */
"0NCL3ZZ" = "1" /* Extirpation of Matter from Left Palatine Bone, Percutaneous Approach */
"0NCL4ZZ" = "1" /* Extirpation of Matter from Left Palatine Bone, Percutaneous Endoscopic Approach */
"0NCM0ZZ" = "1" /* Extirpation of Matter from Right Zygomatic Bone, Open Approach */
"0NCM3ZZ" = "1" /* Extirpation of Matter from Right Zygomatic Bone, Percutaneous Approach */
"0NCM4ZZ" = "1" /* Extirpation of Matter from Right Zygomatic Bone, Percutaneous Endoscopic Approach */
"0NCN0ZZ" = "1" /* Extirpation of Matter from Left Zygomatic Bone, Open Approach */
"0NCN3ZZ" = "1" /* Extirpation of Matter from Left Zygomatic Bone, Percutaneous Approach */
"0NCN4ZZ" = "1" /* Extirpation of Matter from Left Zygomatic Bone, Percutaneous Endoscopic Approach */
"0NCP0ZZ" = "1" /* Extirpation of Matter from Right Orbit, Open Approach */
"0NCP3ZZ" = "1" /* Extirpation of Matter from Right Orbit, Percutaneous Approach */
"0NCP4ZZ" = "1" /* Extirpation of Matter from Right Orbit, Percutaneous Endoscopic Approach */
"0NCQ0ZZ" = "1" /* Extirpation of Matter from Left Orbit, Open Approach */
"0NCQ3ZZ" = "1" /* Extirpation of Matter from Left Orbit, Percutaneous Approach */
"0NCQ4ZZ" = "1" /* Extirpation of Matter from Left Orbit, Percutaneous Endoscopic Approach */
"0NCX0ZZ" = "1" /* Extirpation of Matter from Hyoid Bone, Open Approach */
"0NCX3ZZ" = "1" /* Extirpation of Matter from Hyoid Bone, Percutaneous Approach */
"0NCX4ZZ" = "1" /* Extirpation of Matter from Hyoid Bone, Percutaneous Endoscopic Approach */
"0NH004Z" = "1" /* Insertion of Internal Fixation Device into Skull, Open Approach */
"0NH00MZ" = "1" /* Insertion of Bone Growth Stimulator into Skull, Open Approach */
"0NH00NZ" = "1" /* Insertion of Neurostimulator Generator into Skull, Open Approach */
"0NH034Z" = "1" /* Insertion of Internal Fixation Device into Skull, Percutaneous Approach */
"0NH03MZ" = "1" /* Insertion of Bone Growth Stimulator into Skull, Percutaneous Approach */
"0NH044Z" = "1" /* Insertion of Internal Fixation Device into Skull, Percutaneous Endoscopic Approach */
"0NH04MZ" = "1" /* Insertion of Bone Growth Stimulator into Skull, Percutaneous Endoscopic Approach */
"0NH104Z" = "1" /* Insertion of Internal Fixation Device into Right Frontal Bone, Open Approach */
"0NH134Z" = "1" /* Insertion of Internal Fixation Device into Right Frontal Bone, Percutaneous Approach */
"0NH144Z" = "1" /* Insertion of Internal Fixation Device into Right Frontal Bone, Percutaneous Endoscopic Approach */
"0NH204Z" = "1" /* Insertion of Internal Fixation Device into Left Frontal Bone, Open Approach */
"0NH234Z" = "1" /* Insertion of Internal Fixation Device into Left Frontal Bone, Percutaneous Approach */
"0NH244Z" = "1" /* Insertion of Internal Fixation Device into Left Frontal Bone, Percutaneous Endoscopic Approach */
"0NH304Z" = "1" /* Insertion of Internal Fixation Device into Right Parietal Bone, Open Approach */
"0NH334Z" = "1" /* Insertion of Internal Fixation Device into Right Parietal Bone, Percutaneous Approach */
"0NH344Z" = "1" /* Insertion of Internal Fixation Device into Right Parietal Bone, Percutaneous Endoscopic Approach */
"0NH404Z" = "1" /* Insertion of Internal Fixation Device into Left Parietal Bone, Open Approach */
"0NH434Z" = "1" /* Insertion of Internal Fixation Device into Left Parietal Bone, Percutaneous Approach */
"0NH444Z" = "1" /* Insertion of Internal Fixation Device into Left Parietal Bone, Percutaneous Endoscopic Approach */
"0NH504Z" = "1" /* Insertion of Internal Fixation Device into Right Temporal Bone, Open Approach */
"0NH50SZ" = "1" /* Insertion of Hearing Device into Right Temporal Bone, Open Approach */
"0NH534Z" = "1" /* Insertion of Internal Fixation Device into Right Temporal Bone, Percutaneous Approach */
"0NH53SZ" = "1" /* Insertion of Hearing Device into Right Temporal Bone, Percutaneous Approach */
"0NH544Z" = "1" /* Insertion of Internal Fixation Device into Right Temporal Bone, Percutaneous Endoscopic Approach */
"0NH54SZ" = "1" /* Insertion of Hearing Device into Right Temporal Bone, Percutaneous Endoscopic Approach */
"0NH604Z" = "1" /* Insertion of Internal Fixation Device into Left Temporal Bone, Open Approach */
"0NH60SZ" = "1" /* Insertion of Hearing Device into Left Temporal Bone, Open Approach */
"0NH634Z" = "1" /* Insertion of Internal Fixation Device into Left Temporal Bone, Percutaneous Approach */
"0NH63SZ" = "1" /* Insertion of Hearing Device into Left Temporal Bone, Percutaneous Approach */
"0NH644Z" = "1" /* Insertion of Internal Fixation Device into Left Temporal Bone, Percutaneous Endoscopic Approach */
"0NH64SZ" = "1" /* Insertion of Hearing Device into Left Temporal Bone, Percutaneous Endoscopic Approach */
"0NH704Z" = "1" /* Insertion of Internal Fixation Device into Right Occipital Bone, Open Approach */
"0NH734Z" = "1" /* Insertion of Internal Fixation Device into Right Occipital Bone, Percutaneous Approach */
"0NH744Z" = "1" /* Insertion of Internal Fixation Device into Right Occipital Bone, Percutaneous Endoscopic Approach */
"0NH804Z" = "1" /* Insertion of Internal Fixation Device into Left Occipital Bone, Open Approach */
"0NH834Z" = "1" /* Insertion of Internal Fixation Device into Left Occipital Bone, Percutaneous Approach */
"0NH844Z" = "1" /* Insertion of Internal Fixation Device into Left Occipital Bone, Percutaneous Endoscopic Approach */
"0NHC04Z" = "1" /* Insertion of Internal Fixation Device into Right Sphenoid Bone, Open Approach */
"0NHC34Z" = "1" /* Insertion of Internal Fixation Device into Right Sphenoid Bone, Percutaneous Approach */
"0NHC44Z" = "1" /* Insertion of Internal Fixation Device into Right Sphenoid Bone, Percutaneous Endoscopic Approach */
"0NHD04Z" = "1" /* Insertion of Internal Fixation Device into Left Sphenoid Bone, Open Approach */
"0NHD34Z" = "1" /* Insertion of Internal Fixation Device into Left Sphenoid Bone, Percutaneous Approach */
"0NHD44Z" = "1" /* Insertion of Internal Fixation Device into Left Sphenoid Bone, Percutaneous Endoscopic Approach */
"0NHF04Z" = "1" /* Insertion of Internal Fixation Device into Right Ethmoid Bone, Open Approach */
"0NHF34Z" = "1" /* Insertion of Internal Fixation Device into Right Ethmoid Bone, Percutaneous Approach */
"0NHF44Z" = "1" /* Insertion of Internal Fixation Device into Right Ethmoid Bone, Percutaneous Endoscopic Approach */
"0NHG04Z" = "1" /* Insertion of Internal Fixation Device into Left Ethmoid Bone, Open Approach */
"0NHG34Z" = "1" /* Insertion of Internal Fixation Device into Left Ethmoid Bone, Percutaneous Approach */
"0NHG44Z" = "1" /* Insertion of Internal Fixation Device into Left Ethmoid Bone, Percutaneous Endoscopic Approach */
"0NHH04Z" = "1" /* Insertion of Internal Fixation Device into Right Lacrimal Bone, Open Approach */
"0NHH34Z" = "1" /* Insertion of Internal Fixation Device into Right Lacrimal Bone, Percutaneous Approach */
"0NHH44Z" = "1" /* Insertion of Internal Fixation Device into Right Lacrimal Bone, Percutaneous Endoscopic Approach */
"0NHJ04Z" = "1" /* Insertion of Internal Fixation Device into Left Lacrimal Bone, Open Approach */
"0NHJ34Z" = "1" /* Insertion of Internal Fixation Device into Left Lacrimal Bone, Percutaneous Approach */
"0NHJ44Z" = "1" /* Insertion of Internal Fixation Device into Left Lacrimal Bone, Percutaneous Endoscopic Approach */
"0NHK04Z" = "1" /* Insertion of Internal Fixation Device into Right Palatine Bone, Open Approach */
"0NHK34Z" = "1" /* Insertion of Internal Fixation Device into Right Palatine Bone, Percutaneous Approach */
"0NHK44Z" = "1" /* Insertion of Internal Fixation Device into Right Palatine Bone, Percutaneous Endoscopic Approach */
"0NHL04Z" = "1" /* Insertion of Internal Fixation Device into Left Palatine Bone, Open Approach */
"0NHL34Z" = "1" /* Insertion of Internal Fixation Device into Left Palatine Bone, Percutaneous Approach */
"0NHL44Z" = "1" /* Insertion of Internal Fixation Device into Left Palatine Bone, Percutaneous Endoscopic Approach */
"0NHM04Z" = "1" /* Insertion of Internal Fixation Device into Right Zygomatic Bone, Open Approach */
"0NHM34Z" = "1" /* Insertion of Internal Fixation Device into Right Zygomatic Bone, Percutaneous Approach */
"0NHM44Z" = "1" /* Insertion of Internal Fixation Device into Right Zygomatic Bone, Percutaneous Endoscopic Approach */
"0NHN04Z" = "1" /* Insertion of Internal Fixation Device into Left Zygomatic Bone, Open Approach */
"0NHN34Z" = "1" /* Insertion of Internal Fixation Device into Left Zygomatic Bone, Percutaneous Approach */
"0NHN44Z" = "1" /* Insertion of Internal Fixation Device into Left Zygomatic Bone, Percutaneous Endoscopic Approach */
"0NHP04Z" = "1" /* Insertion of Internal Fixation Device into Right Orbit, Open Approach */
"0NHP34Z" = "1" /* Insertion of Internal Fixation Device into Right Orbit, Percutaneous Approach */
"0NHP44Z" = "1" /* Insertion of Internal Fixation Device into Right Orbit, Percutaneous Endoscopic Approach */
"0NHQ04Z" = "1" /* Insertion of Internal Fixation Device into Left Orbit, Open Approach */
"0NHQ34Z" = "1" /* Insertion of Internal Fixation Device into Left Orbit, Percutaneous Approach */
"0NHQ44Z" = "1" /* Insertion of Internal Fixation Device into Left Orbit, Percutaneous Endoscopic Approach */
"0NHR04Z" = "1" /* Insertion of Internal Fixation Device into Right Maxilla, Open Approach */
"0NHR05Z" = "1" /* Insertion of External Fixation Device into Right Maxilla, Open Approach */
"0NHR34Z" = "1" /* Insertion of Internal Fixation Device into Right Maxilla, Percutaneous Approach */
"0NHR35Z" = "1" /* Insertion of External Fixation Device into Right Maxilla, Percutaneous Approach */
"0NHR44Z" = "1" /* Insertion of Internal Fixation Device into Right Maxilla, Percutaneous Endoscopic Approach */
"0NHR45Z" = "1" /* Insertion of External Fixation Device into Right Maxilla, Percutaneous Endoscopic Approach */
"0NHS04Z" = "1" /* Insertion of Internal Fixation Device into Left Maxilla, Open Approach */
"0NHS05Z" = "1" /* Insertion of External Fixation Device into Left Maxilla, Open Approach */
"0NHS34Z" = "1" /* Insertion of Internal Fixation Device into Left Maxilla, Percutaneous Approach */
"0NHS35Z" = "1" /* Insertion of External Fixation Device into Left Maxilla, Percutaneous Approach */
"0NHS44Z" = "1" /* Insertion of Internal Fixation Device into Left Maxilla, Percutaneous Endoscopic Approach */
"0NHS45Z" = "1" /* Insertion of External Fixation Device into Left Maxilla, Percutaneous Endoscopic Approach */
"0NHT04Z" = "1" /* Insertion of Internal Fixation Device into Right Mandible, Open Approach */
"0NHT05Z" = "1" /* Insertion of External Fixation Device into Right Mandible, Open Approach */
"0NHT34Z" = "1" /* Insertion of Internal Fixation Device into Right Mandible, Percutaneous Approach */
"0NHT35Z" = "1" /* Insertion of External Fixation Device into Right Mandible, Percutaneous Approach */
"0NHT44Z" = "1" /* Insertion of Internal Fixation Device into Right Mandible, Percutaneous Endoscopic Approach */
"0NHT45Z" = "1" /* Insertion of External Fixation Device into Right Mandible, Percutaneous Endoscopic Approach */
"0NHV04Z" = "1" /* Insertion of Internal Fixation Device into Left Mandible, Open Approach */
"0NHV05Z" = "1" /* Insertion of External Fixation Device into Left Mandible, Open Approach */
"0NHV34Z" = "1" /* Insertion of Internal Fixation Device into Left Mandible, Percutaneous Approach */
"0NHV35Z" = "1" /* Insertion of External Fixation Device into Left Mandible, Percutaneous Approach */
"0NHV44Z" = "1" /* Insertion of Internal Fixation Device into Left Mandible, Percutaneous Endoscopic Approach */
"0NHV45Z" = "1" /* Insertion of External Fixation Device into Left Mandible, Percutaneous Endoscopic Approach */
"0NHW0MZ" = "1" /* Insertion of Bone Growth Stimulator into Facial Bone, Open Approach */
"0NHW3MZ" = "1" /* Insertion of Bone Growth Stimulator into Facial Bone, Percutaneous Approach */
"0NHW4MZ" = "1" /* Insertion of Bone Growth Stimulator into Facial Bone, Percutaneous Endoscopic Approach */
"0NHX04Z" = "1" /* Insertion of Internal Fixation Device into Hyoid Bone, Open Approach */
"0NHX34Z" = "1" /* Insertion of Internal Fixation Device into Hyoid Bone, Percutaneous Approach */
"0NHX44Z" = "1" /* Insertion of Internal Fixation Device into Hyoid Bone, Percutaneous Endoscopic Approach */
"0NJ00ZZ" = "1" /* Inspection of Skull, Open Approach */
"0NJ04ZZ" = "1" /* Inspection of Skull, Percutaneous Endoscopic Approach */
"0NJB0ZZ" = "1" /* Inspection of Nasal Bone, Open Approach */
"0NJB4ZZ" = "1" /* Inspection of Nasal Bone, Percutaneous Endoscopic Approach */
"0NJW0ZZ" = "1" /* Inspection of Facial Bone, Open Approach */
"0NJW4ZZ" = "1" /* Inspection of Facial Bone, Percutaneous Endoscopic Approach */
"0NN10ZZ" = "1" /* Release Right Frontal Bone, Open Approach */
"0NN13ZZ" = "1" /* Release Right Frontal Bone, Percutaneous Approach */
"0NN14ZZ" = "1" /* Release Right Frontal Bone, Percutaneous Endoscopic Approach */
"0NN20ZZ" = "1" /* Release Left Frontal Bone, Open Approach */
"0NN23ZZ" = "1" /* Release Left Frontal Bone, Percutaneous Approach */
"0NN24ZZ" = "1" /* Release Left Frontal Bone, Percutaneous Endoscopic Approach */
"0NN30ZZ" = "1" /* Release Right Parietal Bone, Open Approach */
"0NN33ZZ" = "1" /* Release Right Parietal Bone, Percutaneous Approach */
"0NN34ZZ" = "1" /* Release Right Parietal Bone, Percutaneous Endoscopic Approach */
"0NN40ZZ" = "1" /* Release Left Parietal Bone, Open Approach */
"0NN43ZZ" = "1" /* Release Left Parietal Bone, Percutaneous Approach */
"0NN44ZZ" = "1" /* Release Left Parietal Bone, Percutaneous Endoscopic Approach */
"0NN50ZZ" = "1" /* Release Right Temporal Bone, Open Approach */
"0NN53ZZ" = "1" /* Release Right Temporal Bone, Percutaneous Approach */
"0NN54ZZ" = "1" /* Release Right Temporal Bone, Percutaneous Endoscopic Approach */
"0NN60ZZ" = "1" /* Release Left Temporal Bone, Open Approach */
"0NN63ZZ" = "1" /* Release Left Temporal Bone, Percutaneous Approach */
"0NN64ZZ" = "1" /* Release Left Temporal Bone, Percutaneous Endoscopic Approach */
"0NN70ZZ" = "1" /* Release Right Occipital Bone, Open Approach */
"0NN73ZZ" = "1" /* Release Right Occipital Bone, Percutaneous Approach */
"0NN74ZZ" = "1" /* Release Right Occipital Bone, Percutaneous Endoscopic Approach */
"0NN80ZZ" = "1" /* Release Left Occipital Bone, Open Approach */
"0NN83ZZ" = "1" /* Release Left Occipital Bone, Percutaneous Approach */
"0NN84ZZ" = "1" /* Release Left Occipital Bone, Percutaneous Endoscopic Approach */
"0NNC0ZZ" = "1" /* Release Right Sphenoid Bone, Open Approach */
"0NNC3ZZ" = "1" /* Release Right Sphenoid Bone, Percutaneous Approach */
"0NNC4ZZ" = "1" /* Release Right Sphenoid Bone, Percutaneous Endoscopic Approach */
"0NND0ZZ" = "1" /* Release Left Sphenoid Bone, Open Approach */
"0NND3ZZ" = "1" /* Release Left Sphenoid Bone, Percutaneous Approach */
"0NND4ZZ" = "1" /* Release Left Sphenoid Bone, Percutaneous Endoscopic Approach */
"0NNF0ZZ" = "1" /* Release Right Ethmoid Bone, Open Approach */
"0NNF3ZZ" = "1" /* Release Right Ethmoid Bone, Percutaneous Approach */
"0NNF4ZZ" = "1" /* Release Right Ethmoid Bone, Percutaneous Endoscopic Approach */
"0NNG0ZZ" = "1" /* Release Left Ethmoid Bone, Open Approach */
"0NNG3ZZ" = "1" /* Release Left Ethmoid Bone, Percutaneous Approach */
"0NNG4ZZ" = "1" /* Release Left Ethmoid Bone, Percutaneous Endoscopic Approach */
"0NNH0ZZ" = "1" /* Release Right Lacrimal Bone, Open Approach */
"0NNH3ZZ" = "1" /* Release Right Lacrimal Bone, Percutaneous Approach */
"0NNH4ZZ" = "1" /* Release Right Lacrimal Bone, Percutaneous Endoscopic Approach */
"0NNJ0ZZ" = "1" /* Release Left Lacrimal Bone, Open Approach */
"0NNJ3ZZ" = "1" /* Release Left Lacrimal Bone, Percutaneous Approach */
"0NNJ4ZZ" = "1" /* Release Left Lacrimal Bone, Percutaneous Endoscopic Approach */
"0NNK0ZZ" = "1" /* Release Right Palatine Bone, Open Approach */
"0NNK3ZZ" = "1" /* Release Right Palatine Bone, Percutaneous Approach */
"0NNK4ZZ" = "1" /* Release Right Palatine Bone, Percutaneous Endoscopic Approach */
"0NNL0ZZ" = "1" /* Release Left Palatine Bone, Open Approach */
"0NNL3ZZ" = "1" /* Release Left Palatine Bone, Percutaneous Approach */
"0NNL4ZZ" = "1" /* Release Left Palatine Bone, Percutaneous Endoscopic Approach */
"0NNM0ZZ" = "1" /* Release Right Zygomatic Bone, Open Approach */
"0NNM3ZZ" = "1" /* Release Right Zygomatic Bone, Percutaneous Approach */
"0NNM4ZZ" = "1" /* Release Right Zygomatic Bone, Percutaneous Endoscopic Approach */
"0NNN0ZZ" = "1" /* Release Left Zygomatic Bone, Open Approach */
"0NNN3ZZ" = "1" /* Release Left Zygomatic Bone, Percutaneous Approach */
"0NNN4ZZ" = "1" /* Release Left Zygomatic Bone, Percutaneous Endoscopic Approach */
"0NNP0ZZ" = "1" /* Release Right Orbit, Open Approach */
"0NNP3ZZ" = "1" /* Release Right Orbit, Percutaneous Approach */
"0NNP4ZZ" = "1" /* Release Right Orbit, Percutaneous Endoscopic Approach */
"0NNQ0ZZ" = "1" /* Release Left Orbit, Open Approach */
"0NNQ3ZZ" = "1" /* Release Left Orbit, Percutaneous Approach */
"0NNQ4ZZ" = "1" /* Release Left Orbit, Percutaneous Endoscopic Approach */
"0NNR0ZZ" = "1" /* Release Right Maxilla, Open Approach */
"0NNR3ZZ" = "1" /* Release Right Maxilla, Percutaneous Approach */
"0NNR4ZZ" = "1" /* Release Right Maxilla, Percutaneous Endoscopic Approach */
"0NNS0ZZ" = "1" /* Release Left Maxilla, Open Approach */
"0NNS3ZZ" = "1" /* Release Left Maxilla, Percutaneous Approach */
"0NNS4ZZ" = "1" /* Release Left Maxilla, Percutaneous Endoscopic Approach */
"0NNT0ZZ" = "1" /* Release Right Mandible, Open Approach */
"0NNT3ZZ" = "1" /* Release Right Mandible, Percutaneous Approach */
"0NNT4ZZ" = "1" /* Release Right Mandible, Percutaneous Endoscopic Approach */
"0NNV0ZZ" = "1" /* Release Left Mandible, Open Approach */
"0NNV3ZZ" = "1" /* Release Left Mandible, Percutaneous Approach */
"0NNV4ZZ" = "1" /* Release Left Mandible, Percutaneous Endoscopic Approach */
"0NNX0ZZ" = "1" /* Release Hyoid Bone, Open Approach */
"0NNX3ZZ" = "1" /* Release Hyoid Bone, Percutaneous Approach */
"0NNX4ZZ" = "1" /* Release Hyoid Bone, Percutaneous Endoscopic Approach */
"0NP000Z" = "1" /* Removal of Drainage Device from Skull, Open Approach */
"0NP004Z" = "1" /* Removal of Internal Fixation Device from Skull, Open Approach */
"0NP005Z" = "1" /* Removal of External Fixation Device from Skull, Open Approach */
"0NP007Z" = "1" /* Removal of Autologous Tissue Substitute from Skull, Open Approach */
"0NP00JZ" = "1" /* Removal of Synthetic Substitute from Skull, Open Approach */
"0NP00KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Skull, Open Approach */
"0NP00MZ" = "1" /* Removal of Bone Growth Stimulator from Skull, Open Approach */
"0NP00NZ" = "1" /* Removal of Neurostimulator Generator from Skull, Open Approach */
"0NP00SZ" = "1" /* Removal of Hearing Device from Skull, Open Approach */
"0NP030Z" = "1" /* Removal of Drainage Device from Skull, Percutaneous Approach */
"0NP034Z" = "1" /* Removal of Internal Fixation Device from Skull, Percutaneous Approach */
"0NP037Z" = "1" /* Removal of Autologous Tissue Substitute from Skull, Percutaneous Approach */
"0NP03JZ" = "1" /* Removal of Synthetic Substitute from Skull, Percutaneous Approach */
"0NP03KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Skull, Percutaneous Approach */
"0NP03MZ" = "1" /* Removal of Bone Growth Stimulator from Skull, Percutaneous Approach */
"0NP03SZ" = "1" /* Removal of Hearing Device from Skull, Percutaneous Approach */
"0NP040Z" = "1" /* Removal of Drainage Device from Skull, Percutaneous Endoscopic Approach */
"0NP044Z" = "1" /* Removal of Internal Fixation Device from Skull, Percutaneous Endoscopic Approach */
"0NP047Z" = "1" /* Removal of Autologous Tissue Substitute from Skull, Percutaneous Endoscopic Approach */
"0NP04JZ" = "1" /* Removal of Synthetic Substitute from Skull, Percutaneous Endoscopic Approach */
"0NP04KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Skull, Percutaneous Endoscopic Approach */
"0NP04MZ" = "1" /* Removal of Bone Growth Stimulator from Skull, Percutaneous Endoscopic Approach */
"0NP04SZ" = "1" /* Removal of Hearing Device from Skull, Percutaneous Endoscopic Approach */
"0NP0X4Z" = "1" /* Removal of Internal Fixation Device from Skull, External Approach */
"0NP0XMZ" = "1" /* Removal of Bone Growth Stimulator from Skull, External Approach */
"0NP0XSZ" = "1" /* Removal of Hearing Device from Skull, External Approach */
"0NPW00Z" = "1" /* Removal of Drainage Device from Facial Bone, Open Approach */
"0NPW04Z" = "1" /* Removal of Internal Fixation Device from Facial Bone, Open Approach */
"0NPW07Z" = "1" /* Removal of Autologous Tissue Substitute from Facial Bone, Open Approach */
"0NPW0JZ" = "1" /* Removal of Synthetic Substitute from Facial Bone, Open Approach */
"0NPW0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Facial Bone, Open Approach */
"0NPW0MZ" = "1" /* Removal of Bone Growth Stimulator from Facial Bone, Open Approach */
"0NPW30Z" = "1" /* Removal of Drainage Device from Facial Bone, Percutaneous Approach */
"0NPW34Z" = "1" /* Removal of Internal Fixation Device from Facial Bone, Percutaneous Approach */
"0NPW37Z" = "1" /* Removal of Autologous Tissue Substitute from Facial Bone, Percutaneous Approach */
"0NPW3JZ" = "1" /* Removal of Synthetic Substitute from Facial Bone, Percutaneous Approach */
"0NPW3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Facial Bone, Percutaneous Approach */
"0NPW3MZ" = "1" /* Removal of Bone Growth Stimulator from Facial Bone, Percutaneous Approach */
"0NPW40Z" = "1" /* Removal of Drainage Device from Facial Bone, Percutaneous Endoscopic Approach */
"0NPW44Z" = "1" /* Removal of Internal Fixation Device from Facial Bone, Percutaneous Endoscopic Approach */
"0NPW47Z" = "1" /* Removal of Autologous Tissue Substitute from Facial Bone, Percutaneous Endoscopic Approach */
"0NPW4JZ" = "1" /* Removal of Synthetic Substitute from Facial Bone, Percutaneous Endoscopic Approach */
"0NPW4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Facial Bone, Percutaneous Endoscopic Approach */
"0NPW4MZ" = "1" /* Removal of Bone Growth Stimulator from Facial Bone, Percutaneous Endoscopic Approach */
"0NPWX4Z" = "1" /* Removal of Internal Fixation Device from Facial Bone, External Approach */
"0NQ00ZZ" = "1" /* Repair Skull, Open Approach */
"0NQ03ZZ" = "1" /* Repair Skull, Percutaneous Approach */
"0NQ04ZZ" = "1" /* Repair Skull, Percutaneous Endoscopic Approach */
"0NQ10ZZ" = "1" /* Repair Right Frontal Bone, Open Approach */
"0NQ13ZZ" = "1" /* Repair Right Frontal Bone, Percutaneous Approach */
"0NQ14ZZ" = "1" /* Repair Right Frontal Bone, Percutaneous Endoscopic Approach */
"0NQ20ZZ" = "1" /* Repair Left Frontal Bone, Open Approach */
"0NQ23ZZ" = "1" /* Repair Left Frontal Bone, Percutaneous Approach */
"0NQ24ZZ" = "1" /* Repair Left Frontal Bone, Percutaneous Endoscopic Approach */
"0NQ30ZZ" = "1" /* Repair Right Parietal Bone, Open Approach */
"0NQ33ZZ" = "1" /* Repair Right Parietal Bone, Percutaneous Approach */
"0NQ34ZZ" = "1" /* Repair Right Parietal Bone, Percutaneous Endoscopic Approach */
"0NQ40ZZ" = "1" /* Repair Left Parietal Bone, Open Approach */
"0NQ43ZZ" = "1" /* Repair Left Parietal Bone, Percutaneous Approach */
"0NQ44ZZ" = "1" /* Repair Left Parietal Bone, Percutaneous Endoscopic Approach */
"0NQ50ZZ" = "1" /* Repair Right Temporal Bone, Open Approach */
"0NQ53ZZ" = "1" /* Repair Right Temporal Bone, Percutaneous Approach */
"0NQ54ZZ" = "1" /* Repair Right Temporal Bone, Percutaneous Endoscopic Approach */
"0NQ60ZZ" = "1" /* Repair Left Temporal Bone, Open Approach */
"0NQ63ZZ" = "1" /* Repair Left Temporal Bone, Percutaneous Approach */
"0NQ64ZZ" = "1" /* Repair Left Temporal Bone, Percutaneous Endoscopic Approach */
"0NQ70ZZ" = "1" /* Repair Right Occipital Bone, Open Approach */
"0NQ73ZZ" = "1" /* Repair Right Occipital Bone, Percutaneous Approach */
"0NQ74ZZ" = "1" /* Repair Right Occipital Bone, Percutaneous Endoscopic Approach */
"0NQ80ZZ" = "1" /* Repair Left Occipital Bone, Open Approach */
"0NQ83ZZ" = "1" /* Repair Left Occipital Bone, Percutaneous Approach */
"0NQ84ZZ" = "1" /* Repair Left Occipital Bone, Percutaneous Endoscopic Approach */
"0NQB0ZZ" = "1" /* Repair Nasal Bone, Open Approach */
"0NQB3ZZ" = "1" /* Repair Nasal Bone, Percutaneous Approach */
"0NQB4ZZ" = "1" /* Repair Nasal Bone, Percutaneous Endoscopic Approach */
"0NQC0ZZ" = "1" /* Repair Right Sphenoid Bone, Open Approach */
"0NQC3ZZ" = "1" /* Repair Right Sphenoid Bone, Percutaneous Approach */
"0NQC4ZZ" = "1" /* Repair Right Sphenoid Bone, Percutaneous Endoscopic Approach */
"0NQD0ZZ" = "1" /* Repair Left Sphenoid Bone, Open Approach */
"0NQD3ZZ" = "1" /* Repair Left Sphenoid Bone, Percutaneous Approach */
"0NQD4ZZ" = "1" /* Repair Left Sphenoid Bone, Percutaneous Endoscopic Approach */
"0NQF0ZZ" = "1" /* Repair Right Ethmoid Bone, Open Approach */
"0NQF3ZZ" = "1" /* Repair Right Ethmoid Bone, Percutaneous Approach */
"0NQF4ZZ" = "1" /* Repair Right Ethmoid Bone, Percutaneous Endoscopic Approach */
"0NQG0ZZ" = "1" /* Repair Left Ethmoid Bone, Open Approach */
"0NQG3ZZ" = "1" /* Repair Left Ethmoid Bone, Percutaneous Approach */
"0NQG4ZZ" = "1" /* Repair Left Ethmoid Bone, Percutaneous Endoscopic Approach */
"0NQH0ZZ" = "1" /* Repair Right Lacrimal Bone, Open Approach */
"0NQH3ZZ" = "1" /* Repair Right Lacrimal Bone, Percutaneous Approach */
"0NQH4ZZ" = "1" /* Repair Right Lacrimal Bone, Percutaneous Endoscopic Approach */
"0NQJ0ZZ" = "1" /* Repair Left Lacrimal Bone, Open Approach */
"0NQJ3ZZ" = "1" /* Repair Left Lacrimal Bone, Percutaneous Approach */
"0NQJ4ZZ" = "1" /* Repair Left Lacrimal Bone, Percutaneous Endoscopic Approach */
"0NQK0ZZ" = "1" /* Repair Right Palatine Bone, Open Approach */
"0NQK3ZZ" = "1" /* Repair Right Palatine Bone, Percutaneous Approach */
"0NQK4ZZ" = "1" /* Repair Right Palatine Bone, Percutaneous Endoscopic Approach */
"0NQL0ZZ" = "1" /* Repair Left Palatine Bone, Open Approach */
"0NQL3ZZ" = "1" /* Repair Left Palatine Bone, Percutaneous Approach */
"0NQL4ZZ" = "1" /* Repair Left Palatine Bone, Percutaneous Endoscopic Approach */
"0NQM0ZZ" = "1" /* Repair Right Zygomatic Bone, Open Approach */
"0NQM3ZZ" = "1" /* Repair Right Zygomatic Bone, Percutaneous Approach */
"0NQM4ZZ" = "1" /* Repair Right Zygomatic Bone, Percutaneous Endoscopic Approach */
"0NQN0ZZ" = "1" /* Repair Left Zygomatic Bone, Open Approach */
"0NQN3ZZ" = "1" /* Repair Left Zygomatic Bone, Percutaneous Approach */
"0NQN4ZZ" = "1" /* Repair Left Zygomatic Bone, Percutaneous Endoscopic Approach */
"0NQP0ZZ" = "1" /* Repair Right Orbit, Open Approach */
"0NQP3ZZ" = "1" /* Repair Right Orbit, Percutaneous Approach */
"0NQP4ZZ" = "1" /* Repair Right Orbit, Percutaneous Endoscopic Approach */
"0NQQ0ZZ" = "1" /* Repair Left Orbit, Open Approach */
"0NQQ3ZZ" = "1" /* Repair Left Orbit, Percutaneous Approach */
"0NQQ4ZZ" = "1" /* Repair Left Orbit, Percutaneous Endoscopic Approach */
"0NQR0ZZ" = "1" /* Repair Right Maxilla, Open Approach */
"0NQR3ZZ" = "1" /* Repair Right Maxilla, Percutaneous Approach */
"0NQR4ZZ" = "1" /* Repair Right Maxilla, Percutaneous Endoscopic Approach */
"0NQS0ZZ" = "1" /* Repair Left Maxilla, Open Approach */
"0NQS3ZZ" = "1" /* Repair Left Maxilla, Percutaneous Approach */
"0NQS4ZZ" = "1" /* Repair Left Maxilla, Percutaneous Endoscopic Approach */
"0NQT0ZZ" = "1" /* Repair Right Mandible, Open Approach */
"0NQT3ZZ" = "1" /* Repair Right Mandible, Percutaneous Approach */
"0NQT4ZZ" = "1" /* Repair Right Mandible, Percutaneous Endoscopic Approach */
"0NQV0ZZ" = "1" /* Repair Left Mandible, Open Approach */
"0NQV3ZZ" = "1" /* Repair Left Mandible, Percutaneous Approach */
"0NQV4ZZ" = "1" /* Repair Left Mandible, Percutaneous Endoscopic Approach */
"0NQX0ZZ" = "1" /* Repair Hyoid Bone, Open Approach */
"0NQX3ZZ" = "1" /* Repair Hyoid Bone, Percutaneous Approach */
"0NQX4ZZ" = "1" /* Repair Hyoid Bone, Percutaneous Endoscopic Approach */
"0NR007Z" = "1" /* Replacement of Skull with Autologous Tissue Substitute, Open Approach */
"0NR00JZ" = "1" /* Replacement of Skull with Synthetic Substitute, Open Approach */
"0NR00KZ" = "1" /* Replacement of Skull with Nonautologous Tissue Substitute, Open Approach */
"0NR037Z" = "1" /* Replacement of Skull with Autologous Tissue Substitute, Percutaneous Approach */
"0NR03JZ" = "1" /* Replacement of Skull with Synthetic Substitute, Percutaneous Approach */
"0NR03KZ" = "1" /* Replacement of Skull with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NR047Z" = "1" /* Replacement of Skull with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NR04JZ" = "1" /* Replacement of Skull with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NR04KZ" = "1" /* Replacement of Skull with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NR107Z" = "1" /* Replacement of Right Frontal Bone with Autologous Tissue Substitute, Open Approach */
"0NR10JZ" = "1" /* Replacement of Right Frontal Bone with Synthetic Substitute, Open Approach */
"0NR10KZ" = "1" /* Replacement of Right Frontal Bone with Nonautologous Tissue Substitute, Open Approach */
"0NR137Z" = "1" /* Replacement of Right Frontal Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NR13JZ" = "1" /* Replacement of Right Frontal Bone with Synthetic Substitute, Percutaneous Approach */
"0NR13KZ" = "1" /* Replacement of Right Frontal Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NR147Z" = "1" /* Replacement of Right Frontal Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NR14JZ" = "1" /* Replacement of Right Frontal Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NR14KZ" = "1" /* Replacement of Right Frontal Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NR207Z" = "1" /* Replacement of Left Frontal Bone with Autologous Tissue Substitute, Open Approach */
"0NR20JZ" = "1" /* Replacement of Left Frontal Bone with Synthetic Substitute, Open Approach */
"0NR20KZ" = "1" /* Replacement of Left Frontal Bone with Nonautologous Tissue Substitute, Open Approach */
"0NR237Z" = "1" /* Replacement of Left Frontal Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NR23JZ" = "1" /* Replacement of Left Frontal Bone with Synthetic Substitute, Percutaneous Approach */
"0NR23KZ" = "1" /* Replacement of Left Frontal Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NR247Z" = "1" /* Replacement of Left Frontal Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NR24JZ" = "1" /* Replacement of Left Frontal Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NR24KZ" = "1" /* Replacement of Left Frontal Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NR307Z" = "1" /* Replacement of Right Parietal Bone with Autologous Tissue Substitute, Open Approach */
"0NR30JZ" = "1" /* Replacement of Right Parietal Bone with Synthetic Substitute, Open Approach */
"0NR30KZ" = "1" /* Replacement of Right Parietal Bone with Nonautologous Tissue Substitute, Open Approach */
"0NR337Z" = "1" /* Replacement of Right Parietal Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NR33JZ" = "1" /* Replacement of Right Parietal Bone with Synthetic Substitute, Percutaneous Approach */
"0NR33KZ" = "1" /* Replacement of Right Parietal Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NR347Z" = "1" /* Replacement of Right Parietal Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NR34JZ" = "1" /* Replacement of Right Parietal Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NR34KZ" = "1" /* Replacement of Right Parietal Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NR407Z" = "1" /* Replacement of Left Parietal Bone with Autologous Tissue Substitute, Open Approach */
"0NR40JZ" = "1" /* Replacement of Left Parietal Bone with Synthetic Substitute, Open Approach */
"0NR40KZ" = "1" /* Replacement of Left Parietal Bone with Nonautologous Tissue Substitute, Open Approach */
"0NR437Z" = "1" /* Replacement of Left Parietal Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NR43JZ" = "1" /* Replacement of Left Parietal Bone with Synthetic Substitute, Percutaneous Approach */
"0NR43KZ" = "1" /* Replacement of Left Parietal Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NR447Z" = "1" /* Replacement of Left Parietal Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NR44JZ" = "1" /* Replacement of Left Parietal Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NR44KZ" = "1" /* Replacement of Left Parietal Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NR507Z" = "1" /* Replacement of Right Temporal Bone with Autologous Tissue Substitute, Open Approach */
"0NR50JZ" = "1" /* Replacement of Right Temporal Bone with Synthetic Substitute, Open Approach */
"0NR50KZ" = "1" /* Replacement of Right Temporal Bone with Nonautologous Tissue Substitute, Open Approach */
"0NR537Z" = "1" /* Replacement of Right Temporal Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NR53JZ" = "1" /* Replacement of Right Temporal Bone with Synthetic Substitute, Percutaneous Approach */
"0NR53KZ" = "1" /* Replacement of Right Temporal Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NR547Z" = "1" /* Replacement of Right Temporal Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NR54JZ" = "1" /* Replacement of Right Temporal Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NR54KZ" = "1" /* Replacement of Right Temporal Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NR607Z" = "1" /* Replacement of Left Temporal Bone with Autologous Tissue Substitute, Open Approach */
"0NR60JZ" = "1" /* Replacement of Left Temporal Bone with Synthetic Substitute, Open Approach */
"0NR60KZ" = "1" /* Replacement of Left Temporal Bone with Nonautologous Tissue Substitute, Open Approach */
"0NR637Z" = "1" /* Replacement of Left Temporal Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NR63JZ" = "1" /* Replacement of Left Temporal Bone with Synthetic Substitute, Percutaneous Approach */
"0NR63KZ" = "1" /* Replacement of Left Temporal Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NR647Z" = "1" /* Replacement of Left Temporal Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NR64JZ" = "1" /* Replacement of Left Temporal Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NR64KZ" = "1" /* Replacement of Left Temporal Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NR707Z" = "1" /* Replacement of Right Occipital Bone with Autologous Tissue Substitute, Open Approach */
"0NR70JZ" = "1" /* Replacement of Right Occipital Bone with Synthetic Substitute, Open Approach */
"0NR70KZ" = "1" /* Replacement of Right Occipital Bone with Nonautologous Tissue Substitute, Open Approach */
"0NR737Z" = "1" /* Replacement of Right Occipital Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NR73JZ" = "1" /* Replacement of Right Occipital Bone with Synthetic Substitute, Percutaneous Approach */
"0NR73KZ" = "1" /* Replacement of Right Occipital Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NR747Z" = "1" /* Replacement of Right Occipital Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NR74JZ" = "1" /* Replacement of Right Occipital Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NR74KZ" = "1" /* Replacement of Right Occipital Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NR807Z" = "1" /* Replacement of Left Occipital Bone with Autologous Tissue Substitute, Open Approach */
"0NR80JZ" = "1" /* Replacement of Left Occipital Bone with Synthetic Substitute, Open Approach */
"0NR80KZ" = "1" /* Replacement of Left Occipital Bone with Nonautologous Tissue Substitute, Open Approach */
"0NR837Z" = "1" /* Replacement of Left Occipital Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NR83JZ" = "1" /* Replacement of Left Occipital Bone with Synthetic Substitute, Percutaneous Approach */
"0NR83KZ" = "1" /* Replacement of Left Occipital Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NR847Z" = "1" /* Replacement of Left Occipital Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NR84JZ" = "1" /* Replacement of Left Occipital Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NR84KZ" = "1" /* Replacement of Left Occipital Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRB07Z" = "1" /* Replacement of Nasal Bone with Autologous Tissue Substitute, Open Approach */
"0NRB0JZ" = "1" /* Replacement of Nasal Bone with Synthetic Substitute, Open Approach */
"0NRB0KZ" = "1" /* Replacement of Nasal Bone with Nonautologous Tissue Substitute, Open Approach */
"0NRB37Z" = "1" /* Replacement of Nasal Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NRB3JZ" = "1" /* Replacement of Nasal Bone with Synthetic Substitute, Percutaneous Approach */
"0NRB3KZ" = "1" /* Replacement of Nasal Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NRB47Z" = "1" /* Replacement of Nasal Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRB4JZ" = "1" /* Replacement of Nasal Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NRB4KZ" = "1" /* Replacement of Nasal Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRC07Z" = "1" /* Replacement of Right Sphenoid Bone with Autologous Tissue Substitute, Open Approach */
"0NRC0JZ" = "1" /* Replacement of Right Sphenoid Bone with Synthetic Substitute, Open Approach */
"0NRC0KZ" = "1" /* Replacement of Right Sphenoid Bone with Nonautologous Tissue Substitute, Open Approach */
"0NRC37Z" = "1" /* Replacement of Right Sphenoid Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NRC3JZ" = "1" /* Replacement of Right Sphenoid Bone with Synthetic Substitute, Percutaneous Approach */
"0NRC3KZ" = "1" /* Replacement of Right Sphenoid Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NRC47Z" = "1" /* Replacement of Right Sphenoid Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRC4JZ" = "1" /* Replacement of Right Sphenoid Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NRC4KZ" = "1" /* Replacement of Right Sphenoid Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRD07Z" = "1" /* Replacement of Left Sphenoid Bone with Autologous Tissue Substitute, Open Approach */
"0NRD0JZ" = "1" /* Replacement of Left Sphenoid Bone with Synthetic Substitute, Open Approach */
"0NRD0KZ" = "1" /* Replacement of Left Sphenoid Bone with Nonautologous Tissue Substitute, Open Approach */
"0NRD37Z" = "1" /* Replacement of Left Sphenoid Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NRD3JZ" = "1" /* Replacement of Left Sphenoid Bone with Synthetic Substitute, Percutaneous Approach */
"0NRD3KZ" = "1" /* Replacement of Left Sphenoid Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NRD47Z" = "1" /* Replacement of Left Sphenoid Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRD4JZ" = "1" /* Replacement of Left Sphenoid Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NRD4KZ" = "1" /* Replacement of Left Sphenoid Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRF07Z" = "1" /* Replacement of Right Ethmoid Bone with Autologous Tissue Substitute, Open Approach */
"0NRF0JZ" = "1" /* Replacement of Right Ethmoid Bone with Synthetic Substitute, Open Approach */
"0NRF0KZ" = "1" /* Replacement of Right Ethmoid Bone with Nonautologous Tissue Substitute, Open Approach */
"0NRF37Z" = "1" /* Replacement of Right Ethmoid Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NRF3JZ" = "1" /* Replacement of Right Ethmoid Bone with Synthetic Substitute, Percutaneous Approach */
"0NRF3KZ" = "1" /* Replacement of Right Ethmoid Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NRF47Z" = "1" /* Replacement of Right Ethmoid Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRF4JZ" = "1" /* Replacement of Right Ethmoid Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NRF4KZ" = "1" /* Replacement of Right Ethmoid Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRG07Z" = "1" /* Replacement of Left Ethmoid Bone with Autologous Tissue Substitute, Open Approach */
"0NRG0JZ" = "1" /* Replacement of Left Ethmoid Bone with Synthetic Substitute, Open Approach */
"0NRG0KZ" = "1" /* Replacement of Left Ethmoid Bone with Nonautologous Tissue Substitute, Open Approach */
"0NRG37Z" = "1" /* Replacement of Left Ethmoid Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NRG3JZ" = "1" /* Replacement of Left Ethmoid Bone with Synthetic Substitute, Percutaneous Approach */
"0NRG3KZ" = "1" /* Replacement of Left Ethmoid Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NRG47Z" = "1" /* Replacement of Left Ethmoid Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRG4JZ" = "1" /* Replacement of Left Ethmoid Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NRG4KZ" = "1" /* Replacement of Left Ethmoid Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRH07Z" = "1" /* Replacement of Right Lacrimal Bone with Autologous Tissue Substitute, Open Approach */
"0NRH0JZ" = "1" /* Replacement of Right Lacrimal Bone with Synthetic Substitute, Open Approach */
"0NRH0KZ" = "1" /* Replacement of Right Lacrimal Bone with Nonautologous Tissue Substitute, Open Approach */
"0NRH37Z" = "1" /* Replacement of Right Lacrimal Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NRH3JZ" = "1" /* Replacement of Right Lacrimal Bone with Synthetic Substitute, Percutaneous Approach */
"0NRH3KZ" = "1" /* Replacement of Right Lacrimal Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NRH47Z" = "1" /* Replacement of Right Lacrimal Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRH4JZ" = "1" /* Replacement of Right Lacrimal Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NRH4KZ" = "1" /* Replacement of Right Lacrimal Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRJ07Z" = "1" /* Replacement of Left Lacrimal Bone with Autologous Tissue Substitute, Open Approach */
"0NRJ0JZ" = "1" /* Replacement of Left Lacrimal Bone with Synthetic Substitute, Open Approach */
"0NRJ0KZ" = "1" /* Replacement of Left Lacrimal Bone with Nonautologous Tissue Substitute, Open Approach */
"0NRJ37Z" = "1" /* Replacement of Left Lacrimal Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NRJ3JZ" = "1" /* Replacement of Left Lacrimal Bone with Synthetic Substitute, Percutaneous Approach */
"0NRJ3KZ" = "1" /* Replacement of Left Lacrimal Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NRJ47Z" = "1" /* Replacement of Left Lacrimal Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRJ4JZ" = "1" /* Replacement of Left Lacrimal Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NRJ4KZ" = "1" /* Replacement of Left Lacrimal Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRK07Z" = "1" /* Replacement of Right Palatine Bone with Autologous Tissue Substitute, Open Approach */
"0NRK0JZ" = "1" /* Replacement of Right Palatine Bone with Synthetic Substitute, Open Approach */
"0NRK0KZ" = "1" /* Replacement of Right Palatine Bone with Nonautologous Tissue Substitute, Open Approach */
"0NRK37Z" = "1" /* Replacement of Right Palatine Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NRK3JZ" = "1" /* Replacement of Right Palatine Bone with Synthetic Substitute, Percutaneous Approach */
"0NRK3KZ" = "1" /* Replacement of Right Palatine Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NRK47Z" = "1" /* Replacement of Right Palatine Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRK4JZ" = "1" /* Replacement of Right Palatine Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NRK4KZ" = "1" /* Replacement of Right Palatine Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRL07Z" = "1" /* Replacement of Left Palatine Bone with Autologous Tissue Substitute, Open Approach */
"0NRL0JZ" = "1" /* Replacement of Left Palatine Bone with Synthetic Substitute, Open Approach */
"0NRL0KZ" = "1" /* Replacement of Left Palatine Bone with Nonautologous Tissue Substitute, Open Approach */
"0NRL37Z" = "1" /* Replacement of Left Palatine Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NRL3JZ" = "1" /* Replacement of Left Palatine Bone with Synthetic Substitute, Percutaneous Approach */
"0NRL3KZ" = "1" /* Replacement of Left Palatine Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NRL47Z" = "1" /* Replacement of Left Palatine Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRL4JZ" = "1" /* Replacement of Left Palatine Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NRL4KZ" = "1" /* Replacement of Left Palatine Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRM07Z" = "1" /* Replacement of Right Zygomatic Bone with Autologous Tissue Substitute, Open Approach */
"0NRM0JZ" = "1" /* Replacement of Right Zygomatic Bone with Synthetic Substitute, Open Approach */
"0NRM0KZ" = "1" /* Replacement of Right Zygomatic Bone with Nonautologous Tissue Substitute, Open Approach */
"0NRM37Z" = "1" /* Replacement of Right Zygomatic Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NRM3JZ" = "1" /* Replacement of Right Zygomatic Bone with Synthetic Substitute, Percutaneous Approach */
"0NRM3KZ" = "1" /* Replacement of Right Zygomatic Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NRM47Z" = "1" /* Replacement of Right Zygomatic Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRM4JZ" = "1" /* Replacement of Right Zygomatic Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NRM4KZ" = "1" /* Replacement of Right Zygomatic Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRN07Z" = "1" /* Replacement of Left Zygomatic Bone with Autologous Tissue Substitute, Open Approach */
"0NRN0JZ" = "1" /* Replacement of Left Zygomatic Bone with Synthetic Substitute, Open Approach */
"0NRN0KZ" = "1" /* Replacement of Left Zygomatic Bone with Nonautologous Tissue Substitute, Open Approach */
"0NRN37Z" = "1" /* Replacement of Left Zygomatic Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NRN3JZ" = "1" /* Replacement of Left Zygomatic Bone with Synthetic Substitute, Percutaneous Approach */
"0NRN3KZ" = "1" /* Replacement of Left Zygomatic Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NRN47Z" = "1" /* Replacement of Left Zygomatic Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRN4JZ" = "1" /* Replacement of Left Zygomatic Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NRN4KZ" = "1" /* Replacement of Left Zygomatic Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRP07Z" = "1" /* Replacement of Right Orbit with Autologous Tissue Substitute, Open Approach */
"0NRP0JZ" = "1" /* Replacement of Right Orbit with Synthetic Substitute, Open Approach */
"0NRP0KZ" = "1" /* Replacement of Right Orbit with Nonautologous Tissue Substitute, Open Approach */
"0NRP37Z" = "1" /* Replacement of Right Orbit with Autologous Tissue Substitute, Percutaneous Approach */
"0NRP3JZ" = "1" /* Replacement of Right Orbit with Synthetic Substitute, Percutaneous Approach */
"0NRP3KZ" = "1" /* Replacement of Right Orbit with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NRP47Z" = "1" /* Replacement of Right Orbit with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRP4JZ" = "1" /* Replacement of Right Orbit with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NRP4KZ" = "1" /* Replacement of Right Orbit with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRQ07Z" = "1" /* Replacement of Left Orbit with Autologous Tissue Substitute, Open Approach */
"0NRQ0JZ" = "1" /* Replacement of Left Orbit with Synthetic Substitute, Open Approach */
"0NRQ0KZ" = "1" /* Replacement of Left Orbit with Nonautologous Tissue Substitute, Open Approach */
"0NRQ37Z" = "1" /* Replacement of Left Orbit with Autologous Tissue Substitute, Percutaneous Approach */
"0NRQ3JZ" = "1" /* Replacement of Left Orbit with Synthetic Substitute, Percutaneous Approach */
"0NRQ3KZ" = "1" /* Replacement of Left Orbit with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NRQ47Z" = "1" /* Replacement of Left Orbit with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRQ4JZ" = "1" /* Replacement of Left Orbit with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NRQ4KZ" = "1" /* Replacement of Left Orbit with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRR07Z" = "1" /* Replacement of Right Maxilla with Autologous Tissue Substitute, Open Approach */
"0NRR0JZ" = "1" /* Replacement of Right Maxilla with Synthetic Substitute, Open Approach */
"0NRR0KZ" = "1" /* Replacement of Right Maxilla with Nonautologous Tissue Substitute, Open Approach */
"0NRR37Z" = "1" /* Replacement of Right Maxilla with Autologous Tissue Substitute, Percutaneous Approach */
"0NRR3JZ" = "1" /* Replacement of Right Maxilla with Synthetic Substitute, Percutaneous Approach */
"0NRR3KZ" = "1" /* Replacement of Right Maxilla with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NRR47Z" = "1" /* Replacement of Right Maxilla with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRR4JZ" = "1" /* Replacement of Right Maxilla with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NRR4KZ" = "1" /* Replacement of Right Maxilla with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRS07Z" = "1" /* Replacement of Left Maxilla with Autologous Tissue Substitute, Open Approach */
"0NRS0JZ" = "1" /* Replacement of Left Maxilla with Synthetic Substitute, Open Approach */
"0NRS0KZ" = "1" /* Replacement of Left Maxilla with Nonautologous Tissue Substitute, Open Approach */
"0NRS37Z" = "1" /* Replacement of Left Maxilla with Autologous Tissue Substitute, Percutaneous Approach */
"0NRS3JZ" = "1" /* Replacement of Left Maxilla with Synthetic Substitute, Percutaneous Approach */
"0NRS3KZ" = "1" /* Replacement of Left Maxilla with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NRS47Z" = "1" /* Replacement of Left Maxilla with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRS4JZ" = "1" /* Replacement of Left Maxilla with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NRS4KZ" = "1" /* Replacement of Left Maxilla with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRT07Z" = "1" /* Replacement of Right Mandible with Autologous Tissue Substitute, Open Approach */
"0NRT0JZ" = "1" /* Replacement of Right Mandible with Synthetic Substitute, Open Approach */
"0NRT0KZ" = "1" /* Replacement of Right Mandible with Nonautologous Tissue Substitute, Open Approach */
"0NRT37Z" = "1" /* Replacement of Right Mandible with Autologous Tissue Substitute, Percutaneous Approach */
"0NRT3JZ" = "1" /* Replacement of Right Mandible with Synthetic Substitute, Percutaneous Approach */
"0NRT3KZ" = "1" /* Replacement of Right Mandible with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NRT47Z" = "1" /* Replacement of Right Mandible with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRT4JZ" = "1" /* Replacement of Right Mandible with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NRT4KZ" = "1" /* Replacement of Right Mandible with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRV07Z" = "1" /* Replacement of Left Mandible with Autologous Tissue Substitute, Open Approach */
"0NRV0JZ" = "1" /* Replacement of Left Mandible with Synthetic Substitute, Open Approach */
"0NRV0KZ" = "1" /* Replacement of Left Mandible with Nonautologous Tissue Substitute, Open Approach */
"0NRV37Z" = "1" /* Replacement of Left Mandible with Autologous Tissue Substitute, Percutaneous Approach */
"0NRV3JZ" = "1" /* Replacement of Left Mandible with Synthetic Substitute, Percutaneous Approach */
"0NRV3KZ" = "1" /* Replacement of Left Mandible with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NRV47Z" = "1" /* Replacement of Left Mandible with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRV4JZ" = "1" /* Replacement of Left Mandible with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NRV4KZ" = "1" /* Replacement of Left Mandible with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRX07Z" = "1" /* Replacement of Hyoid Bone with Autologous Tissue Substitute, Open Approach */
"0NRX0JZ" = "1" /* Replacement of Hyoid Bone with Synthetic Substitute, Open Approach */
"0NRX0KZ" = "1" /* Replacement of Hyoid Bone with Nonautologous Tissue Substitute, Open Approach */
"0NRX37Z" = "1" /* Replacement of Hyoid Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NRX3JZ" = "1" /* Replacement of Hyoid Bone with Synthetic Substitute, Percutaneous Approach */
"0NRX3KZ" = "1" /* Replacement of Hyoid Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NRX47Z" = "1" /* Replacement of Hyoid Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NRX4JZ" = "1" /* Replacement of Hyoid Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NRX4KZ" = "1" /* Replacement of Hyoid Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NS004Z" = "1" /* Reposition Skull with Internal Fixation Device, Open Approach */
"0NS005Z" = "1" /* Reposition Skull with External Fixation Device, Open Approach */
"0NS00ZZ" = "1" /* Reposition Skull, Open Approach */
"0NS034Z" = "1" /* Reposition Skull with Internal Fixation Device, Percutaneous Approach */
"0NS035Z" = "1" /* Reposition Skull with External Fixation Device, Percutaneous Approach */
"0NS03ZZ" = "1" /* Reposition Skull, Percutaneous Approach */
"0NS044Z" = "1" /* Reposition Skull with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0NS045Z" = "1" /* Reposition Skull with External Fixation Device, Percutaneous Endoscopic Approach */
"0NS04ZZ" = "1" /* Reposition Skull, Percutaneous Endoscopic Approach */
"0NS104Z" = "1" /* Reposition Right Frontal Bone with Internal Fixation Device, Open Approach */
"0NS10ZZ" = "1" /* Reposition Right Frontal Bone, Open Approach */
"0NS134Z" = "1" /* Reposition Right Frontal Bone with Internal Fixation Device, Percutaneous Approach */
"0NS13ZZ" = "1" /* Reposition Right Frontal Bone, Percutaneous Approach */
"0NS144Z" = "1" /* Reposition Right Frontal Bone with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0NS14ZZ" = "1" /* Reposition Right Frontal Bone, Percutaneous Endoscopic Approach */
"0NS204Z" = "1" /* Reposition Left Frontal Bone with Internal Fixation Device, Open Approach */
"0NS20ZZ" = "1" /* Reposition Left Frontal Bone, Open Approach */
"0NS234Z" = "1" /* Reposition Left Frontal Bone with Internal Fixation Device, Percutaneous Approach */
"0NS23ZZ" = "1" /* Reposition Left Frontal Bone, Percutaneous Approach */
"0NS244Z" = "1" /* Reposition Left Frontal Bone with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0NS24ZZ" = "1" /* Reposition Left Frontal Bone, Percutaneous Endoscopic Approach */
"0NS304Z" = "1" /* Reposition Right Parietal Bone with Internal Fixation Device, Open Approach */
"0NS30ZZ" = "1" /* Reposition Right Parietal Bone, Open Approach */
"0NS334Z" = "1" /* Reposition Right Parietal Bone with Internal Fixation Device, Percutaneous Approach */
"0NS33ZZ" = "1" /* Reposition Right Parietal Bone, Percutaneous Approach */
"0NS344Z" = "1" /* Reposition Right Parietal Bone with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0NS34ZZ" = "1" /* Reposition Right Parietal Bone, Percutaneous Endoscopic Approach */
"0NS404Z" = "1" /* Reposition Left Parietal Bone with Internal Fixation Device, Open Approach */
"0NS40ZZ" = "1" /* Reposition Left Parietal Bone, Open Approach */
"0NS434Z" = "1" /* Reposition Left Parietal Bone with Internal Fixation Device, Percutaneous Approach */
"0NS43ZZ" = "1" /* Reposition Left Parietal Bone, Percutaneous Approach */
"0NS444Z" = "1" /* Reposition Left Parietal Bone with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0NS44ZZ" = "1" /* Reposition Left Parietal Bone, Percutaneous Endoscopic Approach */
"0NS504Z" = "1" /* Reposition Right Temporal Bone with Internal Fixation Device, Open Approach */
"0NS50ZZ" = "1" /* Reposition Right Temporal Bone, Open Approach */
"0NS534Z" = "1" /* Reposition Right Temporal Bone with Internal Fixation Device, Percutaneous Approach */
"0NS53ZZ" = "1" /* Reposition Right Temporal Bone, Percutaneous Approach */
"0NS544Z" = "1" /* Reposition Right Temporal Bone with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0NS54ZZ" = "1" /* Reposition Right Temporal Bone, Percutaneous Endoscopic Approach */
"0NS604Z" = "1" /* Reposition Left Temporal Bone with Internal Fixation Device, Open Approach */
"0NS60ZZ" = "1" /* Reposition Left Temporal Bone, Open Approach */
"0NS634Z" = "1" /* Reposition Left Temporal Bone with Internal Fixation Device, Percutaneous Approach */
"0NS63ZZ" = "1" /* Reposition Left Temporal Bone, Percutaneous Approach */
"0NS644Z" = "1" /* Reposition Left Temporal Bone with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0NS64ZZ" = "1" /* Reposition Left Temporal Bone, Percutaneous Endoscopic Approach */
"0NS704Z" = "1" /* Reposition Right Occipital Bone with Internal Fixation Device, Open Approach */
"0NS70ZZ" = "1" /* Reposition Right Occipital Bone, Open Approach */
"0NS734Z" = "1" /* Reposition Right Occipital Bone with Internal Fixation Device, Percutaneous Approach */
"0NS73ZZ" = "1" /* Reposition Right Occipital Bone, Percutaneous Approach */
"0NS744Z" = "1" /* Reposition Right Occipital Bone with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0NS74ZZ" = "1" /* Reposition Right Occipital Bone, Percutaneous Endoscopic Approach */
"0NS804Z" = "1" /* Reposition Left Occipital Bone with Internal Fixation Device, Open Approach */
"0NS80ZZ" = "1" /* Reposition Left Occipital Bone, Open Approach */
"0NS834Z" = "1" /* Reposition Left Occipital Bone with Internal Fixation Device, Percutaneous Approach */
"0NS83ZZ" = "1" /* Reposition Left Occipital Bone, Percutaneous Approach */
"0NS844Z" = "1" /* Reposition Left Occipital Bone with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0NS84ZZ" = "1" /* Reposition Left Occipital Bone, Percutaneous Endoscopic Approach */
"0NSB04Z" = "1" /* Reposition Nasal Bone with Internal Fixation Device, Open Approach */
"0NSB0ZZ" = "1" /* Reposition Nasal Bone, Open Approach */
"0NSC04Z" = "1" /* Reposition Right Sphenoid Bone with Internal Fixation Device, Open Approach */
"0NSC0ZZ" = "1" /* Reposition Right Sphenoid Bone, Open Approach */
"0NSD04Z" = "1" /* Reposition Left Sphenoid Bone with Internal Fixation Device, Open Approach */
"0NSD0ZZ" = "1" /* Reposition Left Sphenoid Bone, Open Approach */
"0NSF04Z" = "1" /* Reposition Right Ethmoid Bone with Internal Fixation Device, Open Approach */
"0NSF0ZZ" = "1" /* Reposition Right Ethmoid Bone, Open Approach */
"0NSG04Z" = "1" /* Reposition Left Ethmoid Bone with Internal Fixation Device, Open Approach */
"0NSG0ZZ" = "1" /* Reposition Left Ethmoid Bone, Open Approach */
"0NSH04Z" = "1" /* Reposition Right Lacrimal Bone with Internal Fixation Device, Open Approach */
"0NSH0ZZ" = "1" /* Reposition Right Lacrimal Bone, Open Approach */
"0NSJ04Z" = "1" /* Reposition Left Lacrimal Bone with Internal Fixation Device, Open Approach */
"0NSJ0ZZ" = "1" /* Reposition Left Lacrimal Bone, Open Approach */
"0NSK04Z" = "1" /* Reposition Right Palatine Bone with Internal Fixation Device, Open Approach */
"0NSK0ZZ" = "1" /* Reposition Right Palatine Bone, Open Approach */
"0NSL04Z" = "1" /* Reposition Left Palatine Bone with Internal Fixation Device, Open Approach */
"0NSL0ZZ" = "1" /* Reposition Left Palatine Bone, Open Approach */
"0NSM04Z" = "1" /* Reposition Right Zygomatic Bone with Internal Fixation Device, Open Approach */
"0NSM0ZZ" = "1" /* Reposition Right Zygomatic Bone, Open Approach */
"0NSN04Z" = "1" /* Reposition Left Zygomatic Bone with Internal Fixation Device, Open Approach */
"0NSN0ZZ" = "1" /* Reposition Left Zygomatic Bone, Open Approach */
"0NSP04Z" = "1" /* Reposition Right Orbit with Internal Fixation Device, Open Approach */
"0NSP0ZZ" = "1" /* Reposition Right Orbit, Open Approach */
"0NSQ04Z" = "1" /* Reposition Left Orbit with Internal Fixation Device, Open Approach */
"0NSQ0ZZ" = "1" /* Reposition Left Orbit, Open Approach */
"0NSR04Z" = "1" /* Reposition Right Maxilla with Internal Fixation Device, Open Approach */
"0NSR05Z" = "1" /* Reposition Right Maxilla with External Fixation Device, Open Approach */
"0NSR0ZZ" = "1" /* Reposition Right Maxilla, Open Approach */
"0NSS04Z" = "1" /* Reposition Left Maxilla with Internal Fixation Device, Open Approach */
"0NSS05Z" = "1" /* Reposition Left Maxilla with External Fixation Device, Open Approach */
"0NSS0ZZ" = "1" /* Reposition Left Maxilla, Open Approach */
"0NST04Z" = "1" /* Reposition Right Mandible with Internal Fixation Device, Open Approach */
"0NST05Z" = "1" /* Reposition Right Mandible with External Fixation Device, Open Approach */
"0NST0ZZ" = "1" /* Reposition Right Mandible, Open Approach */
"0NSV04Z" = "1" /* Reposition Left Mandible with Internal Fixation Device, Open Approach */
"0NSV05Z" = "1" /* Reposition Left Mandible with External Fixation Device, Open Approach */
"0NSV0ZZ" = "1" /* Reposition Left Mandible, Open Approach */
"0NSX04Z" = "1" /* Reposition Hyoid Bone with Internal Fixation Device, Open Approach */
"0NSX0ZZ" = "1" /* Reposition Hyoid Bone, Open Approach */
"0NT10ZZ" = "1" /* Resection of Right Frontal Bone, Open Approach */
"0NT20ZZ" = "1" /* Resection of Left Frontal Bone, Open Approach */
"0NT30ZZ" = "1" /* Resection of Right Parietal Bone, Open Approach */
"0NT40ZZ" = "1" /* Resection of Left Parietal Bone, Open Approach */
"0NT50ZZ" = "1" /* Resection of Right Temporal Bone, Open Approach */
"0NT60ZZ" = "1" /* Resection of Left Temporal Bone, Open Approach */
"0NT70ZZ" = "1" /* Resection of Right Occipital Bone, Open Approach */
"0NT80ZZ" = "1" /* Resection of Left Occipital Bone, Open Approach */
"0NTB0ZZ" = "1" /* Resection of Nasal Bone, Open Approach */
"0NTC0ZZ" = "1" /* Resection of Right Sphenoid Bone, Open Approach */
"0NTD0ZZ" = "1" /* Resection of Left Sphenoid Bone, Open Approach */
"0NTF0ZZ" = "1" /* Resection of Right Ethmoid Bone, Open Approach */
"0NTG0ZZ" = "1" /* Resection of Left Ethmoid Bone, Open Approach */
"0NTH0ZZ" = "1" /* Resection of Right Lacrimal Bone, Open Approach */
"0NTJ0ZZ" = "1" /* Resection of Left Lacrimal Bone, Open Approach */
"0NTK0ZZ" = "1" /* Resection of Right Palatine Bone, Open Approach */
"0NTL0ZZ" = "1" /* Resection of Left Palatine Bone, Open Approach */
"0NTM0ZZ" = "1" /* Resection of Right Zygomatic Bone, Open Approach */
"0NTN0ZZ" = "1" /* Resection of Left Zygomatic Bone, Open Approach */
"0NTP0ZZ" = "1" /* Resection of Right Orbit, Open Approach */
"0NTQ0ZZ" = "1" /* Resection of Left Orbit, Open Approach */
"0NTR0ZZ" = "1" /* Resection of Right Maxilla, Open Approach */
"0NTS0ZZ" = "1" /* Resection of Left Maxilla, Open Approach */
"0NTT0ZZ" = "1" /* Resection of Right Mandible, Open Approach */
"0NTV0ZZ" = "1" /* Resection of Left Mandible, Open Approach */
"0NTX0ZZ" = "1" /* Resection of Hyoid Bone, Open Approach */
"0NU007Z" = "1" /* Supplement Skull with Autologous Tissue Substitute, Open Approach */
"0NU00JZ" = "1" /* Supplement Skull with Synthetic Substitute, Open Approach */
"0NU00KZ" = "1" /* Supplement Skull with Nonautologous Tissue Substitute, Open Approach */
"0NU037Z" = "1" /* Supplement Skull with Autologous Tissue Substitute, Percutaneous Approach */
"0NU03JZ" = "1" /* Supplement Skull with Synthetic Substitute, Percutaneous Approach */
"0NU03KZ" = "1" /* Supplement Skull with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NU047Z" = "1" /* Supplement Skull with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NU04JZ" = "1" /* Supplement Skull with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NU04KZ" = "1" /* Supplement Skull with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NU107Z" = "1" /* Supplement Right Frontal Bone with Autologous Tissue Substitute, Open Approach */
"0NU10JZ" = "1" /* Supplement Right Frontal Bone with Synthetic Substitute, Open Approach */
"0NU10KZ" = "1" /* Supplement Right Frontal Bone with Nonautologous Tissue Substitute, Open Approach */
"0NU137Z" = "1" /* Supplement Right Frontal Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NU13JZ" = "1" /* Supplement Right Frontal Bone with Synthetic Substitute, Percutaneous Approach */
"0NU13KZ" = "1" /* Supplement Right Frontal Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NU147Z" = "1" /* Supplement Right Frontal Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NU14JZ" = "1" /* Supplement Right Frontal Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NU14KZ" = "1" /* Supplement Right Frontal Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NU207Z" = "1" /* Supplement Left Frontal Bone with Autologous Tissue Substitute, Open Approach */
"0NU20JZ" = "1" /* Supplement Left Frontal Bone with Synthetic Substitute, Open Approach */
"0NU20KZ" = "1" /* Supplement Left Frontal Bone with Nonautologous Tissue Substitute, Open Approach */
"0NU237Z" = "1" /* Supplement Left Frontal Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NU23JZ" = "1" /* Supplement Left Frontal Bone with Synthetic Substitute, Percutaneous Approach */
"0NU23KZ" = "1" /* Supplement Left Frontal Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NU247Z" = "1" /* Supplement Left Frontal Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NU24JZ" = "1" /* Supplement Left Frontal Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NU24KZ" = "1" /* Supplement Left Frontal Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NU307Z" = "1" /* Supplement Right Parietal Bone with Autologous Tissue Substitute, Open Approach */
"0NU30JZ" = "1" /* Supplement Right Parietal Bone with Synthetic Substitute, Open Approach */
"0NU30KZ" = "1" /* Supplement Right Parietal Bone with Nonautologous Tissue Substitute, Open Approach */
"0NU337Z" = "1" /* Supplement Right Parietal Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NU33JZ" = "1" /* Supplement Right Parietal Bone with Synthetic Substitute, Percutaneous Approach */
"0NU33KZ" = "1" /* Supplement Right Parietal Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NU347Z" = "1" /* Supplement Right Parietal Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NU34JZ" = "1" /* Supplement Right Parietal Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NU34KZ" = "1" /* Supplement Right Parietal Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NU407Z" = "1" /* Supplement Left Parietal Bone with Autologous Tissue Substitute, Open Approach */
"0NU40JZ" = "1" /* Supplement Left Parietal Bone with Synthetic Substitute, Open Approach */
"0NU40KZ" = "1" /* Supplement Left Parietal Bone with Nonautologous Tissue Substitute, Open Approach */
"0NU437Z" = "1" /* Supplement Left Parietal Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NU43JZ" = "1" /* Supplement Left Parietal Bone with Synthetic Substitute, Percutaneous Approach */
"0NU43KZ" = "1" /* Supplement Left Parietal Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NU447Z" = "1" /* Supplement Left Parietal Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NU44JZ" = "1" /* Supplement Left Parietal Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NU44KZ" = "1" /* Supplement Left Parietal Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NU507Z" = "1" /* Supplement Right Temporal Bone with Autologous Tissue Substitute, Open Approach */
"0NU50JZ" = "1" /* Supplement Right Temporal Bone with Synthetic Substitute, Open Approach */
"0NU50KZ" = "1" /* Supplement Right Temporal Bone with Nonautologous Tissue Substitute, Open Approach */
"0NU537Z" = "1" /* Supplement Right Temporal Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NU53JZ" = "1" /* Supplement Right Temporal Bone with Synthetic Substitute, Percutaneous Approach */
"0NU53KZ" = "1" /* Supplement Right Temporal Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NU547Z" = "1" /* Supplement Right Temporal Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NU54JZ" = "1" /* Supplement Right Temporal Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NU54KZ" = "1" /* Supplement Right Temporal Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NU607Z" = "1" /* Supplement Left Temporal Bone with Autologous Tissue Substitute, Open Approach */
"0NU60JZ" = "1" /* Supplement Left Temporal Bone with Synthetic Substitute, Open Approach */
"0NU60KZ" = "1" /* Supplement Left Temporal Bone with Nonautologous Tissue Substitute, Open Approach */
"0NU637Z" = "1" /* Supplement Left Temporal Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NU63JZ" = "1" /* Supplement Left Temporal Bone with Synthetic Substitute, Percutaneous Approach */
"0NU63KZ" = "1" /* Supplement Left Temporal Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NU647Z" = "1" /* Supplement Left Temporal Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NU64JZ" = "1" /* Supplement Left Temporal Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NU64KZ" = "1" /* Supplement Left Temporal Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NU707Z" = "1" /* Supplement Right Occipital Bone with Autologous Tissue Substitute, Open Approach */
"0NU70JZ" = "1" /* Supplement Right Occipital Bone with Synthetic Substitute, Open Approach */
"0NU70KZ" = "1" /* Supplement Right Occipital Bone with Nonautologous Tissue Substitute, Open Approach */
"0NU737Z" = "1" /* Supplement Right Occipital Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NU73JZ" = "1" /* Supplement Right Occipital Bone with Synthetic Substitute, Percutaneous Approach */
"0NU73KZ" = "1" /* Supplement Right Occipital Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NU747Z" = "1" /* Supplement Right Occipital Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NU74JZ" = "1" /* Supplement Right Occipital Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NU74KZ" = "1" /* Supplement Right Occipital Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NU807Z" = "1" /* Supplement Left Occipital Bone with Autologous Tissue Substitute, Open Approach */
"0NU80JZ" = "1" /* Supplement Left Occipital Bone with Synthetic Substitute, Open Approach */
"0NU80KZ" = "1" /* Supplement Left Occipital Bone with Nonautologous Tissue Substitute, Open Approach */
"0NU837Z" = "1" /* Supplement Left Occipital Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NU83JZ" = "1" /* Supplement Left Occipital Bone with Synthetic Substitute, Percutaneous Approach */
"0NU83KZ" = "1" /* Supplement Left Occipital Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NU847Z" = "1" /* Supplement Left Occipital Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NU84JZ" = "1" /* Supplement Left Occipital Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NU84KZ" = "1" /* Supplement Left Occipital Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUB07Z" = "1" /* Supplement Nasal Bone with Autologous Tissue Substitute, Open Approach */
"0NUB0JZ" = "1" /* Supplement Nasal Bone with Synthetic Substitute, Open Approach */
"0NUB0KZ" = "1" /* Supplement Nasal Bone with Nonautologous Tissue Substitute, Open Approach */
"0NUB37Z" = "1" /* Supplement Nasal Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NUB3JZ" = "1" /* Supplement Nasal Bone with Synthetic Substitute, Percutaneous Approach */
"0NUB3KZ" = "1" /* Supplement Nasal Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NUB47Z" = "1" /* Supplement Nasal Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUB4JZ" = "1" /* Supplement Nasal Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NUB4KZ" = "1" /* Supplement Nasal Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUC07Z" = "1" /* Supplement Right Sphenoid Bone with Autologous Tissue Substitute, Open Approach */
"0NUC0JZ" = "1" /* Supplement Right Sphenoid Bone with Synthetic Substitute, Open Approach */
"0NUC0KZ" = "1" /* Supplement Right Sphenoid Bone with Nonautologous Tissue Substitute, Open Approach */
"0NUC37Z" = "1" /* Supplement Right Sphenoid Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NUC3JZ" = "1" /* Supplement Right Sphenoid Bone with Synthetic Substitute, Percutaneous Approach */
"0NUC3KZ" = "1" /* Supplement Right Sphenoid Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NUC47Z" = "1" /* Supplement Right Sphenoid Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUC4JZ" = "1" /* Supplement Right Sphenoid Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NUC4KZ" = "1" /* Supplement Right Sphenoid Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUD07Z" = "1" /* Supplement Left Sphenoid Bone with Autologous Tissue Substitute, Open Approach */
"0NUD0JZ" = "1" /* Supplement Left Sphenoid Bone with Synthetic Substitute, Open Approach */
"0NUD0KZ" = "1" /* Supplement Left Sphenoid Bone with Nonautologous Tissue Substitute, Open Approach */
"0NUD37Z" = "1" /* Supplement Left Sphenoid Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NUD3JZ" = "1" /* Supplement Left Sphenoid Bone with Synthetic Substitute, Percutaneous Approach */
"0NUD3KZ" = "1" /* Supplement Left Sphenoid Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NUD47Z" = "1" /* Supplement Left Sphenoid Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUD4JZ" = "1" /* Supplement Left Sphenoid Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NUD4KZ" = "1" /* Supplement Left Sphenoid Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUF07Z" = "1" /* Supplement Right Ethmoid Bone with Autologous Tissue Substitute, Open Approach */
"0NUF0JZ" = "1" /* Supplement Right Ethmoid Bone with Synthetic Substitute, Open Approach */
"0NUF0KZ" = "1" /* Supplement Right Ethmoid Bone with Nonautologous Tissue Substitute, Open Approach */
"0NUF37Z" = "1" /* Supplement Right Ethmoid Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NUF3JZ" = "1" /* Supplement Right Ethmoid Bone with Synthetic Substitute, Percutaneous Approach */
"0NUF3KZ" = "1" /* Supplement Right Ethmoid Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NUF47Z" = "1" /* Supplement Right Ethmoid Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUF4JZ" = "1" /* Supplement Right Ethmoid Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NUF4KZ" = "1" /* Supplement Right Ethmoid Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUG07Z" = "1" /* Supplement Left Ethmoid Bone with Autologous Tissue Substitute, Open Approach */
"0NUG0JZ" = "1" /* Supplement Left Ethmoid Bone with Synthetic Substitute, Open Approach */
"0NUG0KZ" = "1" /* Supplement Left Ethmoid Bone with Nonautologous Tissue Substitute, Open Approach */
"0NUG37Z" = "1" /* Supplement Left Ethmoid Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NUG3JZ" = "1" /* Supplement Left Ethmoid Bone with Synthetic Substitute, Percutaneous Approach */
"0NUG3KZ" = "1" /* Supplement Left Ethmoid Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NUG47Z" = "1" /* Supplement Left Ethmoid Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUG4JZ" = "1" /* Supplement Left Ethmoid Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NUG4KZ" = "1" /* Supplement Left Ethmoid Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUH07Z" = "1" /* Supplement Right Lacrimal Bone with Autologous Tissue Substitute, Open Approach */
"0NUH0JZ" = "1" /* Supplement Right Lacrimal Bone with Synthetic Substitute, Open Approach */
"0NUH0KZ" = "1" /* Supplement Right Lacrimal Bone with Nonautologous Tissue Substitute, Open Approach */
"0NUH37Z" = "1" /* Supplement Right Lacrimal Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NUH3JZ" = "1" /* Supplement Right Lacrimal Bone with Synthetic Substitute, Percutaneous Approach */
"0NUH3KZ" = "1" /* Supplement Right Lacrimal Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NUH47Z" = "1" /* Supplement Right Lacrimal Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUH4JZ" = "1" /* Supplement Right Lacrimal Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NUH4KZ" = "1" /* Supplement Right Lacrimal Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUJ07Z" = "1" /* Supplement Left Lacrimal Bone with Autologous Tissue Substitute, Open Approach */
"0NUJ0JZ" = "1" /* Supplement Left Lacrimal Bone with Synthetic Substitute, Open Approach */
"0NUJ0KZ" = "1" /* Supplement Left Lacrimal Bone with Nonautologous Tissue Substitute, Open Approach */
"0NUJ37Z" = "1" /* Supplement Left Lacrimal Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NUJ3JZ" = "1" /* Supplement Left Lacrimal Bone with Synthetic Substitute, Percutaneous Approach */
"0NUJ3KZ" = "1" /* Supplement Left Lacrimal Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NUJ47Z" = "1" /* Supplement Left Lacrimal Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUJ4JZ" = "1" /* Supplement Left Lacrimal Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NUJ4KZ" = "1" /* Supplement Left Lacrimal Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUK07Z" = "1" /* Supplement Right Palatine Bone with Autologous Tissue Substitute, Open Approach */
"0NUK0JZ" = "1" /* Supplement Right Palatine Bone with Synthetic Substitute, Open Approach */
"0NUK0KZ" = "1" /* Supplement Right Palatine Bone with Nonautologous Tissue Substitute, Open Approach */
"0NUK37Z" = "1" /* Supplement Right Palatine Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NUK3JZ" = "1" /* Supplement Right Palatine Bone with Synthetic Substitute, Percutaneous Approach */
"0NUK3KZ" = "1" /* Supplement Right Palatine Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NUK47Z" = "1" /* Supplement Right Palatine Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUK4JZ" = "1" /* Supplement Right Palatine Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NUK4KZ" = "1" /* Supplement Right Palatine Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUL07Z" = "1" /* Supplement Left Palatine Bone with Autologous Tissue Substitute, Open Approach */
"0NUL0JZ" = "1" /* Supplement Left Palatine Bone with Synthetic Substitute, Open Approach */
"0NUL0KZ" = "1" /* Supplement Left Palatine Bone with Nonautologous Tissue Substitute, Open Approach */
"0NUL37Z" = "1" /* Supplement Left Palatine Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NUL3JZ" = "1" /* Supplement Left Palatine Bone with Synthetic Substitute, Percutaneous Approach */
"0NUL3KZ" = "1" /* Supplement Left Palatine Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NUL47Z" = "1" /* Supplement Left Palatine Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUL4JZ" = "1" /* Supplement Left Palatine Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NUL4KZ" = "1" /* Supplement Left Palatine Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUM07Z" = "1" /* Supplement Right Zygomatic Bone with Autologous Tissue Substitute, Open Approach */
"0NUM0JZ" = "1" /* Supplement Right Zygomatic Bone with Synthetic Substitute, Open Approach */
"0NUM0KZ" = "1" /* Supplement Right Zygomatic Bone with Nonautologous Tissue Substitute, Open Approach */
"0NUM37Z" = "1" /* Supplement Right Zygomatic Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NUM3JZ" = "1" /* Supplement Right Zygomatic Bone with Synthetic Substitute, Percutaneous Approach */
"0NUM3KZ" = "1" /* Supplement Right Zygomatic Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NUM47Z" = "1" /* Supplement Right Zygomatic Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUM4JZ" = "1" /* Supplement Right Zygomatic Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NUM4KZ" = "1" /* Supplement Right Zygomatic Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUN07Z" = "1" /* Supplement Left Zygomatic Bone with Autologous Tissue Substitute, Open Approach */
"0NUN0JZ" = "1" /* Supplement Left Zygomatic Bone with Synthetic Substitute, Open Approach */
"0NUN0KZ" = "1" /* Supplement Left Zygomatic Bone with Nonautologous Tissue Substitute, Open Approach */
"0NUN37Z" = "1" /* Supplement Left Zygomatic Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NUN3JZ" = "1" /* Supplement Left Zygomatic Bone with Synthetic Substitute, Percutaneous Approach */
"0NUN3KZ" = "1" /* Supplement Left Zygomatic Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NUN47Z" = "1" /* Supplement Left Zygomatic Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUN4JZ" = "1" /* Supplement Left Zygomatic Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NUN4KZ" = "1" /* Supplement Left Zygomatic Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUP07Z" = "1" /* Supplement Right Orbit with Autologous Tissue Substitute, Open Approach */
"0NUP0JZ" = "1" /* Supplement Right Orbit with Synthetic Substitute, Open Approach */
"0NUP0KZ" = "1" /* Supplement Right Orbit with Nonautologous Tissue Substitute, Open Approach */
"0NUP37Z" = "1" /* Supplement Right Orbit with Autologous Tissue Substitute, Percutaneous Approach */
"0NUP3JZ" = "1" /* Supplement Right Orbit with Synthetic Substitute, Percutaneous Approach */
"0NUP3KZ" = "1" /* Supplement Right Orbit with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NUP47Z" = "1" /* Supplement Right Orbit with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUP4JZ" = "1" /* Supplement Right Orbit with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NUP4KZ" = "1" /* Supplement Right Orbit with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUQ07Z" = "1" /* Supplement Left Orbit with Autologous Tissue Substitute, Open Approach */
"0NUQ0JZ" = "1" /* Supplement Left Orbit with Synthetic Substitute, Open Approach */
"0NUQ0KZ" = "1" /* Supplement Left Orbit with Nonautologous Tissue Substitute, Open Approach */
"0NUQ37Z" = "1" /* Supplement Left Orbit with Autologous Tissue Substitute, Percutaneous Approach */
"0NUQ3JZ" = "1" /* Supplement Left Orbit with Synthetic Substitute, Percutaneous Approach */
"0NUQ3KZ" = "1" /* Supplement Left Orbit with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NUQ47Z" = "1" /* Supplement Left Orbit with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUQ4JZ" = "1" /* Supplement Left Orbit with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NUQ4KZ" = "1" /* Supplement Left Orbit with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUR07Z" = "1" /* Supplement Right Maxilla with Autologous Tissue Substitute, Open Approach */
"0NUR0JZ" = "1" /* Supplement Right Maxilla with Synthetic Substitute, Open Approach */
"0NUR0KZ" = "1" /* Supplement Right Maxilla with Nonautologous Tissue Substitute, Open Approach */
"0NUR37Z" = "1" /* Supplement Right Maxilla with Autologous Tissue Substitute, Percutaneous Approach */
"0NUR3JZ" = "1" /* Supplement Right Maxilla with Synthetic Substitute, Percutaneous Approach */
"0NUR3KZ" = "1" /* Supplement Right Maxilla with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NUR47Z" = "1" /* Supplement Right Maxilla with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUR4JZ" = "1" /* Supplement Right Maxilla with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NUR4KZ" = "1" /* Supplement Right Maxilla with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUS07Z" = "1" /* Supplement Left Maxilla with Autologous Tissue Substitute, Open Approach */
"0NUS0JZ" = "1" /* Supplement Left Maxilla with Synthetic Substitute, Open Approach */
"0NUS0KZ" = "1" /* Supplement Left Maxilla with Nonautologous Tissue Substitute, Open Approach */
"0NUS37Z" = "1" /* Supplement Left Maxilla with Autologous Tissue Substitute, Percutaneous Approach */
"0NUS3JZ" = "1" /* Supplement Left Maxilla with Synthetic Substitute, Percutaneous Approach */
"0NUS3KZ" = "1" /* Supplement Left Maxilla with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NUS47Z" = "1" /* Supplement Left Maxilla with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUS4JZ" = "1" /* Supplement Left Maxilla with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NUS4KZ" = "1" /* Supplement Left Maxilla with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUT07Z" = "1" /* Supplement Right Mandible with Autologous Tissue Substitute, Open Approach */
"0NUT0JZ" = "1" /* Supplement Right Mandible with Synthetic Substitute, Open Approach */
"0NUT0KZ" = "1" /* Supplement Right Mandible with Nonautologous Tissue Substitute, Open Approach */
"0NUT37Z" = "1" /* Supplement Right Mandible with Autologous Tissue Substitute, Percutaneous Approach */
"0NUT3JZ" = "1" /* Supplement Right Mandible with Synthetic Substitute, Percutaneous Approach */
"0NUT3KZ" = "1" /* Supplement Right Mandible with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NUT47Z" = "1" /* Supplement Right Mandible with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUT4JZ" = "1" /* Supplement Right Mandible with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NUT4KZ" = "1" /* Supplement Right Mandible with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUV07Z" = "1" /* Supplement Left Mandible with Autologous Tissue Substitute, Open Approach */
"0NUV0JZ" = "1" /* Supplement Left Mandible with Synthetic Substitute, Open Approach */
"0NUV0KZ" = "1" /* Supplement Left Mandible with Nonautologous Tissue Substitute, Open Approach */
"0NUV37Z" = "1" /* Supplement Left Mandible with Autologous Tissue Substitute, Percutaneous Approach */
"0NUV3JZ" = "1" /* Supplement Left Mandible with Synthetic Substitute, Percutaneous Approach */
"0NUV3KZ" = "1" /* Supplement Left Mandible with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NUV47Z" = "1" /* Supplement Left Mandible with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUV4JZ" = "1" /* Supplement Left Mandible with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NUV4KZ" = "1" /* Supplement Left Mandible with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUX07Z" = "1" /* Supplement Hyoid Bone with Autologous Tissue Substitute, Open Approach */
"0NUX0JZ" = "1" /* Supplement Hyoid Bone with Synthetic Substitute, Open Approach */
"0NUX0KZ" = "1" /* Supplement Hyoid Bone with Nonautologous Tissue Substitute, Open Approach */
"0NUX37Z" = "1" /* Supplement Hyoid Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0NUX3JZ" = "1" /* Supplement Hyoid Bone with Synthetic Substitute, Percutaneous Approach */
"0NUX3KZ" = "1" /* Supplement Hyoid Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0NUX47Z" = "1" /* Supplement Hyoid Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NUX4JZ" = "1" /* Supplement Hyoid Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0NUX4KZ" = "1" /* Supplement Hyoid Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0NW000Z" = "1" /* Revision of Drainage Device in Skull, Open Approach */
"0NW004Z" = "1" /* Revision of Internal Fixation Device in Skull, Open Approach */
"0NW005Z" = "1" /* Revision of External Fixation Device in Skull, Open Approach */
"0NW007Z" = "1" /* Revision of Autologous Tissue Substitute in Skull, Open Approach */
"0NW00JZ" = "1" /* Revision of Synthetic Substitute in Skull, Open Approach */
"0NW00KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Skull, Open Approach */
"0NW00MZ" = "1" /* Revision of Bone Growth Stimulator in Skull, Open Approach */
"0NW00NZ" = "1" /* Revision of Neurostimulator Generator in Skull, Open Approach */
"0NW00SZ" = "1" /* Revision of Hearing Device in Skull, Open Approach */
"0NW030Z" = "1" /* Revision of Drainage Device in Skull, Percutaneous Approach */
"0NW034Z" = "1" /* Revision of Internal Fixation Device in Skull, Percutaneous Approach */
"0NW035Z" = "1" /* Revision of External Fixation Device in Skull, Percutaneous Approach */
"0NW037Z" = "1" /* Revision of Autologous Tissue Substitute in Skull, Percutaneous Approach */
"0NW03JZ" = "1" /* Revision of Synthetic Substitute in Skull, Percutaneous Approach */
"0NW03KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Skull, Percutaneous Approach */
"0NW03MZ" = "1" /* Revision of Bone Growth Stimulator in Skull, Percutaneous Approach */
"0NW03SZ" = "1" /* Revision of Hearing Device in Skull, Percutaneous Approach */
"0NW040Z" = "1" /* Revision of Drainage Device in Skull, Percutaneous Endoscopic Approach */
"0NW044Z" = "1" /* Revision of Internal Fixation Device in Skull, Percutaneous Endoscopic Approach */
"0NW045Z" = "1" /* Revision of External Fixation Device in Skull, Percutaneous Endoscopic Approach */
"0NW047Z" = "1" /* Revision of Autologous Tissue Substitute in Skull, Percutaneous Endoscopic Approach */
"0NW04JZ" = "1" /* Revision of Synthetic Substitute in Skull, Percutaneous Endoscopic Approach */
"0NW04KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Skull, Percutaneous Endoscopic Approach */
"0NW04MZ" = "1" /* Revision of Bone Growth Stimulator in Skull, Percutaneous Endoscopic Approach */
"0NW04SZ" = "1" /* Revision of Hearing Device in Skull, Percutaneous Endoscopic Approach */
"0NWW00Z" = "1" /* Revision of Drainage Device in Facial Bone, Open Approach */
"0NWW04Z" = "1" /* Revision of Internal Fixation Device in Facial Bone, Open Approach */
"0NWW07Z" = "1" /* Revision of Autologous Tissue Substitute in Facial Bone, Open Approach */
"0NWW0JZ" = "1" /* Revision of Synthetic Substitute in Facial Bone, Open Approach */
"0NWW0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Facial Bone, Open Approach */
"0NWW0MZ" = "1" /* Revision of Bone Growth Stimulator in Facial Bone, Open Approach */
"0NWW30Z" = "1" /* Revision of Drainage Device in Facial Bone, Percutaneous Approach */
"0NWW34Z" = "1" /* Revision of Internal Fixation Device in Facial Bone, Percutaneous Approach */
"0NWW37Z" = "1" /* Revision of Autologous Tissue Substitute in Facial Bone, Percutaneous Approach */
"0NWW3JZ" = "1" /* Revision of Synthetic Substitute in Facial Bone, Percutaneous Approach */
"0NWW3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Facial Bone, Percutaneous Approach */
"0NWW3MZ" = "1" /* Revision of Bone Growth Stimulator in Facial Bone, Percutaneous Approach */
"0NWW40Z" = "1" /* Revision of Drainage Device in Facial Bone, Percutaneous Endoscopic Approach */
"0NWW44Z" = "1" /* Revision of Internal Fixation Device in Facial Bone, Percutaneous Endoscopic Approach */
"0NWW47Z" = "1" /* Revision of Autologous Tissue Substitute in Facial Bone, Percutaneous Endoscopic Approach */
"0NWW4JZ" = "1" /* Revision of Synthetic Substitute in Facial Bone, Percutaneous Endoscopic Approach */
"0NWW4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Facial Bone, Percutaneous Endoscopic Approach */
"0NWW4MZ" = "1" /* Revision of Bone Growth Stimulator in Facial Bone, Percutaneous Endoscopic Approach */
"0P500ZZ" = "1" /* Destruction of Sternum, Open Approach */
"0P503ZZ" = "1" /* Destruction of Sternum, Percutaneous Approach */
"0P504ZZ" = "1" /* Destruction of Sternum, Percutaneous Endoscopic Approach */
"0P510ZZ" = "1" /* Destruction of Right Rib, Open Approach */
"0P513ZZ" = "1" /* Destruction of Right Rib, Percutaneous Approach */
"0P514ZZ" = "1" /* Destruction of Right Rib, Percutaneous Endoscopic Approach */
"0P520ZZ" = "1" /* Destruction of Left Rib, Open Approach */
"0P523ZZ" = "1" /* Destruction of Left Rib, Percutaneous Approach */
"0P524ZZ" = "1" /* Destruction of Left Rib, Percutaneous Endoscopic Approach */
"0P530ZZ" = "1" /* Destruction of Cervical Vertebra, Open Approach */
"0P533ZZ" = "1" /* Destruction of Cervical Vertebra, Percutaneous Approach */
"0P534ZZ" = "1" /* Destruction of Cervical Vertebra, Percutaneous Endoscopic Approach */
"0P540ZZ" = "1" /* Destruction of Thoracic Vertebra, Open Approach */
"0P543ZZ" = "1" /* Destruction of Thoracic Vertebra, Percutaneous Approach */
"0P544ZZ" = "1" /* Destruction of Thoracic Vertebra, Percutaneous Endoscopic Approach */
"0P550ZZ" = "1" /* Destruction of Right Scapula, Open Approach */
"0P553ZZ" = "1" /* Destruction of Right Scapula, Percutaneous Approach */
"0P554ZZ" = "1" /* Destruction of Right Scapula, Percutaneous Endoscopic Approach */
"0P560ZZ" = "1" /* Destruction of Left Scapula, Open Approach */
"0P563ZZ" = "1" /* Destruction of Left Scapula, Percutaneous Approach */
"0P564ZZ" = "1" /* Destruction of Left Scapula, Percutaneous Endoscopic Approach */
"0P570ZZ" = "1" /* Destruction of Right Glenoid Cavity, Open Approach */
"0P573ZZ" = "1" /* Destruction of Right Glenoid Cavity, Percutaneous Approach */
"0P574ZZ" = "1" /* Destruction of Right Glenoid Cavity, Percutaneous Endoscopic Approach */
"0P580ZZ" = "1" /* Destruction of Left Glenoid Cavity, Open Approach */
"0P583ZZ" = "1" /* Destruction of Left Glenoid Cavity, Percutaneous Approach */
"0P584ZZ" = "1" /* Destruction of Left Glenoid Cavity, Percutaneous Endoscopic Approach */
"0P590ZZ" = "1" /* Destruction of Right Clavicle, Open Approach */
"0P593ZZ" = "1" /* Destruction of Right Clavicle, Percutaneous Approach */
"0P594ZZ" = "1" /* Destruction of Right Clavicle, Percutaneous Endoscopic Approach */
"0P5B0ZZ" = "1" /* Destruction of Left Clavicle, Open Approach */
"0P5B3ZZ" = "1" /* Destruction of Left Clavicle, Percutaneous Approach */
"0P5B4ZZ" = "1" /* Destruction of Left Clavicle, Percutaneous Endoscopic Approach */
"0P5C0ZZ" = "1" /* Destruction of Right Humeral Head, Open Approach */
"0P5C3ZZ" = "1" /* Destruction of Right Humeral Head, Percutaneous Approach */
"0P5C4ZZ" = "1" /* Destruction of Right Humeral Head, Percutaneous Endoscopic Approach */
"0P5D0ZZ" = "1" /* Destruction of Left Humeral Head, Open Approach */
"0P5D3ZZ" = "1" /* Destruction of Left Humeral Head, Percutaneous Approach */
"0P5D4ZZ" = "1" /* Destruction of Left Humeral Head, Percutaneous Endoscopic Approach */
"0P5F0ZZ" = "1" /* Destruction of Right Humeral Shaft, Open Approach */
"0P5F3ZZ" = "1" /* Destruction of Right Humeral Shaft, Percutaneous Approach */
"0P5F4ZZ" = "1" /* Destruction of Right Humeral Shaft, Percutaneous Endoscopic Approach */
"0P5G0ZZ" = "1" /* Destruction of Left Humeral Shaft, Open Approach */
"0P5G3ZZ" = "1" /* Destruction of Left Humeral Shaft, Percutaneous Approach */
"0P5G4ZZ" = "1" /* Destruction of Left Humeral Shaft, Percutaneous Endoscopic Approach */
"0P5H0ZZ" = "1" /* Destruction of Right Radius, Open Approach */
"0P5H3ZZ" = "1" /* Destruction of Right Radius, Percutaneous Approach */
"0P5H4ZZ" = "1" /* Destruction of Right Radius, Percutaneous Endoscopic Approach */
"0P5J0ZZ" = "1" /* Destruction of Left Radius, Open Approach */
"0P5J3ZZ" = "1" /* Destruction of Left Radius, Percutaneous Approach */
"0P5J4ZZ" = "1" /* Destruction of Left Radius, Percutaneous Endoscopic Approach */
"0P5K0ZZ" = "1" /* Destruction of Right Ulna, Open Approach */
"0P5K3ZZ" = "1" /* Destruction of Right Ulna, Percutaneous Approach */
"0P5K4ZZ" = "1" /* Destruction of Right Ulna, Percutaneous Endoscopic Approach */
"0P5L0ZZ" = "1" /* Destruction of Left Ulna, Open Approach */
"0P5L3ZZ" = "1" /* Destruction of Left Ulna, Percutaneous Approach */
"0P5L4ZZ" = "1" /* Destruction of Left Ulna, Percutaneous Endoscopic Approach */
"0P5M0ZZ" = "1" /* Destruction of Right Carpal, Open Approach */
"0P5M3ZZ" = "1" /* Destruction of Right Carpal, Percutaneous Approach */
"0P5M4ZZ" = "1" /* Destruction of Right Carpal, Percutaneous Endoscopic Approach */
"0P5N0ZZ" = "1" /* Destruction of Left Carpal, Open Approach */
"0P5N3ZZ" = "1" /* Destruction of Left Carpal, Percutaneous Approach */
"0P5N4ZZ" = "1" /* Destruction of Left Carpal, Percutaneous Endoscopic Approach */
"0P5P0ZZ" = "1" /* Destruction of Right Metacarpal, Open Approach */
"0P5P3ZZ" = "1" /* Destruction of Right Metacarpal, Percutaneous Approach */
"0P5P4ZZ" = "1" /* Destruction of Right Metacarpal, Percutaneous Endoscopic Approach */
"0P5Q0ZZ" = "1" /* Destruction of Left Metacarpal, Open Approach */
"0P5Q3ZZ" = "1" /* Destruction of Left Metacarpal, Percutaneous Approach */
"0P5Q4ZZ" = "1" /* Destruction of Left Metacarpal, Percutaneous Endoscopic Approach */
"0P5R0ZZ" = "1" /* Destruction of Right Thumb Phalanx, Open Approach */
"0P5R3ZZ" = "1" /* Destruction of Right Thumb Phalanx, Percutaneous Approach */
"0P5R4ZZ" = "1" /* Destruction of Right Thumb Phalanx, Percutaneous Endoscopic Approach */
"0P5S0ZZ" = "1" /* Destruction of Left Thumb Phalanx, Open Approach */
"0P5S3ZZ" = "1" /* Destruction of Left Thumb Phalanx, Percutaneous Approach */
"0P5S4ZZ" = "1" /* Destruction of Left Thumb Phalanx, Percutaneous Endoscopic Approach */
"0P5T0ZZ" = "1" /* Destruction of Right Finger Phalanx, Open Approach */
"0P5T3ZZ" = "1" /* Destruction of Right Finger Phalanx, Percutaneous Approach */
"0P5T4ZZ" = "1" /* Destruction of Right Finger Phalanx, Percutaneous Endoscopic Approach */
"0P5V0ZZ" = "1" /* Destruction of Left Finger Phalanx, Open Approach */
"0P5V3ZZ" = "1" /* Destruction of Left Finger Phalanx, Percutaneous Approach */
"0P5V4ZZ" = "1" /* Destruction of Left Finger Phalanx, Percutaneous Endoscopic Approach */
"0P800ZZ" = "1" /* Division of Sternum, Open Approach */
"0P803ZZ" = "1" /* Division of Sternum, Percutaneous Approach */
"0P804ZZ" = "1" /* Division of Sternum, Percutaneous Endoscopic Approach */
"0P810ZZ" = "1" /* Division of Right Rib, Open Approach */
"0P813ZZ" = "1" /* Division of Right Rib, Percutaneous Approach */
"0P814ZZ" = "1" /* Division of Right Rib, Percutaneous Endoscopic Approach */
"0P820ZZ" = "1" /* Division of Left Rib, Open Approach */
"0P823ZZ" = "1" /* Division of Left Rib, Percutaneous Approach */
"0P824ZZ" = "1" /* Division of Left Rib, Percutaneous Endoscopic Approach */
"0P830ZZ" = "1" /* Division of Cervical Vertebra, Open Approach */
"0P833ZZ" = "1" /* Division of Cervical Vertebra, Percutaneous Approach */
"0P834ZZ" = "1" /* Division of Cervical Vertebra, Percutaneous Endoscopic Approach */
"0P840ZZ" = "1" /* Division of Thoracic Vertebra, Open Approach */
"0P843ZZ" = "1" /* Division of Thoracic Vertebra, Percutaneous Approach */
"0P844ZZ" = "1" /* Division of Thoracic Vertebra, Percutaneous Endoscopic Approach */
"0P850ZZ" = "1" /* Division of Right Scapula, Open Approach */
"0P853ZZ" = "1" /* Division of Right Scapula, Percutaneous Approach */
"0P854ZZ" = "1" /* Division of Right Scapula, Percutaneous Endoscopic Approach */
"0P860ZZ" = "1" /* Division of Left Scapula, Open Approach */
"0P863ZZ" = "1" /* Division of Left Scapula, Percutaneous Approach */
"0P864ZZ" = "1" /* Division of Left Scapula, Percutaneous Endoscopic Approach */
"0P870ZZ" = "1" /* Division of Right Glenoid Cavity, Open Approach */
"0P873ZZ" = "1" /* Division of Right Glenoid Cavity, Percutaneous Approach */
"0P874ZZ" = "1" /* Division of Right Glenoid Cavity, Percutaneous Endoscopic Approach */
"0P880ZZ" = "1" /* Division of Left Glenoid Cavity, Open Approach */
"0P883ZZ" = "1" /* Division of Left Glenoid Cavity, Percutaneous Approach */
"0P884ZZ" = "1" /* Division of Left Glenoid Cavity, Percutaneous Endoscopic Approach */
"0P890ZZ" = "1" /* Division of Right Clavicle, Open Approach */
"0P893ZZ" = "1" /* Division of Right Clavicle, Percutaneous Approach */
"0P894ZZ" = "1" /* Division of Right Clavicle, Percutaneous Endoscopic Approach */
"0P8B0ZZ" = "1" /* Division of Left Clavicle, Open Approach */
"0P8B3ZZ" = "1" /* Division of Left Clavicle, Percutaneous Approach */
"0P8B4ZZ" = "1" /* Division of Left Clavicle, Percutaneous Endoscopic Approach */
"0P8C0ZZ" = "1" /* Division of Right Humeral Head, Open Approach */
"0P8C3ZZ" = "1" /* Division of Right Humeral Head, Percutaneous Approach */
"0P8C4ZZ" = "1" /* Division of Right Humeral Head, Percutaneous Endoscopic Approach */
"0P8D0ZZ" = "1" /* Division of Left Humeral Head, Open Approach */
"0P8D3ZZ" = "1" /* Division of Left Humeral Head, Percutaneous Approach */
"0P8D4ZZ" = "1" /* Division of Left Humeral Head, Percutaneous Endoscopic Approach */
"0P8F0ZZ" = "1" /* Division of Right Humeral Shaft, Open Approach */
"0P8F3ZZ" = "1" /* Division of Right Humeral Shaft, Percutaneous Approach */
"0P8F4ZZ" = "1" /* Division of Right Humeral Shaft, Percutaneous Endoscopic Approach */
"0P8G0ZZ" = "1" /* Division of Left Humeral Shaft, Open Approach */
"0P8G3ZZ" = "1" /* Division of Left Humeral Shaft, Percutaneous Approach */
"0P8G4ZZ" = "1" /* Division of Left Humeral Shaft, Percutaneous Endoscopic Approach */
"0P8H0ZZ" = "1" /* Division of Right Radius, Open Approach */
"0P8H3ZZ" = "1" /* Division of Right Radius, Percutaneous Approach */
"0P8H4ZZ" = "1" /* Division of Right Radius, Percutaneous Endoscopic Approach */
"0P8J0ZZ" = "1" /* Division of Left Radius, Open Approach */
"0P8J3ZZ" = "1" /* Division of Left Radius, Percutaneous Approach */
"0P8J4ZZ" = "1" /* Division of Left Radius, Percutaneous Endoscopic Approach */
"0P8K0ZZ" = "1" /* Division of Right Ulna, Open Approach */
"0P8K3ZZ" = "1" /* Division of Right Ulna, Percutaneous Approach */
"0P8K4ZZ" = "1" /* Division of Right Ulna, Percutaneous Endoscopic Approach */
"0P8L0ZZ" = "1" /* Division of Left Ulna, Open Approach */
"0P8L3ZZ" = "1" /* Division of Left Ulna, Percutaneous Approach */
"0P8L4ZZ" = "1" /* Division of Left Ulna, Percutaneous Endoscopic Approach */
"0P8M0ZZ" = "1" /* Division of Right Carpal, Open Approach */
"0P8M3ZZ" = "1" /* Division of Right Carpal, Percutaneous Approach */
"0P8M4ZZ" = "1" /* Division of Right Carpal, Percutaneous Endoscopic Approach */
"0P8N0ZZ" = "1" /* Division of Left Carpal, Open Approach */
"0P8N3ZZ" = "1" /* Division of Left Carpal, Percutaneous Approach */
"0P8N4ZZ" = "1" /* Division of Left Carpal, Percutaneous Endoscopic Approach */
"0P8P0ZZ" = "1" /* Division of Right Metacarpal, Open Approach */
"0P8P3ZZ" = "1" /* Division of Right Metacarpal, Percutaneous Approach */
"0P8P4ZZ" = "1" /* Division of Right Metacarpal, Percutaneous Endoscopic Approach */
"0P8Q0ZZ" = "1" /* Division of Left Metacarpal, Open Approach */
"0P8Q3ZZ" = "1" /* Division of Left Metacarpal, Percutaneous Approach */
"0P8Q4ZZ" = "1" /* Division of Left Metacarpal, Percutaneous Endoscopic Approach */
"0P8R0ZZ" = "1" /* Division of Right Thumb Phalanx, Open Approach */
"0P8R3ZZ" = "1" /* Division of Right Thumb Phalanx, Percutaneous Approach */
"0P8R4ZZ" = "1" /* Division of Right Thumb Phalanx, Percutaneous Endoscopic Approach */
"0P8S0ZZ" = "1" /* Division of Left Thumb Phalanx, Open Approach */
"0P8S3ZZ" = "1" /* Division of Left Thumb Phalanx, Percutaneous Approach */
"0P8S4ZZ" = "1" /* Division of Left Thumb Phalanx, Percutaneous Endoscopic Approach */
"0P8T0ZZ" = "1" /* Division of Right Finger Phalanx, Open Approach */
"0P8T3ZZ" = "1" /* Division of Right Finger Phalanx, Percutaneous Approach */
"0P8T4ZZ" = "1" /* Division of Right Finger Phalanx, Percutaneous Endoscopic Approach */
"0P8V0ZZ" = "1" /* Division of Left Finger Phalanx, Open Approach */
"0P8V3ZZ" = "1" /* Division of Left Finger Phalanx, Percutaneous Approach */
"0P8V4ZZ" = "1" /* Division of Left Finger Phalanx, Percutaneous Endoscopic Approach */
"0P9000Z" = "1" /* Drainage of Sternum with Drainage Device, Open Approach */
"0P900ZX" = "1" /* Drainage of Sternum, Open Approach, Diagnostic */
"0P900ZZ" = "1" /* Drainage of Sternum, Open Approach */
"0P9040Z" = "1" /* Drainage of Sternum with Drainage Device, Percutaneous Endoscopic Approach */
"0P904ZX" = "1" /* Drainage of Sternum, Percutaneous Endoscopic Approach, Diagnostic */
"0P904ZZ" = "1" /* Drainage of Sternum, Percutaneous Endoscopic Approach */
"0P9100Z" = "1" /* Drainage of Right Rib with Drainage Device, Open Approach */
"0P910ZX" = "1" /* Drainage of Right Rib, Open Approach, Diagnostic */
"0P910ZZ" = "1" /* Drainage of Right Rib, Open Approach */
"0P9140Z" = "1" /* Drainage of Right Rib with Drainage Device, Percutaneous Endoscopic Approach */
"0P914ZX" = "1" /* Drainage of Right Rib, Percutaneous Endoscopic Approach, Diagnostic */
"0P914ZZ" = "1" /* Drainage of Right Rib, Percutaneous Endoscopic Approach */
"0P9200Z" = "1" /* Drainage of Left Rib with Drainage Device, Open Approach */
"0P920ZX" = "1" /* Drainage of Left Rib, Open Approach, Diagnostic */
"0P920ZZ" = "1" /* Drainage of Left Rib, Open Approach */
"0P9240Z" = "1" /* Drainage of Left Rib with Drainage Device, Percutaneous Endoscopic Approach */
"0P924ZX" = "1" /* Drainage of Left Rib, Percutaneous Endoscopic Approach, Diagnostic */
"0P924ZZ" = "1" /* Drainage of Left Rib, Percutaneous Endoscopic Approach */
"0P9300Z" = "1" /* Drainage of Cervical Vertebra with Drainage Device, Open Approach */
"0P930ZX" = "1" /* Drainage of Cervical Vertebra, Open Approach, Diagnostic */
"0P930ZZ" = "1" /* Drainage of Cervical Vertebra, Open Approach */
"0P9340Z" = "1" /* Drainage of Cervical Vertebra with Drainage Device, Percutaneous Endoscopic Approach */
"0P934ZX" = "1" /* Drainage of Cervical Vertebra, Percutaneous Endoscopic Approach, Diagnostic */
"0P934ZZ" = "1" /* Drainage of Cervical Vertebra, Percutaneous Endoscopic Approach */
"0P9400Z" = "1" /* Drainage of Thoracic Vertebra with Drainage Device, Open Approach */
"0P940ZX" = "1" /* Drainage of Thoracic Vertebra, Open Approach, Diagnostic */
"0P940ZZ" = "1" /* Drainage of Thoracic Vertebra, Open Approach */
"0P9440Z" = "1" /* Drainage of Thoracic Vertebra with Drainage Device, Percutaneous Endoscopic Approach */
"0P944ZX" = "1" /* Drainage of Thoracic Vertebra, Percutaneous Endoscopic Approach, Diagnostic */
"0P944ZZ" = "1" /* Drainage of Thoracic Vertebra, Percutaneous Endoscopic Approach */
"0P9500Z" = "1" /* Drainage of Right Scapula with Drainage Device, Open Approach */
"0P950ZX" = "1" /* Drainage of Right Scapula, Open Approach, Diagnostic */
"0P950ZZ" = "1" /* Drainage of Right Scapula, Open Approach */
"0P9540Z" = "1" /* Drainage of Right Scapula with Drainage Device, Percutaneous Endoscopic Approach */
"0P954ZX" = "1" /* Drainage of Right Scapula, Percutaneous Endoscopic Approach, Diagnostic */
"0P954ZZ" = "1" /* Drainage of Right Scapula, Percutaneous Endoscopic Approach */
"0P9600Z" = "1" /* Drainage of Left Scapula with Drainage Device, Open Approach */
"0P960ZX" = "1" /* Drainage of Left Scapula, Open Approach, Diagnostic */
"0P960ZZ" = "1" /* Drainage of Left Scapula, Open Approach */
"0P9640Z" = "1" /* Drainage of Left Scapula with Drainage Device, Percutaneous Endoscopic Approach */
"0P964ZX" = "1" /* Drainage of Left Scapula, Percutaneous Endoscopic Approach, Diagnostic */
"0P964ZZ" = "1" /* Drainage of Left Scapula, Percutaneous Endoscopic Approach */
"0P9700Z" = "1" /* Drainage of Right Glenoid Cavity with Drainage Device, Open Approach */
"0P970ZX" = "1" /* Drainage of Right Glenoid Cavity, Open Approach, Diagnostic */
"0P970ZZ" = "1" /* Drainage of Right Glenoid Cavity, Open Approach */
"0P9740Z" = "1" /* Drainage of Right Glenoid Cavity with Drainage Device, Percutaneous Endoscopic Approach */
"0P974ZX" = "1" /* Drainage of Right Glenoid Cavity, Percutaneous Endoscopic Approach, Diagnostic */
"0P974ZZ" = "1" /* Drainage of Right Glenoid Cavity, Percutaneous Endoscopic Approach */
"0P9800Z" = "1" /* Drainage of Left Glenoid Cavity with Drainage Device, Open Approach */
"0P980ZX" = "1" /* Drainage of Left Glenoid Cavity, Open Approach, Diagnostic */
"0P980ZZ" = "1" /* Drainage of Left Glenoid Cavity, Open Approach */
"0P9840Z" = "1" /* Drainage of Left Glenoid Cavity with Drainage Device, Percutaneous Endoscopic Approach */
"0P984ZX" = "1" /* Drainage of Left Glenoid Cavity, Percutaneous Endoscopic Approach, Diagnostic */
"0P984ZZ" = "1" /* Drainage of Left Glenoid Cavity, Percutaneous Endoscopic Approach */
"0P9900Z" = "1" /* Drainage of Right Clavicle with Drainage Device, Open Approach */
"0P990ZX" = "1" /* Drainage of Right Clavicle, Open Approach, Diagnostic */
"0P990ZZ" = "1" /* Drainage of Right Clavicle, Open Approach */
"0P9940Z" = "1" /* Drainage of Right Clavicle with Drainage Device, Percutaneous Endoscopic Approach */
"0P994ZX" = "1" /* Drainage of Right Clavicle, Percutaneous Endoscopic Approach, Diagnostic */
"0P994ZZ" = "1" /* Drainage of Right Clavicle, Percutaneous Endoscopic Approach */
"0P9B00Z" = "1" /* Drainage of Left Clavicle with Drainage Device, Open Approach */
"0P9B0ZX" = "1" /* Drainage of Left Clavicle, Open Approach, Diagnostic */
"0P9B0ZZ" = "1" /* Drainage of Left Clavicle, Open Approach */
"0P9B40Z" = "1" /* Drainage of Left Clavicle with Drainage Device, Percutaneous Endoscopic Approach */
"0P9B4ZX" = "1" /* Drainage of Left Clavicle, Percutaneous Endoscopic Approach, Diagnostic */
"0P9B4ZZ" = "1" /* Drainage of Left Clavicle, Percutaneous Endoscopic Approach */
"0P9C00Z" = "1" /* Drainage of Right Humeral Head with Drainage Device, Open Approach */
"0P9C0ZX" = "1" /* Drainage of Right Humeral Head, Open Approach, Diagnostic */
"0P9C0ZZ" = "1" /* Drainage of Right Humeral Head, Open Approach */
"0P9C40Z" = "1" /* Drainage of Right Humeral Head with Drainage Device, Percutaneous Endoscopic Approach */
"0P9C4ZX" = "1" /* Drainage of Right Humeral Head, Percutaneous Endoscopic Approach, Diagnostic */
"0P9C4ZZ" = "1" /* Drainage of Right Humeral Head, Percutaneous Endoscopic Approach */
"0P9D00Z" = "1" /* Drainage of Left Humeral Head with Drainage Device, Open Approach */
"0P9D0ZX" = "1" /* Drainage of Left Humeral Head, Open Approach, Diagnostic */
"0P9D0ZZ" = "1" /* Drainage of Left Humeral Head, Open Approach */
"0P9D40Z" = "1" /* Drainage of Left Humeral Head with Drainage Device, Percutaneous Endoscopic Approach */
"0P9D4ZX" = "1" /* Drainage of Left Humeral Head, Percutaneous Endoscopic Approach, Diagnostic */
"0P9D4ZZ" = "1" /* Drainage of Left Humeral Head, Percutaneous Endoscopic Approach */
"0P9F00Z" = "1" /* Drainage of Right Humeral Shaft with Drainage Device, Open Approach */
"0P9F0ZX" = "1" /* Drainage of Right Humeral Shaft, Open Approach, Diagnostic */
"0P9F0ZZ" = "1" /* Drainage of Right Humeral Shaft, Open Approach */
"0P9F40Z" = "1" /* Drainage of Right Humeral Shaft with Drainage Device, Percutaneous Endoscopic Approach */
"0P9F4ZX" = "1" /* Drainage of Right Humeral Shaft, Percutaneous Endoscopic Approach, Diagnostic */
"0P9F4ZZ" = "1" /* Drainage of Right Humeral Shaft, Percutaneous Endoscopic Approach */
"0P9G00Z" = "1" /* Drainage of Left Humeral Shaft with Drainage Device, Open Approach */
"0P9G0ZX" = "1" /* Drainage of Left Humeral Shaft, Open Approach, Diagnostic */
"0P9G0ZZ" = "1" /* Drainage of Left Humeral Shaft, Open Approach */
"0P9G40Z" = "1" /* Drainage of Left Humeral Shaft with Drainage Device, Percutaneous Endoscopic Approach */
"0P9G4ZX" = "1" /* Drainage of Left Humeral Shaft, Percutaneous Endoscopic Approach, Diagnostic */
"0P9G4ZZ" = "1" /* Drainage of Left Humeral Shaft, Percutaneous Endoscopic Approach */
"0P9H00Z" = "1" /* Drainage of Right Radius with Drainage Device, Open Approach */
"0P9H0ZX" = "1" /* Drainage of Right Radius, Open Approach, Diagnostic */
"0P9H0ZZ" = "1" /* Drainage of Right Radius, Open Approach */
"0P9H40Z" = "1" /* Drainage of Right Radius with Drainage Device, Percutaneous Endoscopic Approach */
"0P9H4ZX" = "1" /* Drainage of Right Radius, Percutaneous Endoscopic Approach, Diagnostic */
"0P9H4ZZ" = "1" /* Drainage of Right Radius, Percutaneous Endoscopic Approach */
"0P9J00Z" = "1" /* Drainage of Left Radius with Drainage Device, Open Approach */
"0P9J0ZX" = "1" /* Drainage of Left Radius, Open Approach, Diagnostic */
"0P9J0ZZ" = "1" /* Drainage of Left Radius, Open Approach */
"0P9J40Z" = "1" /* Drainage of Left Radius with Drainage Device, Percutaneous Endoscopic Approach */
"0P9J4ZX" = "1" /* Drainage of Left Radius, Percutaneous Endoscopic Approach, Diagnostic */
"0P9J4ZZ" = "1" /* Drainage of Left Radius, Percutaneous Endoscopic Approach */
"0P9K00Z" = "1" /* Drainage of Right Ulna with Drainage Device, Open Approach */
"0P9K0ZX" = "1" /* Drainage of Right Ulna, Open Approach, Diagnostic */
"0P9K0ZZ" = "1" /* Drainage of Right Ulna, Open Approach */
"0P9K40Z" = "1" /* Drainage of Right Ulna with Drainage Device, Percutaneous Endoscopic Approach */
"0P9K4ZX" = "1" /* Drainage of Right Ulna, Percutaneous Endoscopic Approach, Diagnostic */
"0P9K4ZZ" = "1" /* Drainage of Right Ulna, Percutaneous Endoscopic Approach */
"0P9L00Z" = "1" /* Drainage of Left Ulna with Drainage Device, Open Approach */
"0P9L0ZX" = "1" /* Drainage of Left Ulna, Open Approach, Diagnostic */
"0P9L0ZZ" = "1" /* Drainage of Left Ulna, Open Approach */
"0P9L40Z" = "1" /* Drainage of Left Ulna with Drainage Device, Percutaneous Endoscopic Approach */
"0P9L4ZX" = "1" /* Drainage of Left Ulna, Percutaneous Endoscopic Approach, Diagnostic */
"0P9L4ZZ" = "1" /* Drainage of Left Ulna, Percutaneous Endoscopic Approach */
"0P9M00Z" = "1" /* Drainage of Right Carpal with Drainage Device, Open Approach */
"0P9M0ZX" = "1" /* Drainage of Right Carpal, Open Approach, Diagnostic */
"0P9M0ZZ" = "1" /* Drainage of Right Carpal, Open Approach */
"0P9M40Z" = "1" /* Drainage of Right Carpal with Drainage Device, Percutaneous Endoscopic Approach */
"0P9M4ZX" = "1" /* Drainage of Right Carpal, Percutaneous Endoscopic Approach, Diagnostic */
"0P9M4ZZ" = "1" /* Drainage of Right Carpal, Percutaneous Endoscopic Approach */
"0P9N00Z" = "1" /* Drainage of Left Carpal with Drainage Device, Open Approach */
"0P9N0ZX" = "1" /* Drainage of Left Carpal, Open Approach, Diagnostic */
"0P9N0ZZ" = "1" /* Drainage of Left Carpal, Open Approach */
"0P9N40Z" = "1" /* Drainage of Left Carpal with Drainage Device, Percutaneous Endoscopic Approach */
"0P9N4ZX" = "1" /* Drainage of Left Carpal, Percutaneous Endoscopic Approach, Diagnostic */
"0P9N4ZZ" = "1" /* Drainage of Left Carpal, Percutaneous Endoscopic Approach */
"0P9P00Z" = "1" /* Drainage of Right Metacarpal with Drainage Device, Open Approach */
"0P9P0ZX" = "1" /* Drainage of Right Metacarpal, Open Approach, Diagnostic */
"0P9P0ZZ" = "1" /* Drainage of Right Metacarpal, Open Approach */
"0P9P40Z" = "1" /* Drainage of Right Metacarpal with Drainage Device, Percutaneous Endoscopic Approach */
"0P9P4ZX" = "1" /* Drainage of Right Metacarpal, Percutaneous Endoscopic Approach, Diagnostic */
"0P9P4ZZ" = "1" /* Drainage of Right Metacarpal, Percutaneous Endoscopic Approach */
"0P9Q00Z" = "1" /* Drainage of Left Metacarpal with Drainage Device, Open Approach */
"0P9Q0ZX" = "1" /* Drainage of Left Metacarpal, Open Approach, Diagnostic */
"0P9Q0ZZ" = "1" /* Drainage of Left Metacarpal, Open Approach */
"0P9Q40Z" = "1" /* Drainage of Left Metacarpal with Drainage Device, Percutaneous Endoscopic Approach */
"0P9Q4ZX" = "1" /* Drainage of Left Metacarpal, Percutaneous Endoscopic Approach, Diagnostic */
"0P9Q4ZZ" = "1" /* Drainage of Left Metacarpal, Percutaneous Endoscopic Approach */
"0P9R00Z" = "1" /* Drainage of Right Thumb Phalanx with Drainage Device, Open Approach */
"0P9R0ZX" = "1" /* Drainage of Right Thumb Phalanx, Open Approach, Diagnostic */
"0P9R0ZZ" = "1" /* Drainage of Right Thumb Phalanx, Open Approach */
"0P9R40Z" = "1" /* Drainage of Right Thumb Phalanx with Drainage Device, Percutaneous Endoscopic Approach */
"0P9R4ZX" = "1" /* Drainage of Right Thumb Phalanx, Percutaneous Endoscopic Approach, Diagnostic */
"0P9R4ZZ" = "1" /* Drainage of Right Thumb Phalanx, Percutaneous Endoscopic Approach */
"0P9S00Z" = "1" /* Drainage of Left Thumb Phalanx with Drainage Device, Open Approach */
"0P9S0ZX" = "1" /* Drainage of Left Thumb Phalanx, Open Approach, Diagnostic */
"0P9S0ZZ" = "1" /* Drainage of Left Thumb Phalanx, Open Approach */
"0P9S40Z" = "1" /* Drainage of Left Thumb Phalanx with Drainage Device, Percutaneous Endoscopic Approach */
"0P9S4ZX" = "1" /* Drainage of Left Thumb Phalanx, Percutaneous Endoscopic Approach, Diagnostic */
"0P9S4ZZ" = "1" /* Drainage of Left Thumb Phalanx, Percutaneous Endoscopic Approach */
"0P9T00Z" = "1" /* Drainage of Right Finger Phalanx with Drainage Device, Open Approach */
"0P9T0ZX" = "1" /* Drainage of Right Finger Phalanx, Open Approach, Diagnostic */
"0P9T0ZZ" = "1" /* Drainage of Right Finger Phalanx, Open Approach */
"0P9T40Z" = "1" /* Drainage of Right Finger Phalanx with Drainage Device, Percutaneous Endoscopic Approach */
"0P9T4ZX" = "1" /* Drainage of Right Finger Phalanx, Percutaneous Endoscopic Approach, Diagnostic */
"0P9T4ZZ" = "1" /* Drainage of Right Finger Phalanx, Percutaneous Endoscopic Approach */
"0P9V00Z" = "1" /* Drainage of Left Finger Phalanx with Drainage Device, Open Approach */
"0P9V0ZX" = "1" /* Drainage of Left Finger Phalanx, Open Approach, Diagnostic */
"0P9V0ZZ" = "1" /* Drainage of Left Finger Phalanx, Open Approach */
"0P9V40Z" = "1" /* Drainage of Left Finger Phalanx with Drainage Device, Percutaneous Endoscopic Approach */
"0P9V4ZX" = "1" /* Drainage of Left Finger Phalanx, Percutaneous Endoscopic Approach, Diagnostic */
"0P9V4ZZ" = "1" /* Drainage of Left Finger Phalanx, Percutaneous Endoscopic Approach */
"0PB00ZX" = "1" /* Excision of Sternum, Open Approach, Diagnostic */
"0PB00ZZ" = "1" /* Excision of Sternum, Open Approach */
"0PB03ZX" = "1" /* Excision of Sternum, Percutaneous Approach, Diagnostic */
"0PB03ZZ" = "1" /* Excision of Sternum, Percutaneous Approach */
"0PB04ZX" = "1" /* Excision of Sternum, Percutaneous Endoscopic Approach, Diagnostic */
"0PB04ZZ" = "1" /* Excision of Sternum, Percutaneous Endoscopic Approach */
"0PB10ZX" = "1" /* Excision of Right Rib, Open Approach, Diagnostic */
"0PB10ZZ" = "1" /* Excision of Right Rib, Open Approach */
"0PB13ZX" = "1" /* Excision of Right Rib, Percutaneous Approach, Diagnostic */
"0PB13ZZ" = "1" /* Excision of Right Rib, Percutaneous Approach */
"0PB14ZX" = "1" /* Excision of Right Rib, Percutaneous Endoscopic Approach, Diagnostic */
"0PB14ZZ" = "1" /* Excision of Right Rib, Percutaneous Endoscopic Approach */
"0PB20ZX" = "1" /* Excision of Left Rib, Open Approach, Diagnostic */
"0PB20ZZ" = "1" /* Excision of Left Rib, Open Approach */
"0PB23ZX" = "1" /* Excision of Left Rib, Percutaneous Approach, Diagnostic */
"0PB23ZZ" = "1" /* Excision of Left Rib, Percutaneous Approach */
"0PB24ZX" = "1" /* Excision of Left Rib, Percutaneous Endoscopic Approach, Diagnostic */
"0PB24ZZ" = "1" /* Excision of Left Rib, Percutaneous Endoscopic Approach */
"0PB30ZX" = "1" /* Excision of Cervical Vertebra, Open Approach, Diagnostic */
"0PB30ZZ" = "1" /* Excision of Cervical Vertebra, Open Approach */
"0PB33ZX" = "1" /* Excision of Cervical Vertebra, Percutaneous Approach, Diagnostic */
"0PB33ZZ" = "1" /* Excision of Cervical Vertebra, Percutaneous Approach */
"0PB34ZX" = "1" /* Excision of Cervical Vertebra, Percutaneous Endoscopic Approach, Diagnostic */
"0PB34ZZ" = "1" /* Excision of Cervical Vertebra, Percutaneous Endoscopic Approach */
"0PB40ZX" = "1" /* Excision of Thoracic Vertebra, Open Approach, Diagnostic */
"0PB40ZZ" = "1" /* Excision of Thoracic Vertebra, Open Approach */
"0PB43ZX" = "1" /* Excision of Thoracic Vertebra, Percutaneous Approach, Diagnostic */
"0PB43ZZ" = "1" /* Excision of Thoracic Vertebra, Percutaneous Approach */
"0PB44ZX" = "1" /* Excision of Thoracic Vertebra, Percutaneous Endoscopic Approach, Diagnostic */
"0PB44ZZ" = "1" /* Excision of Thoracic Vertebra, Percutaneous Endoscopic Approach */
"0PB50ZX" = "1" /* Excision of Right Scapula, Open Approach, Diagnostic */
"0PB50ZZ" = "1" /* Excision of Right Scapula, Open Approach */
"0PB53ZX" = "1" /* Excision of Right Scapula, Percutaneous Approach, Diagnostic */
"0PB53ZZ" = "1" /* Excision of Right Scapula, Percutaneous Approach */
"0PB54ZX" = "1" /* Excision of Right Scapula, Percutaneous Endoscopic Approach, Diagnostic */
"0PB54ZZ" = "1" /* Excision of Right Scapula, Percutaneous Endoscopic Approach */
"0PB60ZX" = "1" /* Excision of Left Scapula, Open Approach, Diagnostic */
"0PB60ZZ" = "1" /* Excision of Left Scapula, Open Approach */
"0PB63ZX" = "1" /* Excision of Left Scapula, Percutaneous Approach, Diagnostic */
"0PB63ZZ" = "1" /* Excision of Left Scapula, Percutaneous Approach */
"0PB64ZX" = "1" /* Excision of Left Scapula, Percutaneous Endoscopic Approach, Diagnostic */
"0PB64ZZ" = "1" /* Excision of Left Scapula, Percutaneous Endoscopic Approach */
"0PB70ZX" = "1" /* Excision of Right Glenoid Cavity, Open Approach, Diagnostic */
"0PB70ZZ" = "1" /* Excision of Right Glenoid Cavity, Open Approach */
"0PB73ZX" = "1" /* Excision of Right Glenoid Cavity, Percutaneous Approach, Diagnostic */
"0PB73ZZ" = "1" /* Excision of Right Glenoid Cavity, Percutaneous Approach */
"0PB74ZX" = "1" /* Excision of Right Glenoid Cavity, Percutaneous Endoscopic Approach, Diagnostic */
"0PB74ZZ" = "1" /* Excision of Right Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PB80ZX" = "1" /* Excision of Left Glenoid Cavity, Open Approach, Diagnostic */
"0PB80ZZ" = "1" /* Excision of Left Glenoid Cavity, Open Approach */
"0PB83ZX" = "1" /* Excision of Left Glenoid Cavity, Percutaneous Approach, Diagnostic */
"0PB83ZZ" = "1" /* Excision of Left Glenoid Cavity, Percutaneous Approach */
"0PB84ZX" = "1" /* Excision of Left Glenoid Cavity, Percutaneous Endoscopic Approach, Diagnostic */
"0PB84ZZ" = "1" /* Excision of Left Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PB90ZX" = "1" /* Excision of Right Clavicle, Open Approach, Diagnostic */
"0PB90ZZ" = "1" /* Excision of Right Clavicle, Open Approach */
"0PB93ZX" = "1" /* Excision of Right Clavicle, Percutaneous Approach, Diagnostic */
"0PB93ZZ" = "1" /* Excision of Right Clavicle, Percutaneous Approach */
"0PB94ZX" = "1" /* Excision of Right Clavicle, Percutaneous Endoscopic Approach, Diagnostic */
"0PB94ZZ" = "1" /* Excision of Right Clavicle, Percutaneous Endoscopic Approach */
"0PBB0ZX" = "1" /* Excision of Left Clavicle, Open Approach, Diagnostic */
"0PBB0ZZ" = "1" /* Excision of Left Clavicle, Open Approach */
"0PBB3ZX" = "1" /* Excision of Left Clavicle, Percutaneous Approach, Diagnostic */
"0PBB3ZZ" = "1" /* Excision of Left Clavicle, Percutaneous Approach */
"0PBB4ZX" = "1" /* Excision of Left Clavicle, Percutaneous Endoscopic Approach, Diagnostic */
"0PBB4ZZ" = "1" /* Excision of Left Clavicle, Percutaneous Endoscopic Approach */
"0PBC0ZX" = "1" /* Excision of Right Humeral Head, Open Approach, Diagnostic */
"0PBC0ZZ" = "1" /* Excision of Right Humeral Head, Open Approach */
"0PBC3ZX" = "1" /* Excision of Right Humeral Head, Percutaneous Approach, Diagnostic */
"0PBC3ZZ" = "1" /* Excision of Right Humeral Head, Percutaneous Approach */
"0PBC4ZX" = "1" /* Excision of Right Humeral Head, Percutaneous Endoscopic Approach, Diagnostic */
"0PBC4ZZ" = "1" /* Excision of Right Humeral Head, Percutaneous Endoscopic Approach */
"0PBD0ZX" = "1" /* Excision of Left Humeral Head, Open Approach, Diagnostic */
"0PBD0ZZ" = "1" /* Excision of Left Humeral Head, Open Approach */
"0PBD3ZX" = "1" /* Excision of Left Humeral Head, Percutaneous Approach, Diagnostic */
"0PBD3ZZ" = "1" /* Excision of Left Humeral Head, Percutaneous Approach */
"0PBD4ZX" = "1" /* Excision of Left Humeral Head, Percutaneous Endoscopic Approach, Diagnostic */
"0PBD4ZZ" = "1" /* Excision of Left Humeral Head, Percutaneous Endoscopic Approach */
"0PBF0ZX" = "1" /* Excision of Right Humeral Shaft, Open Approach, Diagnostic */
"0PBF0ZZ" = "1" /* Excision of Right Humeral Shaft, Open Approach */
"0PBF3ZX" = "1" /* Excision of Right Humeral Shaft, Percutaneous Approach, Diagnostic */
"0PBF3ZZ" = "1" /* Excision of Right Humeral Shaft, Percutaneous Approach */
"0PBF4ZX" = "1" /* Excision of Right Humeral Shaft, Percutaneous Endoscopic Approach, Diagnostic */
"0PBF4ZZ" = "1" /* Excision of Right Humeral Shaft, Percutaneous Endoscopic Approach */
"0PBG0ZX" = "1" /* Excision of Left Humeral Shaft, Open Approach, Diagnostic */
"0PBG0ZZ" = "1" /* Excision of Left Humeral Shaft, Open Approach */
"0PBG3ZX" = "1" /* Excision of Left Humeral Shaft, Percutaneous Approach, Diagnostic */
"0PBG3ZZ" = "1" /* Excision of Left Humeral Shaft, Percutaneous Approach */
"0PBG4ZX" = "1" /* Excision of Left Humeral Shaft, Percutaneous Endoscopic Approach, Diagnostic */
"0PBG4ZZ" = "1" /* Excision of Left Humeral Shaft, Percutaneous Endoscopic Approach */
"0PBH0ZX" = "1" /* Excision of Right Radius, Open Approach, Diagnostic */
"0PBH0ZZ" = "1" /* Excision of Right Radius, Open Approach */
"0PBH3ZX" = "1" /* Excision of Right Radius, Percutaneous Approach, Diagnostic */
"0PBH3ZZ" = "1" /* Excision of Right Radius, Percutaneous Approach */
"0PBH4ZX" = "1" /* Excision of Right Radius, Percutaneous Endoscopic Approach, Diagnostic */
"0PBH4ZZ" = "1" /* Excision of Right Radius, Percutaneous Endoscopic Approach */
"0PBJ0ZX" = "1" /* Excision of Left Radius, Open Approach, Diagnostic */
"0PBJ0ZZ" = "1" /* Excision of Left Radius, Open Approach */
"0PBJ3ZX" = "1" /* Excision of Left Radius, Percutaneous Approach, Diagnostic */
"0PBJ3ZZ" = "1" /* Excision of Left Radius, Percutaneous Approach */
"0PBJ4ZX" = "1" /* Excision of Left Radius, Percutaneous Endoscopic Approach, Diagnostic */
"0PBJ4ZZ" = "1" /* Excision of Left Radius, Percutaneous Endoscopic Approach */
"0PBK0ZX" = "1" /* Excision of Right Ulna, Open Approach, Diagnostic */
"0PBK0ZZ" = "1" /* Excision of Right Ulna, Open Approach */
"0PBK3ZX" = "1" /* Excision of Right Ulna, Percutaneous Approach, Diagnostic */
"0PBK3ZZ" = "1" /* Excision of Right Ulna, Percutaneous Approach */
"0PBK4ZX" = "1" /* Excision of Right Ulna, Percutaneous Endoscopic Approach, Diagnostic */
"0PBK4ZZ" = "1" /* Excision of Right Ulna, Percutaneous Endoscopic Approach */
"0PBL0ZX" = "1" /* Excision of Left Ulna, Open Approach, Diagnostic */
"0PBL0ZZ" = "1" /* Excision of Left Ulna, Open Approach */
"0PBL3ZX" = "1" /* Excision of Left Ulna, Percutaneous Approach, Diagnostic */
"0PBL3ZZ" = "1" /* Excision of Left Ulna, Percutaneous Approach */
"0PBL4ZX" = "1" /* Excision of Left Ulna, Percutaneous Endoscopic Approach, Diagnostic */
"0PBL4ZZ" = "1" /* Excision of Left Ulna, Percutaneous Endoscopic Approach */
"0PBM0ZX" = "1" /* Excision of Right Carpal, Open Approach, Diagnostic */
"0PBM0ZZ" = "1" /* Excision of Right Carpal, Open Approach */
"0PBM3ZX" = "1" /* Excision of Right Carpal, Percutaneous Approach, Diagnostic */
"0PBM3ZZ" = "1" /* Excision of Right Carpal, Percutaneous Approach */
"0PBM4ZX" = "1" /* Excision of Right Carpal, Percutaneous Endoscopic Approach, Diagnostic */
"0PBM4ZZ" = "1" /* Excision of Right Carpal, Percutaneous Endoscopic Approach */
"0PBN0ZX" = "1" /* Excision of Left Carpal, Open Approach, Diagnostic */
"0PBN0ZZ" = "1" /* Excision of Left Carpal, Open Approach */
"0PBN3ZX" = "1" /* Excision of Left Carpal, Percutaneous Approach, Diagnostic */
"0PBN3ZZ" = "1" /* Excision of Left Carpal, Percutaneous Approach */
"0PBN4ZX" = "1" /* Excision of Left Carpal, Percutaneous Endoscopic Approach, Diagnostic */
"0PBN4ZZ" = "1" /* Excision of Left Carpal, Percutaneous Endoscopic Approach */
"0PBP0ZX" = "1" /* Excision of Right Metacarpal, Open Approach, Diagnostic */
"0PBP0ZZ" = "1" /* Excision of Right Metacarpal, Open Approach */
"0PBP3ZX" = "1" /* Excision of Right Metacarpal, Percutaneous Approach, Diagnostic */
"0PBP3ZZ" = "1" /* Excision of Right Metacarpal, Percutaneous Approach */
"0PBP4ZX" = "1" /* Excision of Right Metacarpal, Percutaneous Endoscopic Approach, Diagnostic */
"0PBP4ZZ" = "1" /* Excision of Right Metacarpal, Percutaneous Endoscopic Approach */
"0PBQ0ZX" = "1" /* Excision of Left Metacarpal, Open Approach, Diagnostic */
"0PBQ0ZZ" = "1" /* Excision of Left Metacarpal, Open Approach */
"0PBQ3ZX" = "1" /* Excision of Left Metacarpal, Percutaneous Approach, Diagnostic */
"0PBQ3ZZ" = "1" /* Excision of Left Metacarpal, Percutaneous Approach */
"0PBQ4ZX" = "1" /* Excision of Left Metacarpal, Percutaneous Endoscopic Approach, Diagnostic */
"0PBQ4ZZ" = "1" /* Excision of Left Metacarpal, Percutaneous Endoscopic Approach */
"0PBR0ZX" = "1" /* Excision of Right Thumb Phalanx, Open Approach, Diagnostic */
"0PBR0ZZ" = "1" /* Excision of Right Thumb Phalanx, Open Approach */
"0PBR3ZX" = "1" /* Excision of Right Thumb Phalanx, Percutaneous Approach, Diagnostic */
"0PBR3ZZ" = "1" /* Excision of Right Thumb Phalanx, Percutaneous Approach */
"0PBR4ZX" = "1" /* Excision of Right Thumb Phalanx, Percutaneous Endoscopic Approach, Diagnostic */
"0PBR4ZZ" = "1" /* Excision of Right Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PBS0ZX" = "1" /* Excision of Left Thumb Phalanx, Open Approach, Diagnostic */
"0PBS0ZZ" = "1" /* Excision of Left Thumb Phalanx, Open Approach */
"0PBS3ZX" = "1" /* Excision of Left Thumb Phalanx, Percutaneous Approach, Diagnostic */
"0PBS3ZZ" = "1" /* Excision of Left Thumb Phalanx, Percutaneous Approach */
"0PBS4ZX" = "1" /* Excision of Left Thumb Phalanx, Percutaneous Endoscopic Approach, Diagnostic */
"0PBS4ZZ" = "1" /* Excision of Left Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PBT0ZX" = "1" /* Excision of Right Finger Phalanx, Open Approach, Diagnostic */
"0PBT0ZZ" = "1" /* Excision of Right Finger Phalanx, Open Approach */
"0PBT3ZX" = "1" /* Excision of Right Finger Phalanx, Percutaneous Approach, Diagnostic */
"0PBT3ZZ" = "1" /* Excision of Right Finger Phalanx, Percutaneous Approach */
"0PBT4ZX" = "1" /* Excision of Right Finger Phalanx, Percutaneous Endoscopic Approach, Diagnostic */
"0PBT4ZZ" = "1" /* Excision of Right Finger Phalanx, Percutaneous Endoscopic Approach */
"0PBV0ZX" = "1" /* Excision of Left Finger Phalanx, Open Approach, Diagnostic */
"0PBV0ZZ" = "1" /* Excision of Left Finger Phalanx, Open Approach */
"0PBV3ZX" = "1" /* Excision of Left Finger Phalanx, Percutaneous Approach, Diagnostic */
"0PBV3ZZ" = "1" /* Excision of Left Finger Phalanx, Percutaneous Approach */
"0PBV4ZX" = "1" /* Excision of Left Finger Phalanx, Percutaneous Endoscopic Approach, Diagnostic */
"0PBV4ZZ" = "1" /* Excision of Left Finger Phalanx, Percutaneous Endoscopic Approach */
"0PC00ZZ" = "1" /* Extirpation of Matter from Sternum, Open Approach */
"0PC03ZZ" = "1" /* Extirpation of Matter from Sternum, Percutaneous Approach */
"0PC04ZZ" = "1" /* Extirpation of Matter from Sternum, Percutaneous Endoscopic Approach */
"0PC10ZZ" = "1" /* Extirpation of Matter from Right Rib, Open Approach */
"0PC13ZZ" = "1" /* Extirpation of Matter from Right Rib, Percutaneous Approach */
"0PC14ZZ" = "1" /* Extirpation of Matter from Right Rib, Percutaneous Endoscopic Approach */
"0PC20ZZ" = "1" /* Extirpation of Matter from Left Rib, Open Approach */
"0PC23ZZ" = "1" /* Extirpation of Matter from Left Rib, Percutaneous Approach */
"0PC24ZZ" = "1" /* Extirpation of Matter from Left Rib, Percutaneous Endoscopic Approach */
"0PC30ZZ" = "1" /* Extirpation of Matter from Cervical Vertebra, Open Approach */
"0PC33ZZ" = "1" /* Extirpation of Matter from Cervical Vertebra, Percutaneous Approach */
"0PC34ZZ" = "1" /* Extirpation of Matter from Cervical Vertebra, Percutaneous Endoscopic Approach */
"0PC40ZZ" = "1" /* Extirpation of Matter from Thoracic Vertebra, Open Approach */
"0PC43ZZ" = "1" /* Extirpation of Matter from Thoracic Vertebra, Percutaneous Approach */
"0PC44ZZ" = "1" /* Extirpation of Matter from Thoracic Vertebra, Percutaneous Endoscopic Approach */
"0PC50ZZ" = "1" /* Extirpation of Matter from Right Scapula, Open Approach */
"0PC53ZZ" = "1" /* Extirpation of Matter from Right Scapula, Percutaneous Approach */
"0PC54ZZ" = "1" /* Extirpation of Matter from Right Scapula, Percutaneous Endoscopic Approach */
"0PC60ZZ" = "1" /* Extirpation of Matter from Left Scapula, Open Approach */
"0PC63ZZ" = "1" /* Extirpation of Matter from Left Scapula, Percutaneous Approach */
"0PC64ZZ" = "1" /* Extirpation of Matter from Left Scapula, Percutaneous Endoscopic Approach */
"0PC70ZZ" = "1" /* Extirpation of Matter from Right Glenoid Cavity, Open Approach */
"0PC73ZZ" = "1" /* Extirpation of Matter from Right Glenoid Cavity, Percutaneous Approach */
"0PC74ZZ" = "1" /* Extirpation of Matter from Right Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PC80ZZ" = "1" /* Extirpation of Matter from Left Glenoid Cavity, Open Approach */
"0PC83ZZ" = "1" /* Extirpation of Matter from Left Glenoid Cavity, Percutaneous Approach */
"0PC84ZZ" = "1" /* Extirpation of Matter from Left Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PC90ZZ" = "1" /* Extirpation of Matter from Right Clavicle, Open Approach */
"0PC93ZZ" = "1" /* Extirpation of Matter from Right Clavicle, Percutaneous Approach */
"0PC94ZZ" = "1" /* Extirpation of Matter from Right Clavicle, Percutaneous Endoscopic Approach */
"0PCB0ZZ" = "1" /* Extirpation of Matter from Left Clavicle, Open Approach */
"0PCB3ZZ" = "1" /* Extirpation of Matter from Left Clavicle, Percutaneous Approach */
"0PCB4ZZ" = "1" /* Extirpation of Matter from Left Clavicle, Percutaneous Endoscopic Approach */
"0PCC0ZZ" = "1" /* Extirpation of Matter from Right Humeral Head, Open Approach */
"0PCC3ZZ" = "1" /* Extirpation of Matter from Right Humeral Head, Percutaneous Approach */
"0PCC4ZZ" = "1" /* Extirpation of Matter from Right Humeral Head, Percutaneous Endoscopic Approach */
"0PCD0ZZ" = "1" /* Extirpation of Matter from Left Humeral Head, Open Approach */
"0PCD3ZZ" = "1" /* Extirpation of Matter from Left Humeral Head, Percutaneous Approach */
"0PCD4ZZ" = "1" /* Extirpation of Matter from Left Humeral Head, Percutaneous Endoscopic Approach */
"0PCF0ZZ" = "1" /* Extirpation of Matter from Right Humeral Shaft, Open Approach */
"0PCF3ZZ" = "1" /* Extirpation of Matter from Right Humeral Shaft, Percutaneous Approach */
"0PCF4ZZ" = "1" /* Extirpation of Matter from Right Humeral Shaft, Percutaneous Endoscopic Approach */
"0PCG0ZZ" = "1" /* Extirpation of Matter from Left Humeral Shaft, Open Approach */
"0PCG3ZZ" = "1" /* Extirpation of Matter from Left Humeral Shaft, Percutaneous Approach */
"0PCG4ZZ" = "1" /* Extirpation of Matter from Left Humeral Shaft, Percutaneous Endoscopic Approach */
"0PCH0ZZ" = "1" /* Extirpation of Matter from Right Radius, Open Approach */
"0PCH3ZZ" = "1" /* Extirpation of Matter from Right Radius, Percutaneous Approach */
"0PCH4ZZ" = "1" /* Extirpation of Matter from Right Radius, Percutaneous Endoscopic Approach */
"0PCJ0ZZ" = "1" /* Extirpation of Matter from Left Radius, Open Approach */
"0PCJ3ZZ" = "1" /* Extirpation of Matter from Left Radius, Percutaneous Approach */
"0PCJ4ZZ" = "1" /* Extirpation of Matter from Left Radius, Percutaneous Endoscopic Approach */
"0PCK0ZZ" = "1" /* Extirpation of Matter from Right Ulna, Open Approach */
"0PCK3ZZ" = "1" /* Extirpation of Matter from Right Ulna, Percutaneous Approach */
"0PCK4ZZ" = "1" /* Extirpation of Matter from Right Ulna, Percutaneous Endoscopic Approach */
"0PCL0ZZ" = "1" /* Extirpation of Matter from Left Ulna, Open Approach */
"0PCL3ZZ" = "1" /* Extirpation of Matter from Left Ulna, Percutaneous Approach */
"0PCL4ZZ" = "1" /* Extirpation of Matter from Left Ulna, Percutaneous Endoscopic Approach */
"0PCM0ZZ" = "1" /* Extirpation of Matter from Right Carpal, Open Approach */
"0PCM3ZZ" = "1" /* Extirpation of Matter from Right Carpal, Percutaneous Approach */
"0PCM4ZZ" = "1" /* Extirpation of Matter from Right Carpal, Percutaneous Endoscopic Approach */
"0PCN0ZZ" = "1" /* Extirpation of Matter from Left Carpal, Open Approach */
"0PCN3ZZ" = "1" /* Extirpation of Matter from Left Carpal, Percutaneous Approach */
"0PCN4ZZ" = "1" /* Extirpation of Matter from Left Carpal, Percutaneous Endoscopic Approach */
"0PCP0ZZ" = "1" /* Extirpation of Matter from Right Metacarpal, Open Approach */
"0PCP3ZZ" = "1" /* Extirpation of Matter from Right Metacarpal, Percutaneous Approach */
"0PCP4ZZ" = "1" /* Extirpation of Matter from Right Metacarpal, Percutaneous Endoscopic Approach */
"0PCQ0ZZ" = "1" /* Extirpation of Matter from Left Metacarpal, Open Approach */
"0PCQ3ZZ" = "1" /* Extirpation of Matter from Left Metacarpal, Percutaneous Approach */
"0PCQ4ZZ" = "1" /* Extirpation of Matter from Left Metacarpal, Percutaneous Endoscopic Approach */
"0PCR0ZZ" = "1" /* Extirpation of Matter from Right Thumb Phalanx, Open Approach */
"0PCR3ZZ" = "1" /* Extirpation of Matter from Right Thumb Phalanx, Percutaneous Approach */
"0PCR4ZZ" = "1" /* Extirpation of Matter from Right Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PCS0ZZ" = "1" /* Extirpation of Matter from Left Thumb Phalanx, Open Approach */
"0PCS3ZZ" = "1" /* Extirpation of Matter from Left Thumb Phalanx, Percutaneous Approach */
"0PCS4ZZ" = "1" /* Extirpation of Matter from Left Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PCT0ZZ" = "1" /* Extirpation of Matter from Right Finger Phalanx, Open Approach */
"0PCT3ZZ" = "1" /* Extirpation of Matter from Right Finger Phalanx, Percutaneous Approach */
"0PCT4ZZ" = "1" /* Extirpation of Matter from Right Finger Phalanx, Percutaneous Endoscopic Approach */
"0PCV0ZZ" = "1" /* Extirpation of Matter from Left Finger Phalanx, Open Approach */
"0PCV3ZZ" = "1" /* Extirpation of Matter from Left Finger Phalanx, Percutaneous Approach */
"0PCV4ZZ" = "1" /* Extirpation of Matter from Left Finger Phalanx, Percutaneous Endoscopic Approach */
"0PH000Z" = "1" /* Insertion of Rigid Plate Internal Fixation Device into Sternum, Open Approach */
"0PH004Z" = "1" /* Insertion of Internal Fixation Device into Sternum, Open Approach */
"0PH030Z" = "1" /* Insertion of Rigid Plate Internal Fixation Device into Sternum, Percutaneous Approach */
"0PH034Z" = "1" /* Insertion of Internal Fixation Device into Sternum, Percutaneous Approach */
"0PH040Z" = "1" /* Insertion of Rigid Plate Internal Fixation Device into Sternum, Percutaneous Endoscopic Approach */
"0PH044Z" = "1" /* Insertion of Internal Fixation Device into Sternum, Percutaneous Endoscopic Approach */
"0PH104Z" = "1" /* Insertion of Internal Fixation Device into Right Rib, Open Approach */
"0PH134Z" = "1" /* Insertion of Internal Fixation Device into Right Rib, Percutaneous Approach */
"0PH144Z" = "1" /* Insertion of Internal Fixation Device into Right Rib, Percutaneous Endoscopic Approach */
"0PH204Z" = "1" /* Insertion of Internal Fixation Device into Left Rib, Open Approach */
"0PH234Z" = "1" /* Insertion of Internal Fixation Device into Left Rib, Percutaneous Approach */
"0PH244Z" = "1" /* Insertion of Internal Fixation Device into Left Rib, Percutaneous Endoscopic Approach */
"0PH304Z" = "1" /* Insertion of Internal Fixation Device into Cervical Vertebra, Open Approach */
"0PH334Z" = "1" /* Insertion of Internal Fixation Device into Cervical Vertebra, Percutaneous Approach */
"0PH344Z" = "1" /* Insertion of Internal Fixation Device into Cervical Vertebra, Percutaneous Endoscopic Approach */
"0PH404Z" = "1" /* Insertion of Internal Fixation Device into Thoracic Vertebra, Open Approach */
"0PH434Z" = "1" /* Insertion of Internal Fixation Device into Thoracic Vertebra, Percutaneous Approach */
"0PH444Z" = "1" /* Insertion of Internal Fixation Device into Thoracic Vertebra, Percutaneous Endoscopic Approach */
"0PH504Z" = "1" /* Insertion of Internal Fixation Device into Right Scapula, Open Approach */
"0PH534Z" = "1" /* Insertion of Internal Fixation Device into Right Scapula, Percutaneous Approach */
"0PH544Z" = "1" /* Insertion of Internal Fixation Device into Right Scapula, Percutaneous Endoscopic Approach */
"0PH604Z" = "1" /* Insertion of Internal Fixation Device into Left Scapula, Open Approach */
"0PH634Z" = "1" /* Insertion of Internal Fixation Device into Left Scapula, Percutaneous Approach */
"0PH644Z" = "1" /* Insertion of Internal Fixation Device into Left Scapula, Percutaneous Endoscopic Approach */
"0PH704Z" = "1" /* Insertion of Internal Fixation Device into Right Glenoid Cavity, Open Approach */
"0PH734Z" = "1" /* Insertion of Internal Fixation Device into Right Glenoid Cavity, Percutaneous Approach */
"0PH744Z" = "1" /* Insertion of Internal Fixation Device into Right Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PH804Z" = "1" /* Insertion of Internal Fixation Device into Left Glenoid Cavity, Open Approach */
"0PH834Z" = "1" /* Insertion of Internal Fixation Device into Left Glenoid Cavity, Percutaneous Approach */
"0PH844Z" = "1" /* Insertion of Internal Fixation Device into Left Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PH904Z" = "1" /* Insertion of Internal Fixation Device into Right Clavicle, Open Approach */
"0PH934Z" = "1" /* Insertion of Internal Fixation Device into Right Clavicle, Percutaneous Approach */
"0PH944Z" = "1" /* Insertion of Internal Fixation Device into Right Clavicle, Percutaneous Endoscopic Approach */
"0PHB04Z" = "1" /* Insertion of Internal Fixation Device into Left Clavicle, Open Approach */
"0PHB34Z" = "1" /* Insertion of Internal Fixation Device into Left Clavicle, Percutaneous Approach */
"0PHB44Z" = "1" /* Insertion of Internal Fixation Device into Left Clavicle, Percutaneous Endoscopic Approach */
"0PHC04Z" = "1" /* Insertion of Internal Fixation Device into Right Humeral Head, Open Approach */
"0PHC05Z" = "1" /* Insertion of External Fixation Device into Right Humeral Head, Open Approach */
"0PHC06Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Humeral Head, Open Approach */
"0PHC0BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Humeral Head, Open Approach */
"0PHC0CZ" = "1" /* Insertion of Ring External Fixation Device into Right Humeral Head, Open Approach */
"0PHC0DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Humeral Head, Open Approach */
"0PHC34Z" = "1" /* Insertion of Internal Fixation Device into Right Humeral Head, Percutaneous Approach */
"0PHC35Z" = "1" /* Insertion of External Fixation Device into Right Humeral Head, Percutaneous Approach */
"0PHC36Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Humeral Head, Percutaneous Approach */
"0PHC3BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Humeral Head, Percutaneous Approach */
"0PHC3CZ" = "1" /* Insertion of Ring External Fixation Device into Right Humeral Head, Percutaneous Approach */
"0PHC3DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Humeral Head, Percutaneous Approach */
"0PHC44Z" = "1" /* Insertion of Internal Fixation Device into Right Humeral Head, Percutaneous Endoscopic Approach */
"0PHC45Z" = "1" /* Insertion of External Fixation Device into Right Humeral Head, Percutaneous Endoscopic Approach */
"0PHC46Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Humeral Head, Percutaneous Endoscopic Approach */
"0PHC4BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Humeral Head, Percutaneous Endoscopic Approach */
"0PHC4CZ" = "1" /* Insertion of Ring External Fixation Device into Right Humeral Head, Percutaneous Endoscopic Approach */
"0PHC4DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Humeral Head, Percutaneous Endoscopic Approach */
"0PHD04Z" = "1" /* Insertion of Internal Fixation Device into Left Humeral Head, Open Approach */
"0PHD05Z" = "1" /* Insertion of External Fixation Device into Left Humeral Head, Open Approach */
"0PHD06Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Humeral Head, Open Approach */
"0PHD0BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Humeral Head, Open Approach */
"0PHD0CZ" = "1" /* Insertion of Ring External Fixation Device into Left Humeral Head, Open Approach */
"0PHD0DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Humeral Head, Open Approach */
"0PHD34Z" = "1" /* Insertion of Internal Fixation Device into Left Humeral Head, Percutaneous Approach */
"0PHD35Z" = "1" /* Insertion of External Fixation Device into Left Humeral Head, Percutaneous Approach */
"0PHD36Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Humeral Head, Percutaneous Approach */
"0PHD3BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Humeral Head, Percutaneous Approach */
"0PHD3CZ" = "1" /* Insertion of Ring External Fixation Device into Left Humeral Head, Percutaneous Approach */
"0PHD3DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Humeral Head, Percutaneous Approach */
"0PHD44Z" = "1" /* Insertion of Internal Fixation Device into Left Humeral Head, Percutaneous Endoscopic Approach */
"0PHD45Z" = "1" /* Insertion of External Fixation Device into Left Humeral Head, Percutaneous Endoscopic Approach */
"0PHD46Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Humeral Head, Percutaneous Endoscopic Approach */
"0PHD4BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Humeral Head, Percutaneous Endoscopic Approach */
"0PHD4CZ" = "1" /* Insertion of Ring External Fixation Device into Left Humeral Head, Percutaneous Endoscopic Approach */
"0PHD4DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Humeral Head, Percutaneous Endoscopic Approach */
"0PHF04Z" = "1" /* Insertion of Internal Fixation Device into Right Humeral Shaft, Open Approach */
"0PHF05Z" = "1" /* Insertion of External Fixation Device into Right Humeral Shaft, Open Approach */
"0PHF06Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Humeral Shaft, Open Approach */
"0PHF0BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Humeral Shaft, Open Approach */
"0PHF0CZ" = "1" /* Insertion of Ring External Fixation Device into Right Humeral Shaft, Open Approach */
"0PHF0DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Humeral Shaft, Open Approach */
"0PHF34Z" = "1" /* Insertion of Internal Fixation Device into Right Humeral Shaft, Percutaneous Approach */
"0PHF35Z" = "1" /* Insertion of External Fixation Device into Right Humeral Shaft, Percutaneous Approach */
"0PHF36Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Humeral Shaft, Percutaneous Approach */
"0PHF3BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Humeral Shaft, Percutaneous Approach */
"0PHF3CZ" = "1" /* Insertion of Ring External Fixation Device into Right Humeral Shaft, Percutaneous Approach */
"0PHF3DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Humeral Shaft, Percutaneous Approach */
"0PHF44Z" = "1" /* Insertion of Internal Fixation Device into Right Humeral Shaft, Percutaneous Endoscopic Approach */
"0PHF45Z" = "1" /* Insertion of External Fixation Device into Right Humeral Shaft, Percutaneous Endoscopic Approach */
"0PHF46Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Humeral Shaft, Percutaneous Endoscopic Approach */
"0PHF4BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Humeral Shaft, Percutaneous Endoscopic Approach */
"0PHF4CZ" = "1" /* Insertion of Ring External Fixation Device into Right Humeral Shaft, Percutaneous Endoscopic Approach */
"0PHF4DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Humeral Shaft, Percutaneous Endoscopic Approach */
"0PHG04Z" = "1" /* Insertion of Internal Fixation Device into Left Humeral Shaft, Open Approach */
"0PHG05Z" = "1" /* Insertion of External Fixation Device into Left Humeral Shaft, Open Approach */
"0PHG06Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Humeral Shaft, Open Approach */
"0PHG0BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Humeral Shaft, Open Approach */
"0PHG0CZ" = "1" /* Insertion of Ring External Fixation Device into Left Humeral Shaft, Open Approach */
"0PHG0DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Humeral Shaft, Open Approach */
"0PHG34Z" = "1" /* Insertion of Internal Fixation Device into Left Humeral Shaft, Percutaneous Approach */
"0PHG35Z" = "1" /* Insertion of External Fixation Device into Left Humeral Shaft, Percutaneous Approach */
"0PHG36Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Humeral Shaft, Percutaneous Approach */
"0PHG3BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Humeral Shaft, Percutaneous Approach */
"0PHG3CZ" = "1" /* Insertion of Ring External Fixation Device into Left Humeral Shaft, Percutaneous Approach */
"0PHG3DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Humeral Shaft, Percutaneous Approach */
"0PHG44Z" = "1" /* Insertion of Internal Fixation Device into Left Humeral Shaft, Percutaneous Endoscopic Approach */
"0PHG45Z" = "1" /* Insertion of External Fixation Device into Left Humeral Shaft, Percutaneous Endoscopic Approach */
"0PHG46Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Humeral Shaft, Percutaneous Endoscopic Approach */
"0PHG4BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Humeral Shaft, Percutaneous Endoscopic Approach */
"0PHG4CZ" = "1" /* Insertion of Ring External Fixation Device into Left Humeral Shaft, Percutaneous Endoscopic Approach */
"0PHG4DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Humeral Shaft, Percutaneous Endoscopic Approach */
"0PHH04Z" = "1" /* Insertion of Internal Fixation Device into Right Radius, Open Approach */
"0PHH05Z" = "1" /* Insertion of External Fixation Device into Right Radius, Open Approach */
"0PHH06Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Radius, Open Approach */
"0PHH0BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Radius, Open Approach */
"0PHH0CZ" = "1" /* Insertion of Ring External Fixation Device into Right Radius, Open Approach */
"0PHH0DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Radius, Open Approach */
"0PHH34Z" = "1" /* Insertion of Internal Fixation Device into Right Radius, Percutaneous Approach */
"0PHH35Z" = "1" /* Insertion of External Fixation Device into Right Radius, Percutaneous Approach */
"0PHH36Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Radius, Percutaneous Approach */
"0PHH3BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Radius, Percutaneous Approach */
"0PHH3CZ" = "1" /* Insertion of Ring External Fixation Device into Right Radius, Percutaneous Approach */
"0PHH3DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Radius, Percutaneous Approach */
"0PHH44Z" = "1" /* Insertion of Internal Fixation Device into Right Radius, Percutaneous Endoscopic Approach */
"0PHH45Z" = "1" /* Insertion of External Fixation Device into Right Radius, Percutaneous Endoscopic Approach */
"0PHH46Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Radius, Percutaneous Endoscopic Approach */
"0PHH4BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Radius, Percutaneous Endoscopic Approach */
"0PHH4CZ" = "1" /* Insertion of Ring External Fixation Device into Right Radius, Percutaneous Endoscopic Approach */
"0PHH4DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Radius, Percutaneous Endoscopic Approach */
"0PHJ04Z" = "1" /* Insertion of Internal Fixation Device into Left Radius, Open Approach */
"0PHJ05Z" = "1" /* Insertion of External Fixation Device into Left Radius, Open Approach */
"0PHJ06Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Radius, Open Approach */
"0PHJ0BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Radius, Open Approach */
"0PHJ0CZ" = "1" /* Insertion of Ring External Fixation Device into Left Radius, Open Approach */
"0PHJ0DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Radius, Open Approach */
"0PHJ34Z" = "1" /* Insertion of Internal Fixation Device into Left Radius, Percutaneous Approach */
"0PHJ35Z" = "1" /* Insertion of External Fixation Device into Left Radius, Percutaneous Approach */
"0PHJ36Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Radius, Percutaneous Approach */
"0PHJ3BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Radius, Percutaneous Approach */
"0PHJ3CZ" = "1" /* Insertion of Ring External Fixation Device into Left Radius, Percutaneous Approach */
"0PHJ3DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Radius, Percutaneous Approach */
"0PHJ44Z" = "1" /* Insertion of Internal Fixation Device into Left Radius, Percutaneous Endoscopic Approach */
"0PHJ45Z" = "1" /* Insertion of External Fixation Device into Left Radius, Percutaneous Endoscopic Approach */
"0PHJ46Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Radius, Percutaneous Endoscopic Approach */
"0PHJ4BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Radius, Percutaneous Endoscopic Approach */
"0PHJ4CZ" = "1" /* Insertion of Ring External Fixation Device into Left Radius, Percutaneous Endoscopic Approach */
"0PHJ4DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Radius, Percutaneous Endoscopic Approach */
"0PHK04Z" = "1" /* Insertion of Internal Fixation Device into Right Ulna, Open Approach */
"0PHK05Z" = "1" /* Insertion of External Fixation Device into Right Ulna, Open Approach */
"0PHK06Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Ulna, Open Approach */
"0PHK0BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Ulna, Open Approach */
"0PHK0CZ" = "1" /* Insertion of Ring External Fixation Device into Right Ulna, Open Approach */
"0PHK0DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Ulna, Open Approach */
"0PHK34Z" = "1" /* Insertion of Internal Fixation Device into Right Ulna, Percutaneous Approach */
"0PHK35Z" = "1" /* Insertion of External Fixation Device into Right Ulna, Percutaneous Approach */
"0PHK36Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Ulna, Percutaneous Approach */
"0PHK3BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Ulna, Percutaneous Approach */
"0PHK3CZ" = "1" /* Insertion of Ring External Fixation Device into Right Ulna, Percutaneous Approach */
"0PHK3DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Ulna, Percutaneous Approach */
"0PHK44Z" = "1" /* Insertion of Internal Fixation Device into Right Ulna, Percutaneous Endoscopic Approach */
"0PHK45Z" = "1" /* Insertion of External Fixation Device into Right Ulna, Percutaneous Endoscopic Approach */
"0PHK46Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Ulna, Percutaneous Endoscopic Approach */
"0PHK4BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Ulna, Percutaneous Endoscopic Approach */
"0PHK4CZ" = "1" /* Insertion of Ring External Fixation Device into Right Ulna, Percutaneous Endoscopic Approach */
"0PHK4DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Ulna, Percutaneous Endoscopic Approach */
"0PHL04Z" = "1" /* Insertion of Internal Fixation Device into Left Ulna, Open Approach */
"0PHL05Z" = "1" /* Insertion of External Fixation Device into Left Ulna, Open Approach */
"0PHL06Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Ulna, Open Approach */
"0PHL0BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Ulna, Open Approach */
"0PHL0CZ" = "1" /* Insertion of Ring External Fixation Device into Left Ulna, Open Approach */
"0PHL0DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Ulna, Open Approach */
"0PHL34Z" = "1" /* Insertion of Internal Fixation Device into Left Ulna, Percutaneous Approach */
"0PHL35Z" = "1" /* Insertion of External Fixation Device into Left Ulna, Percutaneous Approach */
"0PHL36Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Ulna, Percutaneous Approach */
"0PHL3BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Ulna, Percutaneous Approach */
"0PHL3CZ" = "1" /* Insertion of Ring External Fixation Device into Left Ulna, Percutaneous Approach */
"0PHL3DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Ulna, Percutaneous Approach */
"0PHL44Z" = "1" /* Insertion of Internal Fixation Device into Left Ulna, Percutaneous Endoscopic Approach */
"0PHL45Z" = "1" /* Insertion of External Fixation Device into Left Ulna, Percutaneous Endoscopic Approach */
"0PHL46Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Ulna, Percutaneous Endoscopic Approach */
"0PHL4BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Ulna, Percutaneous Endoscopic Approach */
"0PHL4CZ" = "1" /* Insertion of Ring External Fixation Device into Left Ulna, Percutaneous Endoscopic Approach */
"0PHL4DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Ulna, Percutaneous Endoscopic Approach */
"0PHM04Z" = "1" /* Insertion of Internal Fixation Device into Right Carpal, Open Approach */
"0PHM05Z" = "1" /* Insertion of External Fixation Device into Right Carpal, Open Approach */
"0PHM34Z" = "1" /* Insertion of Internal Fixation Device into Right Carpal, Percutaneous Approach */
"0PHM35Z" = "1" /* Insertion of External Fixation Device into Right Carpal, Percutaneous Approach */
"0PHM44Z" = "1" /* Insertion of Internal Fixation Device into Right Carpal, Percutaneous Endoscopic Approach */
"0PHM45Z" = "1" /* Insertion of External Fixation Device into Right Carpal, Percutaneous Endoscopic Approach */
"0PHN04Z" = "1" /* Insertion of Internal Fixation Device into Left Carpal, Open Approach */
"0PHN05Z" = "1" /* Insertion of External Fixation Device into Left Carpal, Open Approach */
"0PHN34Z" = "1" /* Insertion of Internal Fixation Device into Left Carpal, Percutaneous Approach */
"0PHN35Z" = "1" /* Insertion of External Fixation Device into Left Carpal, Percutaneous Approach */
"0PHN44Z" = "1" /* Insertion of Internal Fixation Device into Left Carpal, Percutaneous Endoscopic Approach */
"0PHN45Z" = "1" /* Insertion of External Fixation Device into Left Carpal, Percutaneous Endoscopic Approach */
"0PHP04Z" = "1" /* Insertion of Internal Fixation Device into Right Metacarpal, Open Approach */
"0PHP05Z" = "1" /* Insertion of External Fixation Device into Right Metacarpal, Open Approach */
"0PHP34Z" = "1" /* Insertion of Internal Fixation Device into Right Metacarpal, Percutaneous Approach */
"0PHP35Z" = "1" /* Insertion of External Fixation Device into Right Metacarpal, Percutaneous Approach */
"0PHP44Z" = "1" /* Insertion of Internal Fixation Device into Right Metacarpal, Percutaneous Endoscopic Approach */
"0PHP45Z" = "1" /* Insertion of External Fixation Device into Right Metacarpal, Percutaneous Endoscopic Approach */
"0PHQ04Z" = "1" /* Insertion of Internal Fixation Device into Left Metacarpal, Open Approach */
"0PHQ05Z" = "1" /* Insertion of External Fixation Device into Left Metacarpal, Open Approach */
"0PHQ34Z" = "1" /* Insertion of Internal Fixation Device into Left Metacarpal, Percutaneous Approach */
"0PHQ35Z" = "1" /* Insertion of External Fixation Device into Left Metacarpal, Percutaneous Approach */
"0PHQ44Z" = "1" /* Insertion of Internal Fixation Device into Left Metacarpal, Percutaneous Endoscopic Approach */
"0PHQ45Z" = "1" /* Insertion of External Fixation Device into Left Metacarpal, Percutaneous Endoscopic Approach */
"0PHR04Z" = "1" /* Insertion of Internal Fixation Device into Right Thumb Phalanx, Open Approach */
"0PHR05Z" = "1" /* Insertion of External Fixation Device into Right Thumb Phalanx, Open Approach */
"0PHR34Z" = "1" /* Insertion of Internal Fixation Device into Right Thumb Phalanx, Percutaneous Approach */
"0PHR35Z" = "1" /* Insertion of External Fixation Device into Right Thumb Phalanx, Percutaneous Approach */
"0PHR44Z" = "1" /* Insertion of Internal Fixation Device into Right Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PHR45Z" = "1" /* Insertion of External Fixation Device into Right Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PHS04Z" = "1" /* Insertion of Internal Fixation Device into Left Thumb Phalanx, Open Approach */
"0PHS05Z" = "1" /* Insertion of External Fixation Device into Left Thumb Phalanx, Open Approach */
"0PHS34Z" = "1" /* Insertion of Internal Fixation Device into Left Thumb Phalanx, Percutaneous Approach */
"0PHS35Z" = "1" /* Insertion of External Fixation Device into Left Thumb Phalanx, Percutaneous Approach */
"0PHS44Z" = "1" /* Insertion of Internal Fixation Device into Left Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PHS45Z" = "1" /* Insertion of External Fixation Device into Left Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PHT04Z" = "1" /* Insertion of Internal Fixation Device into Right Finger Phalanx, Open Approach */
"0PHT05Z" = "1" /* Insertion of External Fixation Device into Right Finger Phalanx, Open Approach */
"0PHT34Z" = "1" /* Insertion of Internal Fixation Device into Right Finger Phalanx, Percutaneous Approach */
"0PHT35Z" = "1" /* Insertion of External Fixation Device into Right Finger Phalanx, Percutaneous Approach */
"0PHT44Z" = "1" /* Insertion of Internal Fixation Device into Right Finger Phalanx, Percutaneous Endoscopic Approach */
"0PHT45Z" = "1" /* Insertion of External Fixation Device into Right Finger Phalanx, Percutaneous Endoscopic Approach */
"0PHV04Z" = "1" /* Insertion of Internal Fixation Device into Left Finger Phalanx, Open Approach */
"0PHV05Z" = "1" /* Insertion of External Fixation Device into Left Finger Phalanx, Open Approach */
"0PHV34Z" = "1" /* Insertion of Internal Fixation Device into Left Finger Phalanx, Percutaneous Approach */
"0PHV35Z" = "1" /* Insertion of External Fixation Device into Left Finger Phalanx, Percutaneous Approach */
"0PHV44Z" = "1" /* Insertion of Internal Fixation Device into Left Finger Phalanx, Percutaneous Endoscopic Approach */
"0PHV45Z" = "1" /* Insertion of External Fixation Device into Left Finger Phalanx, Percutaneous Endoscopic Approach */
"0PHY0MZ" = "1" /* Insertion of Bone Growth Stimulator into Upper Bone, Open Approach */
"0PHY3MZ" = "1" /* Insertion of Bone Growth Stimulator into Upper Bone, Percutaneous Approach */
"0PHY4MZ" = "1" /* Insertion of Bone Growth Stimulator into Upper Bone, Percutaneous Endoscopic Approach */
"0PJY0ZZ" = "1" /* Inspection of Upper Bone, Open Approach */
"0PJY4ZZ" = "1" /* Inspection of Upper Bone, Percutaneous Endoscopic Approach */
"0PN00ZZ" = "1" /* Release Sternum, Open Approach */
"0PN03ZZ" = "1" /* Release Sternum, Percutaneous Approach */
"0PN04ZZ" = "1" /* Release Sternum, Percutaneous Endoscopic Approach */
"0PN10ZZ" = "1" /* Release Right Rib, Open Approach */
"0PN13ZZ" = "1" /* Release Right Rib, Percutaneous Approach */
"0PN14ZZ" = "1" /* Release Right Rib, Percutaneous Endoscopic Approach */
"0PN20ZZ" = "1" /* Release Left Rib, Open Approach */
"0PN23ZZ" = "1" /* Release Left Rib, Percutaneous Approach */
"0PN24ZZ" = "1" /* Release Left Rib, Percutaneous Endoscopic Approach */
"0PN30ZZ" = "1" /* Release Cervical Vertebra, Open Approach */
"0PN33ZZ" = "1" /* Release Cervical Vertebra, Percutaneous Approach */
"0PN34ZZ" = "1" /* Release Cervical Vertebra, Percutaneous Endoscopic Approach */
"0PN40ZZ" = "1" /* Release Thoracic Vertebra, Open Approach */
"0PN43ZZ" = "1" /* Release Thoracic Vertebra, Percutaneous Approach */
"0PN44ZZ" = "1" /* Release Thoracic Vertebra, Percutaneous Endoscopic Approach */
"0PN50ZZ" = "1" /* Release Right Scapula, Open Approach */
"0PN53ZZ" = "1" /* Release Right Scapula, Percutaneous Approach */
"0PN54ZZ" = "1" /* Release Right Scapula, Percutaneous Endoscopic Approach */
"0PN60ZZ" = "1" /* Release Left Scapula, Open Approach */
"0PN63ZZ" = "1" /* Release Left Scapula, Percutaneous Approach */
"0PN64ZZ" = "1" /* Release Left Scapula, Percutaneous Endoscopic Approach */
"0PN70ZZ" = "1" /* Release Right Glenoid Cavity, Open Approach */
"0PN73ZZ" = "1" /* Release Right Glenoid Cavity, Percutaneous Approach */
"0PN74ZZ" = "1" /* Release Right Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PN80ZZ" = "1" /* Release Left Glenoid Cavity, Open Approach */
"0PN83ZZ" = "1" /* Release Left Glenoid Cavity, Percutaneous Approach */
"0PN84ZZ" = "1" /* Release Left Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PN90ZZ" = "1" /* Release Right Clavicle, Open Approach */
"0PN93ZZ" = "1" /* Release Right Clavicle, Percutaneous Approach */
"0PN94ZZ" = "1" /* Release Right Clavicle, Percutaneous Endoscopic Approach */
"0PNB0ZZ" = "1" /* Release Left Clavicle, Open Approach */
"0PNB3ZZ" = "1" /* Release Left Clavicle, Percutaneous Approach */
"0PNB4ZZ" = "1" /* Release Left Clavicle, Percutaneous Endoscopic Approach */
"0PNC0ZZ" = "1" /* Release Right Humeral Head, Open Approach */
"0PNC3ZZ" = "1" /* Release Right Humeral Head, Percutaneous Approach */
"0PNC4ZZ" = "1" /* Release Right Humeral Head, Percutaneous Endoscopic Approach */
"0PND0ZZ" = "1" /* Release Left Humeral Head, Open Approach */
"0PND3ZZ" = "1" /* Release Left Humeral Head, Percutaneous Approach */
"0PND4ZZ" = "1" /* Release Left Humeral Head, Percutaneous Endoscopic Approach */
"0PNF0ZZ" = "1" /* Release Right Humeral Shaft, Open Approach */
"0PNF3ZZ" = "1" /* Release Right Humeral Shaft, Percutaneous Approach */
"0PNF4ZZ" = "1" /* Release Right Humeral Shaft, Percutaneous Endoscopic Approach */
"0PNG0ZZ" = "1" /* Release Left Humeral Shaft, Open Approach */
"0PNG3ZZ" = "1" /* Release Left Humeral Shaft, Percutaneous Approach */
"0PNG4ZZ" = "1" /* Release Left Humeral Shaft, Percutaneous Endoscopic Approach */
"0PNH0ZZ" = "1" /* Release Right Radius, Open Approach */
"0PNH3ZZ" = "1" /* Release Right Radius, Percutaneous Approach */
"0PNH4ZZ" = "1" /* Release Right Radius, Percutaneous Endoscopic Approach */
"0PNJ0ZZ" = "1" /* Release Left Radius, Open Approach */
"0PNJ3ZZ" = "1" /* Release Left Radius, Percutaneous Approach */
"0PNJ4ZZ" = "1" /* Release Left Radius, Percutaneous Endoscopic Approach */
"0PNK0ZZ" = "1" /* Release Right Ulna, Open Approach */
"0PNK3ZZ" = "1" /* Release Right Ulna, Percutaneous Approach */
"0PNK4ZZ" = "1" /* Release Right Ulna, Percutaneous Endoscopic Approach */
"0PNL0ZZ" = "1" /* Release Left Ulna, Open Approach */
"0PNL3ZZ" = "1" /* Release Left Ulna, Percutaneous Approach */
"0PNL4ZZ" = "1" /* Release Left Ulna, Percutaneous Endoscopic Approach */
"0PNM0ZZ" = "1" /* Release Right Carpal, Open Approach */
"0PNM3ZZ" = "1" /* Release Right Carpal, Percutaneous Approach */
"0PNM4ZZ" = "1" /* Release Right Carpal, Percutaneous Endoscopic Approach */
"0PNN0ZZ" = "1" /* Release Left Carpal, Open Approach */
"0PNN3ZZ" = "1" /* Release Left Carpal, Percutaneous Approach */
"0PNN4ZZ" = "1" /* Release Left Carpal, Percutaneous Endoscopic Approach */
"0PNP0ZZ" = "1" /* Release Right Metacarpal, Open Approach */
"0PNP3ZZ" = "1" /* Release Right Metacarpal, Percutaneous Approach */
"0PNP4ZZ" = "1" /* Release Right Metacarpal, Percutaneous Endoscopic Approach */
"0PNQ0ZZ" = "1" /* Release Left Metacarpal, Open Approach */
"0PNQ3ZZ" = "1" /* Release Left Metacarpal, Percutaneous Approach */
"0PNQ4ZZ" = "1" /* Release Left Metacarpal, Percutaneous Endoscopic Approach */
"0PNR0ZZ" = "1" /* Release Right Thumb Phalanx, Open Approach */
"0PNR3ZZ" = "1" /* Release Right Thumb Phalanx, Percutaneous Approach */
"0PNR4ZZ" = "1" /* Release Right Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PNS0ZZ" = "1" /* Release Left Thumb Phalanx, Open Approach */
"0PNS3ZZ" = "1" /* Release Left Thumb Phalanx, Percutaneous Approach */
"0PNS4ZZ" = "1" /* Release Left Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PNT0ZZ" = "1" /* Release Right Finger Phalanx, Open Approach */
"0PNT3ZZ" = "1" /* Release Right Finger Phalanx, Percutaneous Approach */
"0PNT4ZZ" = "1" /* Release Right Finger Phalanx, Percutaneous Endoscopic Approach */
"0PNV0ZZ" = "1" /* Release Left Finger Phalanx, Open Approach */
"0PNV3ZZ" = "1" /* Release Left Finger Phalanx, Percutaneous Approach */
"0PNV4ZZ" = "1" /* Release Left Finger Phalanx, Percutaneous Endoscopic Approach */
"0PP004Z" = "1" /* Removal of Internal Fixation Device from Sternum, Open Approach */
"0PP007Z" = "1" /* Removal of Autologous Tissue Substitute from Sternum, Open Approach */
"0PP00JZ" = "1" /* Removal of Synthetic Substitute from Sternum, Open Approach */
"0PP00KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Sternum, Open Approach */
"0PP034Z" = "1" /* Removal of Internal Fixation Device from Sternum, Percutaneous Approach */
"0PP037Z" = "1" /* Removal of Autologous Tissue Substitute from Sternum, Percutaneous Approach */
"0PP03JZ" = "1" /* Removal of Synthetic Substitute from Sternum, Percutaneous Approach */
"0PP03KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Sternum, Percutaneous Approach */
"0PP044Z" = "1" /* Removal of Internal Fixation Device from Sternum, Percutaneous Endoscopic Approach */
"0PP047Z" = "1" /* Removal of Autologous Tissue Substitute from Sternum, Percutaneous Endoscopic Approach */
"0PP04JZ" = "1" /* Removal of Synthetic Substitute from Sternum, Percutaneous Endoscopic Approach */
"0PP04KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Sternum, Percutaneous Endoscopic Approach */
"0PP104Z" = "1" /* Removal of Internal Fixation Device from Right Rib, Open Approach */
"0PP107Z" = "1" /* Removal of Autologous Tissue Substitute from Right Rib, Open Approach */
"0PP10JZ" = "1" /* Removal of Synthetic Substitute from Right Rib, Open Approach */
"0PP10KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Rib, Open Approach */
"0PP134Z" = "1" /* Removal of Internal Fixation Device from Right Rib, Percutaneous Approach */
"0PP137Z" = "1" /* Removal of Autologous Tissue Substitute from Right Rib, Percutaneous Approach */
"0PP13JZ" = "1" /* Removal of Synthetic Substitute from Right Rib, Percutaneous Approach */
"0PP13KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Rib, Percutaneous Approach */
"0PP144Z" = "1" /* Removal of Internal Fixation Device from Right Rib, Percutaneous Endoscopic Approach */
"0PP147Z" = "1" /* Removal of Autologous Tissue Substitute from Right Rib, Percutaneous Endoscopic Approach */
"0PP14JZ" = "1" /* Removal of Synthetic Substitute from Right Rib, Percutaneous Endoscopic Approach */
"0PP14KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Rib, Percutaneous Endoscopic Approach */
"0PP204Z" = "1" /* Removal of Internal Fixation Device from Left Rib, Open Approach */
"0PP207Z" = "1" /* Removal of Autologous Tissue Substitute from Left Rib, Open Approach */
"0PP20JZ" = "1" /* Removal of Synthetic Substitute from Left Rib, Open Approach */
"0PP20KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Rib, Open Approach */
"0PP234Z" = "1" /* Removal of Internal Fixation Device from Left Rib, Percutaneous Approach */
"0PP237Z" = "1" /* Removal of Autologous Tissue Substitute from Left Rib, Percutaneous Approach */
"0PP23JZ" = "1" /* Removal of Synthetic Substitute from Left Rib, Percutaneous Approach */
"0PP23KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Rib, Percutaneous Approach */
"0PP244Z" = "1" /* Removal of Internal Fixation Device from Left Rib, Percutaneous Endoscopic Approach */
"0PP247Z" = "1" /* Removal of Autologous Tissue Substitute from Left Rib, Percutaneous Endoscopic Approach */
"0PP24JZ" = "1" /* Removal of Synthetic Substitute from Left Rib, Percutaneous Endoscopic Approach */
"0PP24KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Rib, Percutaneous Endoscopic Approach */
"0PP304Z" = "1" /* Removal of Internal Fixation Device from Cervical Vertebra, Open Approach */
"0PP307Z" = "1" /* Removal of Autologous Tissue Substitute from Cervical Vertebra, Open Approach */
"0PP30JZ" = "1" /* Removal of Synthetic Substitute from Cervical Vertebra, Open Approach */
"0PP30KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Cervical Vertebra, Open Approach */
"0PP334Z" = "1" /* Removal of Internal Fixation Device from Cervical Vertebra, Percutaneous Approach */
"0PP337Z" = "1" /* Removal of Autologous Tissue Substitute from Cervical Vertebra, Percutaneous Approach */
"0PP33JZ" = "1" /* Removal of Synthetic Substitute from Cervical Vertebra, Percutaneous Approach */
"0PP33KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Cervical Vertebra, Percutaneous Approach */
"0PP344Z" = "1" /* Removal of Internal Fixation Device from Cervical Vertebra, Percutaneous Endoscopic Approach */
"0PP347Z" = "1" /* Removal of Autologous Tissue Substitute from Cervical Vertebra, Percutaneous Endoscopic Approach */
"0PP34JZ" = "1" /* Removal of Synthetic Substitute from Cervical Vertebra, Percutaneous Endoscopic Approach */
"0PP34KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Cervical Vertebra, Percutaneous Endoscopic Approach */
"0PP404Z" = "1" /* Removal of Internal Fixation Device from Thoracic Vertebra, Open Approach */
"0PP407Z" = "1" /* Removal of Autologous Tissue Substitute from Thoracic Vertebra, Open Approach */
"0PP40JZ" = "1" /* Removal of Synthetic Substitute from Thoracic Vertebra, Open Approach */
"0PP40KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Thoracic Vertebra, Open Approach */
"0PP434Z" = "1" /* Removal of Internal Fixation Device from Thoracic Vertebra, Percutaneous Approach */
"0PP437Z" = "1" /* Removal of Autologous Tissue Substitute from Thoracic Vertebra, Percutaneous Approach */
"0PP43JZ" = "1" /* Removal of Synthetic Substitute from Thoracic Vertebra, Percutaneous Approach */
"0PP43KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Thoracic Vertebra, Percutaneous Approach */
"0PP444Z" = "1" /* Removal of Internal Fixation Device from Thoracic Vertebra, Percutaneous Endoscopic Approach */
"0PP447Z" = "1" /* Removal of Autologous Tissue Substitute from Thoracic Vertebra, Percutaneous Endoscopic Approach */
"0PP44JZ" = "1" /* Removal of Synthetic Substitute from Thoracic Vertebra, Percutaneous Endoscopic Approach */
"0PP44KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Thoracic Vertebra, Percutaneous Endoscopic Approach */
"0PP504Z" = "1" /* Removal of Internal Fixation Device from Right Scapula, Open Approach */
"0PP507Z" = "1" /* Removal of Autologous Tissue Substitute from Right Scapula, Open Approach */
"0PP50JZ" = "1" /* Removal of Synthetic Substitute from Right Scapula, Open Approach */
"0PP50KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Scapula, Open Approach */
"0PP534Z" = "1" /* Removal of Internal Fixation Device from Right Scapula, Percutaneous Approach */
"0PP537Z" = "1" /* Removal of Autologous Tissue Substitute from Right Scapula, Percutaneous Approach */
"0PP53JZ" = "1" /* Removal of Synthetic Substitute from Right Scapula, Percutaneous Approach */
"0PP53KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Scapula, Percutaneous Approach */
"0PP544Z" = "1" /* Removal of Internal Fixation Device from Right Scapula, Percutaneous Endoscopic Approach */
"0PP547Z" = "1" /* Removal of Autologous Tissue Substitute from Right Scapula, Percutaneous Endoscopic Approach */
"0PP54JZ" = "1" /* Removal of Synthetic Substitute from Right Scapula, Percutaneous Endoscopic Approach */
"0PP54KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Scapula, Percutaneous Endoscopic Approach */
"0PP604Z" = "1" /* Removal of Internal Fixation Device from Left Scapula, Open Approach */
"0PP607Z" = "1" /* Removal of Autologous Tissue Substitute from Left Scapula, Open Approach */
"0PP60JZ" = "1" /* Removal of Synthetic Substitute from Left Scapula, Open Approach */
"0PP60KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Scapula, Open Approach */
"0PP634Z" = "1" /* Removal of Internal Fixation Device from Left Scapula, Percutaneous Approach */
"0PP637Z" = "1" /* Removal of Autologous Tissue Substitute from Left Scapula, Percutaneous Approach */
"0PP63JZ" = "1" /* Removal of Synthetic Substitute from Left Scapula, Percutaneous Approach */
"0PP63KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Scapula, Percutaneous Approach */
"0PP644Z" = "1" /* Removal of Internal Fixation Device from Left Scapula, Percutaneous Endoscopic Approach */
"0PP647Z" = "1" /* Removal of Autologous Tissue Substitute from Left Scapula, Percutaneous Endoscopic Approach */
"0PP64JZ" = "1" /* Removal of Synthetic Substitute from Left Scapula, Percutaneous Endoscopic Approach */
"0PP64KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Scapula, Percutaneous Endoscopic Approach */
"0PP704Z" = "1" /* Removal of Internal Fixation Device from Right Glenoid Cavity, Open Approach */
"0PP707Z" = "1" /* Removal of Autologous Tissue Substitute from Right Glenoid Cavity, Open Approach */
"0PP70JZ" = "1" /* Removal of Synthetic Substitute from Right Glenoid Cavity, Open Approach */
"0PP70KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Glenoid Cavity, Open Approach */
"0PP734Z" = "1" /* Removal of Internal Fixation Device from Right Glenoid Cavity, Percutaneous Approach */
"0PP737Z" = "1" /* Removal of Autologous Tissue Substitute from Right Glenoid Cavity, Percutaneous Approach */
"0PP73JZ" = "1" /* Removal of Synthetic Substitute from Right Glenoid Cavity, Percutaneous Approach */
"0PP73KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Glenoid Cavity, Percutaneous Approach */
"0PP744Z" = "1" /* Removal of Internal Fixation Device from Right Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PP747Z" = "1" /* Removal of Autologous Tissue Substitute from Right Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PP74JZ" = "1" /* Removal of Synthetic Substitute from Right Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PP74KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PP804Z" = "1" /* Removal of Internal Fixation Device from Left Glenoid Cavity, Open Approach */
"0PP807Z" = "1" /* Removal of Autologous Tissue Substitute from Left Glenoid Cavity, Open Approach */
"0PP80JZ" = "1" /* Removal of Synthetic Substitute from Left Glenoid Cavity, Open Approach */
"0PP80KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Glenoid Cavity, Open Approach */
"0PP834Z" = "1" /* Removal of Internal Fixation Device from Left Glenoid Cavity, Percutaneous Approach */
"0PP837Z" = "1" /* Removal of Autologous Tissue Substitute from Left Glenoid Cavity, Percutaneous Approach */
"0PP83JZ" = "1" /* Removal of Synthetic Substitute from Left Glenoid Cavity, Percutaneous Approach */
"0PP83KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Glenoid Cavity, Percutaneous Approach */
"0PP844Z" = "1" /* Removal of Internal Fixation Device from Left Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PP847Z" = "1" /* Removal of Autologous Tissue Substitute from Left Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PP84JZ" = "1" /* Removal of Synthetic Substitute from Left Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PP84KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PP904Z" = "1" /* Removal of Internal Fixation Device from Right Clavicle, Open Approach */
"0PP907Z" = "1" /* Removal of Autologous Tissue Substitute from Right Clavicle, Open Approach */
"0PP90JZ" = "1" /* Removal of Synthetic Substitute from Right Clavicle, Open Approach */
"0PP90KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Clavicle, Open Approach */
"0PP934Z" = "1" /* Removal of Internal Fixation Device from Right Clavicle, Percutaneous Approach */
"0PP937Z" = "1" /* Removal of Autologous Tissue Substitute from Right Clavicle, Percutaneous Approach */
"0PP93JZ" = "1" /* Removal of Synthetic Substitute from Right Clavicle, Percutaneous Approach */
"0PP93KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Clavicle, Percutaneous Approach */
"0PP944Z" = "1" /* Removal of Internal Fixation Device from Right Clavicle, Percutaneous Endoscopic Approach */
"0PP947Z" = "1" /* Removal of Autologous Tissue Substitute from Right Clavicle, Percutaneous Endoscopic Approach */
"0PP94JZ" = "1" /* Removal of Synthetic Substitute from Right Clavicle, Percutaneous Endoscopic Approach */
"0PP94KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Clavicle, Percutaneous Endoscopic Approach */
"0PPB04Z" = "1" /* Removal of Internal Fixation Device from Left Clavicle, Open Approach */
"0PPB07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Clavicle, Open Approach */
"0PPB0JZ" = "1" /* Removal of Synthetic Substitute from Left Clavicle, Open Approach */
"0PPB0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Clavicle, Open Approach */
"0PPB34Z" = "1" /* Removal of Internal Fixation Device from Left Clavicle, Percutaneous Approach */
"0PPB37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Clavicle, Percutaneous Approach */
"0PPB3JZ" = "1" /* Removal of Synthetic Substitute from Left Clavicle, Percutaneous Approach */
"0PPB3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Clavicle, Percutaneous Approach */
"0PPB44Z" = "1" /* Removal of Internal Fixation Device from Left Clavicle, Percutaneous Endoscopic Approach */
"0PPB47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Clavicle, Percutaneous Endoscopic Approach */
"0PPB4JZ" = "1" /* Removal of Synthetic Substitute from Left Clavicle, Percutaneous Endoscopic Approach */
"0PPB4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Clavicle, Percutaneous Endoscopic Approach */
"0PPC04Z" = "1" /* Removal of Internal Fixation Device from Right Humeral Head, Open Approach */
"0PPC05Z" = "1" /* Removal of External Fixation Device from Right Humeral Head, Open Approach */
"0PPC07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Humeral Head, Open Approach */
"0PPC0JZ" = "1" /* Removal of Synthetic Substitute from Right Humeral Head, Open Approach */
"0PPC0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Humeral Head, Open Approach */
"0PPC34Z" = "1" /* Removal of Internal Fixation Device from Right Humeral Head, Percutaneous Approach */
"0PPC35Z" = "1" /* Removal of External Fixation Device from Right Humeral Head, Percutaneous Approach */
"0PPC37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Humeral Head, Percutaneous Approach */
"0PPC3JZ" = "1" /* Removal of Synthetic Substitute from Right Humeral Head, Percutaneous Approach */
"0PPC3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Humeral Head, Percutaneous Approach */
"0PPC44Z" = "1" /* Removal of Internal Fixation Device from Right Humeral Head, Percutaneous Endoscopic Approach */
"0PPC45Z" = "1" /* Removal of External Fixation Device from Right Humeral Head, Percutaneous Endoscopic Approach */
"0PPC47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Humeral Head, Percutaneous Endoscopic Approach */
"0PPC4JZ" = "1" /* Removal of Synthetic Substitute from Right Humeral Head, Percutaneous Endoscopic Approach */
"0PPC4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Humeral Head, Percutaneous Endoscopic Approach */
"0PPD04Z" = "1" /* Removal of Internal Fixation Device from Left Humeral Head, Open Approach */
"0PPD05Z" = "1" /* Removal of External Fixation Device from Left Humeral Head, Open Approach */
"0PPD07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Humeral Head, Open Approach */
"0PPD0JZ" = "1" /* Removal of Synthetic Substitute from Left Humeral Head, Open Approach */
"0PPD0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Humeral Head, Open Approach */
"0PPD34Z" = "1" /* Removal of Internal Fixation Device from Left Humeral Head, Percutaneous Approach */
"0PPD35Z" = "1" /* Removal of External Fixation Device from Left Humeral Head, Percutaneous Approach */
"0PPD37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Humeral Head, Percutaneous Approach */
"0PPD3JZ" = "1" /* Removal of Synthetic Substitute from Left Humeral Head, Percutaneous Approach */
"0PPD3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Humeral Head, Percutaneous Approach */
"0PPD44Z" = "1" /* Removal of Internal Fixation Device from Left Humeral Head, Percutaneous Endoscopic Approach */
"0PPD45Z" = "1" /* Removal of External Fixation Device from Left Humeral Head, Percutaneous Endoscopic Approach */
"0PPD47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Humeral Head, Percutaneous Endoscopic Approach */
"0PPD4JZ" = "1" /* Removal of Synthetic Substitute from Left Humeral Head, Percutaneous Endoscopic Approach */
"0PPD4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Humeral Head, Percutaneous Endoscopic Approach */
"0PPF04Z" = "1" /* Removal of Internal Fixation Device from Right Humeral Shaft, Open Approach */
"0PPF05Z" = "1" /* Removal of External Fixation Device from Right Humeral Shaft, Open Approach */
"0PPF07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Humeral Shaft, Open Approach */
"0PPF0JZ" = "1" /* Removal of Synthetic Substitute from Right Humeral Shaft, Open Approach */
"0PPF0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Humeral Shaft, Open Approach */
"0PPF34Z" = "1" /* Removal of Internal Fixation Device from Right Humeral Shaft, Percutaneous Approach */
"0PPF35Z" = "1" /* Removal of External Fixation Device from Right Humeral Shaft, Percutaneous Approach */
"0PPF37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Humeral Shaft, Percutaneous Approach */
"0PPF3JZ" = "1" /* Removal of Synthetic Substitute from Right Humeral Shaft, Percutaneous Approach */
"0PPF3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Humeral Shaft, Percutaneous Approach */
"0PPF44Z" = "1" /* Removal of Internal Fixation Device from Right Humeral Shaft, Percutaneous Endoscopic Approach */
"0PPF45Z" = "1" /* Removal of External Fixation Device from Right Humeral Shaft, Percutaneous Endoscopic Approach */
"0PPF47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Humeral Shaft, Percutaneous Endoscopic Approach */
"0PPF4JZ" = "1" /* Removal of Synthetic Substitute from Right Humeral Shaft, Percutaneous Endoscopic Approach */
"0PPF4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Humeral Shaft, Percutaneous Endoscopic Approach */
"0PPG04Z" = "1" /* Removal of Internal Fixation Device from Left Humeral Shaft, Open Approach */
"0PPG05Z" = "1" /* Removal of External Fixation Device from Left Humeral Shaft, Open Approach */
"0PPG07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Humeral Shaft, Open Approach */
"0PPG0JZ" = "1" /* Removal of Synthetic Substitute from Left Humeral Shaft, Open Approach */
"0PPG0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Humeral Shaft, Open Approach */
"0PPG34Z" = "1" /* Removal of Internal Fixation Device from Left Humeral Shaft, Percutaneous Approach */
"0PPG35Z" = "1" /* Removal of External Fixation Device from Left Humeral Shaft, Percutaneous Approach */
"0PPG37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Humeral Shaft, Percutaneous Approach */
"0PPG3JZ" = "1" /* Removal of Synthetic Substitute from Left Humeral Shaft, Percutaneous Approach */
"0PPG3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Humeral Shaft, Percutaneous Approach */
"0PPG44Z" = "1" /* Removal of Internal Fixation Device from Left Humeral Shaft, Percutaneous Endoscopic Approach */
"0PPG45Z" = "1" /* Removal of External Fixation Device from Left Humeral Shaft, Percutaneous Endoscopic Approach */
"0PPG47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Humeral Shaft, Percutaneous Endoscopic Approach */
"0PPG4JZ" = "1" /* Removal of Synthetic Substitute from Left Humeral Shaft, Percutaneous Endoscopic Approach */
"0PPG4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Humeral Shaft, Percutaneous Endoscopic Approach */
"0PPH04Z" = "1" /* Removal of Internal Fixation Device from Right Radius, Open Approach */
"0PPH05Z" = "1" /* Removal of External Fixation Device from Right Radius, Open Approach */
"0PPH07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Radius, Open Approach */
"0PPH0JZ" = "1" /* Removal of Synthetic Substitute from Right Radius, Open Approach */
"0PPH0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Radius, Open Approach */
"0PPH34Z" = "1" /* Removal of Internal Fixation Device from Right Radius, Percutaneous Approach */
"0PPH35Z" = "1" /* Removal of External Fixation Device from Right Radius, Percutaneous Approach */
"0PPH37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Radius, Percutaneous Approach */
"0PPH3JZ" = "1" /* Removal of Synthetic Substitute from Right Radius, Percutaneous Approach */
"0PPH3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Radius, Percutaneous Approach */
"0PPH44Z" = "1" /* Removal of Internal Fixation Device from Right Radius, Percutaneous Endoscopic Approach */
"0PPH45Z" = "1" /* Removal of External Fixation Device from Right Radius, Percutaneous Endoscopic Approach */
"0PPH47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Radius, Percutaneous Endoscopic Approach */
"0PPH4JZ" = "1" /* Removal of Synthetic Substitute from Right Radius, Percutaneous Endoscopic Approach */
"0PPH4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Radius, Percutaneous Endoscopic Approach */
"0PPJ04Z" = "1" /* Removal of Internal Fixation Device from Left Radius, Open Approach */
"0PPJ05Z" = "1" /* Removal of External Fixation Device from Left Radius, Open Approach */
"0PPJ07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Radius, Open Approach */
"0PPJ0JZ" = "1" /* Removal of Synthetic Substitute from Left Radius, Open Approach */
"0PPJ0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Radius, Open Approach */
"0PPJ34Z" = "1" /* Removal of Internal Fixation Device from Left Radius, Percutaneous Approach */
"0PPJ35Z" = "1" /* Removal of External Fixation Device from Left Radius, Percutaneous Approach */
"0PPJ37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Radius, Percutaneous Approach */
"0PPJ3JZ" = "1" /* Removal of Synthetic Substitute from Left Radius, Percutaneous Approach */
"0PPJ3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Radius, Percutaneous Approach */
"0PPJ44Z" = "1" /* Removal of Internal Fixation Device from Left Radius, Percutaneous Endoscopic Approach */
"0PPJ45Z" = "1" /* Removal of External Fixation Device from Left Radius, Percutaneous Endoscopic Approach */
"0PPJ47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Radius, Percutaneous Endoscopic Approach */
"0PPJ4JZ" = "1" /* Removal of Synthetic Substitute from Left Radius, Percutaneous Endoscopic Approach */
"0PPJ4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Radius, Percutaneous Endoscopic Approach */
"0PPK04Z" = "1" /* Removal of Internal Fixation Device from Right Ulna, Open Approach */
"0PPK05Z" = "1" /* Removal of External Fixation Device from Right Ulna, Open Approach */
"0PPK07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Ulna, Open Approach */
"0PPK0JZ" = "1" /* Removal of Synthetic Substitute from Right Ulna, Open Approach */
"0PPK0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Ulna, Open Approach */
"0PPK34Z" = "1" /* Removal of Internal Fixation Device from Right Ulna, Percutaneous Approach */
"0PPK35Z" = "1" /* Removal of External Fixation Device from Right Ulna, Percutaneous Approach */
"0PPK37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Ulna, Percutaneous Approach */
"0PPK3JZ" = "1" /* Removal of Synthetic Substitute from Right Ulna, Percutaneous Approach */
"0PPK3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Ulna, Percutaneous Approach */
"0PPK44Z" = "1" /* Removal of Internal Fixation Device from Right Ulna, Percutaneous Endoscopic Approach */
"0PPK45Z" = "1" /* Removal of External Fixation Device from Right Ulna, Percutaneous Endoscopic Approach */
"0PPK47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Ulna, Percutaneous Endoscopic Approach */
"0PPK4JZ" = "1" /* Removal of Synthetic Substitute from Right Ulna, Percutaneous Endoscopic Approach */
"0PPK4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Ulna, Percutaneous Endoscopic Approach */
"0PPL04Z" = "1" /* Removal of Internal Fixation Device from Left Ulna, Open Approach */
"0PPL05Z" = "1" /* Removal of External Fixation Device from Left Ulna, Open Approach */
"0PPL07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Ulna, Open Approach */
"0PPL0JZ" = "1" /* Removal of Synthetic Substitute from Left Ulna, Open Approach */
"0PPL0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Ulna, Open Approach */
"0PPL34Z" = "1" /* Removal of Internal Fixation Device from Left Ulna, Percutaneous Approach */
"0PPL35Z" = "1" /* Removal of External Fixation Device from Left Ulna, Percutaneous Approach */
"0PPL37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Ulna, Percutaneous Approach */
"0PPL3JZ" = "1" /* Removal of Synthetic Substitute from Left Ulna, Percutaneous Approach */
"0PPL3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Ulna, Percutaneous Approach */
"0PPL44Z" = "1" /* Removal of Internal Fixation Device from Left Ulna, Percutaneous Endoscopic Approach */
"0PPL45Z" = "1" /* Removal of External Fixation Device from Left Ulna, Percutaneous Endoscopic Approach */
"0PPL47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Ulna, Percutaneous Endoscopic Approach */
"0PPL4JZ" = "1" /* Removal of Synthetic Substitute from Left Ulna, Percutaneous Endoscopic Approach */
"0PPL4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Ulna, Percutaneous Endoscopic Approach */
"0PPM04Z" = "1" /* Removal of Internal Fixation Device from Right Carpal, Open Approach */
"0PPM05Z" = "1" /* Removal of External Fixation Device from Right Carpal, Open Approach */
"0PPM07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Carpal, Open Approach */
"0PPM0JZ" = "1" /* Removal of Synthetic Substitute from Right Carpal, Open Approach */
"0PPM0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Carpal, Open Approach */
"0PPM34Z" = "1" /* Removal of Internal Fixation Device from Right Carpal, Percutaneous Approach */
"0PPM35Z" = "1" /* Removal of External Fixation Device from Right Carpal, Percutaneous Approach */
"0PPM37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Carpal, Percutaneous Approach */
"0PPM3JZ" = "1" /* Removal of Synthetic Substitute from Right Carpal, Percutaneous Approach */
"0PPM3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Carpal, Percutaneous Approach */
"0PPM44Z" = "1" /* Removal of Internal Fixation Device from Right Carpal, Percutaneous Endoscopic Approach */
"0PPM45Z" = "1" /* Removal of External Fixation Device from Right Carpal, Percutaneous Endoscopic Approach */
"0PPM47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Carpal, Percutaneous Endoscopic Approach */
"0PPM4JZ" = "1" /* Removal of Synthetic Substitute from Right Carpal, Percutaneous Endoscopic Approach */
"0PPM4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Carpal, Percutaneous Endoscopic Approach */
"0PPN04Z" = "1" /* Removal of Internal Fixation Device from Left Carpal, Open Approach */
"0PPN05Z" = "1" /* Removal of External Fixation Device from Left Carpal, Open Approach */
"0PPN07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Carpal, Open Approach */
"0PPN0JZ" = "1" /* Removal of Synthetic Substitute from Left Carpal, Open Approach */
"0PPN0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Carpal, Open Approach */
"0PPN34Z" = "1" /* Removal of Internal Fixation Device from Left Carpal, Percutaneous Approach */
"0PPN35Z" = "1" /* Removal of External Fixation Device from Left Carpal, Percutaneous Approach */
"0PPN37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Carpal, Percutaneous Approach */
"0PPN3JZ" = "1" /* Removal of Synthetic Substitute from Left Carpal, Percutaneous Approach */
"0PPN3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Carpal, Percutaneous Approach */
"0PPN44Z" = "1" /* Removal of Internal Fixation Device from Left Carpal, Percutaneous Endoscopic Approach */
"0PPN45Z" = "1" /* Removal of External Fixation Device from Left Carpal, Percutaneous Endoscopic Approach */
"0PPN47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Carpal, Percutaneous Endoscopic Approach */
"0PPN4JZ" = "1" /* Removal of Synthetic Substitute from Left Carpal, Percutaneous Endoscopic Approach */
"0PPN4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Carpal, Percutaneous Endoscopic Approach */
"0PPP04Z" = "1" /* Removal of Internal Fixation Device from Right Metacarpal, Open Approach */
"0PPP05Z" = "1" /* Removal of External Fixation Device from Right Metacarpal, Open Approach */
"0PPP07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Metacarpal, Open Approach */
"0PPP0JZ" = "1" /* Removal of Synthetic Substitute from Right Metacarpal, Open Approach */
"0PPP0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Metacarpal, Open Approach */
"0PPP34Z" = "1" /* Removal of Internal Fixation Device from Right Metacarpal, Percutaneous Approach */
"0PPP35Z" = "1" /* Removal of External Fixation Device from Right Metacarpal, Percutaneous Approach */
"0PPP37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Metacarpal, Percutaneous Approach */
"0PPP3JZ" = "1" /* Removal of Synthetic Substitute from Right Metacarpal, Percutaneous Approach */
"0PPP3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Metacarpal, Percutaneous Approach */
"0PPP44Z" = "1" /* Removal of Internal Fixation Device from Right Metacarpal, Percutaneous Endoscopic Approach */
"0PPP45Z" = "1" /* Removal of External Fixation Device from Right Metacarpal, Percutaneous Endoscopic Approach */
"0PPP47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Metacarpal, Percutaneous Endoscopic Approach */
"0PPP4JZ" = "1" /* Removal of Synthetic Substitute from Right Metacarpal, Percutaneous Endoscopic Approach */
"0PPP4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Metacarpal, Percutaneous Endoscopic Approach */
"0PPQ04Z" = "1" /* Removal of Internal Fixation Device from Left Metacarpal, Open Approach */
"0PPQ05Z" = "1" /* Removal of External Fixation Device from Left Metacarpal, Open Approach */
"0PPQ07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Metacarpal, Open Approach */
"0PPQ0JZ" = "1" /* Removal of Synthetic Substitute from Left Metacarpal, Open Approach */
"0PPQ0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Metacarpal, Open Approach */
"0PPQ34Z" = "1" /* Removal of Internal Fixation Device from Left Metacarpal, Percutaneous Approach */
"0PPQ35Z" = "1" /* Removal of External Fixation Device from Left Metacarpal, Percutaneous Approach */
"0PPQ37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Metacarpal, Percutaneous Approach */
"0PPQ3JZ" = "1" /* Removal of Synthetic Substitute from Left Metacarpal, Percutaneous Approach */
"0PPQ3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Metacarpal, Percutaneous Approach */
"0PPQ44Z" = "1" /* Removal of Internal Fixation Device from Left Metacarpal, Percutaneous Endoscopic Approach */
"0PPQ45Z" = "1" /* Removal of External Fixation Device from Left Metacarpal, Percutaneous Endoscopic Approach */
"0PPQ47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Metacarpal, Percutaneous Endoscopic Approach */
"0PPQ4JZ" = "1" /* Removal of Synthetic Substitute from Left Metacarpal, Percutaneous Endoscopic Approach */
"0PPQ4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Metacarpal, Percutaneous Endoscopic Approach */
"0PPR04Z" = "1" /* Removal of Internal Fixation Device from Right Thumb Phalanx, Open Approach */
"0PPR05Z" = "1" /* Removal of External Fixation Device from Right Thumb Phalanx, Open Approach */
"0PPR07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Thumb Phalanx, Open Approach */
"0PPR0JZ" = "1" /* Removal of Synthetic Substitute from Right Thumb Phalanx, Open Approach */
"0PPR0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Thumb Phalanx, Open Approach */
"0PPR34Z" = "1" /* Removal of Internal Fixation Device from Right Thumb Phalanx, Percutaneous Approach */
"0PPR35Z" = "1" /* Removal of External Fixation Device from Right Thumb Phalanx, Percutaneous Approach */
"0PPR37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Thumb Phalanx, Percutaneous Approach */
"0PPR3JZ" = "1" /* Removal of Synthetic Substitute from Right Thumb Phalanx, Percutaneous Approach */
"0PPR3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Thumb Phalanx, Percutaneous Approach */
"0PPR44Z" = "1" /* Removal of Internal Fixation Device from Right Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PPR45Z" = "1" /* Removal of External Fixation Device from Right Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PPR47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PPR4JZ" = "1" /* Removal of Synthetic Substitute from Right Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PPR4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PPS04Z" = "1" /* Removal of Internal Fixation Device from Left Thumb Phalanx, Open Approach */
"0PPS05Z" = "1" /* Removal of External Fixation Device from Left Thumb Phalanx, Open Approach */
"0PPS07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Thumb Phalanx, Open Approach */
"0PPS0JZ" = "1" /* Removal of Synthetic Substitute from Left Thumb Phalanx, Open Approach */
"0PPS0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Thumb Phalanx, Open Approach */
"0PPS34Z" = "1" /* Removal of Internal Fixation Device from Left Thumb Phalanx, Percutaneous Approach */
"0PPS35Z" = "1" /* Removal of External Fixation Device from Left Thumb Phalanx, Percutaneous Approach */
"0PPS37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Thumb Phalanx, Percutaneous Approach */
"0PPS3JZ" = "1" /* Removal of Synthetic Substitute from Left Thumb Phalanx, Percutaneous Approach */
"0PPS3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Thumb Phalanx, Percutaneous Approach */
"0PPS44Z" = "1" /* Removal of Internal Fixation Device from Left Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PPS45Z" = "1" /* Removal of External Fixation Device from Left Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PPS47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PPS4JZ" = "1" /* Removal of Synthetic Substitute from Left Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PPS4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PPT04Z" = "1" /* Removal of Internal Fixation Device from Right Finger Phalanx, Open Approach */
"0PPT05Z" = "1" /* Removal of External Fixation Device from Right Finger Phalanx, Open Approach */
"0PPT07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Finger Phalanx, Open Approach */
"0PPT0JZ" = "1" /* Removal of Synthetic Substitute from Right Finger Phalanx, Open Approach */
"0PPT0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Finger Phalanx, Open Approach */
"0PPT34Z" = "1" /* Removal of Internal Fixation Device from Right Finger Phalanx, Percutaneous Approach */
"0PPT35Z" = "1" /* Removal of External Fixation Device from Right Finger Phalanx, Percutaneous Approach */
"0PPT37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Finger Phalanx, Percutaneous Approach */
"0PPT3JZ" = "1" /* Removal of Synthetic Substitute from Right Finger Phalanx, Percutaneous Approach */
"0PPT3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Finger Phalanx, Percutaneous Approach */
"0PPT44Z" = "1" /* Removal of Internal Fixation Device from Right Finger Phalanx, Percutaneous Endoscopic Approach */
"0PPT45Z" = "1" /* Removal of External Fixation Device from Right Finger Phalanx, Percutaneous Endoscopic Approach */
"0PPT47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Finger Phalanx, Percutaneous Endoscopic Approach */
"0PPT4JZ" = "1" /* Removal of Synthetic Substitute from Right Finger Phalanx, Percutaneous Endoscopic Approach */
"0PPT4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Finger Phalanx, Percutaneous Endoscopic Approach */
"0PPV04Z" = "1" /* Removal of Internal Fixation Device from Left Finger Phalanx, Open Approach */
"0PPV05Z" = "1" /* Removal of External Fixation Device from Left Finger Phalanx, Open Approach */
"0PPV07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Finger Phalanx, Open Approach */
"0PPV0JZ" = "1" /* Removal of Synthetic Substitute from Left Finger Phalanx, Open Approach */
"0PPV0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Finger Phalanx, Open Approach */
"0PPV34Z" = "1" /* Removal of Internal Fixation Device from Left Finger Phalanx, Percutaneous Approach */
"0PPV35Z" = "1" /* Removal of External Fixation Device from Left Finger Phalanx, Percutaneous Approach */
"0PPV37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Finger Phalanx, Percutaneous Approach */
"0PPV3JZ" = "1" /* Removal of Synthetic Substitute from Left Finger Phalanx, Percutaneous Approach */
"0PPV3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Finger Phalanx, Percutaneous Approach */
"0PPV44Z" = "1" /* Removal of Internal Fixation Device from Left Finger Phalanx, Percutaneous Endoscopic Approach */
"0PPV45Z" = "1" /* Removal of External Fixation Device from Left Finger Phalanx, Percutaneous Endoscopic Approach */
"0PPV47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Finger Phalanx, Percutaneous Endoscopic Approach */
"0PPV4JZ" = "1" /* Removal of Synthetic Substitute from Left Finger Phalanx, Percutaneous Endoscopic Approach */
"0PPV4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Finger Phalanx, Percutaneous Endoscopic Approach */
"0PPY00Z" = "1" /* Removal of Drainage Device from Upper Bone, Open Approach */
"0PPY0MZ" = "1" /* Removal of Bone Growth Stimulator from Upper Bone, Open Approach */
"0PPY3MZ" = "1" /* Removal of Bone Growth Stimulator from Upper Bone, Percutaneous Approach */
"0PPY40Z" = "1" /* Removal of Drainage Device from Upper Bone, Percutaneous Endoscopic Approach */
"0PPY4MZ" = "1" /* Removal of Bone Growth Stimulator from Upper Bone, Percutaneous Endoscopic Approach */
"0PQ00ZZ" = "1" /* Repair Sternum, Open Approach */
"0PQ03ZZ" = "1" /* Repair Sternum, Percutaneous Approach */
"0PQ04ZZ" = "1" /* Repair Sternum, Percutaneous Endoscopic Approach */
"0PQ10ZZ" = "1" /* Repair Right Rib, Open Approach */
"0PQ13ZZ" = "1" /* Repair Right Rib, Percutaneous Approach */
"0PQ14ZZ" = "1" /* Repair Right Rib, Percutaneous Endoscopic Approach */
"0PQ20ZZ" = "1" /* Repair Left Rib, Open Approach */
"0PQ23ZZ" = "1" /* Repair Left Rib, Percutaneous Approach */
"0PQ24ZZ" = "1" /* Repair Left Rib, Percutaneous Endoscopic Approach */
"0PQ30ZZ" = "1" /* Repair Cervical Vertebra, Open Approach */
"0PQ33ZZ" = "1" /* Repair Cervical Vertebra, Percutaneous Approach */
"0PQ34ZZ" = "1" /* Repair Cervical Vertebra, Percutaneous Endoscopic Approach */
"0PQ40ZZ" = "1" /* Repair Thoracic Vertebra, Open Approach */
"0PQ43ZZ" = "1" /* Repair Thoracic Vertebra, Percutaneous Approach */
"0PQ44ZZ" = "1" /* Repair Thoracic Vertebra, Percutaneous Endoscopic Approach */
"0PQ50ZZ" = "1" /* Repair Right Scapula, Open Approach */
"0PQ53ZZ" = "1" /* Repair Right Scapula, Percutaneous Approach */
"0PQ54ZZ" = "1" /* Repair Right Scapula, Percutaneous Endoscopic Approach */
"0PQ60ZZ" = "1" /* Repair Left Scapula, Open Approach */
"0PQ63ZZ" = "1" /* Repair Left Scapula, Percutaneous Approach */
"0PQ64ZZ" = "1" /* Repair Left Scapula, Percutaneous Endoscopic Approach */
"0PQ70ZZ" = "1" /* Repair Right Glenoid Cavity, Open Approach */
"0PQ73ZZ" = "1" /* Repair Right Glenoid Cavity, Percutaneous Approach */
"0PQ74ZZ" = "1" /* Repair Right Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PQ80ZZ" = "1" /* Repair Left Glenoid Cavity, Open Approach */
"0PQ83ZZ" = "1" /* Repair Left Glenoid Cavity, Percutaneous Approach */
"0PQ84ZZ" = "1" /* Repair Left Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PQ90ZZ" = "1" /* Repair Right Clavicle, Open Approach */
"0PQ93ZZ" = "1" /* Repair Right Clavicle, Percutaneous Approach */
"0PQ94ZZ" = "1" /* Repair Right Clavicle, Percutaneous Endoscopic Approach */
"0PQB0ZZ" = "1" /* Repair Left Clavicle, Open Approach */
"0PQB3ZZ" = "1" /* Repair Left Clavicle, Percutaneous Approach */
"0PQB4ZZ" = "1" /* Repair Left Clavicle, Percutaneous Endoscopic Approach */
"0PQC0ZZ" = "1" /* Repair Right Humeral Head, Open Approach */
"0PQC3ZZ" = "1" /* Repair Right Humeral Head, Percutaneous Approach */
"0PQC4ZZ" = "1" /* Repair Right Humeral Head, Percutaneous Endoscopic Approach */
"0PQD0ZZ" = "1" /* Repair Left Humeral Head, Open Approach */
"0PQD3ZZ" = "1" /* Repair Left Humeral Head, Percutaneous Approach */
"0PQD4ZZ" = "1" /* Repair Left Humeral Head, Percutaneous Endoscopic Approach */
"0PQF0ZZ" = "1" /* Repair Right Humeral Shaft, Open Approach */
"0PQF3ZZ" = "1" /* Repair Right Humeral Shaft, Percutaneous Approach */
"0PQF4ZZ" = "1" /* Repair Right Humeral Shaft, Percutaneous Endoscopic Approach */
"0PQG0ZZ" = "1" /* Repair Left Humeral Shaft, Open Approach */
"0PQG3ZZ" = "1" /* Repair Left Humeral Shaft, Percutaneous Approach */
"0PQG4ZZ" = "1" /* Repair Left Humeral Shaft, Percutaneous Endoscopic Approach */
"0PQH0ZZ" = "1" /* Repair Right Radius, Open Approach */
"0PQH3ZZ" = "1" /* Repair Right Radius, Percutaneous Approach */
"0PQH4ZZ" = "1" /* Repair Right Radius, Percutaneous Endoscopic Approach */
"0PQJ0ZZ" = "1" /* Repair Left Radius, Open Approach */
"0PQJ3ZZ" = "1" /* Repair Left Radius, Percutaneous Approach */
"0PQJ4ZZ" = "1" /* Repair Left Radius, Percutaneous Endoscopic Approach */
"0PQK0ZZ" = "1" /* Repair Right Ulna, Open Approach */
"0PQK3ZZ" = "1" /* Repair Right Ulna, Percutaneous Approach */
"0PQK4ZZ" = "1" /* Repair Right Ulna, Percutaneous Endoscopic Approach */
"0PQL0ZZ" = "1" /* Repair Left Ulna, Open Approach */
"0PQL3ZZ" = "1" /* Repair Left Ulna, Percutaneous Approach */
"0PQL4ZZ" = "1" /* Repair Left Ulna, Percutaneous Endoscopic Approach */
"0PQM0ZZ" = "1" /* Repair Right Carpal, Open Approach */
"0PQM3ZZ" = "1" /* Repair Right Carpal, Percutaneous Approach */
"0PQM4ZZ" = "1" /* Repair Right Carpal, Percutaneous Endoscopic Approach */
"0PQN0ZZ" = "1" /* Repair Left Carpal, Open Approach */
"0PQN3ZZ" = "1" /* Repair Left Carpal, Percutaneous Approach */
"0PQN4ZZ" = "1" /* Repair Left Carpal, Percutaneous Endoscopic Approach */
"0PQP0ZZ" = "1" /* Repair Right Metacarpal, Open Approach */
"0PQP3ZZ" = "1" /* Repair Right Metacarpal, Percutaneous Approach */
"0PQP4ZZ" = "1" /* Repair Right Metacarpal, Percutaneous Endoscopic Approach */
"0PQQ0ZZ" = "1" /* Repair Left Metacarpal, Open Approach */
"0PQQ3ZZ" = "1" /* Repair Left Metacarpal, Percutaneous Approach */
"0PQQ4ZZ" = "1" /* Repair Left Metacarpal, Percutaneous Endoscopic Approach */
"0PQR0ZZ" = "1" /* Repair Right Thumb Phalanx, Open Approach */
"0PQR3ZZ" = "1" /* Repair Right Thumb Phalanx, Percutaneous Approach */
"0PQR4ZZ" = "1" /* Repair Right Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PQS0ZZ" = "1" /* Repair Left Thumb Phalanx, Open Approach */
"0PQS3ZZ" = "1" /* Repair Left Thumb Phalanx, Percutaneous Approach */
"0PQS4ZZ" = "1" /* Repair Left Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PQT0ZZ" = "1" /* Repair Right Finger Phalanx, Open Approach */
"0PQT3ZZ" = "1" /* Repair Right Finger Phalanx, Percutaneous Approach */
"0PQT4ZZ" = "1" /* Repair Right Finger Phalanx, Percutaneous Endoscopic Approach */
"0PQV0ZZ" = "1" /* Repair Left Finger Phalanx, Open Approach */
"0PQV3ZZ" = "1" /* Repair Left Finger Phalanx, Percutaneous Approach */
"0PQV4ZZ" = "1" /* Repair Left Finger Phalanx, Percutaneous Endoscopic Approach */
"0PR007Z" = "1" /* Replacement of Sternum with Autologous Tissue Substitute, Open Approach */
"0PR00JZ" = "1" /* Replacement of Sternum with Synthetic Substitute, Open Approach */
"0PR00KZ" = "1" /* Replacement of Sternum with Nonautologous Tissue Substitute, Open Approach */
"0PR037Z" = "1" /* Replacement of Sternum with Autologous Tissue Substitute, Percutaneous Approach */
"0PR03JZ" = "1" /* Replacement of Sternum with Synthetic Substitute, Percutaneous Approach */
"0PR03KZ" = "1" /* Replacement of Sternum with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PR047Z" = "1" /* Replacement of Sternum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PR04JZ" = "1" /* Replacement of Sternum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PR04KZ" = "1" /* Replacement of Sternum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PR107Z" = "1" /* Replacement of Right Rib with Autologous Tissue Substitute, Open Approach */
"0PR10JZ" = "1" /* Replacement of Right Rib with Synthetic Substitute, Open Approach */
"0PR10KZ" = "1" /* Replacement of Right Rib with Nonautologous Tissue Substitute, Open Approach */
"0PR137Z" = "1" /* Replacement of Right Rib with Autologous Tissue Substitute, Percutaneous Approach */
"0PR13JZ" = "1" /* Replacement of Right Rib with Synthetic Substitute, Percutaneous Approach */
"0PR13KZ" = "1" /* Replacement of Right Rib with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PR147Z" = "1" /* Replacement of Right Rib with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PR14JZ" = "1" /* Replacement of Right Rib with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PR14KZ" = "1" /* Replacement of Right Rib with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PR207Z" = "1" /* Replacement of Left Rib with Autologous Tissue Substitute, Open Approach */
"0PR20JZ" = "1" /* Replacement of Left Rib with Synthetic Substitute, Open Approach */
"0PR20KZ" = "1" /* Replacement of Left Rib with Nonautologous Tissue Substitute, Open Approach */
"0PR237Z" = "1" /* Replacement of Left Rib with Autologous Tissue Substitute, Percutaneous Approach */
"0PR23JZ" = "1" /* Replacement of Left Rib with Synthetic Substitute, Percutaneous Approach */
"0PR23KZ" = "1" /* Replacement of Left Rib with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PR247Z" = "1" /* Replacement of Left Rib with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PR24JZ" = "1" /* Replacement of Left Rib with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PR24KZ" = "1" /* Replacement of Left Rib with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PR307Z" = "1" /* Replacement of Cervical Vertebra with Autologous Tissue Substitute, Open Approach */
"0PR30JZ" = "1" /* Replacement of Cervical Vertebra with Synthetic Substitute, Open Approach */
"0PR30KZ" = "1" /* Replacement of Cervical Vertebra with Nonautologous Tissue Substitute, Open Approach */
"0PR337Z" = "1" /* Replacement of Cervical Vertebra with Autologous Tissue Substitute, Percutaneous Approach */
"0PR33JZ" = "1" /* Replacement of Cervical Vertebra with Synthetic Substitute, Percutaneous Approach */
"0PR33KZ" = "1" /* Replacement of Cervical Vertebra with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PR347Z" = "1" /* Replacement of Cervical Vertebra with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PR34JZ" = "1" /* Replacement of Cervical Vertebra with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PR34KZ" = "1" /* Replacement of Cervical Vertebra with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PR407Z" = "1" /* Replacement of Thoracic Vertebra with Autologous Tissue Substitute, Open Approach */
"0PR40JZ" = "1" /* Replacement of Thoracic Vertebra with Synthetic Substitute, Open Approach */
"0PR40KZ" = "1" /* Replacement of Thoracic Vertebra with Nonautologous Tissue Substitute, Open Approach */
"0PR437Z" = "1" /* Replacement of Thoracic Vertebra with Autologous Tissue Substitute, Percutaneous Approach */
"0PR43JZ" = "1" /* Replacement of Thoracic Vertebra with Synthetic Substitute, Percutaneous Approach */
"0PR43KZ" = "1" /* Replacement of Thoracic Vertebra with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PR447Z" = "1" /* Replacement of Thoracic Vertebra with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PR44JZ" = "1" /* Replacement of Thoracic Vertebra with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PR44KZ" = "1" /* Replacement of Thoracic Vertebra with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PR507Z" = "1" /* Replacement of Right Scapula with Autologous Tissue Substitute, Open Approach */
"0PR50JZ" = "1" /* Replacement of Right Scapula with Synthetic Substitute, Open Approach */
"0PR50KZ" = "1" /* Replacement of Right Scapula with Nonautologous Tissue Substitute, Open Approach */
"0PR537Z" = "1" /* Replacement of Right Scapula with Autologous Tissue Substitute, Percutaneous Approach */
"0PR53JZ" = "1" /* Replacement of Right Scapula with Synthetic Substitute, Percutaneous Approach */
"0PR53KZ" = "1" /* Replacement of Right Scapula with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PR547Z" = "1" /* Replacement of Right Scapula with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PR54JZ" = "1" /* Replacement of Right Scapula with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PR54KZ" = "1" /* Replacement of Right Scapula with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PR607Z" = "1" /* Replacement of Left Scapula with Autologous Tissue Substitute, Open Approach */
"0PR60JZ" = "1" /* Replacement of Left Scapula with Synthetic Substitute, Open Approach */
"0PR60KZ" = "1" /* Replacement of Left Scapula with Nonautologous Tissue Substitute, Open Approach */
"0PR637Z" = "1" /* Replacement of Left Scapula with Autologous Tissue Substitute, Percutaneous Approach */
"0PR63JZ" = "1" /* Replacement of Left Scapula with Synthetic Substitute, Percutaneous Approach */
"0PR63KZ" = "1" /* Replacement of Left Scapula with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PR647Z" = "1" /* Replacement of Left Scapula with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PR64JZ" = "1" /* Replacement of Left Scapula with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PR64KZ" = "1" /* Replacement of Left Scapula with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PR707Z" = "1" /* Replacement of Right Glenoid Cavity with Autologous Tissue Substitute, Open Approach */
"0PR70JZ" = "1" /* Replacement of Right Glenoid Cavity with Synthetic Substitute, Open Approach */
"0PR70KZ" = "1" /* Replacement of Right Glenoid Cavity with Nonautologous Tissue Substitute, Open Approach */
"0PR737Z" = "1" /* Replacement of Right Glenoid Cavity with Autologous Tissue Substitute, Percutaneous Approach */
"0PR73JZ" = "1" /* Replacement of Right Glenoid Cavity with Synthetic Substitute, Percutaneous Approach */
"0PR73KZ" = "1" /* Replacement of Right Glenoid Cavity with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PR747Z" = "1" /* Replacement of Right Glenoid Cavity with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PR74JZ" = "1" /* Replacement of Right Glenoid Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PR74KZ" = "1" /* Replacement of Right Glenoid Cavity with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PR807Z" = "1" /* Replacement of Left Glenoid Cavity with Autologous Tissue Substitute, Open Approach */
"0PR80JZ" = "1" /* Replacement of Left Glenoid Cavity with Synthetic Substitute, Open Approach */
"0PR80KZ" = "1" /* Replacement of Left Glenoid Cavity with Nonautologous Tissue Substitute, Open Approach */
"0PR837Z" = "1" /* Replacement of Left Glenoid Cavity with Autologous Tissue Substitute, Percutaneous Approach */
"0PR83JZ" = "1" /* Replacement of Left Glenoid Cavity with Synthetic Substitute, Percutaneous Approach */
"0PR83KZ" = "1" /* Replacement of Left Glenoid Cavity with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PR847Z" = "1" /* Replacement of Left Glenoid Cavity with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PR84JZ" = "1" /* Replacement of Left Glenoid Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PR84KZ" = "1" /* Replacement of Left Glenoid Cavity with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PR907Z" = "1" /* Replacement of Right Clavicle with Autologous Tissue Substitute, Open Approach */
"0PR90JZ" = "1" /* Replacement of Right Clavicle with Synthetic Substitute, Open Approach */
"0PR90KZ" = "1" /* Replacement of Right Clavicle with Nonautologous Tissue Substitute, Open Approach */
"0PR937Z" = "1" /* Replacement of Right Clavicle with Autologous Tissue Substitute, Percutaneous Approach */
"0PR93JZ" = "1" /* Replacement of Right Clavicle with Synthetic Substitute, Percutaneous Approach */
"0PR93KZ" = "1" /* Replacement of Right Clavicle with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PR947Z" = "1" /* Replacement of Right Clavicle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PR94JZ" = "1" /* Replacement of Right Clavicle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PR94KZ" = "1" /* Replacement of Right Clavicle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRB07Z" = "1" /* Replacement of Left Clavicle with Autologous Tissue Substitute, Open Approach */
"0PRB0JZ" = "1" /* Replacement of Left Clavicle with Synthetic Substitute, Open Approach */
"0PRB0KZ" = "1" /* Replacement of Left Clavicle with Nonautologous Tissue Substitute, Open Approach */
"0PRB37Z" = "1" /* Replacement of Left Clavicle with Autologous Tissue Substitute, Percutaneous Approach */
"0PRB3JZ" = "1" /* Replacement of Left Clavicle with Synthetic Substitute, Percutaneous Approach */
"0PRB3KZ" = "1" /* Replacement of Left Clavicle with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PRB47Z" = "1" /* Replacement of Left Clavicle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRB4JZ" = "1" /* Replacement of Left Clavicle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PRB4KZ" = "1" /* Replacement of Left Clavicle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRC07Z" = "1" /* Replacement of Right Humeral Head with Autologous Tissue Substitute, Open Approach */
"0PRC0KZ" = "1" /* Replacement of Right Humeral Head with Nonautologous Tissue Substitute, Open Approach */
"0PRC37Z" = "1" /* Replacement of Right Humeral Head with Autologous Tissue Substitute, Percutaneous Approach */
"0PRC3JZ" = "1" /* Replacement of Right Humeral Head with Synthetic Substitute, Percutaneous Approach */
"0PRC3KZ" = "1" /* Replacement of Right Humeral Head with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PRC47Z" = "1" /* Replacement of Right Humeral Head with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRC4JZ" = "1" /* Replacement of Right Humeral Head with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PRC4KZ" = "1" /* Replacement of Right Humeral Head with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRD07Z" = "1" /* Replacement of Left Humeral Head with Autologous Tissue Substitute, Open Approach */
"0PRD0KZ" = "1" /* Replacement of Left Humeral Head with Nonautologous Tissue Substitute, Open Approach */
"0PRD37Z" = "1" /* Replacement of Left Humeral Head with Autologous Tissue Substitute, Percutaneous Approach */
"0PRD3JZ" = "1" /* Replacement of Left Humeral Head with Synthetic Substitute, Percutaneous Approach */
"0PRD3KZ" = "1" /* Replacement of Left Humeral Head with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PRD47Z" = "1" /* Replacement of Left Humeral Head with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRD4JZ" = "1" /* Replacement of Left Humeral Head with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PRD4KZ" = "1" /* Replacement of Left Humeral Head with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRF07Z" = "1" /* Replacement of Right Humeral Shaft with Autologous Tissue Substitute, Open Approach */
"0PRF0JZ" = "1" /* Replacement of Right Humeral Shaft with Synthetic Substitute, Open Approach */
"0PRF0KZ" = "1" /* Replacement of Right Humeral Shaft with Nonautologous Tissue Substitute, Open Approach */
"0PRF37Z" = "1" /* Replacement of Right Humeral Shaft with Autologous Tissue Substitute, Percutaneous Approach */
"0PRF3JZ" = "1" /* Replacement of Right Humeral Shaft with Synthetic Substitute, Percutaneous Approach */
"0PRF3KZ" = "1" /* Replacement of Right Humeral Shaft with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PRF47Z" = "1" /* Replacement of Right Humeral Shaft with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRF4JZ" = "1" /* Replacement of Right Humeral Shaft with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PRF4KZ" = "1" /* Replacement of Right Humeral Shaft with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRG07Z" = "1" /* Replacement of Left Humeral Shaft with Autologous Tissue Substitute, Open Approach */
"0PRG0JZ" = "1" /* Replacement of Left Humeral Shaft with Synthetic Substitute, Open Approach */
"0PRG0KZ" = "1" /* Replacement of Left Humeral Shaft with Nonautologous Tissue Substitute, Open Approach */
"0PRG37Z" = "1" /* Replacement of Left Humeral Shaft with Autologous Tissue Substitute, Percutaneous Approach */
"0PRG3JZ" = "1" /* Replacement of Left Humeral Shaft with Synthetic Substitute, Percutaneous Approach */
"0PRG3KZ" = "1" /* Replacement of Left Humeral Shaft with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PRG47Z" = "1" /* Replacement of Left Humeral Shaft with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRG4JZ" = "1" /* Replacement of Left Humeral Shaft with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PRG4KZ" = "1" /* Replacement of Left Humeral Shaft with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRH07Z" = "1" /* Replacement of Right Radius with Autologous Tissue Substitute, Open Approach */
"0PRH0JZ" = "1" /* Replacement of Right Radius with Synthetic Substitute, Open Approach */
"0PRH0KZ" = "1" /* Replacement of Right Radius with Nonautologous Tissue Substitute, Open Approach */
"0PRH37Z" = "1" /* Replacement of Right Radius with Autologous Tissue Substitute, Percutaneous Approach */
"0PRH3JZ" = "1" /* Replacement of Right Radius with Synthetic Substitute, Percutaneous Approach */
"0PRH3KZ" = "1" /* Replacement of Right Radius with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PRH47Z" = "1" /* Replacement of Right Radius with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRH4JZ" = "1" /* Replacement of Right Radius with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PRH4KZ" = "1" /* Replacement of Right Radius with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRJ07Z" = "1" /* Replacement of Left Radius with Autologous Tissue Substitute, Open Approach */
"0PRJ0JZ" = "1" /* Replacement of Left Radius with Synthetic Substitute, Open Approach */
"0PRJ0KZ" = "1" /* Replacement of Left Radius with Nonautologous Tissue Substitute, Open Approach */
"0PRJ37Z" = "1" /* Replacement of Left Radius with Autologous Tissue Substitute, Percutaneous Approach */
"0PRJ3JZ" = "1" /* Replacement of Left Radius with Synthetic Substitute, Percutaneous Approach */
"0PRJ3KZ" = "1" /* Replacement of Left Radius with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PRJ47Z" = "1" /* Replacement of Left Radius with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRJ4JZ" = "1" /* Replacement of Left Radius with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PRJ4KZ" = "1" /* Replacement of Left Radius with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRK07Z" = "1" /* Replacement of Right Ulna with Autologous Tissue Substitute, Open Approach */
"0PRK0JZ" = "1" /* Replacement of Right Ulna with Synthetic Substitute, Open Approach */
"0PRK0KZ" = "1" /* Replacement of Right Ulna with Nonautologous Tissue Substitute, Open Approach */
"0PRK37Z" = "1" /* Replacement of Right Ulna with Autologous Tissue Substitute, Percutaneous Approach */
"0PRK3JZ" = "1" /* Replacement of Right Ulna with Synthetic Substitute, Percutaneous Approach */
"0PRK3KZ" = "1" /* Replacement of Right Ulna with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PRK47Z" = "1" /* Replacement of Right Ulna with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRK4JZ" = "1" /* Replacement of Right Ulna with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PRK4KZ" = "1" /* Replacement of Right Ulna with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRL07Z" = "1" /* Replacement of Left Ulna with Autologous Tissue Substitute, Open Approach */
"0PRL0JZ" = "1" /* Replacement of Left Ulna with Synthetic Substitute, Open Approach */
"0PRL0KZ" = "1" /* Replacement of Left Ulna with Nonautologous Tissue Substitute, Open Approach */
"0PRL37Z" = "1" /* Replacement of Left Ulna with Autologous Tissue Substitute, Percutaneous Approach */
"0PRL3JZ" = "1" /* Replacement of Left Ulna with Synthetic Substitute, Percutaneous Approach */
"0PRL3KZ" = "1" /* Replacement of Left Ulna with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PRL47Z" = "1" /* Replacement of Left Ulna with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRL4JZ" = "1" /* Replacement of Left Ulna with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PRL4KZ" = "1" /* Replacement of Left Ulna with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRM07Z" = "1" /* Replacement of Right Carpal with Autologous Tissue Substitute, Open Approach */
"0PRM0JZ" = "1" /* Replacement of Right Carpal with Synthetic Substitute, Open Approach */
"0PRM0KZ" = "1" /* Replacement of Right Carpal with Nonautologous Tissue Substitute, Open Approach */
"0PRM37Z" = "1" /* Replacement of Right Carpal with Autologous Tissue Substitute, Percutaneous Approach */
"0PRM3JZ" = "1" /* Replacement of Right Carpal with Synthetic Substitute, Percutaneous Approach */
"0PRM3KZ" = "1" /* Replacement of Right Carpal with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PRM47Z" = "1" /* Replacement of Right Carpal with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRM4JZ" = "1" /* Replacement of Right Carpal with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PRM4KZ" = "1" /* Replacement of Right Carpal with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRN07Z" = "1" /* Replacement of Left Carpal with Autologous Tissue Substitute, Open Approach */
"0PRN0JZ" = "1" /* Replacement of Left Carpal with Synthetic Substitute, Open Approach */
"0PRN0KZ" = "1" /* Replacement of Left Carpal with Nonautologous Tissue Substitute, Open Approach */
"0PRN37Z" = "1" /* Replacement of Left Carpal with Autologous Tissue Substitute, Percutaneous Approach */
"0PRN3JZ" = "1" /* Replacement of Left Carpal with Synthetic Substitute, Percutaneous Approach */
"0PRN3KZ" = "1" /* Replacement of Left Carpal with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PRN47Z" = "1" /* Replacement of Left Carpal with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRN4JZ" = "1" /* Replacement of Left Carpal with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PRN4KZ" = "1" /* Replacement of Left Carpal with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRP07Z" = "1" /* Replacement of Right Metacarpal with Autologous Tissue Substitute, Open Approach */
"0PRP0JZ" = "1" /* Replacement of Right Metacarpal with Synthetic Substitute, Open Approach */
"0PRP0KZ" = "1" /* Replacement of Right Metacarpal with Nonautologous Tissue Substitute, Open Approach */
"0PRP37Z" = "1" /* Replacement of Right Metacarpal with Autologous Tissue Substitute, Percutaneous Approach */
"0PRP3JZ" = "1" /* Replacement of Right Metacarpal with Synthetic Substitute, Percutaneous Approach */
"0PRP3KZ" = "1" /* Replacement of Right Metacarpal with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PRP47Z" = "1" /* Replacement of Right Metacarpal with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRP4JZ" = "1" /* Replacement of Right Metacarpal with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PRP4KZ" = "1" /* Replacement of Right Metacarpal with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRQ07Z" = "1" /* Replacement of Left Metacarpal with Autologous Tissue Substitute, Open Approach */
"0PRQ0JZ" = "1" /* Replacement of Left Metacarpal with Synthetic Substitute, Open Approach */
"0PRQ0KZ" = "1" /* Replacement of Left Metacarpal with Nonautologous Tissue Substitute, Open Approach */
"0PRQ37Z" = "1" /* Replacement of Left Metacarpal with Autologous Tissue Substitute, Percutaneous Approach */
"0PRQ3JZ" = "1" /* Replacement of Left Metacarpal with Synthetic Substitute, Percutaneous Approach */
"0PRQ3KZ" = "1" /* Replacement of Left Metacarpal with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PRQ47Z" = "1" /* Replacement of Left Metacarpal with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRQ4JZ" = "1" /* Replacement of Left Metacarpal with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PRQ4KZ" = "1" /* Replacement of Left Metacarpal with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRR07Z" = "1" /* Replacement of Right Thumb Phalanx with Autologous Tissue Substitute, Open Approach */
"0PRR0JZ" = "1" /* Replacement of Right Thumb Phalanx with Synthetic Substitute, Open Approach */
"0PRR0KZ" = "1" /* Replacement of Right Thumb Phalanx with Nonautologous Tissue Substitute, Open Approach */
"0PRR37Z" = "1" /* Replacement of Right Thumb Phalanx with Autologous Tissue Substitute, Percutaneous Approach */
"0PRR3JZ" = "1" /* Replacement of Right Thumb Phalanx with Synthetic Substitute, Percutaneous Approach */
"0PRR3KZ" = "1" /* Replacement of Right Thumb Phalanx with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PRR47Z" = "1" /* Replacement of Right Thumb Phalanx with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRR4JZ" = "1" /* Replacement of Right Thumb Phalanx with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PRR4KZ" = "1" /* Replacement of Right Thumb Phalanx with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRS07Z" = "1" /* Replacement of Left Thumb Phalanx with Autologous Tissue Substitute, Open Approach */
"0PRS0JZ" = "1" /* Replacement of Left Thumb Phalanx with Synthetic Substitute, Open Approach */
"0PRS0KZ" = "1" /* Replacement of Left Thumb Phalanx with Nonautologous Tissue Substitute, Open Approach */
"0PRS37Z" = "1" /* Replacement of Left Thumb Phalanx with Autologous Tissue Substitute, Percutaneous Approach */
"0PRS3JZ" = "1" /* Replacement of Left Thumb Phalanx with Synthetic Substitute, Percutaneous Approach */
"0PRS3KZ" = "1" /* Replacement of Left Thumb Phalanx with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PRS47Z" = "1" /* Replacement of Left Thumb Phalanx with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRS4JZ" = "1" /* Replacement of Left Thumb Phalanx with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PRS4KZ" = "1" /* Replacement of Left Thumb Phalanx with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRT07Z" = "1" /* Replacement of Right Finger Phalanx with Autologous Tissue Substitute, Open Approach */
"0PRT0JZ" = "1" /* Replacement of Right Finger Phalanx with Synthetic Substitute, Open Approach */
"0PRT0KZ" = "1" /* Replacement of Right Finger Phalanx with Nonautologous Tissue Substitute, Open Approach */
"0PRT37Z" = "1" /* Replacement of Right Finger Phalanx with Autologous Tissue Substitute, Percutaneous Approach */
"0PRT3JZ" = "1" /* Replacement of Right Finger Phalanx with Synthetic Substitute, Percutaneous Approach */
"0PRT3KZ" = "1" /* Replacement of Right Finger Phalanx with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PRT47Z" = "1" /* Replacement of Right Finger Phalanx with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRT4JZ" = "1" /* Replacement of Right Finger Phalanx with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PRT4KZ" = "1" /* Replacement of Right Finger Phalanx with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRV07Z" = "1" /* Replacement of Left Finger Phalanx with Autologous Tissue Substitute, Open Approach */
"0PRV0JZ" = "1" /* Replacement of Left Finger Phalanx with Synthetic Substitute, Open Approach */
"0PRV0KZ" = "1" /* Replacement of Left Finger Phalanx with Nonautologous Tissue Substitute, Open Approach */
"0PRV37Z" = "1" /* Replacement of Left Finger Phalanx with Autologous Tissue Substitute, Percutaneous Approach */
"0PRV3JZ" = "1" /* Replacement of Left Finger Phalanx with Synthetic Substitute, Percutaneous Approach */
"0PRV3KZ" = "1" /* Replacement of Left Finger Phalanx with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PRV47Z" = "1" /* Replacement of Left Finger Phalanx with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PRV4JZ" = "1" /* Replacement of Left Finger Phalanx with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PRV4KZ" = "1" /* Replacement of Left Finger Phalanx with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PS000Z" = "1" /* Reposition Sternum with Rigid Plate Internal Fixation Device, Open Approach */
"0PS004Z" = "1" /* Reposition Sternum with Internal Fixation Device, Open Approach */
"0PS00ZZ" = "1" /* Reposition Sternum, Open Approach */
"0PS030Z" = "1" /* Reposition Sternum with Rigid Plate Internal Fixation Device, Percutaneous Approach */
"0PS034Z" = "1" /* Reposition Sternum with Internal Fixation Device, Percutaneous Approach */
"0PS040Z" = "1" /* Reposition Sternum with Rigid Plate Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PS044Z" = "1" /* Reposition Sternum with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PS104Z" = "1" /* Reposition Right Rib with Internal Fixation Device, Open Approach */
"0PS10ZZ" = "1" /* Reposition Right Rib, Open Approach */
"0PS134Z" = "1" /* Reposition Right Rib with Internal Fixation Device, Percutaneous Approach */
"0PS144Z" = "1" /* Reposition Right Rib with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PS204Z" = "1" /* Reposition Left Rib with Internal Fixation Device, Open Approach */
"0PS20ZZ" = "1" /* Reposition Left Rib, Open Approach */
"0PS234Z" = "1" /* Reposition Left Rib with Internal Fixation Device, Percutaneous Approach */
"0PS244Z" = "1" /* Reposition Left Rib with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PS304Z" = "1" /* Reposition Cervical Vertebra with Internal Fixation Device, Open Approach */
"0PS30ZZ" = "1" /* Reposition Cervical Vertebra, Open Approach */
"0PS334Z" = "1" /* Reposition Cervical Vertebra with Internal Fixation Device, Percutaneous Approach */
"0PS33ZZ" = "1" /* Reposition Cervical Vertebra, Percutaneous Approach */
"0PS344Z" = "1" /* Reposition Cervical Vertebra with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PS34ZZ" = "1" /* Reposition Cervical Vertebra, Percutaneous Endoscopic Approach */
"0PS404Z" = "1" /* Reposition Thoracic Vertebra with Internal Fixation Device, Open Approach */
"0PS40ZZ" = "1" /* Reposition Thoracic Vertebra, Open Approach */
"0PS434Z" = "1" /* Reposition Thoracic Vertebra with Internal Fixation Device, Percutaneous Approach */
"0PS43ZZ" = "1" /* Reposition Thoracic Vertebra, Percutaneous Approach */
"0PS444Z" = "1" /* Reposition Thoracic Vertebra with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PS44ZZ" = "1" /* Reposition Thoracic Vertebra, Percutaneous Endoscopic Approach */
"0PS504Z" = "1" /* Reposition Right Scapula with Internal Fixation Device, Open Approach */
"0PS50ZZ" = "1" /* Reposition Right Scapula, Open Approach */
"0PS534Z" = "1" /* Reposition Right Scapula with Internal Fixation Device, Percutaneous Approach */
"0PS544Z" = "1" /* Reposition Right Scapula with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PS604Z" = "1" /* Reposition Left Scapula with Internal Fixation Device, Open Approach */
"0PS60ZZ" = "1" /* Reposition Left Scapula, Open Approach */
"0PS634Z" = "1" /* Reposition Left Scapula with Internal Fixation Device, Percutaneous Approach */
"0PS644Z" = "1" /* Reposition Left Scapula with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PS704Z" = "1" /* Reposition Right Glenoid Cavity with Internal Fixation Device, Open Approach */
"0PS70ZZ" = "1" /* Reposition Right Glenoid Cavity, Open Approach */
"0PS734Z" = "1" /* Reposition Right Glenoid Cavity with Internal Fixation Device, Percutaneous Approach */
"0PS744Z" = "1" /* Reposition Right Glenoid Cavity with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PS804Z" = "1" /* Reposition Left Glenoid Cavity with Internal Fixation Device, Open Approach */
"0PS80ZZ" = "1" /* Reposition Left Glenoid Cavity, Open Approach */
"0PS834Z" = "1" /* Reposition Left Glenoid Cavity with Internal Fixation Device, Percutaneous Approach */
"0PS844Z" = "1" /* Reposition Left Glenoid Cavity with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PS904Z" = "1" /* Reposition Right Clavicle with Internal Fixation Device, Open Approach */
"0PS90ZZ" = "1" /* Reposition Right Clavicle, Open Approach */
"0PS934Z" = "1" /* Reposition Right Clavicle with Internal Fixation Device, Percutaneous Approach */
"0PS944Z" = "1" /* Reposition Right Clavicle with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSB04Z" = "1" /* Reposition Left Clavicle with Internal Fixation Device, Open Approach */
"0PSB0ZZ" = "1" /* Reposition Left Clavicle, Open Approach */
"0PSB34Z" = "1" /* Reposition Left Clavicle with Internal Fixation Device, Percutaneous Approach */
"0PSB44Z" = "1" /* Reposition Left Clavicle with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSC04Z" = "1" /* Reposition Right Humeral Head with Internal Fixation Device, Open Approach */
"0PSC05Z" = "1" /* Reposition Right Humeral Head with External Fixation Device, Open Approach */
"0PSC06Z" = "1" /* Reposition Right Humeral Head with Intramedullary Internal Fixation Device, Open Approach */
"0PSC0BZ" = "1" /* Reposition Right Humeral Head with Monoplanar External Fixation Device, Open Approach */
"0PSC0CZ" = "1" /* Reposition Right Humeral Head with Ring External Fixation Device, Open Approach */
"0PSC0DZ" = "1" /* Reposition Right Humeral Head with Hybrid External Fixation Device, Open Approach */
"0PSC0ZZ" = "1" /* Reposition Right Humeral Head, Open Approach */
"0PSC34Z" = "1" /* Reposition Right Humeral Head with Internal Fixation Device, Percutaneous Approach */
"0PSC35Z" = "1" /* Reposition Right Humeral Head with External Fixation Device, Percutaneous Approach */
"0PSC36Z" = "1" /* Reposition Right Humeral Head with Intramedullary Internal Fixation Device, Percutaneous Approach */
"0PSC3BZ" = "1" /* Reposition Right Humeral Head with Monoplanar External Fixation Device, Percutaneous Approach */
"0PSC3CZ" = "1" /* Reposition Right Humeral Head with Ring External Fixation Device, Percutaneous Approach */
"0PSC3DZ" = "1" /* Reposition Right Humeral Head with Hybrid External Fixation Device, Percutaneous Approach */
"0PSC44Z" = "1" /* Reposition Right Humeral Head with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSC45Z" = "1" /* Reposition Right Humeral Head with External Fixation Device, Percutaneous Endoscopic Approach */
"0PSC46Z" = "1" /* Reposition Right Humeral Head with Intramedullary Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSC4BZ" = "1" /* Reposition Right Humeral Head with Monoplanar External Fixation Device, Percutaneous Endoscopic Approach */
"0PSC4CZ" = "1" /* Reposition Right Humeral Head with Ring External Fixation Device, Percutaneous Endoscopic Approach */
"0PSC4DZ" = "1" /* Reposition Right Humeral Head with Hybrid External Fixation Device, Percutaneous Endoscopic Approach */
"0PSD04Z" = "1" /* Reposition Left Humeral Head with Internal Fixation Device, Open Approach */
"0PSD05Z" = "1" /* Reposition Left Humeral Head with External Fixation Device, Open Approach */
"0PSD06Z" = "1" /* Reposition Left Humeral Head with Intramedullary Internal Fixation Device, Open Approach */
"0PSD0BZ" = "1" /* Reposition Left Humeral Head with Monoplanar External Fixation Device, Open Approach */
"0PSD0CZ" = "1" /* Reposition Left Humeral Head with Ring External Fixation Device, Open Approach */
"0PSD0DZ" = "1" /* Reposition Left Humeral Head with Hybrid External Fixation Device, Open Approach */
"0PSD0ZZ" = "1" /* Reposition Left Humeral Head, Open Approach */
"0PSD34Z" = "1" /* Reposition Left Humeral Head with Internal Fixation Device, Percutaneous Approach */
"0PSD35Z" = "1" /* Reposition Left Humeral Head with External Fixation Device, Percutaneous Approach */
"0PSD36Z" = "1" /* Reposition Left Humeral Head with Intramedullary Internal Fixation Device, Percutaneous Approach */
"0PSD3BZ" = "1" /* Reposition Left Humeral Head with Monoplanar External Fixation Device, Percutaneous Approach */
"0PSD3CZ" = "1" /* Reposition Left Humeral Head with Ring External Fixation Device, Percutaneous Approach */
"0PSD3DZ" = "1" /* Reposition Left Humeral Head with Hybrid External Fixation Device, Percutaneous Approach */
"0PSD44Z" = "1" /* Reposition Left Humeral Head with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSD45Z" = "1" /* Reposition Left Humeral Head with External Fixation Device, Percutaneous Endoscopic Approach */
"0PSD46Z" = "1" /* Reposition Left Humeral Head with Intramedullary Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSD4BZ" = "1" /* Reposition Left Humeral Head with Monoplanar External Fixation Device, Percutaneous Endoscopic Approach */
"0PSD4CZ" = "1" /* Reposition Left Humeral Head with Ring External Fixation Device, Percutaneous Endoscopic Approach */
"0PSD4DZ" = "1" /* Reposition Left Humeral Head with Hybrid External Fixation Device, Percutaneous Endoscopic Approach */
"0PSF04Z" = "1" /* Reposition Right Humeral Shaft with Internal Fixation Device, Open Approach */
"0PSF05Z" = "1" /* Reposition Right Humeral Shaft with External Fixation Device, Open Approach */
"0PSF06Z" = "1" /* Reposition Right Humeral Shaft with Intramedullary Internal Fixation Device, Open Approach */
"0PSF0BZ" = "1" /* Reposition Right Humeral Shaft with Monoplanar External Fixation Device, Open Approach */
"0PSF0CZ" = "1" /* Reposition Right Humeral Shaft with Ring External Fixation Device, Open Approach */
"0PSF0DZ" = "1" /* Reposition Right Humeral Shaft with Hybrid External Fixation Device, Open Approach */
"0PSF0ZZ" = "1" /* Reposition Right Humeral Shaft, Open Approach */
"0PSF34Z" = "1" /* Reposition Right Humeral Shaft with Internal Fixation Device, Percutaneous Approach */
"0PSF35Z" = "1" /* Reposition Right Humeral Shaft with External Fixation Device, Percutaneous Approach */
"0PSF36Z" = "1" /* Reposition Right Humeral Shaft with Intramedullary Internal Fixation Device, Percutaneous Approach */
"0PSF3BZ" = "1" /* Reposition Right Humeral Shaft with Monoplanar External Fixation Device, Percutaneous Approach */
"0PSF3CZ" = "1" /* Reposition Right Humeral Shaft with Ring External Fixation Device, Percutaneous Approach */
"0PSF3DZ" = "1" /* Reposition Right Humeral Shaft with Hybrid External Fixation Device, Percutaneous Approach */
"0PSF44Z" = "1" /* Reposition Right Humeral Shaft with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSF45Z" = "1" /* Reposition Right Humeral Shaft with External Fixation Device, Percutaneous Endoscopic Approach */
"0PSF46Z" = "1" /* Reposition Right Humeral Shaft with Intramedullary Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSF4BZ" = "1" /* Reposition Right Humeral Shaft with Monoplanar External Fixation Device, Percutaneous Endoscopic Approach */
"0PSF4CZ" = "1" /* Reposition Right Humeral Shaft with Ring External Fixation Device, Percutaneous Endoscopic Approach */
"0PSF4DZ" = "1" /* Reposition Right Humeral Shaft with Hybrid External Fixation Device, Percutaneous Endoscopic Approach */
"0PSG04Z" = "1" /* Reposition Left Humeral Shaft with Internal Fixation Device, Open Approach */
"0PSG05Z" = "1" /* Reposition Left Humeral Shaft with External Fixation Device, Open Approach */
"0PSG06Z" = "1" /* Reposition Left Humeral Shaft with Intramedullary Internal Fixation Device, Open Approach */
"0PSG0BZ" = "1" /* Reposition Left Humeral Shaft with Monoplanar External Fixation Device, Open Approach */
"0PSG0CZ" = "1" /* Reposition Left Humeral Shaft with Ring External Fixation Device, Open Approach */
"0PSG0DZ" = "1" /* Reposition Left Humeral Shaft with Hybrid External Fixation Device, Open Approach */
"0PSG0ZZ" = "1" /* Reposition Left Humeral Shaft, Open Approach */
"0PSG34Z" = "1" /* Reposition Left Humeral Shaft with Internal Fixation Device, Percutaneous Approach */
"0PSG35Z" = "1" /* Reposition Left Humeral Shaft with External Fixation Device, Percutaneous Approach */
"0PSG36Z" = "1" /* Reposition Left Humeral Shaft with Intramedullary Internal Fixation Device, Percutaneous Approach */
"0PSG3BZ" = "1" /* Reposition Left Humeral Shaft with Monoplanar External Fixation Device, Percutaneous Approach */
"0PSG3CZ" = "1" /* Reposition Left Humeral Shaft with Ring External Fixation Device, Percutaneous Approach */
"0PSG3DZ" = "1" /* Reposition Left Humeral Shaft with Hybrid External Fixation Device, Percutaneous Approach */
"0PSG44Z" = "1" /* Reposition Left Humeral Shaft with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSG45Z" = "1" /* Reposition Left Humeral Shaft with External Fixation Device, Percutaneous Endoscopic Approach */
"0PSG46Z" = "1" /* Reposition Left Humeral Shaft with Intramedullary Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSG4BZ" = "1" /* Reposition Left Humeral Shaft with Monoplanar External Fixation Device, Percutaneous Endoscopic Approach */
"0PSG4CZ" = "1" /* Reposition Left Humeral Shaft with Ring External Fixation Device, Percutaneous Endoscopic Approach */
"0PSG4DZ" = "1" /* Reposition Left Humeral Shaft with Hybrid External Fixation Device, Percutaneous Endoscopic Approach */
"0PSH04Z" = "1" /* Reposition Right Radius with Internal Fixation Device, Open Approach */
"0PSH05Z" = "1" /* Reposition Right Radius with External Fixation Device, Open Approach */
"0PSH06Z" = "1" /* Reposition Right Radius with Intramedullary Internal Fixation Device, Open Approach */
"0PSH0BZ" = "1" /* Reposition Right Radius with Monoplanar External Fixation Device, Open Approach */
"0PSH0CZ" = "1" /* Reposition Right Radius with Ring External Fixation Device, Open Approach */
"0PSH0DZ" = "1" /* Reposition Right Radius with Hybrid External Fixation Device, Open Approach */
"0PSH0ZZ" = "1" /* Reposition Right Radius, Open Approach */
"0PSH34Z" = "1" /* Reposition Right Radius with Internal Fixation Device, Percutaneous Approach */
"0PSH35Z" = "1" /* Reposition Right Radius with External Fixation Device, Percutaneous Approach */
"0PSH36Z" = "1" /* Reposition Right Radius with Intramedullary Internal Fixation Device, Percutaneous Approach */
"0PSH3BZ" = "1" /* Reposition Right Radius with Monoplanar External Fixation Device, Percutaneous Approach */
"0PSH3CZ" = "1" /* Reposition Right Radius with Ring External Fixation Device, Percutaneous Approach */
"0PSH3DZ" = "1" /* Reposition Right Radius with Hybrid External Fixation Device, Percutaneous Approach */
"0PSH44Z" = "1" /* Reposition Right Radius with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSH45Z" = "1" /* Reposition Right Radius with External Fixation Device, Percutaneous Endoscopic Approach */
"0PSH46Z" = "1" /* Reposition Right Radius with Intramedullary Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSH4BZ" = "1" /* Reposition Right Radius with Monoplanar External Fixation Device, Percutaneous Endoscopic Approach */
"0PSH4CZ" = "1" /* Reposition Right Radius with Ring External Fixation Device, Percutaneous Endoscopic Approach */
"0PSH4DZ" = "1" /* Reposition Right Radius with Hybrid External Fixation Device, Percutaneous Endoscopic Approach */
"0PSJ04Z" = "1" /* Reposition Left Radius with Internal Fixation Device, Open Approach */
"0PSJ05Z" = "1" /* Reposition Left Radius with External Fixation Device, Open Approach */
"0PSJ06Z" = "1" /* Reposition Left Radius with Intramedullary Internal Fixation Device, Open Approach */
"0PSJ0BZ" = "1" /* Reposition Left Radius with Monoplanar External Fixation Device, Open Approach */
"0PSJ0CZ" = "1" /* Reposition Left Radius with Ring External Fixation Device, Open Approach */
"0PSJ0DZ" = "1" /* Reposition Left Radius with Hybrid External Fixation Device, Open Approach */
"0PSJ0ZZ" = "1" /* Reposition Left Radius, Open Approach */
"0PSJ34Z" = "1" /* Reposition Left Radius with Internal Fixation Device, Percutaneous Approach */
"0PSJ35Z" = "1" /* Reposition Left Radius with External Fixation Device, Percutaneous Approach */
"0PSJ36Z" = "1" /* Reposition Left Radius with Intramedullary Internal Fixation Device, Percutaneous Approach */
"0PSJ3BZ" = "1" /* Reposition Left Radius with Monoplanar External Fixation Device, Percutaneous Approach */
"0PSJ3CZ" = "1" /* Reposition Left Radius with Ring External Fixation Device, Percutaneous Approach */
"0PSJ3DZ" = "1" /* Reposition Left Radius with Hybrid External Fixation Device, Percutaneous Approach */
"0PSJ44Z" = "1" /* Reposition Left Radius with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSJ45Z" = "1" /* Reposition Left Radius with External Fixation Device, Percutaneous Endoscopic Approach */
"0PSJ46Z" = "1" /* Reposition Left Radius with Intramedullary Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSJ4BZ" = "1" /* Reposition Left Radius with Monoplanar External Fixation Device, Percutaneous Endoscopic Approach */
"0PSJ4CZ" = "1" /* Reposition Left Radius with Ring External Fixation Device, Percutaneous Endoscopic Approach */
"0PSJ4DZ" = "1" /* Reposition Left Radius with Hybrid External Fixation Device, Percutaneous Endoscopic Approach */
"0PSK04Z" = "1" /* Reposition Right Ulna with Internal Fixation Device, Open Approach */
"0PSK05Z" = "1" /* Reposition Right Ulna with External Fixation Device, Open Approach */
"0PSK06Z" = "1" /* Reposition Right Ulna with Intramedullary Internal Fixation Device, Open Approach */
"0PSK0BZ" = "1" /* Reposition Right Ulna with Monoplanar External Fixation Device, Open Approach */
"0PSK0CZ" = "1" /* Reposition Right Ulna with Ring External Fixation Device, Open Approach */
"0PSK0DZ" = "1" /* Reposition Right Ulna with Hybrid External Fixation Device, Open Approach */
"0PSK0ZZ" = "1" /* Reposition Right Ulna, Open Approach */
"0PSK34Z" = "1" /* Reposition Right Ulna with Internal Fixation Device, Percutaneous Approach */
"0PSK35Z" = "1" /* Reposition Right Ulna with External Fixation Device, Percutaneous Approach */
"0PSK36Z" = "1" /* Reposition Right Ulna with Intramedullary Internal Fixation Device, Percutaneous Approach */
"0PSK3BZ" = "1" /* Reposition Right Ulna with Monoplanar External Fixation Device, Percutaneous Approach */
"0PSK3CZ" = "1" /* Reposition Right Ulna with Ring External Fixation Device, Percutaneous Approach */
"0PSK3DZ" = "1" /* Reposition Right Ulna with Hybrid External Fixation Device, Percutaneous Approach */
"0PSK44Z" = "1" /* Reposition Right Ulna with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSK45Z" = "1" /* Reposition Right Ulna with External Fixation Device, Percutaneous Endoscopic Approach */
"0PSK46Z" = "1" /* Reposition Right Ulna with Intramedullary Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSK4BZ" = "1" /* Reposition Right Ulna with Monoplanar External Fixation Device, Percutaneous Endoscopic Approach */
"0PSK4CZ" = "1" /* Reposition Right Ulna with Ring External Fixation Device, Percutaneous Endoscopic Approach */
"0PSK4DZ" = "1" /* Reposition Right Ulna with Hybrid External Fixation Device, Percutaneous Endoscopic Approach */
"0PSL04Z" = "1" /* Reposition Left Ulna with Internal Fixation Device, Open Approach */
"0PSL05Z" = "1" /* Reposition Left Ulna with External Fixation Device, Open Approach */
"0PSL06Z" = "1" /* Reposition Left Ulna with Intramedullary Internal Fixation Device, Open Approach */
"0PSL0BZ" = "1" /* Reposition Left Ulna with Monoplanar External Fixation Device, Open Approach */
"0PSL0CZ" = "1" /* Reposition Left Ulna with Ring External Fixation Device, Open Approach */
"0PSL0DZ" = "1" /* Reposition Left Ulna with Hybrid External Fixation Device, Open Approach */
"0PSL0ZZ" = "1" /* Reposition Left Ulna, Open Approach */
"0PSL34Z" = "1" /* Reposition Left Ulna with Internal Fixation Device, Percutaneous Approach */
"0PSL35Z" = "1" /* Reposition Left Ulna with External Fixation Device, Percutaneous Approach */
"0PSL36Z" = "1" /* Reposition Left Ulna with Intramedullary Internal Fixation Device, Percutaneous Approach */
"0PSL3BZ" = "1" /* Reposition Left Ulna with Monoplanar External Fixation Device, Percutaneous Approach */
"0PSL3CZ" = "1" /* Reposition Left Ulna with Ring External Fixation Device, Percutaneous Approach */
"0PSL3DZ" = "1" /* Reposition Left Ulna with Hybrid External Fixation Device, Percutaneous Approach */
"0PSL44Z" = "1" /* Reposition Left Ulna with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSL45Z" = "1" /* Reposition Left Ulna with External Fixation Device, Percutaneous Endoscopic Approach */
"0PSL46Z" = "1" /* Reposition Left Ulna with Intramedullary Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSL4BZ" = "1" /* Reposition Left Ulna with Monoplanar External Fixation Device, Percutaneous Endoscopic Approach */
"0PSL4CZ" = "1" /* Reposition Left Ulna with Ring External Fixation Device, Percutaneous Endoscopic Approach */
"0PSL4DZ" = "1" /* Reposition Left Ulna with Hybrid External Fixation Device, Percutaneous Endoscopic Approach */
"0PSM04Z" = "1" /* Reposition Right Carpal with Internal Fixation Device, Open Approach */
"0PSM05Z" = "1" /* Reposition Right Carpal with External Fixation Device, Open Approach */
"0PSM0ZZ" = "1" /* Reposition Right Carpal, Open Approach */
"0PSM34Z" = "1" /* Reposition Right Carpal with Internal Fixation Device, Percutaneous Approach */
"0PSM35Z" = "1" /* Reposition Right Carpal with External Fixation Device, Percutaneous Approach */
"0PSM44Z" = "1" /* Reposition Right Carpal with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSM45Z" = "1" /* Reposition Right Carpal with External Fixation Device, Percutaneous Endoscopic Approach */
"0PSN04Z" = "1" /* Reposition Left Carpal with Internal Fixation Device, Open Approach */
"0PSN05Z" = "1" /* Reposition Left Carpal with External Fixation Device, Open Approach */
"0PSN0ZZ" = "1" /* Reposition Left Carpal, Open Approach */
"0PSN34Z" = "1" /* Reposition Left Carpal with Internal Fixation Device, Percutaneous Approach */
"0PSN35Z" = "1" /* Reposition Left Carpal with External Fixation Device, Percutaneous Approach */
"0PSN44Z" = "1" /* Reposition Left Carpal with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSN45Z" = "1" /* Reposition Left Carpal with External Fixation Device, Percutaneous Endoscopic Approach */
"0PSP04Z" = "1" /* Reposition Right Metacarpal with Internal Fixation Device, Open Approach */
"0PSP05Z" = "1" /* Reposition Right Metacarpal with External Fixation Device, Open Approach */
"0PSP0ZZ" = "1" /* Reposition Right Metacarpal, Open Approach */
"0PSP34Z" = "1" /* Reposition Right Metacarpal with Internal Fixation Device, Percutaneous Approach */
"0PSP35Z" = "1" /* Reposition Right Metacarpal with External Fixation Device, Percutaneous Approach */
"0PSP44Z" = "1" /* Reposition Right Metacarpal with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSP45Z" = "1" /* Reposition Right Metacarpal with External Fixation Device, Percutaneous Endoscopic Approach */
"0PSQ04Z" = "1" /* Reposition Left Metacarpal with Internal Fixation Device, Open Approach */
"0PSQ05Z" = "1" /* Reposition Left Metacarpal with External Fixation Device, Open Approach */
"0PSQ0ZZ" = "1" /* Reposition Left Metacarpal, Open Approach */
"0PSQ34Z" = "1" /* Reposition Left Metacarpal with Internal Fixation Device, Percutaneous Approach */
"0PSQ35Z" = "1" /* Reposition Left Metacarpal with External Fixation Device, Percutaneous Approach */
"0PSQ44Z" = "1" /* Reposition Left Metacarpal with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSQ45Z" = "1" /* Reposition Left Metacarpal with External Fixation Device, Percutaneous Endoscopic Approach */
"0PSR04Z" = "1" /* Reposition Right Thumb Phalanx with Internal Fixation Device, Open Approach */
"0PSR05Z" = "1" /* Reposition Right Thumb Phalanx with External Fixation Device, Open Approach */
"0PSR0ZZ" = "1" /* Reposition Right Thumb Phalanx, Open Approach */
"0PSR34Z" = "1" /* Reposition Right Thumb Phalanx with Internal Fixation Device, Percutaneous Approach */
"0PSR35Z" = "1" /* Reposition Right Thumb Phalanx with External Fixation Device, Percutaneous Approach */
"0PSR44Z" = "1" /* Reposition Right Thumb Phalanx with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSR45Z" = "1" /* Reposition Right Thumb Phalanx with External Fixation Device, Percutaneous Endoscopic Approach */
"0PSS04Z" = "1" /* Reposition Left Thumb Phalanx with Internal Fixation Device, Open Approach */
"0PSS05Z" = "1" /* Reposition Left Thumb Phalanx with External Fixation Device, Open Approach */
"0PSS0ZZ" = "1" /* Reposition Left Thumb Phalanx, Open Approach */
"0PSS34Z" = "1" /* Reposition Left Thumb Phalanx with Internal Fixation Device, Percutaneous Approach */
"0PSS35Z" = "1" /* Reposition Left Thumb Phalanx with External Fixation Device, Percutaneous Approach */
"0PSS44Z" = "1" /* Reposition Left Thumb Phalanx with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSS45Z" = "1" /* Reposition Left Thumb Phalanx with External Fixation Device, Percutaneous Endoscopic Approach */
"0PST04Z" = "1" /* Reposition Right Finger Phalanx with Internal Fixation Device, Open Approach */
"0PST05Z" = "1" /* Reposition Right Finger Phalanx with External Fixation Device, Open Approach */
"0PST0ZZ" = "1" /* Reposition Right Finger Phalanx, Open Approach */
"0PST34Z" = "1" /* Reposition Right Finger Phalanx with Internal Fixation Device, Percutaneous Approach */
"0PST35Z" = "1" /* Reposition Right Finger Phalanx with External Fixation Device, Percutaneous Approach */
"0PST44Z" = "1" /* Reposition Right Finger Phalanx with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PST45Z" = "1" /* Reposition Right Finger Phalanx with External Fixation Device, Percutaneous Endoscopic Approach */
"0PSV04Z" = "1" /* Reposition Left Finger Phalanx with Internal Fixation Device, Open Approach */
"0PSV05Z" = "1" /* Reposition Left Finger Phalanx with External Fixation Device, Open Approach */
"0PSV0ZZ" = "1" /* Reposition Left Finger Phalanx, Open Approach */
"0PSV34Z" = "1" /* Reposition Left Finger Phalanx with Internal Fixation Device, Percutaneous Approach */
"0PSV35Z" = "1" /* Reposition Left Finger Phalanx with External Fixation Device, Percutaneous Approach */
"0PSV44Z" = "1" /* Reposition Left Finger Phalanx with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0PSV45Z" = "1" /* Reposition Left Finger Phalanx with External Fixation Device, Percutaneous Endoscopic Approach */
"0PT00ZZ" = "1" /* Resection of Sternum, Open Approach */
"0PT10ZZ" = "1" /* Resection of Right Rib, Open Approach */
"0PT20ZZ" = "1" /* Resection of Left Rib, Open Approach */
"0PT50ZZ" = "1" /* Resection of Right Scapula, Open Approach */
"0PT60ZZ" = "1" /* Resection of Left Scapula, Open Approach */
"0PT70ZZ" = "1" /* Resection of Right Glenoid Cavity, Open Approach */
"0PT80ZZ" = "1" /* Resection of Left Glenoid Cavity, Open Approach */
"0PT90ZZ" = "1" /* Resection of Right Clavicle, Open Approach */
"0PTB0ZZ" = "1" /* Resection of Left Clavicle, Open Approach */
"0PTC0ZZ" = "1" /* Resection of Right Humeral Head, Open Approach */
"0PTD0ZZ" = "1" /* Resection of Left Humeral Head, Open Approach */
"0PTF0ZZ" = "1" /* Resection of Right Humeral Shaft, Open Approach */
"0PTG0ZZ" = "1" /* Resection of Left Humeral Shaft, Open Approach */
"0PTH0ZZ" = "1" /* Resection of Right Radius, Open Approach */
"0PTJ0ZZ" = "1" /* Resection of Left Radius, Open Approach */
"0PTK0ZZ" = "1" /* Resection of Right Ulna, Open Approach */
"0PTL0ZZ" = "1" /* Resection of Left Ulna, Open Approach */
"0PTM0ZZ" = "1" /* Resection of Right Carpal, Open Approach */
"0PTN0ZZ" = "1" /* Resection of Left Carpal, Open Approach */
"0PTP0ZZ" = "1" /* Resection of Right Metacarpal, Open Approach */
"0PTQ0ZZ" = "1" /* Resection of Left Metacarpal, Open Approach */
"0PTR0ZZ" = "1" /* Resection of Right Thumb Phalanx, Open Approach */
"0PTS0ZZ" = "1" /* Resection of Left Thumb Phalanx, Open Approach */
"0PTT0ZZ" = "1" /* Resection of Right Finger Phalanx, Open Approach */
"0PTV0ZZ" = "1" /* Resection of Left Finger Phalanx, Open Approach */
"0PU007Z" = "1" /* Supplement Sternum with Autologous Tissue Substitute, Open Approach */
"0PU00JZ" = "1" /* Supplement Sternum with Synthetic Substitute, Open Approach */
"0PU00KZ" = "1" /* Supplement Sternum with Nonautologous Tissue Substitute, Open Approach */
"0PU037Z" = "1" /* Supplement Sternum with Autologous Tissue Substitute, Percutaneous Approach */
"0PU03JZ" = "1" /* Supplement Sternum with Synthetic Substitute, Percutaneous Approach */
"0PU03KZ" = "1" /* Supplement Sternum with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PU047Z" = "1" /* Supplement Sternum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PU04JZ" = "1" /* Supplement Sternum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PU04KZ" = "1" /* Supplement Sternum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PU107Z" = "1" /* Supplement Right Rib with Autologous Tissue Substitute, Open Approach */
"0PU10JZ" = "1" /* Supplement Right Rib with Synthetic Substitute, Open Approach */
"0PU10KZ" = "1" /* Supplement Right Rib with Nonautologous Tissue Substitute, Open Approach */
"0PU137Z" = "1" /* Supplement Right Rib with Autologous Tissue Substitute, Percutaneous Approach */
"0PU13JZ" = "1" /* Supplement Right Rib with Synthetic Substitute, Percutaneous Approach */
"0PU13KZ" = "1" /* Supplement Right Rib with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PU147Z" = "1" /* Supplement Right Rib with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PU14JZ" = "1" /* Supplement Right Rib with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PU14KZ" = "1" /* Supplement Right Rib with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PU207Z" = "1" /* Supplement Left Rib with Autologous Tissue Substitute, Open Approach */
"0PU20JZ" = "1" /* Supplement Left Rib with Synthetic Substitute, Open Approach */
"0PU20KZ" = "1" /* Supplement Left Rib with Nonautologous Tissue Substitute, Open Approach */
"0PU237Z" = "1" /* Supplement Left Rib with Autologous Tissue Substitute, Percutaneous Approach */
"0PU23JZ" = "1" /* Supplement Left Rib with Synthetic Substitute, Percutaneous Approach */
"0PU23KZ" = "1" /* Supplement Left Rib with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PU247Z" = "1" /* Supplement Left Rib with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PU24JZ" = "1" /* Supplement Left Rib with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PU24KZ" = "1" /* Supplement Left Rib with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PU307Z" = "1" /* Supplement Cervical Vertebra with Autologous Tissue Substitute, Open Approach */
"0PU30JZ" = "1" /* Supplement Cervical Vertebra with Synthetic Substitute, Open Approach */
"0PU30KZ" = "1" /* Supplement Cervical Vertebra with Nonautologous Tissue Substitute, Open Approach */
"0PU337Z" = "1" /* Supplement Cervical Vertebra with Autologous Tissue Substitute, Percutaneous Approach */
"0PU33JZ" = "1" /* Supplement Cervical Vertebra with Synthetic Substitute, Percutaneous Approach */
"0PU33KZ" = "1" /* Supplement Cervical Vertebra with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PU347Z" = "1" /* Supplement Cervical Vertebra with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PU34JZ" = "1" /* Supplement Cervical Vertebra with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PU34KZ" = "1" /* Supplement Cervical Vertebra with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PU407Z" = "1" /* Supplement Thoracic Vertebra with Autologous Tissue Substitute, Open Approach */
"0PU40JZ" = "1" /* Supplement Thoracic Vertebra with Synthetic Substitute, Open Approach */
"0PU40KZ" = "1" /* Supplement Thoracic Vertebra with Nonautologous Tissue Substitute, Open Approach */
"0PU437Z" = "1" /* Supplement Thoracic Vertebra with Autologous Tissue Substitute, Percutaneous Approach */
"0PU43JZ" = "1" /* Supplement Thoracic Vertebra with Synthetic Substitute, Percutaneous Approach */
"0PU43KZ" = "1" /* Supplement Thoracic Vertebra with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PU447Z" = "1" /* Supplement Thoracic Vertebra with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PU44JZ" = "1" /* Supplement Thoracic Vertebra with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PU44KZ" = "1" /* Supplement Thoracic Vertebra with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PU507Z" = "1" /* Supplement Right Scapula with Autologous Tissue Substitute, Open Approach */
"0PU50JZ" = "1" /* Supplement Right Scapula with Synthetic Substitute, Open Approach */
"0PU50KZ" = "1" /* Supplement Right Scapula with Nonautologous Tissue Substitute, Open Approach */
"0PU537Z" = "1" /* Supplement Right Scapula with Autologous Tissue Substitute, Percutaneous Approach */
"0PU53JZ" = "1" /* Supplement Right Scapula with Synthetic Substitute, Percutaneous Approach */
"0PU53KZ" = "1" /* Supplement Right Scapula with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PU547Z" = "1" /* Supplement Right Scapula with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PU54JZ" = "1" /* Supplement Right Scapula with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PU54KZ" = "1" /* Supplement Right Scapula with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PU607Z" = "1" /* Supplement Left Scapula with Autologous Tissue Substitute, Open Approach */
"0PU60JZ" = "1" /* Supplement Left Scapula with Synthetic Substitute, Open Approach */
"0PU60KZ" = "1" /* Supplement Left Scapula with Nonautologous Tissue Substitute, Open Approach */
"0PU637Z" = "1" /* Supplement Left Scapula with Autologous Tissue Substitute, Percutaneous Approach */
"0PU63JZ" = "1" /* Supplement Left Scapula with Synthetic Substitute, Percutaneous Approach */
"0PU63KZ" = "1" /* Supplement Left Scapula with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PU647Z" = "1" /* Supplement Left Scapula with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PU64JZ" = "1" /* Supplement Left Scapula with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PU64KZ" = "1" /* Supplement Left Scapula with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PU707Z" = "1" /* Supplement Right Glenoid Cavity with Autologous Tissue Substitute, Open Approach */
"0PU70JZ" = "1" /* Supplement Right Glenoid Cavity with Synthetic Substitute, Open Approach */
"0PU70KZ" = "1" /* Supplement Right Glenoid Cavity with Nonautologous Tissue Substitute, Open Approach */
"0PU737Z" = "1" /* Supplement Right Glenoid Cavity with Autologous Tissue Substitute, Percutaneous Approach */
"0PU73JZ" = "1" /* Supplement Right Glenoid Cavity with Synthetic Substitute, Percutaneous Approach */
"0PU73KZ" = "1" /* Supplement Right Glenoid Cavity with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PU747Z" = "1" /* Supplement Right Glenoid Cavity with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PU74JZ" = "1" /* Supplement Right Glenoid Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PU74KZ" = "1" /* Supplement Right Glenoid Cavity with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PU807Z" = "1" /* Supplement Left Glenoid Cavity with Autologous Tissue Substitute, Open Approach */
"0PU80JZ" = "1" /* Supplement Left Glenoid Cavity with Synthetic Substitute, Open Approach */
"0PU80KZ" = "1" /* Supplement Left Glenoid Cavity with Nonautologous Tissue Substitute, Open Approach */
"0PU837Z" = "1" /* Supplement Left Glenoid Cavity with Autologous Tissue Substitute, Percutaneous Approach */
"0PU83JZ" = "1" /* Supplement Left Glenoid Cavity with Synthetic Substitute, Percutaneous Approach */
"0PU83KZ" = "1" /* Supplement Left Glenoid Cavity with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PU847Z" = "1" /* Supplement Left Glenoid Cavity with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PU84JZ" = "1" /* Supplement Left Glenoid Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PU84KZ" = "1" /* Supplement Left Glenoid Cavity with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PU907Z" = "1" /* Supplement Right Clavicle with Autologous Tissue Substitute, Open Approach */
"0PU90JZ" = "1" /* Supplement Right Clavicle with Synthetic Substitute, Open Approach */
"0PU90KZ" = "1" /* Supplement Right Clavicle with Nonautologous Tissue Substitute, Open Approach */
"0PU937Z" = "1" /* Supplement Right Clavicle with Autologous Tissue Substitute, Percutaneous Approach */
"0PU93JZ" = "1" /* Supplement Right Clavicle with Synthetic Substitute, Percutaneous Approach */
"0PU93KZ" = "1" /* Supplement Right Clavicle with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PU947Z" = "1" /* Supplement Right Clavicle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PU94JZ" = "1" /* Supplement Right Clavicle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PU94KZ" = "1" /* Supplement Right Clavicle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUB07Z" = "1" /* Supplement Left Clavicle with Autologous Tissue Substitute, Open Approach */
"0PUB0JZ" = "1" /* Supplement Left Clavicle with Synthetic Substitute, Open Approach */
"0PUB0KZ" = "1" /* Supplement Left Clavicle with Nonautologous Tissue Substitute, Open Approach */
"0PUB37Z" = "1" /* Supplement Left Clavicle with Autologous Tissue Substitute, Percutaneous Approach */
"0PUB3JZ" = "1" /* Supplement Left Clavicle with Synthetic Substitute, Percutaneous Approach */
"0PUB3KZ" = "1" /* Supplement Left Clavicle with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PUB47Z" = "1" /* Supplement Left Clavicle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUB4JZ" = "1" /* Supplement Left Clavicle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PUB4KZ" = "1" /* Supplement Left Clavicle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUC07Z" = "1" /* Supplement Right Humeral Head with Autologous Tissue Substitute, Open Approach */
"0PUC0JZ" = "1" /* Supplement Right Humeral Head with Synthetic Substitute, Open Approach */
"0PUC0KZ" = "1" /* Supplement Right Humeral Head with Nonautologous Tissue Substitute, Open Approach */
"0PUC37Z" = "1" /* Supplement Right Humeral Head with Autologous Tissue Substitute, Percutaneous Approach */
"0PUC3JZ" = "1" /* Supplement Right Humeral Head with Synthetic Substitute, Percutaneous Approach */
"0PUC3KZ" = "1" /* Supplement Right Humeral Head with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PUC47Z" = "1" /* Supplement Right Humeral Head with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUC4JZ" = "1" /* Supplement Right Humeral Head with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PUC4KZ" = "1" /* Supplement Right Humeral Head with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUD07Z" = "1" /* Supplement Left Humeral Head with Autologous Tissue Substitute, Open Approach */
"0PUD0JZ" = "1" /* Supplement Left Humeral Head with Synthetic Substitute, Open Approach */
"0PUD0KZ" = "1" /* Supplement Left Humeral Head with Nonautologous Tissue Substitute, Open Approach */
"0PUD37Z" = "1" /* Supplement Left Humeral Head with Autologous Tissue Substitute, Percutaneous Approach */
"0PUD3JZ" = "1" /* Supplement Left Humeral Head with Synthetic Substitute, Percutaneous Approach */
"0PUD3KZ" = "1" /* Supplement Left Humeral Head with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PUD47Z" = "1" /* Supplement Left Humeral Head with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUD4JZ" = "1" /* Supplement Left Humeral Head with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PUD4KZ" = "1" /* Supplement Left Humeral Head with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUF07Z" = "1" /* Supplement Right Humeral Shaft with Autologous Tissue Substitute, Open Approach */
"0PUF0JZ" = "1" /* Supplement Right Humeral Shaft with Synthetic Substitute, Open Approach */
"0PUF0KZ" = "1" /* Supplement Right Humeral Shaft with Nonautologous Tissue Substitute, Open Approach */
"0PUF37Z" = "1" /* Supplement Right Humeral Shaft with Autologous Tissue Substitute, Percutaneous Approach */
"0PUF3JZ" = "1" /* Supplement Right Humeral Shaft with Synthetic Substitute, Percutaneous Approach */
"0PUF3KZ" = "1" /* Supplement Right Humeral Shaft with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PUF47Z" = "1" /* Supplement Right Humeral Shaft with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUF4JZ" = "1" /* Supplement Right Humeral Shaft with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PUF4KZ" = "1" /* Supplement Right Humeral Shaft with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUG07Z" = "1" /* Supplement Left Humeral Shaft with Autologous Tissue Substitute, Open Approach */
"0PUG0JZ" = "1" /* Supplement Left Humeral Shaft with Synthetic Substitute, Open Approach */
"0PUG0KZ" = "1" /* Supplement Left Humeral Shaft with Nonautologous Tissue Substitute, Open Approach */
"0PUG37Z" = "1" /* Supplement Left Humeral Shaft with Autologous Tissue Substitute, Percutaneous Approach */
"0PUG3JZ" = "1" /* Supplement Left Humeral Shaft with Synthetic Substitute, Percutaneous Approach */
"0PUG3KZ" = "1" /* Supplement Left Humeral Shaft with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PUG47Z" = "1" /* Supplement Left Humeral Shaft with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUG4JZ" = "1" /* Supplement Left Humeral Shaft with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PUG4KZ" = "1" /* Supplement Left Humeral Shaft with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUH07Z" = "1" /* Supplement Right Radius with Autologous Tissue Substitute, Open Approach */
"0PUH0JZ" = "1" /* Supplement Right Radius with Synthetic Substitute, Open Approach */
"0PUH0KZ" = "1" /* Supplement Right Radius with Nonautologous Tissue Substitute, Open Approach */
"0PUH37Z" = "1" /* Supplement Right Radius with Autologous Tissue Substitute, Percutaneous Approach */
"0PUH3JZ" = "1" /* Supplement Right Radius with Synthetic Substitute, Percutaneous Approach */
"0PUH3KZ" = "1" /* Supplement Right Radius with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PUH47Z" = "1" /* Supplement Right Radius with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUH4JZ" = "1" /* Supplement Right Radius with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PUH4KZ" = "1" /* Supplement Right Radius with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUJ07Z" = "1" /* Supplement Left Radius with Autologous Tissue Substitute, Open Approach */
"0PUJ0JZ" = "1" /* Supplement Left Radius with Synthetic Substitute, Open Approach */
"0PUJ0KZ" = "1" /* Supplement Left Radius with Nonautologous Tissue Substitute, Open Approach */
"0PUJ37Z" = "1" /* Supplement Left Radius with Autologous Tissue Substitute, Percutaneous Approach */
"0PUJ3JZ" = "1" /* Supplement Left Radius with Synthetic Substitute, Percutaneous Approach */
"0PUJ3KZ" = "1" /* Supplement Left Radius with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PUJ47Z" = "1" /* Supplement Left Radius with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUJ4JZ" = "1" /* Supplement Left Radius with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PUJ4KZ" = "1" /* Supplement Left Radius with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUK07Z" = "1" /* Supplement Right Ulna with Autologous Tissue Substitute, Open Approach */
"0PUK0JZ" = "1" /* Supplement Right Ulna with Synthetic Substitute, Open Approach */
"0PUK0KZ" = "1" /* Supplement Right Ulna with Nonautologous Tissue Substitute, Open Approach */
"0PUK37Z" = "1" /* Supplement Right Ulna with Autologous Tissue Substitute, Percutaneous Approach */
"0PUK3JZ" = "1" /* Supplement Right Ulna with Synthetic Substitute, Percutaneous Approach */
"0PUK3KZ" = "1" /* Supplement Right Ulna with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PUK47Z" = "1" /* Supplement Right Ulna with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUK4JZ" = "1" /* Supplement Right Ulna with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PUK4KZ" = "1" /* Supplement Right Ulna with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUL07Z" = "1" /* Supplement Left Ulna with Autologous Tissue Substitute, Open Approach */
"0PUL0JZ" = "1" /* Supplement Left Ulna with Synthetic Substitute, Open Approach */
"0PUL0KZ" = "1" /* Supplement Left Ulna with Nonautologous Tissue Substitute, Open Approach */
"0PUL37Z" = "1" /* Supplement Left Ulna with Autologous Tissue Substitute, Percutaneous Approach */
"0PUL3JZ" = "1" /* Supplement Left Ulna with Synthetic Substitute, Percutaneous Approach */
"0PUL3KZ" = "1" /* Supplement Left Ulna with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PUL47Z" = "1" /* Supplement Left Ulna with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUL4JZ" = "1" /* Supplement Left Ulna with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PUL4KZ" = "1" /* Supplement Left Ulna with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUM07Z" = "1" /* Supplement Right Carpal with Autologous Tissue Substitute, Open Approach */
"0PUM0JZ" = "1" /* Supplement Right Carpal with Synthetic Substitute, Open Approach */
"0PUM0KZ" = "1" /* Supplement Right Carpal with Nonautologous Tissue Substitute, Open Approach */
"0PUM37Z" = "1" /* Supplement Right Carpal with Autologous Tissue Substitute, Percutaneous Approach */
"0PUM3JZ" = "1" /* Supplement Right Carpal with Synthetic Substitute, Percutaneous Approach */
"0PUM3KZ" = "1" /* Supplement Right Carpal with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PUM47Z" = "1" /* Supplement Right Carpal with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUM4JZ" = "1" /* Supplement Right Carpal with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PUM4KZ" = "1" /* Supplement Right Carpal with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUN07Z" = "1" /* Supplement Left Carpal with Autologous Tissue Substitute, Open Approach */
"0PUN0JZ" = "1" /* Supplement Left Carpal with Synthetic Substitute, Open Approach */
"0PUN0KZ" = "1" /* Supplement Left Carpal with Nonautologous Tissue Substitute, Open Approach */
"0PUN37Z" = "1" /* Supplement Left Carpal with Autologous Tissue Substitute, Percutaneous Approach */
"0PUN3JZ" = "1" /* Supplement Left Carpal with Synthetic Substitute, Percutaneous Approach */
"0PUN3KZ" = "1" /* Supplement Left Carpal with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PUN47Z" = "1" /* Supplement Left Carpal with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUN4JZ" = "1" /* Supplement Left Carpal with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PUN4KZ" = "1" /* Supplement Left Carpal with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUP07Z" = "1" /* Supplement Right Metacarpal with Autologous Tissue Substitute, Open Approach */
"0PUP0JZ" = "1" /* Supplement Right Metacarpal with Synthetic Substitute, Open Approach */
"0PUP0KZ" = "1" /* Supplement Right Metacarpal with Nonautologous Tissue Substitute, Open Approach */
"0PUP37Z" = "1" /* Supplement Right Metacarpal with Autologous Tissue Substitute, Percutaneous Approach */
"0PUP3JZ" = "1" /* Supplement Right Metacarpal with Synthetic Substitute, Percutaneous Approach */
"0PUP3KZ" = "1" /* Supplement Right Metacarpal with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PUP47Z" = "1" /* Supplement Right Metacarpal with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUP4JZ" = "1" /* Supplement Right Metacarpal with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PUP4KZ" = "1" /* Supplement Right Metacarpal with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUQ07Z" = "1" /* Supplement Left Metacarpal with Autologous Tissue Substitute, Open Approach */
"0PUQ0JZ" = "1" /* Supplement Left Metacarpal with Synthetic Substitute, Open Approach */
"0PUQ0KZ" = "1" /* Supplement Left Metacarpal with Nonautologous Tissue Substitute, Open Approach */
"0PUQ37Z" = "1" /* Supplement Left Metacarpal with Autologous Tissue Substitute, Percutaneous Approach */
"0PUQ3JZ" = "1" /* Supplement Left Metacarpal with Synthetic Substitute, Percutaneous Approach */
"0PUQ3KZ" = "1" /* Supplement Left Metacarpal with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PUQ47Z" = "1" /* Supplement Left Metacarpal with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUQ4JZ" = "1" /* Supplement Left Metacarpal with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PUQ4KZ" = "1" /* Supplement Left Metacarpal with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUR07Z" = "1" /* Supplement Right Thumb Phalanx with Autologous Tissue Substitute, Open Approach */
"0PUR0JZ" = "1" /* Supplement Right Thumb Phalanx with Synthetic Substitute, Open Approach */
"0PUR0KZ" = "1" /* Supplement Right Thumb Phalanx with Nonautologous Tissue Substitute, Open Approach */
"0PUR37Z" = "1" /* Supplement Right Thumb Phalanx with Autologous Tissue Substitute, Percutaneous Approach */
"0PUR3JZ" = "1" /* Supplement Right Thumb Phalanx with Synthetic Substitute, Percutaneous Approach */
"0PUR3KZ" = "1" /* Supplement Right Thumb Phalanx with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PUR47Z" = "1" /* Supplement Right Thumb Phalanx with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUR4JZ" = "1" /* Supplement Right Thumb Phalanx with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PUR4KZ" = "1" /* Supplement Right Thumb Phalanx with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUS07Z" = "1" /* Supplement Left Thumb Phalanx with Autologous Tissue Substitute, Open Approach */
"0PUS0JZ" = "1" /* Supplement Left Thumb Phalanx with Synthetic Substitute, Open Approach */
"0PUS0KZ" = "1" /* Supplement Left Thumb Phalanx with Nonautologous Tissue Substitute, Open Approach */
"0PUS37Z" = "1" /* Supplement Left Thumb Phalanx with Autologous Tissue Substitute, Percutaneous Approach */
"0PUS3JZ" = "1" /* Supplement Left Thumb Phalanx with Synthetic Substitute, Percutaneous Approach */
"0PUS3KZ" = "1" /* Supplement Left Thumb Phalanx with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PUS47Z" = "1" /* Supplement Left Thumb Phalanx with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUS4JZ" = "1" /* Supplement Left Thumb Phalanx with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PUS4KZ" = "1" /* Supplement Left Thumb Phalanx with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUT07Z" = "1" /* Supplement Right Finger Phalanx with Autologous Tissue Substitute, Open Approach */
"0PUT0JZ" = "1" /* Supplement Right Finger Phalanx with Synthetic Substitute, Open Approach */
"0PUT0KZ" = "1" /* Supplement Right Finger Phalanx with Nonautologous Tissue Substitute, Open Approach */
"0PUT37Z" = "1" /* Supplement Right Finger Phalanx with Autologous Tissue Substitute, Percutaneous Approach */
"0PUT3JZ" = "1" /* Supplement Right Finger Phalanx with Synthetic Substitute, Percutaneous Approach */
"0PUT3KZ" = "1" /* Supplement Right Finger Phalanx with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PUT47Z" = "1" /* Supplement Right Finger Phalanx with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUT4JZ" = "1" /* Supplement Right Finger Phalanx with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PUT4KZ" = "1" /* Supplement Right Finger Phalanx with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUV07Z" = "1" /* Supplement Left Finger Phalanx with Autologous Tissue Substitute, Open Approach */
"0PUV0JZ" = "1" /* Supplement Left Finger Phalanx with Synthetic Substitute, Open Approach */
"0PUV0KZ" = "1" /* Supplement Left Finger Phalanx with Nonautologous Tissue Substitute, Open Approach */
"0PUV37Z" = "1" /* Supplement Left Finger Phalanx with Autologous Tissue Substitute, Percutaneous Approach */
"0PUV3JZ" = "1" /* Supplement Left Finger Phalanx with Synthetic Substitute, Percutaneous Approach */
"0PUV3KZ" = "1" /* Supplement Left Finger Phalanx with Nonautologous Tissue Substitute, Percutaneous Approach */
"0PUV47Z" = "1" /* Supplement Left Finger Phalanx with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PUV4JZ" = "1" /* Supplement Left Finger Phalanx with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0PUV4KZ" = "1" /* Supplement Left Finger Phalanx with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0PW004Z" = "1" /* Revision of Internal Fixation Device in Sternum, Open Approach */
"0PW007Z" = "1" /* Revision of Autologous Tissue Substitute in Sternum, Open Approach */
"0PW00JZ" = "1" /* Revision of Synthetic Substitute in Sternum, Open Approach */
"0PW00KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Sternum, Open Approach */
"0PW034Z" = "1" /* Revision of Internal Fixation Device in Sternum, Percutaneous Approach */
"0PW037Z" = "1" /* Revision of Autologous Tissue Substitute in Sternum, Percutaneous Approach */
"0PW03JZ" = "1" /* Revision of Synthetic Substitute in Sternum, Percutaneous Approach */
"0PW03KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Sternum, Percutaneous Approach */
"0PW044Z" = "1" /* Revision of Internal Fixation Device in Sternum, Percutaneous Endoscopic Approach */
"0PW047Z" = "1" /* Revision of Autologous Tissue Substitute in Sternum, Percutaneous Endoscopic Approach */
"0PW04JZ" = "1" /* Revision of Synthetic Substitute in Sternum, Percutaneous Endoscopic Approach */
"0PW04KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Sternum, Percutaneous Endoscopic Approach */
"0PW104Z" = "1" /* Revision of Internal Fixation Device in Right Rib, Open Approach */
"0PW107Z" = "1" /* Revision of Autologous Tissue Substitute in Right Rib, Open Approach */
"0PW10JZ" = "1" /* Revision of Synthetic Substitute in Right Rib, Open Approach */
"0PW10KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Rib, Open Approach */
"0PW134Z" = "1" /* Revision of Internal Fixation Device in Right Rib, Percutaneous Approach */
"0PW137Z" = "1" /* Revision of Autologous Tissue Substitute in Right Rib, Percutaneous Approach */
"0PW13JZ" = "1" /* Revision of Synthetic Substitute in Right Rib, Percutaneous Approach */
"0PW13KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Rib, Percutaneous Approach */
"0PW144Z" = "1" /* Revision of Internal Fixation Device in Right Rib, Percutaneous Endoscopic Approach */
"0PW147Z" = "1" /* Revision of Autologous Tissue Substitute in Right Rib, Percutaneous Endoscopic Approach */
"0PW14JZ" = "1" /* Revision of Synthetic Substitute in Right Rib, Percutaneous Endoscopic Approach */
"0PW14KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Rib, Percutaneous Endoscopic Approach */
"0PW204Z" = "1" /* Revision of Internal Fixation Device in Left Rib, Open Approach */
"0PW207Z" = "1" /* Revision of Autologous Tissue Substitute in Left Rib, Open Approach */
"0PW20JZ" = "1" /* Revision of Synthetic Substitute in Left Rib, Open Approach */
"0PW20KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Rib, Open Approach */
"0PW234Z" = "1" /* Revision of Internal Fixation Device in Left Rib, Percutaneous Approach */
"0PW237Z" = "1" /* Revision of Autologous Tissue Substitute in Left Rib, Percutaneous Approach */
"0PW23JZ" = "1" /* Revision of Synthetic Substitute in Left Rib, Percutaneous Approach */
"0PW23KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Rib, Percutaneous Approach */
"0PW244Z" = "1" /* Revision of Internal Fixation Device in Left Rib, Percutaneous Endoscopic Approach */
"0PW247Z" = "1" /* Revision of Autologous Tissue Substitute in Left Rib, Percutaneous Endoscopic Approach */
"0PW24JZ" = "1" /* Revision of Synthetic Substitute in Left Rib, Percutaneous Endoscopic Approach */
"0PW24KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Rib, Percutaneous Endoscopic Approach */
"0PW304Z" = "1" /* Revision of Internal Fixation Device in Cervical Vertebra, Open Approach */
"0PW307Z" = "1" /* Revision of Autologous Tissue Substitute in Cervical Vertebra, Open Approach */
"0PW30JZ" = "1" /* Revision of Synthetic Substitute in Cervical Vertebra, Open Approach */
"0PW30KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Cervical Vertebra, Open Approach */
"0PW334Z" = "1" /* Revision of Internal Fixation Device in Cervical Vertebra, Percutaneous Approach */
"0PW337Z" = "1" /* Revision of Autologous Tissue Substitute in Cervical Vertebra, Percutaneous Approach */
"0PW33JZ" = "1" /* Revision of Synthetic Substitute in Cervical Vertebra, Percutaneous Approach */
"0PW33KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Cervical Vertebra, Percutaneous Approach */
"0PW344Z" = "1" /* Revision of Internal Fixation Device in Cervical Vertebra, Percutaneous Endoscopic Approach */
"0PW347Z" = "1" /* Revision of Autologous Tissue Substitute in Cervical Vertebra, Percutaneous Endoscopic Approach */
"0PW34JZ" = "1" /* Revision of Synthetic Substitute in Cervical Vertebra, Percutaneous Endoscopic Approach */
"0PW34KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Cervical Vertebra, Percutaneous Endoscopic Approach */
"0PW404Z" = "1" /* Revision of Internal Fixation Device in Thoracic Vertebra, Open Approach */
"0PW407Z" = "1" /* Revision of Autologous Tissue Substitute in Thoracic Vertebra, Open Approach */
"0PW40JZ" = "1" /* Revision of Synthetic Substitute in Thoracic Vertebra, Open Approach */
"0PW40KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Thoracic Vertebra, Open Approach */
"0PW434Z" = "1" /* Revision of Internal Fixation Device in Thoracic Vertebra, Percutaneous Approach */
"0PW437Z" = "1" /* Revision of Autologous Tissue Substitute in Thoracic Vertebra, Percutaneous Approach */
"0PW43JZ" = "1" /* Revision of Synthetic Substitute in Thoracic Vertebra, Percutaneous Approach */
"0PW43KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Thoracic Vertebra, Percutaneous Approach */
"0PW444Z" = "1" /* Revision of Internal Fixation Device in Thoracic Vertebra, Percutaneous Endoscopic Approach */
"0PW447Z" = "1" /* Revision of Autologous Tissue Substitute in Thoracic Vertebra, Percutaneous Endoscopic Approach */
"0PW44JZ" = "1" /* Revision of Synthetic Substitute in Thoracic Vertebra, Percutaneous Endoscopic Approach */
"0PW44KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Thoracic Vertebra, Percutaneous Endoscopic Approach */
"0PW504Z" = "1" /* Revision of Internal Fixation Device in Right Scapula, Open Approach */
"0PW507Z" = "1" /* Revision of Autologous Tissue Substitute in Right Scapula, Open Approach */
"0PW50JZ" = "1" /* Revision of Synthetic Substitute in Right Scapula, Open Approach */
"0PW50KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Scapula, Open Approach */
"0PW534Z" = "1" /* Revision of Internal Fixation Device in Right Scapula, Percutaneous Approach */
"0PW537Z" = "1" /* Revision of Autologous Tissue Substitute in Right Scapula, Percutaneous Approach */
"0PW53JZ" = "1" /* Revision of Synthetic Substitute in Right Scapula, Percutaneous Approach */
"0PW53KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Scapula, Percutaneous Approach */
"0PW544Z" = "1" /* Revision of Internal Fixation Device in Right Scapula, Percutaneous Endoscopic Approach */
"0PW547Z" = "1" /* Revision of Autologous Tissue Substitute in Right Scapula, Percutaneous Endoscopic Approach */
"0PW54JZ" = "1" /* Revision of Synthetic Substitute in Right Scapula, Percutaneous Endoscopic Approach */
"0PW54KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Scapula, Percutaneous Endoscopic Approach */
"0PW604Z" = "1" /* Revision of Internal Fixation Device in Left Scapula, Open Approach */
"0PW607Z" = "1" /* Revision of Autologous Tissue Substitute in Left Scapula, Open Approach */
"0PW60JZ" = "1" /* Revision of Synthetic Substitute in Left Scapula, Open Approach */
"0PW60KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Scapula, Open Approach */
"0PW634Z" = "1" /* Revision of Internal Fixation Device in Left Scapula, Percutaneous Approach */
"0PW637Z" = "1" /* Revision of Autologous Tissue Substitute in Left Scapula, Percutaneous Approach */
"0PW63JZ" = "1" /* Revision of Synthetic Substitute in Left Scapula, Percutaneous Approach */
"0PW63KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Scapula, Percutaneous Approach */
"0PW644Z" = "1" /* Revision of Internal Fixation Device in Left Scapula, Percutaneous Endoscopic Approach */
"0PW647Z" = "1" /* Revision of Autologous Tissue Substitute in Left Scapula, Percutaneous Endoscopic Approach */
"0PW64JZ" = "1" /* Revision of Synthetic Substitute in Left Scapula, Percutaneous Endoscopic Approach */
"0PW64KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Scapula, Percutaneous Endoscopic Approach */
"0PW704Z" = "1" /* Revision of Internal Fixation Device in Right Glenoid Cavity, Open Approach */
"0PW707Z" = "1" /* Revision of Autologous Tissue Substitute in Right Glenoid Cavity, Open Approach */
"0PW70JZ" = "1" /* Revision of Synthetic Substitute in Right Glenoid Cavity, Open Approach */
"0PW70KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Glenoid Cavity, Open Approach */
"0PW734Z" = "1" /* Revision of Internal Fixation Device in Right Glenoid Cavity, Percutaneous Approach */
"0PW737Z" = "1" /* Revision of Autologous Tissue Substitute in Right Glenoid Cavity, Percutaneous Approach */
"0PW73JZ" = "1" /* Revision of Synthetic Substitute in Right Glenoid Cavity, Percutaneous Approach */
"0PW73KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Glenoid Cavity, Percutaneous Approach */
"0PW744Z" = "1" /* Revision of Internal Fixation Device in Right Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PW747Z" = "1" /* Revision of Autologous Tissue Substitute in Right Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PW74JZ" = "1" /* Revision of Synthetic Substitute in Right Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PW74KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PW804Z" = "1" /* Revision of Internal Fixation Device in Left Glenoid Cavity, Open Approach */
"0PW807Z" = "1" /* Revision of Autologous Tissue Substitute in Left Glenoid Cavity, Open Approach */
"0PW80JZ" = "1" /* Revision of Synthetic Substitute in Left Glenoid Cavity, Open Approach */
"0PW80KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Glenoid Cavity, Open Approach */
"0PW834Z" = "1" /* Revision of Internal Fixation Device in Left Glenoid Cavity, Percutaneous Approach */
"0PW837Z" = "1" /* Revision of Autologous Tissue Substitute in Left Glenoid Cavity, Percutaneous Approach */
"0PW83JZ" = "1" /* Revision of Synthetic Substitute in Left Glenoid Cavity, Percutaneous Approach */
"0PW83KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Glenoid Cavity, Percutaneous Approach */
"0PW844Z" = "1" /* Revision of Internal Fixation Device in Left Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PW847Z" = "1" /* Revision of Autologous Tissue Substitute in Left Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PW84JZ" = "1" /* Revision of Synthetic Substitute in Left Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PW84KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Glenoid Cavity, Percutaneous Endoscopic Approach */
"0PW904Z" = "1" /* Revision of Internal Fixation Device in Right Clavicle, Open Approach */
"0PW907Z" = "1" /* Revision of Autologous Tissue Substitute in Right Clavicle, Open Approach */
"0PW90JZ" = "1" /* Revision of Synthetic Substitute in Right Clavicle, Open Approach */
"0PW90KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Clavicle, Open Approach */
"0PW934Z" = "1" /* Revision of Internal Fixation Device in Right Clavicle, Percutaneous Approach */
"0PW937Z" = "1" /* Revision of Autologous Tissue Substitute in Right Clavicle, Percutaneous Approach */
"0PW93JZ" = "1" /* Revision of Synthetic Substitute in Right Clavicle, Percutaneous Approach */
"0PW93KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Clavicle, Percutaneous Approach */
"0PW944Z" = "1" /* Revision of Internal Fixation Device in Right Clavicle, Percutaneous Endoscopic Approach */
"0PW947Z" = "1" /* Revision of Autologous Tissue Substitute in Right Clavicle, Percutaneous Endoscopic Approach */
"0PW94JZ" = "1" /* Revision of Synthetic Substitute in Right Clavicle, Percutaneous Endoscopic Approach */
"0PW94KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Clavicle, Percutaneous Endoscopic Approach */
"0PWB04Z" = "1" /* Revision of Internal Fixation Device in Left Clavicle, Open Approach */
"0PWB07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Clavicle, Open Approach */
"0PWB0JZ" = "1" /* Revision of Synthetic Substitute in Left Clavicle, Open Approach */
"0PWB0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Clavicle, Open Approach */
"0PWB34Z" = "1" /* Revision of Internal Fixation Device in Left Clavicle, Percutaneous Approach */
"0PWB37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Clavicle, Percutaneous Approach */
"0PWB3JZ" = "1" /* Revision of Synthetic Substitute in Left Clavicle, Percutaneous Approach */
"0PWB3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Clavicle, Percutaneous Approach */
"0PWB44Z" = "1" /* Revision of Internal Fixation Device in Left Clavicle, Percutaneous Endoscopic Approach */
"0PWB47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Clavicle, Percutaneous Endoscopic Approach */
"0PWB4JZ" = "1" /* Revision of Synthetic Substitute in Left Clavicle, Percutaneous Endoscopic Approach */
"0PWB4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Clavicle, Percutaneous Endoscopic Approach */
"0PWC04Z" = "1" /* Revision of Internal Fixation Device in Right Humeral Head, Open Approach */
"0PWC05Z" = "1" /* Revision of External Fixation Device in Right Humeral Head, Open Approach */
"0PWC07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Humeral Head, Open Approach */
"0PWC0JZ" = "1" /* Revision of Synthetic Substitute in Right Humeral Head, Open Approach */
"0PWC0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Humeral Head, Open Approach */
"0PWC34Z" = "1" /* Revision of Internal Fixation Device in Right Humeral Head, Percutaneous Approach */
"0PWC35Z" = "1" /* Revision of External Fixation Device in Right Humeral Head, Percutaneous Approach */
"0PWC37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Humeral Head, Percutaneous Approach */
"0PWC3JZ" = "1" /* Revision of Synthetic Substitute in Right Humeral Head, Percutaneous Approach */
"0PWC3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Humeral Head, Percutaneous Approach */
"0PWC44Z" = "1" /* Revision of Internal Fixation Device in Right Humeral Head, Percutaneous Endoscopic Approach */
"0PWC45Z" = "1" /* Revision of External Fixation Device in Right Humeral Head, Percutaneous Endoscopic Approach */
"0PWC47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Humeral Head, Percutaneous Endoscopic Approach */
"0PWC4JZ" = "1" /* Revision of Synthetic Substitute in Right Humeral Head, Percutaneous Endoscopic Approach */
"0PWC4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Humeral Head, Percutaneous Endoscopic Approach */
"0PWD04Z" = "1" /* Revision of Internal Fixation Device in Left Humeral Head, Open Approach */
"0PWD05Z" = "1" /* Revision of External Fixation Device in Left Humeral Head, Open Approach */
"0PWD07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Humeral Head, Open Approach */
"0PWD0JZ" = "1" /* Revision of Synthetic Substitute in Left Humeral Head, Open Approach */
"0PWD0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Humeral Head, Open Approach */
"0PWD34Z" = "1" /* Revision of Internal Fixation Device in Left Humeral Head, Percutaneous Approach */
"0PWD35Z" = "1" /* Revision of External Fixation Device in Left Humeral Head, Percutaneous Approach */
"0PWD37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Humeral Head, Percutaneous Approach */
"0PWD3JZ" = "1" /* Revision of Synthetic Substitute in Left Humeral Head, Percutaneous Approach */
"0PWD3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Humeral Head, Percutaneous Approach */
"0PWD44Z" = "1" /* Revision of Internal Fixation Device in Left Humeral Head, Percutaneous Endoscopic Approach */
"0PWD45Z" = "1" /* Revision of External Fixation Device in Left Humeral Head, Percutaneous Endoscopic Approach */
"0PWD47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Humeral Head, Percutaneous Endoscopic Approach */
"0PWD4JZ" = "1" /* Revision of Synthetic Substitute in Left Humeral Head, Percutaneous Endoscopic Approach */
"0PWD4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Humeral Head, Percutaneous Endoscopic Approach */
"0PWF04Z" = "1" /* Revision of Internal Fixation Device in Right Humeral Shaft, Open Approach */
"0PWF05Z" = "1" /* Revision of External Fixation Device in Right Humeral Shaft, Open Approach */
"0PWF07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Humeral Shaft, Open Approach */
"0PWF0JZ" = "1" /* Revision of Synthetic Substitute in Right Humeral Shaft, Open Approach */
"0PWF0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Humeral Shaft, Open Approach */
"0PWF34Z" = "1" /* Revision of Internal Fixation Device in Right Humeral Shaft, Percutaneous Approach */
"0PWF35Z" = "1" /* Revision of External Fixation Device in Right Humeral Shaft, Percutaneous Approach */
"0PWF37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Humeral Shaft, Percutaneous Approach */
"0PWF3JZ" = "1" /* Revision of Synthetic Substitute in Right Humeral Shaft, Percutaneous Approach */
"0PWF3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Humeral Shaft, Percutaneous Approach */
"0PWF44Z" = "1" /* Revision of Internal Fixation Device in Right Humeral Shaft, Percutaneous Endoscopic Approach */
"0PWF45Z" = "1" /* Revision of External Fixation Device in Right Humeral Shaft, Percutaneous Endoscopic Approach */
"0PWF47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Humeral Shaft, Percutaneous Endoscopic Approach */
"0PWF4JZ" = "1" /* Revision of Synthetic Substitute in Right Humeral Shaft, Percutaneous Endoscopic Approach */
"0PWF4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Humeral Shaft, Percutaneous Endoscopic Approach */
"0PWG04Z" = "1" /* Revision of Internal Fixation Device in Left Humeral Shaft, Open Approach */
"0PWG05Z" = "1" /* Revision of External Fixation Device in Left Humeral Shaft, Open Approach */
"0PWG07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Humeral Shaft, Open Approach */
"0PWG0JZ" = "1" /* Revision of Synthetic Substitute in Left Humeral Shaft, Open Approach */
"0PWG0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Humeral Shaft, Open Approach */
"0PWG34Z" = "1" /* Revision of Internal Fixation Device in Left Humeral Shaft, Percutaneous Approach */
"0PWG35Z" = "1" /* Revision of External Fixation Device in Left Humeral Shaft, Percutaneous Approach */
"0PWG37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Humeral Shaft, Percutaneous Approach */
"0PWG3JZ" = "1" /* Revision of Synthetic Substitute in Left Humeral Shaft, Percutaneous Approach */
"0PWG3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Humeral Shaft, Percutaneous Approach */
"0PWG44Z" = "1" /* Revision of Internal Fixation Device in Left Humeral Shaft, Percutaneous Endoscopic Approach */
"0PWG45Z" = "1" /* Revision of External Fixation Device in Left Humeral Shaft, Percutaneous Endoscopic Approach */
"0PWG47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Humeral Shaft, Percutaneous Endoscopic Approach */
"0PWG4JZ" = "1" /* Revision of Synthetic Substitute in Left Humeral Shaft, Percutaneous Endoscopic Approach */
"0PWG4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Humeral Shaft, Percutaneous Endoscopic Approach */
"0PWH04Z" = "1" /* Revision of Internal Fixation Device in Right Radius, Open Approach */
"0PWH05Z" = "1" /* Revision of External Fixation Device in Right Radius, Open Approach */
"0PWH07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Radius, Open Approach */
"0PWH0JZ" = "1" /* Revision of Synthetic Substitute in Right Radius, Open Approach */
"0PWH0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Radius, Open Approach */
"0PWH34Z" = "1" /* Revision of Internal Fixation Device in Right Radius, Percutaneous Approach */
"0PWH35Z" = "1" /* Revision of External Fixation Device in Right Radius, Percutaneous Approach */
"0PWH37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Radius, Percutaneous Approach */
"0PWH3JZ" = "1" /* Revision of Synthetic Substitute in Right Radius, Percutaneous Approach */
"0PWH3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Radius, Percutaneous Approach */
"0PWH44Z" = "1" /* Revision of Internal Fixation Device in Right Radius, Percutaneous Endoscopic Approach */
"0PWH45Z" = "1" /* Revision of External Fixation Device in Right Radius, Percutaneous Endoscopic Approach */
"0PWH47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Radius, Percutaneous Endoscopic Approach */
"0PWH4JZ" = "1" /* Revision of Synthetic Substitute in Right Radius, Percutaneous Endoscopic Approach */
"0PWH4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Radius, Percutaneous Endoscopic Approach */
"0PWJ04Z" = "1" /* Revision of Internal Fixation Device in Left Radius, Open Approach */
"0PWJ05Z" = "1" /* Revision of External Fixation Device in Left Radius, Open Approach */
"0PWJ07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Radius, Open Approach */
"0PWJ0JZ" = "1" /* Revision of Synthetic Substitute in Left Radius, Open Approach */
"0PWJ0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Radius, Open Approach */
"0PWJ34Z" = "1" /* Revision of Internal Fixation Device in Left Radius, Percutaneous Approach */
"0PWJ35Z" = "1" /* Revision of External Fixation Device in Left Radius, Percutaneous Approach */
"0PWJ37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Radius, Percutaneous Approach */
"0PWJ3JZ" = "1" /* Revision of Synthetic Substitute in Left Radius, Percutaneous Approach */
"0PWJ3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Radius, Percutaneous Approach */
"0PWJ44Z" = "1" /* Revision of Internal Fixation Device in Left Radius, Percutaneous Endoscopic Approach */
"0PWJ45Z" = "1" /* Revision of External Fixation Device in Left Radius, Percutaneous Endoscopic Approach */
"0PWJ47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Radius, Percutaneous Endoscopic Approach */
"0PWJ4JZ" = "1" /* Revision of Synthetic Substitute in Left Radius, Percutaneous Endoscopic Approach */
"0PWJ4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Radius, Percutaneous Endoscopic Approach */
"0PWK04Z" = "1" /* Revision of Internal Fixation Device in Right Ulna, Open Approach */
"0PWK05Z" = "1" /* Revision of External Fixation Device in Right Ulna, Open Approach */
"0PWK07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Ulna, Open Approach */
"0PWK0JZ" = "1" /* Revision of Synthetic Substitute in Right Ulna, Open Approach */
"0PWK0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Ulna, Open Approach */
"0PWK34Z" = "1" /* Revision of Internal Fixation Device in Right Ulna, Percutaneous Approach */
"0PWK35Z" = "1" /* Revision of External Fixation Device in Right Ulna, Percutaneous Approach */
"0PWK37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Ulna, Percutaneous Approach */
"0PWK3JZ" = "1" /* Revision of Synthetic Substitute in Right Ulna, Percutaneous Approach */
"0PWK3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Ulna, Percutaneous Approach */
"0PWK44Z" = "1" /* Revision of Internal Fixation Device in Right Ulna, Percutaneous Endoscopic Approach */
"0PWK45Z" = "1" /* Revision of External Fixation Device in Right Ulna, Percutaneous Endoscopic Approach */
"0PWK47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Ulna, Percutaneous Endoscopic Approach */
"0PWK4JZ" = "1" /* Revision of Synthetic Substitute in Right Ulna, Percutaneous Endoscopic Approach */
"0PWK4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Ulna, Percutaneous Endoscopic Approach */
"0PWL04Z" = "1" /* Revision of Internal Fixation Device in Left Ulna, Open Approach */
"0PWL05Z" = "1" /* Revision of External Fixation Device in Left Ulna, Open Approach */
"0PWL07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Ulna, Open Approach */
"0PWL0JZ" = "1" /* Revision of Synthetic Substitute in Left Ulna, Open Approach */
"0PWL0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Ulna, Open Approach */
"0PWL34Z" = "1" /* Revision of Internal Fixation Device in Left Ulna, Percutaneous Approach */
"0PWL35Z" = "1" /* Revision of External Fixation Device in Left Ulna, Percutaneous Approach */
"0PWL37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Ulna, Percutaneous Approach */
"0PWL3JZ" = "1" /* Revision of Synthetic Substitute in Left Ulna, Percutaneous Approach */
"0PWL3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Ulna, Percutaneous Approach */
"0PWL44Z" = "1" /* Revision of Internal Fixation Device in Left Ulna, Percutaneous Endoscopic Approach */
"0PWL45Z" = "1" /* Revision of External Fixation Device in Left Ulna, Percutaneous Endoscopic Approach */
"0PWL47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Ulna, Percutaneous Endoscopic Approach */
"0PWL4JZ" = "1" /* Revision of Synthetic Substitute in Left Ulna, Percutaneous Endoscopic Approach */
"0PWL4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Ulna, Percutaneous Endoscopic Approach */
"0PWM04Z" = "1" /* Revision of Internal Fixation Device in Right Carpal, Open Approach */
"0PWM05Z" = "1" /* Revision of External Fixation Device in Right Carpal, Open Approach */
"0PWM07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Carpal, Open Approach */
"0PWM0JZ" = "1" /* Revision of Synthetic Substitute in Right Carpal, Open Approach */
"0PWM0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Carpal, Open Approach */
"0PWM34Z" = "1" /* Revision of Internal Fixation Device in Right Carpal, Percutaneous Approach */
"0PWM35Z" = "1" /* Revision of External Fixation Device in Right Carpal, Percutaneous Approach */
"0PWM37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Carpal, Percutaneous Approach */
"0PWM3JZ" = "1" /* Revision of Synthetic Substitute in Right Carpal, Percutaneous Approach */
"0PWM3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Carpal, Percutaneous Approach */
"0PWM44Z" = "1" /* Revision of Internal Fixation Device in Right Carpal, Percutaneous Endoscopic Approach */
"0PWM45Z" = "1" /* Revision of External Fixation Device in Right Carpal, Percutaneous Endoscopic Approach */
"0PWM47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Carpal, Percutaneous Endoscopic Approach */
"0PWM4JZ" = "1" /* Revision of Synthetic Substitute in Right Carpal, Percutaneous Endoscopic Approach */
"0PWM4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Carpal, Percutaneous Endoscopic Approach */
"0PWN04Z" = "1" /* Revision of Internal Fixation Device in Left Carpal, Open Approach */
"0PWN05Z" = "1" /* Revision of External Fixation Device in Left Carpal, Open Approach */
"0PWN07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Carpal, Open Approach */
"0PWN0JZ" = "1" /* Revision of Synthetic Substitute in Left Carpal, Open Approach */
"0PWN0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Carpal, Open Approach */
"0PWN34Z" = "1" /* Revision of Internal Fixation Device in Left Carpal, Percutaneous Approach */
"0PWN35Z" = "1" /* Revision of External Fixation Device in Left Carpal, Percutaneous Approach */
"0PWN37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Carpal, Percutaneous Approach */
"0PWN3JZ" = "1" /* Revision of Synthetic Substitute in Left Carpal, Percutaneous Approach */
"0PWN3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Carpal, Percutaneous Approach */
"0PWN44Z" = "1" /* Revision of Internal Fixation Device in Left Carpal, Percutaneous Endoscopic Approach */
"0PWN45Z" = "1" /* Revision of External Fixation Device in Left Carpal, Percutaneous Endoscopic Approach */
"0PWN47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Carpal, Percutaneous Endoscopic Approach */
"0PWN4JZ" = "1" /* Revision of Synthetic Substitute in Left Carpal, Percutaneous Endoscopic Approach */
"0PWN4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Carpal, Percutaneous Endoscopic Approach */
"0PWP04Z" = "1" /* Revision of Internal Fixation Device in Right Metacarpal, Open Approach */
"0PWP05Z" = "1" /* Revision of External Fixation Device in Right Metacarpal, Open Approach */
"0PWP07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Metacarpal, Open Approach */
"0PWP0JZ" = "1" /* Revision of Synthetic Substitute in Right Metacarpal, Open Approach */
"0PWP0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Metacarpal, Open Approach */
"0PWP34Z" = "1" /* Revision of Internal Fixation Device in Right Metacarpal, Percutaneous Approach */
"0PWP35Z" = "1" /* Revision of External Fixation Device in Right Metacarpal, Percutaneous Approach */
"0PWP37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Metacarpal, Percutaneous Approach */
"0PWP3JZ" = "1" /* Revision of Synthetic Substitute in Right Metacarpal, Percutaneous Approach */
"0PWP3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Metacarpal, Percutaneous Approach */
"0PWP44Z" = "1" /* Revision of Internal Fixation Device in Right Metacarpal, Percutaneous Endoscopic Approach */
"0PWP45Z" = "1" /* Revision of External Fixation Device in Right Metacarpal, Percutaneous Endoscopic Approach */
"0PWP47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Metacarpal, Percutaneous Endoscopic Approach */
"0PWP4JZ" = "1" /* Revision of Synthetic Substitute in Right Metacarpal, Percutaneous Endoscopic Approach */
"0PWP4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Metacarpal, Percutaneous Endoscopic Approach */
"0PWQ04Z" = "1" /* Revision of Internal Fixation Device in Left Metacarpal, Open Approach */
"0PWQ05Z" = "1" /* Revision of External Fixation Device in Left Metacarpal, Open Approach */
"0PWQ07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Metacarpal, Open Approach */
"0PWQ0JZ" = "1" /* Revision of Synthetic Substitute in Left Metacarpal, Open Approach */
"0PWQ0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Metacarpal, Open Approach */
"0PWQ34Z" = "1" /* Revision of Internal Fixation Device in Left Metacarpal, Percutaneous Approach */
"0PWQ35Z" = "1" /* Revision of External Fixation Device in Left Metacarpal, Percutaneous Approach */
"0PWQ37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Metacarpal, Percutaneous Approach */
"0PWQ3JZ" = "1" /* Revision of Synthetic Substitute in Left Metacarpal, Percutaneous Approach */
"0PWQ3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Metacarpal, Percutaneous Approach */
"0PWQ44Z" = "1" /* Revision of Internal Fixation Device in Left Metacarpal, Percutaneous Endoscopic Approach */
"0PWQ45Z" = "1" /* Revision of External Fixation Device in Left Metacarpal, Percutaneous Endoscopic Approach */
"0PWQ47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Metacarpal, Percutaneous Endoscopic Approach */
"0PWQ4JZ" = "1" /* Revision of Synthetic Substitute in Left Metacarpal, Percutaneous Endoscopic Approach */
"0PWQ4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Metacarpal, Percutaneous Endoscopic Approach */
"0PWR04Z" = "1" /* Revision of Internal Fixation Device in Right Thumb Phalanx, Open Approach */
"0PWR05Z" = "1" /* Revision of External Fixation Device in Right Thumb Phalanx, Open Approach */
"0PWR07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Thumb Phalanx, Open Approach */
"0PWR0JZ" = "1" /* Revision of Synthetic Substitute in Right Thumb Phalanx, Open Approach */
"0PWR0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Thumb Phalanx, Open Approach */
"0PWR34Z" = "1" /* Revision of Internal Fixation Device in Right Thumb Phalanx, Percutaneous Approach */
"0PWR35Z" = "1" /* Revision of External Fixation Device in Right Thumb Phalanx, Percutaneous Approach */
"0PWR37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Thumb Phalanx, Percutaneous Approach */
"0PWR3JZ" = "1" /* Revision of Synthetic Substitute in Right Thumb Phalanx, Percutaneous Approach */
"0PWR3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Thumb Phalanx, Percutaneous Approach */
"0PWR44Z" = "1" /* Revision of Internal Fixation Device in Right Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PWR45Z" = "1" /* Revision of External Fixation Device in Right Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PWR47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PWR4JZ" = "1" /* Revision of Synthetic Substitute in Right Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PWR4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PWS04Z" = "1" /* Revision of Internal Fixation Device in Left Thumb Phalanx, Open Approach */
"0PWS05Z" = "1" /* Revision of External Fixation Device in Left Thumb Phalanx, Open Approach */
"0PWS07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Thumb Phalanx, Open Approach */
"0PWS0JZ" = "1" /* Revision of Synthetic Substitute in Left Thumb Phalanx, Open Approach */
"0PWS0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Thumb Phalanx, Open Approach */
"0PWS34Z" = "1" /* Revision of Internal Fixation Device in Left Thumb Phalanx, Percutaneous Approach */
"0PWS35Z" = "1" /* Revision of External Fixation Device in Left Thumb Phalanx, Percutaneous Approach */
"0PWS37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Thumb Phalanx, Percutaneous Approach */
"0PWS3JZ" = "1" /* Revision of Synthetic Substitute in Left Thumb Phalanx, Percutaneous Approach */
"0PWS3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Thumb Phalanx, Percutaneous Approach */
"0PWS44Z" = "1" /* Revision of Internal Fixation Device in Left Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PWS45Z" = "1" /* Revision of External Fixation Device in Left Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PWS47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PWS4JZ" = "1" /* Revision of Synthetic Substitute in Left Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PWS4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Thumb Phalanx, Percutaneous Endoscopic Approach */
"0PWT04Z" = "1" /* Revision of Internal Fixation Device in Right Finger Phalanx, Open Approach */
"0PWT05Z" = "1" /* Revision of External Fixation Device in Right Finger Phalanx, Open Approach */
"0PWT07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Finger Phalanx, Open Approach */
"0PWT0JZ" = "1" /* Revision of Synthetic Substitute in Right Finger Phalanx, Open Approach */
"0PWT0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Finger Phalanx, Open Approach */
"0PWT34Z" = "1" /* Revision of Internal Fixation Device in Right Finger Phalanx, Percutaneous Approach */
"0PWT35Z" = "1" /* Revision of External Fixation Device in Right Finger Phalanx, Percutaneous Approach */
"0PWT37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Finger Phalanx, Percutaneous Approach */
"0PWT3JZ" = "1" /* Revision of Synthetic Substitute in Right Finger Phalanx, Percutaneous Approach */
"0PWT3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Finger Phalanx, Percutaneous Approach */
"0PWT44Z" = "1" /* Revision of Internal Fixation Device in Right Finger Phalanx, Percutaneous Endoscopic Approach */
"0PWT45Z" = "1" /* Revision of External Fixation Device in Right Finger Phalanx, Percutaneous Endoscopic Approach */
"0PWT47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Finger Phalanx, Percutaneous Endoscopic Approach */
"0PWT4JZ" = "1" /* Revision of Synthetic Substitute in Right Finger Phalanx, Percutaneous Endoscopic Approach */
"0PWT4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Finger Phalanx, Percutaneous Endoscopic Approach */
"0PWV04Z" = "1" /* Revision of Internal Fixation Device in Left Finger Phalanx, Open Approach */
"0PWV05Z" = "1" /* Revision of External Fixation Device in Left Finger Phalanx, Open Approach */
"0PWV07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Finger Phalanx, Open Approach */
"0PWV0JZ" = "1" /* Revision of Synthetic Substitute in Left Finger Phalanx, Open Approach */
"0PWV0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Finger Phalanx, Open Approach */
"0PWV34Z" = "1" /* Revision of Internal Fixation Device in Left Finger Phalanx, Percutaneous Approach */
"0PWV35Z" = "1" /* Revision of External Fixation Device in Left Finger Phalanx, Percutaneous Approach */
"0PWV37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Finger Phalanx, Percutaneous Approach */
"0PWV3JZ" = "1" /* Revision of Synthetic Substitute in Left Finger Phalanx, Percutaneous Approach */
"0PWV3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Finger Phalanx, Percutaneous Approach */
"0PWV44Z" = "1" /* Revision of Internal Fixation Device in Left Finger Phalanx, Percutaneous Endoscopic Approach */
"0PWV45Z" = "1" /* Revision of External Fixation Device in Left Finger Phalanx, Percutaneous Endoscopic Approach */
"0PWV47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Finger Phalanx, Percutaneous Endoscopic Approach */
"0PWV4JZ" = "1" /* Revision of Synthetic Substitute in Left Finger Phalanx, Percutaneous Endoscopic Approach */
"0PWV4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Finger Phalanx, Percutaneous Endoscopic Approach */
"0PWY00Z" = "1" /* Revision of Drainage Device in Upper Bone, Open Approach */
"0PWY0MZ" = "1" /* Revision of Bone Growth Stimulator in Upper Bone, Open Approach */
"0PWY30Z" = "1" /* Revision of Drainage Device in Upper Bone, Percutaneous Approach */
"0PWY3MZ" = "1" /* Revision of Bone Growth Stimulator in Upper Bone, Percutaneous Approach */
"0PWY40Z" = "1" /* Revision of Drainage Device in Upper Bone, Percutaneous Endoscopic Approach */
"0PWY4MZ" = "1" /* Revision of Bone Growth Stimulator in Upper Bone, Percutaneous Endoscopic Approach */
"0Q500ZZ" = "1" /* Destruction of Lumbar Vertebra, Open Approach */
"0Q503ZZ" = "1" /* Destruction of Lumbar Vertebra, Percutaneous Approach */
"0Q504ZZ" = "1" /* Destruction of Lumbar Vertebra, Percutaneous Endoscopic Approach */
"0Q510ZZ" = "1" /* Destruction of Sacrum, Open Approach */
"0Q513ZZ" = "1" /* Destruction of Sacrum, Percutaneous Approach */
"0Q514ZZ" = "1" /* Destruction of Sacrum, Percutaneous Endoscopic Approach */
"0Q520ZZ" = "1" /* Destruction of Right Pelvic Bone, Open Approach */
"0Q523ZZ" = "1" /* Destruction of Right Pelvic Bone, Percutaneous Approach */
"0Q524ZZ" = "1" /* Destruction of Right Pelvic Bone, Percutaneous Endoscopic Approach */
"0Q530ZZ" = "1" /* Destruction of Left Pelvic Bone, Open Approach */
"0Q533ZZ" = "1" /* Destruction of Left Pelvic Bone, Percutaneous Approach */
"0Q534ZZ" = "1" /* Destruction of Left Pelvic Bone, Percutaneous Endoscopic Approach */
"0Q540ZZ" = "1" /* Destruction of Right Acetabulum, Open Approach */
"0Q543ZZ" = "1" /* Destruction of Right Acetabulum, Percutaneous Approach */
"0Q544ZZ" = "1" /* Destruction of Right Acetabulum, Percutaneous Endoscopic Approach */
"0Q550ZZ" = "1" /* Destruction of Left Acetabulum, Open Approach */
"0Q553ZZ" = "1" /* Destruction of Left Acetabulum, Percutaneous Approach */
"0Q554ZZ" = "1" /* Destruction of Left Acetabulum, Percutaneous Endoscopic Approach */
"0Q560ZZ" = "1" /* Destruction of Right Upper Femur, Open Approach */
"0Q563ZZ" = "1" /* Destruction of Right Upper Femur, Percutaneous Approach */
"0Q564ZZ" = "1" /* Destruction of Right Upper Femur, Percutaneous Endoscopic Approach */
"0Q570ZZ" = "1" /* Destruction of Left Upper Femur, Open Approach */
"0Q573ZZ" = "1" /* Destruction of Left Upper Femur, Percutaneous Approach */
"0Q574ZZ" = "1" /* Destruction of Left Upper Femur, Percutaneous Endoscopic Approach */
"0Q580ZZ" = "1" /* Destruction of Right Femoral Shaft, Open Approach */
"0Q583ZZ" = "1" /* Destruction of Right Femoral Shaft, Percutaneous Approach */
"0Q584ZZ" = "1" /* Destruction of Right Femoral Shaft, Percutaneous Endoscopic Approach */
"0Q590ZZ" = "1" /* Destruction of Left Femoral Shaft, Open Approach */
"0Q593ZZ" = "1" /* Destruction of Left Femoral Shaft, Percutaneous Approach */
"0Q594ZZ" = "1" /* Destruction of Left Femoral Shaft, Percutaneous Endoscopic Approach */
"0Q5B0ZZ" = "1" /* Destruction of Right Lower Femur, Open Approach */
"0Q5B3ZZ" = "1" /* Destruction of Right Lower Femur, Percutaneous Approach */
"0Q5B4ZZ" = "1" /* Destruction of Right Lower Femur, Percutaneous Endoscopic Approach */
"0Q5C0ZZ" = "1" /* Destruction of Left Lower Femur, Open Approach */
"0Q5C3ZZ" = "1" /* Destruction of Left Lower Femur, Percutaneous Approach */
"0Q5C4ZZ" = "1" /* Destruction of Left Lower Femur, Percutaneous Endoscopic Approach */
"0Q5D0ZZ" = "1" /* Destruction of Right Patella, Open Approach */
"0Q5D3ZZ" = "1" /* Destruction of Right Patella, Percutaneous Approach */
"0Q5D4ZZ" = "1" /* Destruction of Right Patella, Percutaneous Endoscopic Approach */
"0Q5F0ZZ" = "1" /* Destruction of Left Patella, Open Approach */
"0Q5F3ZZ" = "1" /* Destruction of Left Patella, Percutaneous Approach */
"0Q5F4ZZ" = "1" /* Destruction of Left Patella, Percutaneous Endoscopic Approach */
"0Q5G0ZZ" = "1" /* Destruction of Right Tibia, Open Approach */
"0Q5G3ZZ" = "1" /* Destruction of Right Tibia, Percutaneous Approach */
"0Q5G4ZZ" = "1" /* Destruction of Right Tibia, Percutaneous Endoscopic Approach */
"0Q5H0ZZ" = "1" /* Destruction of Left Tibia, Open Approach */
"0Q5H3ZZ" = "1" /* Destruction of Left Tibia, Percutaneous Approach */
"0Q5H4ZZ" = "1" /* Destruction of Left Tibia, Percutaneous Endoscopic Approach */
"0Q5J0ZZ" = "1" /* Destruction of Right Fibula, Open Approach */
"0Q5J3ZZ" = "1" /* Destruction of Right Fibula, Percutaneous Approach */
"0Q5J4ZZ" = "1" /* Destruction of Right Fibula, Percutaneous Endoscopic Approach */
"0Q5K0ZZ" = "1" /* Destruction of Left Fibula, Open Approach */
"0Q5K3ZZ" = "1" /* Destruction of Left Fibula, Percutaneous Approach */
"0Q5K4ZZ" = "1" /* Destruction of Left Fibula, Percutaneous Endoscopic Approach */
"0Q5L0ZZ" = "1" /* Destruction of Right Tarsal, Open Approach */
"0Q5L3ZZ" = "1" /* Destruction of Right Tarsal, Percutaneous Approach */
"0Q5L4ZZ" = "1" /* Destruction of Right Tarsal, Percutaneous Endoscopic Approach */
"0Q5M0ZZ" = "1" /* Destruction of Left Tarsal, Open Approach */
"0Q5M3ZZ" = "1" /* Destruction of Left Tarsal, Percutaneous Approach */
"0Q5M4ZZ" = "1" /* Destruction of Left Tarsal, Percutaneous Endoscopic Approach */
"0Q5N0ZZ" = "1" /* Destruction of Right Metatarsal, Open Approach */
"0Q5N3ZZ" = "1" /* Destruction of Right Metatarsal, Percutaneous Approach */
"0Q5N4ZZ" = "1" /* Destruction of Right Metatarsal, Percutaneous Endoscopic Approach */
"0Q5P0ZZ" = "1" /* Destruction of Left Metatarsal, Open Approach */
"0Q5P3ZZ" = "1" /* Destruction of Left Metatarsal, Percutaneous Approach */
"0Q5P4ZZ" = "1" /* Destruction of Left Metatarsal, Percutaneous Endoscopic Approach */
"0Q5Q0ZZ" = "1" /* Destruction of Right Toe Phalanx, Open Approach */
"0Q5Q3ZZ" = "1" /* Destruction of Right Toe Phalanx, Percutaneous Approach */
"0Q5Q4ZZ" = "1" /* Destruction of Right Toe Phalanx, Percutaneous Endoscopic Approach */
"0Q5R0ZZ" = "1" /* Destruction of Left Toe Phalanx, Open Approach */
"0Q5R3ZZ" = "1" /* Destruction of Left Toe Phalanx, Percutaneous Approach */
"0Q5R4ZZ" = "1" /* Destruction of Left Toe Phalanx, Percutaneous Endoscopic Approach */
"0Q5S0ZZ" = "1" /* Destruction of Coccyx, Open Approach */
"0Q5S3ZZ" = "1" /* Destruction of Coccyx, Percutaneous Approach */
"0Q5S4ZZ" = "1" /* Destruction of Coccyx, Percutaneous Endoscopic Approach */
"0Q800ZZ" = "1" /* Division of Lumbar Vertebra, Open Approach */
"0Q803ZZ" = "1" /* Division of Lumbar Vertebra, Percutaneous Approach */
"0Q804ZZ" = "1" /* Division of Lumbar Vertebra, Percutaneous Endoscopic Approach */
"0Q810ZZ" = "1" /* Division of Sacrum, Open Approach */
"0Q813ZZ" = "1" /* Division of Sacrum, Percutaneous Approach */
"0Q814ZZ" = "1" /* Division of Sacrum, Percutaneous Endoscopic Approach */
"0Q820ZZ" = "1" /* Division of Right Pelvic Bone, Open Approach */
"0Q823ZZ" = "1" /* Division of Right Pelvic Bone, Percutaneous Approach */
"0Q824ZZ" = "1" /* Division of Right Pelvic Bone, Percutaneous Endoscopic Approach */
"0Q830ZZ" = "1" /* Division of Left Pelvic Bone, Open Approach */
"0Q833ZZ" = "1" /* Division of Left Pelvic Bone, Percutaneous Approach */
"0Q834ZZ" = "1" /* Division of Left Pelvic Bone, Percutaneous Endoscopic Approach */
"0Q840ZZ" = "1" /* Division of Right Acetabulum, Open Approach */
"0Q843ZZ" = "1" /* Division of Right Acetabulum, Percutaneous Approach */
"0Q844ZZ" = "1" /* Division of Right Acetabulum, Percutaneous Endoscopic Approach */
"0Q850ZZ" = "1" /* Division of Left Acetabulum, Open Approach */
"0Q853ZZ" = "1" /* Division of Left Acetabulum, Percutaneous Approach */
"0Q854ZZ" = "1" /* Division of Left Acetabulum, Percutaneous Endoscopic Approach */
"0Q860ZZ" = "1" /* Division of Right Upper Femur, Open Approach */
"0Q863ZZ" = "1" /* Division of Right Upper Femur, Percutaneous Approach */
"0Q864ZZ" = "1" /* Division of Right Upper Femur, Percutaneous Endoscopic Approach */
"0Q870ZZ" = "1" /* Division of Left Upper Femur, Open Approach */
"0Q873ZZ" = "1" /* Division of Left Upper Femur, Percutaneous Approach */
"0Q874ZZ" = "1" /* Division of Left Upper Femur, Percutaneous Endoscopic Approach */
"0Q880ZZ" = "1" /* Division of Right Femoral Shaft, Open Approach */
"0Q883ZZ" = "1" /* Division of Right Femoral Shaft, Percutaneous Approach */
"0Q884ZZ" = "1" /* Division of Right Femoral Shaft, Percutaneous Endoscopic Approach */
"0Q890ZZ" = "1" /* Division of Left Femoral Shaft, Open Approach */
"0Q893ZZ" = "1" /* Division of Left Femoral Shaft, Percutaneous Approach */
"0Q894ZZ" = "1" /* Division of Left Femoral Shaft, Percutaneous Endoscopic Approach */
"0Q8B0ZZ" = "1" /* Division of Right Lower Femur, Open Approach */
"0Q8B3ZZ" = "1" /* Division of Right Lower Femur, Percutaneous Approach */
"0Q8B4ZZ" = "1" /* Division of Right Lower Femur, Percutaneous Endoscopic Approach */
"0Q8C0ZZ" = "1" /* Division of Left Lower Femur, Open Approach */
"0Q8C3ZZ" = "1" /* Division of Left Lower Femur, Percutaneous Approach */
"0Q8C4ZZ" = "1" /* Division of Left Lower Femur, Percutaneous Endoscopic Approach */
"0Q8D0ZZ" = "1" /* Division of Right Patella, Open Approach */
"0Q8D3ZZ" = "1" /* Division of Right Patella, Percutaneous Approach */
"0Q8D4ZZ" = "1" /* Division of Right Patella, Percutaneous Endoscopic Approach */
"0Q8F0ZZ" = "1" /* Division of Left Patella, Open Approach */
"0Q8F3ZZ" = "1" /* Division of Left Patella, Percutaneous Approach */
"0Q8F4ZZ" = "1" /* Division of Left Patella, Percutaneous Endoscopic Approach */
"0Q8G0ZZ" = "1" /* Division of Right Tibia, Open Approach */
"0Q8G3ZZ" = "1" /* Division of Right Tibia, Percutaneous Approach */
"0Q8G4ZZ" = "1" /* Division of Right Tibia, Percutaneous Endoscopic Approach */
"0Q8H0ZZ" = "1" /* Division of Left Tibia, Open Approach */
"0Q8H3ZZ" = "1" /* Division of Left Tibia, Percutaneous Approach */
"0Q8H4ZZ" = "1" /* Division of Left Tibia, Percutaneous Endoscopic Approach */
"0Q8J0ZZ" = "1" /* Division of Right Fibula, Open Approach */
"0Q8J3ZZ" = "1" /* Division of Right Fibula, Percutaneous Approach */
"0Q8J4ZZ" = "1" /* Division of Right Fibula, Percutaneous Endoscopic Approach */
"0Q8K0ZZ" = "1" /* Division of Left Fibula, Open Approach */
"0Q8K3ZZ" = "1" /* Division of Left Fibula, Percutaneous Approach */
"0Q8K4ZZ" = "1" /* Division of Left Fibula, Percutaneous Endoscopic Approach */
"0Q8L0ZZ" = "1" /* Division of Right Tarsal, Open Approach */
"0Q8L3ZZ" = "1" /* Division of Right Tarsal, Percutaneous Approach */
"0Q8L4ZZ" = "1" /* Division of Right Tarsal, Percutaneous Endoscopic Approach */
"0Q8M0ZZ" = "1" /* Division of Left Tarsal, Open Approach */
"0Q8M3ZZ" = "1" /* Division of Left Tarsal, Percutaneous Approach */
"0Q8M4ZZ" = "1" /* Division of Left Tarsal, Percutaneous Endoscopic Approach */
"0Q8N0ZZ" = "1" /* Division of Right Metatarsal, Open Approach */
"0Q8N3ZZ" = "1" /* Division of Right Metatarsal, Percutaneous Approach */
"0Q8N4ZZ" = "1" /* Division of Right Metatarsal, Percutaneous Endoscopic Approach */
"0Q8P0ZZ" = "1" /* Division of Left Metatarsal, Open Approach */
"0Q8P3ZZ" = "1" /* Division of Left Metatarsal, Percutaneous Approach */
"0Q8P4ZZ" = "1" /* Division of Left Metatarsal, Percutaneous Endoscopic Approach */
"0Q8Q0ZZ" = "1" /* Division of Right Toe Phalanx, Open Approach */
"0Q8Q3ZZ" = "1" /* Division of Right Toe Phalanx, Percutaneous Approach */
"0Q8Q4ZZ" = "1" /* Division of Right Toe Phalanx, Percutaneous Endoscopic Approach */
"0Q8R0ZZ" = "1" /* Division of Left Toe Phalanx, Open Approach */
"0Q8R3ZZ" = "1" /* Division of Left Toe Phalanx, Percutaneous Approach */
"0Q8R4ZZ" = "1" /* Division of Left Toe Phalanx, Percutaneous Endoscopic Approach */
"0Q8S0ZZ" = "1" /* Division of Coccyx, Open Approach */
"0Q8S3ZZ" = "1" /* Division of Coccyx, Percutaneous Approach */
"0Q8S4ZZ" = "1" /* Division of Coccyx, Percutaneous Endoscopic Approach */
"0Q9000Z" = "1" /* Drainage of Lumbar Vertebra with Drainage Device, Open Approach */
"0Q900ZX" = "1" /* Drainage of Lumbar Vertebra, Open Approach, Diagnostic */
"0Q900ZZ" = "1" /* Drainage of Lumbar Vertebra, Open Approach */
"0Q9040Z" = "1" /* Drainage of Lumbar Vertebra with Drainage Device, Percutaneous Endoscopic Approach */
"0Q904ZX" = "1" /* Drainage of Lumbar Vertebra, Percutaneous Endoscopic Approach, Diagnostic */
"0Q904ZZ" = "1" /* Drainage of Lumbar Vertebra, Percutaneous Endoscopic Approach */
"0Q9100Z" = "1" /* Drainage of Sacrum with Drainage Device, Open Approach */
"0Q910ZX" = "1" /* Drainage of Sacrum, Open Approach, Diagnostic */
"0Q910ZZ" = "1" /* Drainage of Sacrum, Open Approach */
"0Q9140Z" = "1" /* Drainage of Sacrum with Drainage Device, Percutaneous Endoscopic Approach */
"0Q914ZX" = "1" /* Drainage of Sacrum, Percutaneous Endoscopic Approach, Diagnostic */
"0Q914ZZ" = "1" /* Drainage of Sacrum, Percutaneous Endoscopic Approach */
"0Q9200Z" = "1" /* Drainage of Right Pelvic Bone with Drainage Device, Open Approach */
"0Q920ZX" = "1" /* Drainage of Right Pelvic Bone, Open Approach, Diagnostic */
"0Q920ZZ" = "1" /* Drainage of Right Pelvic Bone, Open Approach */
"0Q9240Z" = "1" /* Drainage of Right Pelvic Bone with Drainage Device, Percutaneous Endoscopic Approach */
"0Q924ZX" = "1" /* Drainage of Right Pelvic Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0Q924ZZ" = "1" /* Drainage of Right Pelvic Bone, Percutaneous Endoscopic Approach */
"0Q9300Z" = "1" /* Drainage of Left Pelvic Bone with Drainage Device, Open Approach */
"0Q930ZX" = "1" /* Drainage of Left Pelvic Bone, Open Approach, Diagnostic */
"0Q930ZZ" = "1" /* Drainage of Left Pelvic Bone, Open Approach */
"0Q9340Z" = "1" /* Drainage of Left Pelvic Bone with Drainage Device, Percutaneous Endoscopic Approach */
"0Q934ZX" = "1" /* Drainage of Left Pelvic Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0Q934ZZ" = "1" /* Drainage of Left Pelvic Bone, Percutaneous Endoscopic Approach */
"0Q9400Z" = "1" /* Drainage of Right Acetabulum with Drainage Device, Open Approach */
"0Q940ZX" = "1" /* Drainage of Right Acetabulum, Open Approach, Diagnostic */
"0Q940ZZ" = "1" /* Drainage of Right Acetabulum, Open Approach */
"0Q9440Z" = "1" /* Drainage of Right Acetabulum with Drainage Device, Percutaneous Endoscopic Approach */
"0Q944ZX" = "1" /* Drainage of Right Acetabulum, Percutaneous Endoscopic Approach, Diagnostic */
"0Q944ZZ" = "1" /* Drainage of Right Acetabulum, Percutaneous Endoscopic Approach */
"0Q9500Z" = "1" /* Drainage of Left Acetabulum with Drainage Device, Open Approach */
"0Q950ZX" = "1" /* Drainage of Left Acetabulum, Open Approach, Diagnostic */
"0Q950ZZ" = "1" /* Drainage of Left Acetabulum, Open Approach */
"0Q9540Z" = "1" /* Drainage of Left Acetabulum with Drainage Device, Percutaneous Endoscopic Approach */
"0Q954ZX" = "1" /* Drainage of Left Acetabulum, Percutaneous Endoscopic Approach, Diagnostic */
"0Q954ZZ" = "1" /* Drainage of Left Acetabulum, Percutaneous Endoscopic Approach */
"0Q9600Z" = "1" /* Drainage of Right Upper Femur with Drainage Device, Open Approach */
"0Q960ZX" = "1" /* Drainage of Right Upper Femur, Open Approach, Diagnostic */
"0Q960ZZ" = "1" /* Drainage of Right Upper Femur, Open Approach */
"0Q9640Z" = "1" /* Drainage of Right Upper Femur with Drainage Device, Percutaneous Endoscopic Approach */
"0Q964ZX" = "1" /* Drainage of Right Upper Femur, Percutaneous Endoscopic Approach, Diagnostic */
"0Q964ZZ" = "1" /* Drainage of Right Upper Femur, Percutaneous Endoscopic Approach */
"0Q9700Z" = "1" /* Drainage of Left Upper Femur with Drainage Device, Open Approach */
"0Q970ZX" = "1" /* Drainage of Left Upper Femur, Open Approach, Diagnostic */
"0Q970ZZ" = "1" /* Drainage of Left Upper Femur, Open Approach */
"0Q9740Z" = "1" /* Drainage of Left Upper Femur with Drainage Device, Percutaneous Endoscopic Approach */
"0Q974ZX" = "1" /* Drainage of Left Upper Femur, Percutaneous Endoscopic Approach, Diagnostic */
"0Q974ZZ" = "1" /* Drainage of Left Upper Femur, Percutaneous Endoscopic Approach */
"0Q9800Z" = "1" /* Drainage of Right Femoral Shaft with Drainage Device, Open Approach */
"0Q980ZX" = "1" /* Drainage of Right Femoral Shaft, Open Approach, Diagnostic */
"0Q980ZZ" = "1" /* Drainage of Right Femoral Shaft, Open Approach */
"0Q9840Z" = "1" /* Drainage of Right Femoral Shaft with Drainage Device, Percutaneous Endoscopic Approach */
"0Q984ZX" = "1" /* Drainage of Right Femoral Shaft, Percutaneous Endoscopic Approach, Diagnostic */
"0Q984ZZ" = "1" /* Drainage of Right Femoral Shaft, Percutaneous Endoscopic Approach */
"0Q9900Z" = "1" /* Drainage of Left Femoral Shaft with Drainage Device, Open Approach */
"0Q990ZX" = "1" /* Drainage of Left Femoral Shaft, Open Approach, Diagnostic */
"0Q990ZZ" = "1" /* Drainage of Left Femoral Shaft, Open Approach */
"0Q9940Z" = "1" /* Drainage of Left Femoral Shaft with Drainage Device, Percutaneous Endoscopic Approach */
"0Q994ZX" = "1" /* Drainage of Left Femoral Shaft, Percutaneous Endoscopic Approach, Diagnostic */
"0Q994ZZ" = "1" /* Drainage of Left Femoral Shaft, Percutaneous Endoscopic Approach */
"0Q9B00Z" = "1" /* Drainage of Right Lower Femur with Drainage Device, Open Approach */
"0Q9B0ZX" = "1" /* Drainage of Right Lower Femur, Open Approach, Diagnostic */
"0Q9B0ZZ" = "1" /* Drainage of Right Lower Femur, Open Approach */
"0Q9B40Z" = "1" /* Drainage of Right Lower Femur with Drainage Device, Percutaneous Endoscopic Approach */
"0Q9B4ZX" = "1" /* Drainage of Right Lower Femur, Percutaneous Endoscopic Approach, Diagnostic */
"0Q9B4ZZ" = "1" /* Drainage of Right Lower Femur, Percutaneous Endoscopic Approach */
"0Q9C00Z" = "1" /* Drainage of Left Lower Femur with Drainage Device, Open Approach */
"0Q9C0ZX" = "1" /* Drainage of Left Lower Femur, Open Approach, Diagnostic */
"0Q9C0ZZ" = "1" /* Drainage of Left Lower Femur, Open Approach */
"0Q9C40Z" = "1" /* Drainage of Left Lower Femur with Drainage Device, Percutaneous Endoscopic Approach */
"0Q9C4ZX" = "1" /* Drainage of Left Lower Femur, Percutaneous Endoscopic Approach, Diagnostic */
"0Q9C4ZZ" = "1" /* Drainage of Left Lower Femur, Percutaneous Endoscopic Approach */
"0Q9D00Z" = "1" /* Drainage of Right Patella with Drainage Device, Open Approach */
"0Q9D0ZX" = "1" /* Drainage of Right Patella, Open Approach, Diagnostic */
"0Q9D0ZZ" = "1" /* Drainage of Right Patella, Open Approach */
"0Q9D40Z" = "1" /* Drainage of Right Patella with Drainage Device, Percutaneous Endoscopic Approach */
"0Q9D4ZX" = "1" /* Drainage of Right Patella, Percutaneous Endoscopic Approach, Diagnostic */
"0Q9D4ZZ" = "1" /* Drainage of Right Patella, Percutaneous Endoscopic Approach */
"0Q9F00Z" = "1" /* Drainage of Left Patella with Drainage Device, Open Approach */
"0Q9F0ZX" = "1" /* Drainage of Left Patella, Open Approach, Diagnostic */
"0Q9F0ZZ" = "1" /* Drainage of Left Patella, Open Approach */
"0Q9F40Z" = "1" /* Drainage of Left Patella with Drainage Device, Percutaneous Endoscopic Approach */
"0Q9F4ZX" = "1" /* Drainage of Left Patella, Percutaneous Endoscopic Approach, Diagnostic */
"0Q9F4ZZ" = "1" /* Drainage of Left Patella, Percutaneous Endoscopic Approach */
"0Q9G00Z" = "1" /* Drainage of Right Tibia with Drainage Device, Open Approach */
"0Q9G0ZX" = "1" /* Drainage of Right Tibia, Open Approach, Diagnostic */
"0Q9G0ZZ" = "1" /* Drainage of Right Tibia, Open Approach */
"0Q9G40Z" = "1" /* Drainage of Right Tibia with Drainage Device, Percutaneous Endoscopic Approach */
"0Q9G4ZX" = "1" /* Drainage of Right Tibia, Percutaneous Endoscopic Approach, Diagnostic */
"0Q9G4ZZ" = "1" /* Drainage of Right Tibia, Percutaneous Endoscopic Approach */
"0Q9H00Z" = "1" /* Drainage of Left Tibia with Drainage Device, Open Approach */
"0Q9H0ZX" = "1" /* Drainage of Left Tibia, Open Approach, Diagnostic */
"0Q9H0ZZ" = "1" /* Drainage of Left Tibia, Open Approach */
"0Q9H40Z" = "1" /* Drainage of Left Tibia with Drainage Device, Percutaneous Endoscopic Approach */
"0Q9H4ZX" = "1" /* Drainage of Left Tibia, Percutaneous Endoscopic Approach, Diagnostic */
"0Q9H4ZZ" = "1" /* Drainage of Left Tibia, Percutaneous Endoscopic Approach */
"0Q9J00Z" = "1" /* Drainage of Right Fibula with Drainage Device, Open Approach */
"0Q9J0ZX" = "1" /* Drainage of Right Fibula, Open Approach, Diagnostic */
"0Q9J0ZZ" = "1" /* Drainage of Right Fibula, Open Approach */
"0Q9J40Z" = "1" /* Drainage of Right Fibula with Drainage Device, Percutaneous Endoscopic Approach */
"0Q9J4ZX" = "1" /* Drainage of Right Fibula, Percutaneous Endoscopic Approach, Diagnostic */
"0Q9J4ZZ" = "1" /* Drainage of Right Fibula, Percutaneous Endoscopic Approach */
"0Q9K00Z" = "1" /* Drainage of Left Fibula with Drainage Device, Open Approach */
"0Q9K0ZX" = "1" /* Drainage of Left Fibula, Open Approach, Diagnostic */
"0Q9K0ZZ" = "1" /* Drainage of Left Fibula, Open Approach */
"0Q9K40Z" = "1" /* Drainage of Left Fibula with Drainage Device, Percutaneous Endoscopic Approach */
"0Q9K4ZX" = "1" /* Drainage of Left Fibula, Percutaneous Endoscopic Approach, Diagnostic */
"0Q9K4ZZ" = "1" /* Drainage of Left Fibula, Percutaneous Endoscopic Approach */
"0Q9L00Z" = "1" /* Drainage of Right Tarsal with Drainage Device, Open Approach */
"0Q9L0ZX" = "1" /* Drainage of Right Tarsal, Open Approach, Diagnostic */
"0Q9L0ZZ" = "1" /* Drainage of Right Tarsal, Open Approach */
"0Q9L40Z" = "1" /* Drainage of Right Tarsal with Drainage Device, Percutaneous Endoscopic Approach */
"0Q9L4ZX" = "1" /* Drainage of Right Tarsal, Percutaneous Endoscopic Approach, Diagnostic */
"0Q9L4ZZ" = "1" /* Drainage of Right Tarsal, Percutaneous Endoscopic Approach */
"0Q9M00Z" = "1" /* Drainage of Left Tarsal with Drainage Device, Open Approach */
"0Q9M0ZX" = "1" /* Drainage of Left Tarsal, Open Approach, Diagnostic */
"0Q9M0ZZ" = "1" /* Drainage of Left Tarsal, Open Approach */
"0Q9M40Z" = "1" /* Drainage of Left Tarsal with Drainage Device, Percutaneous Endoscopic Approach */
"0Q9M4ZX" = "1" /* Drainage of Left Tarsal, Percutaneous Endoscopic Approach, Diagnostic */
"0Q9M4ZZ" = "1" /* Drainage of Left Tarsal, Percutaneous Endoscopic Approach */
"0Q9N00Z" = "1" /* Drainage of Right Metatarsal with Drainage Device, Open Approach */
"0Q9N0ZX" = "1" /* Drainage of Right Metatarsal, Open Approach, Diagnostic */
"0Q9N0ZZ" = "1" /* Drainage of Right Metatarsal, Open Approach */
"0Q9N40Z" = "1" /* Drainage of Right Metatarsal with Drainage Device, Percutaneous Endoscopic Approach */
"0Q9N4ZX" = "1" /* Drainage of Right Metatarsal, Percutaneous Endoscopic Approach, Diagnostic */
"0Q9N4ZZ" = "1" /* Drainage of Right Metatarsal, Percutaneous Endoscopic Approach */
"0Q9P00Z" = "1" /* Drainage of Left Metatarsal with Drainage Device, Open Approach */
"0Q9P0ZX" = "1" /* Drainage of Left Metatarsal, Open Approach, Diagnostic */
"0Q9P0ZZ" = "1" /* Drainage of Left Metatarsal, Open Approach */
"0Q9P40Z" = "1" /* Drainage of Left Metatarsal with Drainage Device, Percutaneous Endoscopic Approach */
"0Q9P4ZX" = "1" /* Drainage of Left Metatarsal, Percutaneous Endoscopic Approach, Diagnostic */
"0Q9P4ZZ" = "1" /* Drainage of Left Metatarsal, Percutaneous Endoscopic Approach */
"0Q9Q00Z" = "1" /* Drainage of Right Toe Phalanx with Drainage Device, Open Approach */
"0Q9Q0ZX" = "1" /* Drainage of Right Toe Phalanx, Open Approach, Diagnostic */
"0Q9Q0ZZ" = "1" /* Drainage of Right Toe Phalanx, Open Approach */
"0Q9Q40Z" = "1" /* Drainage of Right Toe Phalanx with Drainage Device, Percutaneous Endoscopic Approach */
"0Q9Q4ZX" = "1" /* Drainage of Right Toe Phalanx, Percutaneous Endoscopic Approach, Diagnostic */
"0Q9Q4ZZ" = "1" /* Drainage of Right Toe Phalanx, Percutaneous Endoscopic Approach */
"0Q9R00Z" = "1" /* Drainage of Left Toe Phalanx with Drainage Device, Open Approach */
"0Q9R0ZX" = "1" /* Drainage of Left Toe Phalanx, Open Approach, Diagnostic */
"0Q9R0ZZ" = "1" /* Drainage of Left Toe Phalanx, Open Approach */
"0Q9R40Z" = "1" /* Drainage of Left Toe Phalanx with Drainage Device, Percutaneous Endoscopic Approach */
"0Q9R4ZX" = "1" /* Drainage of Left Toe Phalanx, Percutaneous Endoscopic Approach, Diagnostic */
"0Q9R4ZZ" = "1" /* Drainage of Left Toe Phalanx, Percutaneous Endoscopic Approach */
"0Q9S00Z" = "1" /* Drainage of Coccyx with Drainage Device, Open Approach */
"0Q9S0ZX" = "1" /* Drainage of Coccyx, Open Approach, Diagnostic */
"0Q9S0ZZ" = "1" /* Drainage of Coccyx, Open Approach */
"0Q9S40Z" = "1" /* Drainage of Coccyx with Drainage Device, Percutaneous Endoscopic Approach */
"0Q9S4ZX" = "1" /* Drainage of Coccyx, Percutaneous Endoscopic Approach, Diagnostic */
"0Q9S4ZZ" = "1" /* Drainage of Coccyx, Percutaneous Endoscopic Approach */
"0QB00ZX" = "1" /* Excision of Lumbar Vertebra, Open Approach, Diagnostic */
"0QB00ZZ" = "1" /* Excision of Lumbar Vertebra, Open Approach */
"0QB03ZX" = "1" /* Excision of Lumbar Vertebra, Percutaneous Approach, Diagnostic */
"0QB03ZZ" = "1" /* Excision of Lumbar Vertebra, Percutaneous Approach */
"0QB04ZX" = "1" /* Excision of Lumbar Vertebra, Percutaneous Endoscopic Approach, Diagnostic */
"0QB04ZZ" = "1" /* Excision of Lumbar Vertebra, Percutaneous Endoscopic Approach */
"0QB10ZX" = "1" /* Excision of Sacrum, Open Approach, Diagnostic */
"0QB10ZZ" = "1" /* Excision of Sacrum, Open Approach */
"0QB13ZX" = "1" /* Excision of Sacrum, Percutaneous Approach, Diagnostic */
"0QB13ZZ" = "1" /* Excision of Sacrum, Percutaneous Approach */
"0QB14ZX" = "1" /* Excision of Sacrum, Percutaneous Endoscopic Approach, Diagnostic */
"0QB14ZZ" = "1" /* Excision of Sacrum, Percutaneous Endoscopic Approach */
"0QB20ZX" = "1" /* Excision of Right Pelvic Bone, Open Approach, Diagnostic */
"0QB20ZZ" = "1" /* Excision of Right Pelvic Bone, Open Approach */
"0QB23ZX" = "1" /* Excision of Right Pelvic Bone, Percutaneous Approach, Diagnostic */
"0QB23ZZ" = "1" /* Excision of Right Pelvic Bone, Percutaneous Approach */
"0QB24ZX" = "1" /* Excision of Right Pelvic Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0QB24ZZ" = "1" /* Excision of Right Pelvic Bone, Percutaneous Endoscopic Approach */
"0QB30ZX" = "1" /* Excision of Left Pelvic Bone, Open Approach, Diagnostic */
"0QB30ZZ" = "1" /* Excision of Left Pelvic Bone, Open Approach */
"0QB33ZX" = "1" /* Excision of Left Pelvic Bone, Percutaneous Approach, Diagnostic */
"0QB33ZZ" = "1" /* Excision of Left Pelvic Bone, Percutaneous Approach */
"0QB34ZX" = "1" /* Excision of Left Pelvic Bone, Percutaneous Endoscopic Approach, Diagnostic */
"0QB34ZZ" = "1" /* Excision of Left Pelvic Bone, Percutaneous Endoscopic Approach */
"0QB40ZX" = "1" /* Excision of Right Acetabulum, Open Approach, Diagnostic */
"0QB40ZZ" = "1" /* Excision of Right Acetabulum, Open Approach */
"0QB43ZX" = "1" /* Excision of Right Acetabulum, Percutaneous Approach, Diagnostic */
"0QB43ZZ" = "1" /* Excision of Right Acetabulum, Percutaneous Approach */
"0QB44ZX" = "1" /* Excision of Right Acetabulum, Percutaneous Endoscopic Approach, Diagnostic */
"0QB44ZZ" = "1" /* Excision of Right Acetabulum, Percutaneous Endoscopic Approach */
"0QB50ZX" = "1" /* Excision of Left Acetabulum, Open Approach, Diagnostic */
"0QB50ZZ" = "1" /* Excision of Left Acetabulum, Open Approach */
"0QB53ZX" = "1" /* Excision of Left Acetabulum, Percutaneous Approach, Diagnostic */
"0QB53ZZ" = "1" /* Excision of Left Acetabulum, Percutaneous Approach */
"0QB54ZX" = "1" /* Excision of Left Acetabulum, Percutaneous Endoscopic Approach, Diagnostic */
"0QB54ZZ" = "1" /* Excision of Left Acetabulum, Percutaneous Endoscopic Approach */
"0QB60ZX" = "1" /* Excision of Right Upper Femur, Open Approach, Diagnostic */
"0QB60ZZ" = "1" /* Excision of Right Upper Femur, Open Approach */
"0QB63ZX" = "1" /* Excision of Right Upper Femur, Percutaneous Approach, Diagnostic */
"0QB63ZZ" = "1" /* Excision of Right Upper Femur, Percutaneous Approach */
"0QB64ZX" = "1" /* Excision of Right Upper Femur, Percutaneous Endoscopic Approach, Diagnostic */
"0QB64ZZ" = "1" /* Excision of Right Upper Femur, Percutaneous Endoscopic Approach */
"0QB70ZX" = "1" /* Excision of Left Upper Femur, Open Approach, Diagnostic */
"0QB70ZZ" = "1" /* Excision of Left Upper Femur, Open Approach */
"0QB73ZX" = "1" /* Excision of Left Upper Femur, Percutaneous Approach, Diagnostic */
"0QB73ZZ" = "1" /* Excision of Left Upper Femur, Percutaneous Approach */
"0QB74ZX" = "1" /* Excision of Left Upper Femur, Percutaneous Endoscopic Approach, Diagnostic */
"0QB74ZZ" = "1" /* Excision of Left Upper Femur, Percutaneous Endoscopic Approach */
"0QB80ZX" = "1" /* Excision of Right Femoral Shaft, Open Approach, Diagnostic */
"0QB80ZZ" = "1" /* Excision of Right Femoral Shaft, Open Approach */
"0QB83ZX" = "1" /* Excision of Right Femoral Shaft, Percutaneous Approach, Diagnostic */
"0QB83ZZ" = "1" /* Excision of Right Femoral Shaft, Percutaneous Approach */
"0QB84ZX" = "1" /* Excision of Right Femoral Shaft, Percutaneous Endoscopic Approach, Diagnostic */
"0QB84ZZ" = "1" /* Excision of Right Femoral Shaft, Percutaneous Endoscopic Approach */
"0QB90ZX" = "1" /* Excision of Left Femoral Shaft, Open Approach, Diagnostic */
"0QB90ZZ" = "1" /* Excision of Left Femoral Shaft, Open Approach */
"0QB93ZX" = "1" /* Excision of Left Femoral Shaft, Percutaneous Approach, Diagnostic */
"0QB93ZZ" = "1" /* Excision of Left Femoral Shaft, Percutaneous Approach */
"0QB94ZX" = "1" /* Excision of Left Femoral Shaft, Percutaneous Endoscopic Approach, Diagnostic */
"0QB94ZZ" = "1" /* Excision of Left Femoral Shaft, Percutaneous Endoscopic Approach */
"0QBB0ZX" = "1" /* Excision of Right Lower Femur, Open Approach, Diagnostic */
"0QBB0ZZ" = "1" /* Excision of Right Lower Femur, Open Approach */
"0QBB3ZX" = "1" /* Excision of Right Lower Femur, Percutaneous Approach, Diagnostic */
"0QBB3ZZ" = "1" /* Excision of Right Lower Femur, Percutaneous Approach */
"0QBB4ZX" = "1" /* Excision of Right Lower Femur, Percutaneous Endoscopic Approach, Diagnostic */
"0QBB4ZZ" = "1" /* Excision of Right Lower Femur, Percutaneous Endoscopic Approach */
"0QBC0ZX" = "1" /* Excision of Left Lower Femur, Open Approach, Diagnostic */
"0QBC0ZZ" = "1" /* Excision of Left Lower Femur, Open Approach */
"0QBC3ZX" = "1" /* Excision of Left Lower Femur, Percutaneous Approach, Diagnostic */
"0QBC3ZZ" = "1" /* Excision of Left Lower Femur, Percutaneous Approach */
"0QBC4ZX" = "1" /* Excision of Left Lower Femur, Percutaneous Endoscopic Approach, Diagnostic */
"0QBC4ZZ" = "1" /* Excision of Left Lower Femur, Percutaneous Endoscopic Approach */
"0QBD0ZX" = "1" /* Excision of Right Patella, Open Approach, Diagnostic */
"0QBD0ZZ" = "1" /* Excision of Right Patella, Open Approach */
"0QBD3ZX" = "1" /* Excision of Right Patella, Percutaneous Approach, Diagnostic */
"0QBD3ZZ" = "1" /* Excision of Right Patella, Percutaneous Approach */
"0QBD4ZX" = "1" /* Excision of Right Patella, Percutaneous Endoscopic Approach, Diagnostic */
"0QBD4ZZ" = "1" /* Excision of Right Patella, Percutaneous Endoscopic Approach */
"0QBF0ZX" = "1" /* Excision of Left Patella, Open Approach, Diagnostic */
"0QBF0ZZ" = "1" /* Excision of Left Patella, Open Approach */
"0QBF3ZX" = "1" /* Excision of Left Patella, Percutaneous Approach, Diagnostic */
"0QBF3ZZ" = "1" /* Excision of Left Patella, Percutaneous Approach */
"0QBF4ZX" = "1" /* Excision of Left Patella, Percutaneous Endoscopic Approach, Diagnostic */
"0QBF4ZZ" = "1" /* Excision of Left Patella, Percutaneous Endoscopic Approach */
"0QBG0ZX" = "1" /* Excision of Right Tibia, Open Approach, Diagnostic */
"0QBG0ZZ" = "1" /* Excision of Right Tibia, Open Approach */
"0QBG3ZX" = "1" /* Excision of Right Tibia, Percutaneous Approach, Diagnostic */
"0QBG3ZZ" = "1" /* Excision of Right Tibia, Percutaneous Approach */
"0QBG4ZX" = "1" /* Excision of Right Tibia, Percutaneous Endoscopic Approach, Diagnostic */
"0QBG4ZZ" = "1" /* Excision of Right Tibia, Percutaneous Endoscopic Approach */
"0QBH0ZX" = "1" /* Excision of Left Tibia, Open Approach, Diagnostic */
"0QBH0ZZ" = "1" /* Excision of Left Tibia, Open Approach */
"0QBH3ZX" = "1" /* Excision of Left Tibia, Percutaneous Approach, Diagnostic */
"0QBH3ZZ" = "1" /* Excision of Left Tibia, Percutaneous Approach */
"0QBH4ZX" = "1" /* Excision of Left Tibia, Percutaneous Endoscopic Approach, Diagnostic */
"0QBH4ZZ" = "1" /* Excision of Left Tibia, Percutaneous Endoscopic Approach */
"0QBJ0ZX" = "1" /* Excision of Right Fibula, Open Approach, Diagnostic */
"0QBJ0ZZ" = "1" /* Excision of Right Fibula, Open Approach */
"0QBJ3ZX" = "1" /* Excision of Right Fibula, Percutaneous Approach, Diagnostic */
"0QBJ3ZZ" = "1" /* Excision of Right Fibula, Percutaneous Approach */
"0QBJ4ZX" = "1" /* Excision of Right Fibula, Percutaneous Endoscopic Approach, Diagnostic */
"0QBJ4ZZ" = "1" /* Excision of Right Fibula, Percutaneous Endoscopic Approach */
"0QBK0ZX" = "1" /* Excision of Left Fibula, Open Approach, Diagnostic */
"0QBK0ZZ" = "1" /* Excision of Left Fibula, Open Approach */
"0QBK3ZX" = "1" /* Excision of Left Fibula, Percutaneous Approach, Diagnostic */
"0QBK3ZZ" = "1" /* Excision of Left Fibula, Percutaneous Approach */
"0QBK4ZX" = "1" /* Excision of Left Fibula, Percutaneous Endoscopic Approach, Diagnostic */
"0QBK4ZZ" = "1" /* Excision of Left Fibula, Percutaneous Endoscopic Approach */
"0QBL0ZX" = "1" /* Excision of Right Tarsal, Open Approach, Diagnostic */
"0QBL0ZZ" = "1" /* Excision of Right Tarsal, Open Approach */
"0QBL3ZX" = "1" /* Excision of Right Tarsal, Percutaneous Approach, Diagnostic */
"0QBL3ZZ" = "1" /* Excision of Right Tarsal, Percutaneous Approach */
"0QBL4ZX" = "1" /* Excision of Right Tarsal, Percutaneous Endoscopic Approach, Diagnostic */
"0QBL4ZZ" = "1" /* Excision of Right Tarsal, Percutaneous Endoscopic Approach */
"0QBM0ZX" = "1" /* Excision of Left Tarsal, Open Approach, Diagnostic */
"0QBM0ZZ" = "1" /* Excision of Left Tarsal, Open Approach */
"0QBM3ZX" = "1" /* Excision of Left Tarsal, Percutaneous Approach, Diagnostic */
"0QBM3ZZ" = "1" /* Excision of Left Tarsal, Percutaneous Approach */
"0QBM4ZX" = "1" /* Excision of Left Tarsal, Percutaneous Endoscopic Approach, Diagnostic */
"0QBM4ZZ" = "1" /* Excision of Left Tarsal, Percutaneous Endoscopic Approach */
"0QBN0ZX" = "1" /* Excision of Right Metatarsal, Open Approach, Diagnostic */
"0QBN0ZZ" = "1" /* Excision of Right Metatarsal, Open Approach */
"0QBN3ZX" = "1" /* Excision of Right Metatarsal, Percutaneous Approach, Diagnostic */
"0QBN3ZZ" = "1" /* Excision of Right Metatarsal, Percutaneous Approach */
"0QBN4ZX" = "1" /* Excision of Right Metatarsal, Percutaneous Endoscopic Approach, Diagnostic */
"0QBN4ZZ" = "1" /* Excision of Right Metatarsal, Percutaneous Endoscopic Approach */
"0QBP0ZX" = "1" /* Excision of Left Metatarsal, Open Approach, Diagnostic */
"0QBP0ZZ" = "1" /* Excision of Left Metatarsal, Open Approach */
"0QBP3ZX" = "1" /* Excision of Left Metatarsal, Percutaneous Approach, Diagnostic */
"0QBP3ZZ" = "1" /* Excision of Left Metatarsal, Percutaneous Approach */
"0QBP4ZX" = "1" /* Excision of Left Metatarsal, Percutaneous Endoscopic Approach, Diagnostic */
"0QBP4ZZ" = "1" /* Excision of Left Metatarsal, Percutaneous Endoscopic Approach */
"0QBQ0ZX" = "1" /* Excision of Right Toe Phalanx, Open Approach, Diagnostic */
"0QBQ0ZZ" = "1" /* Excision of Right Toe Phalanx, Open Approach */
"0QBQ3ZX" = "1" /* Excision of Right Toe Phalanx, Percutaneous Approach, Diagnostic */
"0QBQ3ZZ" = "1" /* Excision of Right Toe Phalanx, Percutaneous Approach */
"0QBQ4ZX" = "1" /* Excision of Right Toe Phalanx, Percutaneous Endoscopic Approach, Diagnostic */
"0QBQ4ZZ" = "1" /* Excision of Right Toe Phalanx, Percutaneous Endoscopic Approach */
"0QBR0ZX" = "1" /* Excision of Left Toe Phalanx, Open Approach, Diagnostic */
"0QBR0ZZ" = "1" /* Excision of Left Toe Phalanx, Open Approach */
"0QBR3ZX" = "1" /* Excision of Left Toe Phalanx, Percutaneous Approach, Diagnostic */
"0QBR3ZZ" = "1" /* Excision of Left Toe Phalanx, Percutaneous Approach */
"0QBR4ZX" = "1" /* Excision of Left Toe Phalanx, Percutaneous Endoscopic Approach, Diagnostic */
"0QBR4ZZ" = "1" /* Excision of Left Toe Phalanx, Percutaneous Endoscopic Approach */
"0QBS0ZX" = "1" /* Excision of Coccyx, Open Approach, Diagnostic */
"0QBS0ZZ" = "1" /* Excision of Coccyx, Open Approach */
"0QBS3ZX" = "1" /* Excision of Coccyx, Percutaneous Approach, Diagnostic */
"0QBS3ZZ" = "1" /* Excision of Coccyx, Percutaneous Approach */
"0QBS4ZX" = "1" /* Excision of Coccyx, Percutaneous Endoscopic Approach, Diagnostic */
"0QBS4ZZ" = "1" /* Excision of Coccyx, Percutaneous Endoscopic Approach */
"0QC00ZZ" = "1" /* Extirpation of Matter from Lumbar Vertebra, Open Approach */
"0QC03ZZ" = "1" /* Extirpation of Matter from Lumbar Vertebra, Percutaneous Approach */
"0QC04ZZ" = "1" /* Extirpation of Matter from Lumbar Vertebra, Percutaneous Endoscopic Approach */
"0QC10ZZ" = "1" /* Extirpation of Matter from Sacrum, Open Approach */
"0QC13ZZ" = "1" /* Extirpation of Matter from Sacrum, Percutaneous Approach */
"0QC14ZZ" = "1" /* Extirpation of Matter from Sacrum, Percutaneous Endoscopic Approach */
"0QC20ZZ" = "1" /* Extirpation of Matter from Right Pelvic Bone, Open Approach */
"0QC23ZZ" = "1" /* Extirpation of Matter from Right Pelvic Bone, Percutaneous Approach */
"0QC24ZZ" = "1" /* Extirpation of Matter from Right Pelvic Bone, Percutaneous Endoscopic Approach */
"0QC30ZZ" = "1" /* Extirpation of Matter from Left Pelvic Bone, Open Approach */
"0QC33ZZ" = "1" /* Extirpation of Matter from Left Pelvic Bone, Percutaneous Approach */
"0QC34ZZ" = "1" /* Extirpation of Matter from Left Pelvic Bone, Percutaneous Endoscopic Approach */
"0QC40ZZ" = "1" /* Extirpation of Matter from Right Acetabulum, Open Approach */
"0QC43ZZ" = "1" /* Extirpation of Matter from Right Acetabulum, Percutaneous Approach */
"0QC44ZZ" = "1" /* Extirpation of Matter from Right Acetabulum, Percutaneous Endoscopic Approach */
"0QC50ZZ" = "1" /* Extirpation of Matter from Left Acetabulum, Open Approach */
"0QC53ZZ" = "1" /* Extirpation of Matter from Left Acetabulum, Percutaneous Approach */
"0QC54ZZ" = "1" /* Extirpation of Matter from Left Acetabulum, Percutaneous Endoscopic Approach */
"0QC60ZZ" = "1" /* Extirpation of Matter from Right Upper Femur, Open Approach */
"0QC63ZZ" = "1" /* Extirpation of Matter from Right Upper Femur, Percutaneous Approach */
"0QC64ZZ" = "1" /* Extirpation of Matter from Right Upper Femur, Percutaneous Endoscopic Approach */
"0QC70ZZ" = "1" /* Extirpation of Matter from Left Upper Femur, Open Approach */
"0QC73ZZ" = "1" /* Extirpation of Matter from Left Upper Femur, Percutaneous Approach */
"0QC74ZZ" = "1" /* Extirpation of Matter from Left Upper Femur, Percutaneous Endoscopic Approach */
"0QC80ZZ" = "1" /* Extirpation of Matter from Right Femoral Shaft, Open Approach */
"0QC83ZZ" = "1" /* Extirpation of Matter from Right Femoral Shaft, Percutaneous Approach */
"0QC84ZZ" = "1" /* Extirpation of Matter from Right Femoral Shaft, Percutaneous Endoscopic Approach */
"0QC90ZZ" = "1" /* Extirpation of Matter from Left Femoral Shaft, Open Approach */
"0QC93ZZ" = "1" /* Extirpation of Matter from Left Femoral Shaft, Percutaneous Approach */
"0QC94ZZ" = "1" /* Extirpation of Matter from Left Femoral Shaft, Percutaneous Endoscopic Approach */
"0QCB0ZZ" = "1" /* Extirpation of Matter from Right Lower Femur, Open Approach */
"0QCB3ZZ" = "1" /* Extirpation of Matter from Right Lower Femur, Percutaneous Approach */
"0QCB4ZZ" = "1" /* Extirpation of Matter from Right Lower Femur, Percutaneous Endoscopic Approach */
"0QCC0ZZ" = "1" /* Extirpation of Matter from Left Lower Femur, Open Approach */
"0QCC3ZZ" = "1" /* Extirpation of Matter from Left Lower Femur, Percutaneous Approach */
"0QCC4ZZ" = "1" /* Extirpation of Matter from Left Lower Femur, Percutaneous Endoscopic Approach */
"0QCD0ZZ" = "1" /* Extirpation of Matter from Right Patella, Open Approach */
"0QCD3ZZ" = "1" /* Extirpation of Matter from Right Patella, Percutaneous Approach */
"0QCD4ZZ" = "1" /* Extirpation of Matter from Right Patella, Percutaneous Endoscopic Approach */
"0QCF0ZZ" = "1" /* Extirpation of Matter from Left Patella, Open Approach */
"0QCF3ZZ" = "1" /* Extirpation of Matter from Left Patella, Percutaneous Approach */
"0QCF4ZZ" = "1" /* Extirpation of Matter from Left Patella, Percutaneous Endoscopic Approach */
"0QCG0ZZ" = "1" /* Extirpation of Matter from Right Tibia, Open Approach */
"0QCG3ZZ" = "1" /* Extirpation of Matter from Right Tibia, Percutaneous Approach */
"0QCG4ZZ" = "1" /* Extirpation of Matter from Right Tibia, Percutaneous Endoscopic Approach */
"0QCH0ZZ" = "1" /* Extirpation of Matter from Left Tibia, Open Approach */
"0QCH3ZZ" = "1" /* Extirpation of Matter from Left Tibia, Percutaneous Approach */
"0QCH4ZZ" = "1" /* Extirpation of Matter from Left Tibia, Percutaneous Endoscopic Approach */
"0QCJ0ZZ" = "1" /* Extirpation of Matter from Right Fibula, Open Approach */
"0QCJ3ZZ" = "1" /* Extirpation of Matter from Right Fibula, Percutaneous Approach */
"0QCJ4ZZ" = "1" /* Extirpation of Matter from Right Fibula, Percutaneous Endoscopic Approach */
"0QCK0ZZ" = "1" /* Extirpation of Matter from Left Fibula, Open Approach */
"0QCK3ZZ" = "1" /* Extirpation of Matter from Left Fibula, Percutaneous Approach */
"0QCK4ZZ" = "1" /* Extirpation of Matter from Left Fibula, Percutaneous Endoscopic Approach */
"0QCL0ZZ" = "1" /* Extirpation of Matter from Right Tarsal, Open Approach */
"0QCL3ZZ" = "1" /* Extirpation of Matter from Right Tarsal, Percutaneous Approach */
"0QCL4ZZ" = "1" /* Extirpation of Matter from Right Tarsal, Percutaneous Endoscopic Approach */
"0QCM0ZZ" = "1" /* Extirpation of Matter from Left Tarsal, Open Approach */
"0QCM3ZZ" = "1" /* Extirpation of Matter from Left Tarsal, Percutaneous Approach */
"0QCM4ZZ" = "1" /* Extirpation of Matter from Left Tarsal, Percutaneous Endoscopic Approach */
"0QCN0ZZ" = "1" /* Extirpation of Matter from Right Metatarsal, Open Approach */
"0QCN3ZZ" = "1" /* Extirpation of Matter from Right Metatarsal, Percutaneous Approach */
"0QCN4ZZ" = "1" /* Extirpation of Matter from Right Metatarsal, Percutaneous Endoscopic Approach */
"0QCP0ZZ" = "1" /* Extirpation of Matter from Left Metatarsal, Open Approach */
"0QCP3ZZ" = "1" /* Extirpation of Matter from Left Metatarsal, Percutaneous Approach */
"0QCP4ZZ" = "1" /* Extirpation of Matter from Left Metatarsal, Percutaneous Endoscopic Approach */
"0QCQ0ZZ" = "1" /* Extirpation of Matter from Right Toe Phalanx, Open Approach */
"0QCQ3ZZ" = "1" /* Extirpation of Matter from Right Toe Phalanx, Percutaneous Approach */
"0QCQ4ZZ" = "1" /* Extirpation of Matter from Right Toe Phalanx, Percutaneous Endoscopic Approach */
"0QCR0ZZ" = "1" /* Extirpation of Matter from Left Toe Phalanx, Open Approach */
"0QCR3ZZ" = "1" /* Extirpation of Matter from Left Toe Phalanx, Percutaneous Approach */
"0QCR4ZZ" = "1" /* Extirpation of Matter from Left Toe Phalanx, Percutaneous Endoscopic Approach */
"0QCS0ZZ" = "1" /* Extirpation of Matter from Coccyx, Open Approach */
"0QCS3ZZ" = "1" /* Extirpation of Matter from Coccyx, Percutaneous Approach */
"0QCS4ZZ" = "1" /* Extirpation of Matter from Coccyx, Percutaneous Endoscopic Approach */
"0QH004Z" = "1" /* Insertion of Internal Fixation Device into Lumbar Vertebra, Open Approach */
"0QH005Z" = "1" /* Insertion of External Fixation Device into Lumbar Vertebra, Open Approach */
"0QH034Z" = "1" /* Insertion of Internal Fixation Device into Lumbar Vertebra, Percutaneous Approach */
"0QH035Z" = "1" /* Insertion of External Fixation Device into Lumbar Vertebra, Percutaneous Approach */
"0QH044Z" = "1" /* Insertion of Internal Fixation Device into Lumbar Vertebra, Percutaneous Endoscopic Approach */
"0QH045Z" = "1" /* Insertion of External Fixation Device into Lumbar Vertebra, Percutaneous Endoscopic Approach */
"0QH104Z" = "1" /* Insertion of Internal Fixation Device into Sacrum, Open Approach */
"0QH105Z" = "1" /* Insertion of External Fixation Device into Sacrum, Open Approach */
"0QH134Z" = "1" /* Insertion of Internal Fixation Device into Sacrum, Percutaneous Approach */
"0QH135Z" = "1" /* Insertion of External Fixation Device into Sacrum, Percutaneous Approach */
"0QH144Z" = "1" /* Insertion of Internal Fixation Device into Sacrum, Percutaneous Endoscopic Approach */
"0QH145Z" = "1" /* Insertion of External Fixation Device into Sacrum, Percutaneous Endoscopic Approach */
"0QH204Z" = "1" /* Insertion of Internal Fixation Device into Right Pelvic Bone, Open Approach */
"0QH205Z" = "1" /* Insertion of External Fixation Device into Right Pelvic Bone, Open Approach */
"0QH234Z" = "1" /* Insertion of Internal Fixation Device into Right Pelvic Bone, Percutaneous Approach */
"0QH235Z" = "1" /* Insertion of External Fixation Device into Right Pelvic Bone, Percutaneous Approach */
"0QH244Z" = "1" /* Insertion of Internal Fixation Device into Right Pelvic Bone, Percutaneous Endoscopic Approach */
"0QH245Z" = "1" /* Insertion of External Fixation Device into Right Pelvic Bone, Percutaneous Endoscopic Approach */
"0QH304Z" = "1" /* Insertion of Internal Fixation Device into Left Pelvic Bone, Open Approach */
"0QH305Z" = "1" /* Insertion of External Fixation Device into Left Pelvic Bone, Open Approach */
"0QH334Z" = "1" /* Insertion of Internal Fixation Device into Left Pelvic Bone, Percutaneous Approach */
"0QH335Z" = "1" /* Insertion of External Fixation Device into Left Pelvic Bone, Percutaneous Approach */
"0QH344Z" = "1" /* Insertion of Internal Fixation Device into Left Pelvic Bone, Percutaneous Endoscopic Approach */
"0QH345Z" = "1" /* Insertion of External Fixation Device into Left Pelvic Bone, Percutaneous Endoscopic Approach */
"0QH404Z" = "1" /* Insertion of Internal Fixation Device into Right Acetabulum, Open Approach */
"0QH405Z" = "1" /* Insertion of External Fixation Device into Right Acetabulum, Open Approach */
"0QH434Z" = "1" /* Insertion of Internal Fixation Device into Right Acetabulum, Percutaneous Approach */
"0QH435Z" = "1" /* Insertion of External Fixation Device into Right Acetabulum, Percutaneous Approach */
"0QH444Z" = "1" /* Insertion of Internal Fixation Device into Right Acetabulum, Percutaneous Endoscopic Approach */
"0QH445Z" = "1" /* Insertion of External Fixation Device into Right Acetabulum, Percutaneous Endoscopic Approach */
"0QH504Z" = "1" /* Insertion of Internal Fixation Device into Left Acetabulum, Open Approach */
"0QH505Z" = "1" /* Insertion of External Fixation Device into Left Acetabulum, Open Approach */
"0QH534Z" = "1" /* Insertion of Internal Fixation Device into Left Acetabulum, Percutaneous Approach */
"0QH535Z" = "1" /* Insertion of External Fixation Device into Left Acetabulum, Percutaneous Approach */
"0QH544Z" = "1" /* Insertion of Internal Fixation Device into Left Acetabulum, Percutaneous Endoscopic Approach */
"0QH545Z" = "1" /* Insertion of External Fixation Device into Left Acetabulum, Percutaneous Endoscopic Approach */
"0QH604Z" = "1" /* Insertion of Internal Fixation Device into Right Upper Femur, Open Approach */
"0QH605Z" = "1" /* Insertion of External Fixation Device into Right Upper Femur, Open Approach */
"0QH606Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Upper Femur, Open Approach */
"0QH60BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Upper Femur, Open Approach */
"0QH60CZ" = "1" /* Insertion of Ring External Fixation Device into Right Upper Femur, Open Approach */
"0QH60DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Upper Femur, Open Approach */
"0QH634Z" = "1" /* Insertion of Internal Fixation Device into Right Upper Femur, Percutaneous Approach */
"0QH635Z" = "1" /* Insertion of External Fixation Device into Right Upper Femur, Percutaneous Approach */
"0QH636Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Upper Femur, Percutaneous Approach */
"0QH63BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Upper Femur, Percutaneous Approach */
"0QH63CZ" = "1" /* Insertion of Ring External Fixation Device into Right Upper Femur, Percutaneous Approach */
"0QH63DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Upper Femur, Percutaneous Approach */
"0QH644Z" = "1" /* Insertion of Internal Fixation Device into Right Upper Femur, Percutaneous Endoscopic Approach */
"0QH645Z" = "1" /* Insertion of External Fixation Device into Right Upper Femur, Percutaneous Endoscopic Approach */
"0QH646Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Upper Femur, Percutaneous Endoscopic Approach */
"0QH64BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Upper Femur, Percutaneous Endoscopic Approach */
"0QH64CZ" = "1" /* Insertion of Ring External Fixation Device into Right Upper Femur, Percutaneous Endoscopic Approach */
"0QH64DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Upper Femur, Percutaneous Endoscopic Approach */
"0QH704Z" = "1" /* Insertion of Internal Fixation Device into Left Upper Femur, Open Approach */
"0QH705Z" = "1" /* Insertion of External Fixation Device into Left Upper Femur, Open Approach */
"0QH706Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Upper Femur, Open Approach */
"0QH70BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Upper Femur, Open Approach */
"0QH70CZ" = "1" /* Insertion of Ring External Fixation Device into Left Upper Femur, Open Approach */
"0QH70DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Upper Femur, Open Approach */
"0QH734Z" = "1" /* Insertion of Internal Fixation Device into Left Upper Femur, Percutaneous Approach */
"0QH735Z" = "1" /* Insertion of External Fixation Device into Left Upper Femur, Percutaneous Approach */
"0QH736Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Upper Femur, Percutaneous Approach */
"0QH73BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Upper Femur, Percutaneous Approach */
"0QH73CZ" = "1" /* Insertion of Ring External Fixation Device into Left Upper Femur, Percutaneous Approach */
"0QH73DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Upper Femur, Percutaneous Approach */
"0QH744Z" = "1" /* Insertion of Internal Fixation Device into Left Upper Femur, Percutaneous Endoscopic Approach */
"0QH745Z" = "1" /* Insertion of External Fixation Device into Left Upper Femur, Percutaneous Endoscopic Approach */
"0QH746Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Upper Femur, Percutaneous Endoscopic Approach */
"0QH74BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Upper Femur, Percutaneous Endoscopic Approach */
"0QH74CZ" = "1" /* Insertion of Ring External Fixation Device into Left Upper Femur, Percutaneous Endoscopic Approach */
"0QH74DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Upper Femur, Percutaneous Endoscopic Approach */
"0QH804Z" = "1" /* Insertion of Internal Fixation Device into Right Femoral Shaft, Open Approach */
"0QH805Z" = "1" /* Insertion of External Fixation Device into Right Femoral Shaft, Open Approach */
"0QH806Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Femoral Shaft, Open Approach */
"0QH80BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Femoral Shaft, Open Approach */
"0QH80CZ" = "1" /* Insertion of Ring External Fixation Device into Right Femoral Shaft, Open Approach */
"0QH80DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Femoral Shaft, Open Approach */
"0QH834Z" = "1" /* Insertion of Internal Fixation Device into Right Femoral Shaft, Percutaneous Approach */
"0QH835Z" = "1" /* Insertion of External Fixation Device into Right Femoral Shaft, Percutaneous Approach */
"0QH836Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Femoral Shaft, Percutaneous Approach */
"0QH83BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Femoral Shaft, Percutaneous Approach */
"0QH83CZ" = "1" /* Insertion of Ring External Fixation Device into Right Femoral Shaft, Percutaneous Approach */
"0QH83DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Femoral Shaft, Percutaneous Approach */
"0QH844Z" = "1" /* Insertion of Internal Fixation Device into Right Femoral Shaft, Percutaneous Endoscopic Approach */
"0QH845Z" = "1" /* Insertion of External Fixation Device into Right Femoral Shaft, Percutaneous Endoscopic Approach */
"0QH846Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Femoral Shaft, Percutaneous Endoscopic Approach */
"0QH84BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Femoral Shaft, Percutaneous Endoscopic Approach */
"0QH84CZ" = "1" /* Insertion of Ring External Fixation Device into Right Femoral Shaft, Percutaneous Endoscopic Approach */
"0QH84DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Femoral Shaft, Percutaneous Endoscopic Approach */
"0QH904Z" = "1" /* Insertion of Internal Fixation Device into Left Femoral Shaft, Open Approach */
"0QH905Z" = "1" /* Insertion of External Fixation Device into Left Femoral Shaft, Open Approach */
"0QH906Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Femoral Shaft, Open Approach */
"0QH90BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Femoral Shaft, Open Approach */
"0QH90CZ" = "1" /* Insertion of Ring External Fixation Device into Left Femoral Shaft, Open Approach */
"0QH90DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Femoral Shaft, Open Approach */
"0QH934Z" = "1" /* Insertion of Internal Fixation Device into Left Femoral Shaft, Percutaneous Approach */
"0QH935Z" = "1" /* Insertion of External Fixation Device into Left Femoral Shaft, Percutaneous Approach */
"0QH936Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Femoral Shaft, Percutaneous Approach */
"0QH93BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Femoral Shaft, Percutaneous Approach */
"0QH93CZ" = "1" /* Insertion of Ring External Fixation Device into Left Femoral Shaft, Percutaneous Approach */
"0QH93DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Femoral Shaft, Percutaneous Approach */
"0QH944Z" = "1" /* Insertion of Internal Fixation Device into Left Femoral Shaft, Percutaneous Endoscopic Approach */
"0QH945Z" = "1" /* Insertion of External Fixation Device into Left Femoral Shaft, Percutaneous Endoscopic Approach */
"0QH946Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Femoral Shaft, Percutaneous Endoscopic Approach */
"0QH94BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Femoral Shaft, Percutaneous Endoscopic Approach */
"0QH94CZ" = "1" /* Insertion of Ring External Fixation Device into Left Femoral Shaft, Percutaneous Endoscopic Approach */
"0QH94DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Femoral Shaft, Percutaneous Endoscopic Approach */
"0QHB04Z" = "1" /* Insertion of Internal Fixation Device into Right Lower Femur, Open Approach */
"0QHB05Z" = "1" /* Insertion of External Fixation Device into Right Lower Femur, Open Approach */
"0QHB06Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Lower Femur, Open Approach */
"0QHB0BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Lower Femur, Open Approach */
"0QHB0CZ" = "1" /* Insertion of Ring External Fixation Device into Right Lower Femur, Open Approach */
"0QHB0DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Lower Femur, Open Approach */
"0QHB34Z" = "1" /* Insertion of Internal Fixation Device into Right Lower Femur, Percutaneous Approach */
"0QHB35Z" = "1" /* Insertion of External Fixation Device into Right Lower Femur, Percutaneous Approach */
"0QHB36Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Lower Femur, Percutaneous Approach */
"0QHB3BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Lower Femur, Percutaneous Approach */
"0QHB3CZ" = "1" /* Insertion of Ring External Fixation Device into Right Lower Femur, Percutaneous Approach */
"0QHB3DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Lower Femur, Percutaneous Approach */
"0QHB44Z" = "1" /* Insertion of Internal Fixation Device into Right Lower Femur, Percutaneous Endoscopic Approach */
"0QHB45Z" = "1" /* Insertion of External Fixation Device into Right Lower Femur, Percutaneous Endoscopic Approach */
"0QHB46Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Lower Femur, Percutaneous Endoscopic Approach */
"0QHB4BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Lower Femur, Percutaneous Endoscopic Approach */
"0QHB4CZ" = "1" /* Insertion of Ring External Fixation Device into Right Lower Femur, Percutaneous Endoscopic Approach */
"0QHB4DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Lower Femur, Percutaneous Endoscopic Approach */
"0QHC04Z" = "1" /* Insertion of Internal Fixation Device into Left Lower Femur, Open Approach */
"0QHC05Z" = "1" /* Insertion of External Fixation Device into Left Lower Femur, Open Approach */
"0QHC06Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Lower Femur, Open Approach */
"0QHC0BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Lower Femur, Open Approach */
"0QHC0CZ" = "1" /* Insertion of Ring External Fixation Device into Left Lower Femur, Open Approach */
"0QHC0DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Lower Femur, Open Approach */
"0QHC34Z" = "1" /* Insertion of Internal Fixation Device into Left Lower Femur, Percutaneous Approach */
"0QHC35Z" = "1" /* Insertion of External Fixation Device into Left Lower Femur, Percutaneous Approach */
"0QHC36Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Lower Femur, Percutaneous Approach */
"0QHC3BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Lower Femur, Percutaneous Approach */
"0QHC3CZ" = "1" /* Insertion of Ring External Fixation Device into Left Lower Femur, Percutaneous Approach */
"0QHC3DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Lower Femur, Percutaneous Approach */
"0QHC44Z" = "1" /* Insertion of Internal Fixation Device into Left Lower Femur, Percutaneous Endoscopic Approach */
"0QHC45Z" = "1" /* Insertion of External Fixation Device into Left Lower Femur, Percutaneous Endoscopic Approach */
"0QHC46Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Lower Femur, Percutaneous Endoscopic Approach */
"0QHC4BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Lower Femur, Percutaneous Endoscopic Approach */
"0QHC4CZ" = "1" /* Insertion of Ring External Fixation Device into Left Lower Femur, Percutaneous Endoscopic Approach */
"0QHC4DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Lower Femur, Percutaneous Endoscopic Approach */
"0QHD04Z" = "1" /* Insertion of Internal Fixation Device into Right Patella, Open Approach */
"0QHD05Z" = "1" /* Insertion of External Fixation Device into Right Patella, Open Approach */
"0QHD34Z" = "1" /* Insertion of Internal Fixation Device into Right Patella, Percutaneous Approach */
"0QHD35Z" = "1" /* Insertion of External Fixation Device into Right Patella, Percutaneous Approach */
"0QHD44Z" = "1" /* Insertion of Internal Fixation Device into Right Patella, Percutaneous Endoscopic Approach */
"0QHD45Z" = "1" /* Insertion of External Fixation Device into Right Patella, Percutaneous Endoscopic Approach */
"0QHF04Z" = "1" /* Insertion of Internal Fixation Device into Left Patella, Open Approach */
"0QHF05Z" = "1" /* Insertion of External Fixation Device into Left Patella, Open Approach */
"0QHF34Z" = "1" /* Insertion of Internal Fixation Device into Left Patella, Percutaneous Approach */
"0QHF35Z" = "1" /* Insertion of External Fixation Device into Left Patella, Percutaneous Approach */
"0QHF44Z" = "1" /* Insertion of Internal Fixation Device into Left Patella, Percutaneous Endoscopic Approach */
"0QHF45Z" = "1" /* Insertion of External Fixation Device into Left Patella, Percutaneous Endoscopic Approach */
"0QHG04Z" = "1" /* Insertion of Internal Fixation Device into Right Tibia, Open Approach */
"0QHG05Z" = "1" /* Insertion of External Fixation Device into Right Tibia, Open Approach */
"0QHG06Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Tibia, Open Approach */
"0QHG0BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Tibia, Open Approach */
"0QHG0CZ" = "1" /* Insertion of Ring External Fixation Device into Right Tibia, Open Approach */
"0QHG0DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Tibia, Open Approach */
"0QHG34Z" = "1" /* Insertion of Internal Fixation Device into Right Tibia, Percutaneous Approach */
"0QHG35Z" = "1" /* Insertion of External Fixation Device into Right Tibia, Percutaneous Approach */
"0QHG36Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Tibia, Percutaneous Approach */
"0QHG3BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Tibia, Percutaneous Approach */
"0QHG3CZ" = "1" /* Insertion of Ring External Fixation Device into Right Tibia, Percutaneous Approach */
"0QHG3DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Tibia, Percutaneous Approach */
"0QHG44Z" = "1" /* Insertion of Internal Fixation Device into Right Tibia, Percutaneous Endoscopic Approach */
"0QHG45Z" = "1" /* Insertion of External Fixation Device into Right Tibia, Percutaneous Endoscopic Approach */
"0QHG46Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Tibia, Percutaneous Endoscopic Approach */
"0QHG4BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Tibia, Percutaneous Endoscopic Approach */
"0QHG4CZ" = "1" /* Insertion of Ring External Fixation Device into Right Tibia, Percutaneous Endoscopic Approach */
"0QHG4DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Tibia, Percutaneous Endoscopic Approach */
"0QHH04Z" = "1" /* Insertion of Internal Fixation Device into Left Tibia, Open Approach */
"0QHH05Z" = "1" /* Insertion of External Fixation Device into Left Tibia, Open Approach */
"0QHH06Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Tibia, Open Approach */
"0QHH0BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Tibia, Open Approach */
"0QHH0CZ" = "1" /* Insertion of Ring External Fixation Device into Left Tibia, Open Approach */
"0QHH0DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Tibia, Open Approach */
"0QHH34Z" = "1" /* Insertion of Internal Fixation Device into Left Tibia, Percutaneous Approach */
"0QHH35Z" = "1" /* Insertion of External Fixation Device into Left Tibia, Percutaneous Approach */
"0QHH36Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Tibia, Percutaneous Approach */
"0QHH3BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Tibia, Percutaneous Approach */
"0QHH3CZ" = "1" /* Insertion of Ring External Fixation Device into Left Tibia, Percutaneous Approach */
"0QHH3DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Tibia, Percutaneous Approach */
"0QHH44Z" = "1" /* Insertion of Internal Fixation Device into Left Tibia, Percutaneous Endoscopic Approach */
"0QHH45Z" = "1" /* Insertion of External Fixation Device into Left Tibia, Percutaneous Endoscopic Approach */
"0QHH46Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Tibia, Percutaneous Endoscopic Approach */
"0QHH4BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Tibia, Percutaneous Endoscopic Approach */
"0QHH4CZ" = "1" /* Insertion of Ring External Fixation Device into Left Tibia, Percutaneous Endoscopic Approach */
"0QHH4DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Tibia, Percutaneous Endoscopic Approach */
"0QHJ04Z" = "1" /* Insertion of Internal Fixation Device into Right Fibula, Open Approach */
"0QHJ05Z" = "1" /* Insertion of External Fixation Device into Right Fibula, Open Approach */
"0QHJ06Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Fibula, Open Approach */
"0QHJ0BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Fibula, Open Approach */
"0QHJ0CZ" = "1" /* Insertion of Ring External Fixation Device into Right Fibula, Open Approach */
"0QHJ0DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Fibula, Open Approach */
"0QHJ34Z" = "1" /* Insertion of Internal Fixation Device into Right Fibula, Percutaneous Approach */
"0QHJ35Z" = "1" /* Insertion of External Fixation Device into Right Fibula, Percutaneous Approach */
"0QHJ36Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Fibula, Percutaneous Approach */
"0QHJ3BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Fibula, Percutaneous Approach */
"0QHJ3CZ" = "1" /* Insertion of Ring External Fixation Device into Right Fibula, Percutaneous Approach */
"0QHJ3DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Fibula, Percutaneous Approach */
"0QHJ44Z" = "1" /* Insertion of Internal Fixation Device into Right Fibula, Percutaneous Endoscopic Approach */
"0QHJ45Z" = "1" /* Insertion of External Fixation Device into Right Fibula, Percutaneous Endoscopic Approach */
"0QHJ46Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Right Fibula, Percutaneous Endoscopic Approach */
"0QHJ4BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Right Fibula, Percutaneous Endoscopic Approach */
"0QHJ4CZ" = "1" /* Insertion of Ring External Fixation Device into Right Fibula, Percutaneous Endoscopic Approach */
"0QHJ4DZ" = "1" /* Insertion of Hybrid External Fixation Device into Right Fibula, Percutaneous Endoscopic Approach */
"0QHK04Z" = "1" /* Insertion of Internal Fixation Device into Left Fibula, Open Approach */
"0QHK05Z" = "1" /* Insertion of External Fixation Device into Left Fibula, Open Approach */
"0QHK06Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Fibula, Open Approach */
"0QHK0BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Fibula, Open Approach */
"0QHK0CZ" = "1" /* Insertion of Ring External Fixation Device into Left Fibula, Open Approach */
"0QHK0DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Fibula, Open Approach */
"0QHK34Z" = "1" /* Insertion of Internal Fixation Device into Left Fibula, Percutaneous Approach */
"0QHK35Z" = "1" /* Insertion of External Fixation Device into Left Fibula, Percutaneous Approach */
"0QHK36Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Fibula, Percutaneous Approach */
"0QHK3BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Fibula, Percutaneous Approach */
"0QHK3CZ" = "1" /* Insertion of Ring External Fixation Device into Left Fibula, Percutaneous Approach */
"0QHK3DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Fibula, Percutaneous Approach */
"0QHK44Z" = "1" /* Insertion of Internal Fixation Device into Left Fibula, Percutaneous Endoscopic Approach */
"0QHK45Z" = "1" /* Insertion of External Fixation Device into Left Fibula, Percutaneous Endoscopic Approach */
"0QHK46Z" = "1" /* Insertion of Intramedullary Internal Fixation Device into Left Fibula, Percutaneous Endoscopic Approach */
"0QHK4BZ" = "1" /* Insertion of Monoplanar External Fixation Device into Left Fibula, Percutaneous Endoscopic Approach */
"0QHK4CZ" = "1" /* Insertion of Ring External Fixation Device into Left Fibula, Percutaneous Endoscopic Approach */
"0QHK4DZ" = "1" /* Insertion of Hybrid External Fixation Device into Left Fibula, Percutaneous Endoscopic Approach */
"0QHL04Z" = "1" /* Insertion of Internal Fixation Device into Right Tarsal, Open Approach */
"0QHL05Z" = "1" /* Insertion of External Fixation Device into Right Tarsal, Open Approach */
"0QHL34Z" = "1" /* Insertion of Internal Fixation Device into Right Tarsal, Percutaneous Approach */
"0QHL35Z" = "1" /* Insertion of External Fixation Device into Right Tarsal, Percutaneous Approach */
"0QHL44Z" = "1" /* Insertion of Internal Fixation Device into Right Tarsal, Percutaneous Endoscopic Approach */
"0QHL45Z" = "1" /* Insertion of External Fixation Device into Right Tarsal, Percutaneous Endoscopic Approach */
"0QHM04Z" = "1" /* Insertion of Internal Fixation Device into Left Tarsal, Open Approach */
"0QHM05Z" = "1" /* Insertion of External Fixation Device into Left Tarsal, Open Approach */
"0QHM34Z" = "1" /* Insertion of Internal Fixation Device into Left Tarsal, Percutaneous Approach */
"0QHM35Z" = "1" /* Insertion of External Fixation Device into Left Tarsal, Percutaneous Approach */
"0QHM44Z" = "1" /* Insertion of Internal Fixation Device into Left Tarsal, Percutaneous Endoscopic Approach */
"0QHM45Z" = "1" /* Insertion of External Fixation Device into Left Tarsal, Percutaneous Endoscopic Approach */
"0QHN04Z" = "1" /* Insertion of Internal Fixation Device into Right Metatarsal, Open Approach */
"0QHN05Z" = "1" /* Insertion of External Fixation Device into Right Metatarsal, Open Approach */
"0QHN34Z" = "1" /* Insertion of Internal Fixation Device into Right Metatarsal, Percutaneous Approach */
"0QHN35Z" = "1" /* Insertion of External Fixation Device into Right Metatarsal, Percutaneous Approach */
"0QHN44Z" = "1" /* Insertion of Internal Fixation Device into Right Metatarsal, Percutaneous Endoscopic Approach */
"0QHN45Z" = "1" /* Insertion of External Fixation Device into Right Metatarsal, Percutaneous Endoscopic Approach */
"0QHP04Z" = "1" /* Insertion of Internal Fixation Device into Left Metatarsal, Open Approach */
"0QHP05Z" = "1" /* Insertion of External Fixation Device into Left Metatarsal, Open Approach */
"0QHP34Z" = "1" /* Insertion of Internal Fixation Device into Left Metatarsal, Percutaneous Approach */
"0QHP35Z" = "1" /* Insertion of External Fixation Device into Left Metatarsal, Percutaneous Approach */
"0QHP44Z" = "1" /* Insertion of Internal Fixation Device into Left Metatarsal, Percutaneous Endoscopic Approach */
"0QHP45Z" = "1" /* Insertion of External Fixation Device into Left Metatarsal, Percutaneous Endoscopic Approach */
"0QHQ04Z" = "1" /* Insertion of Internal Fixation Device into Right Toe Phalanx, Open Approach */
"0QHQ05Z" = "1" /* Insertion of External Fixation Device into Right Toe Phalanx, Open Approach */
"0QHQ34Z" = "1" /* Insertion of Internal Fixation Device into Right Toe Phalanx, Percutaneous Approach */
"0QHQ35Z" = "1" /* Insertion of External Fixation Device into Right Toe Phalanx, Percutaneous Approach */
"0QHQ44Z" = "1" /* Insertion of Internal Fixation Device into Right Toe Phalanx, Percutaneous Endoscopic Approach */
"0QHQ45Z" = "1" /* Insertion of External Fixation Device into Right Toe Phalanx, Percutaneous Endoscopic Approach */
"0QHR04Z" = "1" /* Insertion of Internal Fixation Device into Left Toe Phalanx, Open Approach */
"0QHR05Z" = "1" /* Insertion of External Fixation Device into Left Toe Phalanx, Open Approach */
"0QHR34Z" = "1" /* Insertion of Internal Fixation Device into Left Toe Phalanx, Percutaneous Approach */
"0QHR35Z" = "1" /* Insertion of External Fixation Device into Left Toe Phalanx, Percutaneous Approach */
"0QHR44Z" = "1" /* Insertion of Internal Fixation Device into Left Toe Phalanx, Percutaneous Endoscopic Approach */
"0QHR45Z" = "1" /* Insertion of External Fixation Device into Left Toe Phalanx, Percutaneous Endoscopic Approach */
"0QHS04Z" = "1" /* Insertion of Internal Fixation Device into Coccyx, Open Approach */
"0QHS05Z" = "1" /* Insertion of External Fixation Device into Coccyx, Open Approach */
"0QHS34Z" = "1" /* Insertion of Internal Fixation Device into Coccyx, Percutaneous Approach */
"0QHS35Z" = "1" /* Insertion of External Fixation Device into Coccyx, Percutaneous Approach */
"0QHS44Z" = "1" /* Insertion of Internal Fixation Device into Coccyx, Percutaneous Endoscopic Approach */
"0QHS45Z" = "1" /* Insertion of External Fixation Device into Coccyx, Percutaneous Endoscopic Approach */
"0QHY0MZ" = "1" /* Insertion of Bone Growth Stimulator into Lower Bone, Open Approach */
"0QHY3MZ" = "1" /* Insertion of Bone Growth Stimulator into Lower Bone, Percutaneous Approach */
"0QHY4MZ" = "1" /* Insertion of Bone Growth Stimulator into Lower Bone, Percutaneous Endoscopic Approach */
"0QJY0ZZ" = "1" /* Inspection of Lower Bone, Open Approach */
"0QJY4ZZ" = "1" /* Inspection of Lower Bone, Percutaneous Endoscopic Approach */
"0QN00ZZ" = "1" /* Release Lumbar Vertebra, Open Approach */
"0QN03ZZ" = "1" /* Release Lumbar Vertebra, Percutaneous Approach */
"0QN04ZZ" = "1" /* Release Lumbar Vertebra, Percutaneous Endoscopic Approach */
"0QN10ZZ" = "1" /* Release Sacrum, Open Approach */
"0QN13ZZ" = "1" /* Release Sacrum, Percutaneous Approach */
"0QN14ZZ" = "1" /* Release Sacrum, Percutaneous Endoscopic Approach */
"0QN20ZZ" = "1" /* Release Right Pelvic Bone, Open Approach */
"0QN23ZZ" = "1" /* Release Right Pelvic Bone, Percutaneous Approach */
"0QN24ZZ" = "1" /* Release Right Pelvic Bone, Percutaneous Endoscopic Approach */
"0QN30ZZ" = "1" /* Release Left Pelvic Bone, Open Approach */
"0QN33ZZ" = "1" /* Release Left Pelvic Bone, Percutaneous Approach */
"0QN34ZZ" = "1" /* Release Left Pelvic Bone, Percutaneous Endoscopic Approach */
"0QN40ZZ" = "1" /* Release Right Acetabulum, Open Approach */
"0QN43ZZ" = "1" /* Release Right Acetabulum, Percutaneous Approach */
"0QN44ZZ" = "1" /* Release Right Acetabulum, Percutaneous Endoscopic Approach */
"0QN50ZZ" = "1" /* Release Left Acetabulum, Open Approach */
"0QN53ZZ" = "1" /* Release Left Acetabulum, Percutaneous Approach */
"0QN54ZZ" = "1" /* Release Left Acetabulum, Percutaneous Endoscopic Approach */
"0QN60ZZ" = "1" /* Release Right Upper Femur, Open Approach */
"0QN63ZZ" = "1" /* Release Right Upper Femur, Percutaneous Approach */
"0QN64ZZ" = "1" /* Release Right Upper Femur, Percutaneous Endoscopic Approach */
"0QN70ZZ" = "1" /* Release Left Upper Femur, Open Approach */
"0QN73ZZ" = "1" /* Release Left Upper Femur, Percutaneous Approach */
"0QN74ZZ" = "1" /* Release Left Upper Femur, Percutaneous Endoscopic Approach */
"0QN80ZZ" = "1" /* Release Right Femoral Shaft, Open Approach */
"0QN83ZZ" = "1" /* Release Right Femoral Shaft, Percutaneous Approach */
"0QN84ZZ" = "1" /* Release Right Femoral Shaft, Percutaneous Endoscopic Approach */
"0QN90ZZ" = "1" /* Release Left Femoral Shaft, Open Approach */
"0QN93ZZ" = "1" /* Release Left Femoral Shaft, Percutaneous Approach */
"0QN94ZZ" = "1" /* Release Left Femoral Shaft, Percutaneous Endoscopic Approach */
"0QNB0ZZ" = "1" /* Release Right Lower Femur, Open Approach */
"0QNB3ZZ" = "1" /* Release Right Lower Femur, Percutaneous Approach */
"0QNB4ZZ" = "1" /* Release Right Lower Femur, Percutaneous Endoscopic Approach */
"0QNC0ZZ" = "1" /* Release Left Lower Femur, Open Approach */
"0QNC3ZZ" = "1" /* Release Left Lower Femur, Percutaneous Approach */
"0QNC4ZZ" = "1" /* Release Left Lower Femur, Percutaneous Endoscopic Approach */
"0QND0ZZ" = "1" /* Release Right Patella, Open Approach */
"0QND3ZZ" = "1" /* Release Right Patella, Percutaneous Approach */
"0QND4ZZ" = "1" /* Release Right Patella, Percutaneous Endoscopic Approach */
"0QNF0ZZ" = "1" /* Release Left Patella, Open Approach */
"0QNF3ZZ" = "1" /* Release Left Patella, Percutaneous Approach */
"0QNF4ZZ" = "1" /* Release Left Patella, Percutaneous Endoscopic Approach */
"0QNG0ZZ" = "1" /* Release Right Tibia, Open Approach */
"0QNG3ZZ" = "1" /* Release Right Tibia, Percutaneous Approach */
"0QNG4ZZ" = "1" /* Release Right Tibia, Percutaneous Endoscopic Approach */
"0QNH0ZZ" = "1" /* Release Left Tibia, Open Approach */
"0QNH3ZZ" = "1" /* Release Left Tibia, Percutaneous Approach */
"0QNH4ZZ" = "1" /* Release Left Tibia, Percutaneous Endoscopic Approach */
"0QNJ0ZZ" = "1" /* Release Right Fibula, Open Approach */
"0QNJ3ZZ" = "1" /* Release Right Fibula, Percutaneous Approach */
"0QNJ4ZZ" = "1" /* Release Right Fibula, Percutaneous Endoscopic Approach */
"0QNK0ZZ" = "1" /* Release Left Fibula, Open Approach */
"0QNK3ZZ" = "1" /* Release Left Fibula, Percutaneous Approach */
"0QNK4ZZ" = "1" /* Release Left Fibula, Percutaneous Endoscopic Approach */
"0QNL0ZZ" = "1" /* Release Right Tarsal, Open Approach */
"0QNL3ZZ" = "1" /* Release Right Tarsal, Percutaneous Approach */
"0QNL4ZZ" = "1" /* Release Right Tarsal, Percutaneous Endoscopic Approach */
"0QNM0ZZ" = "1" /* Release Left Tarsal, Open Approach */
"0QNM3ZZ" = "1" /* Release Left Tarsal, Percutaneous Approach */
"0QNM4ZZ" = "1" /* Release Left Tarsal, Percutaneous Endoscopic Approach */
"0QNN0ZZ" = "1" /* Release Right Metatarsal, Open Approach */
"0QNN3ZZ" = "1" /* Release Right Metatarsal, Percutaneous Approach */
"0QNN4ZZ" = "1" /* Release Right Metatarsal, Percutaneous Endoscopic Approach */
"0QNP0ZZ" = "1" /* Release Left Metatarsal, Open Approach */
"0QNP3ZZ" = "1" /* Release Left Metatarsal, Percutaneous Approach */
"0QNP4ZZ" = "1" /* Release Left Metatarsal, Percutaneous Endoscopic Approach */
"0QNQ0ZZ" = "1" /* Release Right Toe Phalanx, Open Approach */
"0QNQ3ZZ" = "1" /* Release Right Toe Phalanx, Percutaneous Approach */
"0QNQ4ZZ" = "1" /* Release Right Toe Phalanx, Percutaneous Endoscopic Approach */
"0QNR0ZZ" = "1" /* Release Left Toe Phalanx, Open Approach */
"0QNR3ZZ" = "1" /* Release Left Toe Phalanx, Percutaneous Approach */
"0QNR4ZZ" = "1" /* Release Left Toe Phalanx, Percutaneous Endoscopic Approach */
"0QNS0ZZ" = "1" /* Release Coccyx, Open Approach */
"0QNS3ZZ" = "1" /* Release Coccyx, Percutaneous Approach */
"0QNS4ZZ" = "1" /* Release Coccyx, Percutaneous Endoscopic Approach */
"0QP004Z" = "1" /* Removal of Internal Fixation Device from Lumbar Vertebra, Open Approach */
"0QP007Z" = "1" /* Removal of Autologous Tissue Substitute from Lumbar Vertebra, Open Approach */
"0QP00JZ" = "1" /* Removal of Synthetic Substitute from Lumbar Vertebra, Open Approach */
"0QP00KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lumbar Vertebra, Open Approach */
"0QP034Z" = "1" /* Removal of Internal Fixation Device from Lumbar Vertebra, Percutaneous Approach */
"0QP037Z" = "1" /* Removal of Autologous Tissue Substitute from Lumbar Vertebra, Percutaneous Approach */
"0QP03JZ" = "1" /* Removal of Synthetic Substitute from Lumbar Vertebra, Percutaneous Approach */
"0QP03KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lumbar Vertebra, Percutaneous Approach */
"0QP044Z" = "1" /* Removal of Internal Fixation Device from Lumbar Vertebra, Percutaneous Endoscopic Approach */
"0QP047Z" = "1" /* Removal of Autologous Tissue Substitute from Lumbar Vertebra, Percutaneous Endoscopic Approach */
"0QP04JZ" = "1" /* Removal of Synthetic Substitute from Lumbar Vertebra, Percutaneous Endoscopic Approach */
"0QP04KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lumbar Vertebra, Percutaneous Endoscopic Approach */
"0QP104Z" = "1" /* Removal of Internal Fixation Device from Sacrum, Open Approach */
"0QP107Z" = "1" /* Removal of Autologous Tissue Substitute from Sacrum, Open Approach */
"0QP10JZ" = "1" /* Removal of Synthetic Substitute from Sacrum, Open Approach */
"0QP10KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Sacrum, Open Approach */
"0QP134Z" = "1" /* Removal of Internal Fixation Device from Sacrum, Percutaneous Approach */
"0QP137Z" = "1" /* Removal of Autologous Tissue Substitute from Sacrum, Percutaneous Approach */
"0QP13JZ" = "1" /* Removal of Synthetic Substitute from Sacrum, Percutaneous Approach */
"0QP13KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Sacrum, Percutaneous Approach */
"0QP144Z" = "1" /* Removal of Internal Fixation Device from Sacrum, Percutaneous Endoscopic Approach */
"0QP147Z" = "1" /* Removal of Autologous Tissue Substitute from Sacrum, Percutaneous Endoscopic Approach */
"0QP14JZ" = "1" /* Removal of Synthetic Substitute from Sacrum, Percutaneous Endoscopic Approach */
"0QP14KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Sacrum, Percutaneous Endoscopic Approach */
"0QP204Z" = "1" /* Removal of Internal Fixation Device from Right Pelvic Bone, Open Approach */
"0QP205Z" = "1" /* Removal of External Fixation Device from Right Pelvic Bone, Open Approach */
"0QP207Z" = "1" /* Removal of Autologous Tissue Substitute from Right Pelvic Bone, Open Approach */
"0QP20JZ" = "1" /* Removal of Synthetic Substitute from Right Pelvic Bone, Open Approach */
"0QP20KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Pelvic Bone, Open Approach */
"0QP234Z" = "1" /* Removal of Internal Fixation Device from Right Pelvic Bone, Percutaneous Approach */
"0QP235Z" = "1" /* Removal of External Fixation Device from Right Pelvic Bone, Percutaneous Approach */
"0QP237Z" = "1" /* Removal of Autologous Tissue Substitute from Right Pelvic Bone, Percutaneous Approach */
"0QP23JZ" = "1" /* Removal of Synthetic Substitute from Right Pelvic Bone, Percutaneous Approach */
"0QP23KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Pelvic Bone, Percutaneous Approach */
"0QP244Z" = "1" /* Removal of Internal Fixation Device from Right Pelvic Bone, Percutaneous Endoscopic Approach */
"0QP245Z" = "1" /* Removal of External Fixation Device from Right Pelvic Bone, Percutaneous Endoscopic Approach */
"0QP247Z" = "1" /* Removal of Autologous Tissue Substitute from Right Pelvic Bone, Percutaneous Endoscopic Approach */
"0QP24JZ" = "1" /* Removal of Synthetic Substitute from Right Pelvic Bone, Percutaneous Endoscopic Approach */
"0QP24KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Pelvic Bone, Percutaneous Endoscopic Approach */
"0QP304Z" = "1" /* Removal of Internal Fixation Device from Left Pelvic Bone, Open Approach */
"0QP305Z" = "1" /* Removal of External Fixation Device from Left Pelvic Bone, Open Approach */
"0QP307Z" = "1" /* Removal of Autologous Tissue Substitute from Left Pelvic Bone, Open Approach */
"0QP30JZ" = "1" /* Removal of Synthetic Substitute from Left Pelvic Bone, Open Approach */
"0QP30KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Pelvic Bone, Open Approach */
"0QP334Z" = "1" /* Removal of Internal Fixation Device from Left Pelvic Bone, Percutaneous Approach */
"0QP335Z" = "1" /* Removal of External Fixation Device from Left Pelvic Bone, Percutaneous Approach */
"0QP337Z" = "1" /* Removal of Autologous Tissue Substitute from Left Pelvic Bone, Percutaneous Approach */
"0QP33JZ" = "1" /* Removal of Synthetic Substitute from Left Pelvic Bone, Percutaneous Approach */
"0QP33KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Pelvic Bone, Percutaneous Approach */
"0QP344Z" = "1" /* Removal of Internal Fixation Device from Left Pelvic Bone, Percutaneous Endoscopic Approach */
"0QP345Z" = "1" /* Removal of External Fixation Device from Left Pelvic Bone, Percutaneous Endoscopic Approach */
"0QP347Z" = "1" /* Removal of Autologous Tissue Substitute from Left Pelvic Bone, Percutaneous Endoscopic Approach */
"0QP34JZ" = "1" /* Removal of Synthetic Substitute from Left Pelvic Bone, Percutaneous Endoscopic Approach */
"0QP34KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Pelvic Bone, Percutaneous Endoscopic Approach */
"0QP404Z" = "1" /* Removal of Internal Fixation Device from Right Acetabulum, Open Approach */
"0QP407Z" = "1" /* Removal of Autologous Tissue Substitute from Right Acetabulum, Open Approach */
"0QP40JZ" = "1" /* Removal of Synthetic Substitute from Right Acetabulum, Open Approach */
"0QP40KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Acetabulum, Open Approach */
"0QP434Z" = "1" /* Removal of Internal Fixation Device from Right Acetabulum, Percutaneous Approach */
"0QP437Z" = "1" /* Removal of Autologous Tissue Substitute from Right Acetabulum, Percutaneous Approach */
"0QP43JZ" = "1" /* Removal of Synthetic Substitute from Right Acetabulum, Percutaneous Approach */
"0QP43KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Acetabulum, Percutaneous Approach */
"0QP444Z" = "1" /* Removal of Internal Fixation Device from Right Acetabulum, Percutaneous Endoscopic Approach */
"0QP447Z" = "1" /* Removal of Autologous Tissue Substitute from Right Acetabulum, Percutaneous Endoscopic Approach */
"0QP44JZ" = "1" /* Removal of Synthetic Substitute from Right Acetabulum, Percutaneous Endoscopic Approach */
"0QP44KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Acetabulum, Percutaneous Endoscopic Approach */
"0QP504Z" = "1" /* Removal of Internal Fixation Device from Left Acetabulum, Open Approach */
"0QP507Z" = "1" /* Removal of Autologous Tissue Substitute from Left Acetabulum, Open Approach */
"0QP50JZ" = "1" /* Removal of Synthetic Substitute from Left Acetabulum, Open Approach */
"0QP50KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Acetabulum, Open Approach */
"0QP534Z" = "1" /* Removal of Internal Fixation Device from Left Acetabulum, Percutaneous Approach */
"0QP537Z" = "1" /* Removal of Autologous Tissue Substitute from Left Acetabulum, Percutaneous Approach */
"0QP53JZ" = "1" /* Removal of Synthetic Substitute from Left Acetabulum, Percutaneous Approach */
"0QP53KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Acetabulum, Percutaneous Approach */
"0QP544Z" = "1" /* Removal of Internal Fixation Device from Left Acetabulum, Percutaneous Endoscopic Approach */
"0QP547Z" = "1" /* Removal of Autologous Tissue Substitute from Left Acetabulum, Percutaneous Endoscopic Approach */
"0QP54JZ" = "1" /* Removal of Synthetic Substitute from Left Acetabulum, Percutaneous Endoscopic Approach */
"0QP54KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Acetabulum, Percutaneous Endoscopic Approach */
"0QP604Z" = "1" /* Removal of Internal Fixation Device from Right Upper Femur, Open Approach */
"0QP605Z" = "1" /* Removal of External Fixation Device from Right Upper Femur, Open Approach */
"0QP607Z" = "1" /* Removal of Autologous Tissue Substitute from Right Upper Femur, Open Approach */
"0QP60JZ" = "1" /* Removal of Synthetic Substitute from Right Upper Femur, Open Approach */
"0QP60KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Upper Femur, Open Approach */
"0QP634Z" = "1" /* Removal of Internal Fixation Device from Right Upper Femur, Percutaneous Approach */
"0QP635Z" = "1" /* Removal of External Fixation Device from Right Upper Femur, Percutaneous Approach */
"0QP637Z" = "1" /* Removal of Autologous Tissue Substitute from Right Upper Femur, Percutaneous Approach */
"0QP63JZ" = "1" /* Removal of Synthetic Substitute from Right Upper Femur, Percutaneous Approach */
"0QP63KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Upper Femur, Percutaneous Approach */
"0QP644Z" = "1" /* Removal of Internal Fixation Device from Right Upper Femur, Percutaneous Endoscopic Approach */
"0QP645Z" = "1" /* Removal of External Fixation Device from Right Upper Femur, Percutaneous Endoscopic Approach */
"0QP647Z" = "1" /* Removal of Autologous Tissue Substitute from Right Upper Femur, Percutaneous Endoscopic Approach */
"0QP64JZ" = "1" /* Removal of Synthetic Substitute from Right Upper Femur, Percutaneous Endoscopic Approach */
"0QP64KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Upper Femur, Percutaneous Endoscopic Approach */
"0QP704Z" = "1" /* Removal of Internal Fixation Device from Left Upper Femur, Open Approach */
"0QP705Z" = "1" /* Removal of External Fixation Device from Left Upper Femur, Open Approach */
"0QP707Z" = "1" /* Removal of Autologous Tissue Substitute from Left Upper Femur, Open Approach */
"0QP70JZ" = "1" /* Removal of Synthetic Substitute from Left Upper Femur, Open Approach */
"0QP70KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Upper Femur, Open Approach */
"0QP734Z" = "1" /* Removal of Internal Fixation Device from Left Upper Femur, Percutaneous Approach */
"0QP735Z" = "1" /* Removal of External Fixation Device from Left Upper Femur, Percutaneous Approach */
"0QP737Z" = "1" /* Removal of Autologous Tissue Substitute from Left Upper Femur, Percutaneous Approach */
"0QP73JZ" = "1" /* Removal of Synthetic Substitute from Left Upper Femur, Percutaneous Approach */
"0QP73KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Upper Femur, Percutaneous Approach */
"0QP744Z" = "1" /* Removal of Internal Fixation Device from Left Upper Femur, Percutaneous Endoscopic Approach */
"0QP745Z" = "1" /* Removal of External Fixation Device from Left Upper Femur, Percutaneous Endoscopic Approach */
"0QP747Z" = "1" /* Removal of Autologous Tissue Substitute from Left Upper Femur, Percutaneous Endoscopic Approach */
"0QP74JZ" = "1" /* Removal of Synthetic Substitute from Left Upper Femur, Percutaneous Endoscopic Approach */
"0QP74KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Upper Femur, Percutaneous Endoscopic Approach */
"0QP804Z" = "1" /* Removal of Internal Fixation Device from Right Femoral Shaft, Open Approach */
"0QP805Z" = "1" /* Removal of External Fixation Device from Right Femoral Shaft, Open Approach */
"0QP807Z" = "1" /* Removal of Autologous Tissue Substitute from Right Femoral Shaft, Open Approach */
"0QP80JZ" = "1" /* Removal of Synthetic Substitute from Right Femoral Shaft, Open Approach */
"0QP80KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Femoral Shaft, Open Approach */
"0QP834Z" = "1" /* Removal of Internal Fixation Device from Right Femoral Shaft, Percutaneous Approach */
"0QP835Z" = "1" /* Removal of External Fixation Device from Right Femoral Shaft, Percutaneous Approach */
"0QP837Z" = "1" /* Removal of Autologous Tissue Substitute from Right Femoral Shaft, Percutaneous Approach */
"0QP83JZ" = "1" /* Removal of Synthetic Substitute from Right Femoral Shaft, Percutaneous Approach */
"0QP83KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Femoral Shaft, Percutaneous Approach */
"0QP844Z" = "1" /* Removal of Internal Fixation Device from Right Femoral Shaft, Percutaneous Endoscopic Approach */
"0QP845Z" = "1" /* Removal of External Fixation Device from Right Femoral Shaft, Percutaneous Endoscopic Approach */
"0QP847Z" = "1" /* Removal of Autologous Tissue Substitute from Right Femoral Shaft, Percutaneous Endoscopic Approach */
"0QP84JZ" = "1" /* Removal of Synthetic Substitute from Right Femoral Shaft, Percutaneous Endoscopic Approach */
"0QP84KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Femoral Shaft, Percutaneous Endoscopic Approach */
"0QP904Z" = "1" /* Removal of Internal Fixation Device from Left Femoral Shaft, Open Approach */
"0QP905Z" = "1" /* Removal of External Fixation Device from Left Femoral Shaft, Open Approach */
"0QP907Z" = "1" /* Removal of Autologous Tissue Substitute from Left Femoral Shaft, Open Approach */
"0QP90JZ" = "1" /* Removal of Synthetic Substitute from Left Femoral Shaft, Open Approach */
"0QP90KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Femoral Shaft, Open Approach */
"0QP934Z" = "1" /* Removal of Internal Fixation Device from Left Femoral Shaft, Percutaneous Approach */
"0QP935Z" = "1" /* Removal of External Fixation Device from Left Femoral Shaft, Percutaneous Approach */
"0QP937Z" = "1" /* Removal of Autologous Tissue Substitute from Left Femoral Shaft, Percutaneous Approach */
"0QP93JZ" = "1" /* Removal of Synthetic Substitute from Left Femoral Shaft, Percutaneous Approach */
"0QP93KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Femoral Shaft, Percutaneous Approach */
"0QP944Z" = "1" /* Removal of Internal Fixation Device from Left Femoral Shaft, Percutaneous Endoscopic Approach */
"0QP945Z" = "1" /* Removal of External Fixation Device from Left Femoral Shaft, Percutaneous Endoscopic Approach */
"0QP947Z" = "1" /* Removal of Autologous Tissue Substitute from Left Femoral Shaft, Percutaneous Endoscopic Approach */
"0QP94JZ" = "1" /* Removal of Synthetic Substitute from Left Femoral Shaft, Percutaneous Endoscopic Approach */
"0QP94KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Femoral Shaft, Percutaneous Endoscopic Approach */
"0QPB04Z" = "1" /* Removal of Internal Fixation Device from Right Lower Femur, Open Approach */
"0QPB05Z" = "1" /* Removal of External Fixation Device from Right Lower Femur, Open Approach */
"0QPB07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Lower Femur, Open Approach */
"0QPB0JZ" = "1" /* Removal of Synthetic Substitute from Right Lower Femur, Open Approach */
"0QPB0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Lower Femur, Open Approach */
"0QPB34Z" = "1" /* Removal of Internal Fixation Device from Right Lower Femur, Percutaneous Approach */
"0QPB35Z" = "1" /* Removal of External Fixation Device from Right Lower Femur, Percutaneous Approach */
"0QPB37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Lower Femur, Percutaneous Approach */
"0QPB3JZ" = "1" /* Removal of Synthetic Substitute from Right Lower Femur, Percutaneous Approach */
"0QPB3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Lower Femur, Percutaneous Approach */
"0QPB44Z" = "1" /* Removal of Internal Fixation Device from Right Lower Femur, Percutaneous Endoscopic Approach */
"0QPB45Z" = "1" /* Removal of External Fixation Device from Right Lower Femur, Percutaneous Endoscopic Approach */
"0QPB47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Lower Femur, Percutaneous Endoscopic Approach */
"0QPB4JZ" = "1" /* Removal of Synthetic Substitute from Right Lower Femur, Percutaneous Endoscopic Approach */
"0QPB4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Lower Femur, Percutaneous Endoscopic Approach */
"0QPC04Z" = "1" /* Removal of Internal Fixation Device from Left Lower Femur, Open Approach */
"0QPC05Z" = "1" /* Removal of External Fixation Device from Left Lower Femur, Open Approach */
"0QPC07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Lower Femur, Open Approach */
"0QPC0JZ" = "1" /* Removal of Synthetic Substitute from Left Lower Femur, Open Approach */
"0QPC0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Lower Femur, Open Approach */
"0QPC34Z" = "1" /* Removal of Internal Fixation Device from Left Lower Femur, Percutaneous Approach */
"0QPC35Z" = "1" /* Removal of External Fixation Device from Left Lower Femur, Percutaneous Approach */
"0QPC37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Lower Femur, Percutaneous Approach */
"0QPC3JZ" = "1" /* Removal of Synthetic Substitute from Left Lower Femur, Percutaneous Approach */
"0QPC3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Lower Femur, Percutaneous Approach */
"0QPC44Z" = "1" /* Removal of Internal Fixation Device from Left Lower Femur, Percutaneous Endoscopic Approach */
"0QPC45Z" = "1" /* Removal of External Fixation Device from Left Lower Femur, Percutaneous Endoscopic Approach */
"0QPC47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Lower Femur, Percutaneous Endoscopic Approach */
"0QPC4JZ" = "1" /* Removal of Synthetic Substitute from Left Lower Femur, Percutaneous Endoscopic Approach */
"0QPC4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Lower Femur, Percutaneous Endoscopic Approach */
"0QPD04Z" = "1" /* Removal of Internal Fixation Device from Right Patella, Open Approach */
"0QPD05Z" = "1" /* Removal of External Fixation Device from Right Patella, Open Approach */
"0QPD07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Patella, Open Approach */
"0QPD0JZ" = "1" /* Removal of Synthetic Substitute from Right Patella, Open Approach */
"0QPD0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Patella, Open Approach */
"0QPD34Z" = "1" /* Removal of Internal Fixation Device from Right Patella, Percutaneous Approach */
"0QPD35Z" = "1" /* Removal of External Fixation Device from Right Patella, Percutaneous Approach */
"0QPD37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Patella, Percutaneous Approach */
"0QPD3JZ" = "1" /* Removal of Synthetic Substitute from Right Patella, Percutaneous Approach */
"0QPD3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Patella, Percutaneous Approach */
"0QPD44Z" = "1" /* Removal of Internal Fixation Device from Right Patella, Percutaneous Endoscopic Approach */
"0QPD45Z" = "1" /* Removal of External Fixation Device from Right Patella, Percutaneous Endoscopic Approach */
"0QPD47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Patella, Percutaneous Endoscopic Approach */
"0QPD4JZ" = "1" /* Removal of Synthetic Substitute from Right Patella, Percutaneous Endoscopic Approach */
"0QPD4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Patella, Percutaneous Endoscopic Approach */
"0QPF04Z" = "1" /* Removal of Internal Fixation Device from Left Patella, Open Approach */
"0QPF05Z" = "1" /* Removal of External Fixation Device from Left Patella, Open Approach */
"0QPF07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Patella, Open Approach */
"0QPF0JZ" = "1" /* Removal of Synthetic Substitute from Left Patella, Open Approach */
"0QPF0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Patella, Open Approach */
"0QPF34Z" = "1" /* Removal of Internal Fixation Device from Left Patella, Percutaneous Approach */
"0QPF35Z" = "1" /* Removal of External Fixation Device from Left Patella, Percutaneous Approach */
"0QPF37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Patella, Percutaneous Approach */
"0QPF3JZ" = "1" /* Removal of Synthetic Substitute from Left Patella, Percutaneous Approach */
"0QPF3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Patella, Percutaneous Approach */
"0QPF44Z" = "1" /* Removal of Internal Fixation Device from Left Patella, Percutaneous Endoscopic Approach */
"0QPF45Z" = "1" /* Removal of External Fixation Device from Left Patella, Percutaneous Endoscopic Approach */
"0QPF47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Patella, Percutaneous Endoscopic Approach */
"0QPF4JZ" = "1" /* Removal of Synthetic Substitute from Left Patella, Percutaneous Endoscopic Approach */
"0QPF4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Patella, Percutaneous Endoscopic Approach */
"0QPG04Z" = "1" /* Removal of Internal Fixation Device from Right Tibia, Open Approach */
"0QPG05Z" = "1" /* Removal of External Fixation Device from Right Tibia, Open Approach */
"0QPG07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Tibia, Open Approach */
"0QPG0JZ" = "1" /* Removal of Synthetic Substitute from Right Tibia, Open Approach */
"0QPG0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Tibia, Open Approach */
"0QPG34Z" = "1" /* Removal of Internal Fixation Device from Right Tibia, Percutaneous Approach */
"0QPG35Z" = "1" /* Removal of External Fixation Device from Right Tibia, Percutaneous Approach */
"0QPG37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Tibia, Percutaneous Approach */
"0QPG3JZ" = "1" /* Removal of Synthetic Substitute from Right Tibia, Percutaneous Approach */
"0QPG3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Tibia, Percutaneous Approach */
"0QPG44Z" = "1" /* Removal of Internal Fixation Device from Right Tibia, Percutaneous Endoscopic Approach */
"0QPG45Z" = "1" /* Removal of External Fixation Device from Right Tibia, Percutaneous Endoscopic Approach */
"0QPG47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Tibia, Percutaneous Endoscopic Approach */
"0QPG4JZ" = "1" /* Removal of Synthetic Substitute from Right Tibia, Percutaneous Endoscopic Approach */
"0QPG4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Tibia, Percutaneous Endoscopic Approach */
"0QPH04Z" = "1" /* Removal of Internal Fixation Device from Left Tibia, Open Approach */
"0QPH05Z" = "1" /* Removal of External Fixation Device from Left Tibia, Open Approach */
"0QPH07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Tibia, Open Approach */
"0QPH0JZ" = "1" /* Removal of Synthetic Substitute from Left Tibia, Open Approach */
"0QPH0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Tibia, Open Approach */
"0QPH34Z" = "1" /* Removal of Internal Fixation Device from Left Tibia, Percutaneous Approach */
"0QPH35Z" = "1" /* Removal of External Fixation Device from Left Tibia, Percutaneous Approach */
"0QPH37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Tibia, Percutaneous Approach */
"0QPH3JZ" = "1" /* Removal of Synthetic Substitute from Left Tibia, Percutaneous Approach */
"0QPH3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Tibia, Percutaneous Approach */
"0QPH44Z" = "1" /* Removal of Internal Fixation Device from Left Tibia, Percutaneous Endoscopic Approach */
"0QPH45Z" = "1" /* Removal of External Fixation Device from Left Tibia, Percutaneous Endoscopic Approach */
"0QPH47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Tibia, Percutaneous Endoscopic Approach */
"0QPH4JZ" = "1" /* Removal of Synthetic Substitute from Left Tibia, Percutaneous Endoscopic Approach */
"0QPH4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Tibia, Percutaneous Endoscopic Approach */
"0QPJ04Z" = "1" /* Removal of Internal Fixation Device from Right Fibula, Open Approach */
"0QPJ05Z" = "1" /* Removal of External Fixation Device from Right Fibula, Open Approach */
"0QPJ07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Fibula, Open Approach */
"0QPJ0JZ" = "1" /* Removal of Synthetic Substitute from Right Fibula, Open Approach */
"0QPJ0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Fibula, Open Approach */
"0QPJ34Z" = "1" /* Removal of Internal Fixation Device from Right Fibula, Percutaneous Approach */
"0QPJ35Z" = "1" /* Removal of External Fixation Device from Right Fibula, Percutaneous Approach */
"0QPJ37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Fibula, Percutaneous Approach */
"0QPJ3JZ" = "1" /* Removal of Synthetic Substitute from Right Fibula, Percutaneous Approach */
"0QPJ3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Fibula, Percutaneous Approach */
"0QPJ44Z" = "1" /* Removal of Internal Fixation Device from Right Fibula, Percutaneous Endoscopic Approach */
"0QPJ45Z" = "1" /* Removal of External Fixation Device from Right Fibula, Percutaneous Endoscopic Approach */
"0QPJ47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Fibula, Percutaneous Endoscopic Approach */
"0QPJ4JZ" = "1" /* Removal of Synthetic Substitute from Right Fibula, Percutaneous Endoscopic Approach */
"0QPJ4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Fibula, Percutaneous Endoscopic Approach */
"0QPK04Z" = "1" /* Removal of Internal Fixation Device from Left Fibula, Open Approach */
"0QPK05Z" = "1" /* Removal of External Fixation Device from Left Fibula, Open Approach */
"0QPK07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Fibula, Open Approach */
"0QPK0JZ" = "1" /* Removal of Synthetic Substitute from Left Fibula, Open Approach */
"0QPK0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Fibula, Open Approach */
"0QPK34Z" = "1" /* Removal of Internal Fixation Device from Left Fibula, Percutaneous Approach */
"0QPK35Z" = "1" /* Removal of External Fixation Device from Left Fibula, Percutaneous Approach */
"0QPK37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Fibula, Percutaneous Approach */
"0QPK3JZ" = "1" /* Removal of Synthetic Substitute from Left Fibula, Percutaneous Approach */
"0QPK3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Fibula, Percutaneous Approach */
"0QPK44Z" = "1" /* Removal of Internal Fixation Device from Left Fibula, Percutaneous Endoscopic Approach */
"0QPK45Z" = "1" /* Removal of External Fixation Device from Left Fibula, Percutaneous Endoscopic Approach */
"0QPK47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Fibula, Percutaneous Endoscopic Approach */
"0QPK4JZ" = "1" /* Removal of Synthetic Substitute from Left Fibula, Percutaneous Endoscopic Approach */
"0QPK4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Fibula, Percutaneous Endoscopic Approach */
"0QPL04Z" = "1" /* Removal of Internal Fixation Device from Right Tarsal, Open Approach */
"0QPL05Z" = "1" /* Removal of External Fixation Device from Right Tarsal, Open Approach */
"0QPL07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Tarsal, Open Approach */
"0QPL0JZ" = "1" /* Removal of Synthetic Substitute from Right Tarsal, Open Approach */
"0QPL0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Tarsal, Open Approach */
"0QPL34Z" = "1" /* Removal of Internal Fixation Device from Right Tarsal, Percutaneous Approach */
"0QPL35Z" = "1" /* Removal of External Fixation Device from Right Tarsal, Percutaneous Approach */
"0QPL37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Tarsal, Percutaneous Approach */
"0QPL3JZ" = "1" /* Removal of Synthetic Substitute from Right Tarsal, Percutaneous Approach */
"0QPL3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Tarsal, Percutaneous Approach */
"0QPL44Z" = "1" /* Removal of Internal Fixation Device from Right Tarsal, Percutaneous Endoscopic Approach */
"0QPL45Z" = "1" /* Removal of External Fixation Device from Right Tarsal, Percutaneous Endoscopic Approach */
"0QPL47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Tarsal, Percutaneous Endoscopic Approach */
"0QPL4JZ" = "1" /* Removal of Synthetic Substitute from Right Tarsal, Percutaneous Endoscopic Approach */
"0QPL4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Tarsal, Percutaneous Endoscopic Approach */
"0QPM04Z" = "1" /* Removal of Internal Fixation Device from Left Tarsal, Open Approach */
"0QPM05Z" = "1" /* Removal of External Fixation Device from Left Tarsal, Open Approach */
"0QPM07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Tarsal, Open Approach */
"0QPM0JZ" = "1" /* Removal of Synthetic Substitute from Left Tarsal, Open Approach */
"0QPM0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Tarsal, Open Approach */
"0QPM34Z" = "1" /* Removal of Internal Fixation Device from Left Tarsal, Percutaneous Approach */
"0QPM35Z" = "1" /* Removal of External Fixation Device from Left Tarsal, Percutaneous Approach */
"0QPM37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Tarsal, Percutaneous Approach */
"0QPM3JZ" = "1" /* Removal of Synthetic Substitute from Left Tarsal, Percutaneous Approach */
"0QPM3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Tarsal, Percutaneous Approach */
"0QPM44Z" = "1" /* Removal of Internal Fixation Device from Left Tarsal, Percutaneous Endoscopic Approach */
"0QPM45Z" = "1" /* Removal of External Fixation Device from Left Tarsal, Percutaneous Endoscopic Approach */
"0QPM47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Tarsal, Percutaneous Endoscopic Approach */
"0QPM4JZ" = "1" /* Removal of Synthetic Substitute from Left Tarsal, Percutaneous Endoscopic Approach */
"0QPM4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Tarsal, Percutaneous Endoscopic Approach */
"0QPN04Z" = "1" /* Removal of Internal Fixation Device from Right Metatarsal, Open Approach */
"0QPN05Z" = "1" /* Removal of External Fixation Device from Right Metatarsal, Open Approach */
"0QPN07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Metatarsal, Open Approach */
"0QPN0JZ" = "1" /* Removal of Synthetic Substitute from Right Metatarsal, Open Approach */
"0QPN0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Metatarsal, Open Approach */
"0QPN34Z" = "1" /* Removal of Internal Fixation Device from Right Metatarsal, Percutaneous Approach */
"0QPN35Z" = "1" /* Removal of External Fixation Device from Right Metatarsal, Percutaneous Approach */
"0QPN37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Metatarsal, Percutaneous Approach */
"0QPN3JZ" = "1" /* Removal of Synthetic Substitute from Right Metatarsal, Percutaneous Approach */
"0QPN3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Metatarsal, Percutaneous Approach */
"0QPN44Z" = "1" /* Removal of Internal Fixation Device from Right Metatarsal, Percutaneous Endoscopic Approach */
"0QPN45Z" = "1" /* Removal of External Fixation Device from Right Metatarsal, Percutaneous Endoscopic Approach */
"0QPN47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Metatarsal, Percutaneous Endoscopic Approach */
"0QPN4JZ" = "1" /* Removal of Synthetic Substitute from Right Metatarsal, Percutaneous Endoscopic Approach */
"0QPN4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Metatarsal, Percutaneous Endoscopic Approach */
"0QPP04Z" = "1" /* Removal of Internal Fixation Device from Left Metatarsal, Open Approach */
"0QPP05Z" = "1" /* Removal of External Fixation Device from Left Metatarsal, Open Approach */
"0QPP07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Metatarsal, Open Approach */
"0QPP0JZ" = "1" /* Removal of Synthetic Substitute from Left Metatarsal, Open Approach */
"0QPP0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Metatarsal, Open Approach */
"0QPP34Z" = "1" /* Removal of Internal Fixation Device from Left Metatarsal, Percutaneous Approach */
"0QPP35Z" = "1" /* Removal of External Fixation Device from Left Metatarsal, Percutaneous Approach */
"0QPP37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Metatarsal, Percutaneous Approach */
"0QPP3JZ" = "1" /* Removal of Synthetic Substitute from Left Metatarsal, Percutaneous Approach */
"0QPP3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Metatarsal, Percutaneous Approach */
"0QPP44Z" = "1" /* Removal of Internal Fixation Device from Left Metatarsal, Percutaneous Endoscopic Approach */
"0QPP45Z" = "1" /* Removal of External Fixation Device from Left Metatarsal, Percutaneous Endoscopic Approach */
"0QPP47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Metatarsal, Percutaneous Endoscopic Approach */
"0QPP4JZ" = "1" /* Removal of Synthetic Substitute from Left Metatarsal, Percutaneous Endoscopic Approach */
"0QPP4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Metatarsal, Percutaneous Endoscopic Approach */
"0QPQ04Z" = "1" /* Removal of Internal Fixation Device from Right Toe Phalanx, Open Approach */
"0QPQ05Z" = "1" /* Removal of External Fixation Device from Right Toe Phalanx, Open Approach */
"0QPQ07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Toe Phalanx, Open Approach */
"0QPQ0JZ" = "1" /* Removal of Synthetic Substitute from Right Toe Phalanx, Open Approach */
"0QPQ0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Toe Phalanx, Open Approach */
"0QPQ34Z" = "1" /* Removal of Internal Fixation Device from Right Toe Phalanx, Percutaneous Approach */
"0QPQ35Z" = "1" /* Removal of External Fixation Device from Right Toe Phalanx, Percutaneous Approach */
"0QPQ37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Toe Phalanx, Percutaneous Approach */
"0QPQ3JZ" = "1" /* Removal of Synthetic Substitute from Right Toe Phalanx, Percutaneous Approach */
"0QPQ3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Toe Phalanx, Percutaneous Approach */
"0QPQ44Z" = "1" /* Removal of Internal Fixation Device from Right Toe Phalanx, Percutaneous Endoscopic Approach */
"0QPQ45Z" = "1" /* Removal of External Fixation Device from Right Toe Phalanx, Percutaneous Endoscopic Approach */
"0QPQ47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Toe Phalanx, Percutaneous Endoscopic Approach */
"0QPQ4JZ" = "1" /* Removal of Synthetic Substitute from Right Toe Phalanx, Percutaneous Endoscopic Approach */
"0QPQ4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Toe Phalanx, Percutaneous Endoscopic Approach */
"0QPR04Z" = "1" /* Removal of Internal Fixation Device from Left Toe Phalanx, Open Approach */
"0QPR05Z" = "1" /* Removal of External Fixation Device from Left Toe Phalanx, Open Approach */
"0QPR07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Toe Phalanx, Open Approach */
"0QPR0JZ" = "1" /* Removal of Synthetic Substitute from Left Toe Phalanx, Open Approach */
"0QPR0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Toe Phalanx, Open Approach */
"0QPR34Z" = "1" /* Removal of Internal Fixation Device from Left Toe Phalanx, Percutaneous Approach */
"0QPR35Z" = "1" /* Removal of External Fixation Device from Left Toe Phalanx, Percutaneous Approach */
"0QPR37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Toe Phalanx, Percutaneous Approach */
"0QPR3JZ" = "1" /* Removal of Synthetic Substitute from Left Toe Phalanx, Percutaneous Approach */
"0QPR3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Toe Phalanx, Percutaneous Approach */
"0QPR44Z" = "1" /* Removal of Internal Fixation Device from Left Toe Phalanx, Percutaneous Endoscopic Approach */
"0QPR45Z" = "1" /* Removal of External Fixation Device from Left Toe Phalanx, Percutaneous Endoscopic Approach */
"0QPR47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Toe Phalanx, Percutaneous Endoscopic Approach */
"0QPR4JZ" = "1" /* Removal of Synthetic Substitute from Left Toe Phalanx, Percutaneous Endoscopic Approach */
"0QPR4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Toe Phalanx, Percutaneous Endoscopic Approach */
"0QPS04Z" = "1" /* Removal of Internal Fixation Device from Coccyx, Open Approach */
"0QPS07Z" = "1" /* Removal of Autologous Tissue Substitute from Coccyx, Open Approach */
"0QPS0JZ" = "1" /* Removal of Synthetic Substitute from Coccyx, Open Approach */
"0QPS0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Coccyx, Open Approach */
"0QPS34Z" = "1" /* Removal of Internal Fixation Device from Coccyx, Percutaneous Approach */
"0QPS37Z" = "1" /* Removal of Autologous Tissue Substitute from Coccyx, Percutaneous Approach */
"0QPS3JZ" = "1" /* Removal of Synthetic Substitute from Coccyx, Percutaneous Approach */
"0QPS3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Coccyx, Percutaneous Approach */
"0QPS44Z" = "1" /* Removal of Internal Fixation Device from Coccyx, Percutaneous Endoscopic Approach */
"0QPS47Z" = "1" /* Removal of Autologous Tissue Substitute from Coccyx, Percutaneous Endoscopic Approach */
"0QPS4JZ" = "1" /* Removal of Synthetic Substitute from Coccyx, Percutaneous Endoscopic Approach */
"0QPS4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Coccyx, Percutaneous Endoscopic Approach */
"0QPY00Z" = "1" /* Removal of Drainage Device from Lower Bone, Open Approach */
"0QPY0MZ" = "1" /* Removal of Bone Growth Stimulator from Lower Bone, Open Approach */
"0QPY3MZ" = "1" /* Removal of Bone Growth Stimulator from Lower Bone, Percutaneous Approach */
"0QPY40Z" = "1" /* Removal of Drainage Device from Lower Bone, Percutaneous Endoscopic Approach */
"0QPY4MZ" = "1" /* Removal of Bone Growth Stimulator from Lower Bone, Percutaneous Endoscopic Approach */
"0QQ00ZZ" = "1" /* Repair Lumbar Vertebra, Open Approach */
"0QQ03ZZ" = "1" /* Repair Lumbar Vertebra, Percutaneous Approach */
"0QQ04ZZ" = "1" /* Repair Lumbar Vertebra, Percutaneous Endoscopic Approach */
"0QQ10ZZ" = "1" /* Repair Sacrum, Open Approach */
"0QQ13ZZ" = "1" /* Repair Sacrum, Percutaneous Approach */
"0QQ14ZZ" = "1" /* Repair Sacrum, Percutaneous Endoscopic Approach */
"0QQ20ZZ" = "1" /* Repair Right Pelvic Bone, Open Approach */
"0QQ23ZZ" = "1" /* Repair Right Pelvic Bone, Percutaneous Approach */
"0QQ24ZZ" = "1" /* Repair Right Pelvic Bone, Percutaneous Endoscopic Approach */
"0QQ30ZZ" = "1" /* Repair Left Pelvic Bone, Open Approach */
"0QQ33ZZ" = "1" /* Repair Left Pelvic Bone, Percutaneous Approach */
"0QQ34ZZ" = "1" /* Repair Left Pelvic Bone, Percutaneous Endoscopic Approach */
"0QQ40ZZ" = "1" /* Repair Right Acetabulum, Open Approach */
"0QQ43ZZ" = "1" /* Repair Right Acetabulum, Percutaneous Approach */
"0QQ44ZZ" = "1" /* Repair Right Acetabulum, Percutaneous Endoscopic Approach */
"0QQ50ZZ" = "1" /* Repair Left Acetabulum, Open Approach */
"0QQ53ZZ" = "1" /* Repair Left Acetabulum, Percutaneous Approach */
"0QQ54ZZ" = "1" /* Repair Left Acetabulum, Percutaneous Endoscopic Approach */
"0QQ60ZZ" = "1" /* Repair Right Upper Femur, Open Approach */
"0QQ63ZZ" = "1" /* Repair Right Upper Femur, Percutaneous Approach */
"0QQ64ZZ" = "1" /* Repair Right Upper Femur, Percutaneous Endoscopic Approach */
"0QQ70ZZ" = "1" /* Repair Left Upper Femur, Open Approach */
"0QQ73ZZ" = "1" /* Repair Left Upper Femur, Percutaneous Approach */
"0QQ74ZZ" = "1" /* Repair Left Upper Femur, Percutaneous Endoscopic Approach */
"0QQ80ZZ" = "1" /* Repair Right Femoral Shaft, Open Approach */
"0QQ83ZZ" = "1" /* Repair Right Femoral Shaft, Percutaneous Approach */
"0QQ84ZZ" = "1" /* Repair Right Femoral Shaft, Percutaneous Endoscopic Approach */
"0QQ90ZZ" = "1" /* Repair Left Femoral Shaft, Open Approach */
"0QQ93ZZ" = "1" /* Repair Left Femoral Shaft, Percutaneous Approach */
"0QQ94ZZ" = "1" /* Repair Left Femoral Shaft, Percutaneous Endoscopic Approach */
"0QQB0ZZ" = "1" /* Repair Right Lower Femur, Open Approach */
"0QQB3ZZ" = "1" /* Repair Right Lower Femur, Percutaneous Approach */
"0QQB4ZZ" = "1" /* Repair Right Lower Femur, Percutaneous Endoscopic Approach */
"0QQC0ZZ" = "1" /* Repair Left Lower Femur, Open Approach */
"0QQC3ZZ" = "1" /* Repair Left Lower Femur, Percutaneous Approach */
"0QQC4ZZ" = "1" /* Repair Left Lower Femur, Percutaneous Endoscopic Approach */
"0QQD0ZZ" = "1" /* Repair Right Patella, Open Approach */
"0QQD3ZZ" = "1" /* Repair Right Patella, Percutaneous Approach */
"0QQD4ZZ" = "1" /* Repair Right Patella, Percutaneous Endoscopic Approach */
"0QQF0ZZ" = "1" /* Repair Left Patella, Open Approach */
"0QQF3ZZ" = "1" /* Repair Left Patella, Percutaneous Approach */
"0QQF4ZZ" = "1" /* Repair Left Patella, Percutaneous Endoscopic Approach */
"0QQG0ZZ" = "1" /* Repair Right Tibia, Open Approach */
"0QQG3ZZ" = "1" /* Repair Right Tibia, Percutaneous Approach */
"0QQG4ZZ" = "1" /* Repair Right Tibia, Percutaneous Endoscopic Approach */
"0QQH0ZZ" = "1" /* Repair Left Tibia, Open Approach */
"0QQH3ZZ" = "1" /* Repair Left Tibia, Percutaneous Approach */
"0QQH4ZZ" = "1" /* Repair Left Tibia, Percutaneous Endoscopic Approach */
"0QQJ0ZZ" = "1" /* Repair Right Fibula, Open Approach */
"0QQJ3ZZ" = "1" /* Repair Right Fibula, Percutaneous Approach */
"0QQJ4ZZ" = "1" /* Repair Right Fibula, Percutaneous Endoscopic Approach */
"0QQK0ZZ" = "1" /* Repair Left Fibula, Open Approach */
"0QQK3ZZ" = "1" /* Repair Left Fibula, Percutaneous Approach */
"0QQK4ZZ" = "1" /* Repair Left Fibula, Percutaneous Endoscopic Approach */
"0QQL0ZZ" = "1" /* Repair Right Tarsal, Open Approach */
"0QQL3ZZ" = "1" /* Repair Right Tarsal, Percutaneous Approach */
"0QQL4ZZ" = "1" /* Repair Right Tarsal, Percutaneous Endoscopic Approach */
"0QQM0ZZ" = "1" /* Repair Left Tarsal, Open Approach */
"0QQM3ZZ" = "1" /* Repair Left Tarsal, Percutaneous Approach */
"0QQM4ZZ" = "1" /* Repair Left Tarsal, Percutaneous Endoscopic Approach */
"0QQN0ZZ" = "1" /* Repair Right Metatarsal, Open Approach */
"0QQN3ZZ" = "1" /* Repair Right Metatarsal, Percutaneous Approach */
"0QQN4ZZ" = "1" /* Repair Right Metatarsal, Percutaneous Endoscopic Approach */
"0QQP0ZZ" = "1" /* Repair Left Metatarsal, Open Approach */
"0QQP3ZZ" = "1" /* Repair Left Metatarsal, Percutaneous Approach */
"0QQP4ZZ" = "1" /* Repair Left Metatarsal, Percutaneous Endoscopic Approach */
"0QQQ0ZZ" = "1" /* Repair Right Toe Phalanx, Open Approach */
"0QQQ3ZZ" = "1" /* Repair Right Toe Phalanx, Percutaneous Approach */
"0QQQ4ZZ" = "1" /* Repair Right Toe Phalanx, Percutaneous Endoscopic Approach */
"0QQR0ZZ" = "1" /* Repair Left Toe Phalanx, Open Approach */
"0QQR3ZZ" = "1" /* Repair Left Toe Phalanx, Percutaneous Approach */
"0QQR4ZZ" = "1" /* Repair Left Toe Phalanx, Percutaneous Endoscopic Approach */
"0QQS0ZZ" = "1" /* Repair Coccyx, Open Approach */
"0QQS3ZZ" = "1" /* Repair Coccyx, Percutaneous Approach */
"0QQS4ZZ" = "1" /* Repair Coccyx, Percutaneous Endoscopic Approach */
"0QR007Z" = "1" /* Replacement of Lumbar Vertebra with Autologous Tissue Substitute, Open Approach */
"0QR00JZ" = "1" /* Replacement of Lumbar Vertebra with Synthetic Substitute, Open Approach */
"0QR00KZ" = "1" /* Replacement of Lumbar Vertebra with Nonautologous Tissue Substitute, Open Approach */
"0QR037Z" = "1" /* Replacement of Lumbar Vertebra with Autologous Tissue Substitute, Percutaneous Approach */
"0QR03JZ" = "1" /* Replacement of Lumbar Vertebra with Synthetic Substitute, Percutaneous Approach */
"0QR03KZ" = "1" /* Replacement of Lumbar Vertebra with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QR047Z" = "1" /* Replacement of Lumbar Vertebra with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QR04JZ" = "1" /* Replacement of Lumbar Vertebra with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QR04KZ" = "1" /* Replacement of Lumbar Vertebra with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QR107Z" = "1" /* Replacement of Sacrum with Autologous Tissue Substitute, Open Approach */
"0QR10JZ" = "1" /* Replacement of Sacrum with Synthetic Substitute, Open Approach */
"0QR10KZ" = "1" /* Replacement of Sacrum with Nonautologous Tissue Substitute, Open Approach */
"0QR137Z" = "1" /* Replacement of Sacrum with Autologous Tissue Substitute, Percutaneous Approach */
"0QR13JZ" = "1" /* Replacement of Sacrum with Synthetic Substitute, Percutaneous Approach */
"0QR13KZ" = "1" /* Replacement of Sacrum with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QR147Z" = "1" /* Replacement of Sacrum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QR14JZ" = "1" /* Replacement of Sacrum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QR14KZ" = "1" /* Replacement of Sacrum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QR207Z" = "1" /* Replacement of Right Pelvic Bone with Autologous Tissue Substitute, Open Approach */
"0QR20JZ" = "1" /* Replacement of Right Pelvic Bone with Synthetic Substitute, Open Approach */
"0QR20KZ" = "1" /* Replacement of Right Pelvic Bone with Nonautologous Tissue Substitute, Open Approach */
"0QR237Z" = "1" /* Replacement of Right Pelvic Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0QR23JZ" = "1" /* Replacement of Right Pelvic Bone with Synthetic Substitute, Percutaneous Approach */
"0QR23KZ" = "1" /* Replacement of Right Pelvic Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QR247Z" = "1" /* Replacement of Right Pelvic Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QR24JZ" = "1" /* Replacement of Right Pelvic Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QR24KZ" = "1" /* Replacement of Right Pelvic Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QR307Z" = "1" /* Replacement of Left Pelvic Bone with Autologous Tissue Substitute, Open Approach */
"0QR30JZ" = "1" /* Replacement of Left Pelvic Bone with Synthetic Substitute, Open Approach */
"0QR30KZ" = "1" /* Replacement of Left Pelvic Bone with Nonautologous Tissue Substitute, Open Approach */
"0QR337Z" = "1" /* Replacement of Left Pelvic Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0QR33JZ" = "1" /* Replacement of Left Pelvic Bone with Synthetic Substitute, Percutaneous Approach */
"0QR33KZ" = "1" /* Replacement of Left Pelvic Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QR347Z" = "1" /* Replacement of Left Pelvic Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QR34JZ" = "1" /* Replacement of Left Pelvic Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QR34KZ" = "1" /* Replacement of Left Pelvic Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QR407Z" = "1" /* Replacement of Right Acetabulum with Autologous Tissue Substitute, Open Approach */
"0QR40JZ" = "1" /* Replacement of Right Acetabulum with Synthetic Substitute, Open Approach */
"0QR40KZ" = "1" /* Replacement of Right Acetabulum with Nonautologous Tissue Substitute, Open Approach */
"0QR437Z" = "1" /* Replacement of Right Acetabulum with Autologous Tissue Substitute, Percutaneous Approach */
"0QR43JZ" = "1" /* Replacement of Right Acetabulum with Synthetic Substitute, Percutaneous Approach */
"0QR43KZ" = "1" /* Replacement of Right Acetabulum with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QR447Z" = "1" /* Replacement of Right Acetabulum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QR44JZ" = "1" /* Replacement of Right Acetabulum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QR44KZ" = "1" /* Replacement of Right Acetabulum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QR507Z" = "1" /* Replacement of Left Acetabulum with Autologous Tissue Substitute, Open Approach */
"0QR50JZ" = "1" /* Replacement of Left Acetabulum with Synthetic Substitute, Open Approach */
"0QR50KZ" = "1" /* Replacement of Left Acetabulum with Nonautologous Tissue Substitute, Open Approach */
"0QR537Z" = "1" /* Replacement of Left Acetabulum with Autologous Tissue Substitute, Percutaneous Approach */
"0QR53JZ" = "1" /* Replacement of Left Acetabulum with Synthetic Substitute, Percutaneous Approach */
"0QR53KZ" = "1" /* Replacement of Left Acetabulum with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QR547Z" = "1" /* Replacement of Left Acetabulum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QR54JZ" = "1" /* Replacement of Left Acetabulum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QR54KZ" = "1" /* Replacement of Left Acetabulum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QR607Z" = "1" /* Replacement of Right Upper Femur with Autologous Tissue Substitute, Open Approach */
"0QR60JZ" = "1" /* Replacement of Right Upper Femur with Synthetic Substitute, Open Approach */
"0QR60KZ" = "1" /* Replacement of Right Upper Femur with Nonautologous Tissue Substitute, Open Approach */
"0QR637Z" = "1" /* Replacement of Right Upper Femur with Autologous Tissue Substitute, Percutaneous Approach */
"0QR63JZ" = "1" /* Replacement of Right Upper Femur with Synthetic Substitute, Percutaneous Approach */
"0QR63KZ" = "1" /* Replacement of Right Upper Femur with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QR647Z" = "1" /* Replacement of Right Upper Femur with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QR64JZ" = "1" /* Replacement of Right Upper Femur with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QR64KZ" = "1" /* Replacement of Right Upper Femur with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QR707Z" = "1" /* Replacement of Left Upper Femur with Autologous Tissue Substitute, Open Approach */
"0QR70JZ" = "1" /* Replacement of Left Upper Femur with Synthetic Substitute, Open Approach */
"0QR70KZ" = "1" /* Replacement of Left Upper Femur with Nonautologous Tissue Substitute, Open Approach */
"0QR737Z" = "1" /* Replacement of Left Upper Femur with Autologous Tissue Substitute, Percutaneous Approach */
"0QR73JZ" = "1" /* Replacement of Left Upper Femur with Synthetic Substitute, Percutaneous Approach */
"0QR73KZ" = "1" /* Replacement of Left Upper Femur with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QR747Z" = "1" /* Replacement of Left Upper Femur with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QR74JZ" = "1" /* Replacement of Left Upper Femur with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QR74KZ" = "1" /* Replacement of Left Upper Femur with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QR807Z" = "1" /* Replacement of Right Femoral Shaft with Autologous Tissue Substitute, Open Approach */
"0QR80JZ" = "1" /* Replacement of Right Femoral Shaft with Synthetic Substitute, Open Approach */
"0QR80KZ" = "1" /* Replacement of Right Femoral Shaft with Nonautologous Tissue Substitute, Open Approach */
"0QR837Z" = "1" /* Replacement of Right Femoral Shaft with Autologous Tissue Substitute, Percutaneous Approach */
"0QR83JZ" = "1" /* Replacement of Right Femoral Shaft with Synthetic Substitute, Percutaneous Approach */
"0QR83KZ" = "1" /* Replacement of Right Femoral Shaft with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QR847Z" = "1" /* Replacement of Right Femoral Shaft with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QR84JZ" = "1" /* Replacement of Right Femoral Shaft with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QR84KZ" = "1" /* Replacement of Right Femoral Shaft with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QR907Z" = "1" /* Replacement of Left Femoral Shaft with Autologous Tissue Substitute, Open Approach */
"0QR90JZ" = "1" /* Replacement of Left Femoral Shaft with Synthetic Substitute, Open Approach */
"0QR90KZ" = "1" /* Replacement of Left Femoral Shaft with Nonautologous Tissue Substitute, Open Approach */
"0QR937Z" = "1" /* Replacement of Left Femoral Shaft with Autologous Tissue Substitute, Percutaneous Approach */
"0QR93JZ" = "1" /* Replacement of Left Femoral Shaft with Synthetic Substitute, Percutaneous Approach */
"0QR93KZ" = "1" /* Replacement of Left Femoral Shaft with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QR947Z" = "1" /* Replacement of Left Femoral Shaft with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QR94JZ" = "1" /* Replacement of Left Femoral Shaft with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QR94KZ" = "1" /* Replacement of Left Femoral Shaft with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRB07Z" = "1" /* Replacement of Right Lower Femur with Autologous Tissue Substitute, Open Approach */
"0QRB0JZ" = "1" /* Replacement of Right Lower Femur with Synthetic Substitute, Open Approach */
"0QRB0KZ" = "1" /* Replacement of Right Lower Femur with Nonautologous Tissue Substitute, Open Approach */
"0QRB37Z" = "1" /* Replacement of Right Lower Femur with Autologous Tissue Substitute, Percutaneous Approach */
"0QRB3JZ" = "1" /* Replacement of Right Lower Femur with Synthetic Substitute, Percutaneous Approach */
"0QRB3KZ" = "1" /* Replacement of Right Lower Femur with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QRB47Z" = "1" /* Replacement of Right Lower Femur with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRB4JZ" = "1" /* Replacement of Right Lower Femur with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QRB4KZ" = "1" /* Replacement of Right Lower Femur with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRC07Z" = "1" /* Replacement of Left Lower Femur with Autologous Tissue Substitute, Open Approach */
"0QRC0JZ" = "1" /* Replacement of Left Lower Femur with Synthetic Substitute, Open Approach */
"0QRC0KZ" = "1" /* Replacement of Left Lower Femur with Nonautologous Tissue Substitute, Open Approach */
"0QRC37Z" = "1" /* Replacement of Left Lower Femur with Autologous Tissue Substitute, Percutaneous Approach */
"0QRC3JZ" = "1" /* Replacement of Left Lower Femur with Synthetic Substitute, Percutaneous Approach */
"0QRC3KZ" = "1" /* Replacement of Left Lower Femur with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QRC47Z" = "1" /* Replacement of Left Lower Femur with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRC4JZ" = "1" /* Replacement of Left Lower Femur with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QRC4KZ" = "1" /* Replacement of Left Lower Femur with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRD07Z" = "1" /* Replacement of Right Patella with Autologous Tissue Substitute, Open Approach */
"0QRD0JZ" = "1" /* Replacement of Right Patella with Synthetic Substitute, Open Approach */
"0QRD0KZ" = "1" /* Replacement of Right Patella with Nonautologous Tissue Substitute, Open Approach */
"0QRD37Z" = "1" /* Replacement of Right Patella with Autologous Tissue Substitute, Percutaneous Approach */
"0QRD3JZ" = "1" /* Replacement of Right Patella with Synthetic Substitute, Percutaneous Approach */
"0QRD3KZ" = "1" /* Replacement of Right Patella with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QRD47Z" = "1" /* Replacement of Right Patella with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRD4JZ" = "1" /* Replacement of Right Patella with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QRD4KZ" = "1" /* Replacement of Right Patella with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRF07Z" = "1" /* Replacement of Left Patella with Autologous Tissue Substitute, Open Approach */
"0QRF0JZ" = "1" /* Replacement of Left Patella with Synthetic Substitute, Open Approach */
"0QRF0KZ" = "1" /* Replacement of Left Patella with Nonautologous Tissue Substitute, Open Approach */
"0QRF37Z" = "1" /* Replacement of Left Patella with Autologous Tissue Substitute, Percutaneous Approach */
"0QRF3JZ" = "1" /* Replacement of Left Patella with Synthetic Substitute, Percutaneous Approach */
"0QRF3KZ" = "1" /* Replacement of Left Patella with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QRF47Z" = "1" /* Replacement of Left Patella with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRF4JZ" = "1" /* Replacement of Left Patella with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QRF4KZ" = "1" /* Replacement of Left Patella with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRG07Z" = "1" /* Replacement of Right Tibia with Autologous Tissue Substitute, Open Approach */
"0QRG0JZ" = "1" /* Replacement of Right Tibia with Synthetic Substitute, Open Approach */
"0QRG0KZ" = "1" /* Replacement of Right Tibia with Nonautologous Tissue Substitute, Open Approach */
"0QRG37Z" = "1" /* Replacement of Right Tibia with Autologous Tissue Substitute, Percutaneous Approach */
"0QRG3JZ" = "1" /* Replacement of Right Tibia with Synthetic Substitute, Percutaneous Approach */
"0QRG3KZ" = "1" /* Replacement of Right Tibia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QRG47Z" = "1" /* Replacement of Right Tibia with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRG4JZ" = "1" /* Replacement of Right Tibia with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QRG4KZ" = "1" /* Replacement of Right Tibia with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRH07Z" = "1" /* Replacement of Left Tibia with Autologous Tissue Substitute, Open Approach */
"0QRH0JZ" = "1" /* Replacement of Left Tibia with Synthetic Substitute, Open Approach */
"0QRH0KZ" = "1" /* Replacement of Left Tibia with Nonautologous Tissue Substitute, Open Approach */
"0QRH37Z" = "1" /* Replacement of Left Tibia with Autologous Tissue Substitute, Percutaneous Approach */
"0QRH3JZ" = "1" /* Replacement of Left Tibia with Synthetic Substitute, Percutaneous Approach */
"0QRH3KZ" = "1" /* Replacement of Left Tibia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QRH47Z" = "1" /* Replacement of Left Tibia with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRH4JZ" = "1" /* Replacement of Left Tibia with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QRH4KZ" = "1" /* Replacement of Left Tibia with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRJ07Z" = "1" /* Replacement of Right Fibula with Autologous Tissue Substitute, Open Approach */
"0QRJ0JZ" = "1" /* Replacement of Right Fibula with Synthetic Substitute, Open Approach */
"0QRJ0KZ" = "1" /* Replacement of Right Fibula with Nonautologous Tissue Substitute, Open Approach */
"0QRJ37Z" = "1" /* Replacement of Right Fibula with Autologous Tissue Substitute, Percutaneous Approach */
"0QRJ3JZ" = "1" /* Replacement of Right Fibula with Synthetic Substitute, Percutaneous Approach */
"0QRJ3KZ" = "1" /* Replacement of Right Fibula with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QRJ47Z" = "1" /* Replacement of Right Fibula with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRJ4JZ" = "1" /* Replacement of Right Fibula with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QRJ4KZ" = "1" /* Replacement of Right Fibula with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRK07Z" = "1" /* Replacement of Left Fibula with Autologous Tissue Substitute, Open Approach */
"0QRK0JZ" = "1" /* Replacement of Left Fibula with Synthetic Substitute, Open Approach */
"0QRK0KZ" = "1" /* Replacement of Left Fibula with Nonautologous Tissue Substitute, Open Approach */
"0QRK37Z" = "1" /* Replacement of Left Fibula with Autologous Tissue Substitute, Percutaneous Approach */
"0QRK3JZ" = "1" /* Replacement of Left Fibula with Synthetic Substitute, Percutaneous Approach */
"0QRK3KZ" = "1" /* Replacement of Left Fibula with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QRK47Z" = "1" /* Replacement of Left Fibula with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRK4JZ" = "1" /* Replacement of Left Fibula with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QRK4KZ" = "1" /* Replacement of Left Fibula with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRL07Z" = "1" /* Replacement of Right Tarsal with Autologous Tissue Substitute, Open Approach */
"0QRL0JZ" = "1" /* Replacement of Right Tarsal with Synthetic Substitute, Open Approach */
"0QRL0KZ" = "1" /* Replacement of Right Tarsal with Nonautologous Tissue Substitute, Open Approach */
"0QRL37Z" = "1" /* Replacement of Right Tarsal with Autologous Tissue Substitute, Percutaneous Approach */
"0QRL3JZ" = "1" /* Replacement of Right Tarsal with Synthetic Substitute, Percutaneous Approach */
"0QRL3KZ" = "1" /* Replacement of Right Tarsal with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QRL47Z" = "1" /* Replacement of Right Tarsal with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRL4JZ" = "1" /* Replacement of Right Tarsal with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QRL4KZ" = "1" /* Replacement of Right Tarsal with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRM07Z" = "1" /* Replacement of Left Tarsal with Autologous Tissue Substitute, Open Approach */
"0QRM0JZ" = "1" /* Replacement of Left Tarsal with Synthetic Substitute, Open Approach */
"0QRM0KZ" = "1" /* Replacement of Left Tarsal with Nonautologous Tissue Substitute, Open Approach */
"0QRM37Z" = "1" /* Replacement of Left Tarsal with Autologous Tissue Substitute, Percutaneous Approach */
"0QRM3JZ" = "1" /* Replacement of Left Tarsal with Synthetic Substitute, Percutaneous Approach */
"0QRM3KZ" = "1" /* Replacement of Left Tarsal with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QRM47Z" = "1" /* Replacement of Left Tarsal with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRM4JZ" = "1" /* Replacement of Left Tarsal with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QRM4KZ" = "1" /* Replacement of Left Tarsal with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRN07Z" = "1" /* Replacement of Right Metatarsal with Autologous Tissue Substitute, Open Approach */
"0QRN0JZ" = "1" /* Replacement of Right Metatarsal with Synthetic Substitute, Open Approach */
"0QRN0KZ" = "1" /* Replacement of Right Metatarsal with Nonautologous Tissue Substitute, Open Approach */
"0QRN37Z" = "1" /* Replacement of Right Metatarsal with Autologous Tissue Substitute, Percutaneous Approach */
"0QRN3JZ" = "1" /* Replacement of Right Metatarsal with Synthetic Substitute, Percutaneous Approach */
"0QRN3KZ" = "1" /* Replacement of Right Metatarsal with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QRN47Z" = "1" /* Replacement of Right Metatarsal with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRN4JZ" = "1" /* Replacement of Right Metatarsal with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QRN4KZ" = "1" /* Replacement of Right Metatarsal with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRP07Z" = "1" /* Replacement of Left Metatarsal with Autologous Tissue Substitute, Open Approach */
"0QRP0JZ" = "1" /* Replacement of Left Metatarsal with Synthetic Substitute, Open Approach */
"0QRP0KZ" = "1" /* Replacement of Left Metatarsal with Nonautologous Tissue Substitute, Open Approach */
"0QRP37Z" = "1" /* Replacement of Left Metatarsal with Autologous Tissue Substitute, Percutaneous Approach */
"0QRP3JZ" = "1" /* Replacement of Left Metatarsal with Synthetic Substitute, Percutaneous Approach */
"0QRP3KZ" = "1" /* Replacement of Left Metatarsal with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QRP47Z" = "1" /* Replacement of Left Metatarsal with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRP4JZ" = "1" /* Replacement of Left Metatarsal with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QRP4KZ" = "1" /* Replacement of Left Metatarsal with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRQ07Z" = "1" /* Replacement of Right Toe Phalanx with Autologous Tissue Substitute, Open Approach */
"0QRQ0JZ" = "1" /* Replacement of Right Toe Phalanx with Synthetic Substitute, Open Approach */
"0QRQ0KZ" = "1" /* Replacement of Right Toe Phalanx with Nonautologous Tissue Substitute, Open Approach */
"0QRQ37Z" = "1" /* Replacement of Right Toe Phalanx with Autologous Tissue Substitute, Percutaneous Approach */
"0QRQ3JZ" = "1" /* Replacement of Right Toe Phalanx with Synthetic Substitute, Percutaneous Approach */
"0QRQ3KZ" = "1" /* Replacement of Right Toe Phalanx with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QRQ47Z" = "1" /* Replacement of Right Toe Phalanx with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRQ4JZ" = "1" /* Replacement of Right Toe Phalanx with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QRQ4KZ" = "1" /* Replacement of Right Toe Phalanx with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRR07Z" = "1" /* Replacement of Left Toe Phalanx with Autologous Tissue Substitute, Open Approach */
"0QRR0JZ" = "1" /* Replacement of Left Toe Phalanx with Synthetic Substitute, Open Approach */
"0QRR0KZ" = "1" /* Replacement of Left Toe Phalanx with Nonautologous Tissue Substitute, Open Approach */
"0QRR37Z" = "1" /* Replacement of Left Toe Phalanx with Autologous Tissue Substitute, Percutaneous Approach */
"0QRR3JZ" = "1" /* Replacement of Left Toe Phalanx with Synthetic Substitute, Percutaneous Approach */
"0QRR3KZ" = "1" /* Replacement of Left Toe Phalanx with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QRR47Z" = "1" /* Replacement of Left Toe Phalanx with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRR4JZ" = "1" /* Replacement of Left Toe Phalanx with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QRR4KZ" = "1" /* Replacement of Left Toe Phalanx with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRS07Z" = "1" /* Replacement of Coccyx with Autologous Tissue Substitute, Open Approach */
"0QRS0JZ" = "1" /* Replacement of Coccyx with Synthetic Substitute, Open Approach */
"0QRS0KZ" = "1" /* Replacement of Coccyx with Nonautologous Tissue Substitute, Open Approach */
"0QRS37Z" = "1" /* Replacement of Coccyx with Autologous Tissue Substitute, Percutaneous Approach */
"0QRS3JZ" = "1" /* Replacement of Coccyx with Synthetic Substitute, Percutaneous Approach */
"0QRS3KZ" = "1" /* Replacement of Coccyx with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QRS47Z" = "1" /* Replacement of Coccyx with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QRS4JZ" = "1" /* Replacement of Coccyx with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QRS4KZ" = "1" /* Replacement of Coccyx with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QS004Z" = "1" /* Reposition Lumbar Vertebra with Internal Fixation Device, Open Approach */
"0QS00ZZ" = "1" /* Reposition Lumbar Vertebra, Open Approach */
"0QS034Z" = "1" /* Reposition Lumbar Vertebra with Internal Fixation Device, Percutaneous Approach */
"0QS03ZZ" = "1" /* Reposition Lumbar Vertebra, Percutaneous Approach */
"0QS044Z" = "1" /* Reposition Lumbar Vertebra with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QS04ZZ" = "1" /* Reposition Lumbar Vertebra, Percutaneous Endoscopic Approach */
"0QS104Z" = "1" /* Reposition Sacrum with Internal Fixation Device, Open Approach */
"0QS10ZZ" = "1" /* Reposition Sacrum, Open Approach */
"0QS134Z" = "1" /* Reposition Sacrum with Internal Fixation Device, Percutaneous Approach */
"0QS13ZZ" = "1" /* Reposition Sacrum, Percutaneous Approach */
"0QS144Z" = "1" /* Reposition Sacrum with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QS14ZZ" = "1" /* Reposition Sacrum, Percutaneous Endoscopic Approach */
"0QS204Z" = "1" /* Reposition Right Pelvic Bone with Internal Fixation Device, Open Approach */
"0QS205Z" = "1" /* Reposition Right Pelvic Bone with External Fixation Device, Open Approach */
"0QS20ZZ" = "1" /* Reposition Right Pelvic Bone, Open Approach */
"0QS234Z" = "1" /* Reposition Right Pelvic Bone with Internal Fixation Device, Percutaneous Approach */
"0QS235Z" = "1" /* Reposition Right Pelvic Bone with External Fixation Device, Percutaneous Approach */
"0QS244Z" = "1" /* Reposition Right Pelvic Bone with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QS245Z" = "1" /* Reposition Right Pelvic Bone with External Fixation Device, Percutaneous Endoscopic Approach */
"0QS304Z" = "1" /* Reposition Left Pelvic Bone with Internal Fixation Device, Open Approach */
"0QS305Z" = "1" /* Reposition Left Pelvic Bone with External Fixation Device, Open Approach */
"0QS30ZZ" = "1" /* Reposition Left Pelvic Bone, Open Approach */
"0QS334Z" = "1" /* Reposition Left Pelvic Bone with Internal Fixation Device, Percutaneous Approach */
"0QS335Z" = "1" /* Reposition Left Pelvic Bone with External Fixation Device, Percutaneous Approach */
"0QS344Z" = "1" /* Reposition Left Pelvic Bone with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QS345Z" = "1" /* Reposition Left Pelvic Bone with External Fixation Device, Percutaneous Endoscopic Approach */
"0QS404Z" = "1" /* Reposition Right Acetabulum with Internal Fixation Device, Open Approach */
"0QS40ZZ" = "1" /* Reposition Right Acetabulum, Open Approach */
"0QS434Z" = "1" /* Reposition Right Acetabulum with Internal Fixation Device, Percutaneous Approach */
"0QS444Z" = "1" /* Reposition Right Acetabulum with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QS504Z" = "1" /* Reposition Left Acetabulum with Internal Fixation Device, Open Approach */
"0QS50ZZ" = "1" /* Reposition Left Acetabulum, Open Approach */
"0QS534Z" = "1" /* Reposition Left Acetabulum with Internal Fixation Device, Percutaneous Approach */
"0QS544Z" = "1" /* Reposition Left Acetabulum with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QS604Z" = "1" /* Reposition Right Upper Femur with Internal Fixation Device, Open Approach */
"0QS605Z" = "1" /* Reposition Right Upper Femur with External Fixation Device, Open Approach */
"0QS606Z" = "1" /* Reposition Right Upper Femur with Intramedullary Internal Fixation Device, Open Approach */
"0QS60BZ" = "1" /* Reposition Right Upper Femur with Monoplanar External Fixation Device, Open Approach */
"0QS60CZ" = "1" /* Reposition Right Upper Femur with Ring External Fixation Device, Open Approach */
"0QS60DZ" = "1" /* Reposition Right Upper Femur with Hybrid External Fixation Device, Open Approach */
"0QS60ZZ" = "1" /* Reposition Right Upper Femur, Open Approach */
"0QS634Z" = "1" /* Reposition Right Upper Femur with Internal Fixation Device, Percutaneous Approach */
"0QS635Z" = "1" /* Reposition Right Upper Femur with External Fixation Device, Percutaneous Approach */
"0QS636Z" = "1" /* Reposition Right Upper Femur with Intramedullary Internal Fixation Device, Percutaneous Approach */
"0QS63BZ" = "1" /* Reposition Right Upper Femur with Monoplanar External Fixation Device, Percutaneous Approach */
"0QS63CZ" = "1" /* Reposition Right Upper Femur with Ring External Fixation Device, Percutaneous Approach */
"0QS63DZ" = "1" /* Reposition Right Upper Femur with Hybrid External Fixation Device, Percutaneous Approach */
"0QS644Z" = "1" /* Reposition Right Upper Femur with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QS645Z" = "1" /* Reposition Right Upper Femur with External Fixation Device, Percutaneous Endoscopic Approach */
"0QS646Z" = "1" /* Reposition Right Upper Femur with Intramedullary Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QS64BZ" = "1" /* Reposition Right Upper Femur with Monoplanar External Fixation Device, Percutaneous Endoscopic Approach */
"0QS64CZ" = "1" /* Reposition Right Upper Femur with Ring External Fixation Device, Percutaneous Endoscopic Approach */
"0QS64DZ" = "1" /* Reposition Right Upper Femur with Hybrid External Fixation Device, Percutaneous Endoscopic Approach */
"0QS704Z" = "1" /* Reposition Left Upper Femur with Internal Fixation Device, Open Approach */
"0QS705Z" = "1" /* Reposition Left Upper Femur with External Fixation Device, Open Approach */
"0QS706Z" = "1" /* Reposition Left Upper Femur with Intramedullary Internal Fixation Device, Open Approach */
"0QS70BZ" = "1" /* Reposition Left Upper Femur with Monoplanar External Fixation Device, Open Approach */
"0QS70CZ" = "1" /* Reposition Left Upper Femur with Ring External Fixation Device, Open Approach */
"0QS70DZ" = "1" /* Reposition Left Upper Femur with Hybrid External Fixation Device, Open Approach */
"0QS70ZZ" = "1" /* Reposition Left Upper Femur, Open Approach */
"0QS734Z" = "1" /* Reposition Left Upper Femur with Internal Fixation Device, Percutaneous Approach */
"0QS735Z" = "1" /* Reposition Left Upper Femur with External Fixation Device, Percutaneous Approach */
"0QS736Z" = "1" /* Reposition Left Upper Femur with Intramedullary Internal Fixation Device, Percutaneous Approach */
"0QS73BZ" = "1" /* Reposition Left Upper Femur with Monoplanar External Fixation Device, Percutaneous Approach */
"0QS73CZ" = "1" /* Reposition Left Upper Femur with Ring External Fixation Device, Percutaneous Approach */
"0QS73DZ" = "1" /* Reposition Left Upper Femur with Hybrid External Fixation Device, Percutaneous Approach */
"0QS744Z" = "1" /* Reposition Left Upper Femur with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QS745Z" = "1" /* Reposition Left Upper Femur with External Fixation Device, Percutaneous Endoscopic Approach */
"0QS746Z" = "1" /* Reposition Left Upper Femur with Intramedullary Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QS74BZ" = "1" /* Reposition Left Upper Femur with Monoplanar External Fixation Device, Percutaneous Endoscopic Approach */
"0QS74CZ" = "1" /* Reposition Left Upper Femur with Ring External Fixation Device, Percutaneous Endoscopic Approach */
"0QS74DZ" = "1" /* Reposition Left Upper Femur with Hybrid External Fixation Device, Percutaneous Endoscopic Approach */
"0QS804Z" = "1" /* Reposition Right Femoral Shaft with Internal Fixation Device, Open Approach */
"0QS805Z" = "1" /* Reposition Right Femoral Shaft with External Fixation Device, Open Approach */
"0QS806Z" = "1" /* Reposition Right Femoral Shaft with Intramedullary Internal Fixation Device, Open Approach */
"0QS80BZ" = "1" /* Reposition Right Femoral Shaft with Monoplanar External Fixation Device, Open Approach */
"0QS80CZ" = "1" /* Reposition Right Femoral Shaft with Ring External Fixation Device, Open Approach */
"0QS80DZ" = "1" /* Reposition Right Femoral Shaft with Hybrid External Fixation Device, Open Approach */
"0QS80ZZ" = "1" /* Reposition Right Femoral Shaft, Open Approach */
"0QS834Z" = "1" /* Reposition Right Femoral Shaft with Internal Fixation Device, Percutaneous Approach */
"0QS835Z" = "1" /* Reposition Right Femoral Shaft with External Fixation Device, Percutaneous Approach */
"0QS836Z" = "1" /* Reposition Right Femoral Shaft with Intramedullary Internal Fixation Device, Percutaneous Approach */
"0QS83BZ" = "1" /* Reposition Right Femoral Shaft with Monoplanar External Fixation Device, Percutaneous Approach */
"0QS83CZ" = "1" /* Reposition Right Femoral Shaft with Ring External Fixation Device, Percutaneous Approach */
"0QS83DZ" = "1" /* Reposition Right Femoral Shaft with Hybrid External Fixation Device, Percutaneous Approach */
"0QS844Z" = "1" /* Reposition Right Femoral Shaft with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QS845Z" = "1" /* Reposition Right Femoral Shaft with External Fixation Device, Percutaneous Endoscopic Approach */
"0QS846Z" = "1" /* Reposition Right Femoral Shaft with Intramedullary Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QS84BZ" = "1" /* Reposition Right Femoral Shaft with Monoplanar External Fixation Device, Percutaneous Endoscopic Approach */
"0QS84CZ" = "1" /* Reposition Right Femoral Shaft with Ring External Fixation Device, Percutaneous Endoscopic Approach */
"0QS84DZ" = "1" /* Reposition Right Femoral Shaft with Hybrid External Fixation Device, Percutaneous Endoscopic Approach */
"0QS904Z" = "1" /* Reposition Left Femoral Shaft with Internal Fixation Device, Open Approach */
"0QS905Z" = "1" /* Reposition Left Femoral Shaft with External Fixation Device, Open Approach */
"0QS906Z" = "1" /* Reposition Left Femoral Shaft with Intramedullary Internal Fixation Device, Open Approach */
"0QS90BZ" = "1" /* Reposition Left Femoral Shaft with Monoplanar External Fixation Device, Open Approach */
"0QS90CZ" = "1" /* Reposition Left Femoral Shaft with Ring External Fixation Device, Open Approach */
"0QS90DZ" = "1" /* Reposition Left Femoral Shaft with Hybrid External Fixation Device, Open Approach */
"0QS90ZZ" = "1" /* Reposition Left Femoral Shaft, Open Approach */
"0QS934Z" = "1" /* Reposition Left Femoral Shaft with Internal Fixation Device, Percutaneous Approach */
"0QS935Z" = "1" /* Reposition Left Femoral Shaft with External Fixation Device, Percutaneous Approach */
"0QS936Z" = "1" /* Reposition Left Femoral Shaft with Intramedullary Internal Fixation Device, Percutaneous Approach */
"0QS93BZ" = "1" /* Reposition Left Femoral Shaft with Monoplanar External Fixation Device, Percutaneous Approach */
"0QS93CZ" = "1" /* Reposition Left Femoral Shaft with Ring External Fixation Device, Percutaneous Approach */
"0QS93DZ" = "1" /* Reposition Left Femoral Shaft with Hybrid External Fixation Device, Percutaneous Approach */
"0QS944Z" = "1" /* Reposition Left Femoral Shaft with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QS945Z" = "1" /* Reposition Left Femoral Shaft with External Fixation Device, Percutaneous Endoscopic Approach */
"0QS946Z" = "1" /* Reposition Left Femoral Shaft with Intramedullary Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QS94BZ" = "1" /* Reposition Left Femoral Shaft with Monoplanar External Fixation Device, Percutaneous Endoscopic Approach */
"0QS94CZ" = "1" /* Reposition Left Femoral Shaft with Ring External Fixation Device, Percutaneous Endoscopic Approach */
"0QS94DZ" = "1" /* Reposition Left Femoral Shaft with Hybrid External Fixation Device, Percutaneous Endoscopic Approach */
"0QSB04Z" = "1" /* Reposition Right Lower Femur with Internal Fixation Device, Open Approach */
"0QSB05Z" = "1" /* Reposition Right Lower Femur with External Fixation Device, Open Approach */
"0QSB06Z" = "1" /* Reposition Right Lower Femur with Intramedullary Internal Fixation Device, Open Approach */
"0QSB0BZ" = "1" /* Reposition Right Lower Femur with Monoplanar External Fixation Device, Open Approach */
"0QSB0CZ" = "1" /* Reposition Right Lower Femur with Ring External Fixation Device, Open Approach */
"0QSB0DZ" = "1" /* Reposition Right Lower Femur with Hybrid External Fixation Device, Open Approach */
"0QSB0ZZ" = "1" /* Reposition Right Lower Femur, Open Approach */
"0QSB34Z" = "1" /* Reposition Right Lower Femur with Internal Fixation Device, Percutaneous Approach */
"0QSB35Z" = "1" /* Reposition Right Lower Femur with External Fixation Device, Percutaneous Approach */
"0QSB36Z" = "1" /* Reposition Right Lower Femur with Intramedullary Internal Fixation Device, Percutaneous Approach */
"0QSB3BZ" = "1" /* Reposition Right Lower Femur with Monoplanar External Fixation Device, Percutaneous Approach */
"0QSB3CZ" = "1" /* Reposition Right Lower Femur with Ring External Fixation Device, Percutaneous Approach */
"0QSB3DZ" = "1" /* Reposition Right Lower Femur with Hybrid External Fixation Device, Percutaneous Approach */
"0QSB44Z" = "1" /* Reposition Right Lower Femur with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QSB45Z" = "1" /* Reposition Right Lower Femur with External Fixation Device, Percutaneous Endoscopic Approach */
"0QSB46Z" = "1" /* Reposition Right Lower Femur with Intramedullary Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QSB4BZ" = "1" /* Reposition Right Lower Femur with Monoplanar External Fixation Device, Percutaneous Endoscopic Approach */
"0QSB4CZ" = "1" /* Reposition Right Lower Femur with Ring External Fixation Device, Percutaneous Endoscopic Approach */
"0QSB4DZ" = "1" /* Reposition Right Lower Femur with Hybrid External Fixation Device, Percutaneous Endoscopic Approach */
"0QSC04Z" = "1" /* Reposition Left Lower Femur with Internal Fixation Device, Open Approach */
"0QSC05Z" = "1" /* Reposition Left Lower Femur with External Fixation Device, Open Approach */
"0QSC06Z" = "1" /* Reposition Left Lower Femur with Intramedullary Internal Fixation Device, Open Approach */
"0QSC0BZ" = "1" /* Reposition Left Lower Femur with Monoplanar External Fixation Device, Open Approach */
"0QSC0CZ" = "1" /* Reposition Left Lower Femur with Ring External Fixation Device, Open Approach */
"0QSC0DZ" = "1" /* Reposition Left Lower Femur with Hybrid External Fixation Device, Open Approach */
"0QSC0ZZ" = "1" /* Reposition Left Lower Femur, Open Approach */
"0QSC34Z" = "1" /* Reposition Left Lower Femur with Internal Fixation Device, Percutaneous Approach */
"0QSC35Z" = "1" /* Reposition Left Lower Femur with External Fixation Device, Percutaneous Approach */
"0QSC36Z" = "1" /* Reposition Left Lower Femur with Intramedullary Internal Fixation Device, Percutaneous Approach */
"0QSC3BZ" = "1" /* Reposition Left Lower Femur with Monoplanar External Fixation Device, Percutaneous Approach */
"0QSC3CZ" = "1" /* Reposition Left Lower Femur with Ring External Fixation Device, Percutaneous Approach */
"0QSC3DZ" = "1" /* Reposition Left Lower Femur with Hybrid External Fixation Device, Percutaneous Approach */
"0QSC44Z" = "1" /* Reposition Left Lower Femur with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QSC45Z" = "1" /* Reposition Left Lower Femur with External Fixation Device, Percutaneous Endoscopic Approach */
"0QSC46Z" = "1" /* Reposition Left Lower Femur with Intramedullary Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QSC4BZ" = "1" /* Reposition Left Lower Femur with Monoplanar External Fixation Device, Percutaneous Endoscopic Approach */
"0QSC4CZ" = "1" /* Reposition Left Lower Femur with Ring External Fixation Device, Percutaneous Endoscopic Approach */
"0QSC4DZ" = "1" /* Reposition Left Lower Femur with Hybrid External Fixation Device, Percutaneous Endoscopic Approach */
"0QSD04Z" = "1" /* Reposition Right Patella with Internal Fixation Device, Open Approach */
"0QSD05Z" = "1" /* Reposition Right Patella with External Fixation Device, Open Approach */
"0QSD0ZZ" = "1" /* Reposition Right Patella, Open Approach */
"0QSD34Z" = "1" /* Reposition Right Patella with Internal Fixation Device, Percutaneous Approach */
"0QSD35Z" = "1" /* Reposition Right Patella with External Fixation Device, Percutaneous Approach */
"0QSD44Z" = "1" /* Reposition Right Patella with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QSD45Z" = "1" /* Reposition Right Patella with External Fixation Device, Percutaneous Endoscopic Approach */
"0QSF04Z" = "1" /* Reposition Left Patella with Internal Fixation Device, Open Approach */
"0QSF05Z" = "1" /* Reposition Left Patella with External Fixation Device, Open Approach */
"0QSF0ZZ" = "1" /* Reposition Left Patella, Open Approach */
"0QSF34Z" = "1" /* Reposition Left Patella with Internal Fixation Device, Percutaneous Approach */
"0QSF35Z" = "1" /* Reposition Left Patella with External Fixation Device, Percutaneous Approach */
"0QSF44Z" = "1" /* Reposition Left Patella with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QSF45Z" = "1" /* Reposition Left Patella with External Fixation Device, Percutaneous Endoscopic Approach */
"0QSG04Z" = "1" /* Reposition Right Tibia with Internal Fixation Device, Open Approach */
"0QSG05Z" = "1" /* Reposition Right Tibia with External Fixation Device, Open Approach */
"0QSG06Z" = "1" /* Reposition Right Tibia with Intramedullary Internal Fixation Device, Open Approach */
"0QSG0BZ" = "1" /* Reposition Right Tibia with Monoplanar External Fixation Device, Open Approach */
"0QSG0CZ" = "1" /* Reposition Right Tibia with Ring External Fixation Device, Open Approach */
"0QSG0DZ" = "1" /* Reposition Right Tibia with Hybrid External Fixation Device, Open Approach */
"0QSG0ZZ" = "1" /* Reposition Right Tibia, Open Approach */
"0QSG34Z" = "1" /* Reposition Right Tibia with Internal Fixation Device, Percutaneous Approach */
"0QSG35Z" = "1" /* Reposition Right Tibia with External Fixation Device, Percutaneous Approach */
"0QSG36Z" = "1" /* Reposition Right Tibia with Intramedullary Internal Fixation Device, Percutaneous Approach */
"0QSG3BZ" = "1" /* Reposition Right Tibia with Monoplanar External Fixation Device, Percutaneous Approach */
"0QSG3CZ" = "1" /* Reposition Right Tibia with Ring External Fixation Device, Percutaneous Approach */
"0QSG3DZ" = "1" /* Reposition Right Tibia with Hybrid External Fixation Device, Percutaneous Approach */
"0QSG44Z" = "1" /* Reposition Right Tibia with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QSG45Z" = "1" /* Reposition Right Tibia with External Fixation Device, Percutaneous Endoscopic Approach */
"0QSG46Z" = "1" /* Reposition Right Tibia with Intramedullary Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QSG4BZ" = "1" /* Reposition Right Tibia with Monoplanar External Fixation Device, Percutaneous Endoscopic Approach */
"0QSG4CZ" = "1" /* Reposition Right Tibia with Ring External Fixation Device, Percutaneous Endoscopic Approach */
"0QSG4DZ" = "1" /* Reposition Right Tibia with Hybrid External Fixation Device, Percutaneous Endoscopic Approach */
"0QSH04Z" = "1" /* Reposition Left Tibia with Internal Fixation Device, Open Approach */
"0QSH05Z" = "1" /* Reposition Left Tibia with External Fixation Device, Open Approach */
"0QSH06Z" = "1" /* Reposition Left Tibia with Intramedullary Internal Fixation Device, Open Approach */
"0QSH0BZ" = "1" /* Reposition Left Tibia with Monoplanar External Fixation Device, Open Approach */
"0QSH0CZ" = "1" /* Reposition Left Tibia with Ring External Fixation Device, Open Approach */
"0QSH0DZ" = "1" /* Reposition Left Tibia with Hybrid External Fixation Device, Open Approach */
"0QSH0ZZ" = "1" /* Reposition Left Tibia, Open Approach */
"0QSH34Z" = "1" /* Reposition Left Tibia with Internal Fixation Device, Percutaneous Approach */
"0QSH35Z" = "1" /* Reposition Left Tibia with External Fixation Device, Percutaneous Approach */
"0QSH36Z" = "1" /* Reposition Left Tibia with Intramedullary Internal Fixation Device, Percutaneous Approach */
"0QSH3BZ" = "1" /* Reposition Left Tibia with Monoplanar External Fixation Device, Percutaneous Approach */
"0QSH3CZ" = "1" /* Reposition Left Tibia with Ring External Fixation Device, Percutaneous Approach */
"0QSH3DZ" = "1" /* Reposition Left Tibia with Hybrid External Fixation Device, Percutaneous Approach */
"0QSH44Z" = "1" /* Reposition Left Tibia with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QSH45Z" = "1" /* Reposition Left Tibia with External Fixation Device, Percutaneous Endoscopic Approach */
"0QSH46Z" = "1" /* Reposition Left Tibia with Intramedullary Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QSH4BZ" = "1" /* Reposition Left Tibia with Monoplanar External Fixation Device, Percutaneous Endoscopic Approach */
"0QSH4CZ" = "1" /* Reposition Left Tibia with Ring External Fixation Device, Percutaneous Endoscopic Approach */
"0QSH4DZ" = "1" /* Reposition Left Tibia with Hybrid External Fixation Device, Percutaneous Endoscopic Approach */
"0QSJ04Z" = "1" /* Reposition Right Fibula with Internal Fixation Device, Open Approach */
"0QSJ05Z" = "1" /* Reposition Right Fibula with External Fixation Device, Open Approach */
"0QSJ06Z" = "1" /* Reposition Right Fibula with Intramedullary Internal Fixation Device, Open Approach */
"0QSJ0BZ" = "1" /* Reposition Right Fibula with Monoplanar External Fixation Device, Open Approach */
"0QSJ0CZ" = "1" /* Reposition Right Fibula with Ring External Fixation Device, Open Approach */
"0QSJ0DZ" = "1" /* Reposition Right Fibula with Hybrid External Fixation Device, Open Approach */
"0QSJ0ZZ" = "1" /* Reposition Right Fibula, Open Approach */
"0QSJ34Z" = "1" /* Reposition Right Fibula with Internal Fixation Device, Percutaneous Approach */
"0QSJ35Z" = "1" /* Reposition Right Fibula with External Fixation Device, Percutaneous Approach */
"0QSJ36Z" = "1" /* Reposition Right Fibula with Intramedullary Internal Fixation Device, Percutaneous Approach */
"0QSJ3BZ" = "1" /* Reposition Right Fibula with Monoplanar External Fixation Device, Percutaneous Approach */
"0QSJ3CZ" = "1" /* Reposition Right Fibula with Ring External Fixation Device, Percutaneous Approach */
"0QSJ3DZ" = "1" /* Reposition Right Fibula with Hybrid External Fixation Device, Percutaneous Approach */
"0QSJ44Z" = "1" /* Reposition Right Fibula with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QSJ45Z" = "1" /* Reposition Right Fibula with External Fixation Device, Percutaneous Endoscopic Approach */
"0QSJ46Z" = "1" /* Reposition Right Fibula with Intramedullary Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QSJ4BZ" = "1" /* Reposition Right Fibula with Monoplanar External Fixation Device, Percutaneous Endoscopic Approach */
"0QSJ4CZ" = "1" /* Reposition Right Fibula with Ring External Fixation Device, Percutaneous Endoscopic Approach */
"0QSJ4DZ" = "1" /* Reposition Right Fibula with Hybrid External Fixation Device, Percutaneous Endoscopic Approach */
"0QSK04Z" = "1" /* Reposition Left Fibula with Internal Fixation Device, Open Approach */
"0QSK05Z" = "1" /* Reposition Left Fibula with External Fixation Device, Open Approach */
"0QSK06Z" = "1" /* Reposition Left Fibula with Intramedullary Internal Fixation Device, Open Approach */
"0QSK0BZ" = "1" /* Reposition Left Fibula with Monoplanar External Fixation Device, Open Approach */
"0QSK0CZ" = "1" /* Reposition Left Fibula with Ring External Fixation Device, Open Approach */
"0QSK0DZ" = "1" /* Reposition Left Fibula with Hybrid External Fixation Device, Open Approach */
"0QSK0ZZ" = "1" /* Reposition Left Fibula, Open Approach */
"0QSK34Z" = "1" /* Reposition Left Fibula with Internal Fixation Device, Percutaneous Approach */
"0QSK35Z" = "1" /* Reposition Left Fibula with External Fixation Device, Percutaneous Approach */
"0QSK36Z" = "1" /* Reposition Left Fibula with Intramedullary Internal Fixation Device, Percutaneous Approach */
"0QSK3BZ" = "1" /* Reposition Left Fibula with Monoplanar External Fixation Device, Percutaneous Approach */
"0QSK3CZ" = "1" /* Reposition Left Fibula with Ring External Fixation Device, Percutaneous Approach */
"0QSK3DZ" = "1" /* Reposition Left Fibula with Hybrid External Fixation Device, Percutaneous Approach */
"0QSK44Z" = "1" /* Reposition Left Fibula with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QSK45Z" = "1" /* Reposition Left Fibula with External Fixation Device, Percutaneous Endoscopic Approach */
"0QSK46Z" = "1" /* Reposition Left Fibula with Intramedullary Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QSK4BZ" = "1" /* Reposition Left Fibula with Monoplanar External Fixation Device, Percutaneous Endoscopic Approach */
"0QSK4CZ" = "1" /* Reposition Left Fibula with Ring External Fixation Device, Percutaneous Endoscopic Approach */
"0QSK4DZ" = "1" /* Reposition Left Fibula with Hybrid External Fixation Device, Percutaneous Endoscopic Approach */
"0QSL04Z" = "1" /* Reposition Right Tarsal with Internal Fixation Device, Open Approach */
"0QSL05Z" = "1" /* Reposition Right Tarsal with External Fixation Device, Open Approach */
"0QSL0ZZ" = "1" /* Reposition Right Tarsal, Open Approach */
"0QSL34Z" = "1" /* Reposition Right Tarsal with Internal Fixation Device, Percutaneous Approach */
"0QSL35Z" = "1" /* Reposition Right Tarsal with External Fixation Device, Percutaneous Approach */
"0QSL44Z" = "1" /* Reposition Right Tarsal with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QSL45Z" = "1" /* Reposition Right Tarsal with External Fixation Device, Percutaneous Endoscopic Approach */
"0QSM04Z" = "1" /* Reposition Left Tarsal with Internal Fixation Device, Open Approach */
"0QSM05Z" = "1" /* Reposition Left Tarsal with External Fixation Device, Open Approach */
"0QSM0ZZ" = "1" /* Reposition Left Tarsal, Open Approach */
"0QSM34Z" = "1" /* Reposition Left Tarsal with Internal Fixation Device, Percutaneous Approach */
"0QSM35Z" = "1" /* Reposition Left Tarsal with External Fixation Device, Percutaneous Approach */
"0QSM44Z" = "1" /* Reposition Left Tarsal with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QSM45Z" = "1" /* Reposition Left Tarsal with External Fixation Device, Percutaneous Endoscopic Approach */
"0QSN04Z" = "1" /* Reposition Right Metatarsal with Internal Fixation Device, Open Approach */
"0QSN05Z" = "1" /* Reposition Right Metatarsal with External Fixation Device, Open Approach */
"0QSN0ZZ" = "1" /* Reposition Right Metatarsal, Open Approach */
"0QSN34Z" = "1" /* Reposition Right Metatarsal with Internal Fixation Device, Percutaneous Approach */
"0QSN35Z" = "1" /* Reposition Right Metatarsal with External Fixation Device, Percutaneous Approach */
"0QSN44Z" = "1" /* Reposition Right Metatarsal with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QSN45Z" = "1" /* Reposition Right Metatarsal with External Fixation Device, Percutaneous Endoscopic Approach */
"0QSP04Z" = "1" /* Reposition Left Metatarsal with Internal Fixation Device, Open Approach */
"0QSP05Z" = "1" /* Reposition Left Metatarsal with External Fixation Device, Open Approach */
"0QSP0ZZ" = "1" /* Reposition Left Metatarsal, Open Approach */
"0QSP34Z" = "1" /* Reposition Left Metatarsal with Internal Fixation Device, Percutaneous Approach */
"0QSP35Z" = "1" /* Reposition Left Metatarsal with External Fixation Device, Percutaneous Approach */
"0QSP44Z" = "1" /* Reposition Left Metatarsal with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QSP45Z" = "1" /* Reposition Left Metatarsal with External Fixation Device, Percutaneous Endoscopic Approach */
"0QSQ04Z" = "1" /* Reposition Right Toe Phalanx with Internal Fixation Device, Open Approach */
"0QSQ05Z" = "1" /* Reposition Right Toe Phalanx with External Fixation Device, Open Approach */
"0QSQ0ZZ" = "1" /* Reposition Right Toe Phalanx, Open Approach */
"0QSQ34Z" = "1" /* Reposition Right Toe Phalanx with Internal Fixation Device, Percutaneous Approach */
"0QSQ35Z" = "1" /* Reposition Right Toe Phalanx with External Fixation Device, Percutaneous Approach */
"0QSQ44Z" = "1" /* Reposition Right Toe Phalanx with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QSQ45Z" = "1" /* Reposition Right Toe Phalanx with External Fixation Device, Percutaneous Endoscopic Approach */
"0QSR04Z" = "1" /* Reposition Left Toe Phalanx with Internal Fixation Device, Open Approach */
"0QSR05Z" = "1" /* Reposition Left Toe Phalanx with External Fixation Device, Open Approach */
"0QSR0ZZ" = "1" /* Reposition Left Toe Phalanx, Open Approach */
"0QSR34Z" = "1" /* Reposition Left Toe Phalanx with Internal Fixation Device, Percutaneous Approach */
"0QSR35Z" = "1" /* Reposition Left Toe Phalanx with External Fixation Device, Percutaneous Approach */
"0QSR44Z" = "1" /* Reposition Left Toe Phalanx with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QSR45Z" = "1" /* Reposition Left Toe Phalanx with External Fixation Device, Percutaneous Endoscopic Approach */
"0QSS04Z" = "1" /* Reposition Coccyx with Internal Fixation Device, Open Approach */
"0QSS0ZZ" = "1" /* Reposition Coccyx, Open Approach */
"0QSS34Z" = "1" /* Reposition Coccyx with Internal Fixation Device, Percutaneous Approach */
"0QSS3ZZ" = "1" /* Reposition Coccyx, Percutaneous Approach */
"0QSS44Z" = "1" /* Reposition Coccyx with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0QSS4ZZ" = "1" /* Reposition Coccyx, Percutaneous Endoscopic Approach */
"0QT20ZZ" = "1" /* Resection of Right Pelvic Bone, Open Approach */
"0QT30ZZ" = "1" /* Resection of Left Pelvic Bone, Open Approach */
"0QT40ZZ" = "1" /* Resection of Right Acetabulum, Open Approach */
"0QT50ZZ" = "1" /* Resection of Left Acetabulum, Open Approach */
"0QT60ZZ" = "1" /* Resection of Right Upper Femur, Open Approach */
"0QT70ZZ" = "1" /* Resection of Left Upper Femur, Open Approach */
"0QT80ZZ" = "1" /* Resection of Right Femoral Shaft, Open Approach */
"0QT90ZZ" = "1" /* Resection of Left Femoral Shaft, Open Approach */
"0QTB0ZZ" = "1" /* Resection of Right Lower Femur, Open Approach */
"0QTC0ZZ" = "1" /* Resection of Left Lower Femur, Open Approach */
"0QTD0ZZ" = "1" /* Resection of Right Patella, Open Approach */
"0QTF0ZZ" = "1" /* Resection of Left Patella, Open Approach */
"0QTG0ZZ" = "1" /* Resection of Right Tibia, Open Approach */
"0QTH0ZZ" = "1" /* Resection of Left Tibia, Open Approach */
"0QTJ0ZZ" = "1" /* Resection of Right Fibula, Open Approach */
"0QTK0ZZ" = "1" /* Resection of Left Fibula, Open Approach */
"0QTL0ZZ" = "1" /* Resection of Right Tarsal, Open Approach */
"0QTM0ZZ" = "1" /* Resection of Left Tarsal, Open Approach */
"0QTN0ZZ" = "1" /* Resection of Right Metatarsal, Open Approach */
"0QTP0ZZ" = "1" /* Resection of Left Metatarsal, Open Approach */
"0QTQ0ZZ" = "1" /* Resection of Right Toe Phalanx, Open Approach */
"0QTR0ZZ" = "1" /* Resection of Left Toe Phalanx, Open Approach */
"0QTS0ZZ" = "1" /* Resection of Coccyx, Open Approach */
"0QU007Z" = "1" /* Supplement Lumbar Vertebra with Autologous Tissue Substitute, Open Approach */
"0QU00JZ" = "1" /* Supplement Lumbar Vertebra with Synthetic Substitute, Open Approach */
"0QU00KZ" = "1" /* Supplement Lumbar Vertebra with Nonautologous Tissue Substitute, Open Approach */
"0QU037Z" = "1" /* Supplement Lumbar Vertebra with Autologous Tissue Substitute, Percutaneous Approach */
"0QU03JZ" = "1" /* Supplement Lumbar Vertebra with Synthetic Substitute, Percutaneous Approach */
"0QU03KZ" = "1" /* Supplement Lumbar Vertebra with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QU047Z" = "1" /* Supplement Lumbar Vertebra with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QU04JZ" = "1" /* Supplement Lumbar Vertebra with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QU04KZ" = "1" /* Supplement Lumbar Vertebra with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QU107Z" = "1" /* Supplement Sacrum with Autologous Tissue Substitute, Open Approach */
"0QU10JZ" = "1" /* Supplement Sacrum with Synthetic Substitute, Open Approach */
"0QU10KZ" = "1" /* Supplement Sacrum with Nonautologous Tissue Substitute, Open Approach */
"0QU137Z" = "1" /* Supplement Sacrum with Autologous Tissue Substitute, Percutaneous Approach */
"0QU13JZ" = "1" /* Supplement Sacrum with Synthetic Substitute, Percutaneous Approach */
"0QU13KZ" = "1" /* Supplement Sacrum with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QU147Z" = "1" /* Supplement Sacrum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QU14JZ" = "1" /* Supplement Sacrum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QU14KZ" = "1" /* Supplement Sacrum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QU207Z" = "1" /* Supplement Right Pelvic Bone with Autologous Tissue Substitute, Open Approach */
"0QU20JZ" = "1" /* Supplement Right Pelvic Bone with Synthetic Substitute, Open Approach */
"0QU20KZ" = "1" /* Supplement Right Pelvic Bone with Nonautologous Tissue Substitute, Open Approach */
"0QU237Z" = "1" /* Supplement Right Pelvic Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0QU23JZ" = "1" /* Supplement Right Pelvic Bone with Synthetic Substitute, Percutaneous Approach */
"0QU23KZ" = "1" /* Supplement Right Pelvic Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QU247Z" = "1" /* Supplement Right Pelvic Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QU24JZ" = "1" /* Supplement Right Pelvic Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QU24KZ" = "1" /* Supplement Right Pelvic Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QU307Z" = "1" /* Supplement Left Pelvic Bone with Autologous Tissue Substitute, Open Approach */
"0QU30JZ" = "1" /* Supplement Left Pelvic Bone with Synthetic Substitute, Open Approach */
"0QU30KZ" = "1" /* Supplement Left Pelvic Bone with Nonautologous Tissue Substitute, Open Approach */
"0QU337Z" = "1" /* Supplement Left Pelvic Bone with Autologous Tissue Substitute, Percutaneous Approach */
"0QU33JZ" = "1" /* Supplement Left Pelvic Bone with Synthetic Substitute, Percutaneous Approach */
"0QU33KZ" = "1" /* Supplement Left Pelvic Bone with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QU347Z" = "1" /* Supplement Left Pelvic Bone with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QU34JZ" = "1" /* Supplement Left Pelvic Bone with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QU34KZ" = "1" /* Supplement Left Pelvic Bone with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QU407Z" = "1" /* Supplement Right Acetabulum with Autologous Tissue Substitute, Open Approach */
"0QU40JZ" = "1" /* Supplement Right Acetabulum with Synthetic Substitute, Open Approach */
"0QU40KZ" = "1" /* Supplement Right Acetabulum with Nonautologous Tissue Substitute, Open Approach */
"0QU437Z" = "1" /* Supplement Right Acetabulum with Autologous Tissue Substitute, Percutaneous Approach */
"0QU43JZ" = "1" /* Supplement Right Acetabulum with Synthetic Substitute, Percutaneous Approach */
"0QU43KZ" = "1" /* Supplement Right Acetabulum with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QU447Z" = "1" /* Supplement Right Acetabulum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QU44JZ" = "1" /* Supplement Right Acetabulum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QU44KZ" = "1" /* Supplement Right Acetabulum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QU507Z" = "1" /* Supplement Left Acetabulum with Autologous Tissue Substitute, Open Approach */
"0QU50JZ" = "1" /* Supplement Left Acetabulum with Synthetic Substitute, Open Approach */
"0QU50KZ" = "1" /* Supplement Left Acetabulum with Nonautologous Tissue Substitute, Open Approach */
"0QU537Z" = "1" /* Supplement Left Acetabulum with Autologous Tissue Substitute, Percutaneous Approach */
"0QU53JZ" = "1" /* Supplement Left Acetabulum with Synthetic Substitute, Percutaneous Approach */
"0QU53KZ" = "1" /* Supplement Left Acetabulum with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QU547Z" = "1" /* Supplement Left Acetabulum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QU54JZ" = "1" /* Supplement Left Acetabulum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QU54KZ" = "1" /* Supplement Left Acetabulum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QU607Z" = "1" /* Supplement Right Upper Femur with Autologous Tissue Substitute, Open Approach */
"0QU60JZ" = "1" /* Supplement Right Upper Femur with Synthetic Substitute, Open Approach */
"0QU60KZ" = "1" /* Supplement Right Upper Femur with Nonautologous Tissue Substitute, Open Approach */
"0QU637Z" = "1" /* Supplement Right Upper Femur with Autologous Tissue Substitute, Percutaneous Approach */
"0QU63JZ" = "1" /* Supplement Right Upper Femur with Synthetic Substitute, Percutaneous Approach */
"0QU63KZ" = "1" /* Supplement Right Upper Femur with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QU647Z" = "1" /* Supplement Right Upper Femur with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QU64JZ" = "1" /* Supplement Right Upper Femur with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QU64KZ" = "1" /* Supplement Right Upper Femur with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QU707Z" = "1" /* Supplement Left Upper Femur with Autologous Tissue Substitute, Open Approach */
"0QU70JZ" = "1" /* Supplement Left Upper Femur with Synthetic Substitute, Open Approach */
"0QU70KZ" = "1" /* Supplement Left Upper Femur with Nonautologous Tissue Substitute, Open Approach */
"0QU737Z" = "1" /* Supplement Left Upper Femur with Autologous Tissue Substitute, Percutaneous Approach */
"0QU73JZ" = "1" /* Supplement Left Upper Femur with Synthetic Substitute, Percutaneous Approach */
"0QU73KZ" = "1" /* Supplement Left Upper Femur with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QU747Z" = "1" /* Supplement Left Upper Femur with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QU74JZ" = "1" /* Supplement Left Upper Femur with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QU74KZ" = "1" /* Supplement Left Upper Femur with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QU807Z" = "1" /* Supplement Right Femoral Shaft with Autologous Tissue Substitute, Open Approach */
"0QU80JZ" = "1" /* Supplement Right Femoral Shaft with Synthetic Substitute, Open Approach */
"0QU80KZ" = "1" /* Supplement Right Femoral Shaft with Nonautologous Tissue Substitute, Open Approach */
"0QU837Z" = "1" /* Supplement Right Femoral Shaft with Autologous Tissue Substitute, Percutaneous Approach */
"0QU83JZ" = "1" /* Supplement Right Femoral Shaft with Synthetic Substitute, Percutaneous Approach */
"0QU83KZ" = "1" /* Supplement Right Femoral Shaft with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QU847Z" = "1" /* Supplement Right Femoral Shaft with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QU84JZ" = "1" /* Supplement Right Femoral Shaft with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QU84KZ" = "1" /* Supplement Right Femoral Shaft with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QU907Z" = "1" /* Supplement Left Femoral Shaft with Autologous Tissue Substitute, Open Approach */
"0QU90JZ" = "1" /* Supplement Left Femoral Shaft with Synthetic Substitute, Open Approach */
"0QU90KZ" = "1" /* Supplement Left Femoral Shaft with Nonautologous Tissue Substitute, Open Approach */
"0QU937Z" = "1" /* Supplement Left Femoral Shaft with Autologous Tissue Substitute, Percutaneous Approach */
"0QU93JZ" = "1" /* Supplement Left Femoral Shaft with Synthetic Substitute, Percutaneous Approach */
"0QU93KZ" = "1" /* Supplement Left Femoral Shaft with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QU947Z" = "1" /* Supplement Left Femoral Shaft with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QU94JZ" = "1" /* Supplement Left Femoral Shaft with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QU94KZ" = "1" /* Supplement Left Femoral Shaft with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUB07Z" = "1" /* Supplement Right Lower Femur with Autologous Tissue Substitute, Open Approach */
"0QUB0JZ" = "1" /* Supplement Right Lower Femur with Synthetic Substitute, Open Approach */
"0QUB0KZ" = "1" /* Supplement Right Lower Femur with Nonautologous Tissue Substitute, Open Approach */
"0QUB37Z" = "1" /* Supplement Right Lower Femur with Autologous Tissue Substitute, Percutaneous Approach */
"0QUB3JZ" = "1" /* Supplement Right Lower Femur with Synthetic Substitute, Percutaneous Approach */
"0QUB3KZ" = "1" /* Supplement Right Lower Femur with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QUB47Z" = "1" /* Supplement Right Lower Femur with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUB4JZ" = "1" /* Supplement Right Lower Femur with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QUB4KZ" = "1" /* Supplement Right Lower Femur with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUC07Z" = "1" /* Supplement Left Lower Femur with Autologous Tissue Substitute, Open Approach */
"0QUC0JZ" = "1" /* Supplement Left Lower Femur with Synthetic Substitute, Open Approach */
"0QUC0KZ" = "1" /* Supplement Left Lower Femur with Nonautologous Tissue Substitute, Open Approach */
"0QUC37Z" = "1" /* Supplement Left Lower Femur with Autologous Tissue Substitute, Percutaneous Approach */
"0QUC3JZ" = "1" /* Supplement Left Lower Femur with Synthetic Substitute, Percutaneous Approach */
"0QUC3KZ" = "1" /* Supplement Left Lower Femur with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QUC47Z" = "1" /* Supplement Left Lower Femur with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUC4JZ" = "1" /* Supplement Left Lower Femur with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QUC4KZ" = "1" /* Supplement Left Lower Femur with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUD07Z" = "1" /* Supplement Right Patella with Autologous Tissue Substitute, Open Approach */
"0QUD0JZ" = "1" /* Supplement Right Patella with Synthetic Substitute, Open Approach */
"0QUD0KZ" = "1" /* Supplement Right Patella with Nonautologous Tissue Substitute, Open Approach */
"0QUD37Z" = "1" /* Supplement Right Patella with Autologous Tissue Substitute, Percutaneous Approach */
"0QUD3JZ" = "1" /* Supplement Right Patella with Synthetic Substitute, Percutaneous Approach */
"0QUD3KZ" = "1" /* Supplement Right Patella with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QUD47Z" = "1" /* Supplement Right Patella with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUD4JZ" = "1" /* Supplement Right Patella with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QUD4KZ" = "1" /* Supplement Right Patella with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUF07Z" = "1" /* Supplement Left Patella with Autologous Tissue Substitute, Open Approach */
"0QUF0JZ" = "1" /* Supplement Left Patella with Synthetic Substitute, Open Approach */
"0QUF0KZ" = "1" /* Supplement Left Patella with Nonautologous Tissue Substitute, Open Approach */
"0QUF37Z" = "1" /* Supplement Left Patella with Autologous Tissue Substitute, Percutaneous Approach */
"0QUF3JZ" = "1" /* Supplement Left Patella with Synthetic Substitute, Percutaneous Approach */
"0QUF3KZ" = "1" /* Supplement Left Patella with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QUF47Z" = "1" /* Supplement Left Patella with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUF4JZ" = "1" /* Supplement Left Patella with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QUF4KZ" = "1" /* Supplement Left Patella with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUG07Z" = "1" /* Supplement Right Tibia with Autologous Tissue Substitute, Open Approach */
"0QUG0JZ" = "1" /* Supplement Right Tibia with Synthetic Substitute, Open Approach */
"0QUG0KZ" = "1" /* Supplement Right Tibia with Nonautologous Tissue Substitute, Open Approach */
"0QUG37Z" = "1" /* Supplement Right Tibia with Autologous Tissue Substitute, Percutaneous Approach */
"0QUG3JZ" = "1" /* Supplement Right Tibia with Synthetic Substitute, Percutaneous Approach */
"0QUG3KZ" = "1" /* Supplement Right Tibia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QUG47Z" = "1" /* Supplement Right Tibia with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUG4JZ" = "1" /* Supplement Right Tibia with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QUG4KZ" = "1" /* Supplement Right Tibia with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUH07Z" = "1" /* Supplement Left Tibia with Autologous Tissue Substitute, Open Approach */
"0QUH0JZ" = "1" /* Supplement Left Tibia with Synthetic Substitute, Open Approach */
"0QUH0KZ" = "1" /* Supplement Left Tibia with Nonautologous Tissue Substitute, Open Approach */
"0QUH37Z" = "1" /* Supplement Left Tibia with Autologous Tissue Substitute, Percutaneous Approach */
"0QUH3JZ" = "1" /* Supplement Left Tibia with Synthetic Substitute, Percutaneous Approach */
"0QUH3KZ" = "1" /* Supplement Left Tibia with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QUH47Z" = "1" /* Supplement Left Tibia with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUH4JZ" = "1" /* Supplement Left Tibia with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QUH4KZ" = "1" /* Supplement Left Tibia with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUJ07Z" = "1" /* Supplement Right Fibula with Autologous Tissue Substitute, Open Approach */
"0QUJ0JZ" = "1" /* Supplement Right Fibula with Synthetic Substitute, Open Approach */
"0QUJ0KZ" = "1" /* Supplement Right Fibula with Nonautologous Tissue Substitute, Open Approach */
"0QUJ37Z" = "1" /* Supplement Right Fibula with Autologous Tissue Substitute, Percutaneous Approach */
"0QUJ3JZ" = "1" /* Supplement Right Fibula with Synthetic Substitute, Percutaneous Approach */
"0QUJ3KZ" = "1" /* Supplement Right Fibula with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QUJ47Z" = "1" /* Supplement Right Fibula with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUJ4JZ" = "1" /* Supplement Right Fibula with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QUJ4KZ" = "1" /* Supplement Right Fibula with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUK07Z" = "1" /* Supplement Left Fibula with Autologous Tissue Substitute, Open Approach */
"0QUK0JZ" = "1" /* Supplement Left Fibula with Synthetic Substitute, Open Approach */
"0QUK0KZ" = "1" /* Supplement Left Fibula with Nonautologous Tissue Substitute, Open Approach */
"0QUK37Z" = "1" /* Supplement Left Fibula with Autologous Tissue Substitute, Percutaneous Approach */
"0QUK3JZ" = "1" /* Supplement Left Fibula with Synthetic Substitute, Percutaneous Approach */
"0QUK3KZ" = "1" /* Supplement Left Fibula with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QUK47Z" = "1" /* Supplement Left Fibula with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUK4JZ" = "1" /* Supplement Left Fibula with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QUK4KZ" = "1" /* Supplement Left Fibula with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUL07Z" = "1" /* Supplement Right Tarsal with Autologous Tissue Substitute, Open Approach */
"0QUL0JZ" = "1" /* Supplement Right Tarsal with Synthetic Substitute, Open Approach */
"0QUL0KZ" = "1" /* Supplement Right Tarsal with Nonautologous Tissue Substitute, Open Approach */
"0QUL37Z" = "1" /* Supplement Right Tarsal with Autologous Tissue Substitute, Percutaneous Approach */
"0QUL3JZ" = "1" /* Supplement Right Tarsal with Synthetic Substitute, Percutaneous Approach */
"0QUL3KZ" = "1" /* Supplement Right Tarsal with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QUL47Z" = "1" /* Supplement Right Tarsal with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUL4JZ" = "1" /* Supplement Right Tarsal with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QUL4KZ" = "1" /* Supplement Right Tarsal with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUM07Z" = "1" /* Supplement Left Tarsal with Autologous Tissue Substitute, Open Approach */
"0QUM0JZ" = "1" /* Supplement Left Tarsal with Synthetic Substitute, Open Approach */
"0QUM0KZ" = "1" /* Supplement Left Tarsal with Nonautologous Tissue Substitute, Open Approach */
"0QUM37Z" = "1" /* Supplement Left Tarsal with Autologous Tissue Substitute, Percutaneous Approach */
"0QUM3JZ" = "1" /* Supplement Left Tarsal with Synthetic Substitute, Percutaneous Approach */
"0QUM3KZ" = "1" /* Supplement Left Tarsal with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QUM47Z" = "1" /* Supplement Left Tarsal with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUM4JZ" = "1" /* Supplement Left Tarsal with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QUM4KZ" = "1" /* Supplement Left Tarsal with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUN07Z" = "1" /* Supplement Right Metatarsal with Autologous Tissue Substitute, Open Approach */
"0QUN0JZ" = "1" /* Supplement Right Metatarsal with Synthetic Substitute, Open Approach */
"0QUN0KZ" = "1" /* Supplement Right Metatarsal with Nonautologous Tissue Substitute, Open Approach */
"0QUN37Z" = "1" /* Supplement Right Metatarsal with Autologous Tissue Substitute, Percutaneous Approach */
"0QUN3JZ" = "1" /* Supplement Right Metatarsal with Synthetic Substitute, Percutaneous Approach */
"0QUN3KZ" = "1" /* Supplement Right Metatarsal with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QUN47Z" = "1" /* Supplement Right Metatarsal with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUN4JZ" = "1" /* Supplement Right Metatarsal with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QUN4KZ" = "1" /* Supplement Right Metatarsal with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUP07Z" = "1" /* Supplement Left Metatarsal with Autologous Tissue Substitute, Open Approach */
"0QUP0JZ" = "1" /* Supplement Left Metatarsal with Synthetic Substitute, Open Approach */
"0QUP0KZ" = "1" /* Supplement Left Metatarsal with Nonautologous Tissue Substitute, Open Approach */
"0QUP37Z" = "1" /* Supplement Left Metatarsal with Autologous Tissue Substitute, Percutaneous Approach */
"0QUP3JZ" = "1" /* Supplement Left Metatarsal with Synthetic Substitute, Percutaneous Approach */
"0QUP3KZ" = "1" /* Supplement Left Metatarsal with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QUP47Z" = "1" /* Supplement Left Metatarsal with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUP4JZ" = "1" /* Supplement Left Metatarsal with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QUP4KZ" = "1" /* Supplement Left Metatarsal with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUQ07Z" = "1" /* Supplement Right Toe Phalanx with Autologous Tissue Substitute, Open Approach */
"0QUQ0JZ" = "1" /* Supplement Right Toe Phalanx with Synthetic Substitute, Open Approach */
"0QUQ0KZ" = "1" /* Supplement Right Toe Phalanx with Nonautologous Tissue Substitute, Open Approach */
"0QUQ37Z" = "1" /* Supplement Right Toe Phalanx with Autologous Tissue Substitute, Percutaneous Approach */
"0QUQ3JZ" = "1" /* Supplement Right Toe Phalanx with Synthetic Substitute, Percutaneous Approach */
"0QUQ3KZ" = "1" /* Supplement Right Toe Phalanx with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QUQ47Z" = "1" /* Supplement Right Toe Phalanx with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUQ4JZ" = "1" /* Supplement Right Toe Phalanx with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QUQ4KZ" = "1" /* Supplement Right Toe Phalanx with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUR07Z" = "1" /* Supplement Left Toe Phalanx with Autologous Tissue Substitute, Open Approach */
"0QUR0JZ" = "1" /* Supplement Left Toe Phalanx with Synthetic Substitute, Open Approach */
"0QUR0KZ" = "1" /* Supplement Left Toe Phalanx with Nonautologous Tissue Substitute, Open Approach */
"0QUR37Z" = "1" /* Supplement Left Toe Phalanx with Autologous Tissue Substitute, Percutaneous Approach */
"0QUR3JZ" = "1" /* Supplement Left Toe Phalanx with Synthetic Substitute, Percutaneous Approach */
"0QUR3KZ" = "1" /* Supplement Left Toe Phalanx with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QUR47Z" = "1" /* Supplement Left Toe Phalanx with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUR4JZ" = "1" /* Supplement Left Toe Phalanx with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QUR4KZ" = "1" /* Supplement Left Toe Phalanx with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUS07Z" = "1" /* Supplement Coccyx with Autologous Tissue Substitute, Open Approach */
"0QUS0JZ" = "1" /* Supplement Coccyx with Synthetic Substitute, Open Approach */
"0QUS0KZ" = "1" /* Supplement Coccyx with Nonautologous Tissue Substitute, Open Approach */
"0QUS37Z" = "1" /* Supplement Coccyx with Autologous Tissue Substitute, Percutaneous Approach */
"0QUS3JZ" = "1" /* Supplement Coccyx with Synthetic Substitute, Percutaneous Approach */
"0QUS3KZ" = "1" /* Supplement Coccyx with Nonautologous Tissue Substitute, Percutaneous Approach */
"0QUS47Z" = "1" /* Supplement Coccyx with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QUS4JZ" = "1" /* Supplement Coccyx with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0QUS4KZ" = "1" /* Supplement Coccyx with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0QW004Z" = "1" /* Revision of Internal Fixation Device in Lumbar Vertebra, Open Approach */
"0QW007Z" = "1" /* Revision of Autologous Tissue Substitute in Lumbar Vertebra, Open Approach */
"0QW00JZ" = "1" /* Revision of Synthetic Substitute in Lumbar Vertebra, Open Approach */
"0QW00KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lumbar Vertebra, Open Approach */
"0QW034Z" = "1" /* Revision of Internal Fixation Device in Lumbar Vertebra, Percutaneous Approach */
"0QW037Z" = "1" /* Revision of Autologous Tissue Substitute in Lumbar Vertebra, Percutaneous Approach */
"0QW03JZ" = "1" /* Revision of Synthetic Substitute in Lumbar Vertebra, Percutaneous Approach */
"0QW03KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lumbar Vertebra, Percutaneous Approach */
"0QW044Z" = "1" /* Revision of Internal Fixation Device in Lumbar Vertebra, Percutaneous Endoscopic Approach */
"0QW047Z" = "1" /* Revision of Autologous Tissue Substitute in Lumbar Vertebra, Percutaneous Endoscopic Approach */
"0QW04JZ" = "1" /* Revision of Synthetic Substitute in Lumbar Vertebra, Percutaneous Endoscopic Approach */
"0QW04KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lumbar Vertebra, Percutaneous Endoscopic Approach */
"0QW104Z" = "1" /* Revision of Internal Fixation Device in Sacrum, Open Approach */
"0QW107Z" = "1" /* Revision of Autologous Tissue Substitute in Sacrum, Open Approach */
"0QW10JZ" = "1" /* Revision of Synthetic Substitute in Sacrum, Open Approach */
"0QW10KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Sacrum, Open Approach */
"0QW134Z" = "1" /* Revision of Internal Fixation Device in Sacrum, Percutaneous Approach */
"0QW137Z" = "1" /* Revision of Autologous Tissue Substitute in Sacrum, Percutaneous Approach */
"0QW13JZ" = "1" /* Revision of Synthetic Substitute in Sacrum, Percutaneous Approach */
"0QW13KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Sacrum, Percutaneous Approach */
"0QW144Z" = "1" /* Revision of Internal Fixation Device in Sacrum, Percutaneous Endoscopic Approach */
"0QW147Z" = "1" /* Revision of Autologous Tissue Substitute in Sacrum, Percutaneous Endoscopic Approach */
"0QW14JZ" = "1" /* Revision of Synthetic Substitute in Sacrum, Percutaneous Endoscopic Approach */
"0QW14KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Sacrum, Percutaneous Endoscopic Approach */
"0QW204Z" = "1" /* Revision of Internal Fixation Device in Right Pelvic Bone, Open Approach */
"0QW205Z" = "1" /* Revision of External Fixation Device in Right Pelvic Bone, Open Approach */
"0QW207Z" = "1" /* Revision of Autologous Tissue Substitute in Right Pelvic Bone, Open Approach */
"0QW20JZ" = "1" /* Revision of Synthetic Substitute in Right Pelvic Bone, Open Approach */
"0QW20KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Pelvic Bone, Open Approach */
"0QW234Z" = "1" /* Revision of Internal Fixation Device in Right Pelvic Bone, Percutaneous Approach */
"0QW235Z" = "1" /* Revision of External Fixation Device in Right Pelvic Bone, Percutaneous Approach */
"0QW237Z" = "1" /* Revision of Autologous Tissue Substitute in Right Pelvic Bone, Percutaneous Approach */
"0QW23JZ" = "1" /* Revision of Synthetic Substitute in Right Pelvic Bone, Percutaneous Approach */
"0QW23KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Pelvic Bone, Percutaneous Approach */
"0QW244Z" = "1" /* Revision of Internal Fixation Device in Right Pelvic Bone, Percutaneous Endoscopic Approach */
"0QW245Z" = "1" /* Revision of External Fixation Device in Right Pelvic Bone, Percutaneous Endoscopic Approach */
"0QW247Z" = "1" /* Revision of Autologous Tissue Substitute in Right Pelvic Bone, Percutaneous Endoscopic Approach */
"0QW24JZ" = "1" /* Revision of Synthetic Substitute in Right Pelvic Bone, Percutaneous Endoscopic Approach */
"0QW24KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Pelvic Bone, Percutaneous Endoscopic Approach */
"0QW304Z" = "1" /* Revision of Internal Fixation Device in Left Pelvic Bone, Open Approach */
"0QW305Z" = "1" /* Revision of External Fixation Device in Left Pelvic Bone, Open Approach */
"0QW307Z" = "1" /* Revision of Autologous Tissue Substitute in Left Pelvic Bone, Open Approach */
"0QW30JZ" = "1" /* Revision of Synthetic Substitute in Left Pelvic Bone, Open Approach */
"0QW30KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Pelvic Bone, Open Approach */
"0QW334Z" = "1" /* Revision of Internal Fixation Device in Left Pelvic Bone, Percutaneous Approach */
"0QW335Z" = "1" /* Revision of External Fixation Device in Left Pelvic Bone, Percutaneous Approach */
"0QW337Z" = "1" /* Revision of Autologous Tissue Substitute in Left Pelvic Bone, Percutaneous Approach */
"0QW33JZ" = "1" /* Revision of Synthetic Substitute in Left Pelvic Bone, Percutaneous Approach */
"0QW33KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Pelvic Bone, Percutaneous Approach */
"0QW344Z" = "1" /* Revision of Internal Fixation Device in Left Pelvic Bone, Percutaneous Endoscopic Approach */
"0QW345Z" = "1" /* Revision of External Fixation Device in Left Pelvic Bone, Percutaneous Endoscopic Approach */
"0QW347Z" = "1" /* Revision of Autologous Tissue Substitute in Left Pelvic Bone, Percutaneous Endoscopic Approach */
"0QW34JZ" = "1" /* Revision of Synthetic Substitute in Left Pelvic Bone, Percutaneous Endoscopic Approach */
"0QW34KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Pelvic Bone, Percutaneous Endoscopic Approach */
"0QW404Z" = "1" /* Revision of Internal Fixation Device in Right Acetabulum, Open Approach */
"0QW407Z" = "1" /* Revision of Autologous Tissue Substitute in Right Acetabulum, Open Approach */
"0QW40JZ" = "1" /* Revision of Synthetic Substitute in Right Acetabulum, Open Approach */
"0QW40KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Acetabulum, Open Approach */
"0QW434Z" = "1" /* Revision of Internal Fixation Device in Right Acetabulum, Percutaneous Approach */
"0QW437Z" = "1" /* Revision of Autologous Tissue Substitute in Right Acetabulum, Percutaneous Approach */
"0QW43JZ" = "1" /* Revision of Synthetic Substitute in Right Acetabulum, Percutaneous Approach */
"0QW43KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Acetabulum, Percutaneous Approach */
"0QW444Z" = "1" /* Revision of Internal Fixation Device in Right Acetabulum, Percutaneous Endoscopic Approach */
"0QW447Z" = "1" /* Revision of Autologous Tissue Substitute in Right Acetabulum, Percutaneous Endoscopic Approach */
"0QW44JZ" = "1" /* Revision of Synthetic Substitute in Right Acetabulum, Percutaneous Endoscopic Approach */
"0QW44KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Acetabulum, Percutaneous Endoscopic Approach */
"0QW504Z" = "1" /* Revision of Internal Fixation Device in Left Acetabulum, Open Approach */
"0QW507Z" = "1" /* Revision of Autologous Tissue Substitute in Left Acetabulum, Open Approach */
"0QW50JZ" = "1" /* Revision of Synthetic Substitute in Left Acetabulum, Open Approach */
"0QW50KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Acetabulum, Open Approach */
"0QW534Z" = "1" /* Revision of Internal Fixation Device in Left Acetabulum, Percutaneous Approach */
"0QW537Z" = "1" /* Revision of Autologous Tissue Substitute in Left Acetabulum, Percutaneous Approach */
"0QW53JZ" = "1" /* Revision of Synthetic Substitute in Left Acetabulum, Percutaneous Approach */
"0QW53KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Acetabulum, Percutaneous Approach */
"0QW544Z" = "1" /* Revision of Internal Fixation Device in Left Acetabulum, Percutaneous Endoscopic Approach */
"0QW547Z" = "1" /* Revision of Autologous Tissue Substitute in Left Acetabulum, Percutaneous Endoscopic Approach */
"0QW54JZ" = "1" /* Revision of Synthetic Substitute in Left Acetabulum, Percutaneous Endoscopic Approach */
"0QW54KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Acetabulum, Percutaneous Endoscopic Approach */
"0QW604Z" = "1" /* Revision of Internal Fixation Device in Right Upper Femur, Open Approach */
"0QW605Z" = "1" /* Revision of External Fixation Device in Right Upper Femur, Open Approach */
"0QW607Z" = "1" /* Revision of Autologous Tissue Substitute in Right Upper Femur, Open Approach */
"0QW60JZ" = "1" /* Revision of Synthetic Substitute in Right Upper Femur, Open Approach */
"0QW60KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Upper Femur, Open Approach */
"0QW634Z" = "1" /* Revision of Internal Fixation Device in Right Upper Femur, Percutaneous Approach */
"0QW635Z" = "1" /* Revision of External Fixation Device in Right Upper Femur, Percutaneous Approach */
"0QW637Z" = "1" /* Revision of Autologous Tissue Substitute in Right Upper Femur, Percutaneous Approach */
"0QW63JZ" = "1" /* Revision of Synthetic Substitute in Right Upper Femur, Percutaneous Approach */
"0QW63KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Upper Femur, Percutaneous Approach */
"0QW644Z" = "1" /* Revision of Internal Fixation Device in Right Upper Femur, Percutaneous Endoscopic Approach */
"0QW645Z" = "1" /* Revision of External Fixation Device in Right Upper Femur, Percutaneous Endoscopic Approach */
"0QW647Z" = "1" /* Revision of Autologous Tissue Substitute in Right Upper Femur, Percutaneous Endoscopic Approach */
"0QW64JZ" = "1" /* Revision of Synthetic Substitute in Right Upper Femur, Percutaneous Endoscopic Approach */
"0QW64KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Upper Femur, Percutaneous Endoscopic Approach */
"0QW704Z" = "1" /* Revision of Internal Fixation Device in Left Upper Femur, Open Approach */
"0QW705Z" = "1" /* Revision of External Fixation Device in Left Upper Femur, Open Approach */
"0QW707Z" = "1" /* Revision of Autologous Tissue Substitute in Left Upper Femur, Open Approach */
"0QW70JZ" = "1" /* Revision of Synthetic Substitute in Left Upper Femur, Open Approach */
"0QW70KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Upper Femur, Open Approach */
"0QW734Z" = "1" /* Revision of Internal Fixation Device in Left Upper Femur, Percutaneous Approach */
"0QW735Z" = "1" /* Revision of External Fixation Device in Left Upper Femur, Percutaneous Approach */
"0QW737Z" = "1" /* Revision of Autologous Tissue Substitute in Left Upper Femur, Percutaneous Approach */
"0QW73JZ" = "1" /* Revision of Synthetic Substitute in Left Upper Femur, Percutaneous Approach */
"0QW73KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Upper Femur, Percutaneous Approach */
"0QW744Z" = "1" /* Revision of Internal Fixation Device in Left Upper Femur, Percutaneous Endoscopic Approach */
"0QW745Z" = "1" /* Revision of External Fixation Device in Left Upper Femur, Percutaneous Endoscopic Approach */
"0QW747Z" = "1" /* Revision of Autologous Tissue Substitute in Left Upper Femur, Percutaneous Endoscopic Approach */
"0QW74JZ" = "1" /* Revision of Synthetic Substitute in Left Upper Femur, Percutaneous Endoscopic Approach */
"0QW74KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Upper Femur, Percutaneous Endoscopic Approach */
"0QW804Z" = "1" /* Revision of Internal Fixation Device in Right Femoral Shaft, Open Approach */
"0QW805Z" = "1" /* Revision of External Fixation Device in Right Femoral Shaft, Open Approach */
"0QW807Z" = "1" /* Revision of Autologous Tissue Substitute in Right Femoral Shaft, Open Approach */
"0QW80JZ" = "1" /* Revision of Synthetic Substitute in Right Femoral Shaft, Open Approach */
"0QW80KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Femoral Shaft, Open Approach */
"0QW834Z" = "1" /* Revision of Internal Fixation Device in Right Femoral Shaft, Percutaneous Approach */
"0QW835Z" = "1" /* Revision of External Fixation Device in Right Femoral Shaft, Percutaneous Approach */
"0QW837Z" = "1" /* Revision of Autologous Tissue Substitute in Right Femoral Shaft, Percutaneous Approach */
"0QW83JZ" = "1" /* Revision of Synthetic Substitute in Right Femoral Shaft, Percutaneous Approach */
"0QW83KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Femoral Shaft, Percutaneous Approach */
"0QW844Z" = "1" /* Revision of Internal Fixation Device in Right Femoral Shaft, Percutaneous Endoscopic Approach */
"0QW845Z" = "1" /* Revision of External Fixation Device in Right Femoral Shaft, Percutaneous Endoscopic Approach */
"0QW847Z" = "1" /* Revision of Autologous Tissue Substitute in Right Femoral Shaft, Percutaneous Endoscopic Approach */
"0QW84JZ" = "1" /* Revision of Synthetic Substitute in Right Femoral Shaft, Percutaneous Endoscopic Approach */
"0QW84KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Femoral Shaft, Percutaneous Endoscopic Approach */
"0QW904Z" = "1" /* Revision of Internal Fixation Device in Left Femoral Shaft, Open Approach */
"0QW905Z" = "1" /* Revision of External Fixation Device in Left Femoral Shaft, Open Approach */
"0QW907Z" = "1" /* Revision of Autologous Tissue Substitute in Left Femoral Shaft, Open Approach */
"0QW90JZ" = "1" /* Revision of Synthetic Substitute in Left Femoral Shaft, Open Approach */
"0QW90KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Femoral Shaft, Open Approach */
"0QW934Z" = "1" /* Revision of Internal Fixation Device in Left Femoral Shaft, Percutaneous Approach */
"0QW935Z" = "1" /* Revision of External Fixation Device in Left Femoral Shaft, Percutaneous Approach */
"0QW937Z" = "1" /* Revision of Autologous Tissue Substitute in Left Femoral Shaft, Percutaneous Approach */
"0QW93JZ" = "1" /* Revision of Synthetic Substitute in Left Femoral Shaft, Percutaneous Approach */
"0QW93KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Femoral Shaft, Percutaneous Approach */
"0QW944Z" = "1" /* Revision of Internal Fixation Device in Left Femoral Shaft, Percutaneous Endoscopic Approach */
"0QW945Z" = "1" /* Revision of External Fixation Device in Left Femoral Shaft, Percutaneous Endoscopic Approach */
"0QW947Z" = "1" /* Revision of Autologous Tissue Substitute in Left Femoral Shaft, Percutaneous Endoscopic Approach */
"0QW94JZ" = "1" /* Revision of Synthetic Substitute in Left Femoral Shaft, Percutaneous Endoscopic Approach */
"0QW94KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Femoral Shaft, Percutaneous Endoscopic Approach */
"0QWB04Z" = "1" /* Revision of Internal Fixation Device in Right Lower Femur, Open Approach */
"0QWB05Z" = "1" /* Revision of External Fixation Device in Right Lower Femur, Open Approach */
"0QWB07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Lower Femur, Open Approach */
"0QWB0JZ" = "1" /* Revision of Synthetic Substitute in Right Lower Femur, Open Approach */
"0QWB0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Lower Femur, Open Approach */
"0QWB34Z" = "1" /* Revision of Internal Fixation Device in Right Lower Femur, Percutaneous Approach */
"0QWB35Z" = "1" /* Revision of External Fixation Device in Right Lower Femur, Percutaneous Approach */
"0QWB37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Lower Femur, Percutaneous Approach */
"0QWB3JZ" = "1" /* Revision of Synthetic Substitute in Right Lower Femur, Percutaneous Approach */
"0QWB3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Lower Femur, Percutaneous Approach */
"0QWB44Z" = "1" /* Revision of Internal Fixation Device in Right Lower Femur, Percutaneous Endoscopic Approach */
"0QWB45Z" = "1" /* Revision of External Fixation Device in Right Lower Femur, Percutaneous Endoscopic Approach */
"0QWB47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Lower Femur, Percutaneous Endoscopic Approach */
"0QWB4JZ" = "1" /* Revision of Synthetic Substitute in Right Lower Femur, Percutaneous Endoscopic Approach */
"0QWB4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Lower Femur, Percutaneous Endoscopic Approach */
"0QWC04Z" = "1" /* Revision of Internal Fixation Device in Left Lower Femur, Open Approach */
"0QWC05Z" = "1" /* Revision of External Fixation Device in Left Lower Femur, Open Approach */
"0QWC07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Lower Femur, Open Approach */
"0QWC0JZ" = "1" /* Revision of Synthetic Substitute in Left Lower Femur, Open Approach */
"0QWC0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Lower Femur, Open Approach */
"0QWC34Z" = "1" /* Revision of Internal Fixation Device in Left Lower Femur, Percutaneous Approach */
"0QWC35Z" = "1" /* Revision of External Fixation Device in Left Lower Femur, Percutaneous Approach */
"0QWC37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Lower Femur, Percutaneous Approach */
"0QWC3JZ" = "1" /* Revision of Synthetic Substitute in Left Lower Femur, Percutaneous Approach */
"0QWC3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Lower Femur, Percutaneous Approach */
"0QWC44Z" = "1" /* Revision of Internal Fixation Device in Left Lower Femur, Percutaneous Endoscopic Approach */
"0QWC45Z" = "1" /* Revision of External Fixation Device in Left Lower Femur, Percutaneous Endoscopic Approach */
"0QWC47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Lower Femur, Percutaneous Endoscopic Approach */
"0QWC4JZ" = "1" /* Revision of Synthetic Substitute in Left Lower Femur, Percutaneous Endoscopic Approach */
"0QWC4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Lower Femur, Percutaneous Endoscopic Approach */
"0QWD04Z" = "1" /* Revision of Internal Fixation Device in Right Patella, Open Approach */
"0QWD05Z" = "1" /* Revision of External Fixation Device in Right Patella, Open Approach */
"0QWD07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Patella, Open Approach */
"0QWD0JZ" = "1" /* Revision of Synthetic Substitute in Right Patella, Open Approach */
"0QWD0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Patella, Open Approach */
"0QWD34Z" = "1" /* Revision of Internal Fixation Device in Right Patella, Percutaneous Approach */
"0QWD35Z" = "1" /* Revision of External Fixation Device in Right Patella, Percutaneous Approach */
"0QWD37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Patella, Percutaneous Approach */
"0QWD3JZ" = "1" /* Revision of Synthetic Substitute in Right Patella, Percutaneous Approach */
"0QWD3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Patella, Percutaneous Approach */
"0QWD44Z" = "1" /* Revision of Internal Fixation Device in Right Patella, Percutaneous Endoscopic Approach */
"0QWD45Z" = "1" /* Revision of External Fixation Device in Right Patella, Percutaneous Endoscopic Approach */
"0QWD47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Patella, Percutaneous Endoscopic Approach */
"0QWD4JZ" = "1" /* Revision of Synthetic Substitute in Right Patella, Percutaneous Endoscopic Approach */
"0QWD4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Patella, Percutaneous Endoscopic Approach */
"0QWF04Z" = "1" /* Revision of Internal Fixation Device in Left Patella, Open Approach */
"0QWF05Z" = "1" /* Revision of External Fixation Device in Left Patella, Open Approach */
"0QWF07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Patella, Open Approach */
"0QWF0JZ" = "1" /* Revision of Synthetic Substitute in Left Patella, Open Approach */
"0QWF0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Patella, Open Approach */
"0QWF34Z" = "1" /* Revision of Internal Fixation Device in Left Patella, Percutaneous Approach */
"0QWF35Z" = "1" /* Revision of External Fixation Device in Left Patella, Percutaneous Approach */
"0QWF37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Patella, Percutaneous Approach */
"0QWF3JZ" = "1" /* Revision of Synthetic Substitute in Left Patella, Percutaneous Approach */
"0QWF3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Patella, Percutaneous Approach */
"0QWF44Z" = "1" /* Revision of Internal Fixation Device in Left Patella, Percutaneous Endoscopic Approach */
"0QWF45Z" = "1" /* Revision of External Fixation Device in Left Patella, Percutaneous Endoscopic Approach */
"0QWF47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Patella, Percutaneous Endoscopic Approach */
"0QWF4JZ" = "1" /* Revision of Synthetic Substitute in Left Patella, Percutaneous Endoscopic Approach */
"0QWF4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Patella, Percutaneous Endoscopic Approach */
"0QWG04Z" = "1" /* Revision of Internal Fixation Device in Right Tibia, Open Approach */
"0QWG05Z" = "1" /* Revision of External Fixation Device in Right Tibia, Open Approach */
"0QWG07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Tibia, Open Approach */
"0QWG0JZ" = "1" /* Revision of Synthetic Substitute in Right Tibia, Open Approach */
"0QWG0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Tibia, Open Approach */
"0QWG34Z" = "1" /* Revision of Internal Fixation Device in Right Tibia, Percutaneous Approach */
"0QWG35Z" = "1" /* Revision of External Fixation Device in Right Tibia, Percutaneous Approach */
"0QWG37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Tibia, Percutaneous Approach */
"0QWG3JZ" = "1" /* Revision of Synthetic Substitute in Right Tibia, Percutaneous Approach */
"0QWG3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Tibia, Percutaneous Approach */
"0QWG44Z" = "1" /* Revision of Internal Fixation Device in Right Tibia, Percutaneous Endoscopic Approach */
"0QWG45Z" = "1" /* Revision of External Fixation Device in Right Tibia, Percutaneous Endoscopic Approach */
"0QWG47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Tibia, Percutaneous Endoscopic Approach */
"0QWG4JZ" = "1" /* Revision of Synthetic Substitute in Right Tibia, Percutaneous Endoscopic Approach */
"0QWG4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Tibia, Percutaneous Endoscopic Approach */
"0QWH04Z" = "1" /* Revision of Internal Fixation Device in Left Tibia, Open Approach */
"0QWH05Z" = "1" /* Revision of External Fixation Device in Left Tibia, Open Approach */
"0QWH07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Tibia, Open Approach */
"0QWH0JZ" = "1" /* Revision of Synthetic Substitute in Left Tibia, Open Approach */
"0QWH0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Tibia, Open Approach */
"0QWH34Z" = "1" /* Revision of Internal Fixation Device in Left Tibia, Percutaneous Approach */
"0QWH35Z" = "1" /* Revision of External Fixation Device in Left Tibia, Percutaneous Approach */
"0QWH37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Tibia, Percutaneous Approach */
"0QWH3JZ" = "1" /* Revision of Synthetic Substitute in Left Tibia, Percutaneous Approach */
"0QWH3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Tibia, Percutaneous Approach */
"0QWH44Z" = "1" /* Revision of Internal Fixation Device in Left Tibia, Percutaneous Endoscopic Approach */
"0QWH45Z" = "1" /* Revision of External Fixation Device in Left Tibia, Percutaneous Endoscopic Approach */
"0QWH47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Tibia, Percutaneous Endoscopic Approach */
"0QWH4JZ" = "1" /* Revision of Synthetic Substitute in Left Tibia, Percutaneous Endoscopic Approach */
"0QWH4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Tibia, Percutaneous Endoscopic Approach */
"0QWJ04Z" = "1" /* Revision of Internal Fixation Device in Right Fibula, Open Approach */
"0QWJ05Z" = "1" /* Revision of External Fixation Device in Right Fibula, Open Approach */
"0QWJ07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Fibula, Open Approach */
"0QWJ0JZ" = "1" /* Revision of Synthetic Substitute in Right Fibula, Open Approach */
"0QWJ0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Fibula, Open Approach */
"0QWJ34Z" = "1" /* Revision of Internal Fixation Device in Right Fibula, Percutaneous Approach */
"0QWJ35Z" = "1" /* Revision of External Fixation Device in Right Fibula, Percutaneous Approach */
"0QWJ37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Fibula, Percutaneous Approach */
"0QWJ3JZ" = "1" /* Revision of Synthetic Substitute in Right Fibula, Percutaneous Approach */
"0QWJ3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Fibula, Percutaneous Approach */
"0QWJ44Z" = "1" /* Revision of Internal Fixation Device in Right Fibula, Percutaneous Endoscopic Approach */
"0QWJ45Z" = "1" /* Revision of External Fixation Device in Right Fibula, Percutaneous Endoscopic Approach */
"0QWJ47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Fibula, Percutaneous Endoscopic Approach */
"0QWJ4JZ" = "1" /* Revision of Synthetic Substitute in Right Fibula, Percutaneous Endoscopic Approach */
"0QWJ4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Fibula, Percutaneous Endoscopic Approach */
"0QWK04Z" = "1" /* Revision of Internal Fixation Device in Left Fibula, Open Approach */
"0QWK05Z" = "1" /* Revision of External Fixation Device in Left Fibula, Open Approach */
"0QWK07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Fibula, Open Approach */
"0QWK0JZ" = "1" /* Revision of Synthetic Substitute in Left Fibula, Open Approach */
"0QWK0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Fibula, Open Approach */
"0QWK34Z" = "1" /* Revision of Internal Fixation Device in Left Fibula, Percutaneous Approach */
"0QWK35Z" = "1" /* Revision of External Fixation Device in Left Fibula, Percutaneous Approach */
"0QWK37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Fibula, Percutaneous Approach */
"0QWK3JZ" = "1" /* Revision of Synthetic Substitute in Left Fibula, Percutaneous Approach */
"0QWK3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Fibula, Percutaneous Approach */
"0QWK44Z" = "1" /* Revision of Internal Fixation Device in Left Fibula, Percutaneous Endoscopic Approach */
"0QWK45Z" = "1" /* Revision of External Fixation Device in Left Fibula, Percutaneous Endoscopic Approach */
"0QWK47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Fibula, Percutaneous Endoscopic Approach */
"0QWK4JZ" = "1" /* Revision of Synthetic Substitute in Left Fibula, Percutaneous Endoscopic Approach */
"0QWK4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Fibula, Percutaneous Endoscopic Approach */
"0QWL04Z" = "1" /* Revision of Internal Fixation Device in Right Tarsal, Open Approach */
"0QWL05Z" = "1" /* Revision of External Fixation Device in Right Tarsal, Open Approach */
"0QWL07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Tarsal, Open Approach */
"0QWL0JZ" = "1" /* Revision of Synthetic Substitute in Right Tarsal, Open Approach */
"0QWL0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Tarsal, Open Approach */
"0QWL34Z" = "1" /* Revision of Internal Fixation Device in Right Tarsal, Percutaneous Approach */
"0QWL35Z" = "1" /* Revision of External Fixation Device in Right Tarsal, Percutaneous Approach */
"0QWL37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Tarsal, Percutaneous Approach */
"0QWL3JZ" = "1" /* Revision of Synthetic Substitute in Right Tarsal, Percutaneous Approach */
"0QWL3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Tarsal, Percutaneous Approach */
"0QWL44Z" = "1" /* Revision of Internal Fixation Device in Right Tarsal, Percutaneous Endoscopic Approach */
"0QWL45Z" = "1" /* Revision of External Fixation Device in Right Tarsal, Percutaneous Endoscopic Approach */
"0QWL47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Tarsal, Percutaneous Endoscopic Approach */
"0QWL4JZ" = "1" /* Revision of Synthetic Substitute in Right Tarsal, Percutaneous Endoscopic Approach */
"0QWL4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Tarsal, Percutaneous Endoscopic Approach */
"0QWM04Z" = "1" /* Revision of Internal Fixation Device in Left Tarsal, Open Approach */
"0QWM05Z" = "1" /* Revision of External Fixation Device in Left Tarsal, Open Approach */
"0QWM07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Tarsal, Open Approach */
"0QWM0JZ" = "1" /* Revision of Synthetic Substitute in Left Tarsal, Open Approach */
"0QWM0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Tarsal, Open Approach */
"0QWM34Z" = "1" /* Revision of Internal Fixation Device in Left Tarsal, Percutaneous Approach */
"0QWM35Z" = "1" /* Revision of External Fixation Device in Left Tarsal, Percutaneous Approach */
"0QWM37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Tarsal, Percutaneous Approach */
"0QWM3JZ" = "1" /* Revision of Synthetic Substitute in Left Tarsal, Percutaneous Approach */
"0QWM3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Tarsal, Percutaneous Approach */
"0QWM44Z" = "1" /* Revision of Internal Fixation Device in Left Tarsal, Percutaneous Endoscopic Approach */
"0QWM45Z" = "1" /* Revision of External Fixation Device in Left Tarsal, Percutaneous Endoscopic Approach */
"0QWM47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Tarsal, Percutaneous Endoscopic Approach */
"0QWM4JZ" = "1" /* Revision of Synthetic Substitute in Left Tarsal, Percutaneous Endoscopic Approach */
"0QWM4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Tarsal, Percutaneous Endoscopic Approach */
"0QWN04Z" = "1" /* Revision of Internal Fixation Device in Right Metatarsal, Open Approach */
"0QWN05Z" = "1" /* Revision of External Fixation Device in Right Metatarsal, Open Approach */
"0QWN07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Metatarsal, Open Approach */
"0QWN0JZ" = "1" /* Revision of Synthetic Substitute in Right Metatarsal, Open Approach */
"0QWN0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Metatarsal, Open Approach */
"0QWN34Z" = "1" /* Revision of Internal Fixation Device in Right Metatarsal, Percutaneous Approach */
"0QWN35Z" = "1" /* Revision of External Fixation Device in Right Metatarsal, Percutaneous Approach */
"0QWN37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Metatarsal, Percutaneous Approach */
"0QWN3JZ" = "1" /* Revision of Synthetic Substitute in Right Metatarsal, Percutaneous Approach */
"0QWN3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Metatarsal, Percutaneous Approach */
"0QWN44Z" = "1" /* Revision of Internal Fixation Device in Right Metatarsal, Percutaneous Endoscopic Approach */
"0QWN45Z" = "1" /* Revision of External Fixation Device in Right Metatarsal, Percutaneous Endoscopic Approach */
"0QWN47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Metatarsal, Percutaneous Endoscopic Approach */
"0QWN4JZ" = "1" /* Revision of Synthetic Substitute in Right Metatarsal, Percutaneous Endoscopic Approach */
"0QWN4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Metatarsal, Percutaneous Endoscopic Approach */
"0QWP04Z" = "1" /* Revision of Internal Fixation Device in Left Metatarsal, Open Approach */
"0QWP05Z" = "1" /* Revision of External Fixation Device in Left Metatarsal, Open Approach */
"0QWP07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Metatarsal, Open Approach */
"0QWP0JZ" = "1" /* Revision of Synthetic Substitute in Left Metatarsal, Open Approach */
"0QWP0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Metatarsal, Open Approach */
"0QWP34Z" = "1" /* Revision of Internal Fixation Device in Left Metatarsal, Percutaneous Approach */
"0QWP35Z" = "1" /* Revision of External Fixation Device in Left Metatarsal, Percutaneous Approach */
"0QWP37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Metatarsal, Percutaneous Approach */
"0QWP3JZ" = "1" /* Revision of Synthetic Substitute in Left Metatarsal, Percutaneous Approach */
"0QWP3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Metatarsal, Percutaneous Approach */
"0QWP44Z" = "1" /* Revision of Internal Fixation Device in Left Metatarsal, Percutaneous Endoscopic Approach */
"0QWP45Z" = "1" /* Revision of External Fixation Device in Left Metatarsal, Percutaneous Endoscopic Approach */
"0QWP47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Metatarsal, Percutaneous Endoscopic Approach */
"0QWP4JZ" = "1" /* Revision of Synthetic Substitute in Left Metatarsal, Percutaneous Endoscopic Approach */
"0QWP4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Metatarsal, Percutaneous Endoscopic Approach */
"0QWQ04Z" = "1" /* Revision of Internal Fixation Device in Right Toe Phalanx, Open Approach */
"0QWQ05Z" = "1" /* Revision of External Fixation Device in Right Toe Phalanx, Open Approach */
"0QWQ07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Toe Phalanx, Open Approach */
"0QWQ0JZ" = "1" /* Revision of Synthetic Substitute in Right Toe Phalanx, Open Approach */
"0QWQ0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Toe Phalanx, Open Approach */
"0QWQ34Z" = "1" /* Revision of Internal Fixation Device in Right Toe Phalanx, Percutaneous Approach */
"0QWQ35Z" = "1" /* Revision of External Fixation Device in Right Toe Phalanx, Percutaneous Approach */
"0QWQ37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Toe Phalanx, Percutaneous Approach */
"0QWQ3JZ" = "1" /* Revision of Synthetic Substitute in Right Toe Phalanx, Percutaneous Approach */
"0QWQ3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Toe Phalanx, Percutaneous Approach */
"0QWQ44Z" = "1" /* Revision of Internal Fixation Device in Right Toe Phalanx, Percutaneous Endoscopic Approach */
"0QWQ45Z" = "1" /* Revision of External Fixation Device in Right Toe Phalanx, Percutaneous Endoscopic Approach */
"0QWQ47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Toe Phalanx, Percutaneous Endoscopic Approach */
"0QWQ4JZ" = "1" /* Revision of Synthetic Substitute in Right Toe Phalanx, Percutaneous Endoscopic Approach */
"0QWQ4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Toe Phalanx, Percutaneous Endoscopic Approach */
"0QWR04Z" = "1" /* Revision of Internal Fixation Device in Left Toe Phalanx, Open Approach */
"0QWR05Z" = "1" /* Revision of External Fixation Device in Left Toe Phalanx, Open Approach */
"0QWR07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Toe Phalanx, Open Approach */
"0QWR0JZ" = "1" /* Revision of Synthetic Substitute in Left Toe Phalanx, Open Approach */
"0QWR0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Toe Phalanx, Open Approach */
"0QWR34Z" = "1" /* Revision of Internal Fixation Device in Left Toe Phalanx, Percutaneous Approach */
"0QWR35Z" = "1" /* Revision of External Fixation Device in Left Toe Phalanx, Percutaneous Approach */
"0QWR37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Toe Phalanx, Percutaneous Approach */
"0QWR3JZ" = "1" /* Revision of Synthetic Substitute in Left Toe Phalanx, Percutaneous Approach */
"0QWR3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Toe Phalanx, Percutaneous Approach */
"0QWR44Z" = "1" /* Revision of Internal Fixation Device in Left Toe Phalanx, Percutaneous Endoscopic Approach */
"0QWR45Z" = "1" /* Revision of External Fixation Device in Left Toe Phalanx, Percutaneous Endoscopic Approach */
"0QWR47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Toe Phalanx, Percutaneous Endoscopic Approach */
"0QWR4JZ" = "1" /* Revision of Synthetic Substitute in Left Toe Phalanx, Percutaneous Endoscopic Approach */
"0QWR4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Toe Phalanx, Percutaneous Endoscopic Approach */
"0QWS04Z" = "1" /* Revision of Internal Fixation Device in Coccyx, Open Approach */
"0QWS07Z" = "1" /* Revision of Autologous Tissue Substitute in Coccyx, Open Approach */
"0QWS0JZ" = "1" /* Revision of Synthetic Substitute in Coccyx, Open Approach */
"0QWS0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Coccyx, Open Approach */
"0QWS34Z" = "1" /* Revision of Internal Fixation Device in Coccyx, Percutaneous Approach */
"0QWS37Z" = "1" /* Revision of Autologous Tissue Substitute in Coccyx, Percutaneous Approach */
"0QWS3JZ" = "1" /* Revision of Synthetic Substitute in Coccyx, Percutaneous Approach */
"0QWS3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Coccyx, Percutaneous Approach */
"0QWS44Z" = "1" /* Revision of Internal Fixation Device in Coccyx, Percutaneous Endoscopic Approach */
"0QWS47Z" = "1" /* Revision of Autologous Tissue Substitute in Coccyx, Percutaneous Endoscopic Approach */
"0QWS4JZ" = "1" /* Revision of Synthetic Substitute in Coccyx, Percutaneous Endoscopic Approach */
"0QWS4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Coccyx, Percutaneous Endoscopic Approach */
"0QWY00Z" = "1" /* Revision of Drainage Device in Lower Bone, Open Approach */
"0QWY0MZ" = "1" /* Revision of Bone Growth Stimulator in Lower Bone, Open Approach */
"0QWY30Z" = "1" /* Revision of Drainage Device in Lower Bone, Percutaneous Approach */
"0QWY3MZ" = "1" /* Revision of Bone Growth Stimulator in Lower Bone, Percutaneous Approach */
"0QWY40Z" = "1" /* Revision of Drainage Device in Lower Bone, Percutaneous Endoscopic Approach */
"0QWY4MZ" = "1" /* Revision of Bone Growth Stimulator in Lower Bone, Percutaneous Endoscopic Approach */
"0R500ZZ" = "1" /* Destruction of Occipital-cervical Joint, Open Approach */
"0R503ZZ" = "1" /* Destruction of Occipital-cervical Joint, Percutaneous Approach */
"0R504ZZ" = "1" /* Destruction of Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0R510ZZ" = "1" /* Destruction of Cervical Vertebral Joint, Open Approach */
"0R513ZZ" = "1" /* Destruction of Cervical Vertebral Joint, Percutaneous Approach */
"0R514ZZ" = "1" /* Destruction of Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0R530ZZ" = "1" /* Destruction of Cervical Vertebral Disc, Open Approach */
"0R540ZZ" = "1" /* Destruction of Cervicothoracic Vertebral Joint, Open Approach */
"0R543ZZ" = "1" /* Destruction of Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0R544ZZ" = "1" /* Destruction of Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0R550ZZ" = "1" /* Destruction of Cervicothoracic Vertebral Disc, Open Approach */
"0R560ZZ" = "1" /* Destruction of Thoracic Vertebral Joint, Open Approach */
"0R563ZZ" = "1" /* Destruction of Thoracic Vertebral Joint, Percutaneous Approach */
"0R564ZZ" = "1" /* Destruction of Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0R590ZZ" = "1" /* Destruction of Thoracic Vertebral Disc, Open Approach */
"0R5A0ZZ" = "1" /* Destruction of Thoracolumbar Vertebral Joint, Open Approach */
"0R5A3ZZ" = "1" /* Destruction of Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0R5A4ZZ" = "1" /* Destruction of Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0R5B0ZZ" = "1" /* Destruction of Thoracolumbar Vertebral Disc, Open Approach */
"0R5C0ZZ" = "1" /* Destruction of Right Temporomandibular Joint, Open Approach */
"0R5C3ZZ" = "1" /* Destruction of Right Temporomandibular Joint, Percutaneous Approach */
"0R5C4ZZ" = "1" /* Destruction of Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0R5D0ZZ" = "1" /* Destruction of Left Temporomandibular Joint, Open Approach */
"0R5D3ZZ" = "1" /* Destruction of Left Temporomandibular Joint, Percutaneous Approach */
"0R5D4ZZ" = "1" /* Destruction of Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0R5E0ZZ" = "1" /* Destruction of Right Sternoclavicular Joint, Open Approach */
"0R5E3ZZ" = "1" /* Destruction of Right Sternoclavicular Joint, Percutaneous Approach */
"0R5E4ZZ" = "1" /* Destruction of Right Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0R5F0ZZ" = "1" /* Destruction of Left Sternoclavicular Joint, Open Approach */
"0R5F3ZZ" = "1" /* Destruction of Left Sternoclavicular Joint, Percutaneous Approach */
"0R5F4ZZ" = "1" /* Destruction of Left Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0R5G0ZZ" = "1" /* Destruction of Right Acromioclavicular Joint, Open Approach */
"0R5G3ZZ" = "1" /* Destruction of Right Acromioclavicular Joint, Percutaneous Approach */
"0R5G4ZZ" = "1" /* Destruction of Right Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0R5H0ZZ" = "1" /* Destruction of Left Acromioclavicular Joint, Open Approach */
"0R5H3ZZ" = "1" /* Destruction of Left Acromioclavicular Joint, Percutaneous Approach */
"0R5H4ZZ" = "1" /* Destruction of Left Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0R5J0ZZ" = "1" /* Destruction of Right Shoulder Joint, Open Approach */
"0R5J3ZZ" = "1" /* Destruction of Right Shoulder Joint, Percutaneous Approach */
"0R5J4ZZ" = "1" /* Destruction of Right Shoulder Joint, Percutaneous Endoscopic Approach */
"0R5K0ZZ" = "1" /* Destruction of Left Shoulder Joint, Open Approach */
"0R5K3ZZ" = "1" /* Destruction of Left Shoulder Joint, Percutaneous Approach */
"0R5K4ZZ" = "1" /* Destruction of Left Shoulder Joint, Percutaneous Endoscopic Approach */
"0R5L0ZZ" = "1" /* Destruction of Right Elbow Joint, Open Approach */
"0R5L3ZZ" = "1" /* Destruction of Right Elbow Joint, Percutaneous Approach */
"0R5L4ZZ" = "1" /* Destruction of Right Elbow Joint, Percutaneous Endoscopic Approach */
"0R5M0ZZ" = "1" /* Destruction of Left Elbow Joint, Open Approach */
"0R5M3ZZ" = "1" /* Destruction of Left Elbow Joint, Percutaneous Approach */
"0R5M4ZZ" = "1" /* Destruction of Left Elbow Joint, Percutaneous Endoscopic Approach */
"0R5N0ZZ" = "1" /* Destruction of Right Wrist Joint, Open Approach */
"0R5N3ZZ" = "1" /* Destruction of Right Wrist Joint, Percutaneous Approach */
"0R5N4ZZ" = "1" /* Destruction of Right Wrist Joint, Percutaneous Endoscopic Approach */
"0R5P0ZZ" = "1" /* Destruction of Left Wrist Joint, Open Approach */
"0R5P3ZZ" = "1" /* Destruction of Left Wrist Joint, Percutaneous Approach */
"0R5P4ZZ" = "1" /* Destruction of Left Wrist Joint, Percutaneous Endoscopic Approach */
"0R5Q0ZZ" = "1" /* Destruction of Right Carpal Joint, Open Approach */
"0R5Q3ZZ" = "1" /* Destruction of Right Carpal Joint, Percutaneous Approach */
"0R5Q4ZZ" = "1" /* Destruction of Right Carpal Joint, Percutaneous Endoscopic Approach */
"0R5R0ZZ" = "1" /* Destruction of Left Carpal Joint, Open Approach */
"0R5R3ZZ" = "1" /* Destruction of Left Carpal Joint, Percutaneous Approach */
"0R5R4ZZ" = "1" /* Destruction of Left Carpal Joint, Percutaneous Endoscopic Approach */
"0R5S0ZZ" = "1" /* Destruction of Right Metacarpocarpal Joint, Open Approach */
"0R5S3ZZ" = "1" /* Destruction of Right Metacarpocarpal Joint, Percutaneous Approach */
"0R5S4ZZ" = "1" /* Destruction of Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0R5T0ZZ" = "1" /* Destruction of Left Metacarpocarpal Joint, Open Approach */
"0R5T3ZZ" = "1" /* Destruction of Left Metacarpocarpal Joint, Percutaneous Approach */
"0R5T4ZZ" = "1" /* Destruction of Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0R5U0ZZ" = "1" /* Destruction of Right Metacarpophalangeal Joint, Open Approach */
"0R5U3ZZ" = "1" /* Destruction of Right Metacarpophalangeal Joint, Percutaneous Approach */
"0R5U4ZZ" = "1" /* Destruction of Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0R5V0ZZ" = "1" /* Destruction of Left Metacarpophalangeal Joint, Open Approach */
"0R5V3ZZ" = "1" /* Destruction of Left Metacarpophalangeal Joint, Percutaneous Approach */
"0R5V4ZZ" = "1" /* Destruction of Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0R5W0ZZ" = "1" /* Destruction of Right Finger Phalangeal Joint, Open Approach */
"0R5W3ZZ" = "1" /* Destruction of Right Finger Phalangeal Joint, Percutaneous Approach */
"0R5W4ZZ" = "1" /* Destruction of Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0R5X0ZZ" = "1" /* Destruction of Left Finger Phalangeal Joint, Open Approach */
"0R5X3ZZ" = "1" /* Destruction of Left Finger Phalangeal Joint, Percutaneous Approach */
"0R5X4ZZ" = "1" /* Destruction of Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0R9000Z" = "1" /* Drainage of Occipital-cervical Joint with Drainage Device, Open Approach */
"0R900ZZ" = "1" /* Drainage of Occipital-cervical Joint, Open Approach */
"0R9100Z" = "1" /* Drainage of Cervical Vertebral Joint with Drainage Device, Open Approach */
"0R910ZZ" = "1" /* Drainage of Cervical Vertebral Joint, Open Approach */
"0R9300Z" = "1" /* Drainage of Cervical Vertebral Disc with Drainage Device, Open Approach */
"0R930ZZ" = "1" /* Drainage of Cervical Vertebral Disc, Open Approach */
"0R9400Z" = "1" /* Drainage of Cervicothoracic Vertebral Joint with Drainage Device, Open Approach */
"0R940ZZ" = "1" /* Drainage of Cervicothoracic Vertebral Joint, Open Approach */
"0R9500Z" = "1" /* Drainage of Cervicothoracic Vertebral Disc with Drainage Device, Open Approach */
"0R950ZZ" = "1" /* Drainage of Cervicothoracic Vertebral Disc, Open Approach */
"0R9600Z" = "1" /* Drainage of Thoracic Vertebral Joint with Drainage Device, Open Approach */
"0R960ZZ" = "1" /* Drainage of Thoracic Vertebral Joint, Open Approach */
"0R9900Z" = "1" /* Drainage of Thoracic Vertebral Disc with Drainage Device, Open Approach */
"0R990ZZ" = "1" /* Drainage of Thoracic Vertebral Disc, Open Approach */
"0R9A00Z" = "1" /* Drainage of Thoracolumbar Vertebral Joint with Drainage Device, Open Approach */
"0R9A0ZZ" = "1" /* Drainage of Thoracolumbar Vertebral Joint, Open Approach */
"0R9B00Z" = "1" /* Drainage of Thoracolumbar Vertebral Disc with Drainage Device, Open Approach */
"0R9B0ZZ" = "1" /* Drainage of Thoracolumbar Vertebral Disc, Open Approach */
"0R9C00Z" = "1" /* Drainage of Right Temporomandibular Joint with Drainage Device, Open Approach */
"0R9C0ZX" = "1" /* Drainage of Right Temporomandibular Joint, Open Approach, Diagnostic */
"0R9C0ZZ" = "1" /* Drainage of Right Temporomandibular Joint, Open Approach */
"0R9C40Z" = "1" /* Drainage of Right Temporomandibular Joint with Drainage Device, Percutaneous Endoscopic Approach */
"0R9C4ZX" = "1" /* Drainage of Right Temporomandibular Joint, Percutaneous Endoscopic Approach, Diagnostic */
"0R9C4ZZ" = "1" /* Drainage of Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0R9D00Z" = "1" /* Drainage of Left Temporomandibular Joint with Drainage Device, Open Approach */
"0R9D0ZX" = "1" /* Drainage of Left Temporomandibular Joint, Open Approach, Diagnostic */
"0R9D0ZZ" = "1" /* Drainage of Left Temporomandibular Joint, Open Approach */
"0R9D40Z" = "1" /* Drainage of Left Temporomandibular Joint with Drainage Device, Percutaneous Endoscopic Approach */
"0R9D4ZX" = "1" /* Drainage of Left Temporomandibular Joint, Percutaneous Endoscopic Approach, Diagnostic */
"0R9D4ZZ" = "1" /* Drainage of Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0R9E00Z" = "1" /* Drainage of Right Sternoclavicular Joint with Drainage Device, Open Approach */
"0R9E0ZZ" = "1" /* Drainage of Right Sternoclavicular Joint, Open Approach */
"0R9F00Z" = "1" /* Drainage of Left Sternoclavicular Joint with Drainage Device, Open Approach */
"0R9F0ZZ" = "1" /* Drainage of Left Sternoclavicular Joint, Open Approach */
"0R9G00Z" = "1" /* Drainage of Right Acromioclavicular Joint with Drainage Device, Open Approach */
"0R9G0ZZ" = "1" /* Drainage of Right Acromioclavicular Joint, Open Approach */
"0R9H00Z" = "1" /* Drainage of Left Acromioclavicular Joint with Drainage Device, Open Approach */
"0R9H0ZZ" = "1" /* Drainage of Left Acromioclavicular Joint, Open Approach */
"0R9J00Z" = "1" /* Drainage of Right Shoulder Joint with Drainage Device, Open Approach */
"0R9J0ZZ" = "1" /* Drainage of Right Shoulder Joint, Open Approach */
"0R9K00Z" = "1" /* Drainage of Left Shoulder Joint with Drainage Device, Open Approach */
"0R9K0ZZ" = "1" /* Drainage of Left Shoulder Joint, Open Approach */
"0R9L00Z" = "1" /* Drainage of Right Elbow Joint with Drainage Device, Open Approach */
"0R9L0ZZ" = "1" /* Drainage of Right Elbow Joint, Open Approach */
"0R9M00Z" = "1" /* Drainage of Left Elbow Joint with Drainage Device, Open Approach */
"0R9M0ZZ" = "1" /* Drainage of Left Elbow Joint, Open Approach */
"0R9N00Z" = "1" /* Drainage of Right Wrist Joint with Drainage Device, Open Approach */
"0R9N0ZZ" = "1" /* Drainage of Right Wrist Joint, Open Approach */
"0R9P00Z" = "1" /* Drainage of Left Wrist Joint with Drainage Device, Open Approach */
"0R9P0ZZ" = "1" /* Drainage of Left Wrist Joint, Open Approach */
"0R9Q00Z" = "1" /* Drainage of Right Carpal Joint with Drainage Device, Open Approach */
"0R9Q0ZZ" = "1" /* Drainage of Right Carpal Joint, Open Approach */
"0R9R00Z" = "1" /* Drainage of Left Carpal Joint with Drainage Device, Open Approach */
"0R9R0ZZ" = "1" /* Drainage of Left Carpal Joint, Open Approach */
"0R9S00Z" = "1" /* Drainage of Right Metacarpocarpal Joint with Drainage Device, Open Approach */
"0R9S0ZZ" = "1" /* Drainage of Right Metacarpocarpal Joint, Open Approach */
"0R9T00Z" = "1" /* Drainage of Left Metacarpocarpal Joint with Drainage Device, Open Approach */
"0R9T0ZZ" = "1" /* Drainage of Left Metacarpocarpal Joint, Open Approach */
"0R9U00Z" = "1" /* Drainage of Right Metacarpophalangeal Joint with Drainage Device, Open Approach */
"0R9U0ZZ" = "1" /* Drainage of Right Metacarpophalangeal Joint, Open Approach */
"0R9V00Z" = "1" /* Drainage of Left Metacarpophalangeal Joint with Drainage Device, Open Approach */
"0R9V0ZZ" = "1" /* Drainage of Left Metacarpophalangeal Joint, Open Approach */
"0R9W00Z" = "1" /* Drainage of Right Finger Phalangeal Joint with Drainage Device, Open Approach */
"0R9W0ZZ" = "1" /* Drainage of Right Finger Phalangeal Joint, Open Approach */
"0R9X00Z" = "1" /* Drainage of Left Finger Phalangeal Joint with Drainage Device, Open Approach */
"0R9X0ZZ" = "1" /* Drainage of Left Finger Phalangeal Joint, Open Approach */
"0RB00ZZ" = "1" /* Excision of Occipital-cervical Joint, Open Approach */
"0RB03ZZ" = "1" /* Excision of Occipital-cervical Joint, Percutaneous Approach */
"0RB04ZZ" = "1" /* Excision of Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RB10ZZ" = "1" /* Excision of Cervical Vertebral Joint, Open Approach */
"0RB13ZZ" = "1" /* Excision of Cervical Vertebral Joint, Percutaneous Approach */
"0RB14ZZ" = "1" /* Excision of Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RB30ZZ" = "1" /* Excision of Cervical Vertebral Disc, Open Approach */
"0RB33ZZ" = "1" /* Excision of Cervical Vertebral Disc, Percutaneous Approach */
"0RB34ZZ" = "1" /* Excision of Cervical Vertebral Disc, Percutaneous Endoscopic Approach */
"0RB40ZZ" = "1" /* Excision of Cervicothoracic Vertebral Joint, Open Approach */
"0RB43ZZ" = "1" /* Excision of Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RB44ZZ" = "1" /* Excision of Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RB50ZZ" = "1" /* Excision of Cervicothoracic Vertebral Disc, Open Approach */
"0RB53ZZ" = "1" /* Excision of Cervicothoracic Vertebral Disc, Percutaneous Approach */
"0RB54ZZ" = "1" /* Excision of Cervicothoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RB60ZZ" = "1" /* Excision of Thoracic Vertebral Joint, Open Approach */
"0RB63ZZ" = "1" /* Excision of Thoracic Vertebral Joint, Percutaneous Approach */
"0RB64ZZ" = "1" /* Excision of Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RB90ZZ" = "1" /* Excision of Thoracic Vertebral Disc, Open Approach */
"0RB93ZZ" = "1" /* Excision of Thoracic Vertebral Disc, Percutaneous Approach */
"0RB94ZZ" = "1" /* Excision of Thoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RBA0ZZ" = "1" /* Excision of Thoracolumbar Vertebral Joint, Open Approach */
"0RBA3ZZ" = "1" /* Excision of Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RBA4ZZ" = "1" /* Excision of Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RBB0ZZ" = "1" /* Excision of Thoracolumbar Vertebral Disc, Open Approach */
"0RBB3ZZ" = "1" /* Excision of Thoracolumbar Vertebral Disc, Percutaneous Approach */
"0RBB4ZZ" = "1" /* Excision of Thoracolumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0RBC0ZX" = "1" /* Excision of Right Temporomandibular Joint, Open Approach, Diagnostic */
"0RBC0ZZ" = "1" /* Excision of Right Temporomandibular Joint, Open Approach */
"0RBC3ZX" = "1" /* Excision of Right Temporomandibular Joint, Percutaneous Approach, Diagnostic */
"0RBC3ZZ" = "1" /* Excision of Right Temporomandibular Joint, Percutaneous Approach */
"0RBC4ZX" = "1" /* Excision of Right Temporomandibular Joint, Percutaneous Endoscopic Approach, Diagnostic */
"0RBC4ZZ" = "1" /* Excision of Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RBD0ZX" = "1" /* Excision of Left Temporomandibular Joint, Open Approach, Diagnostic */
"0RBD0ZZ" = "1" /* Excision of Left Temporomandibular Joint, Open Approach */
"0RBD3ZX" = "1" /* Excision of Left Temporomandibular Joint, Percutaneous Approach, Diagnostic */
"0RBD3ZZ" = "1" /* Excision of Left Temporomandibular Joint, Percutaneous Approach */
"0RBD4ZX" = "1" /* Excision of Left Temporomandibular Joint, Percutaneous Endoscopic Approach, Diagnostic */
"0RBD4ZZ" = "1" /* Excision of Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RBE0ZZ" = "1" /* Excision of Right Sternoclavicular Joint, Open Approach */
"0RBE3ZZ" = "1" /* Excision of Right Sternoclavicular Joint, Percutaneous Approach */
"0RBE4ZZ" = "1" /* Excision of Right Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RBF0ZZ" = "1" /* Excision of Left Sternoclavicular Joint, Open Approach */
"0RBF3ZZ" = "1" /* Excision of Left Sternoclavicular Joint, Percutaneous Approach */
"0RBF4ZZ" = "1" /* Excision of Left Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RBG0ZZ" = "1" /* Excision of Right Acromioclavicular Joint, Open Approach */
"0RBG3ZZ" = "1" /* Excision of Right Acromioclavicular Joint, Percutaneous Approach */
"0RBG4ZZ" = "1" /* Excision of Right Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RBH0ZZ" = "1" /* Excision of Left Acromioclavicular Joint, Open Approach */
"0RBH3ZZ" = "1" /* Excision of Left Acromioclavicular Joint, Percutaneous Approach */
"0RBH4ZZ" = "1" /* Excision of Left Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RBJ0ZZ" = "1" /* Excision of Right Shoulder Joint, Open Approach */
"0RBJ3ZZ" = "1" /* Excision of Right Shoulder Joint, Percutaneous Approach */
"0RBJ4ZZ" = "1" /* Excision of Right Shoulder Joint, Percutaneous Endoscopic Approach */
"0RBK0ZZ" = "1" /* Excision of Left Shoulder Joint, Open Approach */
"0RBK3ZZ" = "1" /* Excision of Left Shoulder Joint, Percutaneous Approach */
"0RBK4ZZ" = "1" /* Excision of Left Shoulder Joint, Percutaneous Endoscopic Approach */
"0RBL0ZZ" = "1" /* Excision of Right Elbow Joint, Open Approach */
"0RBL3ZZ" = "1" /* Excision of Right Elbow Joint, Percutaneous Approach */
"0RBL4ZZ" = "1" /* Excision of Right Elbow Joint, Percutaneous Endoscopic Approach */
"0RBM0ZZ" = "1" /* Excision of Left Elbow Joint, Open Approach */
"0RBM3ZZ" = "1" /* Excision of Left Elbow Joint, Percutaneous Approach */
"0RBM4ZZ" = "1" /* Excision of Left Elbow Joint, Percutaneous Endoscopic Approach */
"0RBN0ZZ" = "1" /* Excision of Right Wrist Joint, Open Approach */
"0RBN3ZZ" = "1" /* Excision of Right Wrist Joint, Percutaneous Approach */
"0RBN4ZZ" = "1" /* Excision of Right Wrist Joint, Percutaneous Endoscopic Approach */
"0RBP0ZZ" = "1" /* Excision of Left Wrist Joint, Open Approach */
"0RBP3ZZ" = "1" /* Excision of Left Wrist Joint, Percutaneous Approach */
"0RBP4ZZ" = "1" /* Excision of Left Wrist Joint, Percutaneous Endoscopic Approach */
"0RBQ0ZZ" = "1" /* Excision of Right Carpal Joint, Open Approach */
"0RBQ3ZZ" = "1" /* Excision of Right Carpal Joint, Percutaneous Approach */
"0RBQ4ZZ" = "1" /* Excision of Right Carpal Joint, Percutaneous Endoscopic Approach */
"0RBR0ZZ" = "1" /* Excision of Left Carpal Joint, Open Approach */
"0RBR3ZZ" = "1" /* Excision of Left Carpal Joint, Percutaneous Approach */
"0RBR4ZZ" = "1" /* Excision of Left Carpal Joint, Percutaneous Endoscopic Approach */
"0RBS0ZZ" = "1" /* Excision of Right Metacarpocarpal Joint, Open Approach */
"0RBS3ZZ" = "1" /* Excision of Right Metacarpocarpal Joint, Percutaneous Approach */
"0RBS4ZZ" = "1" /* Excision of Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RBT0ZZ" = "1" /* Excision of Left Metacarpocarpal Joint, Open Approach */
"0RBT3ZZ" = "1" /* Excision of Left Metacarpocarpal Joint, Percutaneous Approach */
"0RBT4ZZ" = "1" /* Excision of Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RBU0ZZ" = "1" /* Excision of Right Metacarpophalangeal Joint, Open Approach */
"0RBU3ZZ" = "1" /* Excision of Right Metacarpophalangeal Joint, Percutaneous Approach */
"0RBU4ZZ" = "1" /* Excision of Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RBV0ZZ" = "1" /* Excision of Left Metacarpophalangeal Joint, Open Approach */
"0RBV3ZZ" = "1" /* Excision of Left Metacarpophalangeal Joint, Percutaneous Approach */
"0RBV4ZZ" = "1" /* Excision of Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RBW0ZZ" = "1" /* Excision of Right Finger Phalangeal Joint, Open Approach */
"0RBW3ZZ" = "1" /* Excision of Right Finger Phalangeal Joint, Percutaneous Approach */
"0RBW4ZZ" = "1" /* Excision of Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RBX0ZZ" = "1" /* Excision of Left Finger Phalangeal Joint, Open Approach */
"0RBX3ZZ" = "1" /* Excision of Left Finger Phalangeal Joint, Percutaneous Approach */
"0RBX4ZZ" = "1" /* Excision of Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RC00ZZ" = "1" /* Extirpation of Matter from Occipital-cervical Joint, Open Approach */
"0RC03ZZ" = "1" /* Extirpation of Matter from Occipital-cervical Joint, Percutaneous Approach */
"0RC04ZZ" = "1" /* Extirpation of Matter from Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RC10ZZ" = "1" /* Extirpation of Matter from Cervical Vertebral Joint, Open Approach */
"0RC13ZZ" = "1" /* Extirpation of Matter from Cervical Vertebral Joint, Percutaneous Approach */
"0RC14ZZ" = "1" /* Extirpation of Matter from Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RC30ZZ" = "1" /* Extirpation of Matter from Cervical Vertebral Disc, Open Approach */
"0RC33ZZ" = "1" /* Extirpation of Matter from Cervical Vertebral Disc, Percutaneous Approach */
"0RC34ZZ" = "1" /* Extirpation of Matter from Cervical Vertebral Disc, Percutaneous Endoscopic Approach */
"0RC40ZZ" = "1" /* Extirpation of Matter from Cervicothoracic Vertebral Joint, Open Approach */
"0RC43ZZ" = "1" /* Extirpation of Matter from Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RC44ZZ" = "1" /* Extirpation of Matter from Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RC50ZZ" = "1" /* Extirpation of Matter from Cervicothoracic Vertebral Disc, Open Approach */
"0RC53ZZ" = "1" /* Extirpation of Matter from Cervicothoracic Vertebral Disc, Percutaneous Approach */
"0RC54ZZ" = "1" /* Extirpation of Matter from Cervicothoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RC60ZZ" = "1" /* Extirpation of Matter from Thoracic Vertebral Joint, Open Approach */
"0RC63ZZ" = "1" /* Extirpation of Matter from Thoracic Vertebral Joint, Percutaneous Approach */
"0RC64ZZ" = "1" /* Extirpation of Matter from Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RC90ZZ" = "1" /* Extirpation of Matter from Thoracic Vertebral Disc, Open Approach */
"0RC93ZZ" = "1" /* Extirpation of Matter from Thoracic Vertebral Disc, Percutaneous Approach */
"0RC94ZZ" = "1" /* Extirpation of Matter from Thoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RCA0ZZ" = "1" /* Extirpation of Matter from Thoracolumbar Vertebral Joint, Open Approach */
"0RCA3ZZ" = "1" /* Extirpation of Matter from Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RCA4ZZ" = "1" /* Extirpation of Matter from Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RCB0ZZ" = "1" /* Extirpation of Matter from Thoracolumbar Vertebral Disc, Open Approach */
"0RCB3ZZ" = "1" /* Extirpation of Matter from Thoracolumbar Vertebral Disc, Percutaneous Approach */
"0RCB4ZZ" = "1" /* Extirpation of Matter from Thoracolumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0RCC0ZZ" = "1" /* Extirpation of Matter from Right Temporomandibular Joint, Open Approach */
"0RCC3ZZ" = "1" /* Extirpation of Matter from Right Temporomandibular Joint, Percutaneous Approach */
"0RCC4ZZ" = "1" /* Extirpation of Matter from Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RCD0ZZ" = "1" /* Extirpation of Matter from Left Temporomandibular Joint, Open Approach */
"0RCD3ZZ" = "1" /* Extirpation of Matter from Left Temporomandibular Joint, Percutaneous Approach */
"0RCD4ZZ" = "1" /* Extirpation of Matter from Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RCE0ZZ" = "1" /* Extirpation of Matter from Right Sternoclavicular Joint, Open Approach */
"0RCE3ZZ" = "1" /* Extirpation of Matter from Right Sternoclavicular Joint, Percutaneous Approach */
"0RCE4ZZ" = "1" /* Extirpation of Matter from Right Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RCF0ZZ" = "1" /* Extirpation of Matter from Left Sternoclavicular Joint, Open Approach */
"0RCF3ZZ" = "1" /* Extirpation of Matter from Left Sternoclavicular Joint, Percutaneous Approach */
"0RCF4ZZ" = "1" /* Extirpation of Matter from Left Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RCG0ZZ" = "1" /* Extirpation of Matter from Right Acromioclavicular Joint, Open Approach */
"0RCG3ZZ" = "1" /* Extirpation of Matter from Right Acromioclavicular Joint, Percutaneous Approach */
"0RCG4ZZ" = "1" /* Extirpation of Matter from Right Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RCH0ZZ" = "1" /* Extirpation of Matter from Left Acromioclavicular Joint, Open Approach */
"0RCH3ZZ" = "1" /* Extirpation of Matter from Left Acromioclavicular Joint, Percutaneous Approach */
"0RCH4ZZ" = "1" /* Extirpation of Matter from Left Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RCJ0ZZ" = "1" /* Extirpation of Matter from Right Shoulder Joint, Open Approach */
"0RCJ3ZZ" = "1" /* Extirpation of Matter from Right Shoulder Joint, Percutaneous Approach */
"0RCJ4ZZ" = "1" /* Extirpation of Matter from Right Shoulder Joint, Percutaneous Endoscopic Approach */
"0RCK0ZZ" = "1" /* Extirpation of Matter from Left Shoulder Joint, Open Approach */
"0RCK3ZZ" = "1" /* Extirpation of Matter from Left Shoulder Joint, Percutaneous Approach */
"0RCK4ZZ" = "1" /* Extirpation of Matter from Left Shoulder Joint, Percutaneous Endoscopic Approach */
"0RCL0ZZ" = "1" /* Extirpation of Matter from Right Elbow Joint, Open Approach */
"0RCL3ZZ" = "1" /* Extirpation of Matter from Right Elbow Joint, Percutaneous Approach */
"0RCL4ZZ" = "1" /* Extirpation of Matter from Right Elbow Joint, Percutaneous Endoscopic Approach */
"0RCM0ZZ" = "1" /* Extirpation of Matter from Left Elbow Joint, Open Approach */
"0RCM3ZZ" = "1" /* Extirpation of Matter from Left Elbow Joint, Percutaneous Approach */
"0RCM4ZZ" = "1" /* Extirpation of Matter from Left Elbow Joint, Percutaneous Endoscopic Approach */
"0RCN0ZZ" = "1" /* Extirpation of Matter from Right Wrist Joint, Open Approach */
"0RCN3ZZ" = "1" /* Extirpation of Matter from Right Wrist Joint, Percutaneous Approach */
"0RCN4ZZ" = "1" /* Extirpation of Matter from Right Wrist Joint, Percutaneous Endoscopic Approach */
"0RCP0ZZ" = "1" /* Extirpation of Matter from Left Wrist Joint, Open Approach */
"0RCP3ZZ" = "1" /* Extirpation of Matter from Left Wrist Joint, Percutaneous Approach */
"0RCP4ZZ" = "1" /* Extirpation of Matter from Left Wrist Joint, Percutaneous Endoscopic Approach */
"0RCQ0ZZ" = "1" /* Extirpation of Matter from Right Carpal Joint, Open Approach */
"0RCQ3ZZ" = "1" /* Extirpation of Matter from Right Carpal Joint, Percutaneous Approach */
"0RCQ4ZZ" = "1" /* Extirpation of Matter from Right Carpal Joint, Percutaneous Endoscopic Approach */
"0RCR0ZZ" = "1" /* Extirpation of Matter from Left Carpal Joint, Open Approach */
"0RCR3ZZ" = "1" /* Extirpation of Matter from Left Carpal Joint, Percutaneous Approach */
"0RCR4ZZ" = "1" /* Extirpation of Matter from Left Carpal Joint, Percutaneous Endoscopic Approach */
"0RCS0ZZ" = "1" /* Extirpation of Matter from Right Metacarpocarpal Joint, Open Approach */
"0RCS3ZZ" = "1" /* Extirpation of Matter from Right Metacarpocarpal Joint, Percutaneous Approach */
"0RCS4ZZ" = "1" /* Extirpation of Matter from Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RCT0ZZ" = "1" /* Extirpation of Matter from Left Metacarpocarpal Joint, Open Approach */
"0RCT3ZZ" = "1" /* Extirpation of Matter from Left Metacarpocarpal Joint, Percutaneous Approach */
"0RCT4ZZ" = "1" /* Extirpation of Matter from Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RCU0ZZ" = "1" /* Extirpation of Matter from Right Metacarpophalangeal Joint, Open Approach */
"0RCU3ZZ" = "1" /* Extirpation of Matter from Right Metacarpophalangeal Joint, Percutaneous Approach */
"0RCU4ZZ" = "1" /* Extirpation of Matter from Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RCV0ZZ" = "1" /* Extirpation of Matter from Left Metacarpophalangeal Joint, Open Approach */
"0RCV3ZZ" = "1" /* Extirpation of Matter from Left Metacarpophalangeal Joint, Percutaneous Approach */
"0RCV4ZZ" = "1" /* Extirpation of Matter from Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RCW0ZZ" = "1" /* Extirpation of Matter from Right Finger Phalangeal Joint, Open Approach */
"0RCW3ZZ" = "1" /* Extirpation of Matter from Right Finger Phalangeal Joint, Percutaneous Approach */
"0RCW4ZZ" = "1" /* Extirpation of Matter from Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RCX0ZZ" = "1" /* Extirpation of Matter from Left Finger Phalangeal Joint, Open Approach */
"0RCX3ZZ" = "1" /* Extirpation of Matter from Left Finger Phalangeal Joint, Percutaneous Approach */
"0RCX4ZZ" = "1" /* Extirpation of Matter from Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RG0070" = "1" /* Fusion of Occipital-cervical Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG0071" = "1" /* Fusion of Occipital-cervical Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG007J" = "1" /* Fusion of Occipital-cervical Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG00A0" = "1" /* Fusion of Occipital-cervical Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0RG00A1" = "1" /* Fusion of Occipital-cervical Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Open Approach */
"0RG00AJ" = "1" /* Fusion of Occipital-cervical Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Open Approach */
"0RG00J0" = "1" /* Fusion of Occipital-cervical Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG00J1" = "1" /* Fusion of Occipital-cervical Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG00JJ" = "1" /* Fusion of Occipital-cervical Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG00K0" = "1" /* Fusion of Occipital-cervical Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG00K1" = "1" /* Fusion of Occipital-cervical Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG00KJ" = "1" /* Fusion of Occipital-cervical Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG00Z0" = "1" /* Fusion of Occipital-cervical Joint, Anterior Approach, Anterior Column, Open Approach */
"0RG00Z1" = "1" /* Fusion of Occipital-cervical Joint, Posterior Approach, Posterior Column, Open Approach */
"0RG00ZJ" = "1" /* Fusion of Occipital-cervical Joint, Posterior Approach, Anterior Column, Open Approach */
"0RG0370" = "1" /* Fusion of Occipital-cervical Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG0371" = "1" /* Fusion of Occipital-cervical Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG037J" = "1" /* Fusion of Occipital-cervical Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG03A0" = "1" /* Fusion of Occipital-cervical Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG03A1" = "1" /* Fusion of Occipital-cervical Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG03AJ" = "1" /* Fusion of Occipital-cervical Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG03J0" = "1" /* Fusion of Occipital-cervical Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG03J1" = "1" /* Fusion of Occipital-cervical Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG03JJ" = "1" /* Fusion of Occipital-cervical Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG03K0" = "1" /* Fusion of Occipital-cervical Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG03K1" = "1" /* Fusion of Occipital-cervical Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG03KJ" = "1" /* Fusion of Occipital-cervical Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG03Z0" = "1" /* Fusion of Occipital-cervical Joint, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG03Z1" = "1" /* Fusion of Occipital-cervical Joint, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG03ZJ" = "1" /* Fusion of Occipital-cervical Joint, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG0470" = "1" /* Fusion of Occipital-cervical Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG0471" = "1" /* Fusion of Occipital-cervical Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG047J" = "1" /* Fusion of Occipital-cervical Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG04A0" = "1" /* Fusion of Occipital-cervical Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG04A1" = "1" /* Fusion of Occipital-cervical Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG04AJ" = "1" /* Fusion of Occipital-cervical Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG04J0" = "1" /* Fusion of Occipital-cervical Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG04J1" = "1" /* Fusion of Occipital-cervical Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG04JJ" = "1" /* Fusion of Occipital-cervical Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG04K0" = "1" /* Fusion of Occipital-cervical Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG04K1" = "1" /* Fusion of Occipital-cervical Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG04KJ" = "1" /* Fusion of Occipital-cervical Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG04Z0" = "1" /* Fusion of Occipital-cervical Joint, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG04Z1" = "1" /* Fusion of Occipital-cervical Joint, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG04ZJ" = "1" /* Fusion of Occipital-cervical Joint, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG1070" = "1" /* Fusion of Cervical Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG1071" = "1" /* Fusion of Cervical Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG107J" = "1" /* Fusion of Cervical Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG10A0" = "1" /* Fusion of Cervical Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0RG10A1" = "1" /* Fusion of Cervical Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Open Approach */
"0RG10AJ" = "1" /* Fusion of Cervical Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Open Approach */
"0RG10J0" = "1" /* Fusion of Cervical Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG10J1" = "1" /* Fusion of Cervical Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG10JJ" = "1" /* Fusion of Cervical Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG10K0" = "1" /* Fusion of Cervical Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG10K1" = "1" /* Fusion of Cervical Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG10KJ" = "1" /* Fusion of Cervical Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG10Z0" = "1" /* Fusion of Cervical Vertebral Joint, Anterior Approach, Anterior Column, Open Approach */
"0RG10Z1" = "1" /* Fusion of Cervical Vertebral Joint, Posterior Approach, Posterior Column, Open Approach */
"0RG10ZJ" = "1" /* Fusion of Cervical Vertebral Joint, Posterior Approach, Anterior Column, Open Approach */
"0RG1370" = "1" /* Fusion of Cervical Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG1371" = "1" /* Fusion of Cervical Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG137J" = "1" /* Fusion of Cervical Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG13A0" = "1" /* Fusion of Cervical Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG13A1" = "1" /* Fusion of Cervical Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG13AJ" = "1" /* Fusion of Cervical Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG13J0" = "1" /* Fusion of Cervical Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG13J1" = "1" /* Fusion of Cervical Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG13JJ" = "1" /* Fusion of Cervical Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG13K0" = "1" /* Fusion of Cervical Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG13K1" = "1" /* Fusion of Cervical Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG13KJ" = "1" /* Fusion of Cervical Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG13Z0" = "1" /* Fusion of Cervical Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG13Z1" = "1" /* Fusion of Cervical Vertebral Joint, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG13ZJ" = "1" /* Fusion of Cervical Vertebral Joint, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG1470" = "1" /* Fusion of Cervical Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG1471" = "1" /* Fusion of Cervical Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG147J" = "1" /* Fusion of Cervical Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG14A0" = "1" /* Fusion of Cervical Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG14A1" = "1" /* Fusion of Cervical Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG14AJ" = "1" /* Fusion of Cervical Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG14J0" = "1" /* Fusion of Cervical Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG14J1" = "1" /* Fusion of Cervical Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG14JJ" = "1" /* Fusion of Cervical Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG14K0" = "1" /* Fusion of Cervical Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG14K1" = "1" /* Fusion of Cervical Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG14KJ" = "1" /* Fusion of Cervical Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG14Z0" = "1" /* Fusion of Cervical Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG14Z1" = "1" /* Fusion of Cervical Vertebral Joint, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG14ZJ" = "1" /* Fusion of Cervical Vertebral Joint, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG2070" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG2071" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG207J" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG20A0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0RG20A1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Open Approach */
"0RG20AJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Open Approach */
"0RG20J0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG20J1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG20JJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG20K0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG20K1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG20KJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG20Z0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints, Anterior Approach, Anterior Column, Open Approach */
"0RG20Z1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints, Posterior Approach, Posterior Column, Open Approach */
"0RG20ZJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints, Posterior Approach, Anterior Column, Open Approach */
"0RG2370" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG2371" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG237J" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG23A0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG23A1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG23AJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG23J0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG23J1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG23JJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG23K0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG23K1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG23KJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG23Z0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG23Z1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG23ZJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG2470" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG2471" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG247J" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG24A0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG24A1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG24AJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG24J0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG24J1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG24JJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG24K0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG24K1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG24KJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG24Z0" = "1" /* Fusion of 2 or more Cervical Vertebral Joints, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG24Z1" = "1" /* Fusion of 2 or more Cervical Vertebral Joints, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG24ZJ" = "1" /* Fusion of 2 or more Cervical Vertebral Joints, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG4070" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG4071" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG407J" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG40A0" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0RG40A1" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Open Approach */
"0RG40AJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Open Approach */
"0RG40J0" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG40J1" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG40JJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG40K0" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG40K1" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG40KJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG40Z0" = "1" /* Fusion of Cervicothoracic Vertebral Joint, Anterior Approach, Anterior Column, Open Approach */
"0RG40Z1" = "1" /* Fusion of Cervicothoracic Vertebral Joint, Posterior Approach, Posterior Column, Open Approach */
"0RG40ZJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint, Posterior Approach, Anterior Column, Open Approach */
"0RG4370" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG4371" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG437J" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG43A0" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG43A1" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG43AJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG43J0" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG43J1" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG43JJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG43K0" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG43K1" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG43KJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG43Z0" = "1" /* Fusion of Cervicothoracic Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG43Z1" = "1" /* Fusion of Cervicothoracic Vertebral Joint, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG43ZJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG4470" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG4471" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG447J" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG44A0" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG44A1" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG44AJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG44J0" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG44J1" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG44JJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG44K0" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG44K1" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG44KJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG44Z0" = "1" /* Fusion of Cervicothoracic Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG44Z1" = "1" /* Fusion of Cervicothoracic Vertebral Joint, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG44ZJ" = "1" /* Fusion of Cervicothoracic Vertebral Joint, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG6070" = "1" /* Fusion of Thoracic Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG6071" = "1" /* Fusion of Thoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG607J" = "1" /* Fusion of Thoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG60A0" = "1" /* Fusion of Thoracic Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0RG60A1" = "1" /* Fusion of Thoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Open Approach */
"0RG60AJ" = "1" /* Fusion of Thoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Open Approach */
"0RG60J0" = "1" /* Fusion of Thoracic Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG60J1" = "1" /* Fusion of Thoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG60JJ" = "1" /* Fusion of Thoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG60K0" = "1" /* Fusion of Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG60K1" = "1" /* Fusion of Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG60KJ" = "1" /* Fusion of Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG60Z0" = "1" /* Fusion of Thoracic Vertebral Joint, Anterior Approach, Anterior Column, Open Approach */
"0RG60Z1" = "1" /* Fusion of Thoracic Vertebral Joint, Posterior Approach, Posterior Column, Open Approach */
"0RG60ZJ" = "1" /* Fusion of Thoracic Vertebral Joint, Posterior Approach, Anterior Column, Open Approach */
"0RG6370" = "1" /* Fusion of Thoracic Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG6371" = "1" /* Fusion of Thoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG637J" = "1" /* Fusion of Thoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG63A0" = "1" /* Fusion of Thoracic Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG63A1" = "1" /* Fusion of Thoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG63AJ" = "1" /* Fusion of Thoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG63J0" = "1" /* Fusion of Thoracic Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG63J1" = "1" /* Fusion of Thoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG63JJ" = "1" /* Fusion of Thoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG63K0" = "1" /* Fusion of Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG63K1" = "1" /* Fusion of Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG63KJ" = "1" /* Fusion of Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG63Z0" = "1" /* Fusion of Thoracic Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG63Z1" = "1" /* Fusion of Thoracic Vertebral Joint, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG63ZJ" = "1" /* Fusion of Thoracic Vertebral Joint, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG6470" = "1" /* Fusion of Thoracic Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG6471" = "1" /* Fusion of Thoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG647J" = "1" /* Fusion of Thoracic Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG64A0" = "1" /* Fusion of Thoracic Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG64A1" = "1" /* Fusion of Thoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG64AJ" = "1" /* Fusion of Thoracic Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG64J0" = "1" /* Fusion of Thoracic Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG64J1" = "1" /* Fusion of Thoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG64JJ" = "1" /* Fusion of Thoracic Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG64K0" = "1" /* Fusion of Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG64K1" = "1" /* Fusion of Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG64KJ" = "1" /* Fusion of Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG64Z0" = "1" /* Fusion of Thoracic Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG64Z1" = "1" /* Fusion of Thoracic Vertebral Joint, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG64ZJ" = "1" /* Fusion of Thoracic Vertebral Joint, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG7070" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG7071" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG707J" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG70A0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0RG70A1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Open Approach */
"0RG70AJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Open Approach */
"0RG70J0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG70J1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG70JJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG70K0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG70K1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG70KJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG70Z0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints, Anterior Approach, Anterior Column, Open Approach */
"0RG70Z1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints, Posterior Approach, Posterior Column, Open Approach */
"0RG70ZJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints, Posterior Approach, Anterior Column, Open Approach */
"0RG7370" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG7371" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG737J" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG73A0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG73A1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG73AJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG73J0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG73J1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG73JJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG73K0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG73K1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG73KJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG73Z0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG73Z1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG73ZJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG7470" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG7471" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG747J" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG74A0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG74A1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG74AJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG74J0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG74J1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG74JJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG74K0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG74K1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG74KJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG74Z0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG74Z1" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG74ZJ" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG8070" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG8071" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG807J" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG80A0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0RG80A1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Open Approach */
"0RG80AJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Open Approach */
"0RG80J0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG80J1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG80JJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG80K0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG80K1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RG80KJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RG80Z0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints, Anterior Approach, Anterior Column, Open Approach */
"0RG80Z1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints, Posterior Approach, Posterior Column, Open Approach */
"0RG80ZJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints, Posterior Approach, Anterior Column, Open Approach */
"0RG8370" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG8371" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG837J" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG83A0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG83A1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG83AJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG83J0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG83J1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG83JJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG83K0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG83K1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG83KJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG83Z0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG83Z1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RG83ZJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RG8470" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG8471" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG847J" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG84A0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG84A1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG84AJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG84J0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG84J1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG84JJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG84K0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG84K1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG84KJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG84Z0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG84Z1" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RG84ZJ" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA070" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RGA071" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RGA07J" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RGA0A0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0RGA0A1" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Open Approach */
"0RGA0AJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Open Approach */
"0RGA0J0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RGA0J1" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RGA0JJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RGA0K0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RGA0K1" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0RGA0KJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0RGA0Z0" = "1" /* Fusion of Thoracolumbar Vertebral Joint, Anterior Approach, Anterior Column, Open Approach */
"0RGA0Z1" = "1" /* Fusion of Thoracolumbar Vertebral Joint, Posterior Approach, Posterior Column, Open Approach */
"0RGA0ZJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint, Posterior Approach, Anterior Column, Open Approach */
"0RGA370" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RGA371" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RGA37J" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RGA3A0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RGA3A1" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RGA3AJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RGA3J0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RGA3J1" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RGA3JJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RGA3K0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RGA3K1" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RGA3KJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RGA3Z0" = "1" /* Fusion of Thoracolumbar Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RGA3Z1" = "1" /* Fusion of Thoracolumbar Vertebral Joint, Posterior Approach, Posterior Column, Percutaneous Approach */
"0RGA3ZJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint, Posterior Approach, Anterior Column, Percutaneous Approach */
"0RGA470" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA471" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RGA47J" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA4A0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA4A1" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RGA4AJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA4J0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA4J1" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RGA4JJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA4K0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA4K1" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RGA4KJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA4Z0" = "1" /* Fusion of Thoracolumbar Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA4Z1" = "1" /* Fusion of Thoracolumbar Vertebral Joint, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0RGA4ZJ" = "1" /* Fusion of Thoracolumbar Vertebral Joint, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGC04Z" = "1" /* Fusion of Right Temporomandibular Joint with Internal Fixation Device, Open Approach */
"0RGC07Z" = "1" /* Fusion of Right Temporomandibular Joint with Autologous Tissue Substitute, Open Approach */
"0RGC0JZ" = "1" /* Fusion of Right Temporomandibular Joint with Synthetic Substitute, Open Approach */
"0RGC0KZ" = "1" /* Fusion of Right Temporomandibular Joint with Nonautologous Tissue Substitute, Open Approach */
"0RGC0ZZ" = "1" /* Fusion of Right Temporomandibular Joint, Open Approach */
"0RGC34Z" = "1" /* Fusion of Right Temporomandibular Joint with Internal Fixation Device, Percutaneous Approach */
"0RGC37Z" = "1" /* Fusion of Right Temporomandibular Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RGC3JZ" = "1" /* Fusion of Right Temporomandibular Joint with Synthetic Substitute, Percutaneous Approach */
"0RGC3KZ" = "1" /* Fusion of Right Temporomandibular Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RGC3ZZ" = "1" /* Fusion of Right Temporomandibular Joint, Percutaneous Approach */
"0RGC44Z" = "1" /* Fusion of Right Temporomandibular Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RGC47Z" = "1" /* Fusion of Right Temporomandibular Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGC4JZ" = "1" /* Fusion of Right Temporomandibular Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RGC4KZ" = "1" /* Fusion of Right Temporomandibular Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGC4ZZ" = "1" /* Fusion of Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RGD04Z" = "1" /* Fusion of Left Temporomandibular Joint with Internal Fixation Device, Open Approach */
"0RGD07Z" = "1" /* Fusion of Left Temporomandibular Joint with Autologous Tissue Substitute, Open Approach */
"0RGD0JZ" = "1" /* Fusion of Left Temporomandibular Joint with Synthetic Substitute, Open Approach */
"0RGD0KZ" = "1" /* Fusion of Left Temporomandibular Joint with Nonautologous Tissue Substitute, Open Approach */
"0RGD0ZZ" = "1" /* Fusion of Left Temporomandibular Joint, Open Approach */
"0RGD34Z" = "1" /* Fusion of Left Temporomandibular Joint with Internal Fixation Device, Percutaneous Approach */
"0RGD37Z" = "1" /* Fusion of Left Temporomandibular Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RGD3JZ" = "1" /* Fusion of Left Temporomandibular Joint with Synthetic Substitute, Percutaneous Approach */
"0RGD3KZ" = "1" /* Fusion of Left Temporomandibular Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RGD3ZZ" = "1" /* Fusion of Left Temporomandibular Joint, Percutaneous Approach */
"0RGD44Z" = "1" /* Fusion of Left Temporomandibular Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RGD47Z" = "1" /* Fusion of Left Temporomandibular Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGD4JZ" = "1" /* Fusion of Left Temporomandibular Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RGD4KZ" = "1" /* Fusion of Left Temporomandibular Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGD4ZZ" = "1" /* Fusion of Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RGE04Z" = "1" /* Fusion of Right Sternoclavicular Joint with Internal Fixation Device, Open Approach */
"0RGE07Z" = "1" /* Fusion of Right Sternoclavicular Joint with Autologous Tissue Substitute, Open Approach */
"0RGE0JZ" = "1" /* Fusion of Right Sternoclavicular Joint with Synthetic Substitute, Open Approach */
"0RGE0KZ" = "1" /* Fusion of Right Sternoclavicular Joint with Nonautologous Tissue Substitute, Open Approach */
"0RGE0ZZ" = "1" /* Fusion of Right Sternoclavicular Joint, Open Approach */
"0RGE34Z" = "1" /* Fusion of Right Sternoclavicular Joint with Internal Fixation Device, Percutaneous Approach */
"0RGE37Z" = "1" /* Fusion of Right Sternoclavicular Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RGE3JZ" = "1" /* Fusion of Right Sternoclavicular Joint with Synthetic Substitute, Percutaneous Approach */
"0RGE3KZ" = "1" /* Fusion of Right Sternoclavicular Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RGE3ZZ" = "1" /* Fusion of Right Sternoclavicular Joint, Percutaneous Approach */
"0RGE44Z" = "1" /* Fusion of Right Sternoclavicular Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RGE47Z" = "1" /* Fusion of Right Sternoclavicular Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGE4JZ" = "1" /* Fusion of Right Sternoclavicular Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RGE4KZ" = "1" /* Fusion of Right Sternoclavicular Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGE4ZZ" = "1" /* Fusion of Right Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RGF04Z" = "1" /* Fusion of Left Sternoclavicular Joint with Internal Fixation Device, Open Approach */
"0RGF07Z" = "1" /* Fusion of Left Sternoclavicular Joint with Autologous Tissue Substitute, Open Approach */
"0RGF0JZ" = "1" /* Fusion of Left Sternoclavicular Joint with Synthetic Substitute, Open Approach */
"0RGF0KZ" = "1" /* Fusion of Left Sternoclavicular Joint with Nonautologous Tissue Substitute, Open Approach */
"0RGF0ZZ" = "1" /* Fusion of Left Sternoclavicular Joint, Open Approach */
"0RGF34Z" = "1" /* Fusion of Left Sternoclavicular Joint with Internal Fixation Device, Percutaneous Approach */
"0RGF37Z" = "1" /* Fusion of Left Sternoclavicular Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RGF3JZ" = "1" /* Fusion of Left Sternoclavicular Joint with Synthetic Substitute, Percutaneous Approach */
"0RGF3KZ" = "1" /* Fusion of Left Sternoclavicular Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RGF3ZZ" = "1" /* Fusion of Left Sternoclavicular Joint, Percutaneous Approach */
"0RGF44Z" = "1" /* Fusion of Left Sternoclavicular Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RGF47Z" = "1" /* Fusion of Left Sternoclavicular Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGF4JZ" = "1" /* Fusion of Left Sternoclavicular Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RGF4KZ" = "1" /* Fusion of Left Sternoclavicular Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGF4ZZ" = "1" /* Fusion of Left Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RGG04Z" = "1" /* Fusion of Right Acromioclavicular Joint with Internal Fixation Device, Open Approach */
"0RGG07Z" = "1" /* Fusion of Right Acromioclavicular Joint with Autologous Tissue Substitute, Open Approach */
"0RGG0JZ" = "1" /* Fusion of Right Acromioclavicular Joint with Synthetic Substitute, Open Approach */
"0RGG0KZ" = "1" /* Fusion of Right Acromioclavicular Joint with Nonautologous Tissue Substitute, Open Approach */
"0RGG0ZZ" = "1" /* Fusion of Right Acromioclavicular Joint, Open Approach */
"0RGG34Z" = "1" /* Fusion of Right Acromioclavicular Joint with Internal Fixation Device, Percutaneous Approach */
"0RGG37Z" = "1" /* Fusion of Right Acromioclavicular Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RGG3JZ" = "1" /* Fusion of Right Acromioclavicular Joint with Synthetic Substitute, Percutaneous Approach */
"0RGG3KZ" = "1" /* Fusion of Right Acromioclavicular Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RGG3ZZ" = "1" /* Fusion of Right Acromioclavicular Joint, Percutaneous Approach */
"0RGG44Z" = "1" /* Fusion of Right Acromioclavicular Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RGG47Z" = "1" /* Fusion of Right Acromioclavicular Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGG4JZ" = "1" /* Fusion of Right Acromioclavicular Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RGG4KZ" = "1" /* Fusion of Right Acromioclavicular Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGG4ZZ" = "1" /* Fusion of Right Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RGH04Z" = "1" /* Fusion of Left Acromioclavicular Joint with Internal Fixation Device, Open Approach */
"0RGH07Z" = "1" /* Fusion of Left Acromioclavicular Joint with Autologous Tissue Substitute, Open Approach */
"0RGH0JZ" = "1" /* Fusion of Left Acromioclavicular Joint with Synthetic Substitute, Open Approach */
"0RGH0KZ" = "1" /* Fusion of Left Acromioclavicular Joint with Nonautologous Tissue Substitute, Open Approach */
"0RGH0ZZ" = "1" /* Fusion of Left Acromioclavicular Joint, Open Approach */
"0RGH34Z" = "1" /* Fusion of Left Acromioclavicular Joint with Internal Fixation Device, Percutaneous Approach */
"0RGH37Z" = "1" /* Fusion of Left Acromioclavicular Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RGH3JZ" = "1" /* Fusion of Left Acromioclavicular Joint with Synthetic Substitute, Percutaneous Approach */
"0RGH3KZ" = "1" /* Fusion of Left Acromioclavicular Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RGH3ZZ" = "1" /* Fusion of Left Acromioclavicular Joint, Percutaneous Approach */
"0RGH44Z" = "1" /* Fusion of Left Acromioclavicular Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RGH47Z" = "1" /* Fusion of Left Acromioclavicular Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGH4JZ" = "1" /* Fusion of Left Acromioclavicular Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RGH4KZ" = "1" /* Fusion of Left Acromioclavicular Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGH4ZZ" = "1" /* Fusion of Left Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RGJ04Z" = "1" /* Fusion of Right Shoulder Joint with Internal Fixation Device, Open Approach */
"0RGJ07Z" = "1" /* Fusion of Right Shoulder Joint with Autologous Tissue Substitute, Open Approach */
"0RGJ0JZ" = "1" /* Fusion of Right Shoulder Joint with Synthetic Substitute, Open Approach */
"0RGJ0KZ" = "1" /* Fusion of Right Shoulder Joint with Nonautologous Tissue Substitute, Open Approach */
"0RGJ0ZZ" = "1" /* Fusion of Right Shoulder Joint, Open Approach */
"0RGJ34Z" = "1" /* Fusion of Right Shoulder Joint with Internal Fixation Device, Percutaneous Approach */
"0RGJ37Z" = "1" /* Fusion of Right Shoulder Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RGJ3JZ" = "1" /* Fusion of Right Shoulder Joint with Synthetic Substitute, Percutaneous Approach */
"0RGJ3KZ" = "1" /* Fusion of Right Shoulder Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RGJ3ZZ" = "1" /* Fusion of Right Shoulder Joint, Percutaneous Approach */
"0RGJ44Z" = "1" /* Fusion of Right Shoulder Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RGJ47Z" = "1" /* Fusion of Right Shoulder Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGJ4JZ" = "1" /* Fusion of Right Shoulder Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RGJ4KZ" = "1" /* Fusion of Right Shoulder Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGJ4ZZ" = "1" /* Fusion of Right Shoulder Joint, Percutaneous Endoscopic Approach */
"0RGK04Z" = "1" /* Fusion of Left Shoulder Joint with Internal Fixation Device, Open Approach */
"0RGK07Z" = "1" /* Fusion of Left Shoulder Joint with Autologous Tissue Substitute, Open Approach */
"0RGK0JZ" = "1" /* Fusion of Left Shoulder Joint with Synthetic Substitute, Open Approach */
"0RGK0KZ" = "1" /* Fusion of Left Shoulder Joint with Nonautologous Tissue Substitute, Open Approach */
"0RGK0ZZ" = "1" /* Fusion of Left Shoulder Joint, Open Approach */
"0RGK34Z" = "1" /* Fusion of Left Shoulder Joint with Internal Fixation Device, Percutaneous Approach */
"0RGK37Z" = "1" /* Fusion of Left Shoulder Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RGK3JZ" = "1" /* Fusion of Left Shoulder Joint with Synthetic Substitute, Percutaneous Approach */
"0RGK3KZ" = "1" /* Fusion of Left Shoulder Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RGK3ZZ" = "1" /* Fusion of Left Shoulder Joint, Percutaneous Approach */
"0RGK44Z" = "1" /* Fusion of Left Shoulder Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RGK47Z" = "1" /* Fusion of Left Shoulder Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGK4JZ" = "1" /* Fusion of Left Shoulder Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RGK4KZ" = "1" /* Fusion of Left Shoulder Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGK4ZZ" = "1" /* Fusion of Left Shoulder Joint, Percutaneous Endoscopic Approach */
"0RGL04Z" = "1" /* Fusion of Right Elbow Joint with Internal Fixation Device, Open Approach */
"0RGL05Z" = "1" /* Fusion of Right Elbow Joint with External Fixation Device, Open Approach */
"0RGL07Z" = "1" /* Fusion of Right Elbow Joint with Autologous Tissue Substitute, Open Approach */
"0RGL0JZ" = "1" /* Fusion of Right Elbow Joint with Synthetic Substitute, Open Approach */
"0RGL0KZ" = "1" /* Fusion of Right Elbow Joint with Nonautologous Tissue Substitute, Open Approach */
"0RGL0ZZ" = "1" /* Fusion of Right Elbow Joint, Open Approach */
"0RGL34Z" = "1" /* Fusion of Right Elbow Joint with Internal Fixation Device, Percutaneous Approach */
"0RGL35Z" = "1" /* Fusion of Right Elbow Joint with External Fixation Device, Percutaneous Approach */
"0RGL37Z" = "1" /* Fusion of Right Elbow Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RGL3JZ" = "1" /* Fusion of Right Elbow Joint with Synthetic Substitute, Percutaneous Approach */
"0RGL3KZ" = "1" /* Fusion of Right Elbow Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RGL3ZZ" = "1" /* Fusion of Right Elbow Joint, Percutaneous Approach */
"0RGL44Z" = "1" /* Fusion of Right Elbow Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RGL45Z" = "1" /* Fusion of Right Elbow Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0RGL47Z" = "1" /* Fusion of Right Elbow Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGL4JZ" = "1" /* Fusion of Right Elbow Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RGL4KZ" = "1" /* Fusion of Right Elbow Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGL4ZZ" = "1" /* Fusion of Right Elbow Joint, Percutaneous Endoscopic Approach */
"0RGM04Z" = "1" /* Fusion of Left Elbow Joint with Internal Fixation Device, Open Approach */
"0RGM05Z" = "1" /* Fusion of Left Elbow Joint with External Fixation Device, Open Approach */
"0RGM07Z" = "1" /* Fusion of Left Elbow Joint with Autologous Tissue Substitute, Open Approach */
"0RGM0JZ" = "1" /* Fusion of Left Elbow Joint with Synthetic Substitute, Open Approach */
"0RGM0KZ" = "1" /* Fusion of Left Elbow Joint with Nonautologous Tissue Substitute, Open Approach */
"0RGM0ZZ" = "1" /* Fusion of Left Elbow Joint, Open Approach */
"0RGM34Z" = "1" /* Fusion of Left Elbow Joint with Internal Fixation Device, Percutaneous Approach */
"0RGM35Z" = "1" /* Fusion of Left Elbow Joint with External Fixation Device, Percutaneous Approach */
"0RGM37Z" = "1" /* Fusion of Left Elbow Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RGM3JZ" = "1" /* Fusion of Left Elbow Joint with Synthetic Substitute, Percutaneous Approach */
"0RGM3KZ" = "1" /* Fusion of Left Elbow Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RGM3ZZ" = "1" /* Fusion of Left Elbow Joint, Percutaneous Approach */
"0RGM44Z" = "1" /* Fusion of Left Elbow Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RGM45Z" = "1" /* Fusion of Left Elbow Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0RGM47Z" = "1" /* Fusion of Left Elbow Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGM4JZ" = "1" /* Fusion of Left Elbow Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RGM4KZ" = "1" /* Fusion of Left Elbow Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGM4ZZ" = "1" /* Fusion of Left Elbow Joint, Percutaneous Endoscopic Approach */
"0RGN04Z" = "1" /* Fusion of Right Wrist Joint with Internal Fixation Device, Open Approach */
"0RGN05Z" = "1" /* Fusion of Right Wrist Joint with External Fixation Device, Open Approach */
"0RGN07Z" = "1" /* Fusion of Right Wrist Joint with Autologous Tissue Substitute, Open Approach */
"0RGN0JZ" = "1" /* Fusion of Right Wrist Joint with Synthetic Substitute, Open Approach */
"0RGN0KZ" = "1" /* Fusion of Right Wrist Joint with Nonautologous Tissue Substitute, Open Approach */
"0RGN0ZZ" = "1" /* Fusion of Right Wrist Joint, Open Approach */
"0RGN34Z" = "1" /* Fusion of Right Wrist Joint with Internal Fixation Device, Percutaneous Approach */
"0RGN35Z" = "1" /* Fusion of Right Wrist Joint with External Fixation Device, Percutaneous Approach */
"0RGN37Z" = "1" /* Fusion of Right Wrist Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RGN3JZ" = "1" /* Fusion of Right Wrist Joint with Synthetic Substitute, Percutaneous Approach */
"0RGN3KZ" = "1" /* Fusion of Right Wrist Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RGN3ZZ" = "1" /* Fusion of Right Wrist Joint, Percutaneous Approach */
"0RGN44Z" = "1" /* Fusion of Right Wrist Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RGN45Z" = "1" /* Fusion of Right Wrist Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0RGN47Z" = "1" /* Fusion of Right Wrist Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGN4JZ" = "1" /* Fusion of Right Wrist Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RGN4KZ" = "1" /* Fusion of Right Wrist Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGN4ZZ" = "1" /* Fusion of Right Wrist Joint, Percutaneous Endoscopic Approach */
"0RGP04Z" = "1" /* Fusion of Left Wrist Joint with Internal Fixation Device, Open Approach */
"0RGP05Z" = "1" /* Fusion of Left Wrist Joint with External Fixation Device, Open Approach */
"0RGP07Z" = "1" /* Fusion of Left Wrist Joint with Autologous Tissue Substitute, Open Approach */
"0RGP0JZ" = "1" /* Fusion of Left Wrist Joint with Synthetic Substitute, Open Approach */
"0RGP0KZ" = "1" /* Fusion of Left Wrist Joint with Nonautologous Tissue Substitute, Open Approach */
"0RGP0ZZ" = "1" /* Fusion of Left Wrist Joint, Open Approach */
"0RGP34Z" = "1" /* Fusion of Left Wrist Joint with Internal Fixation Device, Percutaneous Approach */
"0RGP35Z" = "1" /* Fusion of Left Wrist Joint with External Fixation Device, Percutaneous Approach */
"0RGP37Z" = "1" /* Fusion of Left Wrist Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RGP3JZ" = "1" /* Fusion of Left Wrist Joint with Synthetic Substitute, Percutaneous Approach */
"0RGP3KZ" = "1" /* Fusion of Left Wrist Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RGP3ZZ" = "1" /* Fusion of Left Wrist Joint, Percutaneous Approach */
"0RGP44Z" = "1" /* Fusion of Left Wrist Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RGP45Z" = "1" /* Fusion of Left Wrist Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0RGP47Z" = "1" /* Fusion of Left Wrist Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGP4JZ" = "1" /* Fusion of Left Wrist Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RGP4KZ" = "1" /* Fusion of Left Wrist Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGP4ZZ" = "1" /* Fusion of Left Wrist Joint, Percutaneous Endoscopic Approach */
"0RGQ04Z" = "1" /* Fusion of Right Carpal Joint with Internal Fixation Device, Open Approach */
"0RGQ05Z" = "1" /* Fusion of Right Carpal Joint with External Fixation Device, Open Approach */
"0RGQ07Z" = "1" /* Fusion of Right Carpal Joint with Autologous Tissue Substitute, Open Approach */
"0RGQ0JZ" = "1" /* Fusion of Right Carpal Joint with Synthetic Substitute, Open Approach */
"0RGQ0KZ" = "1" /* Fusion of Right Carpal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RGQ0ZZ" = "1" /* Fusion of Right Carpal Joint, Open Approach */
"0RGQ34Z" = "1" /* Fusion of Right Carpal Joint with Internal Fixation Device, Percutaneous Approach */
"0RGQ35Z" = "1" /* Fusion of Right Carpal Joint with External Fixation Device, Percutaneous Approach */
"0RGQ37Z" = "1" /* Fusion of Right Carpal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RGQ3JZ" = "1" /* Fusion of Right Carpal Joint with Synthetic Substitute, Percutaneous Approach */
"0RGQ3KZ" = "1" /* Fusion of Right Carpal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RGQ3ZZ" = "1" /* Fusion of Right Carpal Joint, Percutaneous Approach */
"0RGQ44Z" = "1" /* Fusion of Right Carpal Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RGQ45Z" = "1" /* Fusion of Right Carpal Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0RGQ47Z" = "1" /* Fusion of Right Carpal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGQ4JZ" = "1" /* Fusion of Right Carpal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RGQ4KZ" = "1" /* Fusion of Right Carpal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGQ4ZZ" = "1" /* Fusion of Right Carpal Joint, Percutaneous Endoscopic Approach */
"0RGR04Z" = "1" /* Fusion of Left Carpal Joint with Internal Fixation Device, Open Approach */
"0RGR05Z" = "1" /* Fusion of Left Carpal Joint with External Fixation Device, Open Approach */
"0RGR07Z" = "1" /* Fusion of Left Carpal Joint with Autologous Tissue Substitute, Open Approach */
"0RGR0JZ" = "1" /* Fusion of Left Carpal Joint with Synthetic Substitute, Open Approach */
"0RGR0KZ" = "1" /* Fusion of Left Carpal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RGR0ZZ" = "1" /* Fusion of Left Carpal Joint, Open Approach */
"0RGR34Z" = "1" /* Fusion of Left Carpal Joint with Internal Fixation Device, Percutaneous Approach */
"0RGR35Z" = "1" /* Fusion of Left Carpal Joint with External Fixation Device, Percutaneous Approach */
"0RGR37Z" = "1" /* Fusion of Left Carpal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RGR3JZ" = "1" /* Fusion of Left Carpal Joint with Synthetic Substitute, Percutaneous Approach */
"0RGR3KZ" = "1" /* Fusion of Left Carpal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RGR3ZZ" = "1" /* Fusion of Left Carpal Joint, Percutaneous Approach */
"0RGR44Z" = "1" /* Fusion of Left Carpal Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RGR45Z" = "1" /* Fusion of Left Carpal Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0RGR47Z" = "1" /* Fusion of Left Carpal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGR4JZ" = "1" /* Fusion of Left Carpal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RGR4KZ" = "1" /* Fusion of Left Carpal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGR4ZZ" = "1" /* Fusion of Left Carpal Joint, Percutaneous Endoscopic Approach */
"0RGS04Z" = "1" /* Fusion of Right Metacarpocarpal Joint with Internal Fixation Device, Open Approach */
"0RGS05Z" = "1" /* Fusion of Right Metacarpocarpal Joint with External Fixation Device, Open Approach */
"0RGS07Z" = "1" /* Fusion of Right Metacarpocarpal Joint with Autologous Tissue Substitute, Open Approach */
"0RGS0JZ" = "1" /* Fusion of Right Metacarpocarpal Joint with Synthetic Substitute, Open Approach */
"0RGS0KZ" = "1" /* Fusion of Right Metacarpocarpal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RGS0ZZ" = "1" /* Fusion of Right Metacarpocarpal Joint, Open Approach */
"0RGS34Z" = "1" /* Fusion of Right Metacarpocarpal Joint with Internal Fixation Device, Percutaneous Approach */
"0RGS35Z" = "1" /* Fusion of Right Metacarpocarpal Joint with External Fixation Device, Percutaneous Approach */
"0RGS37Z" = "1" /* Fusion of Right Metacarpocarpal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RGS3JZ" = "1" /* Fusion of Right Metacarpocarpal Joint with Synthetic Substitute, Percutaneous Approach */
"0RGS3KZ" = "1" /* Fusion of Right Metacarpocarpal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RGS3ZZ" = "1" /* Fusion of Right Metacarpocarpal Joint, Percutaneous Approach */
"0RGS44Z" = "1" /* Fusion of Right Metacarpocarpal Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RGS45Z" = "1" /* Fusion of Right Metacarpocarpal Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0RGS47Z" = "1" /* Fusion of Right Metacarpocarpal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGS4JZ" = "1" /* Fusion of Right Metacarpocarpal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RGS4KZ" = "1" /* Fusion of Right Metacarpocarpal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGS4ZZ" = "1" /* Fusion of Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RGT04Z" = "1" /* Fusion of Left Metacarpocarpal Joint with Internal Fixation Device, Open Approach */
"0RGT05Z" = "1" /* Fusion of Left Metacarpocarpal Joint with External Fixation Device, Open Approach */
"0RGT07Z" = "1" /* Fusion of Left Metacarpocarpal Joint with Autologous Tissue Substitute, Open Approach */
"0RGT0JZ" = "1" /* Fusion of Left Metacarpocarpal Joint with Synthetic Substitute, Open Approach */
"0RGT0KZ" = "1" /* Fusion of Left Metacarpocarpal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RGT0ZZ" = "1" /* Fusion of Left Metacarpocarpal Joint, Open Approach */
"0RGT34Z" = "1" /* Fusion of Left Metacarpocarpal Joint with Internal Fixation Device, Percutaneous Approach */
"0RGT35Z" = "1" /* Fusion of Left Metacarpocarpal Joint with External Fixation Device, Percutaneous Approach */
"0RGT37Z" = "1" /* Fusion of Left Metacarpocarpal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RGT3JZ" = "1" /* Fusion of Left Metacarpocarpal Joint with Synthetic Substitute, Percutaneous Approach */
"0RGT3KZ" = "1" /* Fusion of Left Metacarpocarpal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RGT3ZZ" = "1" /* Fusion of Left Metacarpocarpal Joint, Percutaneous Approach */
"0RGT44Z" = "1" /* Fusion of Left Metacarpocarpal Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RGT45Z" = "1" /* Fusion of Left Metacarpocarpal Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0RGT47Z" = "1" /* Fusion of Left Metacarpocarpal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGT4JZ" = "1" /* Fusion of Left Metacarpocarpal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RGT4KZ" = "1" /* Fusion of Left Metacarpocarpal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGT4ZZ" = "1" /* Fusion of Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RGU04Z" = "1" /* Fusion of Right Metacarpophalangeal Joint with Internal Fixation Device, Open Approach */
"0RGU05Z" = "1" /* Fusion of Right Metacarpophalangeal Joint with External Fixation Device, Open Approach */
"0RGU07Z" = "1" /* Fusion of Right Metacarpophalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0RGU0JZ" = "1" /* Fusion of Right Metacarpophalangeal Joint with Synthetic Substitute, Open Approach */
"0RGU0KZ" = "1" /* Fusion of Right Metacarpophalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RGU0ZZ" = "1" /* Fusion of Right Metacarpophalangeal Joint, Open Approach */
"0RGU34Z" = "1" /* Fusion of Right Metacarpophalangeal Joint with Internal Fixation Device, Percutaneous Approach */
"0RGU35Z" = "1" /* Fusion of Right Metacarpophalangeal Joint with External Fixation Device, Percutaneous Approach */
"0RGU37Z" = "1" /* Fusion of Right Metacarpophalangeal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RGU3JZ" = "1" /* Fusion of Right Metacarpophalangeal Joint with Synthetic Substitute, Percutaneous Approach */
"0RGU3KZ" = "1" /* Fusion of Right Metacarpophalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RGU3ZZ" = "1" /* Fusion of Right Metacarpophalangeal Joint, Percutaneous Approach */
"0RGU44Z" = "1" /* Fusion of Right Metacarpophalangeal Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RGU45Z" = "1" /* Fusion of Right Metacarpophalangeal Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0RGU47Z" = "1" /* Fusion of Right Metacarpophalangeal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGU4JZ" = "1" /* Fusion of Right Metacarpophalangeal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RGU4KZ" = "1" /* Fusion of Right Metacarpophalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGU4ZZ" = "1" /* Fusion of Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RGV04Z" = "1" /* Fusion of Left Metacarpophalangeal Joint with Internal Fixation Device, Open Approach */
"0RGV05Z" = "1" /* Fusion of Left Metacarpophalangeal Joint with External Fixation Device, Open Approach */
"0RGV07Z" = "1" /* Fusion of Left Metacarpophalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0RGV0JZ" = "1" /* Fusion of Left Metacarpophalangeal Joint with Synthetic Substitute, Open Approach */
"0RGV0KZ" = "1" /* Fusion of Left Metacarpophalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RGV0ZZ" = "1" /* Fusion of Left Metacarpophalangeal Joint, Open Approach */
"0RGV34Z" = "1" /* Fusion of Left Metacarpophalangeal Joint with Internal Fixation Device, Percutaneous Approach */
"0RGV35Z" = "1" /* Fusion of Left Metacarpophalangeal Joint with External Fixation Device, Percutaneous Approach */
"0RGV37Z" = "1" /* Fusion of Left Metacarpophalangeal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RGV3JZ" = "1" /* Fusion of Left Metacarpophalangeal Joint with Synthetic Substitute, Percutaneous Approach */
"0RGV3KZ" = "1" /* Fusion of Left Metacarpophalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RGV3ZZ" = "1" /* Fusion of Left Metacarpophalangeal Joint, Percutaneous Approach */
"0RGV44Z" = "1" /* Fusion of Left Metacarpophalangeal Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RGV45Z" = "1" /* Fusion of Left Metacarpophalangeal Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0RGV47Z" = "1" /* Fusion of Left Metacarpophalangeal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGV4JZ" = "1" /* Fusion of Left Metacarpophalangeal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RGV4KZ" = "1" /* Fusion of Left Metacarpophalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGV4ZZ" = "1" /* Fusion of Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RGW04Z" = "1" /* Fusion of Right Finger Phalangeal Joint with Internal Fixation Device, Open Approach */
"0RGW05Z" = "1" /* Fusion of Right Finger Phalangeal Joint with External Fixation Device, Open Approach */
"0RGW07Z" = "1" /* Fusion of Right Finger Phalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0RGW0JZ" = "1" /* Fusion of Right Finger Phalangeal Joint with Synthetic Substitute, Open Approach */
"0RGW0KZ" = "1" /* Fusion of Right Finger Phalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RGW0ZZ" = "1" /* Fusion of Right Finger Phalangeal Joint, Open Approach */
"0RGW34Z" = "1" /* Fusion of Right Finger Phalangeal Joint with Internal Fixation Device, Percutaneous Approach */
"0RGW35Z" = "1" /* Fusion of Right Finger Phalangeal Joint with External Fixation Device, Percutaneous Approach */
"0RGW37Z" = "1" /* Fusion of Right Finger Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RGW3JZ" = "1" /* Fusion of Right Finger Phalangeal Joint with Synthetic Substitute, Percutaneous Approach */
"0RGW3KZ" = "1" /* Fusion of Right Finger Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RGW3ZZ" = "1" /* Fusion of Right Finger Phalangeal Joint, Percutaneous Approach */
"0RGW44Z" = "1" /* Fusion of Right Finger Phalangeal Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RGW45Z" = "1" /* Fusion of Right Finger Phalangeal Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0RGW47Z" = "1" /* Fusion of Right Finger Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGW4JZ" = "1" /* Fusion of Right Finger Phalangeal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RGW4KZ" = "1" /* Fusion of Right Finger Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGW4ZZ" = "1" /* Fusion of Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RGX04Z" = "1" /* Fusion of Left Finger Phalangeal Joint with Internal Fixation Device, Open Approach */
"0RGX05Z" = "1" /* Fusion of Left Finger Phalangeal Joint with External Fixation Device, Open Approach */
"0RGX07Z" = "1" /* Fusion of Left Finger Phalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0RGX0JZ" = "1" /* Fusion of Left Finger Phalangeal Joint with Synthetic Substitute, Open Approach */
"0RGX0KZ" = "1" /* Fusion of Left Finger Phalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RGX0ZZ" = "1" /* Fusion of Left Finger Phalangeal Joint, Open Approach */
"0RGX34Z" = "1" /* Fusion of Left Finger Phalangeal Joint with Internal Fixation Device, Percutaneous Approach */
"0RGX35Z" = "1" /* Fusion of Left Finger Phalangeal Joint with External Fixation Device, Percutaneous Approach */
"0RGX37Z" = "1" /* Fusion of Left Finger Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RGX3JZ" = "1" /* Fusion of Left Finger Phalangeal Joint with Synthetic Substitute, Percutaneous Approach */
"0RGX3KZ" = "1" /* Fusion of Left Finger Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RGX3ZZ" = "1" /* Fusion of Left Finger Phalangeal Joint, Percutaneous Approach */
"0RGX44Z" = "1" /* Fusion of Left Finger Phalangeal Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0RGX45Z" = "1" /* Fusion of Left Finger Phalangeal Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0RGX47Z" = "1" /* Fusion of Left Finger Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGX4JZ" = "1" /* Fusion of Left Finger Phalangeal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RGX4KZ" = "1" /* Fusion of Left Finger Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RGX4ZZ" = "1" /* Fusion of Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RH004Z" = "1" /* Insertion of Internal Fixation Device into Occipital-cervical Joint, Open Approach */
"0RH00BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Occipital-cervical Joint, Open Approach */
"0RH00CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Occipital-cervical Joint, Open Approach */
"0RH00DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Occipital-cervical Joint, Open Approach */
"0RH034Z" = "1" /* Insertion of Internal Fixation Device into Occipital-cervical Joint, Percutaneous Approach */
"0RH03BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Occipital-cervical Joint, Percutaneous Approach */
"0RH03CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Occipital-cervical Joint, Percutaneous Approach */
"0RH03DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Occipital-cervical Joint, Percutaneous Approach */
"0RH044Z" = "1" /* Insertion of Internal Fixation Device into Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RH04BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RH04CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RH04DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RH104Z" = "1" /* Insertion of Internal Fixation Device into Cervical Vertebral Joint, Open Approach */
"0RH10BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Cervical Vertebral Joint, Open Approach */
"0RH10CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Cervical Vertebral Joint, Open Approach */
"0RH10DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Cervical Vertebral Joint, Open Approach */
"0RH134Z" = "1" /* Insertion of Internal Fixation Device into Cervical Vertebral Joint, Percutaneous Approach */
"0RH13BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Cervical Vertebral Joint, Percutaneous Approach */
"0RH13CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Cervical Vertebral Joint, Percutaneous Approach */
"0RH13DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Cervical Vertebral Joint, Percutaneous Approach */
"0RH144Z" = "1" /* Insertion of Internal Fixation Device into Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RH14BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RH14CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RH14DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RH404Z" = "1" /* Insertion of Internal Fixation Device into Cervicothoracic Vertebral Joint, Open Approach */
"0RH40BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Cervicothoracic Vertebral Joint, Open Approach */
"0RH40CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Cervicothoracic Vertebral Joint, Open Approach */
"0RH40DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Cervicothoracic Vertebral Joint, Open Approach */
"0RH434Z" = "1" /* Insertion of Internal Fixation Device into Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RH43BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RH43CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RH43DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RH444Z" = "1" /* Insertion of Internal Fixation Device into Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RH44BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RH44CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RH44DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RH604Z" = "1" /* Insertion of Internal Fixation Device into Thoracic Vertebral Joint, Open Approach */
"0RH60BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Thoracic Vertebral Joint, Open Approach */
"0RH60CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Thoracic Vertebral Joint, Open Approach */
"0RH60DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Thoracic Vertebral Joint, Open Approach */
"0RH634Z" = "1" /* Insertion of Internal Fixation Device into Thoracic Vertebral Joint, Percutaneous Approach */
"0RH63BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Thoracic Vertebral Joint, Percutaneous Approach */
"0RH63CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Thoracic Vertebral Joint, Percutaneous Approach */
"0RH63DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Thoracic Vertebral Joint, Percutaneous Approach */
"0RH644Z" = "1" /* Insertion of Internal Fixation Device into Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RH64BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RH64CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RH64DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RHA04Z" = "1" /* Insertion of Internal Fixation Device into Thoracolumbar Vertebral Joint, Open Approach */
"0RHA0BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Thoracolumbar Vertebral Joint, Open Approach */
"0RHA0CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Thoracolumbar Vertebral Joint, Open Approach */
"0RHA0DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Thoracolumbar Vertebral Joint, Open Approach */
"0RHA34Z" = "1" /* Insertion of Internal Fixation Device into Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RHA3BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RHA3CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RHA3DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RHA44Z" = "1" /* Insertion of Internal Fixation Device into Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RHA4BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RHA4CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RHA4DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RHC03Z" = "1" /* Insertion of Infusion Device into Right Temporomandibular Joint, Open Approach */
"0RHC04Z" = "1" /* Insertion of Internal Fixation Device into Right Temporomandibular Joint, Open Approach */
"0RHC34Z" = "1" /* Insertion of Internal Fixation Device into Right Temporomandibular Joint, Percutaneous Approach */
"0RHC43Z" = "1" /* Insertion of Infusion Device into Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RHC44Z" = "1" /* Insertion of Internal Fixation Device into Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RHD03Z" = "1" /* Insertion of Infusion Device into Left Temporomandibular Joint, Open Approach */
"0RHD04Z" = "1" /* Insertion of Internal Fixation Device into Left Temporomandibular Joint, Open Approach */
"0RHD34Z" = "1" /* Insertion of Internal Fixation Device into Left Temporomandibular Joint, Percutaneous Approach */
"0RHD43Z" = "1" /* Insertion of Infusion Device into Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RHD44Z" = "1" /* Insertion of Internal Fixation Device into Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RHE04Z" = "1" /* Insertion of Internal Fixation Device into Right Sternoclavicular Joint, Open Approach */
"0RHE34Z" = "1" /* Insertion of Internal Fixation Device into Right Sternoclavicular Joint, Percutaneous Approach */
"0RHE44Z" = "1" /* Insertion of Internal Fixation Device into Right Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RHF04Z" = "1" /* Insertion of Internal Fixation Device into Left Sternoclavicular Joint, Open Approach */
"0RHF34Z" = "1" /* Insertion of Internal Fixation Device into Left Sternoclavicular Joint, Percutaneous Approach */
"0RHF44Z" = "1" /* Insertion of Internal Fixation Device into Left Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RHG04Z" = "1" /* Insertion of Internal Fixation Device into Right Acromioclavicular Joint, Open Approach */
"0RHG34Z" = "1" /* Insertion of Internal Fixation Device into Right Acromioclavicular Joint, Percutaneous Approach */
"0RHG44Z" = "1" /* Insertion of Internal Fixation Device into Right Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RHH04Z" = "1" /* Insertion of Internal Fixation Device into Left Acromioclavicular Joint, Open Approach */
"0RHH34Z" = "1" /* Insertion of Internal Fixation Device into Left Acromioclavicular Joint, Percutaneous Approach */
"0RHH44Z" = "1" /* Insertion of Internal Fixation Device into Left Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RHJ04Z" = "1" /* Insertion of Internal Fixation Device into Right Shoulder Joint, Open Approach */
"0RHJ34Z" = "1" /* Insertion of Internal Fixation Device into Right Shoulder Joint, Percutaneous Approach */
"0RHJ44Z" = "1" /* Insertion of Internal Fixation Device into Right Shoulder Joint, Percutaneous Endoscopic Approach */
"0RHK04Z" = "1" /* Insertion of Internal Fixation Device into Left Shoulder Joint, Open Approach */
"0RHK34Z" = "1" /* Insertion of Internal Fixation Device into Left Shoulder Joint, Percutaneous Approach */
"0RHK44Z" = "1" /* Insertion of Internal Fixation Device into Left Shoulder Joint, Percutaneous Endoscopic Approach */
"0RHL04Z" = "1" /* Insertion of Internal Fixation Device into Right Elbow Joint, Open Approach */
"0RHL05Z" = "1" /* Insertion of External Fixation Device into Right Elbow Joint, Open Approach */
"0RHL34Z" = "1" /* Insertion of Internal Fixation Device into Right Elbow Joint, Percutaneous Approach */
"0RHL35Z" = "1" /* Insertion of External Fixation Device into Right Elbow Joint, Percutaneous Approach */
"0RHL44Z" = "1" /* Insertion of Internal Fixation Device into Right Elbow Joint, Percutaneous Endoscopic Approach */
"0RHL45Z" = "1" /* Insertion of External Fixation Device into Right Elbow Joint, Percutaneous Endoscopic Approach */
"0RHM04Z" = "1" /* Insertion of Internal Fixation Device into Left Elbow Joint, Open Approach */
"0RHM05Z" = "1" /* Insertion of External Fixation Device into Left Elbow Joint, Open Approach */
"0RHM34Z" = "1" /* Insertion of Internal Fixation Device into Left Elbow Joint, Percutaneous Approach */
"0RHM35Z" = "1" /* Insertion of External Fixation Device into Left Elbow Joint, Percutaneous Approach */
"0RHM44Z" = "1" /* Insertion of Internal Fixation Device into Left Elbow Joint, Percutaneous Endoscopic Approach */
"0RHM45Z" = "1" /* Insertion of External Fixation Device into Left Elbow Joint, Percutaneous Endoscopic Approach */
"0RHN04Z" = "1" /* Insertion of Internal Fixation Device into Right Wrist Joint, Open Approach */
"0RHN05Z" = "1" /* Insertion of External Fixation Device into Right Wrist Joint, Open Approach */
"0RHN34Z" = "1" /* Insertion of Internal Fixation Device into Right Wrist Joint, Percutaneous Approach */
"0RHN35Z" = "1" /* Insertion of External Fixation Device into Right Wrist Joint, Percutaneous Approach */
"0RHN44Z" = "1" /* Insertion of Internal Fixation Device into Right Wrist Joint, Percutaneous Endoscopic Approach */
"0RHN45Z" = "1" /* Insertion of External Fixation Device into Right Wrist Joint, Percutaneous Endoscopic Approach */
"0RHP04Z" = "1" /* Insertion of Internal Fixation Device into Left Wrist Joint, Open Approach */
"0RHP05Z" = "1" /* Insertion of External Fixation Device into Left Wrist Joint, Open Approach */
"0RHP34Z" = "1" /* Insertion of Internal Fixation Device into Left Wrist Joint, Percutaneous Approach */
"0RHP35Z" = "1" /* Insertion of External Fixation Device into Left Wrist Joint, Percutaneous Approach */
"0RHP44Z" = "1" /* Insertion of Internal Fixation Device into Left Wrist Joint, Percutaneous Endoscopic Approach */
"0RHP45Z" = "1" /* Insertion of External Fixation Device into Left Wrist Joint, Percutaneous Endoscopic Approach */
"0RHQ04Z" = "1" /* Insertion of Internal Fixation Device into Right Carpal Joint, Open Approach */
"0RHQ05Z" = "1" /* Insertion of External Fixation Device into Right Carpal Joint, Open Approach */
"0RHQ34Z" = "1" /* Insertion of Internal Fixation Device into Right Carpal Joint, Percutaneous Approach */
"0RHQ35Z" = "1" /* Insertion of External Fixation Device into Right Carpal Joint, Percutaneous Approach */
"0RHQ44Z" = "1" /* Insertion of Internal Fixation Device into Right Carpal Joint, Percutaneous Endoscopic Approach */
"0RHQ45Z" = "1" /* Insertion of External Fixation Device into Right Carpal Joint, Percutaneous Endoscopic Approach */
"0RHR04Z" = "1" /* Insertion of Internal Fixation Device into Left Carpal Joint, Open Approach */
"0RHR05Z" = "1" /* Insertion of External Fixation Device into Left Carpal Joint, Open Approach */
"0RHR34Z" = "1" /* Insertion of Internal Fixation Device into Left Carpal Joint, Percutaneous Approach */
"0RHR35Z" = "1" /* Insertion of External Fixation Device into Left Carpal Joint, Percutaneous Approach */
"0RHR44Z" = "1" /* Insertion of Internal Fixation Device into Left Carpal Joint, Percutaneous Endoscopic Approach */
"0RHR45Z" = "1" /* Insertion of External Fixation Device into Left Carpal Joint, Percutaneous Endoscopic Approach */
"0RHS04Z" = "1" /* Insertion of Internal Fixation Device into Right Metacarpocarpal Joint, Open Approach */
"0RHS05Z" = "1" /* Insertion of External Fixation Device into Right Metacarpocarpal Joint, Open Approach */
"0RHS34Z" = "1" /* Insertion of Internal Fixation Device into Right Metacarpocarpal Joint, Percutaneous Approach */
"0RHS35Z" = "1" /* Insertion of External Fixation Device into Right Metacarpocarpal Joint, Percutaneous Approach */
"0RHS44Z" = "1" /* Insertion of Internal Fixation Device into Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RHS45Z" = "1" /* Insertion of External Fixation Device into Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RHT04Z" = "1" /* Insertion of Internal Fixation Device into Left Metacarpocarpal Joint, Open Approach */
"0RHT05Z" = "1" /* Insertion of External Fixation Device into Left Metacarpocarpal Joint, Open Approach */
"0RHT34Z" = "1" /* Insertion of Internal Fixation Device into Left Metacarpocarpal Joint, Percutaneous Approach */
"0RHT35Z" = "1" /* Insertion of External Fixation Device into Left Metacarpocarpal Joint, Percutaneous Approach */
"0RHT44Z" = "1" /* Insertion of Internal Fixation Device into Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RHT45Z" = "1" /* Insertion of External Fixation Device into Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RHU04Z" = "1" /* Insertion of Internal Fixation Device into Right Metacarpophalangeal Joint, Open Approach */
"0RHU05Z" = "1" /* Insertion of External Fixation Device into Right Metacarpophalangeal Joint, Open Approach */
"0RHU34Z" = "1" /* Insertion of Internal Fixation Device into Right Metacarpophalangeal Joint, Percutaneous Approach */
"0RHU35Z" = "1" /* Insertion of External Fixation Device into Right Metacarpophalangeal Joint, Percutaneous Approach */
"0RHU44Z" = "1" /* Insertion of Internal Fixation Device into Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RHU45Z" = "1" /* Insertion of External Fixation Device into Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RHV04Z" = "1" /* Insertion of Internal Fixation Device into Left Metacarpophalangeal Joint, Open Approach */
"0RHV05Z" = "1" /* Insertion of External Fixation Device into Left Metacarpophalangeal Joint, Open Approach */
"0RHV34Z" = "1" /* Insertion of Internal Fixation Device into Left Metacarpophalangeal Joint, Percutaneous Approach */
"0RHV35Z" = "1" /* Insertion of External Fixation Device into Left Metacarpophalangeal Joint, Percutaneous Approach */
"0RHV44Z" = "1" /* Insertion of Internal Fixation Device into Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RHV45Z" = "1" /* Insertion of External Fixation Device into Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RHW04Z" = "1" /* Insertion of Internal Fixation Device into Right Finger Phalangeal Joint, Open Approach */
"0RHW05Z" = "1" /* Insertion of External Fixation Device into Right Finger Phalangeal Joint, Open Approach */
"0RHW34Z" = "1" /* Insertion of Internal Fixation Device into Right Finger Phalangeal Joint, Percutaneous Approach */
"0RHW35Z" = "1" /* Insertion of External Fixation Device into Right Finger Phalangeal Joint, Percutaneous Approach */
"0RHW44Z" = "1" /* Insertion of Internal Fixation Device into Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RHW45Z" = "1" /* Insertion of External Fixation Device into Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RHX04Z" = "1" /* Insertion of Internal Fixation Device into Left Finger Phalangeal Joint, Open Approach */
"0RHX05Z" = "1" /* Insertion of External Fixation Device into Left Finger Phalangeal Joint, Open Approach */
"0RHX34Z" = "1" /* Insertion of Internal Fixation Device into Left Finger Phalangeal Joint, Percutaneous Approach */
"0RHX35Z" = "1" /* Insertion of External Fixation Device into Left Finger Phalangeal Joint, Percutaneous Approach */
"0RHX44Z" = "1" /* Insertion of Internal Fixation Device into Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RHX45Z" = "1" /* Insertion of External Fixation Device into Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RJ00ZZ" = "1" /* Inspection of Occipital-cervical Joint, Open Approach */
"0RJ04ZZ" = "1" /* Inspection of Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RJ10ZZ" = "1" /* Inspection of Cervical Vertebral Joint, Open Approach */
"0RJ14ZZ" = "1" /* Inspection of Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RJ30ZZ" = "1" /* Inspection of Cervical Vertebral Disc, Open Approach */
"0RJ34ZZ" = "1" /* Inspection of Cervical Vertebral Disc, Percutaneous Endoscopic Approach */
"0RJ40ZZ" = "1" /* Inspection of Cervicothoracic Vertebral Joint, Open Approach */
"0RJ44ZZ" = "1" /* Inspection of Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RJ50ZZ" = "1" /* Inspection of Cervicothoracic Vertebral Disc, Open Approach */
"0RJ54ZZ" = "1" /* Inspection of Cervicothoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RJ60ZZ" = "1" /* Inspection of Thoracic Vertebral Joint, Open Approach */
"0RJ64ZZ" = "1" /* Inspection of Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RJ90ZZ" = "1" /* Inspection of Thoracic Vertebral Disc, Open Approach */
"0RJ94ZZ" = "1" /* Inspection of Thoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RJA0ZZ" = "1" /* Inspection of Thoracolumbar Vertebral Joint, Open Approach */
"0RJA4ZZ" = "1" /* Inspection of Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RJB0ZZ" = "1" /* Inspection of Thoracolumbar Vertebral Disc, Open Approach */
"0RJB4ZZ" = "1" /* Inspection of Thoracolumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0RJC0ZZ" = "1" /* Inspection of Right Temporomandibular Joint, Open Approach */
"0RJC4ZZ" = "1" /* Inspection of Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RJD0ZZ" = "1" /* Inspection of Left Temporomandibular Joint, Open Approach */
"0RJD4ZZ" = "1" /* Inspection of Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RJE0ZZ" = "1" /* Inspection of Right Sternoclavicular Joint, Open Approach */
"0RJE4ZZ" = "1" /* Inspection of Right Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RJF0ZZ" = "1" /* Inspection of Left Sternoclavicular Joint, Open Approach */
"0RJF4ZZ" = "1" /* Inspection of Left Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RJG0ZZ" = "1" /* Inspection of Right Acromioclavicular Joint, Open Approach */
"0RJG4ZZ" = "1" /* Inspection of Right Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RJH0ZZ" = "1" /* Inspection of Left Acromioclavicular Joint, Open Approach */
"0RJH4ZZ" = "1" /* Inspection of Left Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RJJ0ZZ" = "1" /* Inspection of Right Shoulder Joint, Open Approach */
"0RJJ4ZZ" = "1" /* Inspection of Right Shoulder Joint, Percutaneous Endoscopic Approach */
"0RJK0ZZ" = "1" /* Inspection of Left Shoulder Joint, Open Approach */
"0RJK4ZZ" = "1" /* Inspection of Left Shoulder Joint, Percutaneous Endoscopic Approach */
"0RJL0ZZ" = "1" /* Inspection of Right Elbow Joint, Open Approach */
"0RJL4ZZ" = "1" /* Inspection of Right Elbow Joint, Percutaneous Endoscopic Approach */
"0RJM0ZZ" = "1" /* Inspection of Left Elbow Joint, Open Approach */
"0RJM4ZZ" = "1" /* Inspection of Left Elbow Joint, Percutaneous Endoscopic Approach */
"0RJN0ZZ" = "1" /* Inspection of Right Wrist Joint, Open Approach */
"0RJN4ZZ" = "1" /* Inspection of Right Wrist Joint, Percutaneous Endoscopic Approach */
"0RJP0ZZ" = "1" /* Inspection of Left Wrist Joint, Open Approach */
"0RJP4ZZ" = "1" /* Inspection of Left Wrist Joint, Percutaneous Endoscopic Approach */
"0RJQ0ZZ" = "1" /* Inspection of Right Carpal Joint, Open Approach */
"0RJQ4ZZ" = "1" /* Inspection of Right Carpal Joint, Percutaneous Endoscopic Approach */
"0RJR0ZZ" = "1" /* Inspection of Left Carpal Joint, Open Approach */
"0RJR4ZZ" = "1" /* Inspection of Left Carpal Joint, Percutaneous Endoscopic Approach */
"0RJS0ZZ" = "1" /* Inspection of Right Metacarpocarpal Joint, Open Approach */
"0RJS4ZZ" = "1" /* Inspection of Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RJT0ZZ" = "1" /* Inspection of Left Metacarpocarpal Joint, Open Approach */
"0RJT4ZZ" = "1" /* Inspection of Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RJU0ZZ" = "1" /* Inspection of Right Metacarpophalangeal Joint, Open Approach */
"0RJU4ZZ" = "1" /* Inspection of Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RJV0ZZ" = "1" /* Inspection of Left Metacarpophalangeal Joint, Open Approach */
"0RJV4ZZ" = "1" /* Inspection of Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RJW0ZZ" = "1" /* Inspection of Right Finger Phalangeal Joint, Open Approach */
"0RJW4ZZ" = "1" /* Inspection of Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RJX0ZZ" = "1" /* Inspection of Left Finger Phalangeal Joint, Open Approach */
"0RJX4ZZ" = "1" /* Inspection of Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RN00ZZ" = "1" /* Release Occipital-cervical Joint, Open Approach */
"0RN03ZZ" = "1" /* Release Occipital-cervical Joint, Percutaneous Approach */
"0RN04ZZ" = "1" /* Release Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RN10ZZ" = "1" /* Release Cervical Vertebral Joint, Open Approach */
"0RN13ZZ" = "1" /* Release Cervical Vertebral Joint, Percutaneous Approach */
"0RN14ZZ" = "1" /* Release Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RN30ZZ" = "1" /* Release Cervical Vertebral Disc, Open Approach */
"0RN33ZZ" = "1" /* Release Cervical Vertebral Disc, Percutaneous Approach */
"0RN34ZZ" = "1" /* Release Cervical Vertebral Disc, Percutaneous Endoscopic Approach */
"0RN40ZZ" = "1" /* Release Cervicothoracic Vertebral Joint, Open Approach */
"0RN43ZZ" = "1" /* Release Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RN44ZZ" = "1" /* Release Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RN50ZZ" = "1" /* Release Cervicothoracic Vertebral Disc, Open Approach */
"0RN53ZZ" = "1" /* Release Cervicothoracic Vertebral Disc, Percutaneous Approach */
"0RN54ZZ" = "1" /* Release Cervicothoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RN60ZZ" = "1" /* Release Thoracic Vertebral Joint, Open Approach */
"0RN63ZZ" = "1" /* Release Thoracic Vertebral Joint, Percutaneous Approach */
"0RN64ZZ" = "1" /* Release Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RN90ZZ" = "1" /* Release Thoracic Vertebral Disc, Open Approach */
"0RN93ZZ" = "1" /* Release Thoracic Vertebral Disc, Percutaneous Approach */
"0RN94ZZ" = "1" /* Release Thoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RNA0ZZ" = "1" /* Release Thoracolumbar Vertebral Joint, Open Approach */
"0RNA3ZZ" = "1" /* Release Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RNA4ZZ" = "1" /* Release Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RNB0ZZ" = "1" /* Release Thoracolumbar Vertebral Disc, Open Approach */
"0RNB3ZZ" = "1" /* Release Thoracolumbar Vertebral Disc, Percutaneous Approach */
"0RNB4ZZ" = "1" /* Release Thoracolumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0RNC0ZZ" = "1" /* Release Right Temporomandibular Joint, Open Approach */
"0RNC3ZZ" = "1" /* Release Right Temporomandibular Joint, Percutaneous Approach */
"0RNC4ZZ" = "1" /* Release Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RND0ZZ" = "1" /* Release Left Temporomandibular Joint, Open Approach */
"0RND3ZZ" = "1" /* Release Left Temporomandibular Joint, Percutaneous Approach */
"0RND4ZZ" = "1" /* Release Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RNE0ZZ" = "1" /* Release Right Sternoclavicular Joint, Open Approach */
"0RNE3ZZ" = "1" /* Release Right Sternoclavicular Joint, Percutaneous Approach */
"0RNE4ZZ" = "1" /* Release Right Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RNF0ZZ" = "1" /* Release Left Sternoclavicular Joint, Open Approach */
"0RNF3ZZ" = "1" /* Release Left Sternoclavicular Joint, Percutaneous Approach */
"0RNF4ZZ" = "1" /* Release Left Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RNG0ZZ" = "1" /* Release Right Acromioclavicular Joint, Open Approach */
"0RNG3ZZ" = "1" /* Release Right Acromioclavicular Joint, Percutaneous Approach */
"0RNG4ZZ" = "1" /* Release Right Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RNH0ZZ" = "1" /* Release Left Acromioclavicular Joint, Open Approach */
"0RNH3ZZ" = "1" /* Release Left Acromioclavicular Joint, Percutaneous Approach */
"0RNH4ZZ" = "1" /* Release Left Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RNJ0ZZ" = "1" /* Release Right Shoulder Joint, Open Approach */
"0RNJ3ZZ" = "1" /* Release Right Shoulder Joint, Percutaneous Approach */
"0RNJ4ZZ" = "1" /* Release Right Shoulder Joint, Percutaneous Endoscopic Approach */
"0RNK0ZZ" = "1" /* Release Left Shoulder Joint, Open Approach */
"0RNK3ZZ" = "1" /* Release Left Shoulder Joint, Percutaneous Approach */
"0RNK4ZZ" = "1" /* Release Left Shoulder Joint, Percutaneous Endoscopic Approach */
"0RNL0ZZ" = "1" /* Release Right Elbow Joint, Open Approach */
"0RNL3ZZ" = "1" /* Release Right Elbow Joint, Percutaneous Approach */
"0RNL4ZZ" = "1" /* Release Right Elbow Joint, Percutaneous Endoscopic Approach */
"0RNM0ZZ" = "1" /* Release Left Elbow Joint, Open Approach */
"0RNM3ZZ" = "1" /* Release Left Elbow Joint, Percutaneous Approach */
"0RNM4ZZ" = "1" /* Release Left Elbow Joint, Percutaneous Endoscopic Approach */
"0RNN0ZZ" = "1" /* Release Right Wrist Joint, Open Approach */
"0RNN3ZZ" = "1" /* Release Right Wrist Joint, Percutaneous Approach */
"0RNN4ZZ" = "1" /* Release Right Wrist Joint, Percutaneous Endoscopic Approach */
"0RNP0ZZ" = "1" /* Release Left Wrist Joint, Open Approach */
"0RNP3ZZ" = "1" /* Release Left Wrist Joint, Percutaneous Approach */
"0RNP4ZZ" = "1" /* Release Left Wrist Joint, Percutaneous Endoscopic Approach */
"0RNQ0ZZ" = "1" /* Release Right Carpal Joint, Open Approach */
"0RNQ3ZZ" = "1" /* Release Right Carpal Joint, Percutaneous Approach */
"0RNQ4ZZ" = "1" /* Release Right Carpal Joint, Percutaneous Endoscopic Approach */
"0RNR0ZZ" = "1" /* Release Left Carpal Joint, Open Approach */
"0RNR3ZZ" = "1" /* Release Left Carpal Joint, Percutaneous Approach */
"0RNR4ZZ" = "1" /* Release Left Carpal Joint, Percutaneous Endoscopic Approach */
"0RNS0ZZ" = "1" /* Release Right Metacarpocarpal Joint, Open Approach */
"0RNS3ZZ" = "1" /* Release Right Metacarpocarpal Joint, Percutaneous Approach */
"0RNS4ZZ" = "1" /* Release Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RNT0ZZ" = "1" /* Release Left Metacarpocarpal Joint, Open Approach */
"0RNT3ZZ" = "1" /* Release Left Metacarpocarpal Joint, Percutaneous Approach */
"0RNT4ZZ" = "1" /* Release Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RNU0ZZ" = "1" /* Release Right Metacarpophalangeal Joint, Open Approach */
"0RNU3ZZ" = "1" /* Release Right Metacarpophalangeal Joint, Percutaneous Approach */
"0RNU4ZZ" = "1" /* Release Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RNV0ZZ" = "1" /* Release Left Metacarpophalangeal Joint, Open Approach */
"0RNV3ZZ" = "1" /* Release Left Metacarpophalangeal Joint, Percutaneous Approach */
"0RNV4ZZ" = "1" /* Release Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RNW0ZZ" = "1" /* Release Right Finger Phalangeal Joint, Open Approach */
"0RNW3ZZ" = "1" /* Release Right Finger Phalangeal Joint, Percutaneous Approach */
"0RNW4ZZ" = "1" /* Release Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RNX0ZZ" = "1" /* Release Left Finger Phalangeal Joint, Open Approach */
"0RNX3ZZ" = "1" /* Release Left Finger Phalangeal Joint, Percutaneous Approach */
"0RNX4ZZ" = "1" /* Release Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RP000Z" = "1" /* Removal of Drainage Device from Occipital-cervical Joint, Open Approach */
"0RP003Z" = "1" /* Removal of Infusion Device from Occipital-cervical Joint, Open Approach */
"0RP004Z" = "1" /* Removal of Internal Fixation Device from Occipital-cervical Joint, Open Approach */
"0RP007Z" = "1" /* Removal of Autologous Tissue Substitute from Occipital-cervical Joint, Open Approach */
"0RP00AZ" = "1" /* Removal of Interbody Fusion Device from Occipital-cervical Joint, Open Approach */
"0RP00JZ" = "1" /* Removal of Synthetic Substitute from Occipital-cervical Joint, Open Approach */
"0RP00KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Occipital-cervical Joint, Open Approach */
"0RP034Z" = "1" /* Removal of Internal Fixation Device from Occipital-cervical Joint, Percutaneous Approach */
"0RP037Z" = "1" /* Removal of Autologous Tissue Substitute from Occipital-cervical Joint, Percutaneous Approach */
"0RP03AZ" = "1" /* Removal of Interbody Fusion Device from Occipital-cervical Joint, Percutaneous Approach */
"0RP03JZ" = "1" /* Removal of Synthetic Substitute from Occipital-cervical Joint, Percutaneous Approach */
"0RP03KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Occipital-cervical Joint, Percutaneous Approach */
"0RP040Z" = "1" /* Removal of Drainage Device from Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RP043Z" = "1" /* Removal of Infusion Device from Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RP044Z" = "1" /* Removal of Internal Fixation Device from Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RP047Z" = "1" /* Removal of Autologous Tissue Substitute from Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RP04AZ" = "1" /* Removal of Interbody Fusion Device from Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RP04JZ" = "1" /* Removal of Synthetic Substitute from Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RP04KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RP100Z" = "1" /* Removal of Drainage Device from Cervical Vertebral Joint, Open Approach */
"0RP103Z" = "1" /* Removal of Infusion Device from Cervical Vertebral Joint, Open Approach */
"0RP104Z" = "1" /* Removal of Internal Fixation Device from Cervical Vertebral Joint, Open Approach */
"0RP107Z" = "1" /* Removal of Autologous Tissue Substitute from Cervical Vertebral Joint, Open Approach */
"0RP10AZ" = "1" /* Removal of Interbody Fusion Device from Cervical Vertebral Joint, Open Approach */
"0RP10JZ" = "1" /* Removal of Synthetic Substitute from Cervical Vertebral Joint, Open Approach */
"0RP10KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Cervical Vertebral Joint, Open Approach */
"0RP134Z" = "1" /* Removal of Internal Fixation Device from Cervical Vertebral Joint, Percutaneous Approach */
"0RP137Z" = "1" /* Removal of Autologous Tissue Substitute from Cervical Vertebral Joint, Percutaneous Approach */
"0RP13AZ" = "1" /* Removal of Interbody Fusion Device from Cervical Vertebral Joint, Percutaneous Approach */
"0RP13JZ" = "1" /* Removal of Synthetic Substitute from Cervical Vertebral Joint, Percutaneous Approach */
"0RP13KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Cervical Vertebral Joint, Percutaneous Approach */
"0RP140Z" = "1" /* Removal of Drainage Device from Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP143Z" = "1" /* Removal of Infusion Device from Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP144Z" = "1" /* Removal of Internal Fixation Device from Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP147Z" = "1" /* Removal of Autologous Tissue Substitute from Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP14AZ" = "1" /* Removal of Interbody Fusion Device from Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP14JZ" = "1" /* Removal of Synthetic Substitute from Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP14KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP300Z" = "1" /* Removal of Drainage Device from Cervical Vertebral Disc, Open Approach */
"0RP303Z" = "1" /* Removal of Infusion Device from Cervical Vertebral Disc, Open Approach */
"0RP307Z" = "1" /* Removal of Autologous Tissue Substitute from Cervical Vertebral Disc, Open Approach */
"0RP30JZ" = "1" /* Removal of Synthetic Substitute from Cervical Vertebral Disc, Open Approach */
"0RP30KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Cervical Vertebral Disc, Open Approach */
"0RP337Z" = "1" /* Removal of Autologous Tissue Substitute from Cervical Vertebral Disc, Percutaneous Approach */
"0RP33JZ" = "1" /* Removal of Synthetic Substitute from Cervical Vertebral Disc, Percutaneous Approach */
"0RP33KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Cervical Vertebral Disc, Percutaneous Approach */
"0RP340Z" = "1" /* Removal of Drainage Device from Cervical Vertebral Disc, Percutaneous Endoscopic Approach */
"0RP343Z" = "1" /* Removal of Infusion Device from Cervical Vertebral Disc, Percutaneous Endoscopic Approach */
"0RP347Z" = "1" /* Removal of Autologous Tissue Substitute from Cervical Vertebral Disc, Percutaneous Endoscopic Approach */
"0RP34JZ" = "1" /* Removal of Synthetic Substitute from Cervical Vertebral Disc, Percutaneous Endoscopic Approach */
"0RP34KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Cervical Vertebral Disc, Percutaneous Endoscopic Approach */
"0RP400Z" = "1" /* Removal of Drainage Device from Cervicothoracic Vertebral Joint, Open Approach */
"0RP403Z" = "1" /* Removal of Infusion Device from Cervicothoracic Vertebral Joint, Open Approach */
"0RP404Z" = "1" /* Removal of Internal Fixation Device from Cervicothoracic Vertebral Joint, Open Approach */
"0RP407Z" = "1" /* Removal of Autologous Tissue Substitute from Cervicothoracic Vertebral Joint, Open Approach */
"0RP40AZ" = "1" /* Removal of Interbody Fusion Device from Cervicothoracic Vertebral Joint, Open Approach */
"0RP40JZ" = "1" /* Removal of Synthetic Substitute from Cervicothoracic Vertebral Joint, Open Approach */
"0RP40KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Cervicothoracic Vertebral Joint, Open Approach */
"0RP434Z" = "1" /* Removal of Internal Fixation Device from Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RP437Z" = "1" /* Removal of Autologous Tissue Substitute from Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RP43AZ" = "1" /* Removal of Interbody Fusion Device from Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RP43JZ" = "1" /* Removal of Synthetic Substitute from Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RP43KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RP440Z" = "1" /* Removal of Drainage Device from Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP443Z" = "1" /* Removal of Infusion Device from Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP444Z" = "1" /* Removal of Internal Fixation Device from Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP447Z" = "1" /* Removal of Autologous Tissue Substitute from Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP44AZ" = "1" /* Removal of Interbody Fusion Device from Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP44JZ" = "1" /* Removal of Synthetic Substitute from Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP44KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP500Z" = "1" /* Removal of Drainage Device from Cervicothoracic Vertebral Disc, Open Approach */
"0RP503Z" = "1" /* Removal of Infusion Device from Cervicothoracic Vertebral Disc, Open Approach */
"0RP507Z" = "1" /* Removal of Autologous Tissue Substitute from Cervicothoracic Vertebral Disc, Open Approach */
"0RP50JZ" = "1" /* Removal of Synthetic Substitute from Cervicothoracic Vertebral Disc, Open Approach */
"0RP50KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Cervicothoracic Vertebral Disc, Open Approach */
"0RP537Z" = "1" /* Removal of Autologous Tissue Substitute from Cervicothoracic Vertebral Disc, Percutaneous Approach */
"0RP53JZ" = "1" /* Removal of Synthetic Substitute from Cervicothoracic Vertebral Disc, Percutaneous Approach */
"0RP53KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Cervicothoracic Vertebral Disc, Percutaneous Approach */
"0RP540Z" = "1" /* Removal of Drainage Device from Cervicothoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RP543Z" = "1" /* Removal of Infusion Device from Cervicothoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RP547Z" = "1" /* Removal of Autologous Tissue Substitute from Cervicothoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RP54JZ" = "1" /* Removal of Synthetic Substitute from Cervicothoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RP54KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Cervicothoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RP600Z" = "1" /* Removal of Drainage Device from Thoracic Vertebral Joint, Open Approach */
"0RP603Z" = "1" /* Removal of Infusion Device from Thoracic Vertebral Joint, Open Approach */
"0RP604Z" = "1" /* Removal of Internal Fixation Device from Thoracic Vertebral Joint, Open Approach */
"0RP607Z" = "1" /* Removal of Autologous Tissue Substitute from Thoracic Vertebral Joint, Open Approach */
"0RP60AZ" = "1" /* Removal of Interbody Fusion Device from Thoracic Vertebral Joint, Open Approach */
"0RP60JZ" = "1" /* Removal of Synthetic Substitute from Thoracic Vertebral Joint, Open Approach */
"0RP60KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Thoracic Vertebral Joint, Open Approach */
"0RP634Z" = "1" /* Removal of Internal Fixation Device from Thoracic Vertebral Joint, Percutaneous Approach */
"0RP637Z" = "1" /* Removal of Autologous Tissue Substitute from Thoracic Vertebral Joint, Percutaneous Approach */
"0RP63AZ" = "1" /* Removal of Interbody Fusion Device from Thoracic Vertebral Joint, Percutaneous Approach */
"0RP63JZ" = "1" /* Removal of Synthetic Substitute from Thoracic Vertebral Joint, Percutaneous Approach */
"0RP63KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Thoracic Vertebral Joint, Percutaneous Approach */
"0RP640Z" = "1" /* Removal of Drainage Device from Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP643Z" = "1" /* Removal of Infusion Device from Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP644Z" = "1" /* Removal of Internal Fixation Device from Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP647Z" = "1" /* Removal of Autologous Tissue Substitute from Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP64AZ" = "1" /* Removal of Interbody Fusion Device from Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP64JZ" = "1" /* Removal of Synthetic Substitute from Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP64KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RP900Z" = "1" /* Removal of Drainage Device from Thoracic Vertebral Disc, Open Approach */
"0RP903Z" = "1" /* Removal of Infusion Device from Thoracic Vertebral Disc, Open Approach */
"0RP907Z" = "1" /* Removal of Autologous Tissue Substitute from Thoracic Vertebral Disc, Open Approach */
"0RP90JZ" = "1" /* Removal of Synthetic Substitute from Thoracic Vertebral Disc, Open Approach */
"0RP90KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Thoracic Vertebral Disc, Open Approach */
"0RP937Z" = "1" /* Removal of Autologous Tissue Substitute from Thoracic Vertebral Disc, Percutaneous Approach */
"0RP93JZ" = "1" /* Removal of Synthetic Substitute from Thoracic Vertebral Disc, Percutaneous Approach */
"0RP93KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Thoracic Vertebral Disc, Percutaneous Approach */
"0RP940Z" = "1" /* Removal of Drainage Device from Thoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RP943Z" = "1" /* Removal of Infusion Device from Thoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RP947Z" = "1" /* Removal of Autologous Tissue Substitute from Thoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RP94JZ" = "1" /* Removal of Synthetic Substitute from Thoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RP94KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Thoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RPA00Z" = "1" /* Removal of Drainage Device from Thoracolumbar Vertebral Joint, Open Approach */
"0RPA03Z" = "1" /* Removal of Infusion Device from Thoracolumbar Vertebral Joint, Open Approach */
"0RPA04Z" = "1" /* Removal of Internal Fixation Device from Thoracolumbar Vertebral Joint, Open Approach */
"0RPA07Z" = "1" /* Removal of Autologous Tissue Substitute from Thoracolumbar Vertebral Joint, Open Approach */
"0RPA0AZ" = "1" /* Removal of Interbody Fusion Device from Thoracolumbar Vertebral Joint, Open Approach */
"0RPA0JZ" = "1" /* Removal of Synthetic Substitute from Thoracolumbar Vertebral Joint, Open Approach */
"0RPA0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Thoracolumbar Vertebral Joint, Open Approach */
"0RPA34Z" = "1" /* Removal of Internal Fixation Device from Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RPA37Z" = "1" /* Removal of Autologous Tissue Substitute from Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RPA3AZ" = "1" /* Removal of Interbody Fusion Device from Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RPA3JZ" = "1" /* Removal of Synthetic Substitute from Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RPA3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RPA40Z" = "1" /* Removal of Drainage Device from Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RPA43Z" = "1" /* Removal of Infusion Device from Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RPA44Z" = "1" /* Removal of Internal Fixation Device from Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RPA47Z" = "1" /* Removal of Autologous Tissue Substitute from Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RPA4AZ" = "1" /* Removal of Interbody Fusion Device from Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RPA4JZ" = "1" /* Removal of Synthetic Substitute from Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RPA4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RPB00Z" = "1" /* Removal of Drainage Device from Thoracolumbar Vertebral Disc, Open Approach */
"0RPB03Z" = "1" /* Removal of Infusion Device from Thoracolumbar Vertebral Disc, Open Approach */
"0RPB07Z" = "1" /* Removal of Autologous Tissue Substitute from Thoracolumbar Vertebral Disc, Open Approach */
"0RPB0JZ" = "1" /* Removal of Synthetic Substitute from Thoracolumbar Vertebral Disc, Open Approach */
"0RPB0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Thoracolumbar Vertebral Disc, Open Approach */
"0RPB37Z" = "1" /* Removal of Autologous Tissue Substitute from Thoracolumbar Vertebral Disc, Percutaneous Approach */
"0RPB3JZ" = "1" /* Removal of Synthetic Substitute from Thoracolumbar Vertebral Disc, Percutaneous Approach */
"0RPB3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Thoracolumbar Vertebral Disc, Percutaneous Approach */
"0RPB40Z" = "1" /* Removal of Drainage Device from Thoracolumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0RPB43Z" = "1" /* Removal of Infusion Device from Thoracolumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0RPB47Z" = "1" /* Removal of Autologous Tissue Substitute from Thoracolumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0RPB4JZ" = "1" /* Removal of Synthetic Substitute from Thoracolumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0RPB4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Thoracolumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0RPC00Z" = "1" /* Removal of Drainage Device from Right Temporomandibular Joint, Open Approach */
"0RPC03Z" = "1" /* Removal of Infusion Device from Right Temporomandibular Joint, Open Approach */
"0RPC04Z" = "1" /* Removal of Internal Fixation Device from Right Temporomandibular Joint, Open Approach */
"0RPC07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Temporomandibular Joint, Open Approach */
"0RPC0JZ" = "1" /* Removal of Synthetic Substitute from Right Temporomandibular Joint, Open Approach */
"0RPC0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Temporomandibular Joint, Open Approach */
"0RPC34Z" = "1" /* Removal of Internal Fixation Device from Right Temporomandibular Joint, Percutaneous Approach */
"0RPC37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Temporomandibular Joint, Percutaneous Approach */
"0RPC3JZ" = "1" /* Removal of Synthetic Substitute from Right Temporomandibular Joint, Percutaneous Approach */
"0RPC3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Temporomandibular Joint, Percutaneous Approach */
"0RPC40Z" = "1" /* Removal of Drainage Device from Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RPC43Z" = "1" /* Removal of Infusion Device from Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RPC44Z" = "1" /* Removal of Internal Fixation Device from Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RPC47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RPC4JZ" = "1" /* Removal of Synthetic Substitute from Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RPC4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RPCX4Z" = "1" /* Removal of Internal Fixation Device from Right Temporomandibular Joint, External Approach */
"0RPD00Z" = "1" /* Removal of Drainage Device from Left Temporomandibular Joint, Open Approach */
"0RPD03Z" = "1" /* Removal of Infusion Device from Left Temporomandibular Joint, Open Approach */
"0RPD04Z" = "1" /* Removal of Internal Fixation Device from Left Temporomandibular Joint, Open Approach */
"0RPD07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Temporomandibular Joint, Open Approach */
"0RPD0JZ" = "1" /* Removal of Synthetic Substitute from Left Temporomandibular Joint, Open Approach */
"0RPD0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Temporomandibular Joint, Open Approach */
"0RPD34Z" = "1" /* Removal of Internal Fixation Device from Left Temporomandibular Joint, Percutaneous Approach */
"0RPD37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Temporomandibular Joint, Percutaneous Approach */
"0RPD3JZ" = "1" /* Removal of Synthetic Substitute from Left Temporomandibular Joint, Percutaneous Approach */
"0RPD3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Temporomandibular Joint, Percutaneous Approach */
"0RPD40Z" = "1" /* Removal of Drainage Device from Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RPD43Z" = "1" /* Removal of Infusion Device from Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RPD44Z" = "1" /* Removal of Internal Fixation Device from Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RPD47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RPD4JZ" = "1" /* Removal of Synthetic Substitute from Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RPD4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RPDX4Z" = "1" /* Removal of Internal Fixation Device from Left Temporomandibular Joint, External Approach */
"0RPE00Z" = "1" /* Removal of Drainage Device from Right Sternoclavicular Joint, Open Approach */
"0RPE03Z" = "1" /* Removal of Infusion Device from Right Sternoclavicular Joint, Open Approach */
"0RPE04Z" = "1" /* Removal of Internal Fixation Device from Right Sternoclavicular Joint, Open Approach */
"0RPE07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Sternoclavicular Joint, Open Approach */
"0RPE0JZ" = "1" /* Removal of Synthetic Substitute from Right Sternoclavicular Joint, Open Approach */
"0RPE0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Sternoclavicular Joint, Open Approach */
"0RPE34Z" = "1" /* Removal of Internal Fixation Device from Right Sternoclavicular Joint, Percutaneous Approach */
"0RPE37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Sternoclavicular Joint, Percutaneous Approach */
"0RPE3JZ" = "1" /* Removal of Synthetic Substitute from Right Sternoclavicular Joint, Percutaneous Approach */
"0RPE3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Sternoclavicular Joint, Percutaneous Approach */
"0RPE40Z" = "1" /* Removal of Drainage Device from Right Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RPE43Z" = "1" /* Removal of Infusion Device from Right Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RPE44Z" = "1" /* Removal of Internal Fixation Device from Right Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RPE47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RPE4JZ" = "1" /* Removal of Synthetic Substitute from Right Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RPE4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RPF00Z" = "1" /* Removal of Drainage Device from Left Sternoclavicular Joint, Open Approach */
"0RPF03Z" = "1" /* Removal of Infusion Device from Left Sternoclavicular Joint, Open Approach */
"0RPF04Z" = "1" /* Removal of Internal Fixation Device from Left Sternoclavicular Joint, Open Approach */
"0RPF07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Sternoclavicular Joint, Open Approach */
"0RPF0JZ" = "1" /* Removal of Synthetic Substitute from Left Sternoclavicular Joint, Open Approach */
"0RPF0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Sternoclavicular Joint, Open Approach */
"0RPF34Z" = "1" /* Removal of Internal Fixation Device from Left Sternoclavicular Joint, Percutaneous Approach */
"0RPF37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Sternoclavicular Joint, Percutaneous Approach */
"0RPF3JZ" = "1" /* Removal of Synthetic Substitute from Left Sternoclavicular Joint, Percutaneous Approach */
"0RPF3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Sternoclavicular Joint, Percutaneous Approach */
"0RPF40Z" = "1" /* Removal of Drainage Device from Left Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RPF43Z" = "1" /* Removal of Infusion Device from Left Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RPF44Z" = "1" /* Removal of Internal Fixation Device from Left Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RPF47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RPF4JZ" = "1" /* Removal of Synthetic Substitute from Left Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RPF4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RPG00Z" = "1" /* Removal of Drainage Device from Right Acromioclavicular Joint, Open Approach */
"0RPG03Z" = "1" /* Removal of Infusion Device from Right Acromioclavicular Joint, Open Approach */
"0RPG04Z" = "1" /* Removal of Internal Fixation Device from Right Acromioclavicular Joint, Open Approach */
"0RPG07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Acromioclavicular Joint, Open Approach */
"0RPG0JZ" = "1" /* Removal of Synthetic Substitute from Right Acromioclavicular Joint, Open Approach */
"0RPG0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Acromioclavicular Joint, Open Approach */
"0RPG34Z" = "1" /* Removal of Internal Fixation Device from Right Acromioclavicular Joint, Percutaneous Approach */
"0RPG37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Acromioclavicular Joint, Percutaneous Approach */
"0RPG3JZ" = "1" /* Removal of Synthetic Substitute from Right Acromioclavicular Joint, Percutaneous Approach */
"0RPG3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Acromioclavicular Joint, Percutaneous Approach */
"0RPG40Z" = "1" /* Removal of Drainage Device from Right Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RPG43Z" = "1" /* Removal of Infusion Device from Right Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RPG44Z" = "1" /* Removal of Internal Fixation Device from Right Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RPG47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RPG4JZ" = "1" /* Removal of Synthetic Substitute from Right Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RPG4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RPH00Z" = "1" /* Removal of Drainage Device from Left Acromioclavicular Joint, Open Approach */
"0RPH03Z" = "1" /* Removal of Infusion Device from Left Acromioclavicular Joint, Open Approach */
"0RPH04Z" = "1" /* Removal of Internal Fixation Device from Left Acromioclavicular Joint, Open Approach */
"0RPH07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Acromioclavicular Joint, Open Approach */
"0RPH0JZ" = "1" /* Removal of Synthetic Substitute from Left Acromioclavicular Joint, Open Approach */
"0RPH0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Acromioclavicular Joint, Open Approach */
"0RPH34Z" = "1" /* Removal of Internal Fixation Device from Left Acromioclavicular Joint, Percutaneous Approach */
"0RPH37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Acromioclavicular Joint, Percutaneous Approach */
"0RPH3JZ" = "1" /* Removal of Synthetic Substitute from Left Acromioclavicular Joint, Percutaneous Approach */
"0RPH3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Acromioclavicular Joint, Percutaneous Approach */
"0RPH40Z" = "1" /* Removal of Drainage Device from Left Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RPH43Z" = "1" /* Removal of Infusion Device from Left Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RPH44Z" = "1" /* Removal of Internal Fixation Device from Left Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RPH47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RPH4JZ" = "1" /* Removal of Synthetic Substitute from Left Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RPH4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RPJ00Z" = "1" /* Removal of Drainage Device from Right Shoulder Joint, Open Approach */
"0RPJ03Z" = "1" /* Removal of Infusion Device from Right Shoulder Joint, Open Approach */
"0RPJ04Z" = "1" /* Removal of Internal Fixation Device from Right Shoulder Joint, Open Approach */
"0RPJ07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Shoulder Joint, Open Approach */
"0RPJ0JZ" = "1" /* Removal of Synthetic Substitute from Right Shoulder Joint, Open Approach */
"0RPJ0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Shoulder Joint, Open Approach */
"0RPJ34Z" = "1" /* Removal of Internal Fixation Device from Right Shoulder Joint, Percutaneous Approach */
"0RPJ37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Shoulder Joint, Percutaneous Approach */
"0RPJ3JZ" = "1" /* Removal of Synthetic Substitute from Right Shoulder Joint, Percutaneous Approach */
"0RPJ3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Shoulder Joint, Percutaneous Approach */
"0RPJ40Z" = "1" /* Removal of Drainage Device from Right Shoulder Joint, Percutaneous Endoscopic Approach */
"0RPJ43Z" = "1" /* Removal of Infusion Device from Right Shoulder Joint, Percutaneous Endoscopic Approach */
"0RPJ44Z" = "1" /* Removal of Internal Fixation Device from Right Shoulder Joint, Percutaneous Endoscopic Approach */
"0RPJ47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Shoulder Joint, Percutaneous Endoscopic Approach */
"0RPJ4JZ" = "1" /* Removal of Synthetic Substitute from Right Shoulder Joint, Percutaneous Endoscopic Approach */
"0RPJ4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Shoulder Joint, Percutaneous Endoscopic Approach */
"0RPK00Z" = "1" /* Removal of Drainage Device from Left Shoulder Joint, Open Approach */
"0RPK03Z" = "1" /* Removal of Infusion Device from Left Shoulder Joint, Open Approach */
"0RPK04Z" = "1" /* Removal of Internal Fixation Device from Left Shoulder Joint, Open Approach */
"0RPK07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Shoulder Joint, Open Approach */
"0RPK0JZ" = "1" /* Removal of Synthetic Substitute from Left Shoulder Joint, Open Approach */
"0RPK0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Shoulder Joint, Open Approach */
"0RPK34Z" = "1" /* Removal of Internal Fixation Device from Left Shoulder Joint, Percutaneous Approach */
"0RPK37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Shoulder Joint, Percutaneous Approach */
"0RPK3JZ" = "1" /* Removal of Synthetic Substitute from Left Shoulder Joint, Percutaneous Approach */
"0RPK3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Shoulder Joint, Percutaneous Approach */
"0RPK40Z" = "1" /* Removal of Drainage Device from Left Shoulder Joint, Percutaneous Endoscopic Approach */
"0RPK43Z" = "1" /* Removal of Infusion Device from Left Shoulder Joint, Percutaneous Endoscopic Approach */
"0RPK44Z" = "1" /* Removal of Internal Fixation Device from Left Shoulder Joint, Percutaneous Endoscopic Approach */
"0RPK47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Shoulder Joint, Percutaneous Endoscopic Approach */
"0RPK4JZ" = "1" /* Removal of Synthetic Substitute from Left Shoulder Joint, Percutaneous Endoscopic Approach */
"0RPK4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Shoulder Joint, Percutaneous Endoscopic Approach */
"0RPL00Z" = "1" /* Removal of Drainage Device from Right Elbow Joint, Open Approach */
"0RPL03Z" = "1" /* Removal of Infusion Device from Right Elbow Joint, Open Approach */
"0RPL04Z" = "1" /* Removal of Internal Fixation Device from Right Elbow Joint, Open Approach */
"0RPL05Z" = "1" /* Removal of External Fixation Device from Right Elbow Joint, Open Approach */
"0RPL07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Elbow Joint, Open Approach */
"0RPL0JZ" = "1" /* Removal of Synthetic Substitute from Right Elbow Joint, Open Approach */
"0RPL0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Elbow Joint, Open Approach */
"0RPL34Z" = "1" /* Removal of Internal Fixation Device from Right Elbow Joint, Percutaneous Approach */
"0RPL35Z" = "1" /* Removal of External Fixation Device from Right Elbow Joint, Percutaneous Approach */
"0RPL37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Elbow Joint, Percutaneous Approach */
"0RPL3JZ" = "1" /* Removal of Synthetic Substitute from Right Elbow Joint, Percutaneous Approach */
"0RPL3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Elbow Joint, Percutaneous Approach */
"0RPL40Z" = "1" /* Removal of Drainage Device from Right Elbow Joint, Percutaneous Endoscopic Approach */
"0RPL43Z" = "1" /* Removal of Infusion Device from Right Elbow Joint, Percutaneous Endoscopic Approach */
"0RPL44Z" = "1" /* Removal of Internal Fixation Device from Right Elbow Joint, Percutaneous Endoscopic Approach */
"0RPL45Z" = "1" /* Removal of External Fixation Device from Right Elbow Joint, Percutaneous Endoscopic Approach */
"0RPL47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Elbow Joint, Percutaneous Endoscopic Approach */
"0RPL4JZ" = "1" /* Removal of Synthetic Substitute from Right Elbow Joint, Percutaneous Endoscopic Approach */
"0RPL4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Elbow Joint, Percutaneous Endoscopic Approach */
"0RPM00Z" = "1" /* Removal of Drainage Device from Left Elbow Joint, Open Approach */
"0RPM03Z" = "1" /* Removal of Infusion Device from Left Elbow Joint, Open Approach */
"0RPM04Z" = "1" /* Removal of Internal Fixation Device from Left Elbow Joint, Open Approach */
"0RPM05Z" = "1" /* Removal of External Fixation Device from Left Elbow Joint, Open Approach */
"0RPM07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Elbow Joint, Open Approach */
"0RPM0JZ" = "1" /* Removal of Synthetic Substitute from Left Elbow Joint, Open Approach */
"0RPM0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Elbow Joint, Open Approach */
"0RPM34Z" = "1" /* Removal of Internal Fixation Device from Left Elbow Joint, Percutaneous Approach */
"0RPM35Z" = "1" /* Removal of External Fixation Device from Left Elbow Joint, Percutaneous Approach */
"0RPM37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Elbow Joint, Percutaneous Approach */
"0RPM3JZ" = "1" /* Removal of Synthetic Substitute from Left Elbow Joint, Percutaneous Approach */
"0RPM3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Elbow Joint, Percutaneous Approach */
"0RPM40Z" = "1" /* Removal of Drainage Device from Left Elbow Joint, Percutaneous Endoscopic Approach */
"0RPM43Z" = "1" /* Removal of Infusion Device from Left Elbow Joint, Percutaneous Endoscopic Approach */
"0RPM44Z" = "1" /* Removal of Internal Fixation Device from Left Elbow Joint, Percutaneous Endoscopic Approach */
"0RPM45Z" = "1" /* Removal of External Fixation Device from Left Elbow Joint, Percutaneous Endoscopic Approach */
"0RPM47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Elbow Joint, Percutaneous Endoscopic Approach */
"0RPM4JZ" = "1" /* Removal of Synthetic Substitute from Left Elbow Joint, Percutaneous Endoscopic Approach */
"0RPM4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Elbow Joint, Percutaneous Endoscopic Approach */
"0RPN00Z" = "1" /* Removal of Drainage Device from Right Wrist Joint, Open Approach */
"0RPN03Z" = "1" /* Removal of Infusion Device from Right Wrist Joint, Open Approach */
"0RPN04Z" = "1" /* Removal of Internal Fixation Device from Right Wrist Joint, Open Approach */
"0RPN05Z" = "1" /* Removal of External Fixation Device from Right Wrist Joint, Open Approach */
"0RPN07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Wrist Joint, Open Approach */
"0RPN0JZ" = "1" /* Removal of Synthetic Substitute from Right Wrist Joint, Open Approach */
"0RPN0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Wrist Joint, Open Approach */
"0RPN34Z" = "1" /* Removal of Internal Fixation Device from Right Wrist Joint, Percutaneous Approach */
"0RPN35Z" = "1" /* Removal of External Fixation Device from Right Wrist Joint, Percutaneous Approach */
"0RPN37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Wrist Joint, Percutaneous Approach */
"0RPN3JZ" = "1" /* Removal of Synthetic Substitute from Right Wrist Joint, Percutaneous Approach */
"0RPN3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Wrist Joint, Percutaneous Approach */
"0RPN40Z" = "1" /* Removal of Drainage Device from Right Wrist Joint, Percutaneous Endoscopic Approach */
"0RPN43Z" = "1" /* Removal of Infusion Device from Right Wrist Joint, Percutaneous Endoscopic Approach */
"0RPN44Z" = "1" /* Removal of Internal Fixation Device from Right Wrist Joint, Percutaneous Endoscopic Approach */
"0RPN45Z" = "1" /* Removal of External Fixation Device from Right Wrist Joint, Percutaneous Endoscopic Approach */
"0RPN47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Wrist Joint, Percutaneous Endoscopic Approach */
"0RPN4JZ" = "1" /* Removal of Synthetic Substitute from Right Wrist Joint, Percutaneous Endoscopic Approach */
"0RPN4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Wrist Joint, Percutaneous Endoscopic Approach */
"0RPP00Z" = "1" /* Removal of Drainage Device from Left Wrist Joint, Open Approach */
"0RPP03Z" = "1" /* Removal of Infusion Device from Left Wrist Joint, Open Approach */
"0RPP04Z" = "1" /* Removal of Internal Fixation Device from Left Wrist Joint, Open Approach */
"0RPP05Z" = "1" /* Removal of External Fixation Device from Left Wrist Joint, Open Approach */
"0RPP07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Wrist Joint, Open Approach */
"0RPP0JZ" = "1" /* Removal of Synthetic Substitute from Left Wrist Joint, Open Approach */
"0RPP0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Wrist Joint, Open Approach */
"0RPP34Z" = "1" /* Removal of Internal Fixation Device from Left Wrist Joint, Percutaneous Approach */
"0RPP35Z" = "1" /* Removal of External Fixation Device from Left Wrist Joint, Percutaneous Approach */
"0RPP37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Wrist Joint, Percutaneous Approach */
"0RPP3JZ" = "1" /* Removal of Synthetic Substitute from Left Wrist Joint, Percutaneous Approach */
"0RPP3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Wrist Joint, Percutaneous Approach */
"0RPP40Z" = "1" /* Removal of Drainage Device from Left Wrist Joint, Percutaneous Endoscopic Approach */
"0RPP43Z" = "1" /* Removal of Infusion Device from Left Wrist Joint, Percutaneous Endoscopic Approach */
"0RPP44Z" = "1" /* Removal of Internal Fixation Device from Left Wrist Joint, Percutaneous Endoscopic Approach */
"0RPP45Z" = "1" /* Removal of External Fixation Device from Left Wrist Joint, Percutaneous Endoscopic Approach */
"0RPP47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Wrist Joint, Percutaneous Endoscopic Approach */
"0RPP4JZ" = "1" /* Removal of Synthetic Substitute from Left Wrist Joint, Percutaneous Endoscopic Approach */
"0RPP4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Wrist Joint, Percutaneous Endoscopic Approach */
"0RPQ00Z" = "1" /* Removal of Drainage Device from Right Carpal Joint, Open Approach */
"0RPQ03Z" = "1" /* Removal of Infusion Device from Right Carpal Joint, Open Approach */
"0RPQ04Z" = "1" /* Removal of Internal Fixation Device from Right Carpal Joint, Open Approach */
"0RPQ05Z" = "1" /* Removal of External Fixation Device from Right Carpal Joint, Open Approach */
"0RPQ07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Carpal Joint, Open Approach */
"0RPQ0JZ" = "1" /* Removal of Synthetic Substitute from Right Carpal Joint, Open Approach */
"0RPQ0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Carpal Joint, Open Approach */
"0RPQ34Z" = "1" /* Removal of Internal Fixation Device from Right Carpal Joint, Percutaneous Approach */
"0RPQ35Z" = "1" /* Removal of External Fixation Device from Right Carpal Joint, Percutaneous Approach */
"0RPQ37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Carpal Joint, Percutaneous Approach */
"0RPQ3JZ" = "1" /* Removal of Synthetic Substitute from Right Carpal Joint, Percutaneous Approach */
"0RPQ3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Carpal Joint, Percutaneous Approach */
"0RPQ40Z" = "1" /* Removal of Drainage Device from Right Carpal Joint, Percutaneous Endoscopic Approach */
"0RPQ43Z" = "1" /* Removal of Infusion Device from Right Carpal Joint, Percutaneous Endoscopic Approach */
"0RPQ44Z" = "1" /* Removal of Internal Fixation Device from Right Carpal Joint, Percutaneous Endoscopic Approach */
"0RPQ45Z" = "1" /* Removal of External Fixation Device from Right Carpal Joint, Percutaneous Endoscopic Approach */
"0RPQ47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Carpal Joint, Percutaneous Endoscopic Approach */
"0RPQ4JZ" = "1" /* Removal of Synthetic Substitute from Right Carpal Joint, Percutaneous Endoscopic Approach */
"0RPQ4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Carpal Joint, Percutaneous Endoscopic Approach */
"0RPR00Z" = "1" /* Removal of Drainage Device from Left Carpal Joint, Open Approach */
"0RPR03Z" = "1" /* Removal of Infusion Device from Left Carpal Joint, Open Approach */
"0RPR04Z" = "1" /* Removal of Internal Fixation Device from Left Carpal Joint, Open Approach */
"0RPR05Z" = "1" /* Removal of External Fixation Device from Left Carpal Joint, Open Approach */
"0RPR07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Carpal Joint, Open Approach */
"0RPR0JZ" = "1" /* Removal of Synthetic Substitute from Left Carpal Joint, Open Approach */
"0RPR0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Carpal Joint, Open Approach */
"0RPR34Z" = "1" /* Removal of Internal Fixation Device from Left Carpal Joint, Percutaneous Approach */
"0RPR35Z" = "1" /* Removal of External Fixation Device from Left Carpal Joint, Percutaneous Approach */
"0RPR37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Carpal Joint, Percutaneous Approach */
"0RPR3JZ" = "1" /* Removal of Synthetic Substitute from Left Carpal Joint, Percutaneous Approach */
"0RPR3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Carpal Joint, Percutaneous Approach */
"0RPR40Z" = "1" /* Removal of Drainage Device from Left Carpal Joint, Percutaneous Endoscopic Approach */
"0RPR43Z" = "1" /* Removal of Infusion Device from Left Carpal Joint, Percutaneous Endoscopic Approach */
"0RPR44Z" = "1" /* Removal of Internal Fixation Device from Left Carpal Joint, Percutaneous Endoscopic Approach */
"0RPR45Z" = "1" /* Removal of External Fixation Device from Left Carpal Joint, Percutaneous Endoscopic Approach */
"0RPR47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Carpal Joint, Percutaneous Endoscopic Approach */
"0RPR4JZ" = "1" /* Removal of Synthetic Substitute from Left Carpal Joint, Percutaneous Endoscopic Approach */
"0RPR4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Carpal Joint, Percutaneous Endoscopic Approach */
"0RPS00Z" = "1" /* Removal of Drainage Device from Right Metacarpocarpal Joint, Open Approach */
"0RPS03Z" = "1" /* Removal of Infusion Device from Right Metacarpocarpal Joint, Open Approach */
"0RPS04Z" = "1" /* Removal of Internal Fixation Device from Right Metacarpocarpal Joint, Open Approach */
"0RPS05Z" = "1" /* Removal of External Fixation Device from Right Metacarpocarpal Joint, Open Approach */
"0RPS07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Metacarpocarpal Joint, Open Approach */
"0RPS0JZ" = "1" /* Removal of Synthetic Substitute from Right Metacarpocarpal Joint, Open Approach */
"0RPS0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Metacarpocarpal Joint, Open Approach */
"0RPS34Z" = "1" /* Removal of Internal Fixation Device from Right Metacarpocarpal Joint, Percutaneous Approach */
"0RPS35Z" = "1" /* Removal of External Fixation Device from Right Metacarpocarpal Joint, Percutaneous Approach */
"0RPS37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Metacarpocarpal Joint, Percutaneous Approach */
"0RPS3JZ" = "1" /* Removal of Synthetic Substitute from Right Metacarpocarpal Joint, Percutaneous Approach */
"0RPS3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Metacarpocarpal Joint, Percutaneous Approach */
"0RPS40Z" = "1" /* Removal of Drainage Device from Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RPS43Z" = "1" /* Removal of Infusion Device from Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RPS44Z" = "1" /* Removal of Internal Fixation Device from Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RPS45Z" = "1" /* Removal of External Fixation Device from Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RPS47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RPS4JZ" = "1" /* Removal of Synthetic Substitute from Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RPS4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RPT00Z" = "1" /* Removal of Drainage Device from Left Metacarpocarpal Joint, Open Approach */
"0RPT03Z" = "1" /* Removal of Infusion Device from Left Metacarpocarpal Joint, Open Approach */
"0RPT04Z" = "1" /* Removal of Internal Fixation Device from Left Metacarpocarpal Joint, Open Approach */
"0RPT05Z" = "1" /* Removal of External Fixation Device from Left Metacarpocarpal Joint, Open Approach */
"0RPT07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Metacarpocarpal Joint, Open Approach */
"0RPT0JZ" = "1" /* Removal of Synthetic Substitute from Left Metacarpocarpal Joint, Open Approach */
"0RPT0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Metacarpocarpal Joint, Open Approach */
"0RPT34Z" = "1" /* Removal of Internal Fixation Device from Left Metacarpocarpal Joint, Percutaneous Approach */
"0RPT35Z" = "1" /* Removal of External Fixation Device from Left Metacarpocarpal Joint, Percutaneous Approach */
"0RPT37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Metacarpocarpal Joint, Percutaneous Approach */
"0RPT3JZ" = "1" /* Removal of Synthetic Substitute from Left Metacarpocarpal Joint, Percutaneous Approach */
"0RPT3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Metacarpocarpal Joint, Percutaneous Approach */
"0RPT40Z" = "1" /* Removal of Drainage Device from Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RPT43Z" = "1" /* Removal of Infusion Device from Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RPT44Z" = "1" /* Removal of Internal Fixation Device from Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RPT45Z" = "1" /* Removal of External Fixation Device from Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RPT47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RPT4JZ" = "1" /* Removal of Synthetic Substitute from Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RPT4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RPU00Z" = "1" /* Removal of Drainage Device from Right Metacarpophalangeal Joint, Open Approach */
"0RPU03Z" = "1" /* Removal of Infusion Device from Right Metacarpophalangeal Joint, Open Approach */
"0RPU04Z" = "1" /* Removal of Internal Fixation Device from Right Metacarpophalangeal Joint, Open Approach */
"0RPU05Z" = "1" /* Removal of External Fixation Device from Right Metacarpophalangeal Joint, Open Approach */
"0RPU07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Metacarpophalangeal Joint, Open Approach */
"0RPU0JZ" = "1" /* Removal of Synthetic Substitute from Right Metacarpophalangeal Joint, Open Approach */
"0RPU0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Metacarpophalangeal Joint, Open Approach */
"0RPU34Z" = "1" /* Removal of Internal Fixation Device from Right Metacarpophalangeal Joint, Percutaneous Approach */
"0RPU35Z" = "1" /* Removal of External Fixation Device from Right Metacarpophalangeal Joint, Percutaneous Approach */
"0RPU37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Metacarpophalangeal Joint, Percutaneous Approach */
"0RPU3JZ" = "1" /* Removal of Synthetic Substitute from Right Metacarpophalangeal Joint, Percutaneous Approach */
"0RPU3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Metacarpophalangeal Joint, Percutaneous Approach */
"0RPU40Z" = "1" /* Removal of Drainage Device from Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RPU43Z" = "1" /* Removal of Infusion Device from Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RPU44Z" = "1" /* Removal of Internal Fixation Device from Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RPU45Z" = "1" /* Removal of External Fixation Device from Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RPU47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RPU4JZ" = "1" /* Removal of Synthetic Substitute from Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RPU4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RPV00Z" = "1" /* Removal of Drainage Device from Left Metacarpophalangeal Joint, Open Approach */
"0RPV03Z" = "1" /* Removal of Infusion Device from Left Metacarpophalangeal Joint, Open Approach */
"0RPV04Z" = "1" /* Removal of Internal Fixation Device from Left Metacarpophalangeal Joint, Open Approach */
"0RPV05Z" = "1" /* Removal of External Fixation Device from Left Metacarpophalangeal Joint, Open Approach */
"0RPV07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Metacarpophalangeal Joint, Open Approach */
"0RPV0JZ" = "1" /* Removal of Synthetic Substitute from Left Metacarpophalangeal Joint, Open Approach */
"0RPV0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Metacarpophalangeal Joint, Open Approach */
"0RPV34Z" = "1" /* Removal of Internal Fixation Device from Left Metacarpophalangeal Joint, Percutaneous Approach */
"0RPV35Z" = "1" /* Removal of External Fixation Device from Left Metacarpophalangeal Joint, Percutaneous Approach */
"0RPV37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Metacarpophalangeal Joint, Percutaneous Approach */
"0RPV3JZ" = "1" /* Removal of Synthetic Substitute from Left Metacarpophalangeal Joint, Percutaneous Approach */
"0RPV3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Metacarpophalangeal Joint, Percutaneous Approach */
"0RPV40Z" = "1" /* Removal of Drainage Device from Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RPV43Z" = "1" /* Removal of Infusion Device from Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RPV44Z" = "1" /* Removal of Internal Fixation Device from Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RPV45Z" = "1" /* Removal of External Fixation Device from Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RPV47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RPV4JZ" = "1" /* Removal of Synthetic Substitute from Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RPV4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RPW00Z" = "1" /* Removal of Drainage Device from Right Finger Phalangeal Joint, Open Approach */
"0RPW03Z" = "1" /* Removal of Infusion Device from Right Finger Phalangeal Joint, Open Approach */
"0RPW04Z" = "1" /* Removal of Internal Fixation Device from Right Finger Phalangeal Joint, Open Approach */
"0RPW05Z" = "1" /* Removal of External Fixation Device from Right Finger Phalangeal Joint, Open Approach */
"0RPW07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Finger Phalangeal Joint, Open Approach */
"0RPW0JZ" = "1" /* Removal of Synthetic Substitute from Right Finger Phalangeal Joint, Open Approach */
"0RPW0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Finger Phalangeal Joint, Open Approach */
"0RPW34Z" = "1" /* Removal of Internal Fixation Device from Right Finger Phalangeal Joint, Percutaneous Approach */
"0RPW35Z" = "1" /* Removal of External Fixation Device from Right Finger Phalangeal Joint, Percutaneous Approach */
"0RPW37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Finger Phalangeal Joint, Percutaneous Approach */
"0RPW3JZ" = "1" /* Removal of Synthetic Substitute from Right Finger Phalangeal Joint, Percutaneous Approach */
"0RPW3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Finger Phalangeal Joint, Percutaneous Approach */
"0RPW40Z" = "1" /* Removal of Drainage Device from Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RPW43Z" = "1" /* Removal of Infusion Device from Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RPW44Z" = "1" /* Removal of Internal Fixation Device from Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RPW45Z" = "1" /* Removal of External Fixation Device from Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RPW47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RPW4JZ" = "1" /* Removal of Synthetic Substitute from Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RPW4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RPX00Z" = "1" /* Removal of Drainage Device from Left Finger Phalangeal Joint, Open Approach */
"0RPX03Z" = "1" /* Removal of Infusion Device from Left Finger Phalangeal Joint, Open Approach */
"0RPX04Z" = "1" /* Removal of Internal Fixation Device from Left Finger Phalangeal Joint, Open Approach */
"0RPX05Z" = "1" /* Removal of External Fixation Device from Left Finger Phalangeal Joint, Open Approach */
"0RPX07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Finger Phalangeal Joint, Open Approach */
"0RPX0JZ" = "1" /* Removal of Synthetic Substitute from Left Finger Phalangeal Joint, Open Approach */
"0RPX0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Finger Phalangeal Joint, Open Approach */
"0RPX34Z" = "1" /* Removal of Internal Fixation Device from Left Finger Phalangeal Joint, Percutaneous Approach */
"0RPX35Z" = "1" /* Removal of External Fixation Device from Left Finger Phalangeal Joint, Percutaneous Approach */
"0RPX37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Finger Phalangeal Joint, Percutaneous Approach */
"0RPX3JZ" = "1" /* Removal of Synthetic Substitute from Left Finger Phalangeal Joint, Percutaneous Approach */
"0RPX3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Finger Phalangeal Joint, Percutaneous Approach */
"0RPX40Z" = "1" /* Removal of Drainage Device from Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RPX43Z" = "1" /* Removal of Infusion Device from Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RPX44Z" = "1" /* Removal of Internal Fixation Device from Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RPX45Z" = "1" /* Removal of External Fixation Device from Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RPX47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RPX4JZ" = "1" /* Removal of Synthetic Substitute from Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RPX4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RQ00ZZ" = "1" /* Repair Occipital-cervical Joint, Open Approach */
"0RQ03ZZ" = "1" /* Repair Occipital-cervical Joint, Percutaneous Approach */
"0RQ04ZZ" = "1" /* Repair Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RQ10ZZ" = "1" /* Repair Cervical Vertebral Joint, Open Approach */
"0RQ13ZZ" = "1" /* Repair Cervical Vertebral Joint, Percutaneous Approach */
"0RQ14ZZ" = "1" /* Repair Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RQ30ZZ" = "1" /* Repair Cervical Vertebral Disc, Open Approach */
"0RQ33ZZ" = "1" /* Repair Cervical Vertebral Disc, Percutaneous Approach */
"0RQ34ZZ" = "1" /* Repair Cervical Vertebral Disc, Percutaneous Endoscopic Approach */
"0RQ40ZZ" = "1" /* Repair Cervicothoracic Vertebral Joint, Open Approach */
"0RQ43ZZ" = "1" /* Repair Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RQ44ZZ" = "1" /* Repair Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RQ50ZZ" = "1" /* Repair Cervicothoracic Vertebral Disc, Open Approach */
"0RQ53ZZ" = "1" /* Repair Cervicothoracic Vertebral Disc, Percutaneous Approach */
"0RQ54ZZ" = "1" /* Repair Cervicothoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RQ60ZZ" = "1" /* Repair Thoracic Vertebral Joint, Open Approach */
"0RQ63ZZ" = "1" /* Repair Thoracic Vertebral Joint, Percutaneous Approach */
"0RQ64ZZ" = "1" /* Repair Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RQ90ZZ" = "1" /* Repair Thoracic Vertebral Disc, Open Approach */
"0RQ93ZZ" = "1" /* Repair Thoracic Vertebral Disc, Percutaneous Approach */
"0RQ94ZZ" = "1" /* Repair Thoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RQA0ZZ" = "1" /* Repair Thoracolumbar Vertebral Joint, Open Approach */
"0RQA3ZZ" = "1" /* Repair Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RQA4ZZ" = "1" /* Repair Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RQB0ZZ" = "1" /* Repair Thoracolumbar Vertebral Disc, Open Approach */
"0RQB3ZZ" = "1" /* Repair Thoracolumbar Vertebral Disc, Percutaneous Approach */
"0RQB4ZZ" = "1" /* Repair Thoracolumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0RQC0ZZ" = "1" /* Repair Right Temporomandibular Joint, Open Approach */
"0RQC3ZZ" = "1" /* Repair Right Temporomandibular Joint, Percutaneous Approach */
"0RQC4ZZ" = "1" /* Repair Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RQD0ZZ" = "1" /* Repair Left Temporomandibular Joint, Open Approach */
"0RQD3ZZ" = "1" /* Repair Left Temporomandibular Joint, Percutaneous Approach */
"0RQD4ZZ" = "1" /* Repair Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RQE0ZZ" = "1" /* Repair Right Sternoclavicular Joint, Open Approach */
"0RQE3ZZ" = "1" /* Repair Right Sternoclavicular Joint, Percutaneous Approach */
"0RQE4ZZ" = "1" /* Repair Right Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RQF0ZZ" = "1" /* Repair Left Sternoclavicular Joint, Open Approach */
"0RQF3ZZ" = "1" /* Repair Left Sternoclavicular Joint, Percutaneous Approach */
"0RQF4ZZ" = "1" /* Repair Left Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RQG0ZZ" = "1" /* Repair Right Acromioclavicular Joint, Open Approach */
"0RQG3ZZ" = "1" /* Repair Right Acromioclavicular Joint, Percutaneous Approach */
"0RQG4ZZ" = "1" /* Repair Right Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RQH0ZZ" = "1" /* Repair Left Acromioclavicular Joint, Open Approach */
"0RQH3ZZ" = "1" /* Repair Left Acromioclavicular Joint, Percutaneous Approach */
"0RQH4ZZ" = "1" /* Repair Left Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RQJ0ZZ" = "1" /* Repair Right Shoulder Joint, Open Approach */
"0RQJ3ZZ" = "1" /* Repair Right Shoulder Joint, Percutaneous Approach */
"0RQJ4ZZ" = "1" /* Repair Right Shoulder Joint, Percutaneous Endoscopic Approach */
"0RQK0ZZ" = "1" /* Repair Left Shoulder Joint, Open Approach */
"0RQK3ZZ" = "1" /* Repair Left Shoulder Joint, Percutaneous Approach */
"0RQK4ZZ" = "1" /* Repair Left Shoulder Joint, Percutaneous Endoscopic Approach */
"0RQL0ZZ" = "1" /* Repair Right Elbow Joint, Open Approach */
"0RQL3ZZ" = "1" /* Repair Right Elbow Joint, Percutaneous Approach */
"0RQL4ZZ" = "1" /* Repair Right Elbow Joint, Percutaneous Endoscopic Approach */
"0RQM0ZZ" = "1" /* Repair Left Elbow Joint, Open Approach */
"0RQM3ZZ" = "1" /* Repair Left Elbow Joint, Percutaneous Approach */
"0RQM4ZZ" = "1" /* Repair Left Elbow Joint, Percutaneous Endoscopic Approach */
"0RQN0ZZ" = "1" /* Repair Right Wrist Joint, Open Approach */
"0RQN3ZZ" = "1" /* Repair Right Wrist Joint, Percutaneous Approach */
"0RQN4ZZ" = "1" /* Repair Right Wrist Joint, Percutaneous Endoscopic Approach */
"0RQP0ZZ" = "1" /* Repair Left Wrist Joint, Open Approach */
"0RQP3ZZ" = "1" /* Repair Left Wrist Joint, Percutaneous Approach */
"0RQP4ZZ" = "1" /* Repair Left Wrist Joint, Percutaneous Endoscopic Approach */
"0RQQ0ZZ" = "1" /* Repair Right Carpal Joint, Open Approach */
"0RQQ3ZZ" = "1" /* Repair Right Carpal Joint, Percutaneous Approach */
"0RQQ4ZZ" = "1" /* Repair Right Carpal Joint, Percutaneous Endoscopic Approach */
"0RQR0ZZ" = "1" /* Repair Left Carpal Joint, Open Approach */
"0RQR3ZZ" = "1" /* Repair Left Carpal Joint, Percutaneous Approach */
"0RQR4ZZ" = "1" /* Repair Left Carpal Joint, Percutaneous Endoscopic Approach */
"0RQS0ZZ" = "1" /* Repair Right Metacarpocarpal Joint, Open Approach */
"0RQS3ZZ" = "1" /* Repair Right Metacarpocarpal Joint, Percutaneous Approach */
"0RQS4ZZ" = "1" /* Repair Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RQT0ZZ" = "1" /* Repair Left Metacarpocarpal Joint, Open Approach */
"0RQT3ZZ" = "1" /* Repair Left Metacarpocarpal Joint, Percutaneous Approach */
"0RQT4ZZ" = "1" /* Repair Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RQU0ZZ" = "1" /* Repair Right Metacarpophalangeal Joint, Open Approach */
"0RQU3ZZ" = "1" /* Repair Right Metacarpophalangeal Joint, Percutaneous Approach */
"0RQU4ZZ" = "1" /* Repair Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RQV0ZZ" = "1" /* Repair Left Metacarpophalangeal Joint, Open Approach */
"0RQV3ZZ" = "1" /* Repair Left Metacarpophalangeal Joint, Percutaneous Approach */
"0RQV4ZZ" = "1" /* Repair Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RQW0ZZ" = "1" /* Repair Right Finger Phalangeal Joint, Open Approach */
"0RQW3ZZ" = "1" /* Repair Right Finger Phalangeal Joint, Percutaneous Approach */
"0RQW4ZZ" = "1" /* Repair Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RQX0ZZ" = "1" /* Repair Left Finger Phalangeal Joint, Open Approach */
"0RQX3ZZ" = "1" /* Repair Left Finger Phalangeal Joint, Percutaneous Approach */
"0RQX4ZZ" = "1" /* Repair Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RR007Z" = "1" /* Replacement of Occipital-cervical Joint with Autologous Tissue Substitute, Open Approach */
"0RR00JZ" = "1" /* Replacement of Occipital-cervical Joint with Synthetic Substitute, Open Approach */
"0RR00KZ" = "1" /* Replacement of Occipital-cervical Joint with Nonautologous Tissue Substitute, Open Approach */
"0RR107Z" = "1" /* Replacement of Cervical Vertebral Joint with Autologous Tissue Substitute, Open Approach */
"0RR10JZ" = "1" /* Replacement of Cervical Vertebral Joint with Synthetic Substitute, Open Approach */
"0RR10KZ" = "1" /* Replacement of Cervical Vertebral Joint with Nonautologous Tissue Substitute, Open Approach */
"0RR307Z" = "1" /* Replacement of Cervical Vertebral Disc with Autologous Tissue Substitute, Open Approach */
"0RR30JZ" = "1" /* Replacement of Cervical Vertebral Disc with Synthetic Substitute, Open Approach */
"0RR30KZ" = "1" /* Replacement of Cervical Vertebral Disc with Nonautologous Tissue Substitute, Open Approach */
"0RR407Z" = "1" /* Replacement of Cervicothoracic Vertebral Joint with Autologous Tissue Substitute, Open Approach */
"0RR40JZ" = "1" /* Replacement of Cervicothoracic Vertebral Joint with Synthetic Substitute, Open Approach */
"0RR40KZ" = "1" /* Replacement of Cervicothoracic Vertebral Joint with Nonautologous Tissue Substitute, Open Approach */
"0RR507Z" = "1" /* Replacement of Cervicothoracic Vertebral Disc with Autologous Tissue Substitute, Open Approach */
"0RR50JZ" = "1" /* Replacement of Cervicothoracic Vertebral Disc with Synthetic Substitute, Open Approach */
"0RR50KZ" = "1" /* Replacement of Cervicothoracic Vertebral Disc with Nonautologous Tissue Substitute, Open Approach */
"0RR607Z" = "1" /* Replacement of Thoracic Vertebral Joint with Autologous Tissue Substitute, Open Approach */
"0RR60JZ" = "1" /* Replacement of Thoracic Vertebral Joint with Synthetic Substitute, Open Approach */
"0RR60KZ" = "1" /* Replacement of Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Open Approach */
"0RR907Z" = "1" /* Replacement of Thoracic Vertebral Disc with Autologous Tissue Substitute, Open Approach */
"0RR90JZ" = "1" /* Replacement of Thoracic Vertebral Disc with Synthetic Substitute, Open Approach */
"0RR90KZ" = "1" /* Replacement of Thoracic Vertebral Disc with Nonautologous Tissue Substitute, Open Approach */
"0RRA07Z" = "1" /* Replacement of Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Open Approach */
"0RRA0JZ" = "1" /* Replacement of Thoracolumbar Vertebral Joint with Synthetic Substitute, Open Approach */
"0RRA0KZ" = "1" /* Replacement of Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Open Approach */
"0RRB07Z" = "1" /* Replacement of Thoracolumbar Vertebral Disc with Autologous Tissue Substitute, Open Approach */
"0RRB0JZ" = "1" /* Replacement of Thoracolumbar Vertebral Disc with Synthetic Substitute, Open Approach */
"0RRB0KZ" = "1" /* Replacement of Thoracolumbar Vertebral Disc with Nonautologous Tissue Substitute, Open Approach */
"0RRC07Z" = "1" /* Replacement of Right Temporomandibular Joint with Autologous Tissue Substitute, Open Approach */
"0RRC0JZ" = "1" /* Replacement of Right Temporomandibular Joint with Synthetic Substitute, Open Approach */
"0RRC0KZ" = "1" /* Replacement of Right Temporomandibular Joint with Nonautologous Tissue Substitute, Open Approach */
"0RRD07Z" = "1" /* Replacement of Left Temporomandibular Joint with Autologous Tissue Substitute, Open Approach */
"0RRD0JZ" = "1" /* Replacement of Left Temporomandibular Joint with Synthetic Substitute, Open Approach */
"0RRD0KZ" = "1" /* Replacement of Left Temporomandibular Joint with Nonautologous Tissue Substitute, Open Approach */
"0RRE07Z" = "1" /* Replacement of Right Sternoclavicular Joint with Autologous Tissue Substitute, Open Approach */
"0RRE0JZ" = "1" /* Replacement of Right Sternoclavicular Joint with Synthetic Substitute, Open Approach */
"0RRE0KZ" = "1" /* Replacement of Right Sternoclavicular Joint with Nonautologous Tissue Substitute, Open Approach */
"0RRF07Z" = "1" /* Replacement of Left Sternoclavicular Joint with Autologous Tissue Substitute, Open Approach */
"0RRF0JZ" = "1" /* Replacement of Left Sternoclavicular Joint with Synthetic Substitute, Open Approach */
"0RRF0KZ" = "1" /* Replacement of Left Sternoclavicular Joint with Nonautologous Tissue Substitute, Open Approach */
"0RRG07Z" = "1" /* Replacement of Right Acromioclavicular Joint with Autologous Tissue Substitute, Open Approach */
"0RRG0JZ" = "1" /* Replacement of Right Acromioclavicular Joint with Synthetic Substitute, Open Approach */
"0RRG0KZ" = "1" /* Replacement of Right Acromioclavicular Joint with Nonautologous Tissue Substitute, Open Approach */
"0RRH07Z" = "1" /* Replacement of Left Acromioclavicular Joint with Autologous Tissue Substitute, Open Approach */
"0RRH0JZ" = "1" /* Replacement of Left Acromioclavicular Joint with Synthetic Substitute, Open Approach */
"0RRH0KZ" = "1" /* Replacement of Left Acromioclavicular Joint with Nonautologous Tissue Substitute, Open Approach */
"0RRJ00Z" = "1" /* Replacement of Right Shoulder Joint with Reverse Ball and Socket Synthetic Substitute, Open Approach */
"0RRJ07Z" = "1" /* Replacement of Right Shoulder Joint with Autologous Tissue Substitute, Open Approach */
"0RRJ0J6" = "1" /* Replacement of Right Shoulder Joint with Synthetic Substitute, Humeral Surface, Open Approach */
"0RRJ0J7" = "1" /* Replacement of Right Shoulder Joint with Synthetic Substitute, Glenoid Surface, Open Approach */
"0RRJ0JZ" = "1" /* Replacement of Right Shoulder Joint with Synthetic Substitute, Open Approach */
"0RRJ0KZ" = "1" /* Replacement of Right Shoulder Joint with Nonautologous Tissue Substitute, Open Approach */
"0RRK00Z" = "1" /* Replacement of Left Shoulder Joint with Reverse Ball and Socket Synthetic Substitute, Open Approach */
"0RRK07Z" = "1" /* Replacement of Left Shoulder Joint with Autologous Tissue Substitute, Open Approach */
"0RRK0J6" = "1" /* Replacement of Left Shoulder Joint with Synthetic Substitute, Humeral Surface, Open Approach */
"0RRK0J7" = "1" /* Replacement of Left Shoulder Joint with Synthetic Substitute, Glenoid Surface, Open Approach */
"0RRK0JZ" = "1" /* Replacement of Left Shoulder Joint with Synthetic Substitute, Open Approach */
"0RRK0KZ" = "1" /* Replacement of Left Shoulder Joint with Nonautologous Tissue Substitute, Open Approach */
"0RRL07Z" = "1" /* Replacement of Right Elbow Joint with Autologous Tissue Substitute, Open Approach */
"0RRL0JZ" = "1" /* Replacement of Right Elbow Joint with Synthetic Substitute, Open Approach */
"0RRL0KZ" = "1" /* Replacement of Right Elbow Joint with Nonautologous Tissue Substitute, Open Approach */
"0RRM07Z" = "1" /* Replacement of Left Elbow Joint with Autologous Tissue Substitute, Open Approach */
"0RRM0JZ" = "1" /* Replacement of Left Elbow Joint with Synthetic Substitute, Open Approach */
"0RRM0KZ" = "1" /* Replacement of Left Elbow Joint with Nonautologous Tissue Substitute, Open Approach */
"0RRN07Z" = "1" /* Replacement of Right Wrist Joint with Autologous Tissue Substitute, Open Approach */
"0RRN0JZ" = "1" /* Replacement of Right Wrist Joint with Synthetic Substitute, Open Approach */
"0RRN0KZ" = "1" /* Replacement of Right Wrist Joint with Nonautologous Tissue Substitute, Open Approach */
"0RRP07Z" = "1" /* Replacement of Left Wrist Joint with Autologous Tissue Substitute, Open Approach */
"0RRP0JZ" = "1" /* Replacement of Left Wrist Joint with Synthetic Substitute, Open Approach */
"0RRP0KZ" = "1" /* Replacement of Left Wrist Joint with Nonautologous Tissue Substitute, Open Approach */
"0RRQ07Z" = "1" /* Replacement of Right Carpal Joint with Autologous Tissue Substitute, Open Approach */
"0RRQ0JZ" = "1" /* Replacement of Right Carpal Joint with Synthetic Substitute, Open Approach */
"0RRQ0KZ" = "1" /* Replacement of Right Carpal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RRR07Z" = "1" /* Replacement of Left Carpal Joint with Autologous Tissue Substitute, Open Approach */
"0RRR0JZ" = "1" /* Replacement of Left Carpal Joint with Synthetic Substitute, Open Approach */
"0RRR0KZ" = "1" /* Replacement of Left Carpal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RRS07Z" = "1" /* Replacement of Right Metacarpocarpal Joint with Autologous Tissue Substitute, Open Approach */
"0RRS0JZ" = "1" /* Replacement of Right Metacarpocarpal Joint with Synthetic Substitute, Open Approach */
"0RRS0KZ" = "1" /* Replacement of Right Metacarpocarpal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RRT07Z" = "1" /* Replacement of Left Metacarpocarpal Joint with Autologous Tissue Substitute, Open Approach */
"0RRT0JZ" = "1" /* Replacement of Left Metacarpocarpal Joint with Synthetic Substitute, Open Approach */
"0RRT0KZ" = "1" /* Replacement of Left Metacarpocarpal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RRU07Z" = "1" /* Replacement of Right Metacarpophalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0RRU0JZ" = "1" /* Replacement of Right Metacarpophalangeal Joint with Synthetic Substitute, Open Approach */
"0RRU0KZ" = "1" /* Replacement of Right Metacarpophalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RRV07Z" = "1" /* Replacement of Left Metacarpophalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0RRV0JZ" = "1" /* Replacement of Left Metacarpophalangeal Joint with Synthetic Substitute, Open Approach */
"0RRV0KZ" = "1" /* Replacement of Left Metacarpophalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RRW07Z" = "1" /* Replacement of Right Finger Phalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0RRW0JZ" = "1" /* Replacement of Right Finger Phalangeal Joint with Synthetic Substitute, Open Approach */
"0RRW0KZ" = "1" /* Replacement of Right Finger Phalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RRX07Z" = "1" /* Replacement of Left Finger Phalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0RRX0JZ" = "1" /* Replacement of Left Finger Phalangeal Joint with Synthetic Substitute, Open Approach */
"0RRX0KZ" = "1" /* Replacement of Left Finger Phalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RS004Z" = "1" /* Reposition Occipital-cervical Joint with Internal Fixation Device, Open Approach */
"0RS00ZZ" = "1" /* Reposition Occipital-cervical Joint, Open Approach */
"0RS104Z" = "1" /* Reposition Cervical Vertebral Joint with Internal Fixation Device, Open Approach */
"0RS10ZZ" = "1" /* Reposition Cervical Vertebral Joint, Open Approach */
"0RS404Z" = "1" /* Reposition Cervicothoracic Vertebral Joint with Internal Fixation Device, Open Approach */
"0RS40ZZ" = "1" /* Reposition Cervicothoracic Vertebral Joint, Open Approach */
"0RS604Z" = "1" /* Reposition Thoracic Vertebral Joint with Internal Fixation Device, Open Approach */
"0RS60ZZ" = "1" /* Reposition Thoracic Vertebral Joint, Open Approach */
"0RSA04Z" = "1" /* Reposition Thoracolumbar Vertebral Joint with Internal Fixation Device, Open Approach */
"0RSA0ZZ" = "1" /* Reposition Thoracolumbar Vertebral Joint, Open Approach */
"0RSC04Z" = "1" /* Reposition Right Temporomandibular Joint with Internal Fixation Device, Open Approach */
"0RSC0ZZ" = "1" /* Reposition Right Temporomandibular Joint, Open Approach */
"0RSD04Z" = "1" /* Reposition Left Temporomandibular Joint with Internal Fixation Device, Open Approach */
"0RSD0ZZ" = "1" /* Reposition Left Temporomandibular Joint, Open Approach */
"0RSE04Z" = "1" /* Reposition Right Sternoclavicular Joint with Internal Fixation Device, Open Approach */
"0RSE0ZZ" = "1" /* Reposition Right Sternoclavicular Joint, Open Approach */
"0RSF04Z" = "1" /* Reposition Left Sternoclavicular Joint with Internal Fixation Device, Open Approach */
"0RSF0ZZ" = "1" /* Reposition Left Sternoclavicular Joint, Open Approach */
"0RSG04Z" = "1" /* Reposition Right Acromioclavicular Joint with Internal Fixation Device, Open Approach */
"0RSG0ZZ" = "1" /* Reposition Right Acromioclavicular Joint, Open Approach */
"0RSH04Z" = "1" /* Reposition Left Acromioclavicular Joint with Internal Fixation Device, Open Approach */
"0RSH0ZZ" = "1" /* Reposition Left Acromioclavicular Joint, Open Approach */
"0RSJ04Z" = "1" /* Reposition Right Shoulder Joint with Internal Fixation Device, Open Approach */
"0RSJ0ZZ" = "1" /* Reposition Right Shoulder Joint, Open Approach */
"0RSK04Z" = "1" /* Reposition Left Shoulder Joint with Internal Fixation Device, Open Approach */
"0RSK0ZZ" = "1" /* Reposition Left Shoulder Joint, Open Approach */
"0RSL04Z" = "1" /* Reposition Right Elbow Joint with Internal Fixation Device, Open Approach */
"0RSL05Z" = "1" /* Reposition Right Elbow Joint with External Fixation Device, Open Approach */
"0RSL0ZZ" = "1" /* Reposition Right Elbow Joint, Open Approach */
"0RSM04Z" = "1" /* Reposition Left Elbow Joint with Internal Fixation Device, Open Approach */
"0RSM05Z" = "1" /* Reposition Left Elbow Joint with External Fixation Device, Open Approach */
"0RSM0ZZ" = "1" /* Reposition Left Elbow Joint, Open Approach */
"0RSN04Z" = "1" /* Reposition Right Wrist Joint with Internal Fixation Device, Open Approach */
"0RSN05Z" = "1" /* Reposition Right Wrist Joint with External Fixation Device, Open Approach */
"0RSN0ZZ" = "1" /* Reposition Right Wrist Joint, Open Approach */
"0RSP04Z" = "1" /* Reposition Left Wrist Joint with Internal Fixation Device, Open Approach */
"0RSP05Z" = "1" /* Reposition Left Wrist Joint with External Fixation Device, Open Approach */
"0RSP0ZZ" = "1" /* Reposition Left Wrist Joint, Open Approach */
"0RSQ04Z" = "1" /* Reposition Right Carpal Joint with Internal Fixation Device, Open Approach */
"0RSQ05Z" = "1" /* Reposition Right Carpal Joint with External Fixation Device, Open Approach */
"0RSQ0ZZ" = "1" /* Reposition Right Carpal Joint, Open Approach */
"0RSR04Z" = "1" /* Reposition Left Carpal Joint with Internal Fixation Device, Open Approach */
"0RSR05Z" = "1" /* Reposition Left Carpal Joint with External Fixation Device, Open Approach */
"0RSR0ZZ" = "1" /* Reposition Left Carpal Joint, Open Approach */
"0RSS04Z" = "1" /* Reposition Right Metacarpocarpal Joint with Internal Fixation Device, Open Approach */
"0RSS05Z" = "1" /* Reposition Right Metacarpocarpal Joint with External Fixation Device, Open Approach */
"0RSS0ZZ" = "1" /* Reposition Right Metacarpocarpal Joint, Open Approach */
"0RST04Z" = "1" /* Reposition Left Metacarpocarpal Joint with Internal Fixation Device, Open Approach */
"0RST05Z" = "1" /* Reposition Left Metacarpocarpal Joint with External Fixation Device, Open Approach */
"0RST0ZZ" = "1" /* Reposition Left Metacarpocarpal Joint, Open Approach */
"0RSU04Z" = "1" /* Reposition Right Metacarpophalangeal Joint with Internal Fixation Device, Open Approach */
"0RSU05Z" = "1" /* Reposition Right Metacarpophalangeal Joint with External Fixation Device, Open Approach */
"0RSU0ZZ" = "1" /* Reposition Right Metacarpophalangeal Joint, Open Approach */
"0RSV04Z" = "1" /* Reposition Left Metacarpophalangeal Joint with Internal Fixation Device, Open Approach */
"0RSV05Z" = "1" /* Reposition Left Metacarpophalangeal Joint with External Fixation Device, Open Approach */
"0RSV0ZZ" = "1" /* Reposition Left Metacarpophalangeal Joint, Open Approach */
"0RSW04Z" = "1" /* Reposition Right Finger Phalangeal Joint with Internal Fixation Device, Open Approach */
"0RSW05Z" = "1" /* Reposition Right Finger Phalangeal Joint with External Fixation Device, Open Approach */
"0RSW0ZZ" = "1" /* Reposition Right Finger Phalangeal Joint, Open Approach */
"0RSX04Z" = "1" /* Reposition Left Finger Phalangeal Joint with Internal Fixation Device, Open Approach */
"0RSX05Z" = "1" /* Reposition Left Finger Phalangeal Joint with External Fixation Device, Open Approach */
"0RSX0ZZ" = "1" /* Reposition Left Finger Phalangeal Joint, Open Approach */
"0RT30ZZ" = "1" /* Resection of Cervical Vertebral Disc, Open Approach */
"0RT40ZZ" = "1" /* Resection of Cervicothoracic Vertebral Joint, Open Approach */
"0RT50ZZ" = "1" /* Resection of Cervicothoracic Vertebral Disc, Open Approach */
"0RT90ZZ" = "1" /* Resection of Thoracic Vertebral Disc, Open Approach */
"0RTB0ZZ" = "1" /* Resection of Thoracolumbar Vertebral Disc, Open Approach */
"0RTC0ZZ" = "1" /* Resection of Right Temporomandibular Joint, Open Approach */
"0RTD0ZZ" = "1" /* Resection of Left Temporomandibular Joint, Open Approach */
"0RTE0ZZ" = "1" /* Resection of Right Sternoclavicular Joint, Open Approach */
"0RTF0ZZ" = "1" /* Resection of Left Sternoclavicular Joint, Open Approach */
"0RTG0ZZ" = "1" /* Resection of Right Acromioclavicular Joint, Open Approach */
"0RTH0ZZ" = "1" /* Resection of Left Acromioclavicular Joint, Open Approach */
"0RTJ0ZZ" = "1" /* Resection of Right Shoulder Joint, Open Approach */
"0RTK0ZZ" = "1" /* Resection of Left Shoulder Joint, Open Approach */
"0RTL0ZZ" = "1" /* Resection of Right Elbow Joint, Open Approach */
"0RTM0ZZ" = "1" /* Resection of Left Elbow Joint, Open Approach */
"0RTN0ZZ" = "1" /* Resection of Right Wrist Joint, Open Approach */
"0RTP0ZZ" = "1" /* Resection of Left Wrist Joint, Open Approach */
"0RTQ0ZZ" = "1" /* Resection of Right Carpal Joint, Open Approach */
"0RTR0ZZ" = "1" /* Resection of Left Carpal Joint, Open Approach */
"0RTS0ZZ" = "1" /* Resection of Right Metacarpocarpal Joint, Open Approach */
"0RTT0ZZ" = "1" /* Resection of Left Metacarpocarpal Joint, Open Approach */
"0RTU0ZZ" = "1" /* Resection of Right Metacarpophalangeal Joint, Open Approach */
"0RTV0ZZ" = "1" /* Resection of Left Metacarpophalangeal Joint, Open Approach */
"0RTW0ZZ" = "1" /* Resection of Right Finger Phalangeal Joint, Open Approach */
"0RTX0ZZ" = "1" /* Resection of Left Finger Phalangeal Joint, Open Approach */
"0RU007Z" = "1" /* Supplement Occipital-cervical Joint with Autologous Tissue Substitute, Open Approach */
"0RU00JZ" = "1" /* Supplement Occipital-cervical Joint with Synthetic Substitute, Open Approach */
"0RU00KZ" = "1" /* Supplement Occipital-cervical Joint with Nonautologous Tissue Substitute, Open Approach */
"0RU037Z" = "1" /* Supplement Occipital-cervical Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RU03JZ" = "1" /* Supplement Occipital-cervical Joint with Synthetic Substitute, Percutaneous Approach */
"0RU03KZ" = "1" /* Supplement Occipital-cervical Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RU047Z" = "1" /* Supplement Occipital-cervical Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RU04JZ" = "1" /* Supplement Occipital-cervical Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RU04KZ" = "1" /* Supplement Occipital-cervical Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RU107Z" = "1" /* Supplement Cervical Vertebral Joint with Autologous Tissue Substitute, Open Approach */
"0RU10JZ" = "1" /* Supplement Cervical Vertebral Joint with Synthetic Substitute, Open Approach */
"0RU10KZ" = "1" /* Supplement Cervical Vertebral Joint with Nonautologous Tissue Substitute, Open Approach */
"0RU137Z" = "1" /* Supplement Cervical Vertebral Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RU13JZ" = "1" /* Supplement Cervical Vertebral Joint with Synthetic Substitute, Percutaneous Approach */
"0RU13KZ" = "1" /* Supplement Cervical Vertebral Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RU147Z" = "1" /* Supplement Cervical Vertebral Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RU14JZ" = "1" /* Supplement Cervical Vertebral Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RU14KZ" = "1" /* Supplement Cervical Vertebral Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RU307Z" = "1" /* Supplement Cervical Vertebral Disc with Autologous Tissue Substitute, Open Approach */
"0RU30JZ" = "1" /* Supplement Cervical Vertebral Disc with Synthetic Substitute, Open Approach */
"0RU30KZ" = "1" /* Supplement Cervical Vertebral Disc with Nonautologous Tissue Substitute, Open Approach */
"0RU337Z" = "1" /* Supplement Cervical Vertebral Disc with Autologous Tissue Substitute, Percutaneous Approach */
"0RU33JZ" = "1" /* Supplement Cervical Vertebral Disc with Synthetic Substitute, Percutaneous Approach */
"0RU33KZ" = "1" /* Supplement Cervical Vertebral Disc with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RU347Z" = "1" /* Supplement Cervical Vertebral Disc with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RU34JZ" = "1" /* Supplement Cervical Vertebral Disc with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RU34KZ" = "1" /* Supplement Cervical Vertebral Disc with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RU407Z" = "1" /* Supplement Cervicothoracic Vertebral Joint with Autologous Tissue Substitute, Open Approach */
"0RU40JZ" = "1" /* Supplement Cervicothoracic Vertebral Joint with Synthetic Substitute, Open Approach */
"0RU40KZ" = "1" /* Supplement Cervicothoracic Vertebral Joint with Nonautologous Tissue Substitute, Open Approach */
"0RU437Z" = "1" /* Supplement Cervicothoracic Vertebral Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RU43JZ" = "1" /* Supplement Cervicothoracic Vertebral Joint with Synthetic Substitute, Percutaneous Approach */
"0RU43KZ" = "1" /* Supplement Cervicothoracic Vertebral Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RU447Z" = "1" /* Supplement Cervicothoracic Vertebral Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RU44JZ" = "1" /* Supplement Cervicothoracic Vertebral Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RU44KZ" = "1" /* Supplement Cervicothoracic Vertebral Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RU507Z" = "1" /* Supplement Cervicothoracic Vertebral Disc with Autologous Tissue Substitute, Open Approach */
"0RU50JZ" = "1" /* Supplement Cervicothoracic Vertebral Disc with Synthetic Substitute, Open Approach */
"0RU50KZ" = "1" /* Supplement Cervicothoracic Vertebral Disc with Nonautologous Tissue Substitute, Open Approach */
"0RU537Z" = "1" /* Supplement Cervicothoracic Vertebral Disc with Autologous Tissue Substitute, Percutaneous Approach */
"0RU53JZ" = "1" /* Supplement Cervicothoracic Vertebral Disc with Synthetic Substitute, Percutaneous Approach */
"0RU53KZ" = "1" /* Supplement Cervicothoracic Vertebral Disc with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RU547Z" = "1" /* Supplement Cervicothoracic Vertebral Disc with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RU54JZ" = "1" /* Supplement Cervicothoracic Vertebral Disc with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RU54KZ" = "1" /* Supplement Cervicothoracic Vertebral Disc with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RU607Z" = "1" /* Supplement Thoracic Vertebral Joint with Autologous Tissue Substitute, Open Approach */
"0RU60JZ" = "1" /* Supplement Thoracic Vertebral Joint with Synthetic Substitute, Open Approach */
"0RU60KZ" = "1" /* Supplement Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Open Approach */
"0RU637Z" = "1" /* Supplement Thoracic Vertebral Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RU63JZ" = "1" /* Supplement Thoracic Vertebral Joint with Synthetic Substitute, Percutaneous Approach */
"0RU63KZ" = "1" /* Supplement Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RU647Z" = "1" /* Supplement Thoracic Vertebral Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RU64JZ" = "1" /* Supplement Thoracic Vertebral Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RU64KZ" = "1" /* Supplement Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RU907Z" = "1" /* Supplement Thoracic Vertebral Disc with Autologous Tissue Substitute, Open Approach */
"0RU90JZ" = "1" /* Supplement Thoracic Vertebral Disc with Synthetic Substitute, Open Approach */
"0RU90KZ" = "1" /* Supplement Thoracic Vertebral Disc with Nonautologous Tissue Substitute, Open Approach */
"0RU937Z" = "1" /* Supplement Thoracic Vertebral Disc with Autologous Tissue Substitute, Percutaneous Approach */
"0RU93JZ" = "1" /* Supplement Thoracic Vertebral Disc with Synthetic Substitute, Percutaneous Approach */
"0RU93KZ" = "1" /* Supplement Thoracic Vertebral Disc with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RU947Z" = "1" /* Supplement Thoracic Vertebral Disc with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RU94JZ" = "1" /* Supplement Thoracic Vertebral Disc with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RU94KZ" = "1" /* Supplement Thoracic Vertebral Disc with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUA07Z" = "1" /* Supplement Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Open Approach */
"0RUA0JZ" = "1" /* Supplement Thoracolumbar Vertebral Joint with Synthetic Substitute, Open Approach */
"0RUA0KZ" = "1" /* Supplement Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Open Approach */
"0RUA37Z" = "1" /* Supplement Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RUA3JZ" = "1" /* Supplement Thoracolumbar Vertebral Joint with Synthetic Substitute, Percutaneous Approach */
"0RUA3KZ" = "1" /* Supplement Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RUA47Z" = "1" /* Supplement Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUA4JZ" = "1" /* Supplement Thoracolumbar Vertebral Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUA4KZ" = "1" /* Supplement Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUB07Z" = "1" /* Supplement Thoracolumbar Vertebral Disc with Autologous Tissue Substitute, Open Approach */
"0RUB0JZ" = "1" /* Supplement Thoracolumbar Vertebral Disc with Synthetic Substitute, Open Approach */
"0RUB0KZ" = "1" /* Supplement Thoracolumbar Vertebral Disc with Nonautologous Tissue Substitute, Open Approach */
"0RUB37Z" = "1" /* Supplement Thoracolumbar Vertebral Disc with Autologous Tissue Substitute, Percutaneous Approach */
"0RUB3JZ" = "1" /* Supplement Thoracolumbar Vertebral Disc with Synthetic Substitute, Percutaneous Approach */
"0RUB3KZ" = "1" /* Supplement Thoracolumbar Vertebral Disc with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RUB47Z" = "1" /* Supplement Thoracolumbar Vertebral Disc with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUB4JZ" = "1" /* Supplement Thoracolumbar Vertebral Disc with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUB4KZ" = "1" /* Supplement Thoracolumbar Vertebral Disc with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUC07Z" = "1" /* Supplement Right Temporomandibular Joint with Autologous Tissue Substitute, Open Approach */
"0RUC0JZ" = "1" /* Supplement Right Temporomandibular Joint with Synthetic Substitute, Open Approach */
"0RUC0KZ" = "1" /* Supplement Right Temporomandibular Joint with Nonautologous Tissue Substitute, Open Approach */
"0RUC37Z" = "1" /* Supplement Right Temporomandibular Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RUC3JZ" = "1" /* Supplement Right Temporomandibular Joint with Synthetic Substitute, Percutaneous Approach */
"0RUC3KZ" = "1" /* Supplement Right Temporomandibular Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RUC47Z" = "1" /* Supplement Right Temporomandibular Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUC4JZ" = "1" /* Supplement Right Temporomandibular Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUC4KZ" = "1" /* Supplement Right Temporomandibular Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUD07Z" = "1" /* Supplement Left Temporomandibular Joint with Autologous Tissue Substitute, Open Approach */
"0RUD0JZ" = "1" /* Supplement Left Temporomandibular Joint with Synthetic Substitute, Open Approach */
"0RUD0KZ" = "1" /* Supplement Left Temporomandibular Joint with Nonautologous Tissue Substitute, Open Approach */
"0RUD37Z" = "1" /* Supplement Left Temporomandibular Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RUD3JZ" = "1" /* Supplement Left Temporomandibular Joint with Synthetic Substitute, Percutaneous Approach */
"0RUD3KZ" = "1" /* Supplement Left Temporomandibular Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RUD47Z" = "1" /* Supplement Left Temporomandibular Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUD4JZ" = "1" /* Supplement Left Temporomandibular Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUD4KZ" = "1" /* Supplement Left Temporomandibular Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUE07Z" = "1" /* Supplement Right Sternoclavicular Joint with Autologous Tissue Substitute, Open Approach */
"0RUE0JZ" = "1" /* Supplement Right Sternoclavicular Joint with Synthetic Substitute, Open Approach */
"0RUE0KZ" = "1" /* Supplement Right Sternoclavicular Joint with Nonautologous Tissue Substitute, Open Approach */
"0RUE37Z" = "1" /* Supplement Right Sternoclavicular Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RUE3JZ" = "1" /* Supplement Right Sternoclavicular Joint with Synthetic Substitute, Percutaneous Approach */
"0RUE3KZ" = "1" /* Supplement Right Sternoclavicular Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RUE47Z" = "1" /* Supplement Right Sternoclavicular Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUE4JZ" = "1" /* Supplement Right Sternoclavicular Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUE4KZ" = "1" /* Supplement Right Sternoclavicular Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUF07Z" = "1" /* Supplement Left Sternoclavicular Joint with Autologous Tissue Substitute, Open Approach */
"0RUF0JZ" = "1" /* Supplement Left Sternoclavicular Joint with Synthetic Substitute, Open Approach */
"0RUF0KZ" = "1" /* Supplement Left Sternoclavicular Joint with Nonautologous Tissue Substitute, Open Approach */
"0RUF37Z" = "1" /* Supplement Left Sternoclavicular Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RUF3JZ" = "1" /* Supplement Left Sternoclavicular Joint with Synthetic Substitute, Percutaneous Approach */
"0RUF3KZ" = "1" /* Supplement Left Sternoclavicular Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RUF47Z" = "1" /* Supplement Left Sternoclavicular Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUF4JZ" = "1" /* Supplement Left Sternoclavicular Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUF4KZ" = "1" /* Supplement Left Sternoclavicular Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUG07Z" = "1" /* Supplement Right Acromioclavicular Joint with Autologous Tissue Substitute, Open Approach */
"0RUG0JZ" = "1" /* Supplement Right Acromioclavicular Joint with Synthetic Substitute, Open Approach */
"0RUG0KZ" = "1" /* Supplement Right Acromioclavicular Joint with Nonautologous Tissue Substitute, Open Approach */
"0RUG37Z" = "1" /* Supplement Right Acromioclavicular Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RUG3JZ" = "1" /* Supplement Right Acromioclavicular Joint with Synthetic Substitute, Percutaneous Approach */
"0RUG3KZ" = "1" /* Supplement Right Acromioclavicular Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RUG47Z" = "1" /* Supplement Right Acromioclavicular Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUG4JZ" = "1" /* Supplement Right Acromioclavicular Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUG4KZ" = "1" /* Supplement Right Acromioclavicular Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUH07Z" = "1" /* Supplement Left Acromioclavicular Joint with Autologous Tissue Substitute, Open Approach */
"0RUH0JZ" = "1" /* Supplement Left Acromioclavicular Joint with Synthetic Substitute, Open Approach */
"0RUH0KZ" = "1" /* Supplement Left Acromioclavicular Joint with Nonautologous Tissue Substitute, Open Approach */
"0RUH37Z" = "1" /* Supplement Left Acromioclavicular Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RUH3JZ" = "1" /* Supplement Left Acromioclavicular Joint with Synthetic Substitute, Percutaneous Approach */
"0RUH3KZ" = "1" /* Supplement Left Acromioclavicular Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RUH47Z" = "1" /* Supplement Left Acromioclavicular Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUH4JZ" = "1" /* Supplement Left Acromioclavicular Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUH4KZ" = "1" /* Supplement Left Acromioclavicular Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUJ07Z" = "1" /* Supplement Right Shoulder Joint with Autologous Tissue Substitute, Open Approach */
"0RUJ0JZ" = "1" /* Supplement Right Shoulder Joint with Synthetic Substitute, Open Approach */
"0RUJ0KZ" = "1" /* Supplement Right Shoulder Joint with Nonautologous Tissue Substitute, Open Approach */
"0RUJ37Z" = "1" /* Supplement Right Shoulder Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RUJ3JZ" = "1" /* Supplement Right Shoulder Joint with Synthetic Substitute, Percutaneous Approach */
"0RUJ3KZ" = "1" /* Supplement Right Shoulder Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RUJ47Z" = "1" /* Supplement Right Shoulder Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUJ4JZ" = "1" /* Supplement Right Shoulder Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUJ4KZ" = "1" /* Supplement Right Shoulder Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUK07Z" = "1" /* Supplement Left Shoulder Joint with Autologous Tissue Substitute, Open Approach */
"0RUK0JZ" = "1" /* Supplement Left Shoulder Joint with Synthetic Substitute, Open Approach */
"0RUK0KZ" = "1" /* Supplement Left Shoulder Joint with Nonautologous Tissue Substitute, Open Approach */
"0RUK37Z" = "1" /* Supplement Left Shoulder Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RUK3JZ" = "1" /* Supplement Left Shoulder Joint with Synthetic Substitute, Percutaneous Approach */
"0RUK3KZ" = "1" /* Supplement Left Shoulder Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RUK47Z" = "1" /* Supplement Left Shoulder Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUK4JZ" = "1" /* Supplement Left Shoulder Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUK4KZ" = "1" /* Supplement Left Shoulder Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUL07Z" = "1" /* Supplement Right Elbow Joint with Autologous Tissue Substitute, Open Approach */
"0RUL0JZ" = "1" /* Supplement Right Elbow Joint with Synthetic Substitute, Open Approach */
"0RUL0KZ" = "1" /* Supplement Right Elbow Joint with Nonautologous Tissue Substitute, Open Approach */
"0RUL37Z" = "1" /* Supplement Right Elbow Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RUL3JZ" = "1" /* Supplement Right Elbow Joint with Synthetic Substitute, Percutaneous Approach */
"0RUL3KZ" = "1" /* Supplement Right Elbow Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RUL47Z" = "1" /* Supplement Right Elbow Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUL4JZ" = "1" /* Supplement Right Elbow Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUL4KZ" = "1" /* Supplement Right Elbow Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUM07Z" = "1" /* Supplement Left Elbow Joint with Autologous Tissue Substitute, Open Approach */
"0RUM0JZ" = "1" /* Supplement Left Elbow Joint with Synthetic Substitute, Open Approach */
"0RUM0KZ" = "1" /* Supplement Left Elbow Joint with Nonautologous Tissue Substitute, Open Approach */
"0RUM37Z" = "1" /* Supplement Left Elbow Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RUM3JZ" = "1" /* Supplement Left Elbow Joint with Synthetic Substitute, Percutaneous Approach */
"0RUM3KZ" = "1" /* Supplement Left Elbow Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RUM47Z" = "1" /* Supplement Left Elbow Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUM4JZ" = "1" /* Supplement Left Elbow Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUM4KZ" = "1" /* Supplement Left Elbow Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUN07Z" = "1" /* Supplement Right Wrist Joint with Autologous Tissue Substitute, Open Approach */
"0RUN0JZ" = "1" /* Supplement Right Wrist Joint with Synthetic Substitute, Open Approach */
"0RUN0KZ" = "1" /* Supplement Right Wrist Joint with Nonautologous Tissue Substitute, Open Approach */
"0RUN37Z" = "1" /* Supplement Right Wrist Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RUN3JZ" = "1" /* Supplement Right Wrist Joint with Synthetic Substitute, Percutaneous Approach */
"0RUN3KZ" = "1" /* Supplement Right Wrist Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RUN47Z" = "1" /* Supplement Right Wrist Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUN4JZ" = "1" /* Supplement Right Wrist Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUN4KZ" = "1" /* Supplement Right Wrist Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUP07Z" = "1" /* Supplement Left Wrist Joint with Autologous Tissue Substitute, Open Approach */
"0RUP0JZ" = "1" /* Supplement Left Wrist Joint with Synthetic Substitute, Open Approach */
"0RUP0KZ" = "1" /* Supplement Left Wrist Joint with Nonautologous Tissue Substitute, Open Approach */
"0RUP37Z" = "1" /* Supplement Left Wrist Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RUP3JZ" = "1" /* Supplement Left Wrist Joint with Synthetic Substitute, Percutaneous Approach */
"0RUP3KZ" = "1" /* Supplement Left Wrist Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RUP47Z" = "1" /* Supplement Left Wrist Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUP4JZ" = "1" /* Supplement Left Wrist Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUP4KZ" = "1" /* Supplement Left Wrist Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUQ07Z" = "1" /* Supplement Right Carpal Joint with Autologous Tissue Substitute, Open Approach */
"0RUQ0JZ" = "1" /* Supplement Right Carpal Joint with Synthetic Substitute, Open Approach */
"0RUQ0KZ" = "1" /* Supplement Right Carpal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RUQ37Z" = "1" /* Supplement Right Carpal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RUQ3JZ" = "1" /* Supplement Right Carpal Joint with Synthetic Substitute, Percutaneous Approach */
"0RUQ3KZ" = "1" /* Supplement Right Carpal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RUQ47Z" = "1" /* Supplement Right Carpal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUQ4JZ" = "1" /* Supplement Right Carpal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUQ4KZ" = "1" /* Supplement Right Carpal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUR07Z" = "1" /* Supplement Left Carpal Joint with Autologous Tissue Substitute, Open Approach */
"0RUR0JZ" = "1" /* Supplement Left Carpal Joint with Synthetic Substitute, Open Approach */
"0RUR0KZ" = "1" /* Supplement Left Carpal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RUR37Z" = "1" /* Supplement Left Carpal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RUR3JZ" = "1" /* Supplement Left Carpal Joint with Synthetic Substitute, Percutaneous Approach */
"0RUR3KZ" = "1" /* Supplement Left Carpal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RUR47Z" = "1" /* Supplement Left Carpal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUR4JZ" = "1" /* Supplement Left Carpal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUR4KZ" = "1" /* Supplement Left Carpal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUS07Z" = "1" /* Supplement Right Metacarpocarpal Joint with Autologous Tissue Substitute, Open Approach */
"0RUS0JZ" = "1" /* Supplement Right Metacarpocarpal Joint with Synthetic Substitute, Open Approach */
"0RUS0KZ" = "1" /* Supplement Right Metacarpocarpal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RUS37Z" = "1" /* Supplement Right Metacarpocarpal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RUS3JZ" = "1" /* Supplement Right Metacarpocarpal Joint with Synthetic Substitute, Percutaneous Approach */
"0RUS3KZ" = "1" /* Supplement Right Metacarpocarpal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RUS47Z" = "1" /* Supplement Right Metacarpocarpal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUS4JZ" = "1" /* Supplement Right Metacarpocarpal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUS4KZ" = "1" /* Supplement Right Metacarpocarpal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUT07Z" = "1" /* Supplement Left Metacarpocarpal Joint with Autologous Tissue Substitute, Open Approach */
"0RUT0JZ" = "1" /* Supplement Left Metacarpocarpal Joint with Synthetic Substitute, Open Approach */
"0RUT0KZ" = "1" /* Supplement Left Metacarpocarpal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RUT37Z" = "1" /* Supplement Left Metacarpocarpal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RUT3JZ" = "1" /* Supplement Left Metacarpocarpal Joint with Synthetic Substitute, Percutaneous Approach */
"0RUT3KZ" = "1" /* Supplement Left Metacarpocarpal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RUT47Z" = "1" /* Supplement Left Metacarpocarpal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUT4JZ" = "1" /* Supplement Left Metacarpocarpal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUT4KZ" = "1" /* Supplement Left Metacarpocarpal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUU07Z" = "1" /* Supplement Right Metacarpophalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0RUU0JZ" = "1" /* Supplement Right Metacarpophalangeal Joint with Synthetic Substitute, Open Approach */
"0RUU0KZ" = "1" /* Supplement Right Metacarpophalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RUU37Z" = "1" /* Supplement Right Metacarpophalangeal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RUU3JZ" = "1" /* Supplement Right Metacarpophalangeal Joint with Synthetic Substitute, Percutaneous Approach */
"0RUU3KZ" = "1" /* Supplement Right Metacarpophalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RUU47Z" = "1" /* Supplement Right Metacarpophalangeal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUU4JZ" = "1" /* Supplement Right Metacarpophalangeal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUU4KZ" = "1" /* Supplement Right Metacarpophalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUV07Z" = "1" /* Supplement Left Metacarpophalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0RUV0JZ" = "1" /* Supplement Left Metacarpophalangeal Joint with Synthetic Substitute, Open Approach */
"0RUV0KZ" = "1" /* Supplement Left Metacarpophalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RUV37Z" = "1" /* Supplement Left Metacarpophalangeal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RUV3JZ" = "1" /* Supplement Left Metacarpophalangeal Joint with Synthetic Substitute, Percutaneous Approach */
"0RUV3KZ" = "1" /* Supplement Left Metacarpophalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RUV47Z" = "1" /* Supplement Left Metacarpophalangeal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUV4JZ" = "1" /* Supplement Left Metacarpophalangeal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUV4KZ" = "1" /* Supplement Left Metacarpophalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUW07Z" = "1" /* Supplement Right Finger Phalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0RUW0JZ" = "1" /* Supplement Right Finger Phalangeal Joint with Synthetic Substitute, Open Approach */
"0RUW0KZ" = "1" /* Supplement Right Finger Phalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RUW37Z" = "1" /* Supplement Right Finger Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RUW3JZ" = "1" /* Supplement Right Finger Phalangeal Joint with Synthetic Substitute, Percutaneous Approach */
"0RUW3KZ" = "1" /* Supplement Right Finger Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RUW47Z" = "1" /* Supplement Right Finger Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUW4JZ" = "1" /* Supplement Right Finger Phalangeal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUW4KZ" = "1" /* Supplement Right Finger Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUX07Z" = "1" /* Supplement Left Finger Phalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0RUX0JZ" = "1" /* Supplement Left Finger Phalangeal Joint with Synthetic Substitute, Open Approach */
"0RUX0KZ" = "1" /* Supplement Left Finger Phalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0RUX37Z" = "1" /* Supplement Left Finger Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0RUX3JZ" = "1" /* Supplement Left Finger Phalangeal Joint with Synthetic Substitute, Percutaneous Approach */
"0RUX3KZ" = "1" /* Supplement Left Finger Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0RUX47Z" = "1" /* Supplement Left Finger Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RUX4JZ" = "1" /* Supplement Left Finger Phalangeal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0RUX4KZ" = "1" /* Supplement Left Finger Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0RW000Z" = "1" /* Revision of Drainage Device in Occipital-cervical Joint, Open Approach */
"0RW003Z" = "1" /* Revision of Infusion Device in Occipital-cervical Joint, Open Approach */
"0RW004Z" = "1" /* Revision of Internal Fixation Device in Occipital-cervical Joint, Open Approach */
"0RW007Z" = "1" /* Revision of Autologous Tissue Substitute in Occipital-cervical Joint, Open Approach */
"0RW008Z" = "1" /* Revision of Spacer in Occipital-cervical Joint, Open Approach */
"0RW00AZ" = "1" /* Revision of Interbody Fusion Device in Occipital-cervical Joint, Open Approach */
"0RW00JZ" = "1" /* Revision of Synthetic Substitute in Occipital-cervical Joint, Open Approach */
"0RW00KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Occipital-cervical Joint, Open Approach */
"0RW030Z" = "1" /* Revision of Drainage Device in Occipital-cervical Joint, Percutaneous Approach */
"0RW033Z" = "1" /* Revision of Infusion Device in Occipital-cervical Joint, Percutaneous Approach */
"0RW034Z" = "1" /* Revision of Internal Fixation Device in Occipital-cervical Joint, Percutaneous Approach */
"0RW037Z" = "1" /* Revision of Autologous Tissue Substitute in Occipital-cervical Joint, Percutaneous Approach */
"0RW038Z" = "1" /* Revision of Spacer in Occipital-cervical Joint, Percutaneous Approach */
"0RW03AZ" = "1" /* Revision of Interbody Fusion Device in Occipital-cervical Joint, Percutaneous Approach */
"0RW03JZ" = "1" /* Revision of Synthetic Substitute in Occipital-cervical Joint, Percutaneous Approach */
"0RW03KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Occipital-cervical Joint, Percutaneous Approach */
"0RW040Z" = "1" /* Revision of Drainage Device in Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RW043Z" = "1" /* Revision of Infusion Device in Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RW044Z" = "1" /* Revision of Internal Fixation Device in Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RW047Z" = "1" /* Revision of Autologous Tissue Substitute in Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RW048Z" = "1" /* Revision of Spacer in Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RW04AZ" = "1" /* Revision of Interbody Fusion Device in Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RW04JZ" = "1" /* Revision of Synthetic Substitute in Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RW04KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Occipital-cervical Joint, Percutaneous Endoscopic Approach */
"0RW100Z" = "1" /* Revision of Drainage Device in Cervical Vertebral Joint, Open Approach */
"0RW103Z" = "1" /* Revision of Infusion Device in Cervical Vertebral Joint, Open Approach */
"0RW104Z" = "1" /* Revision of Internal Fixation Device in Cervical Vertebral Joint, Open Approach */
"0RW107Z" = "1" /* Revision of Autologous Tissue Substitute in Cervical Vertebral Joint, Open Approach */
"0RW108Z" = "1" /* Revision of Spacer in Cervical Vertebral Joint, Open Approach */
"0RW10AZ" = "1" /* Revision of Interbody Fusion Device in Cervical Vertebral Joint, Open Approach */
"0RW10JZ" = "1" /* Revision of Synthetic Substitute in Cervical Vertebral Joint, Open Approach */
"0RW10KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Cervical Vertebral Joint, Open Approach */
"0RW130Z" = "1" /* Revision of Drainage Device in Cervical Vertebral Joint, Percutaneous Approach */
"0RW133Z" = "1" /* Revision of Infusion Device in Cervical Vertebral Joint, Percutaneous Approach */
"0RW134Z" = "1" /* Revision of Internal Fixation Device in Cervical Vertebral Joint, Percutaneous Approach */
"0RW137Z" = "1" /* Revision of Autologous Tissue Substitute in Cervical Vertebral Joint, Percutaneous Approach */
"0RW138Z" = "1" /* Revision of Spacer in Cervical Vertebral Joint, Percutaneous Approach */
"0RW13AZ" = "1" /* Revision of Interbody Fusion Device in Cervical Vertebral Joint, Percutaneous Approach */
"0RW13JZ" = "1" /* Revision of Synthetic Substitute in Cervical Vertebral Joint, Percutaneous Approach */
"0RW13KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Cervical Vertebral Joint, Percutaneous Approach */
"0RW140Z" = "1" /* Revision of Drainage Device in Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW143Z" = "1" /* Revision of Infusion Device in Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW144Z" = "1" /* Revision of Internal Fixation Device in Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW147Z" = "1" /* Revision of Autologous Tissue Substitute in Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW148Z" = "1" /* Revision of Spacer in Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW14AZ" = "1" /* Revision of Interbody Fusion Device in Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW14JZ" = "1" /* Revision of Synthetic Substitute in Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW14KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Cervical Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW300Z" = "1" /* Revision of Drainage Device in Cervical Vertebral Disc, Open Approach */
"0RW303Z" = "1" /* Revision of Infusion Device in Cervical Vertebral Disc, Open Approach */
"0RW307Z" = "1" /* Revision of Autologous Tissue Substitute in Cervical Vertebral Disc, Open Approach */
"0RW30JZ" = "1" /* Revision of Synthetic Substitute in Cervical Vertebral Disc, Open Approach */
"0RW30KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Cervical Vertebral Disc, Open Approach */
"0RW330Z" = "1" /* Revision of Drainage Device in Cervical Vertebral Disc, Percutaneous Approach */
"0RW333Z" = "1" /* Revision of Infusion Device in Cervical Vertebral Disc, Percutaneous Approach */
"0RW337Z" = "1" /* Revision of Autologous Tissue Substitute in Cervical Vertebral Disc, Percutaneous Approach */
"0RW33JZ" = "1" /* Revision of Synthetic Substitute in Cervical Vertebral Disc, Percutaneous Approach */
"0RW33KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Cervical Vertebral Disc, Percutaneous Approach */
"0RW340Z" = "1" /* Revision of Drainage Device in Cervical Vertebral Disc, Percutaneous Endoscopic Approach */
"0RW343Z" = "1" /* Revision of Infusion Device in Cervical Vertebral Disc, Percutaneous Endoscopic Approach */
"0RW347Z" = "1" /* Revision of Autologous Tissue Substitute in Cervical Vertebral Disc, Percutaneous Endoscopic Approach */
"0RW34JZ" = "1" /* Revision of Synthetic Substitute in Cervical Vertebral Disc, Percutaneous Endoscopic Approach */
"0RW34KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Cervical Vertebral Disc, Percutaneous Endoscopic Approach */
"0RW400Z" = "1" /* Revision of Drainage Device in Cervicothoracic Vertebral Joint, Open Approach */
"0RW403Z" = "1" /* Revision of Infusion Device in Cervicothoracic Vertebral Joint, Open Approach */
"0RW404Z" = "1" /* Revision of Internal Fixation Device in Cervicothoracic Vertebral Joint, Open Approach */
"0RW407Z" = "1" /* Revision of Autologous Tissue Substitute in Cervicothoracic Vertebral Joint, Open Approach */
"0RW408Z" = "1" /* Revision of Spacer in Cervicothoracic Vertebral Joint, Open Approach */
"0RW40AZ" = "1" /* Revision of Interbody Fusion Device in Cervicothoracic Vertebral Joint, Open Approach */
"0RW40JZ" = "1" /* Revision of Synthetic Substitute in Cervicothoracic Vertebral Joint, Open Approach */
"0RW40KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Cervicothoracic Vertebral Joint, Open Approach */
"0RW430Z" = "1" /* Revision of Drainage Device in Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RW433Z" = "1" /* Revision of Infusion Device in Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RW434Z" = "1" /* Revision of Internal Fixation Device in Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RW437Z" = "1" /* Revision of Autologous Tissue Substitute in Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RW438Z" = "1" /* Revision of Spacer in Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RW43AZ" = "1" /* Revision of Interbody Fusion Device in Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RW43JZ" = "1" /* Revision of Synthetic Substitute in Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RW43KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Cervicothoracic Vertebral Joint, Percutaneous Approach */
"0RW440Z" = "1" /* Revision of Drainage Device in Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW443Z" = "1" /* Revision of Infusion Device in Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW444Z" = "1" /* Revision of Internal Fixation Device in Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW447Z" = "1" /* Revision of Autologous Tissue Substitute in Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW448Z" = "1" /* Revision of Spacer in Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW44AZ" = "1" /* Revision of Interbody Fusion Device in Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW44JZ" = "1" /* Revision of Synthetic Substitute in Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW44KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Cervicothoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW500Z" = "1" /* Revision of Drainage Device in Cervicothoracic Vertebral Disc, Open Approach */
"0RW503Z" = "1" /* Revision of Infusion Device in Cervicothoracic Vertebral Disc, Open Approach */
"0RW507Z" = "1" /* Revision of Autologous Tissue Substitute in Cervicothoracic Vertebral Disc, Open Approach */
"0RW50JZ" = "1" /* Revision of Synthetic Substitute in Cervicothoracic Vertebral Disc, Open Approach */
"0RW50KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Cervicothoracic Vertebral Disc, Open Approach */
"0RW530Z" = "1" /* Revision of Drainage Device in Cervicothoracic Vertebral Disc, Percutaneous Approach */
"0RW533Z" = "1" /* Revision of Infusion Device in Cervicothoracic Vertebral Disc, Percutaneous Approach */
"0RW537Z" = "1" /* Revision of Autologous Tissue Substitute in Cervicothoracic Vertebral Disc, Percutaneous Approach */
"0RW53JZ" = "1" /* Revision of Synthetic Substitute in Cervicothoracic Vertebral Disc, Percutaneous Approach */
"0RW53KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Cervicothoracic Vertebral Disc, Percutaneous Approach */
"0RW540Z" = "1" /* Revision of Drainage Device in Cervicothoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RW543Z" = "1" /* Revision of Infusion Device in Cervicothoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RW547Z" = "1" /* Revision of Autologous Tissue Substitute in Cervicothoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RW54JZ" = "1" /* Revision of Synthetic Substitute in Cervicothoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RW54KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Cervicothoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RW600Z" = "1" /* Revision of Drainage Device in Thoracic Vertebral Joint, Open Approach */
"0RW603Z" = "1" /* Revision of Infusion Device in Thoracic Vertebral Joint, Open Approach */
"0RW604Z" = "1" /* Revision of Internal Fixation Device in Thoracic Vertebral Joint, Open Approach */
"0RW607Z" = "1" /* Revision of Autologous Tissue Substitute in Thoracic Vertebral Joint, Open Approach */
"0RW608Z" = "1" /* Revision of Spacer in Thoracic Vertebral Joint, Open Approach */
"0RW60AZ" = "1" /* Revision of Interbody Fusion Device in Thoracic Vertebral Joint, Open Approach */
"0RW60JZ" = "1" /* Revision of Synthetic Substitute in Thoracic Vertebral Joint, Open Approach */
"0RW60KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Thoracic Vertebral Joint, Open Approach */
"0RW630Z" = "1" /* Revision of Drainage Device in Thoracic Vertebral Joint, Percutaneous Approach */
"0RW633Z" = "1" /* Revision of Infusion Device in Thoracic Vertebral Joint, Percutaneous Approach */
"0RW634Z" = "1" /* Revision of Internal Fixation Device in Thoracic Vertebral Joint, Percutaneous Approach */
"0RW637Z" = "1" /* Revision of Autologous Tissue Substitute in Thoracic Vertebral Joint, Percutaneous Approach */
"0RW638Z" = "1" /* Revision of Spacer in Thoracic Vertebral Joint, Percutaneous Approach */
"0RW63AZ" = "1" /* Revision of Interbody Fusion Device in Thoracic Vertebral Joint, Percutaneous Approach */
"0RW63JZ" = "1" /* Revision of Synthetic Substitute in Thoracic Vertebral Joint, Percutaneous Approach */
"0RW63KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Thoracic Vertebral Joint, Percutaneous Approach */
"0RW640Z" = "1" /* Revision of Drainage Device in Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW643Z" = "1" /* Revision of Infusion Device in Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW644Z" = "1" /* Revision of Internal Fixation Device in Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW647Z" = "1" /* Revision of Autologous Tissue Substitute in Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW648Z" = "1" /* Revision of Spacer in Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW64AZ" = "1" /* Revision of Interbody Fusion Device in Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW64JZ" = "1" /* Revision of Synthetic Substitute in Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW64KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Thoracic Vertebral Joint, Percutaneous Endoscopic Approach */
"0RW900Z" = "1" /* Revision of Drainage Device in Thoracic Vertebral Disc, Open Approach */
"0RW903Z" = "1" /* Revision of Infusion Device in Thoracic Vertebral Disc, Open Approach */
"0RW907Z" = "1" /* Revision of Autologous Tissue Substitute in Thoracic Vertebral Disc, Open Approach */
"0RW90JZ" = "1" /* Revision of Synthetic Substitute in Thoracic Vertebral Disc, Open Approach */
"0RW90KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Thoracic Vertebral Disc, Open Approach */
"0RW930Z" = "1" /* Revision of Drainage Device in Thoracic Vertebral Disc, Percutaneous Approach */
"0RW933Z" = "1" /* Revision of Infusion Device in Thoracic Vertebral Disc, Percutaneous Approach */
"0RW937Z" = "1" /* Revision of Autologous Tissue Substitute in Thoracic Vertebral Disc, Percutaneous Approach */
"0RW93JZ" = "1" /* Revision of Synthetic Substitute in Thoracic Vertebral Disc, Percutaneous Approach */
"0RW93KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Thoracic Vertebral Disc, Percutaneous Approach */
"0RW940Z" = "1" /* Revision of Drainage Device in Thoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RW943Z" = "1" /* Revision of Infusion Device in Thoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RW947Z" = "1" /* Revision of Autologous Tissue Substitute in Thoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RW94JZ" = "1" /* Revision of Synthetic Substitute in Thoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RW94KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Thoracic Vertebral Disc, Percutaneous Endoscopic Approach */
"0RWA00Z" = "1" /* Revision of Drainage Device in Thoracolumbar Vertebral Joint, Open Approach */
"0RWA03Z" = "1" /* Revision of Infusion Device in Thoracolumbar Vertebral Joint, Open Approach */
"0RWA04Z" = "1" /* Revision of Internal Fixation Device in Thoracolumbar Vertebral Joint, Open Approach */
"0RWA07Z" = "1" /* Revision of Autologous Tissue Substitute in Thoracolumbar Vertebral Joint, Open Approach */
"0RWA08Z" = "1" /* Revision of Spacer in Thoracolumbar Vertebral Joint, Open Approach */
"0RWA0AZ" = "1" /* Revision of Interbody Fusion Device in Thoracolumbar Vertebral Joint, Open Approach */
"0RWA0JZ" = "1" /* Revision of Synthetic Substitute in Thoracolumbar Vertebral Joint, Open Approach */
"0RWA0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Thoracolumbar Vertebral Joint, Open Approach */
"0RWA30Z" = "1" /* Revision of Drainage Device in Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RWA33Z" = "1" /* Revision of Infusion Device in Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RWA34Z" = "1" /* Revision of Internal Fixation Device in Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RWA37Z" = "1" /* Revision of Autologous Tissue Substitute in Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RWA38Z" = "1" /* Revision of Spacer in Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RWA3AZ" = "1" /* Revision of Interbody Fusion Device in Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RWA3JZ" = "1" /* Revision of Synthetic Substitute in Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RWA3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Thoracolumbar Vertebral Joint, Percutaneous Approach */
"0RWA40Z" = "1" /* Revision of Drainage Device in Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RWA43Z" = "1" /* Revision of Infusion Device in Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RWA44Z" = "1" /* Revision of Internal Fixation Device in Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RWA47Z" = "1" /* Revision of Autologous Tissue Substitute in Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RWA48Z" = "1" /* Revision of Spacer in Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RWA4AZ" = "1" /* Revision of Interbody Fusion Device in Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RWA4JZ" = "1" /* Revision of Synthetic Substitute in Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RWA4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Thoracolumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0RWB00Z" = "1" /* Revision of Drainage Device in Thoracolumbar Vertebral Disc, Open Approach */
"0RWB03Z" = "1" /* Revision of Infusion Device in Thoracolumbar Vertebral Disc, Open Approach */
"0RWB07Z" = "1" /* Revision of Autologous Tissue Substitute in Thoracolumbar Vertebral Disc, Open Approach */
"0RWB0JZ" = "1" /* Revision of Synthetic Substitute in Thoracolumbar Vertebral Disc, Open Approach */
"0RWB0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Thoracolumbar Vertebral Disc, Open Approach */
"0RWB30Z" = "1" /* Revision of Drainage Device in Thoracolumbar Vertebral Disc, Percutaneous Approach */
"0RWB33Z" = "1" /* Revision of Infusion Device in Thoracolumbar Vertebral Disc, Percutaneous Approach */
"0RWB37Z" = "1" /* Revision of Autologous Tissue Substitute in Thoracolumbar Vertebral Disc, Percutaneous Approach */
"0RWB3JZ" = "1" /* Revision of Synthetic Substitute in Thoracolumbar Vertebral Disc, Percutaneous Approach */
"0RWB3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Thoracolumbar Vertebral Disc, Percutaneous Approach */
"0RWB40Z" = "1" /* Revision of Drainage Device in Thoracolumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0RWB43Z" = "1" /* Revision of Infusion Device in Thoracolumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0RWB47Z" = "1" /* Revision of Autologous Tissue Substitute in Thoracolumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0RWB4JZ" = "1" /* Revision of Synthetic Substitute in Thoracolumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0RWB4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Thoracolumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0RWC00Z" = "1" /* Revision of Drainage Device in Right Temporomandibular Joint, Open Approach */
"0RWC03Z" = "1" /* Revision of Infusion Device in Right Temporomandibular Joint, Open Approach */
"0RWC04Z" = "1" /* Revision of Internal Fixation Device in Right Temporomandibular Joint, Open Approach */
"0RWC07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Temporomandibular Joint, Open Approach */
"0RWC08Z" = "1" /* Revision of Spacer in Right Temporomandibular Joint, Open Approach */
"0RWC0JZ" = "1" /* Revision of Synthetic Substitute in Right Temporomandibular Joint, Open Approach */
"0RWC0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Temporomandibular Joint, Open Approach */
"0RWC30Z" = "1" /* Revision of Drainage Device in Right Temporomandibular Joint, Percutaneous Approach */
"0RWC33Z" = "1" /* Revision of Infusion Device in Right Temporomandibular Joint, Percutaneous Approach */
"0RWC34Z" = "1" /* Revision of Internal Fixation Device in Right Temporomandibular Joint, Percutaneous Approach */
"0RWC37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Temporomandibular Joint, Percutaneous Approach */
"0RWC38Z" = "1" /* Revision of Spacer in Right Temporomandibular Joint, Percutaneous Approach */
"0RWC3JZ" = "1" /* Revision of Synthetic Substitute in Right Temporomandibular Joint, Percutaneous Approach */
"0RWC3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Temporomandibular Joint, Percutaneous Approach */
"0RWC40Z" = "1" /* Revision of Drainage Device in Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RWC43Z" = "1" /* Revision of Infusion Device in Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RWC44Z" = "1" /* Revision of Internal Fixation Device in Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RWC47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RWC48Z" = "1" /* Revision of Spacer in Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RWC4JZ" = "1" /* Revision of Synthetic Substitute in Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RWC4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RWD00Z" = "1" /* Revision of Drainage Device in Left Temporomandibular Joint, Open Approach */
"0RWD03Z" = "1" /* Revision of Infusion Device in Left Temporomandibular Joint, Open Approach */
"0RWD04Z" = "1" /* Revision of Internal Fixation Device in Left Temporomandibular Joint, Open Approach */
"0RWD07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Temporomandibular Joint, Open Approach */
"0RWD08Z" = "1" /* Revision of Spacer in Left Temporomandibular Joint, Open Approach */
"0RWD0JZ" = "1" /* Revision of Synthetic Substitute in Left Temporomandibular Joint, Open Approach */
"0RWD0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Temporomandibular Joint, Open Approach */
"0RWD30Z" = "1" /* Revision of Drainage Device in Left Temporomandibular Joint, Percutaneous Approach */
"0RWD33Z" = "1" /* Revision of Infusion Device in Left Temporomandibular Joint, Percutaneous Approach */
"0RWD34Z" = "1" /* Revision of Internal Fixation Device in Left Temporomandibular Joint, Percutaneous Approach */
"0RWD37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Temporomandibular Joint, Percutaneous Approach */
"0RWD38Z" = "1" /* Revision of Spacer in Left Temporomandibular Joint, Percutaneous Approach */
"0RWD3JZ" = "1" /* Revision of Synthetic Substitute in Left Temporomandibular Joint, Percutaneous Approach */
"0RWD3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Temporomandibular Joint, Percutaneous Approach */
"0RWD40Z" = "1" /* Revision of Drainage Device in Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RWD43Z" = "1" /* Revision of Infusion Device in Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RWD44Z" = "1" /* Revision of Internal Fixation Device in Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RWD47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RWD48Z" = "1" /* Revision of Spacer in Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RWD4JZ" = "1" /* Revision of Synthetic Substitute in Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RWD4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Temporomandibular Joint, Percutaneous Endoscopic Approach */
"0RWE00Z" = "1" /* Revision of Drainage Device in Right Sternoclavicular Joint, Open Approach */
"0RWE03Z" = "1" /* Revision of Infusion Device in Right Sternoclavicular Joint, Open Approach */
"0RWE04Z" = "1" /* Revision of Internal Fixation Device in Right Sternoclavicular Joint, Open Approach */
"0RWE07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Sternoclavicular Joint, Open Approach */
"0RWE08Z" = "1" /* Revision of Spacer in Right Sternoclavicular Joint, Open Approach */
"0RWE0JZ" = "1" /* Revision of Synthetic Substitute in Right Sternoclavicular Joint, Open Approach */
"0RWE0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Sternoclavicular Joint, Open Approach */
"0RWE30Z" = "1" /* Revision of Drainage Device in Right Sternoclavicular Joint, Percutaneous Approach */
"0RWE33Z" = "1" /* Revision of Infusion Device in Right Sternoclavicular Joint, Percutaneous Approach */
"0RWE34Z" = "1" /* Revision of Internal Fixation Device in Right Sternoclavicular Joint, Percutaneous Approach */
"0RWE37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Sternoclavicular Joint, Percutaneous Approach */
"0RWE38Z" = "1" /* Revision of Spacer in Right Sternoclavicular Joint, Percutaneous Approach */
"0RWE3JZ" = "1" /* Revision of Synthetic Substitute in Right Sternoclavicular Joint, Percutaneous Approach */
"0RWE3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Sternoclavicular Joint, Percutaneous Approach */
"0RWE40Z" = "1" /* Revision of Drainage Device in Right Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RWE43Z" = "1" /* Revision of Infusion Device in Right Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RWE44Z" = "1" /* Revision of Internal Fixation Device in Right Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RWE47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RWE48Z" = "1" /* Revision of Spacer in Right Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RWE4JZ" = "1" /* Revision of Synthetic Substitute in Right Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RWE4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RWF00Z" = "1" /* Revision of Drainage Device in Left Sternoclavicular Joint, Open Approach */
"0RWF03Z" = "1" /* Revision of Infusion Device in Left Sternoclavicular Joint, Open Approach */
"0RWF04Z" = "1" /* Revision of Internal Fixation Device in Left Sternoclavicular Joint, Open Approach */
"0RWF07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Sternoclavicular Joint, Open Approach */
"0RWF08Z" = "1" /* Revision of Spacer in Left Sternoclavicular Joint, Open Approach */
"0RWF0JZ" = "1" /* Revision of Synthetic Substitute in Left Sternoclavicular Joint, Open Approach */
"0RWF0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Sternoclavicular Joint, Open Approach */
"0RWF30Z" = "1" /* Revision of Drainage Device in Left Sternoclavicular Joint, Percutaneous Approach */
"0RWF33Z" = "1" /* Revision of Infusion Device in Left Sternoclavicular Joint, Percutaneous Approach */
"0RWF34Z" = "1" /* Revision of Internal Fixation Device in Left Sternoclavicular Joint, Percutaneous Approach */
"0RWF37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Sternoclavicular Joint, Percutaneous Approach */
"0RWF38Z" = "1" /* Revision of Spacer in Left Sternoclavicular Joint, Percutaneous Approach */
"0RWF3JZ" = "1" /* Revision of Synthetic Substitute in Left Sternoclavicular Joint, Percutaneous Approach */
"0RWF3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Sternoclavicular Joint, Percutaneous Approach */
"0RWF40Z" = "1" /* Revision of Drainage Device in Left Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RWF43Z" = "1" /* Revision of Infusion Device in Left Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RWF44Z" = "1" /* Revision of Internal Fixation Device in Left Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RWF47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RWF48Z" = "1" /* Revision of Spacer in Left Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RWF4JZ" = "1" /* Revision of Synthetic Substitute in Left Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RWF4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Sternoclavicular Joint, Percutaneous Endoscopic Approach */
"0RWG00Z" = "1" /* Revision of Drainage Device in Right Acromioclavicular Joint, Open Approach */
"0RWG03Z" = "1" /* Revision of Infusion Device in Right Acromioclavicular Joint, Open Approach */
"0RWG04Z" = "1" /* Revision of Internal Fixation Device in Right Acromioclavicular Joint, Open Approach */
"0RWG07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Acromioclavicular Joint, Open Approach */
"0RWG08Z" = "1" /* Revision of Spacer in Right Acromioclavicular Joint, Open Approach */
"0RWG0JZ" = "1" /* Revision of Synthetic Substitute in Right Acromioclavicular Joint, Open Approach */
"0RWG0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Acromioclavicular Joint, Open Approach */
"0RWG30Z" = "1" /* Revision of Drainage Device in Right Acromioclavicular Joint, Percutaneous Approach */
"0RWG33Z" = "1" /* Revision of Infusion Device in Right Acromioclavicular Joint, Percutaneous Approach */
"0RWG34Z" = "1" /* Revision of Internal Fixation Device in Right Acromioclavicular Joint, Percutaneous Approach */
"0RWG37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Acromioclavicular Joint, Percutaneous Approach */
"0RWG38Z" = "1" /* Revision of Spacer in Right Acromioclavicular Joint, Percutaneous Approach */
"0RWG3JZ" = "1" /* Revision of Synthetic Substitute in Right Acromioclavicular Joint, Percutaneous Approach */
"0RWG3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Acromioclavicular Joint, Percutaneous Approach */
"0RWG40Z" = "1" /* Revision of Drainage Device in Right Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RWG43Z" = "1" /* Revision of Infusion Device in Right Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RWG44Z" = "1" /* Revision of Internal Fixation Device in Right Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RWG47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RWG48Z" = "1" /* Revision of Spacer in Right Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RWG4JZ" = "1" /* Revision of Synthetic Substitute in Right Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RWG4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RWH00Z" = "1" /* Revision of Drainage Device in Left Acromioclavicular Joint, Open Approach */
"0RWH03Z" = "1" /* Revision of Infusion Device in Left Acromioclavicular Joint, Open Approach */
"0RWH04Z" = "1" /* Revision of Internal Fixation Device in Left Acromioclavicular Joint, Open Approach */
"0RWH07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Acromioclavicular Joint, Open Approach */
"0RWH08Z" = "1" /* Revision of Spacer in Left Acromioclavicular Joint, Open Approach */
"0RWH0JZ" = "1" /* Revision of Synthetic Substitute in Left Acromioclavicular Joint, Open Approach */
"0RWH0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Acromioclavicular Joint, Open Approach */
"0RWH30Z" = "1" /* Revision of Drainage Device in Left Acromioclavicular Joint, Percutaneous Approach */
"0RWH33Z" = "1" /* Revision of Infusion Device in Left Acromioclavicular Joint, Percutaneous Approach */
"0RWH34Z" = "1" /* Revision of Internal Fixation Device in Left Acromioclavicular Joint, Percutaneous Approach */
"0RWH37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Acromioclavicular Joint, Percutaneous Approach */
"0RWH38Z" = "1" /* Revision of Spacer in Left Acromioclavicular Joint, Percutaneous Approach */
"0RWH3JZ" = "1" /* Revision of Synthetic Substitute in Left Acromioclavicular Joint, Percutaneous Approach */
"0RWH3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Acromioclavicular Joint, Percutaneous Approach */
"0RWH40Z" = "1" /* Revision of Drainage Device in Left Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RWH43Z" = "1" /* Revision of Infusion Device in Left Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RWH44Z" = "1" /* Revision of Internal Fixation Device in Left Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RWH47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RWH48Z" = "1" /* Revision of Spacer in Left Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RWH4JZ" = "1" /* Revision of Synthetic Substitute in Left Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RWH4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Acromioclavicular Joint, Percutaneous Endoscopic Approach */
"0RWJ00Z" = "1" /* Revision of Drainage Device in Right Shoulder Joint, Open Approach */
"0RWJ03Z" = "1" /* Revision of Infusion Device in Right Shoulder Joint, Open Approach */
"0RWJ04Z" = "1" /* Revision of Internal Fixation Device in Right Shoulder Joint, Open Approach */
"0RWJ07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Shoulder Joint, Open Approach */
"0RWJ08Z" = "1" /* Revision of Spacer in Right Shoulder Joint, Open Approach */
"0RWJ0JZ" = "1" /* Revision of Synthetic Substitute in Right Shoulder Joint, Open Approach */
"0RWJ0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Shoulder Joint, Open Approach */
"0RWJ30Z" = "1" /* Revision of Drainage Device in Right Shoulder Joint, Percutaneous Approach */
"0RWJ33Z" = "1" /* Revision of Infusion Device in Right Shoulder Joint, Percutaneous Approach */
"0RWJ34Z" = "1" /* Revision of Internal Fixation Device in Right Shoulder Joint, Percutaneous Approach */
"0RWJ37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Shoulder Joint, Percutaneous Approach */
"0RWJ38Z" = "1" /* Revision of Spacer in Right Shoulder Joint, Percutaneous Approach */
"0RWJ3JZ" = "1" /* Revision of Synthetic Substitute in Right Shoulder Joint, Percutaneous Approach */
"0RWJ3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Shoulder Joint, Percutaneous Approach */
"0RWJ40Z" = "1" /* Revision of Drainage Device in Right Shoulder Joint, Percutaneous Endoscopic Approach */
"0RWJ43Z" = "1" /* Revision of Infusion Device in Right Shoulder Joint, Percutaneous Endoscopic Approach */
"0RWJ44Z" = "1" /* Revision of Internal Fixation Device in Right Shoulder Joint, Percutaneous Endoscopic Approach */
"0RWJ47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Shoulder Joint, Percutaneous Endoscopic Approach */
"0RWJ48Z" = "1" /* Revision of Spacer in Right Shoulder Joint, Percutaneous Endoscopic Approach */
"0RWJ4JZ" = "1" /* Revision of Synthetic Substitute in Right Shoulder Joint, Percutaneous Endoscopic Approach */
"0RWJ4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Shoulder Joint, Percutaneous Endoscopic Approach */
"0RWK00Z" = "1" /* Revision of Drainage Device in Left Shoulder Joint, Open Approach */
"0RWK03Z" = "1" /* Revision of Infusion Device in Left Shoulder Joint, Open Approach */
"0RWK04Z" = "1" /* Revision of Internal Fixation Device in Left Shoulder Joint, Open Approach */
"0RWK07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Shoulder Joint, Open Approach */
"0RWK08Z" = "1" /* Revision of Spacer in Left Shoulder Joint, Open Approach */
"0RWK0JZ" = "1" /* Revision of Synthetic Substitute in Left Shoulder Joint, Open Approach */
"0RWK0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Shoulder Joint, Open Approach */
"0RWK30Z" = "1" /* Revision of Drainage Device in Left Shoulder Joint, Percutaneous Approach */
"0RWK33Z" = "1" /* Revision of Infusion Device in Left Shoulder Joint, Percutaneous Approach */
"0RWK34Z" = "1" /* Revision of Internal Fixation Device in Left Shoulder Joint, Percutaneous Approach */
"0RWK37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Shoulder Joint, Percutaneous Approach */
"0RWK38Z" = "1" /* Revision of Spacer in Left Shoulder Joint, Percutaneous Approach */
"0RWK3JZ" = "1" /* Revision of Synthetic Substitute in Left Shoulder Joint, Percutaneous Approach */
"0RWK3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Shoulder Joint, Percutaneous Approach */
"0RWK40Z" = "1" /* Revision of Drainage Device in Left Shoulder Joint, Percutaneous Endoscopic Approach */
"0RWK43Z" = "1" /* Revision of Infusion Device in Left Shoulder Joint, Percutaneous Endoscopic Approach */
"0RWK44Z" = "1" /* Revision of Internal Fixation Device in Left Shoulder Joint, Percutaneous Endoscopic Approach */
"0RWK47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Shoulder Joint, Percutaneous Endoscopic Approach */
"0RWK48Z" = "1" /* Revision of Spacer in Left Shoulder Joint, Percutaneous Endoscopic Approach */
"0RWK4JZ" = "1" /* Revision of Synthetic Substitute in Left Shoulder Joint, Percutaneous Endoscopic Approach */
"0RWK4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Shoulder Joint, Percutaneous Endoscopic Approach */
"0RWL00Z" = "1" /* Revision of Drainage Device in Right Elbow Joint, Open Approach */
"0RWL03Z" = "1" /* Revision of Infusion Device in Right Elbow Joint, Open Approach */
"0RWL04Z" = "1" /* Revision of Internal Fixation Device in Right Elbow Joint, Open Approach */
"0RWL05Z" = "1" /* Revision of External Fixation Device in Right Elbow Joint, Open Approach */
"0RWL07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Elbow Joint, Open Approach */
"0RWL08Z" = "1" /* Revision of Spacer in Right Elbow Joint, Open Approach */
"0RWL0JZ" = "1" /* Revision of Synthetic Substitute in Right Elbow Joint, Open Approach */
"0RWL0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Elbow Joint, Open Approach */
"0RWL30Z" = "1" /* Revision of Drainage Device in Right Elbow Joint, Percutaneous Approach */
"0RWL33Z" = "1" /* Revision of Infusion Device in Right Elbow Joint, Percutaneous Approach */
"0RWL34Z" = "1" /* Revision of Internal Fixation Device in Right Elbow Joint, Percutaneous Approach */
"0RWL35Z" = "1" /* Revision of External Fixation Device in Right Elbow Joint, Percutaneous Approach */
"0RWL37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Elbow Joint, Percutaneous Approach */
"0RWL38Z" = "1" /* Revision of Spacer in Right Elbow Joint, Percutaneous Approach */
"0RWL3JZ" = "1" /* Revision of Synthetic Substitute in Right Elbow Joint, Percutaneous Approach */
"0RWL3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Elbow Joint, Percutaneous Approach */
"0RWL40Z" = "1" /* Revision of Drainage Device in Right Elbow Joint, Percutaneous Endoscopic Approach */
"0RWL43Z" = "1" /* Revision of Infusion Device in Right Elbow Joint, Percutaneous Endoscopic Approach */
"0RWL44Z" = "1" /* Revision of Internal Fixation Device in Right Elbow Joint, Percutaneous Endoscopic Approach */
"0RWL45Z" = "1" /* Revision of External Fixation Device in Right Elbow Joint, Percutaneous Endoscopic Approach */
"0RWL47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Elbow Joint, Percutaneous Endoscopic Approach */
"0RWL48Z" = "1" /* Revision of Spacer in Right Elbow Joint, Percutaneous Endoscopic Approach */
"0RWL4JZ" = "1" /* Revision of Synthetic Substitute in Right Elbow Joint, Percutaneous Endoscopic Approach */
"0RWL4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Elbow Joint, Percutaneous Endoscopic Approach */
"0RWM00Z" = "1" /* Revision of Drainage Device in Left Elbow Joint, Open Approach */
"0RWM03Z" = "1" /* Revision of Infusion Device in Left Elbow Joint, Open Approach */
"0RWM04Z" = "1" /* Revision of Internal Fixation Device in Left Elbow Joint, Open Approach */
"0RWM05Z" = "1" /* Revision of External Fixation Device in Left Elbow Joint, Open Approach */
"0RWM07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Elbow Joint, Open Approach */
"0RWM08Z" = "1" /* Revision of Spacer in Left Elbow Joint, Open Approach */
"0RWM0JZ" = "1" /* Revision of Synthetic Substitute in Left Elbow Joint, Open Approach */
"0RWM0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Elbow Joint, Open Approach */
"0RWM30Z" = "1" /* Revision of Drainage Device in Left Elbow Joint, Percutaneous Approach */
"0RWM33Z" = "1" /* Revision of Infusion Device in Left Elbow Joint, Percutaneous Approach */
"0RWM34Z" = "1" /* Revision of Internal Fixation Device in Left Elbow Joint, Percutaneous Approach */
"0RWM35Z" = "1" /* Revision of External Fixation Device in Left Elbow Joint, Percutaneous Approach */
"0RWM37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Elbow Joint, Percutaneous Approach */
"0RWM38Z" = "1" /* Revision of Spacer in Left Elbow Joint, Percutaneous Approach */
"0RWM3JZ" = "1" /* Revision of Synthetic Substitute in Left Elbow Joint, Percutaneous Approach */
"0RWM3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Elbow Joint, Percutaneous Approach */
"0RWM40Z" = "1" /* Revision of Drainage Device in Left Elbow Joint, Percutaneous Endoscopic Approach */
"0RWM43Z" = "1" /* Revision of Infusion Device in Left Elbow Joint, Percutaneous Endoscopic Approach */
"0RWM44Z" = "1" /* Revision of Internal Fixation Device in Left Elbow Joint, Percutaneous Endoscopic Approach */
"0RWM45Z" = "1" /* Revision of External Fixation Device in Left Elbow Joint, Percutaneous Endoscopic Approach */
"0RWM47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Elbow Joint, Percutaneous Endoscopic Approach */
"0RWM48Z" = "1" /* Revision of Spacer in Left Elbow Joint, Percutaneous Endoscopic Approach */
"0RWM4JZ" = "1" /* Revision of Synthetic Substitute in Left Elbow Joint, Percutaneous Endoscopic Approach */
"0RWM4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Elbow Joint, Percutaneous Endoscopic Approach */
"0RWN00Z" = "1" /* Revision of Drainage Device in Right Wrist Joint, Open Approach */
"0RWN03Z" = "1" /* Revision of Infusion Device in Right Wrist Joint, Open Approach */
"0RWN04Z" = "1" /* Revision of Internal Fixation Device in Right Wrist Joint, Open Approach */
"0RWN05Z" = "1" /* Revision of External Fixation Device in Right Wrist Joint, Open Approach */
"0RWN07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Wrist Joint, Open Approach */
"0RWN08Z" = "1" /* Revision of Spacer in Right Wrist Joint, Open Approach */
"0RWN0JZ" = "1" /* Revision of Synthetic Substitute in Right Wrist Joint, Open Approach */
"0RWN0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Wrist Joint, Open Approach */
"0RWN30Z" = "1" /* Revision of Drainage Device in Right Wrist Joint, Percutaneous Approach */
"0RWN33Z" = "1" /* Revision of Infusion Device in Right Wrist Joint, Percutaneous Approach */
"0RWN34Z" = "1" /* Revision of Internal Fixation Device in Right Wrist Joint, Percutaneous Approach */
"0RWN35Z" = "1" /* Revision of External Fixation Device in Right Wrist Joint, Percutaneous Approach */
"0RWN37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Wrist Joint, Percutaneous Approach */
"0RWN38Z" = "1" /* Revision of Spacer in Right Wrist Joint, Percutaneous Approach */
"0RWN3JZ" = "1" /* Revision of Synthetic Substitute in Right Wrist Joint, Percutaneous Approach */
"0RWN3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Wrist Joint, Percutaneous Approach */
"0RWN40Z" = "1" /* Revision of Drainage Device in Right Wrist Joint, Percutaneous Endoscopic Approach */
"0RWN43Z" = "1" /* Revision of Infusion Device in Right Wrist Joint, Percutaneous Endoscopic Approach */
"0RWN44Z" = "1" /* Revision of Internal Fixation Device in Right Wrist Joint, Percutaneous Endoscopic Approach */
"0RWN45Z" = "1" /* Revision of External Fixation Device in Right Wrist Joint, Percutaneous Endoscopic Approach */
"0RWN47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Wrist Joint, Percutaneous Endoscopic Approach */
"0RWN48Z" = "1" /* Revision of Spacer in Right Wrist Joint, Percutaneous Endoscopic Approach */
"0RWN4JZ" = "1" /* Revision of Synthetic Substitute in Right Wrist Joint, Percutaneous Endoscopic Approach */
"0RWN4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Wrist Joint, Percutaneous Endoscopic Approach */
"0RWP00Z" = "1" /* Revision of Drainage Device in Left Wrist Joint, Open Approach */
"0RWP03Z" = "1" /* Revision of Infusion Device in Left Wrist Joint, Open Approach */
"0RWP04Z" = "1" /* Revision of Internal Fixation Device in Left Wrist Joint, Open Approach */
"0RWP05Z" = "1" /* Revision of External Fixation Device in Left Wrist Joint, Open Approach */
"0RWP07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Wrist Joint, Open Approach */
"0RWP08Z" = "1" /* Revision of Spacer in Left Wrist Joint, Open Approach */
"0RWP0JZ" = "1" /* Revision of Synthetic Substitute in Left Wrist Joint, Open Approach */
"0RWP0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Wrist Joint, Open Approach */
"0RWP30Z" = "1" /* Revision of Drainage Device in Left Wrist Joint, Percutaneous Approach */
"0RWP33Z" = "1" /* Revision of Infusion Device in Left Wrist Joint, Percutaneous Approach */
"0RWP34Z" = "1" /* Revision of Internal Fixation Device in Left Wrist Joint, Percutaneous Approach */
"0RWP35Z" = "1" /* Revision of External Fixation Device in Left Wrist Joint, Percutaneous Approach */
"0RWP37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Wrist Joint, Percutaneous Approach */
"0RWP38Z" = "1" /* Revision of Spacer in Left Wrist Joint, Percutaneous Approach */
"0RWP3JZ" = "1" /* Revision of Synthetic Substitute in Left Wrist Joint, Percutaneous Approach */
"0RWP3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Wrist Joint, Percutaneous Approach */
"0RWP40Z" = "1" /* Revision of Drainage Device in Left Wrist Joint, Percutaneous Endoscopic Approach */
"0RWP43Z" = "1" /* Revision of Infusion Device in Left Wrist Joint, Percutaneous Endoscopic Approach */
"0RWP44Z" = "1" /* Revision of Internal Fixation Device in Left Wrist Joint, Percutaneous Endoscopic Approach */
"0RWP45Z" = "1" /* Revision of External Fixation Device in Left Wrist Joint, Percutaneous Endoscopic Approach */
"0RWP47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Wrist Joint, Percutaneous Endoscopic Approach */
"0RWP48Z" = "1" /* Revision of Spacer in Left Wrist Joint, Percutaneous Endoscopic Approach */
"0RWP4JZ" = "1" /* Revision of Synthetic Substitute in Left Wrist Joint, Percutaneous Endoscopic Approach */
"0RWP4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Wrist Joint, Percutaneous Endoscopic Approach */
"0RWQ00Z" = "1" /* Revision of Drainage Device in Right Carpal Joint, Open Approach */
"0RWQ03Z" = "1" /* Revision of Infusion Device in Right Carpal Joint, Open Approach */
"0RWQ04Z" = "1" /* Revision of Internal Fixation Device in Right Carpal Joint, Open Approach */
"0RWQ05Z" = "1" /* Revision of External Fixation Device in Right Carpal Joint, Open Approach */
"0RWQ07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Carpal Joint, Open Approach */
"0RWQ08Z" = "1" /* Revision of Spacer in Right Carpal Joint, Open Approach */
"0RWQ0JZ" = "1" /* Revision of Synthetic Substitute in Right Carpal Joint, Open Approach */
"0RWQ0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Carpal Joint, Open Approach */
"0RWQ30Z" = "1" /* Revision of Drainage Device in Right Carpal Joint, Percutaneous Approach */
"0RWQ33Z" = "1" /* Revision of Infusion Device in Right Carpal Joint, Percutaneous Approach */
"0RWQ34Z" = "1" /* Revision of Internal Fixation Device in Right Carpal Joint, Percutaneous Approach */
"0RWQ35Z" = "1" /* Revision of External Fixation Device in Right Carpal Joint, Percutaneous Approach */
"0RWQ37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Carpal Joint, Percutaneous Approach */
"0RWQ38Z" = "1" /* Revision of Spacer in Right Carpal Joint, Percutaneous Approach */
"0RWQ3JZ" = "1" /* Revision of Synthetic Substitute in Right Carpal Joint, Percutaneous Approach */
"0RWQ3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Carpal Joint, Percutaneous Approach */
"0RWQ40Z" = "1" /* Revision of Drainage Device in Right Carpal Joint, Percutaneous Endoscopic Approach */
"0RWQ43Z" = "1" /* Revision of Infusion Device in Right Carpal Joint, Percutaneous Endoscopic Approach */
"0RWQ44Z" = "1" /* Revision of Internal Fixation Device in Right Carpal Joint, Percutaneous Endoscopic Approach */
"0RWQ45Z" = "1" /* Revision of External Fixation Device in Right Carpal Joint, Percutaneous Endoscopic Approach */
"0RWQ47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Carpal Joint, Percutaneous Endoscopic Approach */
"0RWQ48Z" = "1" /* Revision of Spacer in Right Carpal Joint, Percutaneous Endoscopic Approach */
"0RWQ4JZ" = "1" /* Revision of Synthetic Substitute in Right Carpal Joint, Percutaneous Endoscopic Approach */
"0RWQ4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Carpal Joint, Percutaneous Endoscopic Approach */
"0RWR00Z" = "1" /* Revision of Drainage Device in Left Carpal Joint, Open Approach */
"0RWR03Z" = "1" /* Revision of Infusion Device in Left Carpal Joint, Open Approach */
"0RWR04Z" = "1" /* Revision of Internal Fixation Device in Left Carpal Joint, Open Approach */
"0RWR05Z" = "1" /* Revision of External Fixation Device in Left Carpal Joint, Open Approach */
"0RWR07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Carpal Joint, Open Approach */
"0RWR08Z" = "1" /* Revision of Spacer in Left Carpal Joint, Open Approach */
"0RWR0JZ" = "1" /* Revision of Synthetic Substitute in Left Carpal Joint, Open Approach */
"0RWR0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Carpal Joint, Open Approach */
"0RWR30Z" = "1" /* Revision of Drainage Device in Left Carpal Joint, Percutaneous Approach */
"0RWR33Z" = "1" /* Revision of Infusion Device in Left Carpal Joint, Percutaneous Approach */
"0RWR34Z" = "1" /* Revision of Internal Fixation Device in Left Carpal Joint, Percutaneous Approach */
"0RWR35Z" = "1" /* Revision of External Fixation Device in Left Carpal Joint, Percutaneous Approach */
"0RWR37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Carpal Joint, Percutaneous Approach */
"0RWR38Z" = "1" /* Revision of Spacer in Left Carpal Joint, Percutaneous Approach */
"0RWR3JZ" = "1" /* Revision of Synthetic Substitute in Left Carpal Joint, Percutaneous Approach */
"0RWR3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Carpal Joint, Percutaneous Approach */
"0RWR40Z" = "1" /* Revision of Drainage Device in Left Carpal Joint, Percutaneous Endoscopic Approach */
"0RWR43Z" = "1" /* Revision of Infusion Device in Left Carpal Joint, Percutaneous Endoscopic Approach */
"0RWR44Z" = "1" /* Revision of Internal Fixation Device in Left Carpal Joint, Percutaneous Endoscopic Approach */
"0RWR45Z" = "1" /* Revision of External Fixation Device in Left Carpal Joint, Percutaneous Endoscopic Approach */
"0RWR47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Carpal Joint, Percutaneous Endoscopic Approach */
"0RWR48Z" = "1" /* Revision of Spacer in Left Carpal Joint, Percutaneous Endoscopic Approach */
"0RWR4JZ" = "1" /* Revision of Synthetic Substitute in Left Carpal Joint, Percutaneous Endoscopic Approach */
"0RWR4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Carpal Joint, Percutaneous Endoscopic Approach */
"0RWS00Z" = "1" /* Revision of Drainage Device in Right Metacarpocarpal Joint, Open Approach */
"0RWS03Z" = "1" /* Revision of Infusion Device in Right Metacarpocarpal Joint, Open Approach */
"0RWS04Z" = "1" /* Revision of Internal Fixation Device in Right Metacarpocarpal Joint, Open Approach */
"0RWS05Z" = "1" /* Revision of External Fixation Device in Right Metacarpocarpal Joint, Open Approach */
"0RWS07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Metacarpocarpal Joint, Open Approach */
"0RWS08Z" = "1" /* Revision of Spacer in Right Metacarpocarpal Joint, Open Approach */
"0RWS0JZ" = "1" /* Revision of Synthetic Substitute in Right Metacarpocarpal Joint, Open Approach */
"0RWS0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Metacarpocarpal Joint, Open Approach */
"0RWS30Z" = "1" /* Revision of Drainage Device in Right Metacarpocarpal Joint, Percutaneous Approach */
"0RWS33Z" = "1" /* Revision of Infusion Device in Right Metacarpocarpal Joint, Percutaneous Approach */
"0RWS34Z" = "1" /* Revision of Internal Fixation Device in Right Metacarpocarpal Joint, Percutaneous Approach */
"0RWS35Z" = "1" /* Revision of External Fixation Device in Right Metacarpocarpal Joint, Percutaneous Approach */
"0RWS37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Metacarpocarpal Joint, Percutaneous Approach */
"0RWS38Z" = "1" /* Revision of Spacer in Right Metacarpocarpal Joint, Percutaneous Approach */
"0RWS3JZ" = "1" /* Revision of Synthetic Substitute in Right Metacarpocarpal Joint, Percutaneous Approach */
"0RWS3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Metacarpocarpal Joint, Percutaneous Approach */
"0RWS40Z" = "1" /* Revision of Drainage Device in Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RWS43Z" = "1" /* Revision of Infusion Device in Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RWS44Z" = "1" /* Revision of Internal Fixation Device in Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RWS45Z" = "1" /* Revision of External Fixation Device in Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RWS47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RWS48Z" = "1" /* Revision of Spacer in Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RWS4JZ" = "1" /* Revision of Synthetic Substitute in Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RWS4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RWT00Z" = "1" /* Revision of Drainage Device in Left Metacarpocarpal Joint, Open Approach */
"0RWT03Z" = "1" /* Revision of Infusion Device in Left Metacarpocarpal Joint, Open Approach */
"0RWT04Z" = "1" /* Revision of Internal Fixation Device in Left Metacarpocarpal Joint, Open Approach */
"0RWT05Z" = "1" /* Revision of External Fixation Device in Left Metacarpocarpal Joint, Open Approach */
"0RWT07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Metacarpocarpal Joint, Open Approach */
"0RWT08Z" = "1" /* Revision of Spacer in Left Metacarpocarpal Joint, Open Approach */
"0RWT0JZ" = "1" /* Revision of Synthetic Substitute in Left Metacarpocarpal Joint, Open Approach */
"0RWT0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Metacarpocarpal Joint, Open Approach */
"0RWT30Z" = "1" /* Revision of Drainage Device in Left Metacarpocarpal Joint, Percutaneous Approach */
"0RWT33Z" = "1" /* Revision of Infusion Device in Left Metacarpocarpal Joint, Percutaneous Approach */
"0RWT34Z" = "1" /* Revision of Internal Fixation Device in Left Metacarpocarpal Joint, Percutaneous Approach */
"0RWT35Z" = "1" /* Revision of External Fixation Device in Left Metacarpocarpal Joint, Percutaneous Approach */
"0RWT37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Metacarpocarpal Joint, Percutaneous Approach */
"0RWT38Z" = "1" /* Revision of Spacer in Left Metacarpocarpal Joint, Percutaneous Approach */
"0RWT3JZ" = "1" /* Revision of Synthetic Substitute in Left Metacarpocarpal Joint, Percutaneous Approach */
"0RWT3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Metacarpocarpal Joint, Percutaneous Approach */
"0RWT40Z" = "1" /* Revision of Drainage Device in Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RWT43Z" = "1" /* Revision of Infusion Device in Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RWT44Z" = "1" /* Revision of Internal Fixation Device in Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RWT45Z" = "1" /* Revision of External Fixation Device in Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RWT47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RWT48Z" = "1" /* Revision of Spacer in Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RWT4JZ" = "1" /* Revision of Synthetic Substitute in Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RWT4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Metacarpocarpal Joint, Percutaneous Endoscopic Approach */
"0RWU00Z" = "1" /* Revision of Drainage Device in Right Metacarpophalangeal Joint, Open Approach */
"0RWU03Z" = "1" /* Revision of Infusion Device in Right Metacarpophalangeal Joint, Open Approach */
"0RWU04Z" = "1" /* Revision of Internal Fixation Device in Right Metacarpophalangeal Joint, Open Approach */
"0RWU05Z" = "1" /* Revision of External Fixation Device in Right Metacarpophalangeal Joint, Open Approach */
"0RWU07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Metacarpophalangeal Joint, Open Approach */
"0RWU08Z" = "1" /* Revision of Spacer in Right Metacarpophalangeal Joint, Open Approach */
"0RWU0JZ" = "1" /* Revision of Synthetic Substitute in Right Metacarpophalangeal Joint, Open Approach */
"0RWU0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Metacarpophalangeal Joint, Open Approach */
"0RWU30Z" = "1" /* Revision of Drainage Device in Right Metacarpophalangeal Joint, Percutaneous Approach */
"0RWU33Z" = "1" /* Revision of Infusion Device in Right Metacarpophalangeal Joint, Percutaneous Approach */
"0RWU34Z" = "1" /* Revision of Internal Fixation Device in Right Metacarpophalangeal Joint, Percutaneous Approach */
"0RWU35Z" = "1" /* Revision of External Fixation Device in Right Metacarpophalangeal Joint, Percutaneous Approach */
"0RWU37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Metacarpophalangeal Joint, Percutaneous Approach */
"0RWU38Z" = "1" /* Revision of Spacer in Right Metacarpophalangeal Joint, Percutaneous Approach */
"0RWU3JZ" = "1" /* Revision of Synthetic Substitute in Right Metacarpophalangeal Joint, Percutaneous Approach */
"0RWU3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Metacarpophalangeal Joint, Percutaneous Approach */
"0RWU40Z" = "1" /* Revision of Drainage Device in Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RWU43Z" = "1" /* Revision of Infusion Device in Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RWU44Z" = "1" /* Revision of Internal Fixation Device in Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RWU45Z" = "1" /* Revision of External Fixation Device in Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RWU47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RWU48Z" = "1" /* Revision of Spacer in Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RWU4JZ" = "1" /* Revision of Synthetic Substitute in Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RWU4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RWV00Z" = "1" /* Revision of Drainage Device in Left Metacarpophalangeal Joint, Open Approach */
"0RWV03Z" = "1" /* Revision of Infusion Device in Left Metacarpophalangeal Joint, Open Approach */
"0RWV04Z" = "1" /* Revision of Internal Fixation Device in Left Metacarpophalangeal Joint, Open Approach */
"0RWV05Z" = "1" /* Revision of External Fixation Device in Left Metacarpophalangeal Joint, Open Approach */
"0RWV07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Metacarpophalangeal Joint, Open Approach */
"0RWV08Z" = "1" /* Revision of Spacer in Left Metacarpophalangeal Joint, Open Approach */
"0RWV0JZ" = "1" /* Revision of Synthetic Substitute in Left Metacarpophalangeal Joint, Open Approach */
"0RWV0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Metacarpophalangeal Joint, Open Approach */
"0RWV30Z" = "1" /* Revision of Drainage Device in Left Metacarpophalangeal Joint, Percutaneous Approach */
"0RWV33Z" = "1" /* Revision of Infusion Device in Left Metacarpophalangeal Joint, Percutaneous Approach */
"0RWV34Z" = "1" /* Revision of Internal Fixation Device in Left Metacarpophalangeal Joint, Percutaneous Approach */
"0RWV35Z" = "1" /* Revision of External Fixation Device in Left Metacarpophalangeal Joint, Percutaneous Approach */
"0RWV37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Metacarpophalangeal Joint, Percutaneous Approach */
"0RWV38Z" = "1" /* Revision of Spacer in Left Metacarpophalangeal Joint, Percutaneous Approach */
"0RWV3JZ" = "1" /* Revision of Synthetic Substitute in Left Metacarpophalangeal Joint, Percutaneous Approach */
"0RWV3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Metacarpophalangeal Joint, Percutaneous Approach */
"0RWV40Z" = "1" /* Revision of Drainage Device in Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RWV43Z" = "1" /* Revision of Infusion Device in Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RWV44Z" = "1" /* Revision of Internal Fixation Device in Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RWV45Z" = "1" /* Revision of External Fixation Device in Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RWV47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RWV48Z" = "1" /* Revision of Spacer in Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RWV4JZ" = "1" /* Revision of Synthetic Substitute in Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RWV4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Metacarpophalangeal Joint, Percutaneous Endoscopic Approach */
"0RWW00Z" = "1" /* Revision of Drainage Device in Right Finger Phalangeal Joint, Open Approach */
"0RWW03Z" = "1" /* Revision of Infusion Device in Right Finger Phalangeal Joint, Open Approach */
"0RWW04Z" = "1" /* Revision of Internal Fixation Device in Right Finger Phalangeal Joint, Open Approach */
"0RWW05Z" = "1" /* Revision of External Fixation Device in Right Finger Phalangeal Joint, Open Approach */
"0RWW07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Finger Phalangeal Joint, Open Approach */
"0RWW08Z" = "1" /* Revision of Spacer in Right Finger Phalangeal Joint, Open Approach */
"0RWW0JZ" = "1" /* Revision of Synthetic Substitute in Right Finger Phalangeal Joint, Open Approach */
"0RWW0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Finger Phalangeal Joint, Open Approach */
"0RWW30Z" = "1" /* Revision of Drainage Device in Right Finger Phalangeal Joint, Percutaneous Approach */
"0RWW33Z" = "1" /* Revision of Infusion Device in Right Finger Phalangeal Joint, Percutaneous Approach */
"0RWW34Z" = "1" /* Revision of Internal Fixation Device in Right Finger Phalangeal Joint, Percutaneous Approach */
"0RWW35Z" = "1" /* Revision of External Fixation Device in Right Finger Phalangeal Joint, Percutaneous Approach */
"0RWW37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Finger Phalangeal Joint, Percutaneous Approach */
"0RWW38Z" = "1" /* Revision of Spacer in Right Finger Phalangeal Joint, Percutaneous Approach */
"0RWW3JZ" = "1" /* Revision of Synthetic Substitute in Right Finger Phalangeal Joint, Percutaneous Approach */
"0RWW3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Finger Phalangeal Joint, Percutaneous Approach */
"0RWW40Z" = "1" /* Revision of Drainage Device in Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RWW43Z" = "1" /* Revision of Infusion Device in Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RWW44Z" = "1" /* Revision of Internal Fixation Device in Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RWW45Z" = "1" /* Revision of External Fixation Device in Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RWW47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RWW48Z" = "1" /* Revision of Spacer in Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RWW4JZ" = "1" /* Revision of Synthetic Substitute in Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RWW4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RWX00Z" = "1" /* Revision of Drainage Device in Left Finger Phalangeal Joint, Open Approach */
"0RWX03Z" = "1" /* Revision of Infusion Device in Left Finger Phalangeal Joint, Open Approach */
"0RWX04Z" = "1" /* Revision of Internal Fixation Device in Left Finger Phalangeal Joint, Open Approach */
"0RWX05Z" = "1" /* Revision of External Fixation Device in Left Finger Phalangeal Joint, Open Approach */
"0RWX07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Finger Phalangeal Joint, Open Approach */
"0RWX08Z" = "1" /* Revision of Spacer in Left Finger Phalangeal Joint, Open Approach */
"0RWX0JZ" = "1" /* Revision of Synthetic Substitute in Left Finger Phalangeal Joint, Open Approach */
"0RWX0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Finger Phalangeal Joint, Open Approach */
"0RWX30Z" = "1" /* Revision of Drainage Device in Left Finger Phalangeal Joint, Percutaneous Approach */
"0RWX33Z" = "1" /* Revision of Infusion Device in Left Finger Phalangeal Joint, Percutaneous Approach */
"0RWX34Z" = "1" /* Revision of Internal Fixation Device in Left Finger Phalangeal Joint, Percutaneous Approach */
"0RWX35Z" = "1" /* Revision of External Fixation Device in Left Finger Phalangeal Joint, Percutaneous Approach */
"0RWX37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Finger Phalangeal Joint, Percutaneous Approach */
"0RWX38Z" = "1" /* Revision of Spacer in Left Finger Phalangeal Joint, Percutaneous Approach */
"0RWX3JZ" = "1" /* Revision of Synthetic Substitute in Left Finger Phalangeal Joint, Percutaneous Approach */
"0RWX3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Finger Phalangeal Joint, Percutaneous Approach */
"0RWX40Z" = "1" /* Revision of Drainage Device in Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RWX43Z" = "1" /* Revision of Infusion Device in Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RWX44Z" = "1" /* Revision of Internal Fixation Device in Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RWX45Z" = "1" /* Revision of External Fixation Device in Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RWX47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RWX48Z" = "1" /* Revision of Spacer in Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RWX4JZ" = "1" /* Revision of Synthetic Substitute in Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0RWX4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Finger Phalangeal Joint, Percutaneous Endoscopic Approach */
"0S500ZZ" = "1" /* Destruction of Lumbar Vertebral Joint, Open Approach */
"0S503ZZ" = "1" /* Destruction of Lumbar Vertebral Joint, Percutaneous Approach */
"0S504ZZ" = "1" /* Destruction of Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0S520ZZ" = "1" /* Destruction of Lumbar Vertebral Disc, Open Approach */
"0S523ZZ" = "1" /* Destruction of Lumbar Vertebral Disc, Percutaneous Approach */
"0S524ZZ" = "1" /* Destruction of Lumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0S530ZZ" = "1" /* Destruction of Lumbosacral Joint, Open Approach */
"0S533ZZ" = "1" /* Destruction of Lumbosacral Joint, Percutaneous Approach */
"0S534ZZ" = "1" /* Destruction of Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0S540ZZ" = "1" /* Destruction of Lumbosacral Disc, Open Approach */
"0S543ZZ" = "1" /* Destruction of Lumbosacral Disc, Percutaneous Approach */
"0S544ZZ" = "1" /* Destruction of Lumbosacral Disc, Percutaneous Endoscopic Approach */
"0S550ZZ" = "1" /* Destruction of Sacrococcygeal Joint, Open Approach */
"0S553ZZ" = "1" /* Destruction of Sacrococcygeal Joint, Percutaneous Approach */
"0S554ZZ" = "1" /* Destruction of Sacrococcygeal Joint, Percutaneous Endoscopic Approach */
"0S560ZZ" = "1" /* Destruction of Coccygeal Joint, Open Approach */
"0S563ZZ" = "1" /* Destruction of Coccygeal Joint, Percutaneous Approach */
"0S564ZZ" = "1" /* Destruction of Coccygeal Joint, Percutaneous Endoscopic Approach */
"0S570ZZ" = "1" /* Destruction of Right Sacroiliac Joint, Open Approach */
"0S573ZZ" = "1" /* Destruction of Right Sacroiliac Joint, Percutaneous Approach */
"0S574ZZ" = "1" /* Destruction of Right Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0S580ZZ" = "1" /* Destruction of Left Sacroiliac Joint, Open Approach */
"0S583ZZ" = "1" /* Destruction of Left Sacroiliac Joint, Percutaneous Approach */
"0S584ZZ" = "1" /* Destruction of Left Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0S590ZZ" = "1" /* Destruction of Right Hip Joint, Open Approach */
"0S593ZZ" = "1" /* Destruction of Right Hip Joint, Percutaneous Approach */
"0S594ZZ" = "1" /* Destruction of Right Hip Joint, Percutaneous Endoscopic Approach */
"0S5B0ZZ" = "1" /* Destruction of Left Hip Joint, Open Approach */
"0S5B3ZZ" = "1" /* Destruction of Left Hip Joint, Percutaneous Approach */
"0S5B4ZZ" = "1" /* Destruction of Left Hip Joint, Percutaneous Endoscopic Approach */
"0S5C0ZZ" = "1" /* Destruction of Right Knee Joint, Open Approach */
"0S5C3ZZ" = "1" /* Destruction of Right Knee Joint, Percutaneous Approach */
"0S5C4ZZ" = "1" /* Destruction of Right Knee Joint, Percutaneous Endoscopic Approach */
"0S5D0ZZ" = "1" /* Destruction of Left Knee Joint, Open Approach */
"0S5D3ZZ" = "1" /* Destruction of Left Knee Joint, Percutaneous Approach */
"0S5D4ZZ" = "1" /* Destruction of Left Knee Joint, Percutaneous Endoscopic Approach */
"0S5F0ZZ" = "1" /* Destruction of Right Ankle Joint, Open Approach */
"0S5F3ZZ" = "1" /* Destruction of Right Ankle Joint, Percutaneous Approach */
"0S5F4ZZ" = "1" /* Destruction of Right Ankle Joint, Percutaneous Endoscopic Approach */
"0S5G0ZZ" = "1" /* Destruction of Left Ankle Joint, Open Approach */
"0S5G3ZZ" = "1" /* Destruction of Left Ankle Joint, Percutaneous Approach */
"0S5G4ZZ" = "1" /* Destruction of Left Ankle Joint, Percutaneous Endoscopic Approach */
"0S5H0ZZ" = "1" /* Destruction of Right Tarsal Joint, Open Approach */
"0S5H3ZZ" = "1" /* Destruction of Right Tarsal Joint, Percutaneous Approach */
"0S5H4ZZ" = "1" /* Destruction of Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0S5J0ZZ" = "1" /* Destruction of Left Tarsal Joint, Open Approach */
"0S5J3ZZ" = "1" /* Destruction of Left Tarsal Joint, Percutaneous Approach */
"0S5J4ZZ" = "1" /* Destruction of Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0S5K0ZZ" = "1" /* Destruction of Right Metatarsal-Tarsal Joint, Open Approach */
"0S5K3ZZ" = "1" /* Destruction of Right Metatarsal-Tarsal Joint, Percutaneous Approach */
"0S5K4ZZ" = "1" /* Destruction of Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0S5L0ZZ" = "1" /* Destruction of Left Metatarsal-Tarsal Joint, Open Approach */
"0S5L3ZZ" = "1" /* Destruction of Left Metatarsal-Tarsal Joint, Percutaneous Approach */
"0S5L4ZZ" = "1" /* Destruction of Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0S5M0ZZ" = "1" /* Destruction of Right Metatarsal-Phalangeal Joint, Open Approach */
"0S5M3ZZ" = "1" /* Destruction of Right Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0S5M4ZZ" = "1" /* Destruction of Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0S5N0ZZ" = "1" /* Destruction of Left Metatarsal-Phalangeal Joint, Open Approach */
"0S5N3ZZ" = "1" /* Destruction of Left Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0S5N4ZZ" = "1" /* Destruction of Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0S5P0ZZ" = "1" /* Destruction of Right Toe Phalangeal Joint, Open Approach */
"0S5P3ZZ" = "1" /* Destruction of Right Toe Phalangeal Joint, Percutaneous Approach */
"0S5P4ZZ" = "1" /* Destruction of Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0S5Q0ZZ" = "1" /* Destruction of Left Toe Phalangeal Joint, Open Approach */
"0S5Q3ZZ" = "1" /* Destruction of Left Toe Phalangeal Joint, Percutaneous Approach */
"0S5Q4ZZ" = "1" /* Destruction of Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0S9000Z" = "1" /* Drainage of Lumbar Vertebral Joint with Drainage Device, Open Approach */
"0S900ZZ" = "1" /* Drainage of Lumbar Vertebral Joint, Open Approach */
"0S9200Z" = "1" /* Drainage of Lumbar Vertebral Disc with Drainage Device, Open Approach */
"0S920ZZ" = "1" /* Drainage of Lumbar Vertebral Disc, Open Approach */
"0S9300Z" = "1" /* Drainage of Lumbosacral Joint with Drainage Device, Open Approach */
"0S930ZZ" = "1" /* Drainage of Lumbosacral Joint, Open Approach */
"0S9400Z" = "1" /* Drainage of Lumbosacral Disc with Drainage Device, Open Approach */
"0S940ZZ" = "1" /* Drainage of Lumbosacral Disc, Open Approach */
"0S9500Z" = "1" /* Drainage of Sacrococcygeal Joint with Drainage Device, Open Approach */
"0S950ZZ" = "1" /* Drainage of Sacrococcygeal Joint, Open Approach */
"0S9600Z" = "1" /* Drainage of Coccygeal Joint with Drainage Device, Open Approach */
"0S960ZZ" = "1" /* Drainage of Coccygeal Joint, Open Approach */
"0S9700Z" = "1" /* Drainage of Right Sacroiliac Joint with Drainage Device, Open Approach */
"0S970ZZ" = "1" /* Drainage of Right Sacroiliac Joint, Open Approach */
"0S9800Z" = "1" /* Drainage of Left Sacroiliac Joint with Drainage Device, Open Approach */
"0S980ZZ" = "1" /* Drainage of Left Sacroiliac Joint, Open Approach */
"0S9900Z" = "1" /* Drainage of Right Hip Joint with Drainage Device, Open Approach */
"0S990ZZ" = "1" /* Drainage of Right Hip Joint, Open Approach */
"0S9B00Z" = "1" /* Drainage of Left Hip Joint with Drainage Device, Open Approach */
"0S9B0ZZ" = "1" /* Drainage of Left Hip Joint, Open Approach */
"0S9C00Z" = "1" /* Drainage of Right Knee Joint with Drainage Device, Open Approach */
"0S9C0ZZ" = "1" /* Drainage of Right Knee Joint, Open Approach */
"0S9D00Z" = "1" /* Drainage of Left Knee Joint with Drainage Device, Open Approach */
"0S9D0ZZ" = "1" /* Drainage of Left Knee Joint, Open Approach */
"0S9F00Z" = "1" /* Drainage of Right Ankle Joint with Drainage Device, Open Approach */
"0S9F0ZZ" = "1" /* Drainage of Right Ankle Joint, Open Approach */
"0S9G00Z" = "1" /* Drainage of Left Ankle Joint with Drainage Device, Open Approach */
"0S9G0ZZ" = "1" /* Drainage of Left Ankle Joint, Open Approach */
"0S9H00Z" = "1" /* Drainage of Right Tarsal Joint with Drainage Device, Open Approach */
"0S9H0ZZ" = "1" /* Drainage of Right Tarsal Joint, Open Approach */
"0S9J00Z" = "1" /* Drainage of Left Tarsal Joint with Drainage Device, Open Approach */
"0S9J0ZZ" = "1" /* Drainage of Left Tarsal Joint, Open Approach */
"0S9K00Z" = "1" /* Drainage of Right Metatarsal-Tarsal Joint with Drainage Device, Open Approach */
"0S9K0ZZ" = "1" /* Drainage of Right Metatarsal-Tarsal Joint, Open Approach */
"0S9L00Z" = "1" /* Drainage of Left Metatarsal-Tarsal Joint with Drainage Device, Open Approach */
"0S9L0ZZ" = "1" /* Drainage of Left Metatarsal-Tarsal Joint, Open Approach */
"0S9M00Z" = "1" /* Drainage of Right Metatarsal-Phalangeal Joint with Drainage Device, Open Approach */
"0S9M0ZZ" = "1" /* Drainage of Right Metatarsal-Phalangeal Joint, Open Approach */
"0S9N00Z" = "1" /* Drainage of Left Metatarsal-Phalangeal Joint with Drainage Device, Open Approach */
"0S9N0ZZ" = "1" /* Drainage of Left Metatarsal-Phalangeal Joint, Open Approach */
"0S9P00Z" = "1" /* Drainage of Right Toe Phalangeal Joint with Drainage Device, Open Approach */
"0S9P0ZZ" = "1" /* Drainage of Right Toe Phalangeal Joint, Open Approach */
"0S9Q00Z" = "1" /* Drainage of Left Toe Phalangeal Joint with Drainage Device, Open Approach */
"0S9Q0ZZ" = "1" /* Drainage of Left Toe Phalangeal Joint, Open Approach */
"0SB00ZZ" = "1" /* Excision of Lumbar Vertebral Joint, Open Approach */
"0SB03ZZ" = "1" /* Excision of Lumbar Vertebral Joint, Percutaneous Approach */
"0SB04ZZ" = "1" /* Excision of Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SB20ZZ" = "1" /* Excision of Lumbar Vertebral Disc, Open Approach */
"0SB23ZZ" = "1" /* Excision of Lumbar Vertebral Disc, Percutaneous Approach */
"0SB24ZZ" = "1" /* Excision of Lumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0SB30ZZ" = "1" /* Excision of Lumbosacral Joint, Open Approach */
"0SB33ZZ" = "1" /* Excision of Lumbosacral Joint, Percutaneous Approach */
"0SB34ZZ" = "1" /* Excision of Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SB40ZZ" = "1" /* Excision of Lumbosacral Disc, Open Approach */
"0SB43ZZ" = "1" /* Excision of Lumbosacral Disc, Percutaneous Approach */
"0SB44ZZ" = "1" /* Excision of Lumbosacral Disc, Percutaneous Endoscopic Approach */
"0SB50ZZ" = "1" /* Excision of Sacrococcygeal Joint, Open Approach */
"0SB53ZZ" = "1" /* Excision of Sacrococcygeal Joint, Percutaneous Approach */
"0SB54ZZ" = "1" /* Excision of Sacrococcygeal Joint, Percutaneous Endoscopic Approach */
"0SB60ZZ" = "1" /* Excision of Coccygeal Joint, Open Approach */
"0SB63ZZ" = "1" /* Excision of Coccygeal Joint, Percutaneous Approach */
"0SB64ZZ" = "1" /* Excision of Coccygeal Joint, Percutaneous Endoscopic Approach */
"0SB70ZZ" = "1" /* Excision of Right Sacroiliac Joint, Open Approach */
"0SB73ZZ" = "1" /* Excision of Right Sacroiliac Joint, Percutaneous Approach */
"0SB74ZZ" = "1" /* Excision of Right Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SB80ZZ" = "1" /* Excision of Left Sacroiliac Joint, Open Approach */
"0SB83ZZ" = "1" /* Excision of Left Sacroiliac Joint, Percutaneous Approach */
"0SB84ZZ" = "1" /* Excision of Left Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SB90ZZ" = "1" /* Excision of Right Hip Joint, Open Approach */
"0SB93ZZ" = "1" /* Excision of Right Hip Joint, Percutaneous Approach */
"0SB94ZZ" = "1" /* Excision of Right Hip Joint, Percutaneous Endoscopic Approach */
"0SBB0ZZ" = "1" /* Excision of Left Hip Joint, Open Approach */
"0SBB3ZZ" = "1" /* Excision of Left Hip Joint, Percutaneous Approach */
"0SBB4ZZ" = "1" /* Excision of Left Hip Joint, Percutaneous Endoscopic Approach */
"0SBC0ZZ" = "1" /* Excision of Right Knee Joint, Open Approach */
"0SBC3ZZ" = "1" /* Excision of Right Knee Joint, Percutaneous Approach */
"0SBC4ZZ" = "1" /* Excision of Right Knee Joint, Percutaneous Endoscopic Approach */
"0SBD0ZZ" = "1" /* Excision of Left Knee Joint, Open Approach */
"0SBD3ZZ" = "1" /* Excision of Left Knee Joint, Percutaneous Approach */
"0SBD4ZZ" = "1" /* Excision of Left Knee Joint, Percutaneous Endoscopic Approach */
"0SBF0ZZ" = "1" /* Excision of Right Ankle Joint, Open Approach */
"0SBF3ZZ" = "1" /* Excision of Right Ankle Joint, Percutaneous Approach */
"0SBF4ZZ" = "1" /* Excision of Right Ankle Joint, Percutaneous Endoscopic Approach */
"0SBG0ZZ" = "1" /* Excision of Left Ankle Joint, Open Approach */
"0SBG3ZZ" = "1" /* Excision of Left Ankle Joint, Percutaneous Approach */
"0SBG4ZZ" = "1" /* Excision of Left Ankle Joint, Percutaneous Endoscopic Approach */
"0SBH0ZZ" = "1" /* Excision of Right Tarsal Joint, Open Approach */
"0SBH3ZZ" = "1" /* Excision of Right Tarsal Joint, Percutaneous Approach */
"0SBH4ZZ" = "1" /* Excision of Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0SBJ0ZZ" = "1" /* Excision of Left Tarsal Joint, Open Approach */
"0SBJ3ZZ" = "1" /* Excision of Left Tarsal Joint, Percutaneous Approach */
"0SBJ4ZZ" = "1" /* Excision of Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0SBK0ZZ" = "1" /* Excision of Right Metatarsal-Tarsal Joint, Open Approach */
"0SBK3ZZ" = "1" /* Excision of Right Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SBK4ZZ" = "1" /* Excision of Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SBL0ZZ" = "1" /* Excision of Left Metatarsal-Tarsal Joint, Open Approach */
"0SBL3ZZ" = "1" /* Excision of Left Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SBL4ZZ" = "1" /* Excision of Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SBM0ZZ" = "1" /* Excision of Right Metatarsal-Phalangeal Joint, Open Approach */
"0SBM3ZZ" = "1" /* Excision of Right Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SBM4ZZ" = "1" /* Excision of Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SBN0ZZ" = "1" /* Excision of Left Metatarsal-Phalangeal Joint, Open Approach */
"0SBN3ZZ" = "1" /* Excision of Left Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SBN4ZZ" = "1" /* Excision of Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SBP0ZZ" = "1" /* Excision of Right Toe Phalangeal Joint, Open Approach */
"0SBP3ZZ" = "1" /* Excision of Right Toe Phalangeal Joint, Percutaneous Approach */
"0SBP4ZZ" = "1" /* Excision of Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SBQ0ZZ" = "1" /* Excision of Left Toe Phalangeal Joint, Open Approach */
"0SBQ3ZZ" = "1" /* Excision of Left Toe Phalangeal Joint, Percutaneous Approach */
"0SBQ4ZZ" = "1" /* Excision of Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SC00ZZ" = "1" /* Extirpation of Matter from Lumbar Vertebral Joint, Open Approach */
"0SC03ZZ" = "1" /* Extirpation of Matter from Lumbar Vertebral Joint, Percutaneous Approach */
"0SC04ZZ" = "1" /* Extirpation of Matter from Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SC20ZZ" = "1" /* Extirpation of Matter from Lumbar Vertebral Disc, Open Approach */
"0SC23ZZ" = "1" /* Extirpation of Matter from Lumbar Vertebral Disc, Percutaneous Approach */
"0SC24ZZ" = "1" /* Extirpation of Matter from Lumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0SC30ZZ" = "1" /* Extirpation of Matter from Lumbosacral Joint, Open Approach */
"0SC33ZZ" = "1" /* Extirpation of Matter from Lumbosacral Joint, Percutaneous Approach */
"0SC34ZZ" = "1" /* Extirpation of Matter from Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SC40ZZ" = "1" /* Extirpation of Matter from Lumbosacral Disc, Open Approach */
"0SC43ZZ" = "1" /* Extirpation of Matter from Lumbosacral Disc, Percutaneous Approach */
"0SC44ZZ" = "1" /* Extirpation of Matter from Lumbosacral Disc, Percutaneous Endoscopic Approach */
"0SC50ZZ" = "1" /* Extirpation of Matter from Sacrococcygeal Joint, Open Approach */
"0SC53ZZ" = "1" /* Extirpation of Matter from Sacrococcygeal Joint, Percutaneous Approach */
"0SC54ZZ" = "1" /* Extirpation of Matter from Sacrococcygeal Joint, Percutaneous Endoscopic Approach */
"0SC60ZZ" = "1" /* Extirpation of Matter from Coccygeal Joint, Open Approach */
"0SC63ZZ" = "1" /* Extirpation of Matter from Coccygeal Joint, Percutaneous Approach */
"0SC64ZZ" = "1" /* Extirpation of Matter from Coccygeal Joint, Percutaneous Endoscopic Approach */
"0SC70ZZ" = "1" /* Extirpation of Matter from Right Sacroiliac Joint, Open Approach */
"0SC73ZZ" = "1" /* Extirpation of Matter from Right Sacroiliac Joint, Percutaneous Approach */
"0SC74ZZ" = "1" /* Extirpation of Matter from Right Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SC80ZZ" = "1" /* Extirpation of Matter from Left Sacroiliac Joint, Open Approach */
"0SC83ZZ" = "1" /* Extirpation of Matter from Left Sacroiliac Joint, Percutaneous Approach */
"0SC84ZZ" = "1" /* Extirpation of Matter from Left Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SC90ZZ" = "1" /* Extirpation of Matter from Right Hip Joint, Open Approach */
"0SC93ZZ" = "1" /* Extirpation of Matter from Right Hip Joint, Percutaneous Approach */
"0SC94ZZ" = "1" /* Extirpation of Matter from Right Hip Joint, Percutaneous Endoscopic Approach */
"0SCB0ZZ" = "1" /* Extirpation of Matter from Left Hip Joint, Open Approach */
"0SCB3ZZ" = "1" /* Extirpation of Matter from Left Hip Joint, Percutaneous Approach */
"0SCB4ZZ" = "1" /* Extirpation of Matter from Left Hip Joint, Percutaneous Endoscopic Approach */
"0SCC0ZZ" = "1" /* Extirpation of Matter from Right Knee Joint, Open Approach */
"0SCC3ZZ" = "1" /* Extirpation of Matter from Right Knee Joint, Percutaneous Approach */
"0SCC4ZZ" = "1" /* Extirpation of Matter from Right Knee Joint, Percutaneous Endoscopic Approach */
"0SCD0ZZ" = "1" /* Extirpation of Matter from Left Knee Joint, Open Approach */
"0SCD3ZZ" = "1" /* Extirpation of Matter from Left Knee Joint, Percutaneous Approach */
"0SCD4ZZ" = "1" /* Extirpation of Matter from Left Knee Joint, Percutaneous Endoscopic Approach */
"0SCF0ZZ" = "1" /* Extirpation of Matter from Right Ankle Joint, Open Approach */
"0SCF3ZZ" = "1" /* Extirpation of Matter from Right Ankle Joint, Percutaneous Approach */
"0SCF4ZZ" = "1" /* Extirpation of Matter from Right Ankle Joint, Percutaneous Endoscopic Approach */
"0SCG0ZZ" = "1" /* Extirpation of Matter from Left Ankle Joint, Open Approach */
"0SCG3ZZ" = "1" /* Extirpation of Matter from Left Ankle Joint, Percutaneous Approach */
"0SCG4ZZ" = "1" /* Extirpation of Matter from Left Ankle Joint, Percutaneous Endoscopic Approach */
"0SCH0ZZ" = "1" /* Extirpation of Matter from Right Tarsal Joint, Open Approach */
"0SCH3ZZ" = "1" /* Extirpation of Matter from Right Tarsal Joint, Percutaneous Approach */
"0SCH4ZZ" = "1" /* Extirpation of Matter from Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0SCJ0ZZ" = "1" /* Extirpation of Matter from Left Tarsal Joint, Open Approach */
"0SCJ3ZZ" = "1" /* Extirpation of Matter from Left Tarsal Joint, Percutaneous Approach */
"0SCJ4ZZ" = "1" /* Extirpation of Matter from Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0SCK0ZZ" = "1" /* Extirpation of Matter from Right Metatarsal-Tarsal Joint, Open Approach */
"0SCK3ZZ" = "1" /* Extirpation of Matter from Right Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SCK4ZZ" = "1" /* Extirpation of Matter from Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SCL0ZZ" = "1" /* Extirpation of Matter from Left Metatarsal-Tarsal Joint, Open Approach */
"0SCL3ZZ" = "1" /* Extirpation of Matter from Left Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SCL4ZZ" = "1" /* Extirpation of Matter from Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SCM0ZZ" = "1" /* Extirpation of Matter from Right Metatarsal-Phalangeal Joint, Open Approach */
"0SCM3ZZ" = "1" /* Extirpation of Matter from Right Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SCM4ZZ" = "1" /* Extirpation of Matter from Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SCN0ZZ" = "1" /* Extirpation of Matter from Left Metatarsal-Phalangeal Joint, Open Approach */
"0SCN3ZZ" = "1" /* Extirpation of Matter from Left Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SCN4ZZ" = "1" /* Extirpation of Matter from Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SCP0ZZ" = "1" /* Extirpation of Matter from Right Toe Phalangeal Joint, Open Approach */
"0SCP3ZZ" = "1" /* Extirpation of Matter from Right Toe Phalangeal Joint, Percutaneous Approach */
"0SCP4ZZ" = "1" /* Extirpation of Matter from Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SCQ0ZZ" = "1" /* Extirpation of Matter from Left Toe Phalangeal Joint, Open Approach */
"0SCQ3ZZ" = "1" /* Extirpation of Matter from Left Toe Phalangeal Joint, Percutaneous Approach */
"0SCQ4ZZ" = "1" /* Extirpation of Matter from Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SG0070" = "1" /* Fusion of Lumbar Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG0071" = "1" /* Fusion of Lumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0SG007J" = "1" /* Fusion of Lumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0SG00A0" = "1" /* Fusion of Lumbar Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0SG00A1" = "1" /* Fusion of Lumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Open Approach */
"0SG00AJ" = "1" /* Fusion of Lumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Open Approach */
"0SG00J0" = "1" /* Fusion of Lumbar Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG00J1" = "1" /* Fusion of Lumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Open Approach */
"0SG00JJ" = "1" /* Fusion of Lumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Open Approach */
"0SG00K0" = "1" /* Fusion of Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG00K1" = "1" /* Fusion of Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0SG00KJ" = "1" /* Fusion of Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0SG00Z0" = "1" /* Fusion of Lumbar Vertebral Joint, Anterior Approach, Anterior Column, Open Approach */
"0SG00Z1" = "1" /* Fusion of Lumbar Vertebral Joint, Posterior Approach, Posterior Column, Open Approach */
"0SG00ZJ" = "1" /* Fusion of Lumbar Vertebral Joint, Posterior Approach, Anterior Column, Open Approach */
"0SG0370" = "1" /* Fusion of Lumbar Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG0371" = "1" /* Fusion of Lumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG037J" = "1" /* Fusion of Lumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG03A0" = "1" /* Fusion of Lumbar Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG03A1" = "1" /* Fusion of Lumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG03AJ" = "1" /* Fusion of Lumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG03J0" = "1" /* Fusion of Lumbar Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG03J1" = "1" /* Fusion of Lumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG03JJ" = "1" /* Fusion of Lumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG03K0" = "1" /* Fusion of Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG03K1" = "1" /* Fusion of Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG03KJ" = "1" /* Fusion of Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG03Z0" = "1" /* Fusion of Lumbar Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG03Z1" = "1" /* Fusion of Lumbar Vertebral Joint, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG03ZJ" = "1" /* Fusion of Lumbar Vertebral Joint, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG0470" = "1" /* Fusion of Lumbar Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG0471" = "1" /* Fusion of Lumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG047J" = "1" /* Fusion of Lumbar Vertebral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG04A0" = "1" /* Fusion of Lumbar Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG04A1" = "1" /* Fusion of Lumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG04AJ" = "1" /* Fusion of Lumbar Vertebral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG04J0" = "1" /* Fusion of Lumbar Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG04J1" = "1" /* Fusion of Lumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG04JJ" = "1" /* Fusion of Lumbar Vertebral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG04K0" = "1" /* Fusion of Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG04K1" = "1" /* Fusion of Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG04KJ" = "1" /* Fusion of Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG04Z0" = "1" /* Fusion of Lumbar Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG04Z1" = "1" /* Fusion of Lumbar Vertebral Joint, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG04ZJ" = "1" /* Fusion of Lumbar Vertebral Joint, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG1070" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG1071" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0SG107J" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0SG10A0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0SG10A1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Open Approach */
"0SG10AJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Open Approach */
"0SG10J0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG10J1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Open Approach */
"0SG10JJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Open Approach */
"0SG10K0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG10K1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0SG10KJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0SG10Z0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints, Anterior Approach, Anterior Column, Open Approach */
"0SG10Z1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints, Posterior Approach, Posterior Column, Open Approach */
"0SG10ZJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints, Posterior Approach, Anterior Column, Open Approach */
"0SG1370" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG1371" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG137J" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG13A0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG13A1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG13AJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG13J0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG13J1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG13JJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG13K0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG13K1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG13KJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG13Z0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG13Z1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG13ZJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG1470" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG1471" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG147J" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG14A0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG14A1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG14AJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG14J0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG14J1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG14JJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG14K0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG14K1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG14KJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG14Z0" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG14Z1" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG14ZJ" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG3070" = "1" /* Fusion of Lumbosacral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG3071" = "1" /* Fusion of Lumbosacral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0SG307J" = "1" /* Fusion of Lumbosacral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0SG30A0" = "1" /* Fusion of Lumbosacral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0SG30A1" = "1" /* Fusion of Lumbosacral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Open Approach */
"0SG30AJ" = "1" /* Fusion of Lumbosacral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Open Approach */
"0SG30J0" = "1" /* Fusion of Lumbosacral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG30J1" = "1" /* Fusion of Lumbosacral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Open Approach */
"0SG30JJ" = "1" /* Fusion of Lumbosacral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Open Approach */
"0SG30K0" = "1" /* Fusion of Lumbosacral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0SG30K1" = "1" /* Fusion of Lumbosacral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Open Approach */
"0SG30KJ" = "1" /* Fusion of Lumbosacral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Open Approach */
"0SG30Z0" = "1" /* Fusion of Lumbosacral Joint, Anterior Approach, Anterior Column, Open Approach */
"0SG30Z1" = "1" /* Fusion of Lumbosacral Joint, Posterior Approach, Posterior Column, Open Approach */
"0SG30ZJ" = "1" /* Fusion of Lumbosacral Joint, Posterior Approach, Anterior Column, Open Approach */
"0SG3370" = "1" /* Fusion of Lumbosacral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG3371" = "1" /* Fusion of Lumbosacral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG337J" = "1" /* Fusion of Lumbosacral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG33A0" = "1" /* Fusion of Lumbosacral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG33A1" = "1" /* Fusion of Lumbosacral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG33AJ" = "1" /* Fusion of Lumbosacral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG33J0" = "1" /* Fusion of Lumbosacral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG33J1" = "1" /* Fusion of Lumbosacral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG33JJ" = "1" /* Fusion of Lumbosacral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG33K0" = "1" /* Fusion of Lumbosacral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG33K1" = "1" /* Fusion of Lumbosacral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG33KJ" = "1" /* Fusion of Lumbosacral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG33Z0" = "1" /* Fusion of Lumbosacral Joint, Anterior Approach, Anterior Column, Percutaneous Approach */
"0SG33Z1" = "1" /* Fusion of Lumbosacral Joint, Posterior Approach, Posterior Column, Percutaneous Approach */
"0SG33ZJ" = "1" /* Fusion of Lumbosacral Joint, Posterior Approach, Anterior Column, Percutaneous Approach */
"0SG3470" = "1" /* Fusion of Lumbosacral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG3471" = "1" /* Fusion of Lumbosacral Joint with Autologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG347J" = "1" /* Fusion of Lumbosacral Joint with Autologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG34A0" = "1" /* Fusion of Lumbosacral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG34A1" = "1" /* Fusion of Lumbosacral Joint with Interbody Fusion Device, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG34AJ" = "1" /* Fusion of Lumbosacral Joint with Interbody Fusion Device, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG34J0" = "1" /* Fusion of Lumbosacral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG34J1" = "1" /* Fusion of Lumbosacral Joint with Synthetic Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG34JJ" = "1" /* Fusion of Lumbosacral Joint with Synthetic Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG34K0" = "1" /* Fusion of Lumbosacral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG34K1" = "1" /* Fusion of Lumbosacral Joint with Nonautologous Tissue Substitute, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG34KJ" = "1" /* Fusion of Lumbosacral Joint with Nonautologous Tissue Substitute, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG34Z0" = "1" /* Fusion of Lumbosacral Joint, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG34Z1" = "1" /* Fusion of Lumbosacral Joint, Posterior Approach, Posterior Column, Percutaneous Endoscopic Approach */
"0SG34ZJ" = "1" /* Fusion of Lumbosacral Joint, Posterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0SG504Z" = "1" /* Fusion of Sacrococcygeal Joint with Internal Fixation Device, Open Approach */
"0SG507Z" = "1" /* Fusion of Sacrococcygeal Joint with Autologous Tissue Substitute, Open Approach */
"0SG50JZ" = "1" /* Fusion of Sacrococcygeal Joint with Synthetic Substitute, Open Approach */
"0SG50KZ" = "1" /* Fusion of Sacrococcygeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SG50ZZ" = "1" /* Fusion of Sacrococcygeal Joint, Open Approach */
"0SG534Z" = "1" /* Fusion of Sacrococcygeal Joint with Internal Fixation Device, Percutaneous Approach */
"0SG537Z" = "1" /* Fusion of Sacrococcygeal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SG53JZ" = "1" /* Fusion of Sacrococcygeal Joint with Synthetic Substitute, Percutaneous Approach */
"0SG53KZ" = "1" /* Fusion of Sacrococcygeal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SG53ZZ" = "1" /* Fusion of Sacrococcygeal Joint, Percutaneous Approach */
"0SG544Z" = "1" /* Fusion of Sacrococcygeal Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0SG547Z" = "1" /* Fusion of Sacrococcygeal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SG54JZ" = "1" /* Fusion of Sacrococcygeal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SG54KZ" = "1" /* Fusion of Sacrococcygeal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SG54ZZ" = "1" /* Fusion of Sacrococcygeal Joint, Percutaneous Endoscopic Approach */
"0SG604Z" = "1" /* Fusion of Coccygeal Joint with Internal Fixation Device, Open Approach */
"0SG607Z" = "1" /* Fusion of Coccygeal Joint with Autologous Tissue Substitute, Open Approach */
"0SG60JZ" = "1" /* Fusion of Coccygeal Joint with Synthetic Substitute, Open Approach */
"0SG60KZ" = "1" /* Fusion of Coccygeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SG60ZZ" = "1" /* Fusion of Coccygeal Joint, Open Approach */
"0SG634Z" = "1" /* Fusion of Coccygeal Joint with Internal Fixation Device, Percutaneous Approach */
"0SG637Z" = "1" /* Fusion of Coccygeal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SG63JZ" = "1" /* Fusion of Coccygeal Joint with Synthetic Substitute, Percutaneous Approach */
"0SG63KZ" = "1" /* Fusion of Coccygeal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SG63ZZ" = "1" /* Fusion of Coccygeal Joint, Percutaneous Approach */
"0SG644Z" = "1" /* Fusion of Coccygeal Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0SG647Z" = "1" /* Fusion of Coccygeal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SG64JZ" = "1" /* Fusion of Coccygeal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SG64KZ" = "1" /* Fusion of Coccygeal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SG64ZZ" = "1" /* Fusion of Coccygeal Joint, Percutaneous Endoscopic Approach */
"0SG704Z" = "1" /* Fusion of Right Sacroiliac Joint with Internal Fixation Device, Open Approach */
"0SG707Z" = "1" /* Fusion of Right Sacroiliac Joint with Autologous Tissue Substitute, Open Approach */
"0SG70JZ" = "1" /* Fusion of Right Sacroiliac Joint with Synthetic Substitute, Open Approach */
"0SG70KZ" = "1" /* Fusion of Right Sacroiliac Joint with Nonautologous Tissue Substitute, Open Approach */
"0SG70ZZ" = "1" /* Fusion of Right Sacroiliac Joint, Open Approach */
"0SG734Z" = "1" /* Fusion of Right Sacroiliac Joint with Internal Fixation Device, Percutaneous Approach */
"0SG737Z" = "1" /* Fusion of Right Sacroiliac Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SG73JZ" = "1" /* Fusion of Right Sacroiliac Joint with Synthetic Substitute, Percutaneous Approach */
"0SG73KZ" = "1" /* Fusion of Right Sacroiliac Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SG73ZZ" = "1" /* Fusion of Right Sacroiliac Joint, Percutaneous Approach */
"0SG744Z" = "1" /* Fusion of Right Sacroiliac Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0SG747Z" = "1" /* Fusion of Right Sacroiliac Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SG74JZ" = "1" /* Fusion of Right Sacroiliac Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SG74KZ" = "1" /* Fusion of Right Sacroiliac Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SG74ZZ" = "1" /* Fusion of Right Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SG804Z" = "1" /* Fusion of Left Sacroiliac Joint with Internal Fixation Device, Open Approach */
"0SG807Z" = "1" /* Fusion of Left Sacroiliac Joint with Autologous Tissue Substitute, Open Approach */
"0SG80JZ" = "1" /* Fusion of Left Sacroiliac Joint with Synthetic Substitute, Open Approach */
"0SG80KZ" = "1" /* Fusion of Left Sacroiliac Joint with Nonautologous Tissue Substitute, Open Approach */
"0SG80ZZ" = "1" /* Fusion of Left Sacroiliac Joint, Open Approach */
"0SG834Z" = "1" /* Fusion of Left Sacroiliac Joint with Internal Fixation Device, Percutaneous Approach */
"0SG837Z" = "1" /* Fusion of Left Sacroiliac Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SG83JZ" = "1" /* Fusion of Left Sacroiliac Joint with Synthetic Substitute, Percutaneous Approach */
"0SG83KZ" = "1" /* Fusion of Left Sacroiliac Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SG83ZZ" = "1" /* Fusion of Left Sacroiliac Joint, Percutaneous Approach */
"0SG844Z" = "1" /* Fusion of Left Sacroiliac Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0SG847Z" = "1" /* Fusion of Left Sacroiliac Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SG84JZ" = "1" /* Fusion of Left Sacroiliac Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SG84KZ" = "1" /* Fusion of Left Sacroiliac Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SG84ZZ" = "1" /* Fusion of Left Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SG904Z" = "1" /* Fusion of Right Hip Joint with Internal Fixation Device, Open Approach */
"0SG905Z" = "1" /* Fusion of Right Hip Joint with External Fixation Device, Open Approach */
"0SG907Z" = "1" /* Fusion of Right Hip Joint with Autologous Tissue Substitute, Open Approach */
"0SG90JZ" = "1" /* Fusion of Right Hip Joint with Synthetic Substitute, Open Approach */
"0SG90KZ" = "1" /* Fusion of Right Hip Joint with Nonautologous Tissue Substitute, Open Approach */
"0SG90ZZ" = "1" /* Fusion of Right Hip Joint, Open Approach */
"0SG934Z" = "1" /* Fusion of Right Hip Joint with Internal Fixation Device, Percutaneous Approach */
"0SG935Z" = "1" /* Fusion of Right Hip Joint with External Fixation Device, Percutaneous Approach */
"0SG937Z" = "1" /* Fusion of Right Hip Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SG93JZ" = "1" /* Fusion of Right Hip Joint with Synthetic Substitute, Percutaneous Approach */
"0SG93KZ" = "1" /* Fusion of Right Hip Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SG93ZZ" = "1" /* Fusion of Right Hip Joint, Percutaneous Approach */
"0SG944Z" = "1" /* Fusion of Right Hip Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0SG945Z" = "1" /* Fusion of Right Hip Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0SG947Z" = "1" /* Fusion of Right Hip Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SG94JZ" = "1" /* Fusion of Right Hip Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SG94KZ" = "1" /* Fusion of Right Hip Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SG94ZZ" = "1" /* Fusion of Right Hip Joint, Percutaneous Endoscopic Approach */
"0SGB04Z" = "1" /* Fusion of Left Hip Joint with Internal Fixation Device, Open Approach */
"0SGB05Z" = "1" /* Fusion of Left Hip Joint with External Fixation Device, Open Approach */
"0SGB07Z" = "1" /* Fusion of Left Hip Joint with Autologous Tissue Substitute, Open Approach */
"0SGB0JZ" = "1" /* Fusion of Left Hip Joint with Synthetic Substitute, Open Approach */
"0SGB0KZ" = "1" /* Fusion of Left Hip Joint with Nonautologous Tissue Substitute, Open Approach */
"0SGB0ZZ" = "1" /* Fusion of Left Hip Joint, Open Approach */
"0SGB34Z" = "1" /* Fusion of Left Hip Joint with Internal Fixation Device, Percutaneous Approach */
"0SGB35Z" = "1" /* Fusion of Left Hip Joint with External Fixation Device, Percutaneous Approach */
"0SGB37Z" = "1" /* Fusion of Left Hip Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SGB3JZ" = "1" /* Fusion of Left Hip Joint with Synthetic Substitute, Percutaneous Approach */
"0SGB3KZ" = "1" /* Fusion of Left Hip Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SGB3ZZ" = "1" /* Fusion of Left Hip Joint, Percutaneous Approach */
"0SGB44Z" = "1" /* Fusion of Left Hip Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0SGB45Z" = "1" /* Fusion of Left Hip Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0SGB47Z" = "1" /* Fusion of Left Hip Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGB4JZ" = "1" /* Fusion of Left Hip Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SGB4KZ" = "1" /* Fusion of Left Hip Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGB4ZZ" = "1" /* Fusion of Left Hip Joint, Percutaneous Endoscopic Approach */
"0SGC04Z" = "1" /* Fusion of Right Knee Joint with Internal Fixation Device, Open Approach */
"0SGC05Z" = "1" /* Fusion of Right Knee Joint with External Fixation Device, Open Approach */
"0SGC07Z" = "1" /* Fusion of Right Knee Joint with Autologous Tissue Substitute, Open Approach */
"0SGC0JZ" = "1" /* Fusion of Right Knee Joint with Synthetic Substitute, Open Approach */
"0SGC0KZ" = "1" /* Fusion of Right Knee Joint with Nonautologous Tissue Substitute, Open Approach */
"0SGC0ZZ" = "1" /* Fusion of Right Knee Joint, Open Approach */
"0SGC34Z" = "1" /* Fusion of Right Knee Joint with Internal Fixation Device, Percutaneous Approach */
"0SGC35Z" = "1" /* Fusion of Right Knee Joint with External Fixation Device, Percutaneous Approach */
"0SGC37Z" = "1" /* Fusion of Right Knee Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SGC3JZ" = "1" /* Fusion of Right Knee Joint with Synthetic Substitute, Percutaneous Approach */
"0SGC3KZ" = "1" /* Fusion of Right Knee Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SGC3ZZ" = "1" /* Fusion of Right Knee Joint, Percutaneous Approach */
"0SGC44Z" = "1" /* Fusion of Right Knee Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0SGC45Z" = "1" /* Fusion of Right Knee Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0SGC47Z" = "1" /* Fusion of Right Knee Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGC4JZ" = "1" /* Fusion of Right Knee Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SGC4KZ" = "1" /* Fusion of Right Knee Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGC4ZZ" = "1" /* Fusion of Right Knee Joint, Percutaneous Endoscopic Approach */
"0SGD04Z" = "1" /* Fusion of Left Knee Joint with Internal Fixation Device, Open Approach */
"0SGD05Z" = "1" /* Fusion of Left Knee Joint with External Fixation Device, Open Approach */
"0SGD07Z" = "1" /* Fusion of Left Knee Joint with Autologous Tissue Substitute, Open Approach */
"0SGD0JZ" = "1" /* Fusion of Left Knee Joint with Synthetic Substitute, Open Approach */
"0SGD0KZ" = "1" /* Fusion of Left Knee Joint with Nonautologous Tissue Substitute, Open Approach */
"0SGD0ZZ" = "1" /* Fusion of Left Knee Joint, Open Approach */
"0SGD34Z" = "1" /* Fusion of Left Knee Joint with Internal Fixation Device, Percutaneous Approach */
"0SGD35Z" = "1" /* Fusion of Left Knee Joint with External Fixation Device, Percutaneous Approach */
"0SGD37Z" = "1" /* Fusion of Left Knee Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SGD3JZ" = "1" /* Fusion of Left Knee Joint with Synthetic Substitute, Percutaneous Approach */
"0SGD3KZ" = "1" /* Fusion of Left Knee Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SGD3ZZ" = "1" /* Fusion of Left Knee Joint, Percutaneous Approach */
"0SGD44Z" = "1" /* Fusion of Left Knee Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0SGD45Z" = "1" /* Fusion of Left Knee Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0SGD47Z" = "1" /* Fusion of Left Knee Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGD4JZ" = "1" /* Fusion of Left Knee Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SGD4KZ" = "1" /* Fusion of Left Knee Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGD4ZZ" = "1" /* Fusion of Left Knee Joint, Percutaneous Endoscopic Approach */
"0SGF04Z" = "1" /* Fusion of Right Ankle Joint with Internal Fixation Device, Open Approach */
"0SGF05Z" = "1" /* Fusion of Right Ankle Joint with External Fixation Device, Open Approach */
"0SGF07Z" = "1" /* Fusion of Right Ankle Joint with Autologous Tissue Substitute, Open Approach */
"0SGF0JZ" = "1" /* Fusion of Right Ankle Joint with Synthetic Substitute, Open Approach */
"0SGF0KZ" = "1" /* Fusion of Right Ankle Joint with Nonautologous Tissue Substitute, Open Approach */
"0SGF0ZZ" = "1" /* Fusion of Right Ankle Joint, Open Approach */
"0SGF34Z" = "1" /* Fusion of Right Ankle Joint with Internal Fixation Device, Percutaneous Approach */
"0SGF35Z" = "1" /* Fusion of Right Ankle Joint with External Fixation Device, Percutaneous Approach */
"0SGF37Z" = "1" /* Fusion of Right Ankle Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SGF3JZ" = "1" /* Fusion of Right Ankle Joint with Synthetic Substitute, Percutaneous Approach */
"0SGF3KZ" = "1" /* Fusion of Right Ankle Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SGF3ZZ" = "1" /* Fusion of Right Ankle Joint, Percutaneous Approach */
"0SGF44Z" = "1" /* Fusion of Right Ankle Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0SGF45Z" = "1" /* Fusion of Right Ankle Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0SGF47Z" = "1" /* Fusion of Right Ankle Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGF4JZ" = "1" /* Fusion of Right Ankle Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SGF4KZ" = "1" /* Fusion of Right Ankle Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGF4ZZ" = "1" /* Fusion of Right Ankle Joint, Percutaneous Endoscopic Approach */
"0SGG04Z" = "1" /* Fusion of Left Ankle Joint with Internal Fixation Device, Open Approach */
"0SGG05Z" = "1" /* Fusion of Left Ankle Joint with External Fixation Device, Open Approach */
"0SGG07Z" = "1" /* Fusion of Left Ankle Joint with Autologous Tissue Substitute, Open Approach */
"0SGG0JZ" = "1" /* Fusion of Left Ankle Joint with Synthetic Substitute, Open Approach */
"0SGG0KZ" = "1" /* Fusion of Left Ankle Joint with Nonautologous Tissue Substitute, Open Approach */
"0SGG0ZZ" = "1" /* Fusion of Left Ankle Joint, Open Approach */
"0SGG34Z" = "1" /* Fusion of Left Ankle Joint with Internal Fixation Device, Percutaneous Approach */
"0SGG35Z" = "1" /* Fusion of Left Ankle Joint with External Fixation Device, Percutaneous Approach */
"0SGG37Z" = "1" /* Fusion of Left Ankle Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SGG3JZ" = "1" /* Fusion of Left Ankle Joint with Synthetic Substitute, Percutaneous Approach */
"0SGG3KZ" = "1" /* Fusion of Left Ankle Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SGG3ZZ" = "1" /* Fusion of Left Ankle Joint, Percutaneous Approach */
"0SGG44Z" = "1" /* Fusion of Left Ankle Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0SGG45Z" = "1" /* Fusion of Left Ankle Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0SGG47Z" = "1" /* Fusion of Left Ankle Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGG4JZ" = "1" /* Fusion of Left Ankle Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SGG4KZ" = "1" /* Fusion of Left Ankle Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGG4ZZ" = "1" /* Fusion of Left Ankle Joint, Percutaneous Endoscopic Approach */
"0SGH04Z" = "1" /* Fusion of Right Tarsal Joint with Internal Fixation Device, Open Approach */
"0SGH05Z" = "1" /* Fusion of Right Tarsal Joint with External Fixation Device, Open Approach */
"0SGH07Z" = "1" /* Fusion of Right Tarsal Joint with Autologous Tissue Substitute, Open Approach */
"0SGH0JZ" = "1" /* Fusion of Right Tarsal Joint with Synthetic Substitute, Open Approach */
"0SGH0KZ" = "1" /* Fusion of Right Tarsal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SGH0ZZ" = "1" /* Fusion of Right Tarsal Joint, Open Approach */
"0SGH34Z" = "1" /* Fusion of Right Tarsal Joint with Internal Fixation Device, Percutaneous Approach */
"0SGH35Z" = "1" /* Fusion of Right Tarsal Joint with External Fixation Device, Percutaneous Approach */
"0SGH37Z" = "1" /* Fusion of Right Tarsal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SGH3JZ" = "1" /* Fusion of Right Tarsal Joint with Synthetic Substitute, Percutaneous Approach */
"0SGH3KZ" = "1" /* Fusion of Right Tarsal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SGH3ZZ" = "1" /* Fusion of Right Tarsal Joint, Percutaneous Approach */
"0SGH44Z" = "1" /* Fusion of Right Tarsal Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0SGH45Z" = "1" /* Fusion of Right Tarsal Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0SGH47Z" = "1" /* Fusion of Right Tarsal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGH4JZ" = "1" /* Fusion of Right Tarsal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SGH4KZ" = "1" /* Fusion of Right Tarsal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGH4ZZ" = "1" /* Fusion of Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0SGJ04Z" = "1" /* Fusion of Left Tarsal Joint with Internal Fixation Device, Open Approach */
"0SGJ05Z" = "1" /* Fusion of Left Tarsal Joint with External Fixation Device, Open Approach */
"0SGJ07Z" = "1" /* Fusion of Left Tarsal Joint with Autologous Tissue Substitute, Open Approach */
"0SGJ0JZ" = "1" /* Fusion of Left Tarsal Joint with Synthetic Substitute, Open Approach */
"0SGJ0KZ" = "1" /* Fusion of Left Tarsal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SGJ0ZZ" = "1" /* Fusion of Left Tarsal Joint, Open Approach */
"0SGJ34Z" = "1" /* Fusion of Left Tarsal Joint with Internal Fixation Device, Percutaneous Approach */
"0SGJ35Z" = "1" /* Fusion of Left Tarsal Joint with External Fixation Device, Percutaneous Approach */
"0SGJ37Z" = "1" /* Fusion of Left Tarsal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SGJ3JZ" = "1" /* Fusion of Left Tarsal Joint with Synthetic Substitute, Percutaneous Approach */
"0SGJ3KZ" = "1" /* Fusion of Left Tarsal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SGJ3ZZ" = "1" /* Fusion of Left Tarsal Joint, Percutaneous Approach */
"0SGJ44Z" = "1" /* Fusion of Left Tarsal Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0SGJ45Z" = "1" /* Fusion of Left Tarsal Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0SGJ47Z" = "1" /* Fusion of Left Tarsal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGJ4JZ" = "1" /* Fusion of Left Tarsal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SGJ4KZ" = "1" /* Fusion of Left Tarsal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGJ4ZZ" = "1" /* Fusion of Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0SGK04Z" = "1" /* Fusion of Right Metatarsal-Tarsal Joint with Internal Fixation Device, Open Approach */
"0SGK05Z" = "1" /* Fusion of Right Metatarsal-Tarsal Joint with External Fixation Device, Open Approach */
"0SGK07Z" = "1" /* Fusion of Right Metatarsal-Tarsal Joint with Autologous Tissue Substitute, Open Approach */
"0SGK0JZ" = "1" /* Fusion of Right Metatarsal-Tarsal Joint with Synthetic Substitute, Open Approach */
"0SGK0KZ" = "1" /* Fusion of Right Metatarsal-Tarsal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SGK0ZZ" = "1" /* Fusion of Right Metatarsal-Tarsal Joint, Open Approach */
"0SGK34Z" = "1" /* Fusion of Right Metatarsal-Tarsal Joint with Internal Fixation Device, Percutaneous Approach */
"0SGK35Z" = "1" /* Fusion of Right Metatarsal-Tarsal Joint with External Fixation Device, Percutaneous Approach */
"0SGK37Z" = "1" /* Fusion of Right Metatarsal-Tarsal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SGK3JZ" = "1" /* Fusion of Right Metatarsal-Tarsal Joint with Synthetic Substitute, Percutaneous Approach */
"0SGK3KZ" = "1" /* Fusion of Right Metatarsal-Tarsal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SGK3ZZ" = "1" /* Fusion of Right Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SGK44Z" = "1" /* Fusion of Right Metatarsal-Tarsal Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0SGK45Z" = "1" /* Fusion of Right Metatarsal-Tarsal Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0SGK47Z" = "1" /* Fusion of Right Metatarsal-Tarsal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGK4JZ" = "1" /* Fusion of Right Metatarsal-Tarsal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SGK4KZ" = "1" /* Fusion of Right Metatarsal-Tarsal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGK4ZZ" = "1" /* Fusion of Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SGL04Z" = "1" /* Fusion of Left Metatarsal-Tarsal Joint with Internal Fixation Device, Open Approach */
"0SGL05Z" = "1" /* Fusion of Left Metatarsal-Tarsal Joint with External Fixation Device, Open Approach */
"0SGL07Z" = "1" /* Fusion of Left Metatarsal-Tarsal Joint with Autologous Tissue Substitute, Open Approach */
"0SGL0JZ" = "1" /* Fusion of Left Metatarsal-Tarsal Joint with Synthetic Substitute, Open Approach */
"0SGL0KZ" = "1" /* Fusion of Left Metatarsal-Tarsal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SGL0ZZ" = "1" /* Fusion of Left Metatarsal-Tarsal Joint, Open Approach */
"0SGL34Z" = "1" /* Fusion of Left Metatarsal-Tarsal Joint with Internal Fixation Device, Percutaneous Approach */
"0SGL35Z" = "1" /* Fusion of Left Metatarsal-Tarsal Joint with External Fixation Device, Percutaneous Approach */
"0SGL37Z" = "1" /* Fusion of Left Metatarsal-Tarsal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SGL3JZ" = "1" /* Fusion of Left Metatarsal-Tarsal Joint with Synthetic Substitute, Percutaneous Approach */
"0SGL3KZ" = "1" /* Fusion of Left Metatarsal-Tarsal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SGL3ZZ" = "1" /* Fusion of Left Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SGL44Z" = "1" /* Fusion of Left Metatarsal-Tarsal Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0SGL45Z" = "1" /* Fusion of Left Metatarsal-Tarsal Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0SGL47Z" = "1" /* Fusion of Left Metatarsal-Tarsal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGL4JZ" = "1" /* Fusion of Left Metatarsal-Tarsal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SGL4KZ" = "1" /* Fusion of Left Metatarsal-Tarsal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGL4ZZ" = "1" /* Fusion of Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SGM04Z" = "1" /* Fusion of Right Metatarsal-Phalangeal Joint with Internal Fixation Device, Open Approach */
"0SGM05Z" = "1" /* Fusion of Right Metatarsal-Phalangeal Joint with External Fixation Device, Open Approach */
"0SGM07Z" = "1" /* Fusion of Right Metatarsal-Phalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0SGM0JZ" = "1" /* Fusion of Right Metatarsal-Phalangeal Joint with Synthetic Substitute, Open Approach */
"0SGM0KZ" = "1" /* Fusion of Right Metatarsal-Phalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SGM0ZZ" = "1" /* Fusion of Right Metatarsal-Phalangeal Joint, Open Approach */
"0SGM34Z" = "1" /* Fusion of Right Metatarsal-Phalangeal Joint with Internal Fixation Device, Percutaneous Approach */
"0SGM35Z" = "1" /* Fusion of Right Metatarsal-Phalangeal Joint with External Fixation Device, Percutaneous Approach */
"0SGM37Z" = "1" /* Fusion of Right Metatarsal-Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SGM3JZ" = "1" /* Fusion of Right Metatarsal-Phalangeal Joint with Synthetic Substitute, Percutaneous Approach */
"0SGM3KZ" = "1" /* Fusion of Right Metatarsal-Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SGM3ZZ" = "1" /* Fusion of Right Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SGM44Z" = "1" /* Fusion of Right Metatarsal-Phalangeal Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0SGM45Z" = "1" /* Fusion of Right Metatarsal-Phalangeal Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0SGM47Z" = "1" /* Fusion of Right Metatarsal-Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGM4JZ" = "1" /* Fusion of Right Metatarsal-Phalangeal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SGM4KZ" = "1" /* Fusion of Right Metatarsal-Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGM4ZZ" = "1" /* Fusion of Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SGN04Z" = "1" /* Fusion of Left Metatarsal-Phalangeal Joint with Internal Fixation Device, Open Approach */
"0SGN05Z" = "1" /* Fusion of Left Metatarsal-Phalangeal Joint with External Fixation Device, Open Approach */
"0SGN07Z" = "1" /* Fusion of Left Metatarsal-Phalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0SGN0JZ" = "1" /* Fusion of Left Metatarsal-Phalangeal Joint with Synthetic Substitute, Open Approach */
"0SGN0KZ" = "1" /* Fusion of Left Metatarsal-Phalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SGN0ZZ" = "1" /* Fusion of Left Metatarsal-Phalangeal Joint, Open Approach */
"0SGN34Z" = "1" /* Fusion of Left Metatarsal-Phalangeal Joint with Internal Fixation Device, Percutaneous Approach */
"0SGN35Z" = "1" /* Fusion of Left Metatarsal-Phalangeal Joint with External Fixation Device, Percutaneous Approach */
"0SGN37Z" = "1" /* Fusion of Left Metatarsal-Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SGN3JZ" = "1" /* Fusion of Left Metatarsal-Phalangeal Joint with Synthetic Substitute, Percutaneous Approach */
"0SGN3KZ" = "1" /* Fusion of Left Metatarsal-Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SGN3ZZ" = "1" /* Fusion of Left Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SGN44Z" = "1" /* Fusion of Left Metatarsal-Phalangeal Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0SGN45Z" = "1" /* Fusion of Left Metatarsal-Phalangeal Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0SGN47Z" = "1" /* Fusion of Left Metatarsal-Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGN4JZ" = "1" /* Fusion of Left Metatarsal-Phalangeal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SGN4KZ" = "1" /* Fusion of Left Metatarsal-Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGN4ZZ" = "1" /* Fusion of Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SGP04Z" = "1" /* Fusion of Right Toe Phalangeal Joint with Internal Fixation Device, Open Approach */
"0SGP05Z" = "1" /* Fusion of Right Toe Phalangeal Joint with External Fixation Device, Open Approach */
"0SGP07Z" = "1" /* Fusion of Right Toe Phalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0SGP0JZ" = "1" /* Fusion of Right Toe Phalangeal Joint with Synthetic Substitute, Open Approach */
"0SGP0KZ" = "1" /* Fusion of Right Toe Phalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SGP0ZZ" = "1" /* Fusion of Right Toe Phalangeal Joint, Open Approach */
"0SGP34Z" = "1" /* Fusion of Right Toe Phalangeal Joint with Internal Fixation Device, Percutaneous Approach */
"0SGP35Z" = "1" /* Fusion of Right Toe Phalangeal Joint with External Fixation Device, Percutaneous Approach */
"0SGP37Z" = "1" /* Fusion of Right Toe Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SGP3JZ" = "1" /* Fusion of Right Toe Phalangeal Joint with Synthetic Substitute, Percutaneous Approach */
"0SGP3KZ" = "1" /* Fusion of Right Toe Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SGP3ZZ" = "1" /* Fusion of Right Toe Phalangeal Joint, Percutaneous Approach */
"0SGP44Z" = "1" /* Fusion of Right Toe Phalangeal Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0SGP45Z" = "1" /* Fusion of Right Toe Phalangeal Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0SGP47Z" = "1" /* Fusion of Right Toe Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGP4JZ" = "1" /* Fusion of Right Toe Phalangeal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SGP4KZ" = "1" /* Fusion of Right Toe Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGP4ZZ" = "1" /* Fusion of Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SGQ04Z" = "1" /* Fusion of Left Toe Phalangeal Joint with Internal Fixation Device, Open Approach */
"0SGQ05Z" = "1" /* Fusion of Left Toe Phalangeal Joint with External Fixation Device, Open Approach */
"0SGQ07Z" = "1" /* Fusion of Left Toe Phalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0SGQ0JZ" = "1" /* Fusion of Left Toe Phalangeal Joint with Synthetic Substitute, Open Approach */
"0SGQ0KZ" = "1" /* Fusion of Left Toe Phalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SGQ0ZZ" = "1" /* Fusion of Left Toe Phalangeal Joint, Open Approach */
"0SGQ34Z" = "1" /* Fusion of Left Toe Phalangeal Joint with Internal Fixation Device, Percutaneous Approach */
"0SGQ35Z" = "1" /* Fusion of Left Toe Phalangeal Joint with External Fixation Device, Percutaneous Approach */
"0SGQ37Z" = "1" /* Fusion of Left Toe Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SGQ3JZ" = "1" /* Fusion of Left Toe Phalangeal Joint with Synthetic Substitute, Percutaneous Approach */
"0SGQ3KZ" = "1" /* Fusion of Left Toe Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SGQ3ZZ" = "1" /* Fusion of Left Toe Phalangeal Joint, Percutaneous Approach */
"0SGQ44Z" = "1" /* Fusion of Left Toe Phalangeal Joint with Internal Fixation Device, Percutaneous Endoscopic Approach */
"0SGQ45Z" = "1" /* Fusion of Left Toe Phalangeal Joint with External Fixation Device, Percutaneous Endoscopic Approach */
"0SGQ47Z" = "1" /* Fusion of Left Toe Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGQ4JZ" = "1" /* Fusion of Left Toe Phalangeal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SGQ4KZ" = "1" /* Fusion of Left Toe Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SGQ4ZZ" = "1" /* Fusion of Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SH004Z" = "1" /* Insertion of Internal Fixation Device into Lumbar Vertebral Joint, Open Approach */
"0SH00BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Lumbar Vertebral Joint, Open Approach */
"0SH00CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Lumbar Vertebral Joint, Open Approach */
"0SH00DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Lumbar Vertebral Joint, Open Approach */
"0SH034Z" = "1" /* Insertion of Internal Fixation Device into Lumbar Vertebral Joint, Percutaneous Approach */
"0SH03BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Lumbar Vertebral Joint, Percutaneous Approach */
"0SH03CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Lumbar Vertebral Joint, Percutaneous Approach */
"0SH03DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Lumbar Vertebral Joint, Percutaneous Approach */
"0SH044Z" = "1" /* Insertion of Internal Fixation Device into Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SH04BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SH04CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SH04DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SH304Z" = "1" /* Insertion of Internal Fixation Device into Lumbosacral Joint, Open Approach */
"0SH30BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Lumbosacral Joint, Open Approach */
"0SH30CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Lumbosacral Joint, Open Approach */
"0SH30DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Lumbosacral Joint, Open Approach */
"0SH334Z" = "1" /* Insertion of Internal Fixation Device into Lumbosacral Joint, Percutaneous Approach */
"0SH33BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Lumbosacral Joint, Percutaneous Approach */
"0SH33CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Lumbosacral Joint, Percutaneous Approach */
"0SH33DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Lumbosacral Joint, Percutaneous Approach */
"0SH344Z" = "1" /* Insertion of Internal Fixation Device into Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SH34BZ" = "1" /* Insertion of Interspinous Process Spinal Stabilization Device into Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SH34CZ" = "1" /* Insertion of Pedicle-Based Spinal Stabilization Device into Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SH34DZ" = "1" /* Insertion of Facet Replacement Spinal Stabilization Device into Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SH504Z" = "1" /* Insertion of Internal Fixation Device into Sacrococcygeal Joint, Open Approach */
"0SH534Z" = "1" /* Insertion of Internal Fixation Device into Sacrococcygeal Joint, Percutaneous Approach */
"0SH544Z" = "1" /* Insertion of Internal Fixation Device into Sacrococcygeal Joint, Percutaneous Endoscopic Approach */
"0SH604Z" = "1" /* Insertion of Internal Fixation Device into Coccygeal Joint, Open Approach */
"0SH634Z" = "1" /* Insertion of Internal Fixation Device into Coccygeal Joint, Percutaneous Approach */
"0SH644Z" = "1" /* Insertion of Internal Fixation Device into Coccygeal Joint, Percutaneous Endoscopic Approach */
"0SH704Z" = "1" /* Insertion of Internal Fixation Device into Right Sacroiliac Joint, Open Approach */
"0SH734Z" = "1" /* Insertion of Internal Fixation Device into Right Sacroiliac Joint, Percutaneous Approach */
"0SH744Z" = "1" /* Insertion of Internal Fixation Device into Right Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SH804Z" = "1" /* Insertion of Internal Fixation Device into Left Sacroiliac Joint, Open Approach */
"0SH834Z" = "1" /* Insertion of Internal Fixation Device into Left Sacroiliac Joint, Percutaneous Approach */
"0SH844Z" = "1" /* Insertion of Internal Fixation Device into Left Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SH904Z" = "1" /* Insertion of Internal Fixation Device into Right Hip Joint, Open Approach */
"0SH905Z" = "1" /* Insertion of External Fixation Device into Right Hip Joint, Open Approach */
"0SH934Z" = "1" /* Insertion of Internal Fixation Device into Right Hip Joint, Percutaneous Approach */
"0SH935Z" = "1" /* Insertion of External Fixation Device into Right Hip Joint, Percutaneous Approach */
"0SH944Z" = "1" /* Insertion of Internal Fixation Device into Right Hip Joint, Percutaneous Endoscopic Approach */
"0SH945Z" = "1" /* Insertion of External Fixation Device into Right Hip Joint, Percutaneous Endoscopic Approach */
"0SHB04Z" = "1" /* Insertion of Internal Fixation Device into Left Hip Joint, Open Approach */
"0SHB05Z" = "1" /* Insertion of External Fixation Device into Left Hip Joint, Open Approach */
"0SHB34Z" = "1" /* Insertion of Internal Fixation Device into Left Hip Joint, Percutaneous Approach */
"0SHB35Z" = "1" /* Insertion of External Fixation Device into Left Hip Joint, Percutaneous Approach */
"0SHB44Z" = "1" /* Insertion of Internal Fixation Device into Left Hip Joint, Percutaneous Endoscopic Approach */
"0SHB45Z" = "1" /* Insertion of External Fixation Device into Left Hip Joint, Percutaneous Endoscopic Approach */
"0SHC04Z" = "1" /* Insertion of Internal Fixation Device into Right Knee Joint, Open Approach */
"0SHC05Z" = "1" /* Insertion of External Fixation Device into Right Knee Joint, Open Approach */
"0SHC34Z" = "1" /* Insertion of Internal Fixation Device into Right Knee Joint, Percutaneous Approach */
"0SHC35Z" = "1" /* Insertion of External Fixation Device into Right Knee Joint, Percutaneous Approach */
"0SHC44Z" = "1" /* Insertion of Internal Fixation Device into Right Knee Joint, Percutaneous Endoscopic Approach */
"0SHC45Z" = "1" /* Insertion of External Fixation Device into Right Knee Joint, Percutaneous Endoscopic Approach */
"0SHD04Z" = "1" /* Insertion of Internal Fixation Device into Left Knee Joint, Open Approach */
"0SHD05Z" = "1" /* Insertion of External Fixation Device into Left Knee Joint, Open Approach */
"0SHD34Z" = "1" /* Insertion of Internal Fixation Device into Left Knee Joint, Percutaneous Approach */
"0SHD35Z" = "1" /* Insertion of External Fixation Device into Left Knee Joint, Percutaneous Approach */
"0SHD44Z" = "1" /* Insertion of Internal Fixation Device into Left Knee Joint, Percutaneous Endoscopic Approach */
"0SHD45Z" = "1" /* Insertion of External Fixation Device into Left Knee Joint, Percutaneous Endoscopic Approach */
"0SHF04Z" = "1" /* Insertion of Internal Fixation Device into Right Ankle Joint, Open Approach */
"0SHF05Z" = "1" /* Insertion of External Fixation Device into Right Ankle Joint, Open Approach */
"0SHF34Z" = "1" /* Insertion of Internal Fixation Device into Right Ankle Joint, Percutaneous Approach */
"0SHF35Z" = "1" /* Insertion of External Fixation Device into Right Ankle Joint, Percutaneous Approach */
"0SHF44Z" = "1" /* Insertion of Internal Fixation Device into Right Ankle Joint, Percutaneous Endoscopic Approach */
"0SHF45Z" = "1" /* Insertion of External Fixation Device into Right Ankle Joint, Percutaneous Endoscopic Approach */
"0SHG04Z" = "1" /* Insertion of Internal Fixation Device into Left Ankle Joint, Open Approach */
"0SHG05Z" = "1" /* Insertion of External Fixation Device into Left Ankle Joint, Open Approach */
"0SHG34Z" = "1" /* Insertion of Internal Fixation Device into Left Ankle Joint, Percutaneous Approach */
"0SHG35Z" = "1" /* Insertion of External Fixation Device into Left Ankle Joint, Percutaneous Approach */
"0SHG44Z" = "1" /* Insertion of Internal Fixation Device into Left Ankle Joint, Percutaneous Endoscopic Approach */
"0SHG45Z" = "1" /* Insertion of External Fixation Device into Left Ankle Joint, Percutaneous Endoscopic Approach */
"0SHH04Z" = "1" /* Insertion of Internal Fixation Device into Right Tarsal Joint, Open Approach */
"0SHH05Z" = "1" /* Insertion of External Fixation Device into Right Tarsal Joint, Open Approach */
"0SHH34Z" = "1" /* Insertion of Internal Fixation Device into Right Tarsal Joint, Percutaneous Approach */
"0SHH35Z" = "1" /* Insertion of External Fixation Device into Right Tarsal Joint, Percutaneous Approach */
"0SHH44Z" = "1" /* Insertion of Internal Fixation Device into Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0SHH45Z" = "1" /* Insertion of External Fixation Device into Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0SHJ04Z" = "1" /* Insertion of Internal Fixation Device into Left Tarsal Joint, Open Approach */
"0SHJ05Z" = "1" /* Insertion of External Fixation Device into Left Tarsal Joint, Open Approach */
"0SHJ34Z" = "1" /* Insertion of Internal Fixation Device into Left Tarsal Joint, Percutaneous Approach */
"0SHJ35Z" = "1" /* Insertion of External Fixation Device into Left Tarsal Joint, Percutaneous Approach */
"0SHJ44Z" = "1" /* Insertion of Internal Fixation Device into Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0SHJ45Z" = "1" /* Insertion of External Fixation Device into Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0SHK04Z" = "1" /* Insertion of Internal Fixation Device into Right Metatarsal-Tarsal Joint, Open Approach */
"0SHK05Z" = "1" /* Insertion of External Fixation Device into Right Metatarsal-Tarsal Joint, Open Approach */
"0SHK34Z" = "1" /* Insertion of Internal Fixation Device into Right Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SHK35Z" = "1" /* Insertion of External Fixation Device into Right Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SHK44Z" = "1" /* Insertion of Internal Fixation Device into Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SHK45Z" = "1" /* Insertion of External Fixation Device into Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SHL04Z" = "1" /* Insertion of Internal Fixation Device into Left Metatarsal-Tarsal Joint, Open Approach */
"0SHL05Z" = "1" /* Insertion of External Fixation Device into Left Metatarsal-Tarsal Joint, Open Approach */
"0SHL34Z" = "1" /* Insertion of Internal Fixation Device into Left Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SHL35Z" = "1" /* Insertion of External Fixation Device into Left Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SHL44Z" = "1" /* Insertion of Internal Fixation Device into Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SHL45Z" = "1" /* Insertion of External Fixation Device into Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SHM04Z" = "1" /* Insertion of Internal Fixation Device into Right Metatarsal-Phalangeal Joint, Open Approach */
"0SHM05Z" = "1" /* Insertion of External Fixation Device into Right Metatarsal-Phalangeal Joint, Open Approach */
"0SHM34Z" = "1" /* Insertion of Internal Fixation Device into Right Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SHM35Z" = "1" /* Insertion of External Fixation Device into Right Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SHM44Z" = "1" /* Insertion of Internal Fixation Device into Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SHM45Z" = "1" /* Insertion of External Fixation Device into Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SHN04Z" = "1" /* Insertion of Internal Fixation Device into Left Metatarsal-Phalangeal Joint, Open Approach */
"0SHN05Z" = "1" /* Insertion of External Fixation Device into Left Metatarsal-Phalangeal Joint, Open Approach */
"0SHN34Z" = "1" /* Insertion of Internal Fixation Device into Left Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SHN35Z" = "1" /* Insertion of External Fixation Device into Left Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SHN44Z" = "1" /* Insertion of Internal Fixation Device into Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SHN45Z" = "1" /* Insertion of External Fixation Device into Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SHP04Z" = "1" /* Insertion of Internal Fixation Device into Right Toe Phalangeal Joint, Open Approach */
"0SHP05Z" = "1" /* Insertion of External Fixation Device into Right Toe Phalangeal Joint, Open Approach */
"0SHP34Z" = "1" /* Insertion of Internal Fixation Device into Right Toe Phalangeal Joint, Percutaneous Approach */
"0SHP35Z" = "1" /* Insertion of External Fixation Device into Right Toe Phalangeal Joint, Percutaneous Approach */
"0SHP44Z" = "1" /* Insertion of Internal Fixation Device into Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SHP45Z" = "1" /* Insertion of External Fixation Device into Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SHQ04Z" = "1" /* Insertion of Internal Fixation Device into Left Toe Phalangeal Joint, Open Approach */
"0SHQ05Z" = "1" /* Insertion of External Fixation Device into Left Toe Phalangeal Joint, Open Approach */
"0SHQ34Z" = "1" /* Insertion of Internal Fixation Device into Left Toe Phalangeal Joint, Percutaneous Approach */
"0SHQ35Z" = "1" /* Insertion of External Fixation Device into Left Toe Phalangeal Joint, Percutaneous Approach */
"0SHQ44Z" = "1" /* Insertion of Internal Fixation Device into Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SHQ45Z" = "1" /* Insertion of External Fixation Device into Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SJ00ZZ" = "1" /* Inspection of Lumbar Vertebral Joint, Open Approach */
"0SJ04ZZ" = "1" /* Inspection of Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SJ20ZZ" = "1" /* Inspection of Lumbar Vertebral Disc, Open Approach */
"0SJ24ZZ" = "1" /* Inspection of Lumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0SJ30ZZ" = "1" /* Inspection of Lumbosacral Joint, Open Approach */
"0SJ34ZZ" = "1" /* Inspection of Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SJ40ZZ" = "1" /* Inspection of Lumbosacral Disc, Open Approach */
"0SJ44ZZ" = "1" /* Inspection of Lumbosacral Disc, Percutaneous Endoscopic Approach */
"0SJ50ZZ" = "1" /* Inspection of Sacrococcygeal Joint, Open Approach */
"0SJ54ZZ" = "1" /* Inspection of Sacrococcygeal Joint, Percutaneous Endoscopic Approach */
"0SJ60ZZ" = "1" /* Inspection of Coccygeal Joint, Open Approach */
"0SJ64ZZ" = "1" /* Inspection of Coccygeal Joint, Percutaneous Endoscopic Approach */
"0SJ70ZZ" = "1" /* Inspection of Right Sacroiliac Joint, Open Approach */
"0SJ74ZZ" = "1" /* Inspection of Right Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SJ80ZZ" = "1" /* Inspection of Left Sacroiliac Joint, Open Approach */
"0SJ84ZZ" = "1" /* Inspection of Left Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SJ90ZZ" = "1" /* Inspection of Right Hip Joint, Open Approach */
"0SJ94ZZ" = "1" /* Inspection of Right Hip Joint, Percutaneous Endoscopic Approach */
"0SJB0ZZ" = "1" /* Inspection of Left Hip Joint, Open Approach */
"0SJB4ZZ" = "1" /* Inspection of Left Hip Joint, Percutaneous Endoscopic Approach */
"0SJC0ZZ" = "1" /* Inspection of Right Knee Joint, Open Approach */
"0SJC4ZZ" = "1" /* Inspection of Right Knee Joint, Percutaneous Endoscopic Approach */
"0SJD0ZZ" = "1" /* Inspection of Left Knee Joint, Open Approach */
"0SJD4ZZ" = "1" /* Inspection of Left Knee Joint, Percutaneous Endoscopic Approach */
"0SJF0ZZ" = "1" /* Inspection of Right Ankle Joint, Open Approach */
"0SJF4ZZ" = "1" /* Inspection of Right Ankle Joint, Percutaneous Endoscopic Approach */
"0SJG0ZZ" = "1" /* Inspection of Left Ankle Joint, Open Approach */
"0SJG4ZZ" = "1" /* Inspection of Left Ankle Joint, Percutaneous Endoscopic Approach */
"0SJH0ZZ" = "1" /* Inspection of Right Tarsal Joint, Open Approach */
"0SJH4ZZ" = "1" /* Inspection of Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0SJJ0ZZ" = "1" /* Inspection of Left Tarsal Joint, Open Approach */
"0SJJ4ZZ" = "1" /* Inspection of Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0SJK0ZZ" = "1" /* Inspection of Right Metatarsal-Tarsal Joint, Open Approach */
"0SJK4ZZ" = "1" /* Inspection of Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SJL0ZZ" = "1" /* Inspection of Left Metatarsal-Tarsal Joint, Open Approach */
"0SJL4ZZ" = "1" /* Inspection of Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SJM0ZZ" = "1" /* Inspection of Right Metatarsal-Phalangeal Joint, Open Approach */
"0SJM4ZZ" = "1" /* Inspection of Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SJN0ZZ" = "1" /* Inspection of Left Metatarsal-Phalangeal Joint, Open Approach */
"0SJN4ZZ" = "1" /* Inspection of Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SJP0ZZ" = "1" /* Inspection of Right Toe Phalangeal Joint, Open Approach */
"0SJP4ZZ" = "1" /* Inspection of Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SJQ0ZZ" = "1" /* Inspection of Left Toe Phalangeal Joint, Open Approach */
"0SJQ4ZZ" = "1" /* Inspection of Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SN00ZZ" = "1" /* Release Lumbar Vertebral Joint, Open Approach */
"0SN03ZZ" = "1" /* Release Lumbar Vertebral Joint, Percutaneous Approach */
"0SN04ZZ" = "1" /* Release Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SN20ZZ" = "1" /* Release Lumbar Vertebral Disc, Open Approach */
"0SN23ZZ" = "1" /* Release Lumbar Vertebral Disc, Percutaneous Approach */
"0SN24ZZ" = "1" /* Release Lumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0SN30ZZ" = "1" /* Release Lumbosacral Joint, Open Approach */
"0SN33ZZ" = "1" /* Release Lumbosacral Joint, Percutaneous Approach */
"0SN34ZZ" = "1" /* Release Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SN40ZZ" = "1" /* Release Lumbosacral Disc, Open Approach */
"0SN43ZZ" = "1" /* Release Lumbosacral Disc, Percutaneous Approach */
"0SN44ZZ" = "1" /* Release Lumbosacral Disc, Percutaneous Endoscopic Approach */
"0SN50ZZ" = "1" /* Release Sacrococcygeal Joint, Open Approach */
"0SN53ZZ" = "1" /* Release Sacrococcygeal Joint, Percutaneous Approach */
"0SN54ZZ" = "1" /* Release Sacrococcygeal Joint, Percutaneous Endoscopic Approach */
"0SN60ZZ" = "1" /* Release Coccygeal Joint, Open Approach */
"0SN63ZZ" = "1" /* Release Coccygeal Joint, Percutaneous Approach */
"0SN64ZZ" = "1" /* Release Coccygeal Joint, Percutaneous Endoscopic Approach */
"0SN70ZZ" = "1" /* Release Right Sacroiliac Joint, Open Approach */
"0SN73ZZ" = "1" /* Release Right Sacroiliac Joint, Percutaneous Approach */
"0SN74ZZ" = "1" /* Release Right Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SN80ZZ" = "1" /* Release Left Sacroiliac Joint, Open Approach */
"0SN83ZZ" = "1" /* Release Left Sacroiliac Joint, Percutaneous Approach */
"0SN84ZZ" = "1" /* Release Left Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SN90ZZ" = "1" /* Release Right Hip Joint, Open Approach */
"0SN93ZZ" = "1" /* Release Right Hip Joint, Percutaneous Approach */
"0SN94ZZ" = "1" /* Release Right Hip Joint, Percutaneous Endoscopic Approach */
"0SNB0ZZ" = "1" /* Release Left Hip Joint, Open Approach */
"0SNB3ZZ" = "1" /* Release Left Hip Joint, Percutaneous Approach */
"0SNB4ZZ" = "1" /* Release Left Hip Joint, Percutaneous Endoscopic Approach */
"0SNC0ZZ" = "1" /* Release Right Knee Joint, Open Approach */
"0SNC3ZZ" = "1" /* Release Right Knee Joint, Percutaneous Approach */
"0SNC4ZZ" = "1" /* Release Right Knee Joint, Percutaneous Endoscopic Approach */
"0SND0ZZ" = "1" /* Release Left Knee Joint, Open Approach */
"0SND3ZZ" = "1" /* Release Left Knee Joint, Percutaneous Approach */
"0SND4ZZ" = "1" /* Release Left Knee Joint, Percutaneous Endoscopic Approach */
"0SNF0ZZ" = "1" /* Release Right Ankle Joint, Open Approach */
"0SNF3ZZ" = "1" /* Release Right Ankle Joint, Percutaneous Approach */
"0SNF4ZZ" = "1" /* Release Right Ankle Joint, Percutaneous Endoscopic Approach */
"0SNG0ZZ" = "1" /* Release Left Ankle Joint, Open Approach */
"0SNG3ZZ" = "1" /* Release Left Ankle Joint, Percutaneous Approach */
"0SNG4ZZ" = "1" /* Release Left Ankle Joint, Percutaneous Endoscopic Approach */
"0SNH0ZZ" = "1" /* Release Right Tarsal Joint, Open Approach */
"0SNH3ZZ" = "1" /* Release Right Tarsal Joint, Percutaneous Approach */
"0SNH4ZZ" = "1" /* Release Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0SNJ0ZZ" = "1" /* Release Left Tarsal Joint, Open Approach */
"0SNJ3ZZ" = "1" /* Release Left Tarsal Joint, Percutaneous Approach */
"0SNJ4ZZ" = "1" /* Release Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0SNK0ZZ" = "1" /* Release Right Metatarsal-Tarsal Joint, Open Approach */
"0SNK3ZZ" = "1" /* Release Right Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SNK4ZZ" = "1" /* Release Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SNL0ZZ" = "1" /* Release Left Metatarsal-Tarsal Joint, Open Approach */
"0SNL3ZZ" = "1" /* Release Left Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SNL4ZZ" = "1" /* Release Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SNM0ZZ" = "1" /* Release Right Metatarsal-Phalangeal Joint, Open Approach */
"0SNM3ZZ" = "1" /* Release Right Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SNM4ZZ" = "1" /* Release Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SNN0ZZ" = "1" /* Release Left Metatarsal-Phalangeal Joint, Open Approach */
"0SNN3ZZ" = "1" /* Release Left Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SNN4ZZ" = "1" /* Release Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SNP0ZZ" = "1" /* Release Right Toe Phalangeal Joint, Open Approach */
"0SNP3ZZ" = "1" /* Release Right Toe Phalangeal Joint, Percutaneous Approach */
"0SNP4ZZ" = "1" /* Release Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SNQ0ZZ" = "1" /* Release Left Toe Phalangeal Joint, Open Approach */
"0SNQ3ZZ" = "1" /* Release Left Toe Phalangeal Joint, Percutaneous Approach */
"0SNQ4ZZ" = "1" /* Release Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SP000Z" = "1" /* Removal of Drainage Device from Lumbar Vertebral Joint, Open Approach */
"0SP003Z" = "1" /* Removal of Infusion Device from Lumbar Vertebral Joint, Open Approach */
"0SP004Z" = "1" /* Removal of Internal Fixation Device from Lumbar Vertebral Joint, Open Approach */
"0SP007Z" = "1" /* Removal of Autologous Tissue Substitute from Lumbar Vertebral Joint, Open Approach */
"0SP00AZ" = "1" /* Removal of Interbody Fusion Device from Lumbar Vertebral Joint, Open Approach */
"0SP00JZ" = "1" /* Removal of Synthetic Substitute from Lumbar Vertebral Joint, Open Approach */
"0SP00KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lumbar Vertebral Joint, Open Approach */
"0SP034Z" = "1" /* Removal of Internal Fixation Device from Lumbar Vertebral Joint, Percutaneous Approach */
"0SP037Z" = "1" /* Removal of Autologous Tissue Substitute from Lumbar Vertebral Joint, Percutaneous Approach */
"0SP03AZ" = "1" /* Removal of Interbody Fusion Device from Lumbar Vertebral Joint, Percutaneous Approach */
"0SP03JZ" = "1" /* Removal of Synthetic Substitute from Lumbar Vertebral Joint, Percutaneous Approach */
"0SP03KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lumbar Vertebral Joint, Percutaneous Approach */
"0SP040Z" = "1" /* Removal of Drainage Device from Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SP043Z" = "1" /* Removal of Infusion Device from Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SP044Z" = "1" /* Removal of Internal Fixation Device from Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SP047Z" = "1" /* Removal of Autologous Tissue Substitute from Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SP04AZ" = "1" /* Removal of Interbody Fusion Device from Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SP04JZ" = "1" /* Removal of Synthetic Substitute from Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SP04KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SP200Z" = "1" /* Removal of Drainage Device from Lumbar Vertebral Disc, Open Approach */
"0SP203Z" = "1" /* Removal of Infusion Device from Lumbar Vertebral Disc, Open Approach */
"0SP207Z" = "1" /* Removal of Autologous Tissue Substitute from Lumbar Vertebral Disc, Open Approach */
"0SP20JZ" = "1" /* Removal of Synthetic Substitute from Lumbar Vertebral Disc, Open Approach */
"0SP20KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lumbar Vertebral Disc, Open Approach */
"0SP237Z" = "1" /* Removal of Autologous Tissue Substitute from Lumbar Vertebral Disc, Percutaneous Approach */
"0SP23JZ" = "1" /* Removal of Synthetic Substitute from Lumbar Vertebral Disc, Percutaneous Approach */
"0SP23KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lumbar Vertebral Disc, Percutaneous Approach */
"0SP240Z" = "1" /* Removal of Drainage Device from Lumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0SP243Z" = "1" /* Removal of Infusion Device from Lumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0SP247Z" = "1" /* Removal of Autologous Tissue Substitute from Lumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0SP24JZ" = "1" /* Removal of Synthetic Substitute from Lumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0SP24KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0SP300Z" = "1" /* Removal of Drainage Device from Lumbosacral Joint, Open Approach */
"0SP303Z" = "1" /* Removal of Infusion Device from Lumbosacral Joint, Open Approach */
"0SP304Z" = "1" /* Removal of Internal Fixation Device from Lumbosacral Joint, Open Approach */
"0SP307Z" = "1" /* Removal of Autologous Tissue Substitute from Lumbosacral Joint, Open Approach */
"0SP30AZ" = "1" /* Removal of Interbody Fusion Device from Lumbosacral Joint, Open Approach */
"0SP30JZ" = "1" /* Removal of Synthetic Substitute from Lumbosacral Joint, Open Approach */
"0SP30KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lumbosacral Joint, Open Approach */
"0SP334Z" = "1" /* Removal of Internal Fixation Device from Lumbosacral Joint, Percutaneous Approach */
"0SP337Z" = "1" /* Removal of Autologous Tissue Substitute from Lumbosacral Joint, Percutaneous Approach */
"0SP33AZ" = "1" /* Removal of Interbody Fusion Device from Lumbosacral Joint, Percutaneous Approach */
"0SP33JZ" = "1" /* Removal of Synthetic Substitute from Lumbosacral Joint, Percutaneous Approach */
"0SP33KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lumbosacral Joint, Percutaneous Approach */
"0SP340Z" = "1" /* Removal of Drainage Device from Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SP343Z" = "1" /* Removal of Infusion Device from Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SP344Z" = "1" /* Removal of Internal Fixation Device from Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SP347Z" = "1" /* Removal of Autologous Tissue Substitute from Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SP34AZ" = "1" /* Removal of Interbody Fusion Device from Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SP34JZ" = "1" /* Removal of Synthetic Substitute from Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SP34KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SP400Z" = "1" /* Removal of Drainage Device from Lumbosacral Disc, Open Approach */
"0SP403Z" = "1" /* Removal of Infusion Device from Lumbosacral Disc, Open Approach */
"0SP407Z" = "1" /* Removal of Autologous Tissue Substitute from Lumbosacral Disc, Open Approach */
"0SP40JZ" = "1" /* Removal of Synthetic Substitute from Lumbosacral Disc, Open Approach */
"0SP40KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lumbosacral Disc, Open Approach */
"0SP437Z" = "1" /* Removal of Autologous Tissue Substitute from Lumbosacral Disc, Percutaneous Approach */
"0SP43JZ" = "1" /* Removal of Synthetic Substitute from Lumbosacral Disc, Percutaneous Approach */
"0SP43KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lumbosacral Disc, Percutaneous Approach */
"0SP440Z" = "1" /* Removal of Drainage Device from Lumbosacral Disc, Percutaneous Endoscopic Approach */
"0SP443Z" = "1" /* Removal of Infusion Device from Lumbosacral Disc, Percutaneous Endoscopic Approach */
"0SP447Z" = "1" /* Removal of Autologous Tissue Substitute from Lumbosacral Disc, Percutaneous Endoscopic Approach */
"0SP44JZ" = "1" /* Removal of Synthetic Substitute from Lumbosacral Disc, Percutaneous Endoscopic Approach */
"0SP44KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Lumbosacral Disc, Percutaneous Endoscopic Approach */
"0SP500Z" = "1" /* Removal of Drainage Device from Sacrococcygeal Joint, Open Approach */
"0SP503Z" = "1" /* Removal of Infusion Device from Sacrococcygeal Joint, Open Approach */
"0SP504Z" = "1" /* Removal of Internal Fixation Device from Sacrococcygeal Joint, Open Approach */
"0SP507Z" = "1" /* Removal of Autologous Tissue Substitute from Sacrococcygeal Joint, Open Approach */
"0SP50JZ" = "1" /* Removal of Synthetic Substitute from Sacrococcygeal Joint, Open Approach */
"0SP50KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Sacrococcygeal Joint, Open Approach */
"0SP534Z" = "1" /* Removal of Internal Fixation Device from Sacrococcygeal Joint, Percutaneous Approach */
"0SP537Z" = "1" /* Removal of Autologous Tissue Substitute from Sacrococcygeal Joint, Percutaneous Approach */
"0SP53JZ" = "1" /* Removal of Synthetic Substitute from Sacrococcygeal Joint, Percutaneous Approach */
"0SP53KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Sacrococcygeal Joint, Percutaneous Approach */
"0SP540Z" = "1" /* Removal of Drainage Device from Sacrococcygeal Joint, Percutaneous Endoscopic Approach */
"0SP543Z" = "1" /* Removal of Infusion Device from Sacrococcygeal Joint, Percutaneous Endoscopic Approach */
"0SP544Z" = "1" /* Removal of Internal Fixation Device from Sacrococcygeal Joint, Percutaneous Endoscopic Approach */
"0SP547Z" = "1" /* Removal of Autologous Tissue Substitute from Sacrococcygeal Joint, Percutaneous Endoscopic Approach */
"0SP54JZ" = "1" /* Removal of Synthetic Substitute from Sacrococcygeal Joint, Percutaneous Endoscopic Approach */
"0SP54KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Sacrococcygeal Joint, Percutaneous Endoscopic Approach */
"0SP600Z" = "1" /* Removal of Drainage Device from Coccygeal Joint, Open Approach */
"0SP603Z" = "1" /* Removal of Infusion Device from Coccygeal Joint, Open Approach */
"0SP604Z" = "1" /* Removal of Internal Fixation Device from Coccygeal Joint, Open Approach */
"0SP607Z" = "1" /* Removal of Autologous Tissue Substitute from Coccygeal Joint, Open Approach */
"0SP60JZ" = "1" /* Removal of Synthetic Substitute from Coccygeal Joint, Open Approach */
"0SP60KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Coccygeal Joint, Open Approach */
"0SP634Z" = "1" /* Removal of Internal Fixation Device from Coccygeal Joint, Percutaneous Approach */
"0SP637Z" = "1" /* Removal of Autologous Tissue Substitute from Coccygeal Joint, Percutaneous Approach */
"0SP63JZ" = "1" /* Removal of Synthetic Substitute from Coccygeal Joint, Percutaneous Approach */
"0SP63KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Coccygeal Joint, Percutaneous Approach */
"0SP640Z" = "1" /* Removal of Drainage Device from Coccygeal Joint, Percutaneous Endoscopic Approach */
"0SP643Z" = "1" /* Removal of Infusion Device from Coccygeal Joint, Percutaneous Endoscopic Approach */
"0SP644Z" = "1" /* Removal of Internal Fixation Device from Coccygeal Joint, Percutaneous Endoscopic Approach */
"0SP647Z" = "1" /* Removal of Autologous Tissue Substitute from Coccygeal Joint, Percutaneous Endoscopic Approach */
"0SP64JZ" = "1" /* Removal of Synthetic Substitute from Coccygeal Joint, Percutaneous Endoscopic Approach */
"0SP64KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Coccygeal Joint, Percutaneous Endoscopic Approach */
"0SP700Z" = "1" /* Removal of Drainage Device from Right Sacroiliac Joint, Open Approach */
"0SP703Z" = "1" /* Removal of Infusion Device from Right Sacroiliac Joint, Open Approach */
"0SP704Z" = "1" /* Removal of Internal Fixation Device from Right Sacroiliac Joint, Open Approach */
"0SP707Z" = "1" /* Removal of Autologous Tissue Substitute from Right Sacroiliac Joint, Open Approach */
"0SP70JZ" = "1" /* Removal of Synthetic Substitute from Right Sacroiliac Joint, Open Approach */
"0SP70KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Sacroiliac Joint, Open Approach */
"0SP734Z" = "1" /* Removal of Internal Fixation Device from Right Sacroiliac Joint, Percutaneous Approach */
"0SP737Z" = "1" /* Removal of Autologous Tissue Substitute from Right Sacroiliac Joint, Percutaneous Approach */
"0SP73JZ" = "1" /* Removal of Synthetic Substitute from Right Sacroiliac Joint, Percutaneous Approach */
"0SP73KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Sacroiliac Joint, Percutaneous Approach */
"0SP740Z" = "1" /* Removal of Drainage Device from Right Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SP743Z" = "1" /* Removal of Infusion Device from Right Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SP744Z" = "1" /* Removal of Internal Fixation Device from Right Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SP747Z" = "1" /* Removal of Autologous Tissue Substitute from Right Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SP74JZ" = "1" /* Removal of Synthetic Substitute from Right Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SP74KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SP800Z" = "1" /* Removal of Drainage Device from Left Sacroiliac Joint, Open Approach */
"0SP803Z" = "1" /* Removal of Infusion Device from Left Sacroiliac Joint, Open Approach */
"0SP804Z" = "1" /* Removal of Internal Fixation Device from Left Sacroiliac Joint, Open Approach */
"0SP807Z" = "1" /* Removal of Autologous Tissue Substitute from Left Sacroiliac Joint, Open Approach */
"0SP80JZ" = "1" /* Removal of Synthetic Substitute from Left Sacroiliac Joint, Open Approach */
"0SP80KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Sacroiliac Joint, Open Approach */
"0SP834Z" = "1" /* Removal of Internal Fixation Device from Left Sacroiliac Joint, Percutaneous Approach */
"0SP837Z" = "1" /* Removal of Autologous Tissue Substitute from Left Sacroiliac Joint, Percutaneous Approach */
"0SP83JZ" = "1" /* Removal of Synthetic Substitute from Left Sacroiliac Joint, Percutaneous Approach */
"0SP83KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Sacroiliac Joint, Percutaneous Approach */
"0SP840Z" = "1" /* Removal of Drainage Device from Left Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SP843Z" = "1" /* Removal of Infusion Device from Left Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SP844Z" = "1" /* Removal of Internal Fixation Device from Left Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SP847Z" = "1" /* Removal of Autologous Tissue Substitute from Left Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SP84JZ" = "1" /* Removal of Synthetic Substitute from Left Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SP84KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SP900Z" = "1" /* Removal of Drainage Device from Right Hip Joint, Open Approach */
"0SP903Z" = "1" /* Removal of Infusion Device from Right Hip Joint, Open Approach */
"0SP904Z" = "1" /* Removal of Internal Fixation Device from Right Hip Joint, Open Approach */
"0SP905Z" = "1" /* Removal of External Fixation Device from Right Hip Joint, Open Approach */
"0SP907Z" = "1" /* Removal of Autologous Tissue Substitute from Right Hip Joint, Open Approach */
"0SP909Z" = "1" /* Removal of Liner from Right Hip Joint, Open Approach */
"0SP90BZ" = "1" /* Removal of Resurfacing Device from Right Hip Joint, Open Approach */
"0SP90JZ" = "1" /* Removal of Synthetic Substitute from Right Hip Joint, Open Approach */
"0SP90KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Hip Joint, Open Approach */
"0SP934Z" = "1" /* Removal of Internal Fixation Device from Right Hip Joint, Percutaneous Approach */
"0SP935Z" = "1" /* Removal of External Fixation Device from Right Hip Joint, Percutaneous Approach */
"0SP937Z" = "1" /* Removal of Autologous Tissue Substitute from Right Hip Joint, Percutaneous Approach */
"0SP93JZ" = "1" /* Removal of Synthetic Substitute from Right Hip Joint, Percutaneous Approach */
"0SP93KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Hip Joint, Percutaneous Approach */
"0SP940Z" = "1" /* Removal of Drainage Device from Right Hip Joint, Percutaneous Endoscopic Approach */
"0SP943Z" = "1" /* Removal of Infusion Device from Right Hip Joint, Percutaneous Endoscopic Approach */
"0SP944Z" = "1" /* Removal of Internal Fixation Device from Right Hip Joint, Percutaneous Endoscopic Approach */
"0SP945Z" = "1" /* Removal of External Fixation Device from Right Hip Joint, Percutaneous Endoscopic Approach */
"0SP947Z" = "1" /* Removal of Autologous Tissue Substitute from Right Hip Joint, Percutaneous Endoscopic Approach */
"0SP94JZ" = "1" /* Removal of Synthetic Substitute from Right Hip Joint, Percutaneous Endoscopic Approach */
"0SP94KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Hip Joint, Percutaneous Endoscopic Approach */
"0SPA0JZ" = "1" /* Removal of Synthetic Substitute from Right Hip Joint, Acetabular Surface, Open Approach */
"0SPA3JZ" = "1" /* Removal of Synthetic Substitute from Right Hip Joint, Acetabular Surface, Percutaneous Approach */
"0SPA4JZ" = "1" /* Removal of Synthetic Substitute from Right Hip Joint, Acetabular Surface, Percutaneous Endoscopic Approach */
"0SPB00Z" = "1" /* Removal of Drainage Device from Left Hip Joint, Open Approach */
"0SPB03Z" = "1" /* Removal of Infusion Device from Left Hip Joint, Open Approach */
"0SPB04Z" = "1" /* Removal of Internal Fixation Device from Left Hip Joint, Open Approach */
"0SPB05Z" = "1" /* Removal of External Fixation Device from Left Hip Joint, Open Approach */
"0SPB07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Hip Joint, Open Approach */
"0SPB09Z" = "1" /* Removal of Liner from Left Hip Joint, Open Approach */
"0SPB0BZ" = "1" /* Removal of Resurfacing Device from Left Hip Joint, Open Approach */
"0SPB0JZ" = "1" /* Removal of Synthetic Substitute from Left Hip Joint, Open Approach */
"0SPB0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Hip Joint, Open Approach */
"0SPB34Z" = "1" /* Removal of Internal Fixation Device from Left Hip Joint, Percutaneous Approach */
"0SPB35Z" = "1" /* Removal of External Fixation Device from Left Hip Joint, Percutaneous Approach */
"0SPB37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Hip Joint, Percutaneous Approach */
"0SPB3JZ" = "1" /* Removal of Synthetic Substitute from Left Hip Joint, Percutaneous Approach */
"0SPB3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Hip Joint, Percutaneous Approach */
"0SPB40Z" = "1" /* Removal of Drainage Device from Left Hip Joint, Percutaneous Endoscopic Approach */
"0SPB43Z" = "1" /* Removal of Infusion Device from Left Hip Joint, Percutaneous Endoscopic Approach */
"0SPB44Z" = "1" /* Removal of Internal Fixation Device from Left Hip Joint, Percutaneous Endoscopic Approach */
"0SPB45Z" = "1" /* Removal of External Fixation Device from Left Hip Joint, Percutaneous Endoscopic Approach */
"0SPB47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Hip Joint, Percutaneous Endoscopic Approach */
"0SPB4JZ" = "1" /* Removal of Synthetic Substitute from Left Hip Joint, Percutaneous Endoscopic Approach */
"0SPB4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Hip Joint, Percutaneous Endoscopic Approach */
"0SPC00Z" = "1" /* Removal of Drainage Device from Right Knee Joint, Open Approach */
"0SPC03Z" = "1" /* Removal of Infusion Device from Right Knee Joint, Open Approach */
"0SPC04Z" = "1" /* Removal of Internal Fixation Device from Right Knee Joint, Open Approach */
"0SPC05Z" = "1" /* Removal of External Fixation Device from Right Knee Joint, Open Approach */
"0SPC07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Knee Joint, Open Approach */
"0SPC09Z" = "1" /* Removal of Liner from Right Knee Joint, Open Approach */
"0SPC0JC" = "1" /* Removal of Synthetic Substitute from Right Knee Joint, Patellar Surface, Open Approach */
"0SPC0JZ" = "1" /* Removal of Synthetic Substitute from Right Knee Joint, Open Approach */
"0SPC0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Knee Joint, Open Approach */
"0SPC34Z" = "1" /* Removal of Internal Fixation Device from Right Knee Joint, Percutaneous Approach */
"0SPC35Z" = "1" /* Removal of External Fixation Device from Right Knee Joint, Percutaneous Approach */
"0SPC37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Knee Joint, Percutaneous Approach */
"0SPC3JC" = "1" /* Removal of Synthetic Substitute from Right Knee Joint, Patellar Surface, Percutaneous Approach */
"0SPC3JZ" = "1" /* Removal of Synthetic Substitute from Right Knee Joint, Percutaneous Approach */
"0SPC3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Knee Joint, Percutaneous Approach */
"0SPC40Z" = "1" /* Removal of Drainage Device from Right Knee Joint, Percutaneous Endoscopic Approach */
"0SPC43Z" = "1" /* Removal of Infusion Device from Right Knee Joint, Percutaneous Endoscopic Approach */
"0SPC44Z" = "1" /* Removal of Internal Fixation Device from Right Knee Joint, Percutaneous Endoscopic Approach */
"0SPC45Z" = "1" /* Removal of External Fixation Device from Right Knee Joint, Percutaneous Endoscopic Approach */
"0SPC47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Knee Joint, Percutaneous Endoscopic Approach */
"0SPC4JC" = "1" /* Removal of Synthetic Substitute from Right Knee Joint, Patellar Surface, Percutaneous Endoscopic Approach */
"0SPC4JZ" = "1" /* Removal of Synthetic Substitute from Right Knee Joint, Percutaneous Endoscopic Approach */
"0SPC4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Knee Joint, Percutaneous Endoscopic Approach */
"0SPD00Z" = "1" /* Removal of Drainage Device from Left Knee Joint, Open Approach */
"0SPD03Z" = "1" /* Removal of Infusion Device from Left Knee Joint, Open Approach */
"0SPD04Z" = "1" /* Removal of Internal Fixation Device from Left Knee Joint, Open Approach */
"0SPD05Z" = "1" /* Removal of External Fixation Device from Left Knee Joint, Open Approach */
"0SPD07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Knee Joint, Open Approach */
"0SPD09Z" = "1" /* Removal of Liner from Left Knee Joint, Open Approach */
"0SPD0JC" = "1" /* Removal of Synthetic Substitute from Left Knee Joint, Patellar Surface, Open Approach */
"0SPD0JZ" = "1" /* Removal of Synthetic Substitute from Left Knee Joint, Open Approach */
"0SPD0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Knee Joint, Open Approach */
"0SPD34Z" = "1" /* Removal of Internal Fixation Device from Left Knee Joint, Percutaneous Approach */
"0SPD35Z" = "1" /* Removal of External Fixation Device from Left Knee Joint, Percutaneous Approach */
"0SPD37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Knee Joint, Percutaneous Approach */
"0SPD3JC" = "1" /* Removal of Synthetic Substitute from Left Knee Joint, Patellar Surface, Percutaneous Approach */
"0SPD3JZ" = "1" /* Removal of Synthetic Substitute from Left Knee Joint, Percutaneous Approach */
"0SPD3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Knee Joint, Percutaneous Approach */
"0SPD40Z" = "1" /* Removal of Drainage Device from Left Knee Joint, Percutaneous Endoscopic Approach */
"0SPD43Z" = "1" /* Removal of Infusion Device from Left Knee Joint, Percutaneous Endoscopic Approach */
"0SPD44Z" = "1" /* Removal of Internal Fixation Device from Left Knee Joint, Percutaneous Endoscopic Approach */
"0SPD45Z" = "1" /* Removal of External Fixation Device from Left Knee Joint, Percutaneous Endoscopic Approach */
"0SPD47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Knee Joint, Percutaneous Endoscopic Approach */
"0SPD4JC" = "1" /* Removal of Synthetic Substitute from Left Knee Joint, Patellar Surface, Percutaneous Endoscopic Approach */
"0SPD4JZ" = "1" /* Removal of Synthetic Substitute from Left Knee Joint, Percutaneous Endoscopic Approach */
"0SPD4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Knee Joint, Percutaneous Endoscopic Approach */
"0SPE0JZ" = "1" /* Removal of Synthetic Substitute from Left Hip Joint, Acetabular Surface, Open Approach */
"0SPE3JZ" = "1" /* Removal of Synthetic Substitute from Left Hip Joint, Acetabular Surface, Percutaneous Approach */
"0SPE4JZ" = "1" /* Removal of Synthetic Substitute from Left Hip Joint, Acetabular Surface, Percutaneous Endoscopic Approach */
"0SPF00Z" = "1" /* Removal of Drainage Device from Right Ankle Joint, Open Approach */
"0SPF03Z" = "1" /* Removal of Infusion Device from Right Ankle Joint, Open Approach */
"0SPF04Z" = "1" /* Removal of Internal Fixation Device from Right Ankle Joint, Open Approach */
"0SPF05Z" = "1" /* Removal of External Fixation Device from Right Ankle Joint, Open Approach */
"0SPF07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Ankle Joint, Open Approach */
"0SPF0JZ" = "1" /* Removal of Synthetic Substitute from Right Ankle Joint, Open Approach */
"0SPF0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Ankle Joint, Open Approach */
"0SPF34Z" = "1" /* Removal of Internal Fixation Device from Right Ankle Joint, Percutaneous Approach */
"0SPF35Z" = "1" /* Removal of External Fixation Device from Right Ankle Joint, Percutaneous Approach */
"0SPF37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Ankle Joint, Percutaneous Approach */
"0SPF3JZ" = "1" /* Removal of Synthetic Substitute from Right Ankle Joint, Percutaneous Approach */
"0SPF3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Ankle Joint, Percutaneous Approach */
"0SPF40Z" = "1" /* Removal of Drainage Device from Right Ankle Joint, Percutaneous Endoscopic Approach */
"0SPF43Z" = "1" /* Removal of Infusion Device from Right Ankle Joint, Percutaneous Endoscopic Approach */
"0SPF44Z" = "1" /* Removal of Internal Fixation Device from Right Ankle Joint, Percutaneous Endoscopic Approach */
"0SPF45Z" = "1" /* Removal of External Fixation Device from Right Ankle Joint, Percutaneous Endoscopic Approach */
"0SPF47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Ankle Joint, Percutaneous Endoscopic Approach */
"0SPF4JZ" = "1" /* Removal of Synthetic Substitute from Right Ankle Joint, Percutaneous Endoscopic Approach */
"0SPF4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Ankle Joint, Percutaneous Endoscopic Approach */
"0SPG00Z" = "1" /* Removal of Drainage Device from Left Ankle Joint, Open Approach */
"0SPG03Z" = "1" /* Removal of Infusion Device from Left Ankle Joint, Open Approach */
"0SPG04Z" = "1" /* Removal of Internal Fixation Device from Left Ankle Joint, Open Approach */
"0SPG05Z" = "1" /* Removal of External Fixation Device from Left Ankle Joint, Open Approach */
"0SPG07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Ankle Joint, Open Approach */
"0SPG0JZ" = "1" /* Removal of Synthetic Substitute from Left Ankle Joint, Open Approach */
"0SPG0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Ankle Joint, Open Approach */
"0SPG34Z" = "1" /* Removal of Internal Fixation Device from Left Ankle Joint, Percutaneous Approach */
"0SPG35Z" = "1" /* Removal of External Fixation Device from Left Ankle Joint, Percutaneous Approach */
"0SPG37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Ankle Joint, Percutaneous Approach */
"0SPG3JZ" = "1" /* Removal of Synthetic Substitute from Left Ankle Joint, Percutaneous Approach */
"0SPG3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Ankle Joint, Percutaneous Approach */
"0SPG40Z" = "1" /* Removal of Drainage Device from Left Ankle Joint, Percutaneous Endoscopic Approach */
"0SPG43Z" = "1" /* Removal of Infusion Device from Left Ankle Joint, Percutaneous Endoscopic Approach */
"0SPG44Z" = "1" /* Removal of Internal Fixation Device from Left Ankle Joint, Percutaneous Endoscopic Approach */
"0SPG45Z" = "1" /* Removal of External Fixation Device from Left Ankle Joint, Percutaneous Endoscopic Approach */
"0SPG47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Ankle Joint, Percutaneous Endoscopic Approach */
"0SPG4JZ" = "1" /* Removal of Synthetic Substitute from Left Ankle Joint, Percutaneous Endoscopic Approach */
"0SPG4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Ankle Joint, Percutaneous Endoscopic Approach */
"0SPH00Z" = "1" /* Removal of Drainage Device from Right Tarsal Joint, Open Approach */
"0SPH03Z" = "1" /* Removal of Infusion Device from Right Tarsal Joint, Open Approach */
"0SPH04Z" = "1" /* Removal of Internal Fixation Device from Right Tarsal Joint, Open Approach */
"0SPH05Z" = "1" /* Removal of External Fixation Device from Right Tarsal Joint, Open Approach */
"0SPH07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Tarsal Joint, Open Approach */
"0SPH0JZ" = "1" /* Removal of Synthetic Substitute from Right Tarsal Joint, Open Approach */
"0SPH0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Tarsal Joint, Open Approach */
"0SPH34Z" = "1" /* Removal of Internal Fixation Device from Right Tarsal Joint, Percutaneous Approach */
"0SPH35Z" = "1" /* Removal of External Fixation Device from Right Tarsal Joint, Percutaneous Approach */
"0SPH37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Tarsal Joint, Percutaneous Approach */
"0SPH3JZ" = "1" /* Removal of Synthetic Substitute from Right Tarsal Joint, Percutaneous Approach */
"0SPH3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Tarsal Joint, Percutaneous Approach */
"0SPH40Z" = "1" /* Removal of Drainage Device from Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPH43Z" = "1" /* Removal of Infusion Device from Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPH44Z" = "1" /* Removal of Internal Fixation Device from Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPH45Z" = "1" /* Removal of External Fixation Device from Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPH47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPH4JZ" = "1" /* Removal of Synthetic Substitute from Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPH4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPJ00Z" = "1" /* Removal of Drainage Device from Left Tarsal Joint, Open Approach */
"0SPJ03Z" = "1" /* Removal of Infusion Device from Left Tarsal Joint, Open Approach */
"0SPJ04Z" = "1" /* Removal of Internal Fixation Device from Left Tarsal Joint, Open Approach */
"0SPJ05Z" = "1" /* Removal of External Fixation Device from Left Tarsal Joint, Open Approach */
"0SPJ07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Tarsal Joint, Open Approach */
"0SPJ0JZ" = "1" /* Removal of Synthetic Substitute from Left Tarsal Joint, Open Approach */
"0SPJ0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Tarsal Joint, Open Approach */
"0SPJ34Z" = "1" /* Removal of Internal Fixation Device from Left Tarsal Joint, Percutaneous Approach */
"0SPJ35Z" = "1" /* Removal of External Fixation Device from Left Tarsal Joint, Percutaneous Approach */
"0SPJ37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Tarsal Joint, Percutaneous Approach */
"0SPJ3JZ" = "1" /* Removal of Synthetic Substitute from Left Tarsal Joint, Percutaneous Approach */
"0SPJ3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Tarsal Joint, Percutaneous Approach */
"0SPJ40Z" = "1" /* Removal of Drainage Device from Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPJ43Z" = "1" /* Removal of Infusion Device from Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPJ44Z" = "1" /* Removal of Internal Fixation Device from Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPJ45Z" = "1" /* Removal of External Fixation Device from Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPJ47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPJ4JZ" = "1" /* Removal of Synthetic Substitute from Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPJ4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPK00Z" = "1" /* Removal of Drainage Device from Right Metatarsal-Tarsal Joint, Open Approach */
"0SPK03Z" = "1" /* Removal of Infusion Device from Right Metatarsal-Tarsal Joint, Open Approach */
"0SPK04Z" = "1" /* Removal of Internal Fixation Device from Right Metatarsal-Tarsal Joint, Open Approach */
"0SPK05Z" = "1" /* Removal of External Fixation Device from Right Metatarsal-Tarsal Joint, Open Approach */
"0SPK07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Metatarsal-Tarsal Joint, Open Approach */
"0SPK0JZ" = "1" /* Removal of Synthetic Substitute from Right Metatarsal-Tarsal Joint, Open Approach */
"0SPK0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Metatarsal-Tarsal Joint, Open Approach */
"0SPK34Z" = "1" /* Removal of Internal Fixation Device from Right Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SPK35Z" = "1" /* Removal of External Fixation Device from Right Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SPK37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SPK3JZ" = "1" /* Removal of Synthetic Substitute from Right Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SPK3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SPK40Z" = "1" /* Removal of Drainage Device from Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPK43Z" = "1" /* Removal of Infusion Device from Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPK44Z" = "1" /* Removal of Internal Fixation Device from Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPK45Z" = "1" /* Removal of External Fixation Device from Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPK47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPK4JZ" = "1" /* Removal of Synthetic Substitute from Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPK4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPL00Z" = "1" /* Removal of Drainage Device from Left Metatarsal-Tarsal Joint, Open Approach */
"0SPL03Z" = "1" /* Removal of Infusion Device from Left Metatarsal-Tarsal Joint, Open Approach */
"0SPL04Z" = "1" /* Removal of Internal Fixation Device from Left Metatarsal-Tarsal Joint, Open Approach */
"0SPL05Z" = "1" /* Removal of External Fixation Device from Left Metatarsal-Tarsal Joint, Open Approach */
"0SPL07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Metatarsal-Tarsal Joint, Open Approach */
"0SPL0JZ" = "1" /* Removal of Synthetic Substitute from Left Metatarsal-Tarsal Joint, Open Approach */
"0SPL0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Metatarsal-Tarsal Joint, Open Approach */
"0SPL34Z" = "1" /* Removal of Internal Fixation Device from Left Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SPL35Z" = "1" /* Removal of External Fixation Device from Left Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SPL37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SPL3JZ" = "1" /* Removal of Synthetic Substitute from Left Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SPL3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SPL40Z" = "1" /* Removal of Drainage Device from Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPL43Z" = "1" /* Removal of Infusion Device from Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPL44Z" = "1" /* Removal of Internal Fixation Device from Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPL45Z" = "1" /* Removal of External Fixation Device from Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPL47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPL4JZ" = "1" /* Removal of Synthetic Substitute from Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPL4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SPM00Z" = "1" /* Removal of Drainage Device from Right Metatarsal-Phalangeal Joint, Open Approach */
"0SPM03Z" = "1" /* Removal of Infusion Device from Right Metatarsal-Phalangeal Joint, Open Approach */
"0SPM04Z" = "1" /* Removal of Internal Fixation Device from Right Metatarsal-Phalangeal Joint, Open Approach */
"0SPM05Z" = "1" /* Removal of External Fixation Device from Right Metatarsal-Phalangeal Joint, Open Approach */
"0SPM07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Metatarsal-Phalangeal Joint, Open Approach */
"0SPM0JZ" = "1" /* Removal of Synthetic Substitute from Right Metatarsal-Phalangeal Joint, Open Approach */
"0SPM0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Metatarsal-Phalangeal Joint, Open Approach */
"0SPM34Z" = "1" /* Removal of Internal Fixation Device from Right Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SPM35Z" = "1" /* Removal of External Fixation Device from Right Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SPM37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SPM3JZ" = "1" /* Removal of Synthetic Substitute from Right Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SPM3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SPM40Z" = "1" /* Removal of Drainage Device from Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPM43Z" = "1" /* Removal of Infusion Device from Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPM44Z" = "1" /* Removal of Internal Fixation Device from Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPM45Z" = "1" /* Removal of External Fixation Device from Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPM47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPM4JZ" = "1" /* Removal of Synthetic Substitute from Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPM4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPN00Z" = "1" /* Removal of Drainage Device from Left Metatarsal-Phalangeal Joint, Open Approach */
"0SPN03Z" = "1" /* Removal of Infusion Device from Left Metatarsal-Phalangeal Joint, Open Approach */
"0SPN04Z" = "1" /* Removal of Internal Fixation Device from Left Metatarsal-Phalangeal Joint, Open Approach */
"0SPN05Z" = "1" /* Removal of External Fixation Device from Left Metatarsal-Phalangeal Joint, Open Approach */
"0SPN07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Metatarsal-Phalangeal Joint, Open Approach */
"0SPN0JZ" = "1" /* Removal of Synthetic Substitute from Left Metatarsal-Phalangeal Joint, Open Approach */
"0SPN0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Metatarsal-Phalangeal Joint, Open Approach */
"0SPN34Z" = "1" /* Removal of Internal Fixation Device from Left Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SPN35Z" = "1" /* Removal of External Fixation Device from Left Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SPN37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SPN3JZ" = "1" /* Removal of Synthetic Substitute from Left Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SPN3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SPN40Z" = "1" /* Removal of Drainage Device from Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPN43Z" = "1" /* Removal of Infusion Device from Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPN44Z" = "1" /* Removal of Internal Fixation Device from Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPN45Z" = "1" /* Removal of External Fixation Device from Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPN47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPN4JZ" = "1" /* Removal of Synthetic Substitute from Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPN4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPP00Z" = "1" /* Removal of Drainage Device from Right Toe Phalangeal Joint, Open Approach */
"0SPP03Z" = "1" /* Removal of Infusion Device from Right Toe Phalangeal Joint, Open Approach */
"0SPP04Z" = "1" /* Removal of Internal Fixation Device from Right Toe Phalangeal Joint, Open Approach */
"0SPP05Z" = "1" /* Removal of External Fixation Device from Right Toe Phalangeal Joint, Open Approach */
"0SPP07Z" = "1" /* Removal of Autologous Tissue Substitute from Right Toe Phalangeal Joint, Open Approach */
"0SPP0JZ" = "1" /* Removal of Synthetic Substitute from Right Toe Phalangeal Joint, Open Approach */
"0SPP0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Toe Phalangeal Joint, Open Approach */
"0SPP34Z" = "1" /* Removal of Internal Fixation Device from Right Toe Phalangeal Joint, Percutaneous Approach */
"0SPP35Z" = "1" /* Removal of External Fixation Device from Right Toe Phalangeal Joint, Percutaneous Approach */
"0SPP37Z" = "1" /* Removal of Autologous Tissue Substitute from Right Toe Phalangeal Joint, Percutaneous Approach */
"0SPP3JZ" = "1" /* Removal of Synthetic Substitute from Right Toe Phalangeal Joint, Percutaneous Approach */
"0SPP3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Toe Phalangeal Joint, Percutaneous Approach */
"0SPP40Z" = "1" /* Removal of Drainage Device from Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPP43Z" = "1" /* Removal of Infusion Device from Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPP44Z" = "1" /* Removal of Internal Fixation Device from Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPP45Z" = "1" /* Removal of External Fixation Device from Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPP47Z" = "1" /* Removal of Autologous Tissue Substitute from Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPP4JZ" = "1" /* Removal of Synthetic Substitute from Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPP4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPQ00Z" = "1" /* Removal of Drainage Device from Left Toe Phalangeal Joint, Open Approach */
"0SPQ03Z" = "1" /* Removal of Infusion Device from Left Toe Phalangeal Joint, Open Approach */
"0SPQ04Z" = "1" /* Removal of Internal Fixation Device from Left Toe Phalangeal Joint, Open Approach */
"0SPQ05Z" = "1" /* Removal of External Fixation Device from Left Toe Phalangeal Joint, Open Approach */
"0SPQ07Z" = "1" /* Removal of Autologous Tissue Substitute from Left Toe Phalangeal Joint, Open Approach */
"0SPQ0JZ" = "1" /* Removal of Synthetic Substitute from Left Toe Phalangeal Joint, Open Approach */
"0SPQ0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Toe Phalangeal Joint, Open Approach */
"0SPQ34Z" = "1" /* Removal of Internal Fixation Device from Left Toe Phalangeal Joint, Percutaneous Approach */
"0SPQ35Z" = "1" /* Removal of External Fixation Device from Left Toe Phalangeal Joint, Percutaneous Approach */
"0SPQ37Z" = "1" /* Removal of Autologous Tissue Substitute from Left Toe Phalangeal Joint, Percutaneous Approach */
"0SPQ3JZ" = "1" /* Removal of Synthetic Substitute from Left Toe Phalangeal Joint, Percutaneous Approach */
"0SPQ3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Toe Phalangeal Joint, Percutaneous Approach */
"0SPQ40Z" = "1" /* Removal of Drainage Device from Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPQ43Z" = "1" /* Removal of Infusion Device from Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPQ44Z" = "1" /* Removal of Internal Fixation Device from Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPQ45Z" = "1" /* Removal of External Fixation Device from Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPQ47Z" = "1" /* Removal of Autologous Tissue Substitute from Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPQ4JZ" = "1" /* Removal of Synthetic Substitute from Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPQ4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SPR0JZ" = "1" /* Removal of Synthetic Substitute from Right Hip Joint, Femoral Surface, Open Approach */
"0SPR3JZ" = "1" /* Removal of Synthetic Substitute from Right Hip Joint, Femoral Surface, Percutaneous Approach */
"0SPR4JZ" = "1" /* Removal of Synthetic Substitute from Right Hip Joint, Femoral Surface, Percutaneous Endoscopic Approach */
"0SPS0JZ" = "1" /* Removal of Synthetic Substitute from Left Hip Joint, Femoral Surface, Open Approach */
"0SPS3JZ" = "1" /* Removal of Synthetic Substitute from Left Hip Joint, Femoral Surface, Percutaneous Approach */
"0SPS4JZ" = "1" /* Removal of Synthetic Substitute from Left Hip Joint, Femoral Surface, Percutaneous Endoscopic Approach */
"0SPT0JZ" = "1" /* Removal of Synthetic Substitute from Right Knee Joint, Femoral Surface, Open Approach */
"0SPT3JZ" = "1" /* Removal of Synthetic Substitute from Right Knee Joint, Femoral Surface, Percutaneous Approach */
"0SPT4JZ" = "1" /* Removal of Synthetic Substitute from Right Knee Joint, Femoral Surface, Percutaneous Endoscopic Approach */
"0SPU0JZ" = "1" /* Removal of Synthetic Substitute from Left Knee Joint, Femoral Surface, Open Approach */
"0SPU3JZ" = "1" /* Removal of Synthetic Substitute from Left Knee Joint, Femoral Surface, Percutaneous Approach */
"0SPU4JZ" = "1" /* Removal of Synthetic Substitute from Left Knee Joint, Femoral Surface, Percutaneous Endoscopic Approach */
"0SPV0JZ" = "1" /* Removal of Synthetic Substitute from Right Knee Joint, Tibial Surface, Open Approach */
"0SPV3JZ" = "1" /* Removal of Synthetic Substitute from Right Knee Joint, Tibial Surface, Percutaneous Approach */
"0SPV4JZ" = "1" /* Removal of Synthetic Substitute from Right Knee Joint, Tibial Surface, Percutaneous Endoscopic Approach */
"0SPW0JZ" = "1" /* Removal of Synthetic Substitute from Left Knee Joint, Tibial Surface, Open Approach */
"0SPW3JZ" = "1" /* Removal of Synthetic Substitute from Left Knee Joint, Tibial Surface, Percutaneous Approach */
"0SPW4JZ" = "1" /* Removal of Synthetic Substitute from Left Knee Joint, Tibial Surface, Percutaneous Endoscopic Approach */
"0SQ00ZZ" = "1" /* Repair Lumbar Vertebral Joint, Open Approach */
"0SQ03ZZ" = "1" /* Repair Lumbar Vertebral Joint, Percutaneous Approach */
"0SQ04ZZ" = "1" /* Repair Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SQ20ZZ" = "1" /* Repair Lumbar Vertebral Disc, Open Approach */
"0SQ23ZZ" = "1" /* Repair Lumbar Vertebral Disc, Percutaneous Approach */
"0SQ24ZZ" = "1" /* Repair Lumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0SQ30ZZ" = "1" /* Repair Lumbosacral Joint, Open Approach */
"0SQ33ZZ" = "1" /* Repair Lumbosacral Joint, Percutaneous Approach */
"0SQ34ZZ" = "1" /* Repair Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SQ40ZZ" = "1" /* Repair Lumbosacral Disc, Open Approach */
"0SQ43ZZ" = "1" /* Repair Lumbosacral Disc, Percutaneous Approach */
"0SQ44ZZ" = "1" /* Repair Lumbosacral Disc, Percutaneous Endoscopic Approach */
"0SQ50ZZ" = "1" /* Repair Sacrococcygeal Joint, Open Approach */
"0SQ53ZZ" = "1" /* Repair Sacrococcygeal Joint, Percutaneous Approach */
"0SQ54ZZ" = "1" /* Repair Sacrococcygeal Joint, Percutaneous Endoscopic Approach */
"0SQ60ZZ" = "1" /* Repair Coccygeal Joint, Open Approach */
"0SQ63ZZ" = "1" /* Repair Coccygeal Joint, Percutaneous Approach */
"0SQ64ZZ" = "1" /* Repair Coccygeal Joint, Percutaneous Endoscopic Approach */
"0SQ70ZZ" = "1" /* Repair Right Sacroiliac Joint, Open Approach */
"0SQ73ZZ" = "1" /* Repair Right Sacroiliac Joint, Percutaneous Approach */
"0SQ74ZZ" = "1" /* Repair Right Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SQ80ZZ" = "1" /* Repair Left Sacroiliac Joint, Open Approach */
"0SQ83ZZ" = "1" /* Repair Left Sacroiliac Joint, Percutaneous Approach */
"0SQ84ZZ" = "1" /* Repair Left Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SQ90ZZ" = "1" /* Repair Right Hip Joint, Open Approach */
"0SQ93ZZ" = "1" /* Repair Right Hip Joint, Percutaneous Approach */
"0SQ94ZZ" = "1" /* Repair Right Hip Joint, Percutaneous Endoscopic Approach */
"0SQB0ZZ" = "1" /* Repair Left Hip Joint, Open Approach */
"0SQB3ZZ" = "1" /* Repair Left Hip Joint, Percutaneous Approach */
"0SQB4ZZ" = "1" /* Repair Left Hip Joint, Percutaneous Endoscopic Approach */
"0SQC0ZZ" = "1" /* Repair Right Knee Joint, Open Approach */
"0SQC3ZZ" = "1" /* Repair Right Knee Joint, Percutaneous Approach */
"0SQC4ZZ" = "1" /* Repair Right Knee Joint, Percutaneous Endoscopic Approach */
"0SQD0ZZ" = "1" /* Repair Left Knee Joint, Open Approach */
"0SQD3ZZ" = "1" /* Repair Left Knee Joint, Percutaneous Approach */
"0SQD4ZZ" = "1" /* Repair Left Knee Joint, Percutaneous Endoscopic Approach */
"0SQF0ZZ" = "1" /* Repair Right Ankle Joint, Open Approach */
"0SQF3ZZ" = "1" /* Repair Right Ankle Joint, Percutaneous Approach */
"0SQF4ZZ" = "1" /* Repair Right Ankle Joint, Percutaneous Endoscopic Approach */
"0SQG0ZZ" = "1" /* Repair Left Ankle Joint, Open Approach */
"0SQG3ZZ" = "1" /* Repair Left Ankle Joint, Percutaneous Approach */
"0SQG4ZZ" = "1" /* Repair Left Ankle Joint, Percutaneous Endoscopic Approach */
"0SQH0ZZ" = "1" /* Repair Right Tarsal Joint, Open Approach */
"0SQH3ZZ" = "1" /* Repair Right Tarsal Joint, Percutaneous Approach */
"0SQH4ZZ" = "1" /* Repair Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0SQJ0ZZ" = "1" /* Repair Left Tarsal Joint, Open Approach */
"0SQJ3ZZ" = "1" /* Repair Left Tarsal Joint, Percutaneous Approach */
"0SQJ4ZZ" = "1" /* Repair Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0SQK0ZZ" = "1" /* Repair Right Metatarsal-Tarsal Joint, Open Approach */
"0SQK3ZZ" = "1" /* Repair Right Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SQK4ZZ" = "1" /* Repair Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SQL0ZZ" = "1" /* Repair Left Metatarsal-Tarsal Joint, Open Approach */
"0SQL3ZZ" = "1" /* Repair Left Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SQL4ZZ" = "1" /* Repair Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SQM0ZZ" = "1" /* Repair Right Metatarsal-Phalangeal Joint, Open Approach */
"0SQM3ZZ" = "1" /* Repair Right Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SQM4ZZ" = "1" /* Repair Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SQN0ZZ" = "1" /* Repair Left Metatarsal-Phalangeal Joint, Open Approach */
"0SQN3ZZ" = "1" /* Repair Left Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SQN4ZZ" = "1" /* Repair Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SQP0ZZ" = "1" /* Repair Right Toe Phalangeal Joint, Open Approach */
"0SQP3ZZ" = "1" /* Repair Right Toe Phalangeal Joint, Percutaneous Approach */
"0SQP4ZZ" = "1" /* Repair Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SQQ0ZZ" = "1" /* Repair Left Toe Phalangeal Joint, Open Approach */
"0SQQ3ZZ" = "1" /* Repair Left Toe Phalangeal Joint, Percutaneous Approach */
"0SQQ4ZZ" = "1" /* Repair Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SR007Z" = "1" /* Replacement of Lumbar Vertebral Joint with Autologous Tissue Substitute, Open Approach */
"0SR00JZ" = "1" /* Replacement of Lumbar Vertebral Joint with Synthetic Substitute, Open Approach */
"0SR00KZ" = "1" /* Replacement of Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Open Approach */
"0SR207Z" = "1" /* Replacement of Lumbar Vertebral Disc with Autologous Tissue Substitute, Open Approach */
"0SR20JZ" = "1" /* Replacement of Lumbar Vertebral Disc with Synthetic Substitute, Open Approach */
"0SR20KZ" = "1" /* Replacement of Lumbar Vertebral Disc with Nonautologous Tissue Substitute, Open Approach */
"0SR307Z" = "1" /* Replacement of Lumbosacral Joint with Autologous Tissue Substitute, Open Approach */
"0SR30JZ" = "1" /* Replacement of Lumbosacral Joint with Synthetic Substitute, Open Approach */
"0SR30KZ" = "1" /* Replacement of Lumbosacral Joint with Nonautologous Tissue Substitute, Open Approach */
"0SR407Z" = "1" /* Replacement of Lumbosacral Disc with Autologous Tissue Substitute, Open Approach */
"0SR40JZ" = "1" /* Replacement of Lumbosacral Disc with Synthetic Substitute, Open Approach */
"0SR40KZ" = "1" /* Replacement of Lumbosacral Disc with Nonautologous Tissue Substitute, Open Approach */
"0SR507Z" = "1" /* Replacement of Sacrococcygeal Joint with Autologous Tissue Substitute, Open Approach */
"0SR50JZ" = "1" /* Replacement of Sacrococcygeal Joint with Synthetic Substitute, Open Approach */
"0SR50KZ" = "1" /* Replacement of Sacrococcygeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SR607Z" = "1" /* Replacement of Coccygeal Joint with Autologous Tissue Substitute, Open Approach */
"0SR60JZ" = "1" /* Replacement of Coccygeal Joint with Synthetic Substitute, Open Approach */
"0SR60KZ" = "1" /* Replacement of Coccygeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SR707Z" = "1" /* Replacement of Right Sacroiliac Joint with Autologous Tissue Substitute, Open Approach */
"0SR70JZ" = "1" /* Replacement of Right Sacroiliac Joint with Synthetic Substitute, Open Approach */
"0SR70KZ" = "1" /* Replacement of Right Sacroiliac Joint with Nonautologous Tissue Substitute, Open Approach */
"0SR807Z" = "1" /* Replacement of Left Sacroiliac Joint with Autologous Tissue Substitute, Open Approach */
"0SR80JZ" = "1" /* Replacement of Left Sacroiliac Joint with Synthetic Substitute, Open Approach */
"0SR80KZ" = "1" /* Replacement of Left Sacroiliac Joint with Nonautologous Tissue Substitute, Open Approach */
"0SR9019" = "1" /* Replacement of Right Hip Joint with Metal Synthetic Substitute, Cemented, Open Approach */
"0SR901A" = "1" /* Replacement of Right Hip Joint with Metal Synthetic Substitute, Uncemented, Open Approach */
"0SR901Z" = "1" /* Replacement of Right Hip Joint with Metal Synthetic Substitute, Open Approach */
"0SR9029" = "1" /* Replacement of Right Hip Joint with Metal on Polyethylene Synthetic Substitute, Cemented, Open Approach */
"0SR902A" = "1" /* Replacement of Right Hip Joint with Metal on Polyethylene Synthetic Substitute, Uncemented, Open Approach */
"0SR902Z" = "1" /* Replacement of Right Hip Joint with Metal on Polyethylene Synthetic Substitute, Open Approach */
"0SR9039" = "1" /* Replacement of Right Hip Joint with Ceramic Synthetic Substitute, Cemented, Open Approach */
"0SR903A" = "1" /* Replacement of Right Hip Joint with Ceramic Synthetic Substitute, Uncemented, Open Approach */
"0SR903Z" = "1" /* Replacement of Right Hip Joint with Ceramic Synthetic Substitute, Open Approach */
"0SR9049" = "1" /* Replacement of Right Hip Joint with Ceramic on Polyethylene Synthetic Substitute, Cemented, Open Approach */
"0SR904A" = "1" /* Replacement of Right Hip Joint with Ceramic on Polyethylene Synthetic Substitute, Uncemented, Open Approach */
"0SR904Z" = "1" /* Replacement of Right Hip Joint with Ceramic on Polyethylene Synthetic Substitute, Open Approach */
"0SR907Z" = "1" /* Replacement of Right Hip Joint with Autologous Tissue Substitute, Open Approach */
"0SR90J9" = "1" /* Replacement of Right Hip Joint with Synthetic Substitute, Cemented, Open Approach */
"0SR90JA" = "1" /* Replacement of Right Hip Joint with Synthetic Substitute, Uncemented, Open Approach */
"0SR90JZ" = "1" /* Replacement of Right Hip Joint with Synthetic Substitute, Open Approach */
"0SR90KZ" = "1" /* Replacement of Right Hip Joint with Nonautologous Tissue Substitute, Open Approach */
"0SRA009" = "1" /* Replacement of Right Hip Joint, Acetabular Surface with Polyethylene Synthetic Substitute, Cemented, Open Approach */
"0SRA00A" = "1" /* Replacement of Right Hip Joint, Acetabular Surface with Polyethylene Synthetic Substitute, Uncemented, Open Approach */
"0SRA00Z" = "1" /* Replacement of Right Hip Joint, Acetabular Surface with Polyethylene Synthetic Substitute, Open Approach */
"0SRA019" = "1" /* Replacement of Right Hip Joint, Acetabular Surface with Metal Synthetic Substitute, Cemented, Open Approach */
"0SRA01A" = "1" /* Replacement of Right Hip Joint, Acetabular Surface with Metal Synthetic Substitute, Uncemented, Open Approach */
"0SRA01Z" = "1" /* Replacement of Right Hip Joint, Acetabular Surface with Metal Synthetic Substitute, Open Approach */
"0SRA039" = "1" /* Replacement of Right Hip Joint, Acetabular Surface with Ceramic Synthetic Substitute, Cemented, Open Approach */
"0SRA03A" = "1" /* Replacement of Right Hip Joint, Acetabular Surface with Ceramic Synthetic Substitute, Uncemented, Open Approach */
"0SRA03Z" = "1" /* Replacement of Right Hip Joint, Acetabular Surface with Ceramic Synthetic Substitute, Open Approach */
"0SRA07Z" = "1" /* Replacement of Right Hip Joint, Acetabular Surface with Autologous Tissue Substitute, Open Approach */
"0SRA0J9" = "1" /* Replacement of Right Hip Joint, Acetabular Surface with Synthetic Substitute, Cemented, Open Approach */
"0SRA0JA" = "1" /* Replacement of Right Hip Joint, Acetabular Surface with Synthetic Substitute, Uncemented, Open Approach */
"0SRA0JZ" = "1" /* Replacement of Right Hip Joint, Acetabular Surface with Synthetic Substitute, Open Approach */
"0SRA0KZ" = "1" /* Replacement of Right Hip Joint, Acetabular Surface with Nonautologous Tissue Substitute, Open Approach */
"0SRB019" = "1" /* Replacement of Left Hip Joint with Metal Synthetic Substitute, Cemented, Open Approach */
"0SRB01A" = "1" /* Replacement of Left Hip Joint with Metal Synthetic Substitute, Uncemented, Open Approach */
"0SRB01Z" = "1" /* Replacement of Left Hip Joint with Metal Synthetic Substitute, Open Approach */
"0SRB029" = "1" /* Replacement of Left Hip Joint with Metal on Polyethylene Synthetic Substitute, Cemented, Open Approach */
"0SRB02A" = "1" /* Replacement of Left Hip Joint with Metal on Polyethylene Synthetic Substitute, Uncemented, Open Approach */
"0SRB02Z" = "1" /* Replacement of Left Hip Joint with Metal on Polyethylene Synthetic Substitute, Open Approach */
"0SRB039" = "1" /* Replacement of Left Hip Joint with Ceramic Synthetic Substitute, Cemented, Open Approach */
"0SRB03A" = "1" /* Replacement of Left Hip Joint with Ceramic Synthetic Substitute, Uncemented, Open Approach */
"0SRB03Z" = "1" /* Replacement of Left Hip Joint with Ceramic Synthetic Substitute, Open Approach */
"0SRB049" = "1" /* Replacement of Left Hip Joint with Ceramic on Polyethylene Synthetic Substitute, Cemented, Open Approach */
"0SRB04A" = "1" /* Replacement of Left Hip Joint with Ceramic on Polyethylene Synthetic Substitute, Uncemented, Open Approach */
"0SRB04Z" = "1" /* Replacement of Left Hip Joint with Ceramic on Polyethylene Synthetic Substitute, Open Approach */
"0SRB07Z" = "1" /* Replacement of Left Hip Joint with Autologous Tissue Substitute, Open Approach */
"0SRB0J9" = "1" /* Replacement of Left Hip Joint with Synthetic Substitute, Cemented, Open Approach */
"0SRB0JA" = "1" /* Replacement of Left Hip Joint with Synthetic Substitute, Uncemented, Open Approach */
"0SRB0JZ" = "1" /* Replacement of Left Hip Joint with Synthetic Substitute, Open Approach */
"0SRB0KZ" = "1" /* Replacement of Left Hip Joint with Nonautologous Tissue Substitute, Open Approach */
"0SRC07Z" = "1" /* Replacement of Right Knee Joint with Autologous Tissue Substitute, Open Approach */
"0SRC0J9" = "1" /* Replacement of Right Knee Joint with Synthetic Substitute, Cemented, Open Approach */
"0SRC0JA" = "1" /* Replacement of Right Knee Joint with Synthetic Substitute, Uncemented, Open Approach */
"0SRC0JZ" = "1" /* Replacement of Right Knee Joint with Synthetic Substitute, Open Approach */
"0SRC0KZ" = "1" /* Replacement of Right Knee Joint with Nonautologous Tissue Substitute, Open Approach */
"0SRC0L9" = "1" /* Replacement of Right Knee Joint with Unicondylar Synthetic Substitute, Cemented, Open Approach */
"0SRC0LA" = "1" /* Replacement of Right Knee Joint with Unicondylar Synthetic Substitute, Uncemented, Open Approach */
"0SRC0LZ" = "1" /* Replacement of Right Knee Joint with Unicondylar Synthetic Substitute, Open Approach */
"0SRD07Z" = "1" /* Replacement of Left Knee Joint with Autologous Tissue Substitute, Open Approach */
"0SRD0J9" = "1" /* Replacement of Left Knee Joint with Synthetic Substitute, Cemented, Open Approach */
"0SRD0JA" = "1" /* Replacement of Left Knee Joint with Synthetic Substitute, Uncemented, Open Approach */
"0SRD0JZ" = "1" /* Replacement of Left Knee Joint with Synthetic Substitute, Open Approach */
"0SRD0KZ" = "1" /* Replacement of Left Knee Joint with Nonautologous Tissue Substitute, Open Approach */
"0SRD0L9" = "1" /* Replacement of Left Knee Joint with Unicondylar Synthetic Substitute, Cemented, Open Approach */
"0SRD0LA" = "1" /* Replacement of Left Knee Joint with Unicondylar Synthetic Substitute, Uncemented, Open Approach */
"0SRD0LZ" = "1" /* Replacement of Left Knee Joint with Unicondylar Synthetic Substitute, Open Approach */
"0SRE009" = "1" /* Replacement of Left Hip Joint, Acetabular Surface with Polyethylene Synthetic Substitute, Cemented, Open Approach */
"0SRE00A" = "1" /* Replacement of Left Hip Joint, Acetabular Surface with Polyethylene Synthetic Substitute, Uncemented, Open Approach */
"0SRE00Z" = "1" /* Replacement of Left Hip Joint, Acetabular Surface with Polyethylene Synthetic Substitute, Open Approach */
"0SRE019" = "1" /* Replacement of Left Hip Joint, Acetabular Surface with Metal Synthetic Substitute, Cemented, Open Approach */
"0SRE01A" = "1" /* Replacement of Left Hip Joint, Acetabular Surface with Metal Synthetic Substitute, Uncemented, Open Approach */
"0SRE01Z" = "1" /* Replacement of Left Hip Joint, Acetabular Surface with Metal Synthetic Substitute, Open Approach */
"0SRE039" = "1" /* Replacement of Left Hip Joint, Acetabular Surface with Ceramic Synthetic Substitute, Cemented, Open Approach */
"0SRE03A" = "1" /* Replacement of Left Hip Joint, Acetabular Surface with Ceramic Synthetic Substitute, Uncemented, Open Approach */
"0SRE03Z" = "1" /* Replacement of Left Hip Joint, Acetabular Surface with Ceramic Synthetic Substitute, Open Approach */
"0SRE07Z" = "1" /* Replacement of Left Hip Joint, Acetabular Surface with Autologous Tissue Substitute, Open Approach */
"0SRE0J9" = "1" /* Replacement of Left Hip Joint, Acetabular Surface with Synthetic Substitute, Cemented, Open Approach */
"0SRE0JA" = "1" /* Replacement of Left Hip Joint, Acetabular Surface with Synthetic Substitute, Uncemented, Open Approach */
"0SRE0JZ" = "1" /* Replacement of Left Hip Joint, Acetabular Surface with Synthetic Substitute, Open Approach */
"0SRE0KZ" = "1" /* Replacement of Left Hip Joint, Acetabular Surface with Nonautologous Tissue Substitute, Open Approach */
"0SRF07Z" = "1" /* Replacement of Right Ankle Joint with Autologous Tissue Substitute, Open Approach */
"0SRF0J9" = "1" /* Replacement of Right Ankle Joint with Synthetic Substitute, Cemented, Open Approach */
"0SRF0JA" = "1" /* Replacement of Right Ankle Joint with Synthetic Substitute, Uncemented, Open Approach */
"0SRF0JZ" = "1" /* Replacement of Right Ankle Joint with Synthetic Substitute, Open Approach */
"0SRF0KZ" = "1" /* Replacement of Right Ankle Joint with Nonautologous Tissue Substitute, Open Approach */
"0SRG07Z" = "1" /* Replacement of Left Ankle Joint with Autologous Tissue Substitute, Open Approach */
"0SRG0J9" = "1" /* Replacement of Left Ankle Joint with Synthetic Substitute, Cemented, Open Approach */
"0SRG0JA" = "1" /* Replacement of Left Ankle Joint with Synthetic Substitute, Uncemented, Open Approach */
"0SRG0JZ" = "1" /* Replacement of Left Ankle Joint with Synthetic Substitute, Open Approach */
"0SRG0KZ" = "1" /* Replacement of Left Ankle Joint with Nonautologous Tissue Substitute, Open Approach */
"0SRH07Z" = "1" /* Replacement of Right Tarsal Joint with Autologous Tissue Substitute, Open Approach */
"0SRH0JZ" = "1" /* Replacement of Right Tarsal Joint with Synthetic Substitute, Open Approach */
"0SRH0KZ" = "1" /* Replacement of Right Tarsal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SRJ07Z" = "1" /* Replacement of Left Tarsal Joint with Autologous Tissue Substitute, Open Approach */
"0SRJ0JZ" = "1" /* Replacement of Left Tarsal Joint with Synthetic Substitute, Open Approach */
"0SRJ0KZ" = "1" /* Replacement of Left Tarsal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SRK07Z" = "1" /* Replacement of Right Metatarsal-Tarsal Joint with Autologous Tissue Substitute, Open Approach */
"0SRK0JZ" = "1" /* Replacement of Right Metatarsal-Tarsal Joint with Synthetic Substitute, Open Approach */
"0SRK0KZ" = "1" /* Replacement of Right Metatarsal-Tarsal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SRL07Z" = "1" /* Replacement of Left Metatarsal-Tarsal Joint with Autologous Tissue Substitute, Open Approach */
"0SRL0JZ" = "1" /* Replacement of Left Metatarsal-Tarsal Joint with Synthetic Substitute, Open Approach */
"0SRL0KZ" = "1" /* Replacement of Left Metatarsal-Tarsal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SRM07Z" = "1" /* Replacement of Right Metatarsal-Phalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0SRM0JZ" = "1" /* Replacement of Right Metatarsal-Phalangeal Joint with Synthetic Substitute, Open Approach */
"0SRM0KZ" = "1" /* Replacement of Right Metatarsal-Phalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SRN07Z" = "1" /* Replacement of Left Metatarsal-Phalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0SRN0JZ" = "1" /* Replacement of Left Metatarsal-Phalangeal Joint with Synthetic Substitute, Open Approach */
"0SRN0KZ" = "1" /* Replacement of Left Metatarsal-Phalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SRP07Z" = "1" /* Replacement of Right Toe Phalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0SRP0JZ" = "1" /* Replacement of Right Toe Phalangeal Joint with Synthetic Substitute, Open Approach */
"0SRP0KZ" = "1" /* Replacement of Right Toe Phalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SRQ07Z" = "1" /* Replacement of Left Toe Phalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0SRQ0JZ" = "1" /* Replacement of Left Toe Phalangeal Joint with Synthetic Substitute, Open Approach */
"0SRQ0KZ" = "1" /* Replacement of Left Toe Phalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SRR019" = "1" /* Replacement of Right Hip Joint, Femoral Surface with Metal Synthetic Substitute, Cemented, Open Approach */
"0SRR01A" = "1" /* Replacement of Right Hip Joint, Femoral Surface with Metal Synthetic Substitute, Uncemented, Open Approach */
"0SRR01Z" = "1" /* Replacement of Right Hip Joint, Femoral Surface with Metal Synthetic Substitute, Open Approach */
"0SRR039" = "1" /* Replacement of Right Hip Joint, Femoral Surface with Ceramic Synthetic Substitute, Cemented, Open Approach */
"0SRR03A" = "1" /* Replacement of Right Hip Joint, Femoral Surface with Ceramic Synthetic Substitute, Uncemented, Open Approach */
"0SRR03Z" = "1" /* Replacement of Right Hip Joint, Femoral Surface with Ceramic Synthetic Substitute, Open Approach */
"0SRR07Z" = "1" /* Replacement of Right Hip Joint, Femoral Surface with Autologous Tissue Substitute, Open Approach */
"0SRR0J9" = "1" /* Replacement of Right Hip Joint, Femoral Surface with Synthetic Substitute, Cemented, Open Approach */
"0SRR0JA" = "1" /* Replacement of Right Hip Joint, Femoral Surface with Synthetic Substitute, Uncemented, Open Approach */
"0SRR0JZ" = "1" /* Replacement of Right Hip Joint, Femoral Surface with Synthetic Substitute, Open Approach */
"0SRR0KZ" = "1" /* Replacement of Right Hip Joint, Femoral Surface with Nonautologous Tissue Substitute, Open Approach */
"0SRS019" = "1" /* Replacement of Left Hip Joint, Femoral Surface with Metal Synthetic Substitute, Cemented, Open Approach */
"0SRS01A" = "1" /* Replacement of Left Hip Joint, Femoral Surface with Metal Synthetic Substitute, Uncemented, Open Approach */
"0SRS01Z" = "1" /* Replacement of Left Hip Joint, Femoral Surface with Metal Synthetic Substitute, Open Approach */
"0SRS039" = "1" /* Replacement of Left Hip Joint, Femoral Surface with Ceramic Synthetic Substitute, Cemented, Open Approach */
"0SRS03A" = "1" /* Replacement of Left Hip Joint, Femoral Surface with Ceramic Synthetic Substitute, Uncemented, Open Approach */
"0SRS03Z" = "1" /* Replacement of Left Hip Joint, Femoral Surface with Ceramic Synthetic Substitute, Open Approach */
"0SRS07Z" = "1" /* Replacement of Left Hip Joint, Femoral Surface with Autologous Tissue Substitute, Open Approach */
"0SRS0J9" = "1" /* Replacement of Left Hip Joint, Femoral Surface with Synthetic Substitute, Cemented, Open Approach */
"0SRS0JA" = "1" /* Replacement of Left Hip Joint, Femoral Surface with Synthetic Substitute, Uncemented, Open Approach */
"0SRS0JZ" = "1" /* Replacement of Left Hip Joint, Femoral Surface with Synthetic Substitute, Open Approach */
"0SRS0KZ" = "1" /* Replacement of Left Hip Joint, Femoral Surface with Nonautologous Tissue Substitute, Open Approach */
"0SRT07Z" = "1" /* Replacement of Right Knee Joint, Femoral Surface with Autologous Tissue Substitute, Open Approach */
"0SRT0J9" = "1" /* Replacement of Right Knee Joint, Femoral Surface with Synthetic Substitute, Cemented, Open Approach */
"0SRT0JA" = "1" /* Replacement of Right Knee Joint, Femoral Surface with Synthetic Substitute, Uncemented, Open Approach */
"0SRT0JZ" = "1" /* Replacement of Right Knee Joint, Femoral Surface with Synthetic Substitute, Open Approach */
"0SRT0KZ" = "1" /* Replacement of Right Knee Joint, Femoral Surface with Nonautologous Tissue Substitute, Open Approach */
"0SRU07Z" = "1" /* Replacement of Left Knee Joint, Femoral Surface with Autologous Tissue Substitute, Open Approach */
"0SRU0J9" = "1" /* Replacement of Left Knee Joint, Femoral Surface with Synthetic Substitute, Cemented, Open Approach */
"0SRU0JA" = "1" /* Replacement of Left Knee Joint, Femoral Surface with Synthetic Substitute, Uncemented, Open Approach */
"0SRU0JZ" = "1" /* Replacement of Left Knee Joint, Femoral Surface with Synthetic Substitute, Open Approach */
"0SRU0KZ" = "1" /* Replacement of Left Knee Joint, Femoral Surface with Nonautologous Tissue Substitute, Open Approach */
"0SRV07Z" = "1" /* Replacement of Right Knee Joint, Tibial Surface with Autologous Tissue Substitute, Open Approach */
"0SRV0J9" = "1" /* Replacement of Right Knee Joint, Tibial Surface with Synthetic Substitute, Cemented, Open Approach */
"0SRV0JA" = "1" /* Replacement of Right Knee Joint, Tibial Surface with Synthetic Substitute, Uncemented, Open Approach */
"0SRV0JZ" = "1" /* Replacement of Right Knee Joint, Tibial Surface with Synthetic Substitute, Open Approach */
"0SRV0KZ" = "1" /* Replacement of Right Knee Joint, Tibial Surface with Nonautologous Tissue Substitute, Open Approach */
"0SRW07Z" = "1" /* Replacement of Left Knee Joint, Tibial Surface with Autologous Tissue Substitute, Open Approach */
"0SRW0J9" = "1" /* Replacement of Left Knee Joint, Tibial Surface with Synthetic Substitute, Cemented, Open Approach */
"0SRW0JA" = "1" /* Replacement of Left Knee Joint, Tibial Surface with Synthetic Substitute, Uncemented, Open Approach */
"0SRW0JZ" = "1" /* Replacement of Left Knee Joint, Tibial Surface with Synthetic Substitute, Open Approach */
"0SRW0KZ" = "1" /* Replacement of Left Knee Joint, Tibial Surface with Nonautologous Tissue Substitute, Open Approach */
"0SS004Z" = "1" /* Reposition Lumbar Vertebral Joint with Internal Fixation Device, Open Approach */
"0SS00ZZ" = "1" /* Reposition Lumbar Vertebral Joint, Open Approach */
"0SS304Z" = "1" /* Reposition Lumbosacral Joint with Internal Fixation Device, Open Approach */
"0SS30ZZ" = "1" /* Reposition Lumbosacral Joint, Open Approach */
"0SS504Z" = "1" /* Reposition Sacrococcygeal Joint with Internal Fixation Device, Open Approach */
"0SS50ZZ" = "1" /* Reposition Sacrococcygeal Joint, Open Approach */
"0SS604Z" = "1" /* Reposition Coccygeal Joint with Internal Fixation Device, Open Approach */
"0SS60ZZ" = "1" /* Reposition Coccygeal Joint, Open Approach */
"0SS704Z" = "1" /* Reposition Right Sacroiliac Joint with Internal Fixation Device, Open Approach */
"0SS70ZZ" = "1" /* Reposition Right Sacroiliac Joint, Open Approach */
"0SS804Z" = "1" /* Reposition Left Sacroiliac Joint with Internal Fixation Device, Open Approach */
"0SS80ZZ" = "1" /* Reposition Left Sacroiliac Joint, Open Approach */
"0SS904Z" = "1" /* Reposition Right Hip Joint with Internal Fixation Device, Open Approach */
"0SS905Z" = "1" /* Reposition Right Hip Joint with External Fixation Device, Open Approach */
"0SS90ZZ" = "1" /* Reposition Right Hip Joint, Open Approach */
"0SSB04Z" = "1" /* Reposition Left Hip Joint with Internal Fixation Device, Open Approach */
"0SSB05Z" = "1" /* Reposition Left Hip Joint with External Fixation Device, Open Approach */
"0SSB0ZZ" = "1" /* Reposition Left Hip Joint, Open Approach */
"0SSC04Z" = "1" /* Reposition Right Knee Joint with Internal Fixation Device, Open Approach */
"0SSC05Z" = "1" /* Reposition Right Knee Joint with External Fixation Device, Open Approach */
"0SSC0ZZ" = "1" /* Reposition Right Knee Joint, Open Approach */
"0SSD04Z" = "1" /* Reposition Left Knee Joint with Internal Fixation Device, Open Approach */
"0SSD05Z" = "1" /* Reposition Left Knee Joint with External Fixation Device, Open Approach */
"0SSD0ZZ" = "1" /* Reposition Left Knee Joint, Open Approach */
"0SSF04Z" = "1" /* Reposition Right Ankle Joint with Internal Fixation Device, Open Approach */
"0SSF05Z" = "1" /* Reposition Right Ankle Joint with External Fixation Device, Open Approach */
"0SSF0ZZ" = "1" /* Reposition Right Ankle Joint, Open Approach */
"0SSG04Z" = "1" /* Reposition Left Ankle Joint with Internal Fixation Device, Open Approach */
"0SSG05Z" = "1" /* Reposition Left Ankle Joint with External Fixation Device, Open Approach */
"0SSG0ZZ" = "1" /* Reposition Left Ankle Joint, Open Approach */
"0SSH04Z" = "1" /* Reposition Right Tarsal Joint with Internal Fixation Device, Open Approach */
"0SSH05Z" = "1" /* Reposition Right Tarsal Joint with External Fixation Device, Open Approach */
"0SSH0ZZ" = "1" /* Reposition Right Tarsal Joint, Open Approach */
"0SSJ04Z" = "1" /* Reposition Left Tarsal Joint with Internal Fixation Device, Open Approach */
"0SSJ05Z" = "1" /* Reposition Left Tarsal Joint with External Fixation Device, Open Approach */
"0SSJ0ZZ" = "1" /* Reposition Left Tarsal Joint, Open Approach */
"0SSK04Z" = "1" /* Reposition Right Metatarsal-Tarsal Joint with Internal Fixation Device, Open Approach */
"0SSK05Z" = "1" /* Reposition Right Metatarsal-Tarsal Joint with External Fixation Device, Open Approach */
"0SSK0ZZ" = "1" /* Reposition Right Metatarsal-Tarsal Joint, Open Approach */
"0SSL04Z" = "1" /* Reposition Left Metatarsal-Tarsal Joint with Internal Fixation Device, Open Approach */
"0SSL05Z" = "1" /* Reposition Left Metatarsal-Tarsal Joint with External Fixation Device, Open Approach */
"0SSL0ZZ" = "1" /* Reposition Left Metatarsal-Tarsal Joint, Open Approach */
"0SSM04Z" = "1" /* Reposition Right Metatarsal-Phalangeal Joint with Internal Fixation Device, Open Approach */
"0SSM05Z" = "1" /* Reposition Right Metatarsal-Phalangeal Joint with External Fixation Device, Open Approach */
"0SSM0ZZ" = "1" /* Reposition Right Metatarsal-Phalangeal Joint, Open Approach */
"0SSN04Z" = "1" /* Reposition Left Metatarsal-Phalangeal Joint with Internal Fixation Device, Open Approach */
"0SSN05Z" = "1" /* Reposition Left Metatarsal-Phalangeal Joint with External Fixation Device, Open Approach */
"0SSN0ZZ" = "1" /* Reposition Left Metatarsal-Phalangeal Joint, Open Approach */
"0SSP04Z" = "1" /* Reposition Right Toe Phalangeal Joint with Internal Fixation Device, Open Approach */
"0SSP05Z" = "1" /* Reposition Right Toe Phalangeal Joint with External Fixation Device, Open Approach */
"0SSP0ZZ" = "1" /* Reposition Right Toe Phalangeal Joint, Open Approach */
"0SSQ04Z" = "1" /* Reposition Left Toe Phalangeal Joint with Internal Fixation Device, Open Approach */
"0SSQ05Z" = "1" /* Reposition Left Toe Phalangeal Joint with External Fixation Device, Open Approach */
"0SSQ0ZZ" = "1" /* Reposition Left Toe Phalangeal Joint, Open Approach */
"0ST20ZZ" = "1" /* Resection of Lumbar Vertebral Disc, Open Approach */
"0ST40ZZ" = "1" /* Resection of Lumbosacral Disc, Open Approach */
"0ST50ZZ" = "1" /* Resection of Sacrococcygeal Joint, Open Approach */
"0ST60ZZ" = "1" /* Resection of Coccygeal Joint, Open Approach */
"0ST70ZZ" = "1" /* Resection of Right Sacroiliac Joint, Open Approach */
"0ST80ZZ" = "1" /* Resection of Left Sacroiliac Joint, Open Approach */
"0ST90ZZ" = "1" /* Resection of Right Hip Joint, Open Approach */
"0STB0ZZ" = "1" /* Resection of Left Hip Joint, Open Approach */
"0STC0ZZ" = "1" /* Resection of Right Knee Joint, Open Approach */
"0STD0ZZ" = "1" /* Resection of Left Knee Joint, Open Approach */
"0STF0ZZ" = "1" /* Resection of Right Ankle Joint, Open Approach */
"0STG0ZZ" = "1" /* Resection of Left Ankle Joint, Open Approach */
"0STH0ZZ" = "1" /* Resection of Right Tarsal Joint, Open Approach */
"0STJ0ZZ" = "1" /* Resection of Left Tarsal Joint, Open Approach */
"0STK0ZZ" = "1" /* Resection of Right Metatarsal-Tarsal Joint, Open Approach */
"0STL0ZZ" = "1" /* Resection of Left Metatarsal-Tarsal Joint, Open Approach */
"0STM0ZZ" = "1" /* Resection of Right Metatarsal-Phalangeal Joint, Open Approach */
"0STN0ZZ" = "1" /* Resection of Left Metatarsal-Phalangeal Joint, Open Approach */
"0STP0ZZ" = "1" /* Resection of Right Toe Phalangeal Joint, Open Approach */
"0STQ0ZZ" = "1" /* Resection of Left Toe Phalangeal Joint, Open Approach */
"0SU007Z" = "1" /* Supplement Lumbar Vertebral Joint with Autologous Tissue Substitute, Open Approach */
"0SU00JZ" = "1" /* Supplement Lumbar Vertebral Joint with Synthetic Substitute, Open Approach */
"0SU00KZ" = "1" /* Supplement Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Open Approach */
"0SU037Z" = "1" /* Supplement Lumbar Vertebral Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SU03JZ" = "1" /* Supplement Lumbar Vertebral Joint with Synthetic Substitute, Percutaneous Approach */
"0SU03KZ" = "1" /* Supplement Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SU047Z" = "1" /* Supplement Lumbar Vertebral Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SU04JZ" = "1" /* Supplement Lumbar Vertebral Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SU04KZ" = "1" /* Supplement Lumbar Vertebral Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SU207Z" = "1" /* Supplement Lumbar Vertebral Disc with Autologous Tissue Substitute, Open Approach */
"0SU20JZ" = "1" /* Supplement Lumbar Vertebral Disc with Synthetic Substitute, Open Approach */
"0SU20KZ" = "1" /* Supplement Lumbar Vertebral Disc with Nonautologous Tissue Substitute, Open Approach */
"0SU237Z" = "1" /* Supplement Lumbar Vertebral Disc with Autologous Tissue Substitute, Percutaneous Approach */
"0SU23JZ" = "1" /* Supplement Lumbar Vertebral Disc with Synthetic Substitute, Percutaneous Approach */
"0SU23KZ" = "1" /* Supplement Lumbar Vertebral Disc with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SU247Z" = "1" /* Supplement Lumbar Vertebral Disc with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SU24JZ" = "1" /* Supplement Lumbar Vertebral Disc with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SU24KZ" = "1" /* Supplement Lumbar Vertebral Disc with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SU307Z" = "1" /* Supplement Lumbosacral Joint with Autologous Tissue Substitute, Open Approach */
"0SU30JZ" = "1" /* Supplement Lumbosacral Joint with Synthetic Substitute, Open Approach */
"0SU30KZ" = "1" /* Supplement Lumbosacral Joint with Nonautologous Tissue Substitute, Open Approach */
"0SU337Z" = "1" /* Supplement Lumbosacral Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SU33JZ" = "1" /* Supplement Lumbosacral Joint with Synthetic Substitute, Percutaneous Approach */
"0SU33KZ" = "1" /* Supplement Lumbosacral Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SU347Z" = "1" /* Supplement Lumbosacral Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SU34JZ" = "1" /* Supplement Lumbosacral Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SU34KZ" = "1" /* Supplement Lumbosacral Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SU407Z" = "1" /* Supplement Lumbosacral Disc with Autologous Tissue Substitute, Open Approach */
"0SU40JZ" = "1" /* Supplement Lumbosacral Disc with Synthetic Substitute, Open Approach */
"0SU40KZ" = "1" /* Supplement Lumbosacral Disc with Nonautologous Tissue Substitute, Open Approach */
"0SU437Z" = "1" /* Supplement Lumbosacral Disc with Autologous Tissue Substitute, Percutaneous Approach */
"0SU43JZ" = "1" /* Supplement Lumbosacral Disc with Synthetic Substitute, Percutaneous Approach */
"0SU43KZ" = "1" /* Supplement Lumbosacral Disc with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SU447Z" = "1" /* Supplement Lumbosacral Disc with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SU44JZ" = "1" /* Supplement Lumbosacral Disc with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SU44KZ" = "1" /* Supplement Lumbosacral Disc with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SU507Z" = "1" /* Supplement Sacrococcygeal Joint with Autologous Tissue Substitute, Open Approach */
"0SU50JZ" = "1" /* Supplement Sacrococcygeal Joint with Synthetic Substitute, Open Approach */
"0SU50KZ" = "1" /* Supplement Sacrococcygeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SU537Z" = "1" /* Supplement Sacrococcygeal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SU53JZ" = "1" /* Supplement Sacrococcygeal Joint with Synthetic Substitute, Percutaneous Approach */
"0SU53KZ" = "1" /* Supplement Sacrococcygeal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SU547Z" = "1" /* Supplement Sacrococcygeal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SU54JZ" = "1" /* Supplement Sacrococcygeal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SU54KZ" = "1" /* Supplement Sacrococcygeal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SU607Z" = "1" /* Supplement Coccygeal Joint with Autologous Tissue Substitute, Open Approach */
"0SU60JZ" = "1" /* Supplement Coccygeal Joint with Synthetic Substitute, Open Approach */
"0SU60KZ" = "1" /* Supplement Coccygeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SU637Z" = "1" /* Supplement Coccygeal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SU63JZ" = "1" /* Supplement Coccygeal Joint with Synthetic Substitute, Percutaneous Approach */
"0SU63KZ" = "1" /* Supplement Coccygeal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SU647Z" = "1" /* Supplement Coccygeal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SU64JZ" = "1" /* Supplement Coccygeal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SU64KZ" = "1" /* Supplement Coccygeal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SU707Z" = "1" /* Supplement Right Sacroiliac Joint with Autologous Tissue Substitute, Open Approach */
"0SU70JZ" = "1" /* Supplement Right Sacroiliac Joint with Synthetic Substitute, Open Approach */
"0SU70KZ" = "1" /* Supplement Right Sacroiliac Joint with Nonautologous Tissue Substitute, Open Approach */
"0SU737Z" = "1" /* Supplement Right Sacroiliac Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SU73JZ" = "1" /* Supplement Right Sacroiliac Joint with Synthetic Substitute, Percutaneous Approach */
"0SU73KZ" = "1" /* Supplement Right Sacroiliac Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SU747Z" = "1" /* Supplement Right Sacroiliac Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SU74JZ" = "1" /* Supplement Right Sacroiliac Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SU74KZ" = "1" /* Supplement Right Sacroiliac Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SU807Z" = "1" /* Supplement Left Sacroiliac Joint with Autologous Tissue Substitute, Open Approach */
"0SU80JZ" = "1" /* Supplement Left Sacroiliac Joint with Synthetic Substitute, Open Approach */
"0SU80KZ" = "1" /* Supplement Left Sacroiliac Joint with Nonautologous Tissue Substitute, Open Approach */
"0SU837Z" = "1" /* Supplement Left Sacroiliac Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SU83JZ" = "1" /* Supplement Left Sacroiliac Joint with Synthetic Substitute, Percutaneous Approach */
"0SU83KZ" = "1" /* Supplement Left Sacroiliac Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SU847Z" = "1" /* Supplement Left Sacroiliac Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SU84JZ" = "1" /* Supplement Left Sacroiliac Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SU84KZ" = "1" /* Supplement Left Sacroiliac Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SU907Z" = "1" /* Supplement Right Hip Joint with Autologous Tissue Substitute, Open Approach */
"0SU909Z" = "1" /* Supplement Right Hip Joint with Liner, Open Approach */
"0SU90BZ" = "1" /* Supplement Right Hip Joint with Resurfacing Device, Open Approach */
"0SU90JZ" = "1" /* Supplement Right Hip Joint with Synthetic Substitute, Open Approach */
"0SU90KZ" = "1" /* Supplement Right Hip Joint with Nonautologous Tissue Substitute, Open Approach */
"0SU937Z" = "1" /* Supplement Right Hip Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SU93JZ" = "1" /* Supplement Right Hip Joint with Synthetic Substitute, Percutaneous Approach */
"0SU93KZ" = "1" /* Supplement Right Hip Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SU947Z" = "1" /* Supplement Right Hip Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SU94JZ" = "1" /* Supplement Right Hip Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SU94KZ" = "1" /* Supplement Right Hip Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUA09Z" = "1" /* Supplement Right Hip Joint, Acetabular Surface with Liner, Open Approach */
"0SUA0BZ" = "1" /* Supplement Right Hip Joint, Acetabular Surface with Resurfacing Device, Open Approach */
"0SUB07Z" = "1" /* Supplement Left Hip Joint with Autologous Tissue Substitute, Open Approach */
"0SUB09Z" = "1" /* Supplement Left Hip Joint with Liner, Open Approach */
"0SUB0BZ" = "1" /* Supplement Left Hip Joint with Resurfacing Device, Open Approach */
"0SUB0JZ" = "1" /* Supplement Left Hip Joint with Synthetic Substitute, Open Approach */
"0SUB0KZ" = "1" /* Supplement Left Hip Joint with Nonautologous Tissue Substitute, Open Approach */
"0SUB37Z" = "1" /* Supplement Left Hip Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SUB3JZ" = "1" /* Supplement Left Hip Joint with Synthetic Substitute, Percutaneous Approach */
"0SUB3KZ" = "1" /* Supplement Left Hip Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SUB47Z" = "1" /* Supplement Left Hip Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUB4JZ" = "1" /* Supplement Left Hip Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SUB4KZ" = "1" /* Supplement Left Hip Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUC07Z" = "1" /* Supplement Right Knee Joint with Autologous Tissue Substitute, Open Approach */
"0SUC09C" = "1" /* Supplement Right Knee Joint with Liner, Patellar Surface, Open Approach */
"0SUC09Z" = "1" /* Supplement Right Knee Joint with Liner, Open Approach */
"0SUC0JZ" = "1" /* Supplement Right Knee Joint with Synthetic Substitute, Open Approach */
"0SUC0KZ" = "1" /* Supplement Right Knee Joint with Nonautologous Tissue Substitute, Open Approach */
"0SUC37Z" = "1" /* Supplement Right Knee Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SUC3JZ" = "1" /* Supplement Right Knee Joint with Synthetic Substitute, Percutaneous Approach */
"0SUC3KZ" = "1" /* Supplement Right Knee Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SUC47Z" = "1" /* Supplement Right Knee Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUC4JZ" = "1" /* Supplement Right Knee Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SUC4KZ" = "1" /* Supplement Right Knee Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUD07Z" = "1" /* Supplement Left Knee Joint with Autologous Tissue Substitute, Open Approach */
"0SUD09C" = "1" /* Supplement Left Knee Joint with Liner, Patellar Surface, Open Approach */
"0SUD09Z" = "1" /* Supplement Left Knee Joint with Liner, Open Approach */
"0SUD0JZ" = "1" /* Supplement Left Knee Joint with Synthetic Substitute, Open Approach */
"0SUD0KZ" = "1" /* Supplement Left Knee Joint with Nonautologous Tissue Substitute, Open Approach */
"0SUD37Z" = "1" /* Supplement Left Knee Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SUD3JZ" = "1" /* Supplement Left Knee Joint with Synthetic Substitute, Percutaneous Approach */
"0SUD3KZ" = "1" /* Supplement Left Knee Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SUD47Z" = "1" /* Supplement Left Knee Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUD4JZ" = "1" /* Supplement Left Knee Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SUD4KZ" = "1" /* Supplement Left Knee Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUE09Z" = "1" /* Supplement Left Hip Joint, Acetabular Surface with Liner, Open Approach */
"0SUE0BZ" = "1" /* Supplement Left Hip Joint, Acetabular Surface with Resurfacing Device, Open Approach */
"0SUF07Z" = "1" /* Supplement Right Ankle Joint with Autologous Tissue Substitute, Open Approach */
"0SUF0JZ" = "1" /* Supplement Right Ankle Joint with Synthetic Substitute, Open Approach */
"0SUF0KZ" = "1" /* Supplement Right Ankle Joint with Nonautologous Tissue Substitute, Open Approach */
"0SUF37Z" = "1" /* Supplement Right Ankle Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SUF3JZ" = "1" /* Supplement Right Ankle Joint with Synthetic Substitute, Percutaneous Approach */
"0SUF3KZ" = "1" /* Supplement Right Ankle Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SUF47Z" = "1" /* Supplement Right Ankle Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUF4JZ" = "1" /* Supplement Right Ankle Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SUF4KZ" = "1" /* Supplement Right Ankle Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUG07Z" = "1" /* Supplement Left Ankle Joint with Autologous Tissue Substitute, Open Approach */
"0SUG0JZ" = "1" /* Supplement Left Ankle Joint with Synthetic Substitute, Open Approach */
"0SUG0KZ" = "1" /* Supplement Left Ankle Joint with Nonautologous Tissue Substitute, Open Approach */
"0SUG37Z" = "1" /* Supplement Left Ankle Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SUG3JZ" = "1" /* Supplement Left Ankle Joint with Synthetic Substitute, Percutaneous Approach */
"0SUG3KZ" = "1" /* Supplement Left Ankle Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SUG47Z" = "1" /* Supplement Left Ankle Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUG4JZ" = "1" /* Supplement Left Ankle Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SUG4KZ" = "1" /* Supplement Left Ankle Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUH07Z" = "1" /* Supplement Right Tarsal Joint with Autologous Tissue Substitute, Open Approach */
"0SUH0JZ" = "1" /* Supplement Right Tarsal Joint with Synthetic Substitute, Open Approach */
"0SUH0KZ" = "1" /* Supplement Right Tarsal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SUH37Z" = "1" /* Supplement Right Tarsal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SUH3JZ" = "1" /* Supplement Right Tarsal Joint with Synthetic Substitute, Percutaneous Approach */
"0SUH3KZ" = "1" /* Supplement Right Tarsal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SUH47Z" = "1" /* Supplement Right Tarsal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUH4JZ" = "1" /* Supplement Right Tarsal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SUH4KZ" = "1" /* Supplement Right Tarsal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUJ07Z" = "1" /* Supplement Left Tarsal Joint with Autologous Tissue Substitute, Open Approach */
"0SUJ0JZ" = "1" /* Supplement Left Tarsal Joint with Synthetic Substitute, Open Approach */
"0SUJ0KZ" = "1" /* Supplement Left Tarsal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SUJ37Z" = "1" /* Supplement Left Tarsal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SUJ3JZ" = "1" /* Supplement Left Tarsal Joint with Synthetic Substitute, Percutaneous Approach */
"0SUJ3KZ" = "1" /* Supplement Left Tarsal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SUJ47Z" = "1" /* Supplement Left Tarsal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUJ4JZ" = "1" /* Supplement Left Tarsal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SUJ4KZ" = "1" /* Supplement Left Tarsal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUK07Z" = "1" /* Supplement Right Metatarsal-Tarsal Joint with Autologous Tissue Substitute, Open Approach */
"0SUK0JZ" = "1" /* Supplement Right Metatarsal-Tarsal Joint with Synthetic Substitute, Open Approach */
"0SUK0KZ" = "1" /* Supplement Right Metatarsal-Tarsal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SUK37Z" = "1" /* Supplement Right Metatarsal-Tarsal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SUK3JZ" = "1" /* Supplement Right Metatarsal-Tarsal Joint with Synthetic Substitute, Percutaneous Approach */
"0SUK3KZ" = "1" /* Supplement Right Metatarsal-Tarsal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SUK47Z" = "1" /* Supplement Right Metatarsal-Tarsal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUK4JZ" = "1" /* Supplement Right Metatarsal-Tarsal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SUK4KZ" = "1" /* Supplement Right Metatarsal-Tarsal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUL07Z" = "1" /* Supplement Left Metatarsal-Tarsal Joint with Autologous Tissue Substitute, Open Approach */
"0SUL0JZ" = "1" /* Supplement Left Metatarsal-Tarsal Joint with Synthetic Substitute, Open Approach */
"0SUL0KZ" = "1" /* Supplement Left Metatarsal-Tarsal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SUL37Z" = "1" /* Supplement Left Metatarsal-Tarsal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SUL3JZ" = "1" /* Supplement Left Metatarsal-Tarsal Joint with Synthetic Substitute, Percutaneous Approach */
"0SUL3KZ" = "1" /* Supplement Left Metatarsal-Tarsal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SUL47Z" = "1" /* Supplement Left Metatarsal-Tarsal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUL4JZ" = "1" /* Supplement Left Metatarsal-Tarsal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SUL4KZ" = "1" /* Supplement Left Metatarsal-Tarsal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUM07Z" = "1" /* Supplement Right Metatarsal-Phalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0SUM0JZ" = "1" /* Supplement Right Metatarsal-Phalangeal Joint with Synthetic Substitute, Open Approach */
"0SUM0KZ" = "1" /* Supplement Right Metatarsal-Phalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SUM37Z" = "1" /* Supplement Right Metatarsal-Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SUM3JZ" = "1" /* Supplement Right Metatarsal-Phalangeal Joint with Synthetic Substitute, Percutaneous Approach */
"0SUM3KZ" = "1" /* Supplement Right Metatarsal-Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SUM47Z" = "1" /* Supplement Right Metatarsal-Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUM4JZ" = "1" /* Supplement Right Metatarsal-Phalangeal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SUM4KZ" = "1" /* Supplement Right Metatarsal-Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUN07Z" = "1" /* Supplement Left Metatarsal-Phalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0SUN0JZ" = "1" /* Supplement Left Metatarsal-Phalangeal Joint with Synthetic Substitute, Open Approach */
"0SUN0KZ" = "1" /* Supplement Left Metatarsal-Phalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SUN37Z" = "1" /* Supplement Left Metatarsal-Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SUN3JZ" = "1" /* Supplement Left Metatarsal-Phalangeal Joint with Synthetic Substitute, Percutaneous Approach */
"0SUN3KZ" = "1" /* Supplement Left Metatarsal-Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SUN47Z" = "1" /* Supplement Left Metatarsal-Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUN4JZ" = "1" /* Supplement Left Metatarsal-Phalangeal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SUN4KZ" = "1" /* Supplement Left Metatarsal-Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUP07Z" = "1" /* Supplement Right Toe Phalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0SUP0JZ" = "1" /* Supplement Right Toe Phalangeal Joint with Synthetic Substitute, Open Approach */
"0SUP0KZ" = "1" /* Supplement Right Toe Phalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SUP37Z" = "1" /* Supplement Right Toe Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SUP3JZ" = "1" /* Supplement Right Toe Phalangeal Joint with Synthetic Substitute, Percutaneous Approach */
"0SUP3KZ" = "1" /* Supplement Right Toe Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SUP47Z" = "1" /* Supplement Right Toe Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUP4JZ" = "1" /* Supplement Right Toe Phalangeal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SUP4KZ" = "1" /* Supplement Right Toe Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUQ07Z" = "1" /* Supplement Left Toe Phalangeal Joint with Autologous Tissue Substitute, Open Approach */
"0SUQ0JZ" = "1" /* Supplement Left Toe Phalangeal Joint with Synthetic Substitute, Open Approach */
"0SUQ0KZ" = "1" /* Supplement Left Toe Phalangeal Joint with Nonautologous Tissue Substitute, Open Approach */
"0SUQ37Z" = "1" /* Supplement Left Toe Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Approach */
"0SUQ3JZ" = "1" /* Supplement Left Toe Phalangeal Joint with Synthetic Substitute, Percutaneous Approach */
"0SUQ3KZ" = "1" /* Supplement Left Toe Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Approach */
"0SUQ47Z" = "1" /* Supplement Left Toe Phalangeal Joint with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUQ4JZ" = "1" /* Supplement Left Toe Phalangeal Joint with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0SUQ4KZ" = "1" /* Supplement Left Toe Phalangeal Joint with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0SUR09Z" = "1" /* Supplement Right Hip Joint, Femoral Surface with Liner, Open Approach */
"0SUR0BZ" = "1" /* Supplement Right Hip Joint, Femoral Surface with Resurfacing Device, Open Approach */
"0SUS09Z" = "1" /* Supplement Left Hip Joint, Femoral Surface with Liner, Open Approach */
"0SUS0BZ" = "1" /* Supplement Left Hip Joint, Femoral Surface with Resurfacing Device, Open Approach */
"0SUT09Z" = "1" /* Supplement Right Knee Joint, Femoral Surface with Liner, Open Approach */
"0SUU09Z" = "1" /* Supplement Left Knee Joint, Femoral Surface with Liner, Open Approach */
"0SUV09Z" = "1" /* Supplement Right Knee Joint, Tibial Surface with Liner, Open Approach */
"0SUW09Z" = "1" /* Supplement Left Knee Joint, Tibial Surface with Liner, Open Approach */
"0SW000Z" = "1" /* Revision of Drainage Device in Lumbar Vertebral Joint, Open Approach */
"0SW003Z" = "1" /* Revision of Infusion Device in Lumbar Vertebral Joint, Open Approach */
"0SW004Z" = "1" /* Revision of Internal Fixation Device in Lumbar Vertebral Joint, Open Approach */
"0SW007Z" = "1" /* Revision of Autologous Tissue Substitute in Lumbar Vertebral Joint, Open Approach */
"0SW008Z" = "1" /* Revision of Spacer in Lumbar Vertebral Joint, Open Approach */
"0SW00AZ" = "1" /* Revision of Interbody Fusion Device in Lumbar Vertebral Joint, Open Approach */
"0SW00JZ" = "1" /* Revision of Synthetic Substitute in Lumbar Vertebral Joint, Open Approach */
"0SW00KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lumbar Vertebral Joint, Open Approach */
"0SW030Z" = "1" /* Revision of Drainage Device in Lumbar Vertebral Joint, Percutaneous Approach */
"0SW033Z" = "1" /* Revision of Infusion Device in Lumbar Vertebral Joint, Percutaneous Approach */
"0SW034Z" = "1" /* Revision of Internal Fixation Device in Lumbar Vertebral Joint, Percutaneous Approach */
"0SW037Z" = "1" /* Revision of Autologous Tissue Substitute in Lumbar Vertebral Joint, Percutaneous Approach */
"0SW038Z" = "1" /* Revision of Spacer in Lumbar Vertebral Joint, Percutaneous Approach */
"0SW03AZ" = "1" /* Revision of Interbody Fusion Device in Lumbar Vertebral Joint, Percutaneous Approach */
"0SW03JZ" = "1" /* Revision of Synthetic Substitute in Lumbar Vertebral Joint, Percutaneous Approach */
"0SW03KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lumbar Vertebral Joint, Percutaneous Approach */
"0SW040Z" = "1" /* Revision of Drainage Device in Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SW043Z" = "1" /* Revision of Infusion Device in Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SW044Z" = "1" /* Revision of Internal Fixation Device in Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SW047Z" = "1" /* Revision of Autologous Tissue Substitute in Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SW048Z" = "1" /* Revision of Spacer in Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SW04AZ" = "1" /* Revision of Interbody Fusion Device in Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SW04JZ" = "1" /* Revision of Synthetic Substitute in Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SW04KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lumbar Vertebral Joint, Percutaneous Endoscopic Approach */
"0SW200Z" = "1" /* Revision of Drainage Device in Lumbar Vertebral Disc, Open Approach */
"0SW203Z" = "1" /* Revision of Infusion Device in Lumbar Vertebral Disc, Open Approach */
"0SW207Z" = "1" /* Revision of Autologous Tissue Substitute in Lumbar Vertebral Disc, Open Approach */
"0SW20JZ" = "1" /* Revision of Synthetic Substitute in Lumbar Vertebral Disc, Open Approach */
"0SW20KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lumbar Vertebral Disc, Open Approach */
"0SW230Z" = "1" /* Revision of Drainage Device in Lumbar Vertebral Disc, Percutaneous Approach */
"0SW233Z" = "1" /* Revision of Infusion Device in Lumbar Vertebral Disc, Percutaneous Approach */
"0SW237Z" = "1" /* Revision of Autologous Tissue Substitute in Lumbar Vertebral Disc, Percutaneous Approach */
"0SW23JZ" = "1" /* Revision of Synthetic Substitute in Lumbar Vertebral Disc, Percutaneous Approach */
"0SW23KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lumbar Vertebral Disc, Percutaneous Approach */
"0SW240Z" = "1" /* Revision of Drainage Device in Lumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0SW243Z" = "1" /* Revision of Infusion Device in Lumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0SW247Z" = "1" /* Revision of Autologous Tissue Substitute in Lumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0SW24JZ" = "1" /* Revision of Synthetic Substitute in Lumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0SW24KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lumbar Vertebral Disc, Percutaneous Endoscopic Approach */
"0SW300Z" = "1" /* Revision of Drainage Device in Lumbosacral Joint, Open Approach */
"0SW303Z" = "1" /* Revision of Infusion Device in Lumbosacral Joint, Open Approach */
"0SW304Z" = "1" /* Revision of Internal Fixation Device in Lumbosacral Joint, Open Approach */
"0SW307Z" = "1" /* Revision of Autologous Tissue Substitute in Lumbosacral Joint, Open Approach */
"0SW308Z" = "1" /* Revision of Spacer in Lumbosacral Joint, Open Approach */
"0SW30AZ" = "1" /* Revision of Interbody Fusion Device in Lumbosacral Joint, Open Approach */
"0SW30JZ" = "1" /* Revision of Synthetic Substitute in Lumbosacral Joint, Open Approach */
"0SW30KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lumbosacral Joint, Open Approach */
"0SW330Z" = "1" /* Revision of Drainage Device in Lumbosacral Joint, Percutaneous Approach */
"0SW333Z" = "1" /* Revision of Infusion Device in Lumbosacral Joint, Percutaneous Approach */
"0SW334Z" = "1" /* Revision of Internal Fixation Device in Lumbosacral Joint, Percutaneous Approach */
"0SW337Z" = "1" /* Revision of Autologous Tissue Substitute in Lumbosacral Joint, Percutaneous Approach */
"0SW338Z" = "1" /* Revision of Spacer in Lumbosacral Joint, Percutaneous Approach */
"0SW33AZ" = "1" /* Revision of Interbody Fusion Device in Lumbosacral Joint, Percutaneous Approach */
"0SW33JZ" = "1" /* Revision of Synthetic Substitute in Lumbosacral Joint, Percutaneous Approach */
"0SW33KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lumbosacral Joint, Percutaneous Approach */
"0SW340Z" = "1" /* Revision of Drainage Device in Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SW343Z" = "1" /* Revision of Infusion Device in Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SW344Z" = "1" /* Revision of Internal Fixation Device in Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SW347Z" = "1" /* Revision of Autologous Tissue Substitute in Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SW348Z" = "1" /* Revision of Spacer in Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SW34AZ" = "1" /* Revision of Interbody Fusion Device in Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SW34JZ" = "1" /* Revision of Synthetic Substitute in Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SW34KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lumbosacral Joint, Percutaneous Endoscopic Approach */
"0SW400Z" = "1" /* Revision of Drainage Device in Lumbosacral Disc, Open Approach */
"0SW403Z" = "1" /* Revision of Infusion Device in Lumbosacral Disc, Open Approach */
"0SW407Z" = "1" /* Revision of Autologous Tissue Substitute in Lumbosacral Disc, Open Approach */
"0SW40JZ" = "1" /* Revision of Synthetic Substitute in Lumbosacral Disc, Open Approach */
"0SW40KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lumbosacral Disc, Open Approach */
"0SW430Z" = "1" /* Revision of Drainage Device in Lumbosacral Disc, Percutaneous Approach */
"0SW433Z" = "1" /* Revision of Infusion Device in Lumbosacral Disc, Percutaneous Approach */
"0SW437Z" = "1" /* Revision of Autologous Tissue Substitute in Lumbosacral Disc, Percutaneous Approach */
"0SW43JZ" = "1" /* Revision of Synthetic Substitute in Lumbosacral Disc, Percutaneous Approach */
"0SW43KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lumbosacral Disc, Percutaneous Approach */
"0SW440Z" = "1" /* Revision of Drainage Device in Lumbosacral Disc, Percutaneous Endoscopic Approach */
"0SW443Z" = "1" /* Revision of Infusion Device in Lumbosacral Disc, Percutaneous Endoscopic Approach */
"0SW447Z" = "1" /* Revision of Autologous Tissue Substitute in Lumbosacral Disc, Percutaneous Endoscopic Approach */
"0SW44JZ" = "1" /* Revision of Synthetic Substitute in Lumbosacral Disc, Percutaneous Endoscopic Approach */
"0SW44KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Lumbosacral Disc, Percutaneous Endoscopic Approach */
"0SW500Z" = "1" /* Revision of Drainage Device in Sacrococcygeal Joint, Open Approach */
"0SW503Z" = "1" /* Revision of Infusion Device in Sacrococcygeal Joint, Open Approach */
"0SW504Z" = "1" /* Revision of Internal Fixation Device in Sacrococcygeal Joint, Open Approach */
"0SW507Z" = "1" /* Revision of Autologous Tissue Substitute in Sacrococcygeal Joint, Open Approach */
"0SW508Z" = "1" /* Revision of Spacer in Sacrococcygeal Joint, Open Approach */
"0SW50JZ" = "1" /* Revision of Synthetic Substitute in Sacrococcygeal Joint, Open Approach */
"0SW50KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Sacrococcygeal Joint, Open Approach */
"0SW530Z" = "1" /* Revision of Drainage Device in Sacrococcygeal Joint, Percutaneous Approach */
"0SW533Z" = "1" /* Revision of Infusion Device in Sacrococcygeal Joint, Percutaneous Approach */
"0SW534Z" = "1" /* Revision of Internal Fixation Device in Sacrococcygeal Joint, Percutaneous Approach */
"0SW537Z" = "1" /* Revision of Autologous Tissue Substitute in Sacrococcygeal Joint, Percutaneous Approach */
"0SW538Z" = "1" /* Revision of Spacer in Sacrococcygeal Joint, Percutaneous Approach */
"0SW53JZ" = "1" /* Revision of Synthetic Substitute in Sacrococcygeal Joint, Percutaneous Approach */
"0SW53KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Sacrococcygeal Joint, Percutaneous Approach */
"0SW540Z" = "1" /* Revision of Drainage Device in Sacrococcygeal Joint, Percutaneous Endoscopic Approach */
"0SW543Z" = "1" /* Revision of Infusion Device in Sacrococcygeal Joint, Percutaneous Endoscopic Approach */
"0SW544Z" = "1" /* Revision of Internal Fixation Device in Sacrococcygeal Joint, Percutaneous Endoscopic Approach */
"0SW547Z" = "1" /* Revision of Autologous Tissue Substitute in Sacrococcygeal Joint, Percutaneous Endoscopic Approach */
"0SW548Z" = "1" /* Revision of Spacer in Sacrococcygeal Joint, Percutaneous Endoscopic Approach */
"0SW54JZ" = "1" /* Revision of Synthetic Substitute in Sacrococcygeal Joint, Percutaneous Endoscopic Approach */
"0SW54KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Sacrococcygeal Joint, Percutaneous Endoscopic Approach */
"0SW600Z" = "1" /* Revision of Drainage Device in Coccygeal Joint, Open Approach */
"0SW603Z" = "1" /* Revision of Infusion Device in Coccygeal Joint, Open Approach */
"0SW604Z" = "1" /* Revision of Internal Fixation Device in Coccygeal Joint, Open Approach */
"0SW607Z" = "1" /* Revision of Autologous Tissue Substitute in Coccygeal Joint, Open Approach */
"0SW608Z" = "1" /* Revision of Spacer in Coccygeal Joint, Open Approach */
"0SW60JZ" = "1" /* Revision of Synthetic Substitute in Coccygeal Joint, Open Approach */
"0SW60KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Coccygeal Joint, Open Approach */
"0SW630Z" = "1" /* Revision of Drainage Device in Coccygeal Joint, Percutaneous Approach */
"0SW633Z" = "1" /* Revision of Infusion Device in Coccygeal Joint, Percutaneous Approach */
"0SW634Z" = "1" /* Revision of Internal Fixation Device in Coccygeal Joint, Percutaneous Approach */
"0SW637Z" = "1" /* Revision of Autologous Tissue Substitute in Coccygeal Joint, Percutaneous Approach */
"0SW638Z" = "1" /* Revision of Spacer in Coccygeal Joint, Percutaneous Approach */
"0SW63JZ" = "1" /* Revision of Synthetic Substitute in Coccygeal Joint, Percutaneous Approach */
"0SW63KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Coccygeal Joint, Percutaneous Approach */
"0SW640Z" = "1" /* Revision of Drainage Device in Coccygeal Joint, Percutaneous Endoscopic Approach */
"0SW643Z" = "1" /* Revision of Infusion Device in Coccygeal Joint, Percutaneous Endoscopic Approach */
"0SW644Z" = "1" /* Revision of Internal Fixation Device in Coccygeal Joint, Percutaneous Endoscopic Approach */
"0SW647Z" = "1" /* Revision of Autologous Tissue Substitute in Coccygeal Joint, Percutaneous Endoscopic Approach */
"0SW648Z" = "1" /* Revision of Spacer in Coccygeal Joint, Percutaneous Endoscopic Approach */
"0SW64JZ" = "1" /* Revision of Synthetic Substitute in Coccygeal Joint, Percutaneous Endoscopic Approach */
"0SW64KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Coccygeal Joint, Percutaneous Endoscopic Approach */
"0SW700Z" = "1" /* Revision of Drainage Device in Right Sacroiliac Joint, Open Approach */
"0SW703Z" = "1" /* Revision of Infusion Device in Right Sacroiliac Joint, Open Approach */
"0SW704Z" = "1" /* Revision of Internal Fixation Device in Right Sacroiliac Joint, Open Approach */
"0SW707Z" = "1" /* Revision of Autologous Tissue Substitute in Right Sacroiliac Joint, Open Approach */
"0SW708Z" = "1" /* Revision of Spacer in Right Sacroiliac Joint, Open Approach */
"0SW70JZ" = "1" /* Revision of Synthetic Substitute in Right Sacroiliac Joint, Open Approach */
"0SW70KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Sacroiliac Joint, Open Approach */
"0SW730Z" = "1" /* Revision of Drainage Device in Right Sacroiliac Joint, Percutaneous Approach */
"0SW733Z" = "1" /* Revision of Infusion Device in Right Sacroiliac Joint, Percutaneous Approach */
"0SW734Z" = "1" /* Revision of Internal Fixation Device in Right Sacroiliac Joint, Percutaneous Approach */
"0SW737Z" = "1" /* Revision of Autologous Tissue Substitute in Right Sacroiliac Joint, Percutaneous Approach */
"0SW738Z" = "1" /* Revision of Spacer in Right Sacroiliac Joint, Percutaneous Approach */
"0SW73JZ" = "1" /* Revision of Synthetic Substitute in Right Sacroiliac Joint, Percutaneous Approach */
"0SW73KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Sacroiliac Joint, Percutaneous Approach */
"0SW740Z" = "1" /* Revision of Drainage Device in Right Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SW743Z" = "1" /* Revision of Infusion Device in Right Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SW744Z" = "1" /* Revision of Internal Fixation Device in Right Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SW747Z" = "1" /* Revision of Autologous Tissue Substitute in Right Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SW748Z" = "1" /* Revision of Spacer in Right Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SW74JZ" = "1" /* Revision of Synthetic Substitute in Right Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SW74KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SW800Z" = "1" /* Revision of Drainage Device in Left Sacroiliac Joint, Open Approach */
"0SW803Z" = "1" /* Revision of Infusion Device in Left Sacroiliac Joint, Open Approach */
"0SW804Z" = "1" /* Revision of Internal Fixation Device in Left Sacroiliac Joint, Open Approach */
"0SW807Z" = "1" /* Revision of Autologous Tissue Substitute in Left Sacroiliac Joint, Open Approach */
"0SW808Z" = "1" /* Revision of Spacer in Left Sacroiliac Joint, Open Approach */
"0SW80JZ" = "1" /* Revision of Synthetic Substitute in Left Sacroiliac Joint, Open Approach */
"0SW80KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Sacroiliac Joint, Open Approach */
"0SW830Z" = "1" /* Revision of Drainage Device in Left Sacroiliac Joint, Percutaneous Approach */
"0SW833Z" = "1" /* Revision of Infusion Device in Left Sacroiliac Joint, Percutaneous Approach */
"0SW834Z" = "1" /* Revision of Internal Fixation Device in Left Sacroiliac Joint, Percutaneous Approach */
"0SW837Z" = "1" /* Revision of Autologous Tissue Substitute in Left Sacroiliac Joint, Percutaneous Approach */
"0SW838Z" = "1" /* Revision of Spacer in Left Sacroiliac Joint, Percutaneous Approach */
"0SW83JZ" = "1" /* Revision of Synthetic Substitute in Left Sacroiliac Joint, Percutaneous Approach */
"0SW83KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Sacroiliac Joint, Percutaneous Approach */
"0SW840Z" = "1" /* Revision of Drainage Device in Left Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SW843Z" = "1" /* Revision of Infusion Device in Left Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SW844Z" = "1" /* Revision of Internal Fixation Device in Left Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SW847Z" = "1" /* Revision of Autologous Tissue Substitute in Left Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SW848Z" = "1" /* Revision of Spacer in Left Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SW84JZ" = "1" /* Revision of Synthetic Substitute in Left Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SW84KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Sacroiliac Joint, Percutaneous Endoscopic Approach */
"0SW900Z" = "1" /* Revision of Drainage Device in Right Hip Joint, Open Approach */
"0SW903Z" = "1" /* Revision of Infusion Device in Right Hip Joint, Open Approach */
"0SW904Z" = "1" /* Revision of Internal Fixation Device in Right Hip Joint, Open Approach */
"0SW905Z" = "1" /* Revision of External Fixation Device in Right Hip Joint, Open Approach */
"0SW907Z" = "1" /* Revision of Autologous Tissue Substitute in Right Hip Joint, Open Approach */
"0SW908Z" = "1" /* Revision of Spacer in Right Hip Joint, Open Approach */
"0SW909Z" = "1" /* Revision of Liner in Right Hip Joint, Open Approach */
"0SW90BZ" = "1" /* Revision of Resurfacing Device in Right Hip Joint, Open Approach */
"0SW90JZ" = "1" /* Revision of Synthetic Substitute in Right Hip Joint, Open Approach */
"0SW90KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Hip Joint, Open Approach */
"0SW930Z" = "1" /* Revision of Drainage Device in Right Hip Joint, Percutaneous Approach */
"0SW933Z" = "1" /* Revision of Infusion Device in Right Hip Joint, Percutaneous Approach */
"0SW934Z" = "1" /* Revision of Internal Fixation Device in Right Hip Joint, Percutaneous Approach */
"0SW935Z" = "1" /* Revision of External Fixation Device in Right Hip Joint, Percutaneous Approach */
"0SW937Z" = "1" /* Revision of Autologous Tissue Substitute in Right Hip Joint, Percutaneous Approach */
"0SW938Z" = "1" /* Revision of Spacer in Right Hip Joint, Percutaneous Approach */
"0SW93JZ" = "1" /* Revision of Synthetic Substitute in Right Hip Joint, Percutaneous Approach */
"0SW93KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Hip Joint, Percutaneous Approach */
"0SW940Z" = "1" /* Revision of Drainage Device in Right Hip Joint, Percutaneous Endoscopic Approach */
"0SW943Z" = "1" /* Revision of Infusion Device in Right Hip Joint, Percutaneous Endoscopic Approach */
"0SW944Z" = "1" /* Revision of Internal Fixation Device in Right Hip Joint, Percutaneous Endoscopic Approach */
"0SW945Z" = "1" /* Revision of External Fixation Device in Right Hip Joint, Percutaneous Endoscopic Approach */
"0SW947Z" = "1" /* Revision of Autologous Tissue Substitute in Right Hip Joint, Percutaneous Endoscopic Approach */
"0SW948Z" = "1" /* Revision of Spacer in Right Hip Joint, Percutaneous Endoscopic Approach */
"0SW94JZ" = "1" /* Revision of Synthetic Substitute in Right Hip Joint, Percutaneous Endoscopic Approach */
"0SW94KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Hip Joint, Percutaneous Endoscopic Approach */
"0SWA0JZ" = "1" /* Revision of Synthetic Substitute in Right Hip Joint, Acetabular Surface, Open Approach */
"0SWA3JZ" = "1" /* Revision of Synthetic Substitute in Right Hip Joint, Acetabular Surface, Percutaneous Approach */
"0SWA4JZ" = "1" /* Revision of Synthetic Substitute in Right Hip Joint, Acetabular Surface, Percutaneous Endoscopic Approach */
"0SWB00Z" = "1" /* Revision of Drainage Device in Left Hip Joint, Open Approach */
"0SWB03Z" = "1" /* Revision of Infusion Device in Left Hip Joint, Open Approach */
"0SWB04Z" = "1" /* Revision of Internal Fixation Device in Left Hip Joint, Open Approach */
"0SWB05Z" = "1" /* Revision of External Fixation Device in Left Hip Joint, Open Approach */
"0SWB07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Hip Joint, Open Approach */
"0SWB08Z" = "1" /* Revision of Spacer in Left Hip Joint, Open Approach */
"0SWB09Z" = "1" /* Revision of Liner in Left Hip Joint, Open Approach */
"0SWB0BZ" = "1" /* Revision of Resurfacing Device in Left Hip Joint, Open Approach */
"0SWB0JZ" = "1" /* Revision of Synthetic Substitute in Left Hip Joint, Open Approach */
"0SWB0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Hip Joint, Open Approach */
"0SWB30Z" = "1" /* Revision of Drainage Device in Left Hip Joint, Percutaneous Approach */
"0SWB33Z" = "1" /* Revision of Infusion Device in Left Hip Joint, Percutaneous Approach */
"0SWB34Z" = "1" /* Revision of Internal Fixation Device in Left Hip Joint, Percutaneous Approach */
"0SWB35Z" = "1" /* Revision of External Fixation Device in Left Hip Joint, Percutaneous Approach */
"0SWB37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Hip Joint, Percutaneous Approach */
"0SWB38Z" = "1" /* Revision of Spacer in Left Hip Joint, Percutaneous Approach */
"0SWB3JZ" = "1" /* Revision of Synthetic Substitute in Left Hip Joint, Percutaneous Approach */
"0SWB3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Hip Joint, Percutaneous Approach */
"0SWB40Z" = "1" /* Revision of Drainage Device in Left Hip Joint, Percutaneous Endoscopic Approach */
"0SWB43Z" = "1" /* Revision of Infusion Device in Left Hip Joint, Percutaneous Endoscopic Approach */
"0SWB44Z" = "1" /* Revision of Internal Fixation Device in Left Hip Joint, Percutaneous Endoscopic Approach */
"0SWB45Z" = "1" /* Revision of External Fixation Device in Left Hip Joint, Percutaneous Endoscopic Approach */
"0SWB47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Hip Joint, Percutaneous Endoscopic Approach */
"0SWB48Z" = "1" /* Revision of Spacer in Left Hip Joint, Percutaneous Endoscopic Approach */
"0SWB4JZ" = "1" /* Revision of Synthetic Substitute in Left Hip Joint, Percutaneous Endoscopic Approach */
"0SWB4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Hip Joint, Percutaneous Endoscopic Approach */
"0SWC00Z" = "1" /* Revision of Drainage Device in Right Knee Joint, Open Approach */
"0SWC03Z" = "1" /* Revision of Infusion Device in Right Knee Joint, Open Approach */
"0SWC04Z" = "1" /* Revision of Internal Fixation Device in Right Knee Joint, Open Approach */
"0SWC05Z" = "1" /* Revision of External Fixation Device in Right Knee Joint, Open Approach */
"0SWC07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Knee Joint, Open Approach */
"0SWC08Z" = "1" /* Revision of Spacer in Right Knee Joint, Open Approach */
"0SWC09Z" = "1" /* Revision of Liner in Right Knee Joint, Open Approach */
"0SWC0JC" = "1" /* Revision of Synthetic Substitute in Right Knee Joint, Patellar Surface, Open Approach */
"0SWC0JZ" = "1" /* Revision of Synthetic Substitute in Right Knee Joint, Open Approach */
"0SWC0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Knee Joint, Open Approach */
"0SWC30Z" = "1" /* Revision of Drainage Device in Right Knee Joint, Percutaneous Approach */
"0SWC33Z" = "1" /* Revision of Infusion Device in Right Knee Joint, Percutaneous Approach */
"0SWC34Z" = "1" /* Revision of Internal Fixation Device in Right Knee Joint, Percutaneous Approach */
"0SWC35Z" = "1" /* Revision of External Fixation Device in Right Knee Joint, Percutaneous Approach */
"0SWC37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Knee Joint, Percutaneous Approach */
"0SWC38Z" = "1" /* Revision of Spacer in Right Knee Joint, Percutaneous Approach */
"0SWC3JC" = "1" /* Revision of Synthetic Substitute in Right Knee Joint, Patellar Surface, Percutaneous Approach */
"0SWC3JZ" = "1" /* Revision of Synthetic Substitute in Right Knee Joint, Percutaneous Approach */
"0SWC3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Knee Joint, Percutaneous Approach */
"0SWC40Z" = "1" /* Revision of Drainage Device in Right Knee Joint, Percutaneous Endoscopic Approach */
"0SWC43Z" = "1" /* Revision of Infusion Device in Right Knee Joint, Percutaneous Endoscopic Approach */
"0SWC44Z" = "1" /* Revision of Internal Fixation Device in Right Knee Joint, Percutaneous Endoscopic Approach */
"0SWC45Z" = "1" /* Revision of External Fixation Device in Right Knee Joint, Percutaneous Endoscopic Approach */
"0SWC47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Knee Joint, Percutaneous Endoscopic Approach */
"0SWC48Z" = "1" /* Revision of Spacer in Right Knee Joint, Percutaneous Endoscopic Approach */
"0SWC4JC" = "1" /* Revision of Synthetic Substitute in Right Knee Joint, Patellar Surface, Percutaneous Endoscopic Approach */
"0SWC4JZ" = "1" /* Revision of Synthetic Substitute in Right Knee Joint, Percutaneous Endoscopic Approach */
"0SWC4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Knee Joint, Percutaneous Endoscopic Approach */
"0SWD00Z" = "1" /* Revision of Drainage Device in Left Knee Joint, Open Approach */
"0SWD03Z" = "1" /* Revision of Infusion Device in Left Knee Joint, Open Approach */
"0SWD04Z" = "1" /* Revision of Internal Fixation Device in Left Knee Joint, Open Approach */
"0SWD05Z" = "1" /* Revision of External Fixation Device in Left Knee Joint, Open Approach */
"0SWD07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Knee Joint, Open Approach */
"0SWD08Z" = "1" /* Revision of Spacer in Left Knee Joint, Open Approach */
"0SWD09Z" = "1" /* Revision of Liner in Left Knee Joint, Open Approach */
"0SWD0JC" = "1" /* Revision of Synthetic Substitute in Left Knee Joint, Patellar Surface, Open Approach */
"0SWD0JZ" = "1" /* Revision of Synthetic Substitute in Left Knee Joint, Open Approach */
"0SWD0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Knee Joint, Open Approach */
"0SWD30Z" = "1" /* Revision of Drainage Device in Left Knee Joint, Percutaneous Approach */
"0SWD33Z" = "1" /* Revision of Infusion Device in Left Knee Joint, Percutaneous Approach */
"0SWD34Z" = "1" /* Revision of Internal Fixation Device in Left Knee Joint, Percutaneous Approach */
"0SWD35Z" = "1" /* Revision of External Fixation Device in Left Knee Joint, Percutaneous Approach */
"0SWD37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Knee Joint, Percutaneous Approach */
"0SWD38Z" = "1" /* Revision of Spacer in Left Knee Joint, Percutaneous Approach */
"0SWD3JC" = "1" /* Revision of Synthetic Substitute in Left Knee Joint, Patellar Surface, Percutaneous Approach */
"0SWD3JZ" = "1" /* Revision of Synthetic Substitute in Left Knee Joint, Percutaneous Approach */
"0SWD3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Knee Joint, Percutaneous Approach */
"0SWD40Z" = "1" /* Revision of Drainage Device in Left Knee Joint, Percutaneous Endoscopic Approach */
"0SWD43Z" = "1" /* Revision of Infusion Device in Left Knee Joint, Percutaneous Endoscopic Approach */
"0SWD44Z" = "1" /* Revision of Internal Fixation Device in Left Knee Joint, Percutaneous Endoscopic Approach */
"0SWD45Z" = "1" /* Revision of External Fixation Device in Left Knee Joint, Percutaneous Endoscopic Approach */
"0SWD47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Knee Joint, Percutaneous Endoscopic Approach */
"0SWD48Z" = "1" /* Revision of Spacer in Left Knee Joint, Percutaneous Endoscopic Approach */
"0SWD4JC" = "1" /* Revision of Synthetic Substitute in Left Knee Joint, Patellar Surface, Percutaneous Endoscopic Approach */
"0SWD4JZ" = "1" /* Revision of Synthetic Substitute in Left Knee Joint, Percutaneous Endoscopic Approach */
"0SWD4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Knee Joint, Percutaneous Endoscopic Approach */
"0SWE0JZ" = "1" /* Revision of Synthetic Substitute in Left Hip Joint, Acetabular Surface, Open Approach */
"0SWE3JZ" = "1" /* Revision of Synthetic Substitute in Left Hip Joint, Acetabular Surface, Percutaneous Approach */
"0SWE4JZ" = "1" /* Revision of Synthetic Substitute in Left Hip Joint, Acetabular Surface, Percutaneous Endoscopic Approach */
"0SWF00Z" = "1" /* Revision of Drainage Device in Right Ankle Joint, Open Approach */
"0SWF03Z" = "1" /* Revision of Infusion Device in Right Ankle Joint, Open Approach */
"0SWF04Z" = "1" /* Revision of Internal Fixation Device in Right Ankle Joint, Open Approach */
"0SWF05Z" = "1" /* Revision of External Fixation Device in Right Ankle Joint, Open Approach */
"0SWF07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Ankle Joint, Open Approach */
"0SWF08Z" = "1" /* Revision of Spacer in Right Ankle Joint, Open Approach */
"0SWF0JZ" = "1" /* Revision of Synthetic Substitute in Right Ankle Joint, Open Approach */
"0SWF0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Ankle Joint, Open Approach */
"0SWF30Z" = "1" /* Revision of Drainage Device in Right Ankle Joint, Percutaneous Approach */
"0SWF33Z" = "1" /* Revision of Infusion Device in Right Ankle Joint, Percutaneous Approach */
"0SWF34Z" = "1" /* Revision of Internal Fixation Device in Right Ankle Joint, Percutaneous Approach */
"0SWF35Z" = "1" /* Revision of External Fixation Device in Right Ankle Joint, Percutaneous Approach */
"0SWF37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Ankle Joint, Percutaneous Approach */
"0SWF38Z" = "1" /* Revision of Spacer in Right Ankle Joint, Percutaneous Approach */
"0SWF3JZ" = "1" /* Revision of Synthetic Substitute in Right Ankle Joint, Percutaneous Approach */
"0SWF3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Ankle Joint, Percutaneous Approach */
"0SWF40Z" = "1" /* Revision of Drainage Device in Right Ankle Joint, Percutaneous Endoscopic Approach */
"0SWF43Z" = "1" /* Revision of Infusion Device in Right Ankle Joint, Percutaneous Endoscopic Approach */
"0SWF44Z" = "1" /* Revision of Internal Fixation Device in Right Ankle Joint, Percutaneous Endoscopic Approach */
"0SWF45Z" = "1" /* Revision of External Fixation Device in Right Ankle Joint, Percutaneous Endoscopic Approach */
"0SWF47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Ankle Joint, Percutaneous Endoscopic Approach */
"0SWF48Z" = "1" /* Revision of Spacer in Right Ankle Joint, Percutaneous Endoscopic Approach */
"0SWF4JZ" = "1" /* Revision of Synthetic Substitute in Right Ankle Joint, Percutaneous Endoscopic Approach */
"0SWF4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Ankle Joint, Percutaneous Endoscopic Approach */
"0SWG00Z" = "1" /* Revision of Drainage Device in Left Ankle Joint, Open Approach */
"0SWG03Z" = "1" /* Revision of Infusion Device in Left Ankle Joint, Open Approach */
"0SWG04Z" = "1" /* Revision of Internal Fixation Device in Left Ankle Joint, Open Approach */
"0SWG05Z" = "1" /* Revision of External Fixation Device in Left Ankle Joint, Open Approach */
"0SWG07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Ankle Joint, Open Approach */
"0SWG08Z" = "1" /* Revision of Spacer in Left Ankle Joint, Open Approach */
"0SWG0JZ" = "1" /* Revision of Synthetic Substitute in Left Ankle Joint, Open Approach */
"0SWG0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Ankle Joint, Open Approach */
"0SWG30Z" = "1" /* Revision of Drainage Device in Left Ankle Joint, Percutaneous Approach */
"0SWG33Z" = "1" /* Revision of Infusion Device in Left Ankle Joint, Percutaneous Approach */
"0SWG34Z" = "1" /* Revision of Internal Fixation Device in Left Ankle Joint, Percutaneous Approach */
"0SWG35Z" = "1" /* Revision of External Fixation Device in Left Ankle Joint, Percutaneous Approach */
"0SWG37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Ankle Joint, Percutaneous Approach */
"0SWG38Z" = "1" /* Revision of Spacer in Left Ankle Joint, Percutaneous Approach */
"0SWG3JZ" = "1" /* Revision of Synthetic Substitute in Left Ankle Joint, Percutaneous Approach */
"0SWG3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Ankle Joint, Percutaneous Approach */
"0SWG40Z" = "1" /* Revision of Drainage Device in Left Ankle Joint, Percutaneous Endoscopic Approach */
"0SWG43Z" = "1" /* Revision of Infusion Device in Left Ankle Joint, Percutaneous Endoscopic Approach */
"0SWG44Z" = "1" /* Revision of Internal Fixation Device in Left Ankle Joint, Percutaneous Endoscopic Approach */
"0SWG45Z" = "1" /* Revision of External Fixation Device in Left Ankle Joint, Percutaneous Endoscopic Approach */
"0SWG47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Ankle Joint, Percutaneous Endoscopic Approach */
"0SWG48Z" = "1" /* Revision of Spacer in Left Ankle Joint, Percutaneous Endoscopic Approach */
"0SWG4JZ" = "1" /* Revision of Synthetic Substitute in Left Ankle Joint, Percutaneous Endoscopic Approach */
"0SWG4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Ankle Joint, Percutaneous Endoscopic Approach */
"0SWH00Z" = "1" /* Revision of Drainage Device in Right Tarsal Joint, Open Approach */
"0SWH03Z" = "1" /* Revision of Infusion Device in Right Tarsal Joint, Open Approach */
"0SWH04Z" = "1" /* Revision of Internal Fixation Device in Right Tarsal Joint, Open Approach */
"0SWH05Z" = "1" /* Revision of External Fixation Device in Right Tarsal Joint, Open Approach */
"0SWH07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Tarsal Joint, Open Approach */
"0SWH08Z" = "1" /* Revision of Spacer in Right Tarsal Joint, Open Approach */
"0SWH0JZ" = "1" /* Revision of Synthetic Substitute in Right Tarsal Joint, Open Approach */
"0SWH0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Tarsal Joint, Open Approach */
"0SWH30Z" = "1" /* Revision of Drainage Device in Right Tarsal Joint, Percutaneous Approach */
"0SWH33Z" = "1" /* Revision of Infusion Device in Right Tarsal Joint, Percutaneous Approach */
"0SWH34Z" = "1" /* Revision of Internal Fixation Device in Right Tarsal Joint, Percutaneous Approach */
"0SWH35Z" = "1" /* Revision of External Fixation Device in Right Tarsal Joint, Percutaneous Approach */
"0SWH37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Tarsal Joint, Percutaneous Approach */
"0SWH38Z" = "1" /* Revision of Spacer in Right Tarsal Joint, Percutaneous Approach */
"0SWH3JZ" = "1" /* Revision of Synthetic Substitute in Right Tarsal Joint, Percutaneous Approach */
"0SWH3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Tarsal Joint, Percutaneous Approach */
"0SWH40Z" = "1" /* Revision of Drainage Device in Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWH43Z" = "1" /* Revision of Infusion Device in Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWH44Z" = "1" /* Revision of Internal Fixation Device in Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWH45Z" = "1" /* Revision of External Fixation Device in Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWH47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWH48Z" = "1" /* Revision of Spacer in Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWH4JZ" = "1" /* Revision of Synthetic Substitute in Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWH4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWJ00Z" = "1" /* Revision of Drainage Device in Left Tarsal Joint, Open Approach */
"0SWJ03Z" = "1" /* Revision of Infusion Device in Left Tarsal Joint, Open Approach */
"0SWJ04Z" = "1" /* Revision of Internal Fixation Device in Left Tarsal Joint, Open Approach */
"0SWJ05Z" = "1" /* Revision of External Fixation Device in Left Tarsal Joint, Open Approach */
"0SWJ07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Tarsal Joint, Open Approach */
"0SWJ08Z" = "1" /* Revision of Spacer in Left Tarsal Joint, Open Approach */
"0SWJ0JZ" = "1" /* Revision of Synthetic Substitute in Left Tarsal Joint, Open Approach */
"0SWJ0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Tarsal Joint, Open Approach */
"0SWJ30Z" = "1" /* Revision of Drainage Device in Left Tarsal Joint, Percutaneous Approach */
"0SWJ33Z" = "1" /* Revision of Infusion Device in Left Tarsal Joint, Percutaneous Approach */
"0SWJ34Z" = "1" /* Revision of Internal Fixation Device in Left Tarsal Joint, Percutaneous Approach */
"0SWJ35Z" = "1" /* Revision of External Fixation Device in Left Tarsal Joint, Percutaneous Approach */
"0SWJ37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Tarsal Joint, Percutaneous Approach */
"0SWJ38Z" = "1" /* Revision of Spacer in Left Tarsal Joint, Percutaneous Approach */
"0SWJ3JZ" = "1" /* Revision of Synthetic Substitute in Left Tarsal Joint, Percutaneous Approach */
"0SWJ3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Tarsal Joint, Percutaneous Approach */
"0SWJ40Z" = "1" /* Revision of Drainage Device in Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWJ43Z" = "1" /* Revision of Infusion Device in Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWJ44Z" = "1" /* Revision of Internal Fixation Device in Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWJ45Z" = "1" /* Revision of External Fixation Device in Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWJ47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWJ48Z" = "1" /* Revision of Spacer in Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWJ4JZ" = "1" /* Revision of Synthetic Substitute in Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWJ4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWK00Z" = "1" /* Revision of Drainage Device in Right Metatarsal-Tarsal Joint, Open Approach */
"0SWK03Z" = "1" /* Revision of Infusion Device in Right Metatarsal-Tarsal Joint, Open Approach */
"0SWK04Z" = "1" /* Revision of Internal Fixation Device in Right Metatarsal-Tarsal Joint, Open Approach */
"0SWK05Z" = "1" /* Revision of External Fixation Device in Right Metatarsal-Tarsal Joint, Open Approach */
"0SWK07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Metatarsal-Tarsal Joint, Open Approach */
"0SWK08Z" = "1" /* Revision of Spacer in Right Metatarsal-Tarsal Joint, Open Approach */
"0SWK0JZ" = "1" /* Revision of Synthetic Substitute in Right Metatarsal-Tarsal Joint, Open Approach */
"0SWK0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Metatarsal-Tarsal Joint, Open Approach */
"0SWK30Z" = "1" /* Revision of Drainage Device in Right Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SWK33Z" = "1" /* Revision of Infusion Device in Right Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SWK34Z" = "1" /* Revision of Internal Fixation Device in Right Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SWK35Z" = "1" /* Revision of External Fixation Device in Right Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SWK37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SWK38Z" = "1" /* Revision of Spacer in Right Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SWK3JZ" = "1" /* Revision of Synthetic Substitute in Right Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SWK3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SWK40Z" = "1" /* Revision of Drainage Device in Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWK43Z" = "1" /* Revision of Infusion Device in Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWK44Z" = "1" /* Revision of Internal Fixation Device in Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWK45Z" = "1" /* Revision of External Fixation Device in Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWK47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWK48Z" = "1" /* Revision of Spacer in Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWK4JZ" = "1" /* Revision of Synthetic Substitute in Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWK4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWL00Z" = "1" /* Revision of Drainage Device in Left Metatarsal-Tarsal Joint, Open Approach */
"0SWL03Z" = "1" /* Revision of Infusion Device in Left Metatarsal-Tarsal Joint, Open Approach */
"0SWL04Z" = "1" /* Revision of Internal Fixation Device in Left Metatarsal-Tarsal Joint, Open Approach */
"0SWL05Z" = "1" /* Revision of External Fixation Device in Left Metatarsal-Tarsal Joint, Open Approach */
"0SWL07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Metatarsal-Tarsal Joint, Open Approach */
"0SWL08Z" = "1" /* Revision of Spacer in Left Metatarsal-Tarsal Joint, Open Approach */
"0SWL0JZ" = "1" /* Revision of Synthetic Substitute in Left Metatarsal-Tarsal Joint, Open Approach */
"0SWL0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Metatarsal-Tarsal Joint, Open Approach */
"0SWL30Z" = "1" /* Revision of Drainage Device in Left Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SWL33Z" = "1" /* Revision of Infusion Device in Left Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SWL34Z" = "1" /* Revision of Internal Fixation Device in Left Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SWL35Z" = "1" /* Revision of External Fixation Device in Left Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SWL37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SWL38Z" = "1" /* Revision of Spacer in Left Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SWL3JZ" = "1" /* Revision of Synthetic Substitute in Left Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SWL3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Metatarsal-Tarsal Joint, Percutaneous Approach */
"0SWL40Z" = "1" /* Revision of Drainage Device in Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWL43Z" = "1" /* Revision of Infusion Device in Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWL44Z" = "1" /* Revision of Internal Fixation Device in Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWL45Z" = "1" /* Revision of External Fixation Device in Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWL47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWL48Z" = "1" /* Revision of Spacer in Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWL4JZ" = "1" /* Revision of Synthetic Substitute in Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWL4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Metatarsal-Tarsal Joint, Percutaneous Endoscopic Approach */
"0SWM00Z" = "1" /* Revision of Drainage Device in Right Metatarsal-Phalangeal Joint, Open Approach */
"0SWM03Z" = "1" /* Revision of Infusion Device in Right Metatarsal-Phalangeal Joint, Open Approach */
"0SWM04Z" = "1" /* Revision of Internal Fixation Device in Right Metatarsal-Phalangeal Joint, Open Approach */
"0SWM05Z" = "1" /* Revision of External Fixation Device in Right Metatarsal-Phalangeal Joint, Open Approach */
"0SWM07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Metatarsal-Phalangeal Joint, Open Approach */
"0SWM08Z" = "1" /* Revision of Spacer in Right Metatarsal-Phalangeal Joint, Open Approach */
"0SWM0JZ" = "1" /* Revision of Synthetic Substitute in Right Metatarsal-Phalangeal Joint, Open Approach */
"0SWM0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Metatarsal-Phalangeal Joint, Open Approach */
"0SWM30Z" = "1" /* Revision of Drainage Device in Right Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SWM33Z" = "1" /* Revision of Infusion Device in Right Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SWM34Z" = "1" /* Revision of Internal Fixation Device in Right Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SWM35Z" = "1" /* Revision of External Fixation Device in Right Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SWM37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SWM38Z" = "1" /* Revision of Spacer in Right Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SWM3JZ" = "1" /* Revision of Synthetic Substitute in Right Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SWM3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SWM40Z" = "1" /* Revision of Drainage Device in Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWM43Z" = "1" /* Revision of Infusion Device in Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWM44Z" = "1" /* Revision of Internal Fixation Device in Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWM45Z" = "1" /* Revision of External Fixation Device in Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWM47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWM48Z" = "1" /* Revision of Spacer in Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWM4JZ" = "1" /* Revision of Synthetic Substitute in Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWM4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWN00Z" = "1" /* Revision of Drainage Device in Left Metatarsal-Phalangeal Joint, Open Approach */
"0SWN03Z" = "1" /* Revision of Infusion Device in Left Metatarsal-Phalangeal Joint, Open Approach */
"0SWN04Z" = "1" /* Revision of Internal Fixation Device in Left Metatarsal-Phalangeal Joint, Open Approach */
"0SWN05Z" = "1" /* Revision of External Fixation Device in Left Metatarsal-Phalangeal Joint, Open Approach */
"0SWN07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Metatarsal-Phalangeal Joint, Open Approach */
"0SWN08Z" = "1" /* Revision of Spacer in Left Metatarsal-Phalangeal Joint, Open Approach */
"0SWN0JZ" = "1" /* Revision of Synthetic Substitute in Left Metatarsal-Phalangeal Joint, Open Approach */
"0SWN0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Metatarsal-Phalangeal Joint, Open Approach */
"0SWN30Z" = "1" /* Revision of Drainage Device in Left Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SWN33Z" = "1" /* Revision of Infusion Device in Left Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SWN34Z" = "1" /* Revision of Internal Fixation Device in Left Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SWN35Z" = "1" /* Revision of External Fixation Device in Left Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SWN37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SWN38Z" = "1" /* Revision of Spacer in Left Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SWN3JZ" = "1" /* Revision of Synthetic Substitute in Left Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SWN3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Metatarsal-Phalangeal Joint, Percutaneous Approach */
"0SWN40Z" = "1" /* Revision of Drainage Device in Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWN43Z" = "1" /* Revision of Infusion Device in Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWN44Z" = "1" /* Revision of Internal Fixation Device in Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWN45Z" = "1" /* Revision of External Fixation Device in Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWN47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWN48Z" = "1" /* Revision of Spacer in Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWN4JZ" = "1" /* Revision of Synthetic Substitute in Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWN4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Metatarsal-Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWP00Z" = "1" /* Revision of Drainage Device in Right Toe Phalangeal Joint, Open Approach */
"0SWP03Z" = "1" /* Revision of Infusion Device in Right Toe Phalangeal Joint, Open Approach */
"0SWP04Z" = "1" /* Revision of Internal Fixation Device in Right Toe Phalangeal Joint, Open Approach */
"0SWP05Z" = "1" /* Revision of External Fixation Device in Right Toe Phalangeal Joint, Open Approach */
"0SWP07Z" = "1" /* Revision of Autologous Tissue Substitute in Right Toe Phalangeal Joint, Open Approach */
"0SWP08Z" = "1" /* Revision of Spacer in Right Toe Phalangeal Joint, Open Approach */
"0SWP0JZ" = "1" /* Revision of Synthetic Substitute in Right Toe Phalangeal Joint, Open Approach */
"0SWP0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Toe Phalangeal Joint, Open Approach */
"0SWP30Z" = "1" /* Revision of Drainage Device in Right Toe Phalangeal Joint, Percutaneous Approach */
"0SWP33Z" = "1" /* Revision of Infusion Device in Right Toe Phalangeal Joint, Percutaneous Approach */
"0SWP34Z" = "1" /* Revision of Internal Fixation Device in Right Toe Phalangeal Joint, Percutaneous Approach */
"0SWP35Z" = "1" /* Revision of External Fixation Device in Right Toe Phalangeal Joint, Percutaneous Approach */
"0SWP37Z" = "1" /* Revision of Autologous Tissue Substitute in Right Toe Phalangeal Joint, Percutaneous Approach */
"0SWP38Z" = "1" /* Revision of Spacer in Right Toe Phalangeal Joint, Percutaneous Approach */
"0SWP3JZ" = "1" /* Revision of Synthetic Substitute in Right Toe Phalangeal Joint, Percutaneous Approach */
"0SWP3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Toe Phalangeal Joint, Percutaneous Approach */
"0SWP40Z" = "1" /* Revision of Drainage Device in Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWP43Z" = "1" /* Revision of Infusion Device in Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWP44Z" = "1" /* Revision of Internal Fixation Device in Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWP45Z" = "1" /* Revision of External Fixation Device in Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWP47Z" = "1" /* Revision of Autologous Tissue Substitute in Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWP48Z" = "1" /* Revision of Spacer in Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWP4JZ" = "1" /* Revision of Synthetic Substitute in Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWP4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Right Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWQ00Z" = "1" /* Revision of Drainage Device in Left Toe Phalangeal Joint, Open Approach */
"0SWQ03Z" = "1" /* Revision of Infusion Device in Left Toe Phalangeal Joint, Open Approach */
"0SWQ04Z" = "1" /* Revision of Internal Fixation Device in Left Toe Phalangeal Joint, Open Approach */
"0SWQ05Z" = "1" /* Revision of External Fixation Device in Left Toe Phalangeal Joint, Open Approach */
"0SWQ07Z" = "1" /* Revision of Autologous Tissue Substitute in Left Toe Phalangeal Joint, Open Approach */
"0SWQ08Z" = "1" /* Revision of Spacer in Left Toe Phalangeal Joint, Open Approach */
"0SWQ0JZ" = "1" /* Revision of Synthetic Substitute in Left Toe Phalangeal Joint, Open Approach */
"0SWQ0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Toe Phalangeal Joint, Open Approach */
"0SWQ30Z" = "1" /* Revision of Drainage Device in Left Toe Phalangeal Joint, Percutaneous Approach */
"0SWQ33Z" = "1" /* Revision of Infusion Device in Left Toe Phalangeal Joint, Percutaneous Approach */
"0SWQ34Z" = "1" /* Revision of Internal Fixation Device in Left Toe Phalangeal Joint, Percutaneous Approach */
"0SWQ35Z" = "1" /* Revision of External Fixation Device in Left Toe Phalangeal Joint, Percutaneous Approach */
"0SWQ37Z" = "1" /* Revision of Autologous Tissue Substitute in Left Toe Phalangeal Joint, Percutaneous Approach */
"0SWQ38Z" = "1" /* Revision of Spacer in Left Toe Phalangeal Joint, Percutaneous Approach */
"0SWQ3JZ" = "1" /* Revision of Synthetic Substitute in Left Toe Phalangeal Joint, Percutaneous Approach */
"0SWQ3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Toe Phalangeal Joint, Percutaneous Approach */
"0SWQ40Z" = "1" /* Revision of Drainage Device in Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWQ43Z" = "1" /* Revision of Infusion Device in Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWQ44Z" = "1" /* Revision of Internal Fixation Device in Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWQ45Z" = "1" /* Revision of External Fixation Device in Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWQ47Z" = "1" /* Revision of Autologous Tissue Substitute in Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWQ48Z" = "1" /* Revision of Spacer in Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWQ4JZ" = "1" /* Revision of Synthetic Substitute in Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWQ4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Left Toe Phalangeal Joint, Percutaneous Endoscopic Approach */
"0SWR0JZ" = "1" /* Revision of Synthetic Substitute in Right Hip Joint, Femoral Surface, Open Approach */
"0SWR3JZ" = "1" /* Revision of Synthetic Substitute in Right Hip Joint, Femoral Surface, Percutaneous Approach */
"0SWR4JZ" = "1" /* Revision of Synthetic Substitute in Right Hip Joint, Femoral Surface, Percutaneous Endoscopic Approach */
"0SWS0JZ" = "1" /* Revision of Synthetic Substitute in Left Hip Joint, Femoral Surface, Open Approach */
"0SWS3JZ" = "1" /* Revision of Synthetic Substitute in Left Hip Joint, Femoral Surface, Percutaneous Approach */
"0SWS4JZ" = "1" /* Revision of Synthetic Substitute in Left Hip Joint, Femoral Surface, Percutaneous Endoscopic Approach */
"0SWT0JZ" = "1" /* Revision of Synthetic Substitute in Right Knee Joint, Femoral Surface, Open Approach */
"0SWT3JZ" = "1" /* Revision of Synthetic Substitute in Right Knee Joint, Femoral Surface, Percutaneous Approach */
"0SWT4JZ" = "1" /* Revision of Synthetic Substitute in Right Knee Joint, Femoral Surface, Percutaneous Endoscopic Approach */
"0SWU0JZ" = "1" /* Revision of Synthetic Substitute in Left Knee Joint, Femoral Surface, Open Approach */
"0SWU3JZ" = "1" /* Revision of Synthetic Substitute in Left Knee Joint, Femoral Surface, Percutaneous Approach */
"0SWU4JZ" = "1" /* Revision of Synthetic Substitute in Left Knee Joint, Femoral Surface, Percutaneous Endoscopic Approach */
"0SWV0JZ" = "1" /* Revision of Synthetic Substitute in Right Knee Joint, Tibial Surface, Open Approach */
"0SWV3JZ" = "1" /* Revision of Synthetic Substitute in Right Knee Joint, Tibial Surface, Percutaneous Approach */
"0SWV4JZ" = "1" /* Revision of Synthetic Substitute in Right Knee Joint, Tibial Surface, Percutaneous Endoscopic Approach */
"0SWW0JZ" = "1" /* Revision of Synthetic Substitute in Left Knee Joint, Tibial Surface, Open Approach */
"0SWW3JZ" = "1" /* Revision of Synthetic Substitute in Left Knee Joint, Tibial Surface, Percutaneous Approach */
"0SWW4JZ" = "1" /* Revision of Synthetic Substitute in Left Knee Joint, Tibial Surface, Percutaneous Endoscopic Approach */
"0T13073" = "1" /* Bypass Right Kidney Pelvis to Right Kidney Pelvis with Autologous Tissue Substitute, Open Approach */
"0T13074" = "1" /* Bypass Right Kidney Pelvis to Left Kidney Pelvis with Autologous Tissue Substitute, Open Approach */
"0T13076" = "1" /* Bypass Right Kidney Pelvis to Right Ureter with Autologous Tissue Substitute, Open Approach */
"0T13077" = "1" /* Bypass Right Kidney Pelvis to Left Ureter with Autologous Tissue Substitute, Open Approach */
"0T13078" = "1" /* Bypass Right Kidney Pelvis to Colon with Autologous Tissue Substitute, Open Approach */
"0T13079" = "1" /* Bypass Right Kidney Pelvis to Colocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1307A" = "1" /* Bypass Right Kidney Pelvis to Ileum with Autologous Tissue Substitute, Open Approach */
"0T1307B" = "1" /* Bypass Right Kidney Pelvis to Bladder with Autologous Tissue Substitute, Open Approach */
"0T1307C" = "1" /* Bypass Right Kidney Pelvis to Ileocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1307D" = "1" /* Bypass Right Kidney Pelvis to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0T130J3" = "1" /* Bypass Right Kidney Pelvis to Right Kidney Pelvis with Synthetic Substitute, Open Approach */
"0T130J4" = "1" /* Bypass Right Kidney Pelvis to Left Kidney Pelvis with Synthetic Substitute, Open Approach */
"0T130J6" = "1" /* Bypass Right Kidney Pelvis to Right Ureter with Synthetic Substitute, Open Approach */
"0T130J7" = "1" /* Bypass Right Kidney Pelvis to Left Ureter with Synthetic Substitute, Open Approach */
"0T130J8" = "1" /* Bypass Right Kidney Pelvis to Colon with Synthetic Substitute, Open Approach */
"0T130J9" = "1" /* Bypass Right Kidney Pelvis to Colocutaneous with Synthetic Substitute, Open Approach */
"0T130JA" = "1" /* Bypass Right Kidney Pelvis to Ileum with Synthetic Substitute, Open Approach */
"0T130JB" = "1" /* Bypass Right Kidney Pelvis to Bladder with Synthetic Substitute, Open Approach */
"0T130JC" = "1" /* Bypass Right Kidney Pelvis to Ileocutaneous with Synthetic Substitute, Open Approach */
"0T130JD" = "1" /* Bypass Right Kidney Pelvis to Cutaneous with Synthetic Substitute, Open Approach */
"0T130K3" = "1" /* Bypass Right Kidney Pelvis to Right Kidney Pelvis with Nonautologous Tissue Substitute, Open Approach */
"0T130K4" = "1" /* Bypass Right Kidney Pelvis to Left Kidney Pelvis with Nonautologous Tissue Substitute, Open Approach */
"0T130K6" = "1" /* Bypass Right Kidney Pelvis to Right Ureter with Nonautologous Tissue Substitute, Open Approach */
"0T130K7" = "1" /* Bypass Right Kidney Pelvis to Left Ureter with Nonautologous Tissue Substitute, Open Approach */
"0T130K8" = "1" /* Bypass Right Kidney Pelvis to Colon with Nonautologous Tissue Substitute, Open Approach */
"0T130K9" = "1" /* Bypass Right Kidney Pelvis to Colocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T130KA" = "1" /* Bypass Right Kidney Pelvis to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0T130KB" = "1" /* Bypass Right Kidney Pelvis to Bladder with Nonautologous Tissue Substitute, Open Approach */
"0T130KC" = "1" /* Bypass Right Kidney Pelvis to Ileocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T130KD" = "1" /* Bypass Right Kidney Pelvis to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T130Z3" = "1" /* Bypass Right Kidney Pelvis to Right Kidney Pelvis, Open Approach */
"0T130Z4" = "1" /* Bypass Right Kidney Pelvis to Left Kidney Pelvis, Open Approach */
"0T130Z6" = "1" /* Bypass Right Kidney Pelvis to Right Ureter, Open Approach */
"0T130Z7" = "1" /* Bypass Right Kidney Pelvis to Left Ureter, Open Approach */
"0T130Z8" = "1" /* Bypass Right Kidney Pelvis to Colon, Open Approach */
"0T130Z9" = "1" /* Bypass Right Kidney Pelvis to Colocutaneous, Open Approach */
"0T130ZA" = "1" /* Bypass Right Kidney Pelvis to Ileum, Open Approach */
"0T130ZB" = "1" /* Bypass Right Kidney Pelvis to Bladder, Open Approach */
"0T130ZC" = "1" /* Bypass Right Kidney Pelvis to Ileocutaneous, Open Approach */
"0T130ZD" = "1" /* Bypass Right Kidney Pelvis to Cutaneous, Open Approach */
"0T133JD" = "1" /* Bypass Right Kidney Pelvis to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0T13473" = "1" /* Bypass Right Kidney Pelvis to Right Kidney Pelvis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T13474" = "1" /* Bypass Right Kidney Pelvis to Left Kidney Pelvis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T13476" = "1" /* Bypass Right Kidney Pelvis to Right Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T13477" = "1" /* Bypass Right Kidney Pelvis to Left Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T13478" = "1" /* Bypass Right Kidney Pelvis to Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T13479" = "1" /* Bypass Right Kidney Pelvis to Colocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1347A" = "1" /* Bypass Right Kidney Pelvis to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1347B" = "1" /* Bypass Right Kidney Pelvis to Bladder with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1347C" = "1" /* Bypass Right Kidney Pelvis to Ileocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1347D" = "1" /* Bypass Right Kidney Pelvis to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T134J3" = "1" /* Bypass Right Kidney Pelvis to Right Kidney Pelvis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T134J4" = "1" /* Bypass Right Kidney Pelvis to Left Kidney Pelvis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T134J6" = "1" /* Bypass Right Kidney Pelvis to Right Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T134J7" = "1" /* Bypass Right Kidney Pelvis to Left Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T134J8" = "1" /* Bypass Right Kidney Pelvis to Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T134J9" = "1" /* Bypass Right Kidney Pelvis to Colocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T134JA" = "1" /* Bypass Right Kidney Pelvis to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T134JB" = "1" /* Bypass Right Kidney Pelvis to Bladder with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T134JC" = "1" /* Bypass Right Kidney Pelvis to Ileocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T134JD" = "1" /* Bypass Right Kidney Pelvis to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T134K3" = "1" /* Bypass Right Kidney Pelvis to Right Kidney Pelvis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T134K4" = "1" /* Bypass Right Kidney Pelvis to Left Kidney Pelvis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T134K6" = "1" /* Bypass Right Kidney Pelvis to Right Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T134K7" = "1" /* Bypass Right Kidney Pelvis to Left Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T134K8" = "1" /* Bypass Right Kidney Pelvis to Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T134K9" = "1" /* Bypass Right Kidney Pelvis to Colocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T134KA" = "1" /* Bypass Right Kidney Pelvis to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T134KB" = "1" /* Bypass Right Kidney Pelvis to Bladder with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T134KC" = "1" /* Bypass Right Kidney Pelvis to Ileocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T134KD" = "1" /* Bypass Right Kidney Pelvis to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T134Z3" = "1" /* Bypass Right Kidney Pelvis to Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0T134Z4" = "1" /* Bypass Right Kidney Pelvis to Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0T134Z6" = "1" /* Bypass Right Kidney Pelvis to Right Ureter, Percutaneous Endoscopic Approach */
"0T134Z7" = "1" /* Bypass Right Kidney Pelvis to Left Ureter, Percutaneous Endoscopic Approach */
"0T134Z8" = "1" /* Bypass Right Kidney Pelvis to Colon, Percutaneous Endoscopic Approach */
"0T134Z9" = "1" /* Bypass Right Kidney Pelvis to Colocutaneous, Percutaneous Endoscopic Approach */
"0T134ZA" = "1" /* Bypass Right Kidney Pelvis to Ileum, Percutaneous Endoscopic Approach */
"0T134ZB" = "1" /* Bypass Right Kidney Pelvis to Bladder, Percutaneous Endoscopic Approach */
"0T134ZC" = "1" /* Bypass Right Kidney Pelvis to Ileocutaneous, Percutaneous Endoscopic Approach */
"0T134ZD" = "1" /* Bypass Right Kidney Pelvis to Cutaneous, Percutaneous Endoscopic Approach */
"0T14073" = "1" /* Bypass Left Kidney Pelvis to Right Kidney Pelvis with Autologous Tissue Substitute, Open Approach */
"0T14074" = "1" /* Bypass Left Kidney Pelvis to Left Kidney Pelvis with Autologous Tissue Substitute, Open Approach */
"0T14076" = "1" /* Bypass Left Kidney Pelvis to Right Ureter with Autologous Tissue Substitute, Open Approach */
"0T14077" = "1" /* Bypass Left Kidney Pelvis to Left Ureter with Autologous Tissue Substitute, Open Approach */
"0T14078" = "1" /* Bypass Left Kidney Pelvis to Colon with Autologous Tissue Substitute, Open Approach */
"0T14079" = "1" /* Bypass Left Kidney Pelvis to Colocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1407A" = "1" /* Bypass Left Kidney Pelvis to Ileum with Autologous Tissue Substitute, Open Approach */
"0T1407B" = "1" /* Bypass Left Kidney Pelvis to Bladder with Autologous Tissue Substitute, Open Approach */
"0T1407C" = "1" /* Bypass Left Kidney Pelvis to Ileocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1407D" = "1" /* Bypass Left Kidney Pelvis to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0T140J3" = "1" /* Bypass Left Kidney Pelvis to Right Kidney Pelvis with Synthetic Substitute, Open Approach */
"0T140J4" = "1" /* Bypass Left Kidney Pelvis to Left Kidney Pelvis with Synthetic Substitute, Open Approach */
"0T140J6" = "1" /* Bypass Left Kidney Pelvis to Right Ureter with Synthetic Substitute, Open Approach */
"0T140J7" = "1" /* Bypass Left Kidney Pelvis to Left Ureter with Synthetic Substitute, Open Approach */
"0T140J8" = "1" /* Bypass Left Kidney Pelvis to Colon with Synthetic Substitute, Open Approach */
"0T140J9" = "1" /* Bypass Left Kidney Pelvis to Colocutaneous with Synthetic Substitute, Open Approach */
"0T140JA" = "1" /* Bypass Left Kidney Pelvis to Ileum with Synthetic Substitute, Open Approach */
"0T140JB" = "1" /* Bypass Left Kidney Pelvis to Bladder with Synthetic Substitute, Open Approach */
"0T140JC" = "1" /* Bypass Left Kidney Pelvis to Ileocutaneous with Synthetic Substitute, Open Approach */
"0T140JD" = "1" /* Bypass Left Kidney Pelvis to Cutaneous with Synthetic Substitute, Open Approach */
"0T140K3" = "1" /* Bypass Left Kidney Pelvis to Right Kidney Pelvis with Nonautologous Tissue Substitute, Open Approach */
"0T140K4" = "1" /* Bypass Left Kidney Pelvis to Left Kidney Pelvis with Nonautologous Tissue Substitute, Open Approach */
"0T140K6" = "1" /* Bypass Left Kidney Pelvis to Right Ureter with Nonautologous Tissue Substitute, Open Approach */
"0T140K7" = "1" /* Bypass Left Kidney Pelvis to Left Ureter with Nonautologous Tissue Substitute, Open Approach */
"0T140K8" = "1" /* Bypass Left Kidney Pelvis to Colon with Nonautologous Tissue Substitute, Open Approach */
"0T140K9" = "1" /* Bypass Left Kidney Pelvis to Colocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T140KA" = "1" /* Bypass Left Kidney Pelvis to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0T140KB" = "1" /* Bypass Left Kidney Pelvis to Bladder with Nonautologous Tissue Substitute, Open Approach */
"0T140KC" = "1" /* Bypass Left Kidney Pelvis to Ileocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T140KD" = "1" /* Bypass Left Kidney Pelvis to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T140Z3" = "1" /* Bypass Left Kidney Pelvis to Right Kidney Pelvis, Open Approach */
"0T140Z4" = "1" /* Bypass Left Kidney Pelvis to Left Kidney Pelvis, Open Approach */
"0T140Z6" = "1" /* Bypass Left Kidney Pelvis to Right Ureter, Open Approach */
"0T140Z7" = "1" /* Bypass Left Kidney Pelvis to Left Ureter, Open Approach */
"0T140Z8" = "1" /* Bypass Left Kidney Pelvis to Colon, Open Approach */
"0T140Z9" = "1" /* Bypass Left Kidney Pelvis to Colocutaneous, Open Approach */
"0T140ZA" = "1" /* Bypass Left Kidney Pelvis to Ileum, Open Approach */
"0T140ZB" = "1" /* Bypass Left Kidney Pelvis to Bladder, Open Approach */
"0T140ZC" = "1" /* Bypass Left Kidney Pelvis to Ileocutaneous, Open Approach */
"0T140ZD" = "1" /* Bypass Left Kidney Pelvis to Cutaneous, Open Approach */
"0T143JD" = "1" /* Bypass Left Kidney Pelvis to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0T14473" = "1" /* Bypass Left Kidney Pelvis to Right Kidney Pelvis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T14474" = "1" /* Bypass Left Kidney Pelvis to Left Kidney Pelvis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T14476" = "1" /* Bypass Left Kidney Pelvis to Right Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T14477" = "1" /* Bypass Left Kidney Pelvis to Left Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T14478" = "1" /* Bypass Left Kidney Pelvis to Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T14479" = "1" /* Bypass Left Kidney Pelvis to Colocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1447A" = "1" /* Bypass Left Kidney Pelvis to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1447B" = "1" /* Bypass Left Kidney Pelvis to Bladder with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1447C" = "1" /* Bypass Left Kidney Pelvis to Ileocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1447D" = "1" /* Bypass Left Kidney Pelvis to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T144J3" = "1" /* Bypass Left Kidney Pelvis to Right Kidney Pelvis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T144J4" = "1" /* Bypass Left Kidney Pelvis to Left Kidney Pelvis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T144J6" = "1" /* Bypass Left Kidney Pelvis to Right Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T144J7" = "1" /* Bypass Left Kidney Pelvis to Left Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T144J8" = "1" /* Bypass Left Kidney Pelvis to Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T144J9" = "1" /* Bypass Left Kidney Pelvis to Colocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T144JA" = "1" /* Bypass Left Kidney Pelvis to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T144JB" = "1" /* Bypass Left Kidney Pelvis to Bladder with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T144JC" = "1" /* Bypass Left Kidney Pelvis to Ileocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T144JD" = "1" /* Bypass Left Kidney Pelvis to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T144K3" = "1" /* Bypass Left Kidney Pelvis to Right Kidney Pelvis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T144K4" = "1" /* Bypass Left Kidney Pelvis to Left Kidney Pelvis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T144K6" = "1" /* Bypass Left Kidney Pelvis to Right Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T144K7" = "1" /* Bypass Left Kidney Pelvis to Left Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T144K8" = "1" /* Bypass Left Kidney Pelvis to Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T144K9" = "1" /* Bypass Left Kidney Pelvis to Colocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T144KA" = "1" /* Bypass Left Kidney Pelvis to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T144KB" = "1" /* Bypass Left Kidney Pelvis to Bladder with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T144KC" = "1" /* Bypass Left Kidney Pelvis to Ileocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T144KD" = "1" /* Bypass Left Kidney Pelvis to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T144Z3" = "1" /* Bypass Left Kidney Pelvis to Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0T144Z4" = "1" /* Bypass Left Kidney Pelvis to Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0T144Z6" = "1" /* Bypass Left Kidney Pelvis to Right Ureter, Percutaneous Endoscopic Approach */
"0T144Z7" = "1" /* Bypass Left Kidney Pelvis to Left Ureter, Percutaneous Endoscopic Approach */
"0T144Z8" = "1" /* Bypass Left Kidney Pelvis to Colon, Percutaneous Endoscopic Approach */
"0T144Z9" = "1" /* Bypass Left Kidney Pelvis to Colocutaneous, Percutaneous Endoscopic Approach */
"0T144ZA" = "1" /* Bypass Left Kidney Pelvis to Ileum, Percutaneous Endoscopic Approach */
"0T144ZB" = "1" /* Bypass Left Kidney Pelvis to Bladder, Percutaneous Endoscopic Approach */
"0T144ZC" = "1" /* Bypass Left Kidney Pelvis to Ileocutaneous, Percutaneous Endoscopic Approach */
"0T144ZD" = "1" /* Bypass Left Kidney Pelvis to Cutaneous, Percutaneous Endoscopic Approach */
"0T16076" = "1" /* Bypass Right Ureter to Right Ureter with Autologous Tissue Substitute, Open Approach */
"0T16077" = "1" /* Bypass Right Ureter to Left Ureter with Autologous Tissue Substitute, Open Approach */
"0T16078" = "1" /* Bypass Right Ureter to Colon with Autologous Tissue Substitute, Open Approach */
"0T16079" = "1" /* Bypass Right Ureter to Colocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1607A" = "1" /* Bypass Right Ureter to Ileum with Autologous Tissue Substitute, Open Approach */
"0T1607B" = "1" /* Bypass Right Ureter to Bladder with Autologous Tissue Substitute, Open Approach */
"0T1607C" = "1" /* Bypass Right Ureter to Ileocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1607D" = "1" /* Bypass Right Ureter to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0T160J6" = "1" /* Bypass Right Ureter to Right Ureter with Synthetic Substitute, Open Approach */
"0T160J7" = "1" /* Bypass Right Ureter to Left Ureter with Synthetic Substitute, Open Approach */
"0T160J8" = "1" /* Bypass Right Ureter to Colon with Synthetic Substitute, Open Approach */
"0T160J9" = "1" /* Bypass Right Ureter to Colocutaneous with Synthetic Substitute, Open Approach */
"0T160JA" = "1" /* Bypass Right Ureter to Ileum with Synthetic Substitute, Open Approach */
"0T160JB" = "1" /* Bypass Right Ureter to Bladder with Synthetic Substitute, Open Approach */
"0T160JC" = "1" /* Bypass Right Ureter to Ileocutaneous with Synthetic Substitute, Open Approach */
"0T160JD" = "1" /* Bypass Right Ureter to Cutaneous with Synthetic Substitute, Open Approach */
"0T160K6" = "1" /* Bypass Right Ureter to Right Ureter with Nonautologous Tissue Substitute, Open Approach */
"0T160K7" = "1" /* Bypass Right Ureter to Left Ureter with Nonautologous Tissue Substitute, Open Approach */
"0T160K8" = "1" /* Bypass Right Ureter to Colon with Nonautologous Tissue Substitute, Open Approach */
"0T160K9" = "1" /* Bypass Right Ureter to Colocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T160KA" = "1" /* Bypass Right Ureter to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0T160KB" = "1" /* Bypass Right Ureter to Bladder with Nonautologous Tissue Substitute, Open Approach */
"0T160KC" = "1" /* Bypass Right Ureter to Ileocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T160KD" = "1" /* Bypass Right Ureter to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T160Z6" = "1" /* Bypass Right Ureter to Right Ureter, Open Approach */
"0T160Z7" = "1" /* Bypass Right Ureter to Left Ureter, Open Approach */
"0T160Z8" = "1" /* Bypass Right Ureter to Colon, Open Approach */
"0T160Z9" = "1" /* Bypass Right Ureter to Colocutaneous, Open Approach */
"0T160ZA" = "1" /* Bypass Right Ureter to Ileum, Open Approach */
"0T160ZB" = "1" /* Bypass Right Ureter to Bladder, Open Approach */
"0T160ZC" = "1" /* Bypass Right Ureter to Ileocutaneous, Open Approach */
"0T160ZD" = "1" /* Bypass Right Ureter to Cutaneous, Open Approach */
"0T163JD" = "1" /* Bypass Right Ureter to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0T16476" = "1" /* Bypass Right Ureter to Right Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T16477" = "1" /* Bypass Right Ureter to Left Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T16478" = "1" /* Bypass Right Ureter to Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T16479" = "1" /* Bypass Right Ureter to Colocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1647A" = "1" /* Bypass Right Ureter to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1647B" = "1" /* Bypass Right Ureter to Bladder with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1647C" = "1" /* Bypass Right Ureter to Ileocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1647D" = "1" /* Bypass Right Ureter to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T164J6" = "1" /* Bypass Right Ureter to Right Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T164J7" = "1" /* Bypass Right Ureter to Left Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T164J8" = "1" /* Bypass Right Ureter to Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T164J9" = "1" /* Bypass Right Ureter to Colocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T164JA" = "1" /* Bypass Right Ureter to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T164JB" = "1" /* Bypass Right Ureter to Bladder with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T164JC" = "1" /* Bypass Right Ureter to Ileocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T164JD" = "1" /* Bypass Right Ureter to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T164K6" = "1" /* Bypass Right Ureter to Right Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T164K7" = "1" /* Bypass Right Ureter to Left Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T164K8" = "1" /* Bypass Right Ureter to Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T164K9" = "1" /* Bypass Right Ureter to Colocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T164KA" = "1" /* Bypass Right Ureter to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T164KB" = "1" /* Bypass Right Ureter to Bladder with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T164KC" = "1" /* Bypass Right Ureter to Ileocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T164KD" = "1" /* Bypass Right Ureter to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T164Z6" = "1" /* Bypass Right Ureter to Right Ureter, Percutaneous Endoscopic Approach */
"0T164Z7" = "1" /* Bypass Right Ureter to Left Ureter, Percutaneous Endoscopic Approach */
"0T164Z8" = "1" /* Bypass Right Ureter to Colon, Percutaneous Endoscopic Approach */
"0T164Z9" = "1" /* Bypass Right Ureter to Colocutaneous, Percutaneous Endoscopic Approach */
"0T164ZA" = "1" /* Bypass Right Ureter to Ileum, Percutaneous Endoscopic Approach */
"0T164ZB" = "1" /* Bypass Right Ureter to Bladder, Percutaneous Endoscopic Approach */
"0T164ZC" = "1" /* Bypass Right Ureter to Ileocutaneous, Percutaneous Endoscopic Approach */
"0T164ZD" = "1" /* Bypass Right Ureter to Cutaneous, Percutaneous Endoscopic Approach */
"0T17076" = "1" /* Bypass Left Ureter to Right Ureter with Autologous Tissue Substitute, Open Approach */
"0T17077" = "1" /* Bypass Left Ureter to Left Ureter with Autologous Tissue Substitute, Open Approach */
"0T17078" = "1" /* Bypass Left Ureter to Colon with Autologous Tissue Substitute, Open Approach */
"0T17079" = "1" /* Bypass Left Ureter to Colocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1707A" = "1" /* Bypass Left Ureter to Ileum with Autologous Tissue Substitute, Open Approach */
"0T1707B" = "1" /* Bypass Left Ureter to Bladder with Autologous Tissue Substitute, Open Approach */
"0T1707C" = "1" /* Bypass Left Ureter to Ileocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1707D" = "1" /* Bypass Left Ureter to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0T170J6" = "1" /* Bypass Left Ureter to Right Ureter with Synthetic Substitute, Open Approach */
"0T170J7" = "1" /* Bypass Left Ureter to Left Ureter with Synthetic Substitute, Open Approach */
"0T170J8" = "1" /* Bypass Left Ureter to Colon with Synthetic Substitute, Open Approach */
"0T170J9" = "1" /* Bypass Left Ureter to Colocutaneous with Synthetic Substitute, Open Approach */
"0T170JA" = "1" /* Bypass Left Ureter to Ileum with Synthetic Substitute, Open Approach */
"0T170JB" = "1" /* Bypass Left Ureter to Bladder with Synthetic Substitute, Open Approach */
"0T170JC" = "1" /* Bypass Left Ureter to Ileocutaneous with Synthetic Substitute, Open Approach */
"0T170JD" = "1" /* Bypass Left Ureter to Cutaneous with Synthetic Substitute, Open Approach */
"0T170K6" = "1" /* Bypass Left Ureter to Right Ureter with Nonautologous Tissue Substitute, Open Approach */
"0T170K7" = "1" /* Bypass Left Ureter to Left Ureter with Nonautologous Tissue Substitute, Open Approach */
"0T170K8" = "1" /* Bypass Left Ureter to Colon with Nonautologous Tissue Substitute, Open Approach */
"0T170K9" = "1" /* Bypass Left Ureter to Colocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T170KA" = "1" /* Bypass Left Ureter to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0T170KB" = "1" /* Bypass Left Ureter to Bladder with Nonautologous Tissue Substitute, Open Approach */
"0T170KC" = "1" /* Bypass Left Ureter to Ileocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T170KD" = "1" /* Bypass Left Ureter to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T170Z6" = "1" /* Bypass Left Ureter to Right Ureter, Open Approach */
"0T170Z7" = "1" /* Bypass Left Ureter to Left Ureter, Open Approach */
"0T170Z8" = "1" /* Bypass Left Ureter to Colon, Open Approach */
"0T170Z9" = "1" /* Bypass Left Ureter to Colocutaneous, Open Approach */
"0T170ZA" = "1" /* Bypass Left Ureter to Ileum, Open Approach */
"0T170ZB" = "1" /* Bypass Left Ureter to Bladder, Open Approach */
"0T170ZC" = "1" /* Bypass Left Ureter to Ileocutaneous, Open Approach */
"0T170ZD" = "1" /* Bypass Left Ureter to Cutaneous, Open Approach */
"0T173JD" = "1" /* Bypass Left Ureter to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0T17476" = "1" /* Bypass Left Ureter to Right Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T17477" = "1" /* Bypass Left Ureter to Left Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T17478" = "1" /* Bypass Left Ureter to Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T17479" = "1" /* Bypass Left Ureter to Colocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1747A" = "1" /* Bypass Left Ureter to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1747B" = "1" /* Bypass Left Ureter to Bladder with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1747C" = "1" /* Bypass Left Ureter to Ileocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1747D" = "1" /* Bypass Left Ureter to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T174J6" = "1" /* Bypass Left Ureter to Right Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T174J7" = "1" /* Bypass Left Ureter to Left Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T174J8" = "1" /* Bypass Left Ureter to Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T174J9" = "1" /* Bypass Left Ureter to Colocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T174JA" = "1" /* Bypass Left Ureter to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T174JB" = "1" /* Bypass Left Ureter to Bladder with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T174JC" = "1" /* Bypass Left Ureter to Ileocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T174JD" = "1" /* Bypass Left Ureter to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T174K6" = "1" /* Bypass Left Ureter to Right Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T174K7" = "1" /* Bypass Left Ureter to Left Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T174K8" = "1" /* Bypass Left Ureter to Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T174K9" = "1" /* Bypass Left Ureter to Colocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T174KA" = "1" /* Bypass Left Ureter to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T174KB" = "1" /* Bypass Left Ureter to Bladder with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T174KC" = "1" /* Bypass Left Ureter to Ileocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T174KD" = "1" /* Bypass Left Ureter to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T174Z6" = "1" /* Bypass Left Ureter to Right Ureter, Percutaneous Endoscopic Approach */
"0T174Z7" = "1" /* Bypass Left Ureter to Left Ureter, Percutaneous Endoscopic Approach */
"0T174Z8" = "1" /* Bypass Left Ureter to Colon, Percutaneous Endoscopic Approach */
"0T174Z9" = "1" /* Bypass Left Ureter to Colocutaneous, Percutaneous Endoscopic Approach */
"0T174ZA" = "1" /* Bypass Left Ureter to Ileum, Percutaneous Endoscopic Approach */
"0T174ZB" = "1" /* Bypass Left Ureter to Bladder, Percutaneous Endoscopic Approach */
"0T174ZC" = "1" /* Bypass Left Ureter to Ileocutaneous, Percutaneous Endoscopic Approach */
"0T174ZD" = "1" /* Bypass Left Ureter to Cutaneous, Percutaneous Endoscopic Approach */
"0T18076" = "1" /* Bypass Bilateral Ureters to Right Ureter with Autologous Tissue Substitute, Open Approach */
"0T18077" = "1" /* Bypass Bilateral Ureters to Left Ureter with Autologous Tissue Substitute, Open Approach */
"0T18078" = "1" /* Bypass Bilateral Ureters to Colon with Autologous Tissue Substitute, Open Approach */
"0T18079" = "1" /* Bypass Bilateral Ureters to Colocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1807A" = "1" /* Bypass Bilateral Ureters to Ileum with Autologous Tissue Substitute, Open Approach */
"0T1807B" = "1" /* Bypass Bilateral Ureters to Bladder with Autologous Tissue Substitute, Open Approach */
"0T1807C" = "1" /* Bypass Bilateral Ureters to Ileocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1807D" = "1" /* Bypass Bilateral Ureters to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0T180J6" = "1" /* Bypass Bilateral Ureters to Right Ureter with Synthetic Substitute, Open Approach */
"0T180J7" = "1" /* Bypass Bilateral Ureters to Left Ureter with Synthetic Substitute, Open Approach */
"0T180J8" = "1" /* Bypass Bilateral Ureters to Colon with Synthetic Substitute, Open Approach */
"0T180J9" = "1" /* Bypass Bilateral Ureters to Colocutaneous with Synthetic Substitute, Open Approach */
"0T180JA" = "1" /* Bypass Bilateral Ureters to Ileum with Synthetic Substitute, Open Approach */
"0T180JB" = "1" /* Bypass Bilateral Ureters to Bladder with Synthetic Substitute, Open Approach */
"0T180JC" = "1" /* Bypass Bilateral Ureters to Ileocutaneous with Synthetic Substitute, Open Approach */
"0T180JD" = "1" /* Bypass Bilateral Ureters to Cutaneous with Synthetic Substitute, Open Approach */
"0T180K6" = "1" /* Bypass Bilateral Ureters to Right Ureter with Nonautologous Tissue Substitute, Open Approach */
"0T180K7" = "1" /* Bypass Bilateral Ureters to Left Ureter with Nonautologous Tissue Substitute, Open Approach */
"0T180K8" = "1" /* Bypass Bilateral Ureters to Colon with Nonautologous Tissue Substitute, Open Approach */
"0T180K9" = "1" /* Bypass Bilateral Ureters to Colocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T180KA" = "1" /* Bypass Bilateral Ureters to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0T180KB" = "1" /* Bypass Bilateral Ureters to Bladder with Nonautologous Tissue Substitute, Open Approach */
"0T180KC" = "1" /* Bypass Bilateral Ureters to Ileocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T180KD" = "1" /* Bypass Bilateral Ureters to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T180Z6" = "1" /* Bypass Bilateral Ureters to Right Ureter, Open Approach */
"0T180Z7" = "1" /* Bypass Bilateral Ureters to Left Ureter, Open Approach */
"0T180Z8" = "1" /* Bypass Bilateral Ureters to Colon, Open Approach */
"0T180Z9" = "1" /* Bypass Bilateral Ureters to Colocutaneous, Open Approach */
"0T180ZA" = "1" /* Bypass Bilateral Ureters to Ileum, Open Approach */
"0T180ZB" = "1" /* Bypass Bilateral Ureters to Bladder, Open Approach */
"0T180ZC" = "1" /* Bypass Bilateral Ureters to Ileocutaneous, Open Approach */
"0T180ZD" = "1" /* Bypass Bilateral Ureters to Cutaneous, Open Approach */
"0T183JD" = "1" /* Bypass Bilateral Ureters to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0T18476" = "1" /* Bypass Bilateral Ureters to Right Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T18477" = "1" /* Bypass Bilateral Ureters to Left Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T18478" = "1" /* Bypass Bilateral Ureters to Colon with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T18479" = "1" /* Bypass Bilateral Ureters to Colocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1847A" = "1" /* Bypass Bilateral Ureters to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1847B" = "1" /* Bypass Bilateral Ureters to Bladder with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1847C" = "1" /* Bypass Bilateral Ureters to Ileocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1847D" = "1" /* Bypass Bilateral Ureters to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T184J6" = "1" /* Bypass Bilateral Ureters to Right Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T184J7" = "1" /* Bypass Bilateral Ureters to Left Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T184J8" = "1" /* Bypass Bilateral Ureters to Colon with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T184J9" = "1" /* Bypass Bilateral Ureters to Colocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T184JA" = "1" /* Bypass Bilateral Ureters to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T184JB" = "1" /* Bypass Bilateral Ureters to Bladder with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T184JC" = "1" /* Bypass Bilateral Ureters to Ileocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T184JD" = "1" /* Bypass Bilateral Ureters to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T184K6" = "1" /* Bypass Bilateral Ureters to Right Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T184K7" = "1" /* Bypass Bilateral Ureters to Left Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T184K8" = "1" /* Bypass Bilateral Ureters to Colon with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T184K9" = "1" /* Bypass Bilateral Ureters to Colocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T184KA" = "1" /* Bypass Bilateral Ureters to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T184KB" = "1" /* Bypass Bilateral Ureters to Bladder with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T184KC" = "1" /* Bypass Bilateral Ureters to Ileocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T184KD" = "1" /* Bypass Bilateral Ureters to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T184Z6" = "1" /* Bypass Bilateral Ureters to Right Ureter, Percutaneous Endoscopic Approach */
"0T184Z7" = "1" /* Bypass Bilateral Ureters to Left Ureter, Percutaneous Endoscopic Approach */
"0T184Z8" = "1" /* Bypass Bilateral Ureters to Colon, Percutaneous Endoscopic Approach */
"0T184Z9" = "1" /* Bypass Bilateral Ureters to Colocutaneous, Percutaneous Endoscopic Approach */
"0T184ZA" = "1" /* Bypass Bilateral Ureters to Ileum, Percutaneous Endoscopic Approach */
"0T184ZB" = "1" /* Bypass Bilateral Ureters to Bladder, Percutaneous Endoscopic Approach */
"0T184ZC" = "1" /* Bypass Bilateral Ureters to Ileocutaneous, Percutaneous Endoscopic Approach */
"0T184ZD" = "1" /* Bypass Bilateral Ureters to Cutaneous, Percutaneous Endoscopic Approach */
"0T1B079" = "1" /* Bypass Bladder to Colocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1B07C" = "1" /* Bypass Bladder to Ileocutaneous with Autologous Tissue Substitute, Open Approach */
"0T1B07D" = "1" /* Bypass Bladder to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0T1B0J9" = "1" /* Bypass Bladder to Colocutaneous with Synthetic Substitute, Open Approach */
"0T1B0JC" = "1" /* Bypass Bladder to Ileocutaneous with Synthetic Substitute, Open Approach */
"0T1B0JD" = "1" /* Bypass Bladder to Cutaneous with Synthetic Substitute, Open Approach */
"0T1B0K9" = "1" /* Bypass Bladder to Colocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T1B0KC" = "1" /* Bypass Bladder to Ileocutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T1B0KD" = "1" /* Bypass Bladder to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0T1B0Z9" = "1" /* Bypass Bladder to Colocutaneous, Open Approach */
"0T1B0ZC" = "1" /* Bypass Bladder to Ileocutaneous, Open Approach */
"0T1B0ZD" = "1" /* Bypass Bladder to Cutaneous, Open Approach */
"0T1B3JD" = "1" /* Bypass Bladder to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0T1B479" = "1" /* Bypass Bladder to Colocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1B47C" = "1" /* Bypass Bladder to Ileocutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1B47D" = "1" /* Bypass Bladder to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1B4J9" = "1" /* Bypass Bladder to Colocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T1B4JC" = "1" /* Bypass Bladder to Ileocutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T1B4JD" = "1" /* Bypass Bladder to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0T1B4K9" = "1" /* Bypass Bladder to Colocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1B4KC" = "1" /* Bypass Bladder to Ileocutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1B4KD" = "1" /* Bypass Bladder to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0T1B4Z9" = "1" /* Bypass Bladder to Colocutaneous, Percutaneous Endoscopic Approach */
"0T1B4ZC" = "1" /* Bypass Bladder to Ileocutaneous, Percutaneous Endoscopic Approach */
"0T1B4ZD" = "1" /* Bypass Bladder to Cutaneous, Percutaneous Endoscopic Approach */
"0T500ZZ" = "1" /* Destruction of Right Kidney, Open Approach */
"0T503ZZ" = "1" /* Destruction of Right Kidney, Percutaneous Approach */
"0T504ZZ" = "1" /* Destruction of Right Kidney, Percutaneous Endoscopic Approach */
"0T507ZZ" = "1" /* Destruction of Right Kidney, Via Natural or Artificial Opening */
"0T508ZZ" = "1" /* Destruction of Right Kidney, Via Natural or Artificial Opening Endoscopic */
"0T510ZZ" = "1" /* Destruction of Left Kidney, Open Approach */
"0T513ZZ" = "1" /* Destruction of Left Kidney, Percutaneous Approach */
"0T514ZZ" = "1" /* Destruction of Left Kidney, Percutaneous Endoscopic Approach */
"0T517ZZ" = "1" /* Destruction of Left Kidney, Via Natural or Artificial Opening */
"0T518ZZ" = "1" /* Destruction of Left Kidney, Via Natural or Artificial Opening Endoscopic */
"0T530ZZ" = "1" /* Destruction of Right Kidney Pelvis, Open Approach */
"0T533ZZ" = "1" /* Destruction of Right Kidney Pelvis, Percutaneous Approach */
"0T534ZZ" = "1" /* Destruction of Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0T537ZZ" = "1" /* Destruction of Right Kidney Pelvis, Via Natural or Artificial Opening */
"0T538ZZ" = "1" /* Destruction of Right Kidney Pelvis, Via Natural or Artificial Opening Endoscopic */
"0T540ZZ" = "1" /* Destruction of Left Kidney Pelvis, Open Approach */
"0T543ZZ" = "1" /* Destruction of Left Kidney Pelvis, Percutaneous Approach */
"0T544ZZ" = "1" /* Destruction of Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0T547ZZ" = "1" /* Destruction of Left Kidney Pelvis, Via Natural or Artificial Opening */
"0T548ZZ" = "1" /* Destruction of Left Kidney Pelvis, Via Natural or Artificial Opening Endoscopic */
"0T560ZZ" = "1" /* Destruction of Right Ureter, Open Approach */
"0T563ZZ" = "1" /* Destruction of Right Ureter, Percutaneous Approach */
"0T564ZZ" = "1" /* Destruction of Right Ureter, Percutaneous Endoscopic Approach */
"0T567ZZ" = "1" /* Destruction of Right Ureter, Via Natural or Artificial Opening */
"0T568ZZ" = "1" /* Destruction of Right Ureter, Via Natural or Artificial Opening Endoscopic */
"0T570ZZ" = "1" /* Destruction of Left Ureter, Open Approach */
"0T573ZZ" = "1" /* Destruction of Left Ureter, Percutaneous Approach */
"0T574ZZ" = "1" /* Destruction of Left Ureter, Percutaneous Endoscopic Approach */
"0T577ZZ" = "1" /* Destruction of Left Ureter, Via Natural or Artificial Opening */
"0T578ZZ" = "1" /* Destruction of Left Ureter, Via Natural or Artificial Opening Endoscopic */
"0T5B0ZZ" = "1" /* Destruction of Bladder, Open Approach */
"0T5B3ZZ" = "1" /* Destruction of Bladder, Percutaneous Approach */
"0T5B4ZZ" = "1" /* Destruction of Bladder, Percutaneous Endoscopic Approach */
"0T5B7ZZ" = "1" /* Destruction of Bladder, Via Natural or Artificial Opening */
"0T5B8ZZ" = "1" /* Destruction of Bladder, Via Natural or Artificial Opening Endoscopic */
"0T5C0ZZ" = "1" /* Destruction of Bladder Neck, Open Approach */
"0T5C3ZZ" = "1" /* Destruction of Bladder Neck, Percutaneous Approach */
"0T5C4ZZ" = "1" /* Destruction of Bladder Neck, Percutaneous Endoscopic Approach */
"0T5C7ZZ" = "1" /* Destruction of Bladder Neck, Via Natural or Artificial Opening */
"0T5C8ZZ" = "1" /* Destruction of Bladder Neck, Via Natural or Artificial Opening Endoscopic */
"0T730DZ" = "1" /* Dilation of Right Kidney Pelvis with Intraluminal Device, Open Approach */
"0T730ZZ" = "1" /* Dilation of Right Kidney Pelvis, Open Approach */
"0T733DZ" = "1" /* Dilation of Right Kidney Pelvis with Intraluminal Device, Percutaneous Approach */
"0T733ZZ" = "1" /* Dilation of Right Kidney Pelvis, Percutaneous Approach */
"0T734DZ" = "1" /* Dilation of Right Kidney Pelvis with Intraluminal Device, Percutaneous Endoscopic Approach */
"0T734ZZ" = "1" /* Dilation of Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0T737DZ" = "1" /* Dilation of Right Kidney Pelvis with Intraluminal Device, Via Natural or Artificial Opening */
"0T737ZZ" = "1" /* Dilation of Right Kidney Pelvis, Via Natural or Artificial Opening */
"0T738DZ" = "1" /* Dilation of Right Kidney Pelvis with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0T738ZZ" = "1" /* Dilation of Right Kidney Pelvis, Via Natural or Artificial Opening Endoscopic */
"0T740DZ" = "1" /* Dilation of Left Kidney Pelvis with Intraluminal Device, Open Approach */
"0T740ZZ" = "1" /* Dilation of Left Kidney Pelvis, Open Approach */
"0T743DZ" = "1" /* Dilation of Left Kidney Pelvis with Intraluminal Device, Percutaneous Approach */
"0T743ZZ" = "1" /* Dilation of Left Kidney Pelvis, Percutaneous Approach */
"0T744DZ" = "1" /* Dilation of Left Kidney Pelvis with Intraluminal Device, Percutaneous Endoscopic Approach */
"0T744ZZ" = "1" /* Dilation of Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0T747DZ" = "1" /* Dilation of Left Kidney Pelvis with Intraluminal Device, Via Natural or Artificial Opening */
"0T747ZZ" = "1" /* Dilation of Left Kidney Pelvis, Via Natural or Artificial Opening */
"0T748DZ" = "1" /* Dilation of Left Kidney Pelvis with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0T748ZZ" = "1" /* Dilation of Left Kidney Pelvis, Via Natural or Artificial Opening Endoscopic */
"0T760ZZ" = "1" /* Dilation of Right Ureter, Open Approach */
"0T763ZZ" = "1" /* Dilation of Right Ureter, Percutaneous Approach */
"0T764ZZ" = "1" /* Dilation of Right Ureter, Percutaneous Endoscopic Approach */
"0T770ZZ" = "1" /* Dilation of Left Ureter, Open Approach */
"0T773ZZ" = "1" /* Dilation of Left Ureter, Percutaneous Approach */
"0T774ZZ" = "1" /* Dilation of Left Ureter, Percutaneous Endoscopic Approach */
"0T780ZZ" = "1" /* Dilation of Bilateral Ureters, Open Approach */
"0T783ZZ" = "1" /* Dilation of Bilateral Ureters, Percutaneous Approach */
"0T784ZZ" = "1" /* Dilation of Bilateral Ureters, Percutaneous Endoscopic Approach */
"0T7B0DZ" = "1" /* Dilation of Bladder with Intraluminal Device, Open Approach */
"0T7B0ZZ" = "1" /* Dilation of Bladder, Open Approach */
"0T7B3DZ" = "1" /* Dilation of Bladder with Intraluminal Device, Percutaneous Approach */
"0T7B3ZZ" = "1" /* Dilation of Bladder, Percutaneous Approach */
"0T7B4DZ" = "1" /* Dilation of Bladder with Intraluminal Device, Percutaneous Endoscopic Approach */
"0T7B4ZZ" = "1" /* Dilation of Bladder, Percutaneous Endoscopic Approach */
"0T7D0ZZ" = "1" /* Dilation of Urethra, Open Approach */
"0T7D3ZZ" = "1" /* Dilation of Urethra, Percutaneous Approach */
"0T7D4ZZ" = "1" /* Dilation of Urethra, Percutaneous Endoscopic Approach */
"0T820ZZ" = "1" /* Division of Bilateral Kidneys, Open Approach */
"0T823ZZ" = "1" /* Division of Bilateral Kidneys, Percutaneous Approach */
"0T824ZZ" = "1" /* Division of Bilateral Kidneys, Percutaneous Endoscopic Approach */
"0T8C0ZZ" = "1" /* Division of Bladder Neck, Open Approach */
"0T8C3ZZ" = "1" /* Division of Bladder Neck, Percutaneous Approach */
"0T8C4ZZ" = "1" /* Division of Bladder Neck, Percutaneous Endoscopic Approach */
"0T9000Z" = "1" /* Drainage of Right Kidney with Drainage Device, Open Approach */
"0T900ZX" = "1" /* Drainage of Right Kidney, Open Approach, Diagnostic */
"0T900ZZ" = "1" /* Drainage of Right Kidney, Open Approach */
"0T9040Z" = "1" /* Drainage of Right Kidney with Drainage Device, Percutaneous Endoscopic Approach */
"0T9070Z" = "1" /* Drainage of Right Kidney with Drainage Device, Via Natural or Artificial Opening */
"0T907ZZ" = "1" /* Drainage of Right Kidney, Via Natural or Artificial Opening */
"0T9080Z" = "1" /* Drainage of Right Kidney with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0T908ZZ" = "1" /* Drainage of Right Kidney, Via Natural or Artificial Opening Endoscopic */
"0T9100Z" = "1" /* Drainage of Left Kidney with Drainage Device, Open Approach */
"0T910ZX" = "1" /* Drainage of Left Kidney, Open Approach, Diagnostic */
"0T910ZZ" = "1" /* Drainage of Left Kidney, Open Approach */
"0T9140Z" = "1" /* Drainage of Left Kidney with Drainage Device, Percutaneous Endoscopic Approach */
"0T9170Z" = "1" /* Drainage of Left Kidney with Drainage Device, Via Natural or Artificial Opening */
"0T917ZZ" = "1" /* Drainage of Left Kidney, Via Natural or Artificial Opening */
"0T9180Z" = "1" /* Drainage of Left Kidney with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0T918ZZ" = "1" /* Drainage of Left Kidney, Via Natural or Artificial Opening Endoscopic */
"0T9300Z" = "1" /* Drainage of Right Kidney Pelvis with Drainage Device, Open Approach */
"0T930ZX" = "1" /* Drainage of Right Kidney Pelvis, Open Approach, Diagnostic */
"0T930ZZ" = "1" /* Drainage of Right Kidney Pelvis, Open Approach */
"0T9340Z" = "1" /* Drainage of Right Kidney Pelvis with Drainage Device, Percutaneous Endoscopic Approach */
"0T9370Z" = "1" /* Drainage of Right Kidney Pelvis with Drainage Device, Via Natural or Artificial Opening */
"0T937ZZ" = "1" /* Drainage of Right Kidney Pelvis, Via Natural or Artificial Opening */
"0T9380Z" = "1" /* Drainage of Right Kidney Pelvis with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0T938ZZ" = "1" /* Drainage of Right Kidney Pelvis, Via Natural or Artificial Opening Endoscopic */
"0T9400Z" = "1" /* Drainage of Left Kidney Pelvis with Drainage Device, Open Approach */
"0T940ZX" = "1" /* Drainage of Left Kidney Pelvis, Open Approach, Diagnostic */
"0T940ZZ" = "1" /* Drainage of Left Kidney Pelvis, Open Approach */
"0T9440Z" = "1" /* Drainage of Left Kidney Pelvis with Drainage Device, Percutaneous Endoscopic Approach */
"0T9470Z" = "1" /* Drainage of Left Kidney Pelvis with Drainage Device, Via Natural or Artificial Opening */
"0T947ZZ" = "1" /* Drainage of Left Kidney Pelvis, Via Natural or Artificial Opening */
"0T9480Z" = "1" /* Drainage of Left Kidney Pelvis with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0T948ZZ" = "1" /* Drainage of Left Kidney Pelvis, Via Natural or Artificial Opening Endoscopic */
"0T960ZX" = "1" /* Drainage of Right Ureter, Open Approach, Diagnostic */
"0T960ZZ" = "1" /* Drainage of Right Ureter, Open Approach */
"0T964ZZ" = "1" /* Drainage of Right Ureter, Percutaneous Endoscopic Approach */
"0T967ZZ" = "1" /* Drainage of Right Ureter, Via Natural or Artificial Opening */
"0T968ZZ" = "1" /* Drainage of Right Ureter, Via Natural or Artificial Opening Endoscopic */
"0T970ZX" = "1" /* Drainage of Left Ureter, Open Approach, Diagnostic */
"0T970ZZ" = "1" /* Drainage of Left Ureter, Open Approach */
"0T974ZZ" = "1" /* Drainage of Left Ureter, Percutaneous Endoscopic Approach */
"0T977ZZ" = "1" /* Drainage of Left Ureter, Via Natural or Artificial Opening */
"0T978ZZ" = "1" /* Drainage of Left Ureter, Via Natural or Artificial Opening Endoscopic */
"0T980ZX" = "1" /* Drainage of Bilateral Ureters, Open Approach, Diagnostic */
"0T980ZZ" = "1" /* Drainage of Bilateral Ureters, Open Approach */
"0T984ZZ" = "1" /* Drainage of Bilateral Ureters, Percutaneous Endoscopic Approach */
"0T987ZZ" = "1" /* Drainage of Bilateral Ureters, Via Natural or Artificial Opening */
"0T988ZZ" = "1" /* Drainage of Bilateral Ureters, Via Natural or Artificial Opening Endoscopic */
"0T9B00Z" = "1" /* Drainage of Bladder with Drainage Device, Open Approach */
"0T9B0ZX" = "1" /* Drainage of Bladder, Open Approach, Diagnostic */
"0T9B0ZZ" = "1" /* Drainage of Bladder, Open Approach */
"0T9B4ZX" = "1" /* Drainage of Bladder, Percutaneous Endoscopic Approach, Diagnostic */
"0T9B7ZX" = "1" /* Drainage of Bladder, Via Natural or Artificial Opening, Diagnostic */
"0T9B8ZX" = "1" /* Drainage of Bladder, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0T9C00Z" = "1" /* Drainage of Bladder Neck with Drainage Device, Open Approach */
"0T9C0ZX" = "1" /* Drainage of Bladder Neck, Open Approach, Diagnostic */
"0T9C0ZZ" = "1" /* Drainage of Bladder Neck, Open Approach */
"0T9C4ZX" = "1" /* Drainage of Bladder Neck, Percutaneous Endoscopic Approach, Diagnostic */
"0T9C7ZX" = "1" /* Drainage of Bladder Neck, Via Natural or Artificial Opening, Diagnostic */
"0T9C8ZX" = "1" /* Drainage of Bladder Neck, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0T9D00Z" = "1" /* Drainage of Urethra with Drainage Device, Open Approach */
"0T9D0ZZ" = "1" /* Drainage of Urethra, Open Approach */
"0T9D40Z" = "1" /* Drainage of Urethra with Drainage Device, Percutaneous Endoscopic Approach */
"0T9D4ZZ" = "1" /* Drainage of Urethra, Percutaneous Endoscopic Approach */
"0T9D70Z" = "1" /* Drainage of Urethra with Drainage Device, Via Natural or Artificial Opening */
"0T9D7ZZ" = "1" /* Drainage of Urethra, Via Natural or Artificial Opening */
"0T9D80Z" = "1" /* Drainage of Urethra with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0T9D8ZZ" = "1" /* Drainage of Urethra, Via Natural or Artificial Opening Endoscopic */
"0T9DX0Z" = "1" /* Drainage of Urethra with Drainage Device, External Approach */
"0T9DXZZ" = "1" /* Drainage of Urethra, External Approach */
"0TB00ZX" = "1" /* Excision of Right Kidney, Open Approach, Diagnostic */
"0TB00ZZ" = "1" /* Excision of Right Kidney, Open Approach */
"0TB03ZZ" = "1" /* Excision of Right Kidney, Percutaneous Approach */
"0TB04ZZ" = "1" /* Excision of Right Kidney, Percutaneous Endoscopic Approach */
"0TB07ZZ" = "1" /* Excision of Right Kidney, Via Natural or Artificial Opening */
"0TB08ZZ" = "1" /* Excision of Right Kidney, Via Natural or Artificial Opening Endoscopic */
"0TB10ZX" = "1" /* Excision of Left Kidney, Open Approach, Diagnostic */
"0TB10ZZ" = "1" /* Excision of Left Kidney, Open Approach */
"0TB13ZZ" = "1" /* Excision of Left Kidney, Percutaneous Approach */
"0TB14ZZ" = "1" /* Excision of Left Kidney, Percutaneous Endoscopic Approach */
"0TB17ZZ" = "1" /* Excision of Left Kidney, Via Natural or Artificial Opening */
"0TB18ZZ" = "1" /* Excision of Left Kidney, Via Natural or Artificial Opening Endoscopic */
"0TB30ZX" = "1" /* Excision of Right Kidney Pelvis, Open Approach, Diagnostic */
"0TB30ZZ" = "1" /* Excision of Right Kidney Pelvis, Open Approach */
"0TB33ZZ" = "1" /* Excision of Right Kidney Pelvis, Percutaneous Approach */
"0TB34ZZ" = "1" /* Excision of Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TB37ZZ" = "1" /* Excision of Right Kidney Pelvis, Via Natural or Artificial Opening */
"0TB38ZZ" = "1" /* Excision of Right Kidney Pelvis, Via Natural or Artificial Opening Endoscopic */
"0TB40ZX" = "1" /* Excision of Left Kidney Pelvis, Open Approach, Diagnostic */
"0TB40ZZ" = "1" /* Excision of Left Kidney Pelvis, Open Approach */
"0TB43ZZ" = "1" /* Excision of Left Kidney Pelvis, Percutaneous Approach */
"0TB44ZZ" = "1" /* Excision of Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TB47ZZ" = "1" /* Excision of Left Kidney Pelvis, Via Natural or Artificial Opening */
"0TB48ZZ" = "1" /* Excision of Left Kidney Pelvis, Via Natural or Artificial Opening Endoscopic */
"0TB60ZX" = "1" /* Excision of Right Ureter, Open Approach, Diagnostic */
"0TB60ZZ" = "1" /* Excision of Right Ureter, Open Approach */
"0TB63ZZ" = "1" /* Excision of Right Ureter, Percutaneous Approach */
"0TB64ZZ" = "1" /* Excision of Right Ureter, Percutaneous Endoscopic Approach */
"0TB67ZZ" = "1" /* Excision of Right Ureter, Via Natural or Artificial Opening */
"0TB68ZZ" = "1" /* Excision of Right Ureter, Via Natural or Artificial Opening Endoscopic */
"0TB70ZX" = "1" /* Excision of Left Ureter, Open Approach, Diagnostic */
"0TB70ZZ" = "1" /* Excision of Left Ureter, Open Approach */
"0TB73ZZ" = "1" /* Excision of Left Ureter, Percutaneous Approach */
"0TB74ZZ" = "1" /* Excision of Left Ureter, Percutaneous Endoscopic Approach */
"0TB77ZZ" = "1" /* Excision of Left Ureter, Via Natural or Artificial Opening */
"0TB78ZZ" = "1" /* Excision of Left Ureter, Via Natural or Artificial Opening Endoscopic */
"0TBB0ZX" = "1" /* Excision of Bladder, Open Approach, Diagnostic */
"0TBB0ZZ" = "1" /* Excision of Bladder, Open Approach */
"0TBB3ZX" = "1" /* Excision of Bladder, Percutaneous Approach, Diagnostic */
"0TBB3ZZ" = "1" /* Excision of Bladder, Percutaneous Approach */
"0TBB4ZX" = "1" /* Excision of Bladder, Percutaneous Endoscopic Approach, Diagnostic */
"0TBB4ZZ" = "1" /* Excision of Bladder, Percutaneous Endoscopic Approach */
"0TBB7ZX" = "1" /* Excision of Bladder, Via Natural or Artificial Opening, Diagnostic */
"0TBB7ZZ" = "1" /* Excision of Bladder, Via Natural or Artificial Opening */
"0TBB8ZX" = "1" /* Excision of Bladder, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0TBB8ZZ" = "1" /* Excision of Bladder, Via Natural or Artificial Opening Endoscopic */
"0TBC0ZX" = "1" /* Excision of Bladder Neck, Open Approach, Diagnostic */
"0TBC0ZZ" = "1" /* Excision of Bladder Neck, Open Approach */
"0TBC3ZX" = "1" /* Excision of Bladder Neck, Percutaneous Approach, Diagnostic */
"0TBC3ZZ" = "1" /* Excision of Bladder Neck, Percutaneous Approach */
"0TBC4ZX" = "1" /* Excision of Bladder Neck, Percutaneous Endoscopic Approach, Diagnostic */
"0TBC4ZZ" = "1" /* Excision of Bladder Neck, Percutaneous Endoscopic Approach */
"0TBC7ZX" = "1" /* Excision of Bladder Neck, Via Natural or Artificial Opening, Diagnostic */
"0TBC7ZZ" = "1" /* Excision of Bladder Neck, Via Natural or Artificial Opening */
"0TBC8ZX" = "1" /* Excision of Bladder Neck, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0TBC8ZZ" = "1" /* Excision of Bladder Neck, Via Natural or Artificial Opening Endoscopic */
"0TBD0ZZ" = "1" /* Excision of Urethra, Open Approach */
"0TBD3ZZ" = "1" /* Excision of Urethra, Percutaneous Approach */
"0TBD4ZZ" = "1" /* Excision of Urethra, Percutaneous Endoscopic Approach */
"0TC00ZZ" = "1" /* Extirpation of Matter from Right Kidney, Open Approach */
"0TC03ZZ" = "1" /* Extirpation of Matter from Right Kidney, Percutaneous Approach */
"0TC04ZZ" = "1" /* Extirpation of Matter from Right Kidney, Percutaneous Endoscopic Approach */
"0TC07ZZ" = "1" /* Extirpation of Matter from Right Kidney, Via Natural or Artificial Opening */
"0TC08ZZ" = "1" /* Extirpation of Matter from Right Kidney, Via Natural or Artificial Opening Endoscopic */
"0TC10ZZ" = "1" /* Extirpation of Matter from Left Kidney, Open Approach */
"0TC13ZZ" = "1" /* Extirpation of Matter from Left Kidney, Percutaneous Approach */
"0TC14ZZ" = "1" /* Extirpation of Matter from Left Kidney, Percutaneous Endoscopic Approach */
"0TC17ZZ" = "1" /* Extirpation of Matter from Left Kidney, Via Natural or Artificial Opening */
"0TC18ZZ" = "1" /* Extirpation of Matter from Left Kidney, Via Natural or Artificial Opening Endoscopic */
"0TC30ZZ" = "1" /* Extirpation of Matter from Right Kidney Pelvis, Open Approach */
"0TC33ZZ" = "1" /* Extirpation of Matter from Right Kidney Pelvis, Percutaneous Approach */
"0TC34ZZ" = "1" /* Extirpation of Matter from Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TC37ZZ" = "1" /* Extirpation of Matter from Right Kidney Pelvis, Via Natural or Artificial Opening */
"0TC38ZZ" = "1" /* Extirpation of Matter from Right Kidney Pelvis, Via Natural or Artificial Opening Endoscopic */
"0TC40ZZ" = "1" /* Extirpation of Matter from Left Kidney Pelvis, Open Approach */
"0TC43ZZ" = "1" /* Extirpation of Matter from Left Kidney Pelvis, Percutaneous Approach */
"0TC44ZZ" = "1" /* Extirpation of Matter from Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TC47ZZ" = "1" /* Extirpation of Matter from Left Kidney Pelvis, Via Natural or Artificial Opening */
"0TC48ZZ" = "1" /* Extirpation of Matter from Left Kidney Pelvis, Via Natural or Artificial Opening Endoscopic */
"0TC60ZZ" = "1" /* Extirpation of Matter from Right Ureter, Open Approach */
"0TC63ZZ" = "1" /* Extirpation of Matter from Right Ureter, Percutaneous Approach */
"0TC64ZZ" = "1" /* Extirpation of Matter from Right Ureter, Percutaneous Endoscopic Approach */
"0TC67ZZ" = "1" /* Extirpation of Matter from Right Ureter, Via Natural or Artificial Opening */
"0TC68ZZ" = "1" /* Extirpation of Matter from Right Ureter, Via Natural or Artificial Opening Endoscopic */
"0TC70ZZ" = "1" /* Extirpation of Matter from Left Ureter, Open Approach */
"0TC73ZZ" = "1" /* Extirpation of Matter from Left Ureter, Percutaneous Approach */
"0TC74ZZ" = "1" /* Extirpation of Matter from Left Ureter, Percutaneous Endoscopic Approach */
"0TC77ZZ" = "1" /* Extirpation of Matter from Left Ureter, Via Natural or Artificial Opening */
"0TC78ZZ" = "1" /* Extirpation of Matter from Left Ureter, Via Natural or Artificial Opening Endoscopic */
"0TCB0ZZ" = "1" /* Extirpation of Matter from Bladder, Open Approach */
"0TCB3ZZ" = "1" /* Extirpation of Matter from Bladder, Percutaneous Approach */
"0TCB4ZZ" = "1" /* Extirpation of Matter from Bladder, Percutaneous Endoscopic Approach */
"0TCC0ZZ" = "1" /* Extirpation of Matter from Bladder Neck, Open Approach */
"0TCC3ZZ" = "1" /* Extirpation of Matter from Bladder Neck, Percutaneous Approach */
"0TCC4ZZ" = "1" /* Extirpation of Matter from Bladder Neck, Percutaneous Endoscopic Approach */
"0TCD0ZZ" = "1" /* Extirpation of Matter from Urethra, Open Approach */
"0TCD3ZZ" = "1" /* Extirpation of Matter from Urethra, Percutaneous Approach */
"0TCD4ZZ" = "1" /* Extirpation of Matter from Urethra, Percutaneous Endoscopic Approach */
"0TD00ZZ" = "1" /* Extraction of Right Kidney, Open Approach */
"0TD03ZZ" = "1" /* Extraction of Right Kidney, Percutaneous Approach */
"0TD04ZZ" = "1" /* Extraction of Right Kidney, Percutaneous Endoscopic Approach */
"0TD10ZZ" = "1" /* Extraction of Left Kidney, Open Approach */
"0TD13ZZ" = "1" /* Extraction of Left Kidney, Percutaneous Approach */
"0TD14ZZ" = "1" /* Extraction of Left Kidney, Percutaneous Endoscopic Approach */
"0TF33ZZ" = "1" /* Fragmentation in Right Kidney Pelvis, Percutaneous Approach */
"0TF34ZZ" = "1" /* Fragmentation in Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TF43ZZ" = "1" /* Fragmentation in Left Kidney Pelvis, Percutaneous Approach */
"0TF44ZZ" = "1" /* Fragmentation in Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TH502Z" = "1" /* Insertion of Monitoring Device into Kidney, Open Approach */
"0TH532Z" = "1" /* Insertion of Monitoring Device into Kidney, Percutaneous Approach */
"0TH542Z" = "1" /* Insertion of Monitoring Device into Kidney, Percutaneous Endoscopic Approach */
"0TH902Z" = "1" /* Insertion of Monitoring Device into Ureter, Open Approach */
"0TH90MZ" = "1" /* Insertion of Stimulator Lead into Ureter, Open Approach */
"0TH932Z" = "1" /* Insertion of Monitoring Device into Ureter, Percutaneous Approach */
"0TH93MZ" = "1" /* Insertion of Stimulator Lead into Ureter, Percutaneous Approach */
"0TH942Z" = "1" /* Insertion of Monitoring Device into Ureter, Percutaneous Endoscopic Approach */
"0TH94MZ" = "1" /* Insertion of Stimulator Lead into Ureter, Percutaneous Endoscopic Approach */
"0TH97MZ" = "1" /* Insertion of Stimulator Lead into Ureter, Via Natural or Artificial Opening */
"0TH98MZ" = "1" /* Insertion of Stimulator Lead into Ureter, Via Natural or Artificial Opening Endoscopic */
"0THB02Z" = "1" /* Insertion of Monitoring Device into Bladder, Open Approach */
"0THB0LZ" = "1" /* Insertion of Artificial Sphincter into Bladder, Open Approach */
"0THB0MZ" = "1" /* Insertion of Stimulator Lead into Bladder, Open Approach */
"0THB32Z" = "1" /* Insertion of Monitoring Device into Bladder, Percutaneous Approach */
"0THB3LZ" = "1" /* Insertion of Artificial Sphincter into Bladder, Percutaneous Approach */
"0THB3MZ" = "1" /* Insertion of Stimulator Lead into Bladder, Percutaneous Approach */
"0THB42Z" = "1" /* Insertion of Monitoring Device into Bladder, Percutaneous Endoscopic Approach */
"0THB4LZ" = "1" /* Insertion of Artificial Sphincter into Bladder, Percutaneous Endoscopic Approach */
"0THB4MZ" = "1" /* Insertion of Stimulator Lead into Bladder, Percutaneous Endoscopic Approach */
"0THB7LZ" = "1" /* Insertion of Artificial Sphincter into Bladder, Via Natural or Artificial Opening */
"0THB7MZ" = "1" /* Insertion of Stimulator Lead into Bladder, Via Natural or Artificial Opening */
"0THB8LZ" = "1" /* Insertion of Artificial Sphincter into Bladder, Via Natural or Artificial Opening Endoscopic */
"0THB8MZ" = "1" /* Insertion of Stimulator Lead into Bladder, Via Natural or Artificial Opening Endoscopic */
"0THC0LZ" = "1" /* Insertion of Artificial Sphincter into Bladder Neck, Open Approach */
"0THC3LZ" = "1" /* Insertion of Artificial Sphincter into Bladder Neck, Percutaneous Approach */
"0THC4LZ" = "1" /* Insertion of Artificial Sphincter into Bladder Neck, Percutaneous Endoscopic Approach */
"0THC7LZ" = "1" /* Insertion of Artificial Sphincter into Bladder Neck, Via Natural or Artificial Opening */
"0THC8LZ" = "1" /* Insertion of Artificial Sphincter into Bladder Neck, Via Natural or Artificial Opening Endoscopic */
"0THD02Z" = "1" /* Insertion of Monitoring Device into Urethra, Open Approach */
"0THD0LZ" = "1" /* Insertion of Artificial Sphincter into Urethra, Open Approach */
"0THD32Z" = "1" /* Insertion of Monitoring Device into Urethra, Percutaneous Approach */
"0THD3LZ" = "1" /* Insertion of Artificial Sphincter into Urethra, Percutaneous Approach */
"0THD42Z" = "1" /* Insertion of Monitoring Device into Urethra, Percutaneous Endoscopic Approach */
"0THD4LZ" = "1" /* Insertion of Artificial Sphincter into Urethra, Percutaneous Endoscopic Approach */
"0THD7LZ" = "1" /* Insertion of Artificial Sphincter into Urethra, Via Natural or Artificial Opening */
"0THD8LZ" = "1" /* Insertion of Artificial Sphincter into Urethra, Via Natural or Artificial Opening Endoscopic */
"0THDX2Z" = "1" /* Insertion of Monitoring Device into Urethra, External Approach */
"0THDXLZ" = "1" /* Insertion of Artificial Sphincter into Urethra, External Approach */
"0TJ50ZZ" = "1" /* Inspection of Kidney, Open Approach */
"0TJ90ZZ" = "1" /* Inspection of Ureter, Open Approach */
"0TJB0ZZ" = "1" /* Inspection of Bladder, Open Approach */
"0TJB4ZZ" = "1" /* Inspection of Bladder, Percutaneous Endoscopic Approach */
"0TJD0ZZ" = "1" /* Inspection of Urethra, Open Approach */
"0TL30CZ" = "1" /* Occlusion of Right Kidney Pelvis with Extraluminal Device, Open Approach */
"0TL30DZ" = "1" /* Occlusion of Right Kidney Pelvis with Intraluminal Device, Open Approach */
"0TL30ZZ" = "1" /* Occlusion of Right Kidney Pelvis, Open Approach */
"0TL33CZ" = "1" /* Occlusion of Right Kidney Pelvis with Extraluminal Device, Percutaneous Approach */
"0TL33DZ" = "1" /* Occlusion of Right Kidney Pelvis with Intraluminal Device, Percutaneous Approach */
"0TL33ZZ" = "1" /* Occlusion of Right Kidney Pelvis, Percutaneous Approach */
"0TL34CZ" = "1" /* Occlusion of Right Kidney Pelvis with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TL34DZ" = "1" /* Occlusion of Right Kidney Pelvis with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TL34ZZ" = "1" /* Occlusion of Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TL37DZ" = "1" /* Occlusion of Right Kidney Pelvis with Intraluminal Device, Via Natural or Artificial Opening */
"0TL37ZZ" = "1" /* Occlusion of Right Kidney Pelvis, Via Natural or Artificial Opening */
"0TL38DZ" = "1" /* Occlusion of Right Kidney Pelvis with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0TL38ZZ" = "1" /* Occlusion of Right Kidney Pelvis, Via Natural or Artificial Opening Endoscopic */
"0TL40CZ" = "1" /* Occlusion of Left Kidney Pelvis with Extraluminal Device, Open Approach */
"0TL40DZ" = "1" /* Occlusion of Left Kidney Pelvis with Intraluminal Device, Open Approach */
"0TL40ZZ" = "1" /* Occlusion of Left Kidney Pelvis, Open Approach */
"0TL43CZ" = "1" /* Occlusion of Left Kidney Pelvis with Extraluminal Device, Percutaneous Approach */
"0TL43DZ" = "1" /* Occlusion of Left Kidney Pelvis with Intraluminal Device, Percutaneous Approach */
"0TL43ZZ" = "1" /* Occlusion of Left Kidney Pelvis, Percutaneous Approach */
"0TL44CZ" = "1" /* Occlusion of Left Kidney Pelvis with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TL44DZ" = "1" /* Occlusion of Left Kidney Pelvis with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TL44ZZ" = "1" /* Occlusion of Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TL47DZ" = "1" /* Occlusion of Left Kidney Pelvis with Intraluminal Device, Via Natural or Artificial Opening */
"0TL47ZZ" = "1" /* Occlusion of Left Kidney Pelvis, Via Natural or Artificial Opening */
"0TL48DZ" = "1" /* Occlusion of Left Kidney Pelvis with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0TL48ZZ" = "1" /* Occlusion of Left Kidney Pelvis, Via Natural or Artificial Opening Endoscopic */
"0TL60CZ" = "1" /* Occlusion of Right Ureter with Extraluminal Device, Open Approach */
"0TL60DZ" = "1" /* Occlusion of Right Ureter with Intraluminal Device, Open Approach */
"0TL60ZZ" = "1" /* Occlusion of Right Ureter, Open Approach */
"0TL63CZ" = "1" /* Occlusion of Right Ureter with Extraluminal Device, Percutaneous Approach */
"0TL63DZ" = "1" /* Occlusion of Right Ureter with Intraluminal Device, Percutaneous Approach */
"0TL63ZZ" = "1" /* Occlusion of Right Ureter, Percutaneous Approach */
"0TL64CZ" = "1" /* Occlusion of Right Ureter with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TL64DZ" = "1" /* Occlusion of Right Ureter with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TL64ZZ" = "1" /* Occlusion of Right Ureter, Percutaneous Endoscopic Approach */
"0TL67DZ" = "1" /* Occlusion of Right Ureter with Intraluminal Device, Via Natural or Artificial Opening */
"0TL67ZZ" = "1" /* Occlusion of Right Ureter, Via Natural or Artificial Opening */
"0TL68DZ" = "1" /* Occlusion of Right Ureter with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0TL68ZZ" = "1" /* Occlusion of Right Ureter, Via Natural or Artificial Opening Endoscopic */
"0TL70CZ" = "1" /* Occlusion of Left Ureter with Extraluminal Device, Open Approach */
"0TL70DZ" = "1" /* Occlusion of Left Ureter with Intraluminal Device, Open Approach */
"0TL70ZZ" = "1" /* Occlusion of Left Ureter, Open Approach */
"0TL73CZ" = "1" /* Occlusion of Left Ureter with Extraluminal Device, Percutaneous Approach */
"0TL73DZ" = "1" /* Occlusion of Left Ureter with Intraluminal Device, Percutaneous Approach */
"0TL73ZZ" = "1" /* Occlusion of Left Ureter, Percutaneous Approach */
"0TL74CZ" = "1" /* Occlusion of Left Ureter with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TL74DZ" = "1" /* Occlusion of Left Ureter with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TL74ZZ" = "1" /* Occlusion of Left Ureter, Percutaneous Endoscopic Approach */
"0TL77DZ" = "1" /* Occlusion of Left Ureter with Intraluminal Device, Via Natural or Artificial Opening */
"0TL77ZZ" = "1" /* Occlusion of Left Ureter, Via Natural or Artificial Opening */
"0TL78DZ" = "1" /* Occlusion of Left Ureter with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0TL78ZZ" = "1" /* Occlusion of Left Ureter, Via Natural or Artificial Opening Endoscopic */
"0TLB0CZ" = "1" /* Occlusion of Bladder with Extraluminal Device, Open Approach */
"0TLB0DZ" = "1" /* Occlusion of Bladder with Intraluminal Device, Open Approach */
"0TLB0ZZ" = "1" /* Occlusion of Bladder, Open Approach */
"0TLB3CZ" = "1" /* Occlusion of Bladder with Extraluminal Device, Percutaneous Approach */
"0TLB3DZ" = "1" /* Occlusion of Bladder with Intraluminal Device, Percutaneous Approach */
"0TLB3ZZ" = "1" /* Occlusion of Bladder, Percutaneous Approach */
"0TLB4CZ" = "1" /* Occlusion of Bladder with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TLB4DZ" = "1" /* Occlusion of Bladder with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TLB4ZZ" = "1" /* Occlusion of Bladder, Percutaneous Endoscopic Approach */
"0TLB7DZ" = "1" /* Occlusion of Bladder with Intraluminal Device, Via Natural or Artificial Opening */
"0TLB7ZZ" = "1" /* Occlusion of Bladder, Via Natural or Artificial Opening */
"0TLB8DZ" = "1" /* Occlusion of Bladder with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0TLB8ZZ" = "1" /* Occlusion of Bladder, Via Natural or Artificial Opening Endoscopic */
"0TLC0CZ" = "1" /* Occlusion of Bladder Neck with Extraluminal Device, Open Approach */
"0TLC0DZ" = "1" /* Occlusion of Bladder Neck with Intraluminal Device, Open Approach */
"0TLC0ZZ" = "1" /* Occlusion of Bladder Neck, Open Approach */
"0TLC3CZ" = "1" /* Occlusion of Bladder Neck with Extraluminal Device, Percutaneous Approach */
"0TLC3DZ" = "1" /* Occlusion of Bladder Neck with Intraluminal Device, Percutaneous Approach */
"0TLC3ZZ" = "1" /* Occlusion of Bladder Neck, Percutaneous Approach */
"0TLC4CZ" = "1" /* Occlusion of Bladder Neck with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TLC4DZ" = "1" /* Occlusion of Bladder Neck with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TLC4ZZ" = "1" /* Occlusion of Bladder Neck, Percutaneous Endoscopic Approach */
"0TLC7DZ" = "1" /* Occlusion of Bladder Neck with Intraluminal Device, Via Natural or Artificial Opening */
"0TLC7ZZ" = "1" /* Occlusion of Bladder Neck, Via Natural or Artificial Opening */
"0TLC8DZ" = "1" /* Occlusion of Bladder Neck with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0TLC8ZZ" = "1" /* Occlusion of Bladder Neck, Via Natural or Artificial Opening Endoscopic */
"0TLD0CZ" = "1" /* Occlusion of Urethra with Extraluminal Device, Open Approach */
"0TLD0DZ" = "1" /* Occlusion of Urethra with Intraluminal Device, Open Approach */
"0TLD0ZZ" = "1" /* Occlusion of Urethra, Open Approach */
"0TLD3CZ" = "1" /* Occlusion of Urethra with Extraluminal Device, Percutaneous Approach */
"0TLD3DZ" = "1" /* Occlusion of Urethra with Intraluminal Device, Percutaneous Approach */
"0TLD3ZZ" = "1" /* Occlusion of Urethra, Percutaneous Approach */
"0TLD4CZ" = "1" /* Occlusion of Urethra with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TLD4DZ" = "1" /* Occlusion of Urethra with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TLD4ZZ" = "1" /* Occlusion of Urethra, Percutaneous Endoscopic Approach */
"0TLD7DZ" = "1" /* Occlusion of Urethra with Intraluminal Device, Via Natural or Artificial Opening */
"0TLD7ZZ" = "1" /* Occlusion of Urethra, Via Natural or Artificial Opening */
"0TLD8DZ" = "1" /* Occlusion of Urethra with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0TLD8ZZ" = "1" /* Occlusion of Urethra, Via Natural or Artificial Opening Endoscopic */
"0TLDXCZ" = "1" /* Occlusion of Urethra with Extraluminal Device, External Approach */
"0TLDXDZ" = "1" /* Occlusion of Urethra with Intraluminal Device, External Approach */
"0TLDXZZ" = "1" /* Occlusion of Urethra, External Approach */
"0TM00ZZ" = "1" /* Reattachment of Right Kidney, Open Approach */
"0TM04ZZ" = "1" /* Reattachment of Right Kidney, Percutaneous Endoscopic Approach */
"0TM10ZZ" = "1" /* Reattachment of Left Kidney, Open Approach */
"0TM14ZZ" = "1" /* Reattachment of Left Kidney, Percutaneous Endoscopic Approach */
"0TM20ZZ" = "1" /* Reattachment of Bilateral Kidneys, Open Approach */
"0TM24ZZ" = "1" /* Reattachment of Bilateral Kidneys, Percutaneous Endoscopic Approach */
"0TM30ZZ" = "1" /* Reattachment of Right Kidney Pelvis, Open Approach */
"0TM34ZZ" = "1" /* Reattachment of Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TM40ZZ" = "1" /* Reattachment of Left Kidney Pelvis, Open Approach */
"0TM44ZZ" = "1" /* Reattachment of Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TM60ZZ" = "1" /* Reattachment of Right Ureter, Open Approach */
"0TM64ZZ" = "1" /* Reattachment of Right Ureter, Percutaneous Endoscopic Approach */
"0TM70ZZ" = "1" /* Reattachment of Left Ureter, Open Approach */
"0TM74ZZ" = "1" /* Reattachment of Left Ureter, Percutaneous Endoscopic Approach */
"0TM80ZZ" = "1" /* Reattachment of Bilateral Ureters, Open Approach */
"0TM84ZZ" = "1" /* Reattachment of Bilateral Ureters, Percutaneous Endoscopic Approach */
"0TMB0ZZ" = "1" /* Reattachment of Bladder, Open Approach */
"0TMB4ZZ" = "1" /* Reattachment of Bladder, Percutaneous Endoscopic Approach */
"0TMC0ZZ" = "1" /* Reattachment of Bladder Neck, Open Approach */
"0TMC4ZZ" = "1" /* Reattachment of Bladder Neck, Percutaneous Endoscopic Approach */
"0TMD0ZZ" = "1" /* Reattachment of Urethra, Open Approach */
"0TMD4ZZ" = "1" /* Reattachment of Urethra, Percutaneous Endoscopic Approach */
"0TN00ZZ" = "1" /* Release Right Kidney, Open Approach */
"0TN03ZZ" = "1" /* Release Right Kidney, Percutaneous Approach */
"0TN04ZZ" = "1" /* Release Right Kidney, Percutaneous Endoscopic Approach */
"0TN07ZZ" = "1" /* Release Right Kidney, Via Natural or Artificial Opening */
"0TN08ZZ" = "1" /* Release Right Kidney, Via Natural or Artificial Opening Endoscopic */
"0TN10ZZ" = "1" /* Release Left Kidney, Open Approach */
"0TN13ZZ" = "1" /* Release Left Kidney, Percutaneous Approach */
"0TN14ZZ" = "1" /* Release Left Kidney, Percutaneous Endoscopic Approach */
"0TN17ZZ" = "1" /* Release Left Kidney, Via Natural or Artificial Opening */
"0TN18ZZ" = "1" /* Release Left Kidney, Via Natural or Artificial Opening Endoscopic */
"0TN30ZZ" = "1" /* Release Right Kidney Pelvis, Open Approach */
"0TN33ZZ" = "1" /* Release Right Kidney Pelvis, Percutaneous Approach */
"0TN34ZZ" = "1" /* Release Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TN37ZZ" = "1" /* Release Right Kidney Pelvis, Via Natural or Artificial Opening */
"0TN38ZZ" = "1" /* Release Right Kidney Pelvis, Via Natural or Artificial Opening Endoscopic */
"0TN40ZZ" = "1" /* Release Left Kidney Pelvis, Open Approach */
"0TN43ZZ" = "1" /* Release Left Kidney Pelvis, Percutaneous Approach */
"0TN44ZZ" = "1" /* Release Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TN47ZZ" = "1" /* Release Left Kidney Pelvis, Via Natural or Artificial Opening */
"0TN48ZZ" = "1" /* Release Left Kidney Pelvis, Via Natural or Artificial Opening Endoscopic */
"0TN60ZZ" = "1" /* Release Right Ureter, Open Approach */
"0TN63ZZ" = "1" /* Release Right Ureter, Percutaneous Approach */
"0TN64ZZ" = "1" /* Release Right Ureter, Percutaneous Endoscopic Approach */
"0TN67ZZ" = "1" /* Release Right Ureter, Via Natural or Artificial Opening */
"0TN68ZZ" = "1" /* Release Right Ureter, Via Natural or Artificial Opening Endoscopic */
"0TN70ZZ" = "1" /* Release Left Ureter, Open Approach */
"0TN73ZZ" = "1" /* Release Left Ureter, Percutaneous Approach */
"0TN74ZZ" = "1" /* Release Left Ureter, Percutaneous Endoscopic Approach */
"0TN77ZZ" = "1" /* Release Left Ureter, Via Natural or Artificial Opening */
"0TN78ZZ" = "1" /* Release Left Ureter, Via Natural or Artificial Opening Endoscopic */
"0TNB0ZZ" = "1" /* Release Bladder, Open Approach */
"0TNB3ZZ" = "1" /* Release Bladder, Percutaneous Approach */
"0TNB4ZZ" = "1" /* Release Bladder, Percutaneous Endoscopic Approach */
"0TNB7ZZ" = "1" /* Release Bladder, Via Natural or Artificial Opening */
"0TNB8ZZ" = "1" /* Release Bladder, Via Natural or Artificial Opening Endoscopic */
"0TNC0ZZ" = "1" /* Release Bladder Neck, Open Approach */
"0TNC3ZZ" = "1" /* Release Bladder Neck, Percutaneous Approach */
"0TNC4ZZ" = "1" /* Release Bladder Neck, Percutaneous Endoscopic Approach */
"0TNC7ZZ" = "1" /* Release Bladder Neck, Via Natural or Artificial Opening */
"0TNC8ZZ" = "1" /* Release Bladder Neck, Via Natural or Artificial Opening Endoscopic */
"0TND0ZZ" = "1" /* Release Urethra, Open Approach */
"0TND3ZZ" = "1" /* Release Urethra, Percutaneous Approach */
"0TND4ZZ" = "1" /* Release Urethra, Percutaneous Endoscopic Approach */
"0TND7ZZ" = "1" /* Release Urethra, Via Natural or Artificial Opening */
"0TND8ZZ" = "1" /* Release Urethra, Via Natural or Artificial Opening Endoscopic */
"0TNDXZZ" = "1" /* Release Urethra, External Approach */
"0TP500Z" = "1" /* Removal of Drainage Device from Kidney, Open Approach */
"0TP502Z" = "1" /* Removal of Monitoring Device from Kidney, Open Approach */
"0TP503Z" = "1" /* Removal of Infusion Device from Kidney, Open Approach */
"0TP507Z" = "1" /* Removal of Autologous Tissue Substitute from Kidney, Open Approach */
"0TP50CZ" = "1" /* Removal of Extraluminal Device from Kidney, Open Approach */
"0TP50DZ" = "1" /* Removal of Intraluminal Device from Kidney, Open Approach */
"0TP50JZ" = "1" /* Removal of Synthetic Substitute from Kidney, Open Approach */
"0TP50KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Kidney, Open Approach */
"0TP530Z" = "1" /* Removal of Drainage Device from Kidney, Percutaneous Approach */
"0TP532Z" = "1" /* Removal of Monitoring Device from Kidney, Percutaneous Approach */
"0TP533Z" = "1" /* Removal of Infusion Device from Kidney, Percutaneous Approach */
"0TP537Z" = "1" /* Removal of Autologous Tissue Substitute from Kidney, Percutaneous Approach */
"0TP53CZ" = "1" /* Removal of Extraluminal Device from Kidney, Percutaneous Approach */
"0TP53DZ" = "1" /* Removal of Intraluminal Device from Kidney, Percutaneous Approach */
"0TP53JZ" = "1" /* Removal of Synthetic Substitute from Kidney, Percutaneous Approach */
"0TP53KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Kidney, Percutaneous Approach */
"0TP540Z" = "1" /* Removal of Drainage Device from Kidney, Percutaneous Endoscopic Approach */
"0TP542Z" = "1" /* Removal of Monitoring Device from Kidney, Percutaneous Endoscopic Approach */
"0TP543Z" = "1" /* Removal of Infusion Device from Kidney, Percutaneous Endoscopic Approach */
"0TP547Z" = "1" /* Removal of Autologous Tissue Substitute from Kidney, Percutaneous Endoscopic Approach */
"0TP54CZ" = "1" /* Removal of Extraluminal Device from Kidney, Percutaneous Endoscopic Approach */
"0TP54DZ" = "1" /* Removal of Intraluminal Device from Kidney, Percutaneous Endoscopic Approach */
"0TP54JZ" = "1" /* Removal of Synthetic Substitute from Kidney, Percutaneous Endoscopic Approach */
"0TP54KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Kidney, Percutaneous Endoscopic Approach */
"0TP577Z" = "1" /* Removal of Autologous Tissue Substitute from Kidney, Via Natural or Artificial Opening */
"0TP57CZ" = "1" /* Removal of Extraluminal Device from Kidney, Via Natural or Artificial Opening */
"0TP57JZ" = "1" /* Removal of Synthetic Substitute from Kidney, Via Natural or Artificial Opening */
"0TP57KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Kidney, Via Natural or Artificial Opening */
"0TP587Z" = "1" /* Removal of Autologous Tissue Substitute from Kidney, Via Natural or Artificial Opening Endoscopic */
"0TP58CZ" = "1" /* Removal of Extraluminal Device from Kidney, Via Natural or Artificial Opening Endoscopic */
"0TP58JZ" = "1" /* Removal of Synthetic Substitute from Kidney, Via Natural or Artificial Opening Endoscopic */
"0TP58KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Kidney, Via Natural or Artificial Opening Endoscopic */
"0TP900Z" = "1" /* Removal of Drainage Device from Ureter, Open Approach */
"0TP902Z" = "1" /* Removal of Monitoring Device from Ureter, Open Approach */
"0TP903Z" = "1" /* Removal of Infusion Device from Ureter, Open Approach */
"0TP907Z" = "1" /* Removal of Autologous Tissue Substitute from Ureter, Open Approach */
"0TP90CZ" = "1" /* Removal of Extraluminal Device from Ureter, Open Approach */
"0TP90DZ" = "1" /* Removal of Intraluminal Device from Ureter, Open Approach */
"0TP90JZ" = "1" /* Removal of Synthetic Substitute from Ureter, Open Approach */
"0TP90KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Ureter, Open Approach */
"0TP90MZ" = "1" /* Removal of Stimulator Lead from Ureter, Open Approach */
"0TP930Z" = "1" /* Removal of Drainage Device from Ureter, Percutaneous Approach */
"0TP932Z" = "1" /* Removal of Monitoring Device from Ureter, Percutaneous Approach */
"0TP933Z" = "1" /* Removal of Infusion Device from Ureter, Percutaneous Approach */
"0TP937Z" = "1" /* Removal of Autologous Tissue Substitute from Ureter, Percutaneous Approach */
"0TP93CZ" = "1" /* Removal of Extraluminal Device from Ureter, Percutaneous Approach */
"0TP93DZ" = "1" /* Removal of Intraluminal Device from Ureter, Percutaneous Approach */
"0TP93JZ" = "1" /* Removal of Synthetic Substitute from Ureter, Percutaneous Approach */
"0TP93KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Ureter, Percutaneous Approach */
"0TP93MZ" = "1" /* Removal of Stimulator Lead from Ureter, Percutaneous Approach */
"0TP940Z" = "1" /* Removal of Drainage Device from Ureter, Percutaneous Endoscopic Approach */
"0TP942Z" = "1" /* Removal of Monitoring Device from Ureter, Percutaneous Endoscopic Approach */
"0TP943Z" = "1" /* Removal of Infusion Device from Ureter, Percutaneous Endoscopic Approach */
"0TP947Z" = "1" /* Removal of Autologous Tissue Substitute from Ureter, Percutaneous Endoscopic Approach */
"0TP94CZ" = "1" /* Removal of Extraluminal Device from Ureter, Percutaneous Endoscopic Approach */
"0TP94DZ" = "1" /* Removal of Intraluminal Device from Ureter, Percutaneous Endoscopic Approach */
"0TP94JZ" = "1" /* Removal of Synthetic Substitute from Ureter, Percutaneous Endoscopic Approach */
"0TP94KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Ureter, Percutaneous Endoscopic Approach */
"0TP94MZ" = "1" /* Removal of Stimulator Lead from Ureter, Percutaneous Endoscopic Approach */
"0TP977Z" = "1" /* Removal of Autologous Tissue Substitute from Ureter, Via Natural or Artificial Opening */
"0TP97CZ" = "1" /* Removal of Extraluminal Device from Ureter, Via Natural or Artificial Opening */
"0TP97JZ" = "1" /* Removal of Synthetic Substitute from Ureter, Via Natural or Artificial Opening */
"0TP97KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Ureter, Via Natural or Artificial Opening */
"0TP97MZ" = "1" /* Removal of Stimulator Lead from Ureter, Via Natural or Artificial Opening */
"0TP987Z" = "1" /* Removal of Autologous Tissue Substitute from Ureter, Via Natural or Artificial Opening Endoscopic */
"0TP98CZ" = "1" /* Removal of Extraluminal Device from Ureter, Via Natural or Artificial Opening Endoscopic */
"0TP98JZ" = "1" /* Removal of Synthetic Substitute from Ureter, Via Natural or Artificial Opening Endoscopic */
"0TP98KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Ureter, Via Natural or Artificial Opening Endoscopic */
"0TP98MZ" = "1" /* Removal of Stimulator Lead from Ureter, Via Natural or Artificial Opening Endoscopic */
"0TP9XMZ" = "1" /* Removal of Stimulator Lead from Ureter, External Approach */
"0TPB00Z" = "1" /* Removal of Drainage Device from Bladder, Open Approach */
"0TPB02Z" = "1" /* Removal of Monitoring Device from Bladder, Open Approach */
"0TPB03Z" = "1" /* Removal of Infusion Device from Bladder, Open Approach */
"0TPB07Z" = "1" /* Removal of Autologous Tissue Substitute from Bladder, Open Approach */
"0TPB0CZ" = "1" /* Removal of Extraluminal Device from Bladder, Open Approach */
"0TPB0DZ" = "1" /* Removal of Intraluminal Device from Bladder, Open Approach */
"0TPB0JZ" = "1" /* Removal of Synthetic Substitute from Bladder, Open Approach */
"0TPB0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Bladder, Open Approach */
"0TPB0LZ" = "1" /* Removal of Artificial Sphincter from Bladder, Open Approach */
"0TPB0MZ" = "1" /* Removal of Stimulator Lead from Bladder, Open Approach */
"0TPB30Z" = "1" /* Removal of Drainage Device from Bladder, Percutaneous Approach */
"0TPB32Z" = "1" /* Removal of Monitoring Device from Bladder, Percutaneous Approach */
"0TPB33Z" = "1" /* Removal of Infusion Device from Bladder, Percutaneous Approach */
"0TPB37Z" = "1" /* Removal of Autologous Tissue Substitute from Bladder, Percutaneous Approach */
"0TPB3CZ" = "1" /* Removal of Extraluminal Device from Bladder, Percutaneous Approach */
"0TPB3DZ" = "1" /* Removal of Intraluminal Device from Bladder, Percutaneous Approach */
"0TPB3JZ" = "1" /* Removal of Synthetic Substitute from Bladder, Percutaneous Approach */
"0TPB3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Bladder, Percutaneous Approach */
"0TPB3LZ" = "1" /* Removal of Artificial Sphincter from Bladder, Percutaneous Approach */
"0TPB3MZ" = "1" /* Removal of Stimulator Lead from Bladder, Percutaneous Approach */
"0TPB40Z" = "1" /* Removal of Drainage Device from Bladder, Percutaneous Endoscopic Approach */
"0TPB42Z" = "1" /* Removal of Monitoring Device from Bladder, Percutaneous Endoscopic Approach */
"0TPB43Z" = "1" /* Removal of Infusion Device from Bladder, Percutaneous Endoscopic Approach */
"0TPB47Z" = "1" /* Removal of Autologous Tissue Substitute from Bladder, Percutaneous Endoscopic Approach */
"0TPB4CZ" = "1" /* Removal of Extraluminal Device from Bladder, Percutaneous Endoscopic Approach */
"0TPB4DZ" = "1" /* Removal of Intraluminal Device from Bladder, Percutaneous Endoscopic Approach */
"0TPB4JZ" = "1" /* Removal of Synthetic Substitute from Bladder, Percutaneous Endoscopic Approach */
"0TPB4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Bladder, Percutaneous Endoscopic Approach */
"0TPB4LZ" = "1" /* Removal of Artificial Sphincter from Bladder, Percutaneous Endoscopic Approach */
"0TPB4MZ" = "1" /* Removal of Stimulator Lead from Bladder, Percutaneous Endoscopic Approach */
"0TPB77Z" = "1" /* Removal of Autologous Tissue Substitute from Bladder, Via Natural or Artificial Opening */
"0TPB7CZ" = "1" /* Removal of Extraluminal Device from Bladder, Via Natural or Artificial Opening */
"0TPB7JZ" = "1" /* Removal of Synthetic Substitute from Bladder, Via Natural or Artificial Opening */
"0TPB7KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Bladder, Via Natural or Artificial Opening */
"0TPB7LZ" = "1" /* Removal of Artificial Sphincter from Bladder, Via Natural or Artificial Opening */
"0TPB7MZ" = "1" /* Removal of Stimulator Lead from Bladder, Via Natural or Artificial Opening */
"0TPB87Z" = "1" /* Removal of Autologous Tissue Substitute from Bladder, Via Natural or Artificial Opening Endoscopic */
"0TPB8CZ" = "1" /* Removal of Extraluminal Device from Bladder, Via Natural or Artificial Opening Endoscopic */
"0TPB8JZ" = "1" /* Removal of Synthetic Substitute from Bladder, Via Natural or Artificial Opening Endoscopic */
"0TPB8KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Bladder, Via Natural or Artificial Opening Endoscopic */
"0TPB8LZ" = "1" /* Removal of Artificial Sphincter from Bladder, Via Natural or Artificial Opening Endoscopic */
"0TPB8MZ" = "1" /* Removal of Stimulator Lead from Bladder, Via Natural or Artificial Opening Endoscopic */
"0TPBXMZ" = "1" /* Removal of Stimulator Lead from Bladder, External Approach */
"0TPD00Z" = "1" /* Removal of Drainage Device from Urethra, Open Approach */
"0TPD02Z" = "1" /* Removal of Monitoring Device from Urethra, Open Approach */
"0TPD03Z" = "1" /* Removal of Infusion Device from Urethra, Open Approach */
"0TPD07Z" = "1" /* Removal of Autologous Tissue Substitute from Urethra, Open Approach */
"0TPD0CZ" = "1" /* Removal of Extraluminal Device from Urethra, Open Approach */
"0TPD0DZ" = "1" /* Removal of Intraluminal Device from Urethra, Open Approach */
"0TPD0JZ" = "1" /* Removal of Synthetic Substitute from Urethra, Open Approach */
"0TPD0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Urethra, Open Approach */
"0TPD0LZ" = "1" /* Removal of Artificial Sphincter from Urethra, Open Approach */
"0TPD30Z" = "1" /* Removal of Drainage Device from Urethra, Percutaneous Approach */
"0TPD32Z" = "1" /* Removal of Monitoring Device from Urethra, Percutaneous Approach */
"0TPD33Z" = "1" /* Removal of Infusion Device from Urethra, Percutaneous Approach */
"0TPD37Z" = "1" /* Removal of Autologous Tissue Substitute from Urethra, Percutaneous Approach */
"0TPD3CZ" = "1" /* Removal of Extraluminal Device from Urethra, Percutaneous Approach */
"0TPD3DZ" = "1" /* Removal of Intraluminal Device from Urethra, Percutaneous Approach */
"0TPD3JZ" = "1" /* Removal of Synthetic Substitute from Urethra, Percutaneous Approach */
"0TPD3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Urethra, Percutaneous Approach */
"0TPD3LZ" = "1" /* Removal of Artificial Sphincter from Urethra, Percutaneous Approach */
"0TPD40Z" = "1" /* Removal of Drainage Device from Urethra, Percutaneous Endoscopic Approach */
"0TPD42Z" = "1" /* Removal of Monitoring Device from Urethra, Percutaneous Endoscopic Approach */
"0TPD43Z" = "1" /* Removal of Infusion Device from Urethra, Percutaneous Endoscopic Approach */
"0TPD47Z" = "1" /* Removal of Autologous Tissue Substitute from Urethra, Percutaneous Endoscopic Approach */
"0TPD4CZ" = "1" /* Removal of Extraluminal Device from Urethra, Percutaneous Endoscopic Approach */
"0TPD4DZ" = "1" /* Removal of Intraluminal Device from Urethra, Percutaneous Endoscopic Approach */
"0TPD4JZ" = "1" /* Removal of Synthetic Substitute from Urethra, Percutaneous Endoscopic Approach */
"0TPD4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Urethra, Percutaneous Endoscopic Approach */
"0TPD4LZ" = "1" /* Removal of Artificial Sphincter from Urethra, Percutaneous Endoscopic Approach */
"0TPD77Z" = "1" /* Removal of Autologous Tissue Substitute from Urethra, Via Natural or Artificial Opening */
"0TPD7CZ" = "1" /* Removal of Extraluminal Device from Urethra, Via Natural or Artificial Opening */
"0TPD7JZ" = "1" /* Removal of Synthetic Substitute from Urethra, Via Natural or Artificial Opening */
"0TPD7KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Urethra, Via Natural or Artificial Opening */
"0TPD7LZ" = "1" /* Removal of Artificial Sphincter from Urethra, Via Natural or Artificial Opening */
"0TPD87Z" = "1" /* Removal of Autologous Tissue Substitute from Urethra, Via Natural or Artificial Opening Endoscopic */
"0TPD8CZ" = "1" /* Removal of Extraluminal Device from Urethra, Via Natural or Artificial Opening Endoscopic */
"0TPD8JZ" = "1" /* Removal of Synthetic Substitute from Urethra, Via Natural or Artificial Opening Endoscopic */
"0TPD8KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Urethra, Via Natural or Artificial Opening Endoscopic */
"0TPD8LZ" = "1" /* Removal of Artificial Sphincter from Urethra, Via Natural or Artificial Opening Endoscopic */
"0TPDXLZ" = "1" /* Removal of Artificial Sphincter from Urethra, External Approach */
"0TQ00ZZ" = "1" /* Repair Right Kidney, Open Approach */
"0TQ03ZZ" = "1" /* Repair Right Kidney, Percutaneous Approach */
"0TQ04ZZ" = "1" /* Repair Right Kidney, Percutaneous Endoscopic Approach */
"0TQ07ZZ" = "1" /* Repair Right Kidney, Via Natural or Artificial Opening */
"0TQ08ZZ" = "1" /* Repair Right Kidney, Via Natural or Artificial Opening Endoscopic */
"0TQ10ZZ" = "1" /* Repair Left Kidney, Open Approach */
"0TQ13ZZ" = "1" /* Repair Left Kidney, Percutaneous Approach */
"0TQ14ZZ" = "1" /* Repair Left Kidney, Percutaneous Endoscopic Approach */
"0TQ17ZZ" = "1" /* Repair Left Kidney, Via Natural or Artificial Opening */
"0TQ18ZZ" = "1" /* Repair Left Kidney, Via Natural or Artificial Opening Endoscopic */
"0TQ30ZZ" = "1" /* Repair Right Kidney Pelvis, Open Approach */
"0TQ33ZZ" = "1" /* Repair Right Kidney Pelvis, Percutaneous Approach */
"0TQ34ZZ" = "1" /* Repair Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TQ37ZZ" = "1" /* Repair Right Kidney Pelvis, Via Natural or Artificial Opening */
"0TQ38ZZ" = "1" /* Repair Right Kidney Pelvis, Via Natural or Artificial Opening Endoscopic */
"0TQ40ZZ" = "1" /* Repair Left Kidney Pelvis, Open Approach */
"0TQ43ZZ" = "1" /* Repair Left Kidney Pelvis, Percutaneous Approach */
"0TQ44ZZ" = "1" /* Repair Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TQ47ZZ" = "1" /* Repair Left Kidney Pelvis, Via Natural or Artificial Opening */
"0TQ48ZZ" = "1" /* Repair Left Kidney Pelvis, Via Natural or Artificial Opening Endoscopic */
"0TQ60ZZ" = "1" /* Repair Right Ureter, Open Approach */
"0TQ63ZZ" = "1" /* Repair Right Ureter, Percutaneous Approach */
"0TQ64ZZ" = "1" /* Repair Right Ureter, Percutaneous Endoscopic Approach */
"0TQ67ZZ" = "1" /* Repair Right Ureter, Via Natural or Artificial Opening */
"0TQ68ZZ" = "1" /* Repair Right Ureter, Via Natural or Artificial Opening Endoscopic */
"0TQ70ZZ" = "1" /* Repair Left Ureter, Open Approach */
"0TQ73ZZ" = "1" /* Repair Left Ureter, Percutaneous Approach */
"0TQ74ZZ" = "1" /* Repair Left Ureter, Percutaneous Endoscopic Approach */
"0TQ77ZZ" = "1" /* Repair Left Ureter, Via Natural or Artificial Opening */
"0TQ78ZZ" = "1" /* Repair Left Ureter, Via Natural or Artificial Opening Endoscopic */
"0TQB0ZZ" = "1" /* Repair Bladder, Open Approach */
"0TQB3ZZ" = "1" /* Repair Bladder, Percutaneous Approach */
"0TQB4ZZ" = "1" /* Repair Bladder, Percutaneous Endoscopic Approach */
"0TQB7ZZ" = "1" /* Repair Bladder, Via Natural or Artificial Opening */
"0TQB8ZZ" = "1" /* Repair Bladder, Via Natural or Artificial Opening Endoscopic */
"0TQD0ZZ" = "1" /* Repair Urethra, Open Approach */
"0TQD3ZZ" = "1" /* Repair Urethra, Percutaneous Approach */
"0TQD4ZZ" = "1" /* Repair Urethra, Percutaneous Endoscopic Approach */
"0TQD7ZZ" = "1" /* Repair Urethra, Via Natural or Artificial Opening */
"0TQD8ZZ" = "1" /* Repair Urethra, Via Natural or Artificial Opening Endoscopic */
"0TQDXZZ" = "1" /* Repair Urethra, External Approach */
"0TR307Z" = "1" /* Replacement of Right Kidney Pelvis with Autologous Tissue Substitute, Open Approach */
"0TR30JZ" = "1" /* Replacement of Right Kidney Pelvis with Synthetic Substitute, Open Approach */
"0TR30KZ" = "1" /* Replacement of Right Kidney Pelvis with Nonautologous Tissue Substitute, Open Approach */
"0TR347Z" = "1" /* Replacement of Right Kidney Pelvis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TR34JZ" = "1" /* Replacement of Right Kidney Pelvis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TR34KZ" = "1" /* Replacement of Right Kidney Pelvis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TR377Z" = "1" /* Replacement of Right Kidney Pelvis with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0TR37JZ" = "1" /* Replacement of Right Kidney Pelvis with Synthetic Substitute, Via Natural or Artificial Opening */
"0TR37KZ" = "1" /* Replacement of Right Kidney Pelvis with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0TR387Z" = "1" /* Replacement of Right Kidney Pelvis with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TR38JZ" = "1" /* Replacement of Right Kidney Pelvis with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0TR38KZ" = "1" /* Replacement of Right Kidney Pelvis with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TR407Z" = "1" /* Replacement of Left Kidney Pelvis with Autologous Tissue Substitute, Open Approach */
"0TR40JZ" = "1" /* Replacement of Left Kidney Pelvis with Synthetic Substitute, Open Approach */
"0TR40KZ" = "1" /* Replacement of Left Kidney Pelvis with Nonautologous Tissue Substitute, Open Approach */
"0TR447Z" = "1" /* Replacement of Left Kidney Pelvis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TR44JZ" = "1" /* Replacement of Left Kidney Pelvis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TR44KZ" = "1" /* Replacement of Left Kidney Pelvis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TR477Z" = "1" /* Replacement of Left Kidney Pelvis with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0TR47JZ" = "1" /* Replacement of Left Kidney Pelvis with Synthetic Substitute, Via Natural or Artificial Opening */
"0TR47KZ" = "1" /* Replacement of Left Kidney Pelvis with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0TR487Z" = "1" /* Replacement of Left Kidney Pelvis with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TR48JZ" = "1" /* Replacement of Left Kidney Pelvis with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0TR48KZ" = "1" /* Replacement of Left Kidney Pelvis with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TR607Z" = "1" /* Replacement of Right Ureter with Autologous Tissue Substitute, Open Approach */
"0TR60JZ" = "1" /* Replacement of Right Ureter with Synthetic Substitute, Open Approach */
"0TR60KZ" = "1" /* Replacement of Right Ureter with Nonautologous Tissue Substitute, Open Approach */
"0TR647Z" = "1" /* Replacement of Right Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TR64JZ" = "1" /* Replacement of Right Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TR64KZ" = "1" /* Replacement of Right Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TR677Z" = "1" /* Replacement of Right Ureter with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0TR67JZ" = "1" /* Replacement of Right Ureter with Synthetic Substitute, Via Natural or Artificial Opening */
"0TR67KZ" = "1" /* Replacement of Right Ureter with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0TR687Z" = "1" /* Replacement of Right Ureter with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TR68JZ" = "1" /* Replacement of Right Ureter with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0TR68KZ" = "1" /* Replacement of Right Ureter with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TR707Z" = "1" /* Replacement of Left Ureter with Autologous Tissue Substitute, Open Approach */
"0TR70JZ" = "1" /* Replacement of Left Ureter with Synthetic Substitute, Open Approach */
"0TR70KZ" = "1" /* Replacement of Left Ureter with Nonautologous Tissue Substitute, Open Approach */
"0TR747Z" = "1" /* Replacement of Left Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TR74JZ" = "1" /* Replacement of Left Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TR74KZ" = "1" /* Replacement of Left Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TR777Z" = "1" /* Replacement of Left Ureter with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0TR77JZ" = "1" /* Replacement of Left Ureter with Synthetic Substitute, Via Natural or Artificial Opening */
"0TR77KZ" = "1" /* Replacement of Left Ureter with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0TR787Z" = "1" /* Replacement of Left Ureter with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TR78JZ" = "1" /* Replacement of Left Ureter with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0TR78KZ" = "1" /* Replacement of Left Ureter with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TRB07Z" = "1" /* Replacement of Bladder with Autologous Tissue Substitute, Open Approach */
"0TRB0JZ" = "1" /* Replacement of Bladder with Synthetic Substitute, Open Approach */
"0TRB0KZ" = "1" /* Replacement of Bladder with Nonautologous Tissue Substitute, Open Approach */
"0TRB47Z" = "1" /* Replacement of Bladder with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TRB4JZ" = "1" /* Replacement of Bladder with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TRB4KZ" = "1" /* Replacement of Bladder with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TRB77Z" = "1" /* Replacement of Bladder with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0TRB7JZ" = "1" /* Replacement of Bladder with Synthetic Substitute, Via Natural or Artificial Opening */
"0TRB7KZ" = "1" /* Replacement of Bladder with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0TRB87Z" = "1" /* Replacement of Bladder with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TRB8JZ" = "1" /* Replacement of Bladder with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0TRB8KZ" = "1" /* Replacement of Bladder with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TRC07Z" = "1" /* Replacement of Bladder Neck with Autologous Tissue Substitute, Open Approach */
"0TRC0JZ" = "1" /* Replacement of Bladder Neck with Synthetic Substitute, Open Approach */
"0TRC0KZ" = "1" /* Replacement of Bladder Neck with Nonautologous Tissue Substitute, Open Approach */
"0TRC47Z" = "1" /* Replacement of Bladder Neck with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TRC4JZ" = "1" /* Replacement of Bladder Neck with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TRC4KZ" = "1" /* Replacement of Bladder Neck with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TRC77Z" = "1" /* Replacement of Bladder Neck with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0TRC7JZ" = "1" /* Replacement of Bladder Neck with Synthetic Substitute, Via Natural or Artificial Opening */
"0TRC7KZ" = "1" /* Replacement of Bladder Neck with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0TRC87Z" = "1" /* Replacement of Bladder Neck with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TRC8JZ" = "1" /* Replacement of Bladder Neck with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0TRC8KZ" = "1" /* Replacement of Bladder Neck with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TRD07Z" = "1" /* Replacement of Urethra with Autologous Tissue Substitute, Open Approach */
"0TRD0JZ" = "1" /* Replacement of Urethra with Synthetic Substitute, Open Approach */
"0TRD0KZ" = "1" /* Replacement of Urethra with Nonautologous Tissue Substitute, Open Approach */
"0TRD47Z" = "1" /* Replacement of Urethra with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TRD4JZ" = "1" /* Replacement of Urethra with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TRD4KZ" = "1" /* Replacement of Urethra with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TRD77Z" = "1" /* Replacement of Urethra with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0TRD7JZ" = "1" /* Replacement of Urethra with Synthetic Substitute, Via Natural or Artificial Opening */
"0TRD7KZ" = "1" /* Replacement of Urethra with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0TRD87Z" = "1" /* Replacement of Urethra with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TRD8JZ" = "1" /* Replacement of Urethra with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0TRD8KZ" = "1" /* Replacement of Urethra with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TRDX7Z" = "1" /* Replacement of Urethra with Autologous Tissue Substitute, External Approach */
"0TRDXJZ" = "1" /* Replacement of Urethra with Synthetic Substitute, External Approach */
"0TRDXKZ" = "1" /* Replacement of Urethra with Nonautologous Tissue Substitute, External Approach */
"0TS00ZZ" = "1" /* Reposition Right Kidney, Open Approach */
"0TS04ZZ" = "1" /* Reposition Right Kidney, Percutaneous Endoscopic Approach */
"0TS10ZZ" = "1" /* Reposition Left Kidney, Open Approach */
"0TS14ZZ" = "1" /* Reposition Left Kidney, Percutaneous Endoscopic Approach */
"0TS20ZZ" = "1" /* Reposition Bilateral Kidneys, Open Approach */
"0TS24ZZ" = "1" /* Reposition Bilateral Kidneys, Percutaneous Endoscopic Approach */
"0TS30ZZ" = "1" /* Reposition Right Kidney Pelvis, Open Approach */
"0TS34ZZ" = "1" /* Reposition Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TS40ZZ" = "1" /* Reposition Left Kidney Pelvis, Open Approach */
"0TS44ZZ" = "1" /* Reposition Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TS60ZZ" = "1" /* Reposition Right Ureter, Open Approach */
"0TS64ZZ" = "1" /* Reposition Right Ureter, Percutaneous Endoscopic Approach */
"0TS70ZZ" = "1" /* Reposition Left Ureter, Open Approach */
"0TS74ZZ" = "1" /* Reposition Left Ureter, Percutaneous Endoscopic Approach */
"0TS80ZZ" = "1" /* Reposition Bilateral Ureters, Open Approach */
"0TS84ZZ" = "1" /* Reposition Bilateral Ureters, Percutaneous Endoscopic Approach */
"0TSB0ZZ" = "1" /* Reposition Bladder, Open Approach */
"0TSB4ZZ" = "1" /* Reposition Bladder, Percutaneous Endoscopic Approach */
"0TSC0ZZ" = "1" /* Reposition Bladder Neck, Open Approach */
"0TSC4ZZ" = "1" /* Reposition Bladder Neck, Percutaneous Endoscopic Approach */
"0TSD0ZZ" = "1" /* Reposition Urethra, Open Approach */
"0TSD4ZZ" = "1" /* Reposition Urethra, Percutaneous Endoscopic Approach */
"0TT00ZZ" = "1" /* Resection of Right Kidney, Open Approach */
"0TT04ZZ" = "1" /* Resection of Right Kidney, Percutaneous Endoscopic Approach */
"0TT10ZZ" = "1" /* Resection of Left Kidney, Open Approach */
"0TT14ZZ" = "1" /* Resection of Left Kidney, Percutaneous Endoscopic Approach */
"0TT20ZZ" = "1" /* Resection of Bilateral Kidneys, Open Approach */
"0TT24ZZ" = "1" /* Resection of Bilateral Kidneys, Percutaneous Endoscopic Approach */
"0TT30ZZ" = "1" /* Resection of Right Kidney Pelvis, Open Approach */
"0TT34ZZ" = "1" /* Resection of Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TT37ZZ" = "1" /* Resection of Right Kidney Pelvis, Via Natural or Artificial Opening */
"0TT38ZZ" = "1" /* Resection of Right Kidney Pelvis, Via Natural or Artificial Opening Endoscopic */
"0TT40ZZ" = "1" /* Resection of Left Kidney Pelvis, Open Approach */
"0TT44ZZ" = "1" /* Resection of Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TT47ZZ" = "1" /* Resection of Left Kidney Pelvis, Via Natural or Artificial Opening */
"0TT48ZZ" = "1" /* Resection of Left Kidney Pelvis, Via Natural or Artificial Opening Endoscopic */
"0TT60ZZ" = "1" /* Resection of Right Ureter, Open Approach */
"0TT64ZZ" = "1" /* Resection of Right Ureter, Percutaneous Endoscopic Approach */
"0TT67ZZ" = "1" /* Resection of Right Ureter, Via Natural or Artificial Opening */
"0TT68ZZ" = "1" /* Resection of Right Ureter, Via Natural or Artificial Opening Endoscopic */
"0TT70ZZ" = "1" /* Resection of Left Ureter, Open Approach */
"0TT74ZZ" = "1" /* Resection of Left Ureter, Percutaneous Endoscopic Approach */
"0TT77ZZ" = "1" /* Resection of Left Ureter, Via Natural or Artificial Opening */
"0TT78ZZ" = "1" /* Resection of Left Ureter, Via Natural or Artificial Opening Endoscopic */
"0TTB0ZZ" = "1" /* Resection of Bladder, Open Approach */
"0TTB4ZZ" = "1" /* Resection of Bladder, Percutaneous Endoscopic Approach */
"0TTB7ZZ" = "1" /* Resection of Bladder, Via Natural or Artificial Opening */
"0TTB8ZZ" = "1" /* Resection of Bladder, Via Natural or Artificial Opening Endoscopic */
"0TTC0ZZ" = "1" /* Resection of Bladder Neck, Open Approach */
"0TTC4ZZ" = "1" /* Resection of Bladder Neck, Percutaneous Endoscopic Approach */
"0TTC7ZZ" = "1" /* Resection of Bladder Neck, Via Natural or Artificial Opening */
"0TTC8ZZ" = "1" /* Resection of Bladder Neck, Via Natural or Artificial Opening Endoscopic */
"0TU307Z" = "1" /* Supplement Right Kidney Pelvis with Autologous Tissue Substitute, Open Approach */
"0TU30JZ" = "1" /* Supplement Right Kidney Pelvis with Synthetic Substitute, Open Approach */
"0TU30KZ" = "1" /* Supplement Right Kidney Pelvis with Nonautologous Tissue Substitute, Open Approach */
"0TU347Z" = "1" /* Supplement Right Kidney Pelvis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TU34JZ" = "1" /* Supplement Right Kidney Pelvis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TU34KZ" = "1" /* Supplement Right Kidney Pelvis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TU377Z" = "1" /* Supplement Right Kidney Pelvis with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0TU37JZ" = "1" /* Supplement Right Kidney Pelvis with Synthetic Substitute, Via Natural or Artificial Opening */
"0TU37KZ" = "1" /* Supplement Right Kidney Pelvis with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0TU387Z" = "1" /* Supplement Right Kidney Pelvis with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TU38JZ" = "1" /* Supplement Right Kidney Pelvis with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0TU38KZ" = "1" /* Supplement Right Kidney Pelvis with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TU407Z" = "1" /* Supplement Left Kidney Pelvis with Autologous Tissue Substitute, Open Approach */
"0TU40JZ" = "1" /* Supplement Left Kidney Pelvis with Synthetic Substitute, Open Approach */
"0TU40KZ" = "1" /* Supplement Left Kidney Pelvis with Nonautologous Tissue Substitute, Open Approach */
"0TU447Z" = "1" /* Supplement Left Kidney Pelvis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TU44JZ" = "1" /* Supplement Left Kidney Pelvis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TU44KZ" = "1" /* Supplement Left Kidney Pelvis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TU477Z" = "1" /* Supplement Left Kidney Pelvis with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0TU47JZ" = "1" /* Supplement Left Kidney Pelvis with Synthetic Substitute, Via Natural or Artificial Opening */
"0TU47KZ" = "1" /* Supplement Left Kidney Pelvis with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0TU487Z" = "1" /* Supplement Left Kidney Pelvis with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TU48JZ" = "1" /* Supplement Left Kidney Pelvis with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0TU48KZ" = "1" /* Supplement Left Kidney Pelvis with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TU607Z" = "1" /* Supplement Right Ureter with Autologous Tissue Substitute, Open Approach */
"0TU60JZ" = "1" /* Supplement Right Ureter with Synthetic Substitute, Open Approach */
"0TU60KZ" = "1" /* Supplement Right Ureter with Nonautologous Tissue Substitute, Open Approach */
"0TU647Z" = "1" /* Supplement Right Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TU64JZ" = "1" /* Supplement Right Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TU64KZ" = "1" /* Supplement Right Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TU677Z" = "1" /* Supplement Right Ureter with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0TU67JZ" = "1" /* Supplement Right Ureter with Synthetic Substitute, Via Natural or Artificial Opening */
"0TU67KZ" = "1" /* Supplement Right Ureter with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0TU687Z" = "1" /* Supplement Right Ureter with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TU68JZ" = "1" /* Supplement Right Ureter with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0TU68KZ" = "1" /* Supplement Right Ureter with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TU707Z" = "1" /* Supplement Left Ureter with Autologous Tissue Substitute, Open Approach */
"0TU70JZ" = "1" /* Supplement Left Ureter with Synthetic Substitute, Open Approach */
"0TU70KZ" = "1" /* Supplement Left Ureter with Nonautologous Tissue Substitute, Open Approach */
"0TU747Z" = "1" /* Supplement Left Ureter with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TU74JZ" = "1" /* Supplement Left Ureter with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TU74KZ" = "1" /* Supplement Left Ureter with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TU777Z" = "1" /* Supplement Left Ureter with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0TU77JZ" = "1" /* Supplement Left Ureter with Synthetic Substitute, Via Natural or Artificial Opening */
"0TU77KZ" = "1" /* Supplement Left Ureter with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0TU787Z" = "1" /* Supplement Left Ureter with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TU78JZ" = "1" /* Supplement Left Ureter with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0TU78KZ" = "1" /* Supplement Left Ureter with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TUB07Z" = "1" /* Supplement Bladder with Autologous Tissue Substitute, Open Approach */
"0TUB0JZ" = "1" /* Supplement Bladder with Synthetic Substitute, Open Approach */
"0TUB0KZ" = "1" /* Supplement Bladder with Nonautologous Tissue Substitute, Open Approach */
"0TUB47Z" = "1" /* Supplement Bladder with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TUB4JZ" = "1" /* Supplement Bladder with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TUB4KZ" = "1" /* Supplement Bladder with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TUB77Z" = "1" /* Supplement Bladder with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0TUB7JZ" = "1" /* Supplement Bladder with Synthetic Substitute, Via Natural or Artificial Opening */
"0TUB7KZ" = "1" /* Supplement Bladder with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0TUB87Z" = "1" /* Supplement Bladder with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TUB8JZ" = "1" /* Supplement Bladder with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0TUB8KZ" = "1" /* Supplement Bladder with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TUC07Z" = "1" /* Supplement Bladder Neck with Autologous Tissue Substitute, Open Approach */
"0TUC0JZ" = "1" /* Supplement Bladder Neck with Synthetic Substitute, Open Approach */
"0TUC0KZ" = "1" /* Supplement Bladder Neck with Nonautologous Tissue Substitute, Open Approach */
"0TUC47Z" = "1" /* Supplement Bladder Neck with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TUC4JZ" = "1" /* Supplement Bladder Neck with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TUC4KZ" = "1" /* Supplement Bladder Neck with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TUC77Z" = "1" /* Supplement Bladder Neck with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0TUC7JZ" = "1" /* Supplement Bladder Neck with Synthetic Substitute, Via Natural or Artificial Opening */
"0TUC7KZ" = "1" /* Supplement Bladder Neck with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0TUC87Z" = "1" /* Supplement Bladder Neck with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TUC8JZ" = "1" /* Supplement Bladder Neck with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0TUC8KZ" = "1" /* Supplement Bladder Neck with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TUD07Z" = "1" /* Supplement Urethra with Autologous Tissue Substitute, Open Approach */
"0TUD0JZ" = "1" /* Supplement Urethra with Synthetic Substitute, Open Approach */
"0TUD0KZ" = "1" /* Supplement Urethra with Nonautologous Tissue Substitute, Open Approach */
"0TUD47Z" = "1" /* Supplement Urethra with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TUD4JZ" = "1" /* Supplement Urethra with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0TUD4KZ" = "1" /* Supplement Urethra with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0TUD77Z" = "1" /* Supplement Urethra with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0TUD7JZ" = "1" /* Supplement Urethra with Synthetic Substitute, Via Natural or Artificial Opening */
"0TUD7KZ" = "1" /* Supplement Urethra with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0TUD87Z" = "1" /* Supplement Urethra with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TUD8JZ" = "1" /* Supplement Urethra with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0TUD8KZ" = "1" /* Supplement Urethra with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0TUDX7Z" = "1" /* Supplement Urethra with Autologous Tissue Substitute, External Approach */
"0TUDXJZ" = "1" /* Supplement Urethra with Synthetic Substitute, External Approach */
"0TUDXKZ" = "1" /* Supplement Urethra with Nonautologous Tissue Substitute, External Approach */
"0TV30CZ" = "1" /* Restriction of Right Kidney Pelvis with Extraluminal Device, Open Approach */
"0TV30DZ" = "1" /* Restriction of Right Kidney Pelvis with Intraluminal Device, Open Approach */
"0TV30ZZ" = "1" /* Restriction of Right Kidney Pelvis, Open Approach */
"0TV33CZ" = "1" /* Restriction of Right Kidney Pelvis with Extraluminal Device, Percutaneous Approach */
"0TV33DZ" = "1" /* Restriction of Right Kidney Pelvis with Intraluminal Device, Percutaneous Approach */
"0TV33ZZ" = "1" /* Restriction of Right Kidney Pelvis, Percutaneous Approach */
"0TV34CZ" = "1" /* Restriction of Right Kidney Pelvis with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TV34DZ" = "1" /* Restriction of Right Kidney Pelvis with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TV34ZZ" = "1" /* Restriction of Right Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TV37DZ" = "1" /* Restriction of Right Kidney Pelvis with Intraluminal Device, Via Natural or Artificial Opening */
"0TV37ZZ" = "1" /* Restriction of Right Kidney Pelvis, Via Natural or Artificial Opening */
"0TV38DZ" = "1" /* Restriction of Right Kidney Pelvis with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0TV38ZZ" = "1" /* Restriction of Right Kidney Pelvis, Via Natural or Artificial Opening Endoscopic */
"0TV40CZ" = "1" /* Restriction of Left Kidney Pelvis with Extraluminal Device, Open Approach */
"0TV40DZ" = "1" /* Restriction of Left Kidney Pelvis with Intraluminal Device, Open Approach */
"0TV40ZZ" = "1" /* Restriction of Left Kidney Pelvis, Open Approach */
"0TV43CZ" = "1" /* Restriction of Left Kidney Pelvis with Extraluminal Device, Percutaneous Approach */
"0TV43DZ" = "1" /* Restriction of Left Kidney Pelvis with Intraluminal Device, Percutaneous Approach */
"0TV43ZZ" = "1" /* Restriction of Left Kidney Pelvis, Percutaneous Approach */
"0TV44CZ" = "1" /* Restriction of Left Kidney Pelvis with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TV44DZ" = "1" /* Restriction of Left Kidney Pelvis with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TV44ZZ" = "1" /* Restriction of Left Kidney Pelvis, Percutaneous Endoscopic Approach */
"0TV47DZ" = "1" /* Restriction of Left Kidney Pelvis with Intraluminal Device, Via Natural or Artificial Opening */
"0TV47ZZ" = "1" /* Restriction of Left Kidney Pelvis, Via Natural or Artificial Opening */
"0TV48DZ" = "1" /* Restriction of Left Kidney Pelvis with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0TV48ZZ" = "1" /* Restriction of Left Kidney Pelvis, Via Natural or Artificial Opening Endoscopic */
"0TV60CZ" = "1" /* Restriction of Right Ureter with Extraluminal Device, Open Approach */
"0TV60DZ" = "1" /* Restriction of Right Ureter with Intraluminal Device, Open Approach */
"0TV60ZZ" = "1" /* Restriction of Right Ureter, Open Approach */
"0TV63CZ" = "1" /* Restriction of Right Ureter with Extraluminal Device, Percutaneous Approach */
"0TV63DZ" = "1" /* Restriction of Right Ureter with Intraluminal Device, Percutaneous Approach */
"0TV63ZZ" = "1" /* Restriction of Right Ureter, Percutaneous Approach */
"0TV64CZ" = "1" /* Restriction of Right Ureter with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TV64DZ" = "1" /* Restriction of Right Ureter with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TV64ZZ" = "1" /* Restriction of Right Ureter, Percutaneous Endoscopic Approach */
"0TV67DZ" = "1" /* Restriction of Right Ureter with Intraluminal Device, Via Natural or Artificial Opening */
"0TV67ZZ" = "1" /* Restriction of Right Ureter, Via Natural or Artificial Opening */
"0TV68DZ" = "1" /* Restriction of Right Ureter with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0TV68ZZ" = "1" /* Restriction of Right Ureter, Via Natural or Artificial Opening Endoscopic */
"0TV70CZ" = "1" /* Restriction of Left Ureter with Extraluminal Device, Open Approach */
"0TV70DZ" = "1" /* Restriction of Left Ureter with Intraluminal Device, Open Approach */
"0TV70ZZ" = "1" /* Restriction of Left Ureter, Open Approach */
"0TV73CZ" = "1" /* Restriction of Left Ureter with Extraluminal Device, Percutaneous Approach */
"0TV73DZ" = "1" /* Restriction of Left Ureter with Intraluminal Device, Percutaneous Approach */
"0TV73ZZ" = "1" /* Restriction of Left Ureter, Percutaneous Approach */
"0TV74CZ" = "1" /* Restriction of Left Ureter with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TV74DZ" = "1" /* Restriction of Left Ureter with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TV74ZZ" = "1" /* Restriction of Left Ureter, Percutaneous Endoscopic Approach */
"0TV77DZ" = "1" /* Restriction of Left Ureter with Intraluminal Device, Via Natural or Artificial Opening */
"0TV77ZZ" = "1" /* Restriction of Left Ureter, Via Natural or Artificial Opening */
"0TV78DZ" = "1" /* Restriction of Left Ureter with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0TV78ZZ" = "1" /* Restriction of Left Ureter, Via Natural or Artificial Opening Endoscopic */
"0TVB0CZ" = "1" /* Restriction of Bladder with Extraluminal Device, Open Approach */
"0TVB0DZ" = "1" /* Restriction of Bladder with Intraluminal Device, Open Approach */
"0TVB0ZZ" = "1" /* Restriction of Bladder, Open Approach */
"0TVB3CZ" = "1" /* Restriction of Bladder with Extraluminal Device, Percutaneous Approach */
"0TVB3DZ" = "1" /* Restriction of Bladder with Intraluminal Device, Percutaneous Approach */
"0TVB3ZZ" = "1" /* Restriction of Bladder, Percutaneous Approach */
"0TVB4CZ" = "1" /* Restriction of Bladder with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TVB4DZ" = "1" /* Restriction of Bladder with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TVB4ZZ" = "1" /* Restriction of Bladder, Percutaneous Endoscopic Approach */
"0TVB7DZ" = "1" /* Restriction of Bladder with Intraluminal Device, Via Natural or Artificial Opening */
"0TVB7ZZ" = "1" /* Restriction of Bladder, Via Natural or Artificial Opening */
"0TVB8DZ" = "1" /* Restriction of Bladder with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0TVB8ZZ" = "1" /* Restriction of Bladder, Via Natural or Artificial Opening Endoscopic */
"0TVC0CZ" = "1" /* Restriction of Bladder Neck with Extraluminal Device, Open Approach */
"0TVC0DZ" = "1" /* Restriction of Bladder Neck with Intraluminal Device, Open Approach */
"0TVC0ZZ" = "1" /* Restriction of Bladder Neck, Open Approach */
"0TVC3CZ" = "1" /* Restriction of Bladder Neck with Extraluminal Device, Percutaneous Approach */
"0TVC3DZ" = "1" /* Restriction of Bladder Neck with Intraluminal Device, Percutaneous Approach */
"0TVC3ZZ" = "1" /* Restriction of Bladder Neck, Percutaneous Approach */
"0TVC4CZ" = "1" /* Restriction of Bladder Neck with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TVC4DZ" = "1" /* Restriction of Bladder Neck with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TVC4ZZ" = "1" /* Restriction of Bladder Neck, Percutaneous Endoscopic Approach */
"0TVC7DZ" = "1" /* Restriction of Bladder Neck with Intraluminal Device, Via Natural or Artificial Opening */
"0TVC7ZZ" = "1" /* Restriction of Bladder Neck, Via Natural or Artificial Opening */
"0TVC8DZ" = "1" /* Restriction of Bladder Neck with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0TVC8ZZ" = "1" /* Restriction of Bladder Neck, Via Natural or Artificial Opening Endoscopic */
"0TVD0CZ" = "1" /* Restriction of Urethra with Extraluminal Device, Open Approach */
"0TVD0DZ" = "1" /* Restriction of Urethra with Intraluminal Device, Open Approach */
"0TVD0ZZ" = "1" /* Restriction of Urethra, Open Approach */
"0TVD3CZ" = "1" /* Restriction of Urethra with Extraluminal Device, Percutaneous Approach */
"0TVD3DZ" = "1" /* Restriction of Urethra with Intraluminal Device, Percutaneous Approach */
"0TVD3ZZ" = "1" /* Restriction of Urethra, Percutaneous Approach */
"0TVD4CZ" = "1" /* Restriction of Urethra with Extraluminal Device, Percutaneous Endoscopic Approach */
"0TVD4DZ" = "1" /* Restriction of Urethra with Intraluminal Device, Percutaneous Endoscopic Approach */
"0TVD4ZZ" = "1" /* Restriction of Urethra, Percutaneous Endoscopic Approach */
"0TVD7DZ" = "1" /* Restriction of Urethra with Intraluminal Device, Via Natural or Artificial Opening */
"0TVD7ZZ" = "1" /* Restriction of Urethra, Via Natural or Artificial Opening */
"0TVD8DZ" = "1" /* Restriction of Urethra with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0TVD8ZZ" = "1" /* Restriction of Urethra, Via Natural or Artificial Opening Endoscopic */
"0TVDXZZ" = "1" /* Restriction of Urethra, External Approach */
"0TW500Z" = "1" /* Revision of Drainage Device in Kidney, Open Approach */
"0TW502Z" = "1" /* Revision of Monitoring Device in Kidney, Open Approach */
"0TW503Z" = "1" /* Revision of Infusion Device in Kidney, Open Approach */
"0TW507Z" = "1" /* Revision of Autologous Tissue Substitute in Kidney, Open Approach */
"0TW50CZ" = "1" /* Revision of Extraluminal Device in Kidney, Open Approach */
"0TW50DZ" = "1" /* Revision of Intraluminal Device in Kidney, Open Approach */
"0TW50JZ" = "1" /* Revision of Synthetic Substitute in Kidney, Open Approach */
"0TW50KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Kidney, Open Approach */
"0TW530Z" = "1" /* Revision of Drainage Device in Kidney, Percutaneous Approach */
"0TW532Z" = "1" /* Revision of Monitoring Device in Kidney, Percutaneous Approach */
"0TW533Z" = "1" /* Revision of Infusion Device in Kidney, Percutaneous Approach */
"0TW537Z" = "1" /* Revision of Autologous Tissue Substitute in Kidney, Percutaneous Approach */
"0TW53CZ" = "1" /* Revision of Extraluminal Device in Kidney, Percutaneous Approach */
"0TW53DZ" = "1" /* Revision of Intraluminal Device in Kidney, Percutaneous Approach */
"0TW53JZ" = "1" /* Revision of Synthetic Substitute in Kidney, Percutaneous Approach */
"0TW53KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Kidney, Percutaneous Approach */
"0TW540Z" = "1" /* Revision of Drainage Device in Kidney, Percutaneous Endoscopic Approach */
"0TW542Z" = "1" /* Revision of Monitoring Device in Kidney, Percutaneous Endoscopic Approach */
"0TW543Z" = "1" /* Revision of Infusion Device in Kidney, Percutaneous Endoscopic Approach */
"0TW547Z" = "1" /* Revision of Autologous Tissue Substitute in Kidney, Percutaneous Endoscopic Approach */
"0TW54CZ" = "1" /* Revision of Extraluminal Device in Kidney, Percutaneous Endoscopic Approach */
"0TW54DZ" = "1" /* Revision of Intraluminal Device in Kidney, Percutaneous Endoscopic Approach */
"0TW54JZ" = "1" /* Revision of Synthetic Substitute in Kidney, Percutaneous Endoscopic Approach */
"0TW54KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Kidney, Percutaneous Endoscopic Approach */
"0TW570Z" = "1" /* Revision of Drainage Device in Kidney, Via Natural or Artificial Opening */
"0TW572Z" = "1" /* Revision of Monitoring Device in Kidney, Via Natural or Artificial Opening */
"0TW573Z" = "1" /* Revision of Infusion Device in Kidney, Via Natural or Artificial Opening */
"0TW577Z" = "1" /* Revision of Autologous Tissue Substitute in Kidney, Via Natural or Artificial Opening */
"0TW57CZ" = "1" /* Revision of Extraluminal Device in Kidney, Via Natural or Artificial Opening */
"0TW57DZ" = "1" /* Revision of Intraluminal Device in Kidney, Via Natural or Artificial Opening */
"0TW57JZ" = "1" /* Revision of Synthetic Substitute in Kidney, Via Natural or Artificial Opening */
"0TW57KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Kidney, Via Natural or Artificial Opening */
"0TW580Z" = "1" /* Revision of Drainage Device in Kidney, Via Natural or Artificial Opening Endoscopic */
"0TW582Z" = "1" /* Revision of Monitoring Device in Kidney, Via Natural or Artificial Opening Endoscopic */
"0TW583Z" = "1" /* Revision of Infusion Device in Kidney, Via Natural or Artificial Opening Endoscopic */
"0TW587Z" = "1" /* Revision of Autologous Tissue Substitute in Kidney, Via Natural or Artificial Opening Endoscopic */
"0TW58CZ" = "1" /* Revision of Extraluminal Device in Kidney, Via Natural or Artificial Opening Endoscopic */
"0TW58DZ" = "1" /* Revision of Intraluminal Device in Kidney, Via Natural or Artificial Opening Endoscopic */
"0TW58JZ" = "1" /* Revision of Synthetic Substitute in Kidney, Via Natural or Artificial Opening Endoscopic */
"0TW58KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Kidney, Via Natural or Artificial Opening Endoscopic */
"0TW900Z" = "1" /* Revision of Drainage Device in Ureter, Open Approach */
"0TW902Z" = "1" /* Revision of Monitoring Device in Ureter, Open Approach */
"0TW903Z" = "1" /* Revision of Infusion Device in Ureter, Open Approach */
"0TW907Z" = "1" /* Revision of Autologous Tissue Substitute in Ureter, Open Approach */
"0TW90CZ" = "1" /* Revision of Extraluminal Device in Ureter, Open Approach */
"0TW90DZ" = "1" /* Revision of Intraluminal Device in Ureter, Open Approach */
"0TW90JZ" = "1" /* Revision of Synthetic Substitute in Ureter, Open Approach */
"0TW90KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Ureter, Open Approach */
"0TW90MZ" = "1" /* Revision of Stimulator Lead in Ureter, Open Approach */
"0TW930Z" = "1" /* Revision of Drainage Device in Ureter, Percutaneous Approach */
"0TW932Z" = "1" /* Revision of Monitoring Device in Ureter, Percutaneous Approach */
"0TW933Z" = "1" /* Revision of Infusion Device in Ureter, Percutaneous Approach */
"0TW937Z" = "1" /* Revision of Autologous Tissue Substitute in Ureter, Percutaneous Approach */
"0TW93CZ" = "1" /* Revision of Extraluminal Device in Ureter, Percutaneous Approach */
"0TW93DZ" = "1" /* Revision of Intraluminal Device in Ureter, Percutaneous Approach */
"0TW93JZ" = "1" /* Revision of Synthetic Substitute in Ureter, Percutaneous Approach */
"0TW93KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Ureter, Percutaneous Approach */
"0TW93MZ" = "1" /* Revision of Stimulator Lead in Ureter, Percutaneous Approach */
"0TW940Z" = "1" /* Revision of Drainage Device in Ureter, Percutaneous Endoscopic Approach */
"0TW942Z" = "1" /* Revision of Monitoring Device in Ureter, Percutaneous Endoscopic Approach */
"0TW943Z" = "1" /* Revision of Infusion Device in Ureter, Percutaneous Endoscopic Approach */
"0TW947Z" = "1" /* Revision of Autologous Tissue Substitute in Ureter, Percutaneous Endoscopic Approach */
"0TW94CZ" = "1" /* Revision of Extraluminal Device in Ureter, Percutaneous Endoscopic Approach */
"0TW94DZ" = "1" /* Revision of Intraluminal Device in Ureter, Percutaneous Endoscopic Approach */
"0TW94JZ" = "1" /* Revision of Synthetic Substitute in Ureter, Percutaneous Endoscopic Approach */
"0TW94KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Ureter, Percutaneous Endoscopic Approach */
"0TW94MZ" = "1" /* Revision of Stimulator Lead in Ureter, Percutaneous Endoscopic Approach */
"0TW970Z" = "1" /* Revision of Drainage Device in Ureter, Via Natural or Artificial Opening */
"0TW972Z" = "1" /* Revision of Monitoring Device in Ureter, Via Natural or Artificial Opening */
"0TW973Z" = "1" /* Revision of Infusion Device in Ureter, Via Natural or Artificial Opening */
"0TW977Z" = "1" /* Revision of Autologous Tissue Substitute in Ureter, Via Natural or Artificial Opening */
"0TW97CZ" = "1" /* Revision of Extraluminal Device in Ureter, Via Natural or Artificial Opening */
"0TW97DZ" = "1" /* Revision of Intraluminal Device in Ureter, Via Natural or Artificial Opening */
"0TW97JZ" = "1" /* Revision of Synthetic Substitute in Ureter, Via Natural or Artificial Opening */
"0TW97KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Ureter, Via Natural or Artificial Opening */
"0TW97MZ" = "1" /* Revision of Stimulator Lead in Ureter, Via Natural or Artificial Opening */
"0TW980Z" = "1" /* Revision of Drainage Device in Ureter, Via Natural or Artificial Opening Endoscopic */
"0TW982Z" = "1" /* Revision of Monitoring Device in Ureter, Via Natural or Artificial Opening Endoscopic */
"0TW983Z" = "1" /* Revision of Infusion Device in Ureter, Via Natural or Artificial Opening Endoscopic */
"0TW987Z" = "1" /* Revision of Autologous Tissue Substitute in Ureter, Via Natural or Artificial Opening Endoscopic */
"0TW98CZ" = "1" /* Revision of Extraluminal Device in Ureter, Via Natural or Artificial Opening Endoscopic */
"0TW98DZ" = "1" /* Revision of Intraluminal Device in Ureter, Via Natural or Artificial Opening Endoscopic */
"0TW98JZ" = "1" /* Revision of Synthetic Substitute in Ureter, Via Natural or Artificial Opening Endoscopic */
"0TW98KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Ureter, Via Natural or Artificial Opening Endoscopic */
"0TW98MZ" = "1" /* Revision of Stimulator Lead in Ureter, Via Natural or Artificial Opening Endoscopic */
"0TWB00Z" = "1" /* Revision of Drainage Device in Bladder, Open Approach */
"0TWB02Z" = "1" /* Revision of Monitoring Device in Bladder, Open Approach */
"0TWB03Z" = "1" /* Revision of Infusion Device in Bladder, Open Approach */
"0TWB07Z" = "1" /* Revision of Autologous Tissue Substitute in Bladder, Open Approach */
"0TWB0CZ" = "1" /* Revision of Extraluminal Device in Bladder, Open Approach */
"0TWB0DZ" = "1" /* Revision of Intraluminal Device in Bladder, Open Approach */
"0TWB0JZ" = "1" /* Revision of Synthetic Substitute in Bladder, Open Approach */
"0TWB0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Bladder, Open Approach */
"0TWB0LZ" = "1" /* Revision of Artificial Sphincter in Bladder, Open Approach */
"0TWB0MZ" = "1" /* Revision of Stimulator Lead in Bladder, Open Approach */
"0TWB30Z" = "1" /* Revision of Drainage Device in Bladder, Percutaneous Approach */
"0TWB32Z" = "1" /* Revision of Monitoring Device in Bladder, Percutaneous Approach */
"0TWB33Z" = "1" /* Revision of Infusion Device in Bladder, Percutaneous Approach */
"0TWB37Z" = "1" /* Revision of Autologous Tissue Substitute in Bladder, Percutaneous Approach */
"0TWB3CZ" = "1" /* Revision of Extraluminal Device in Bladder, Percutaneous Approach */
"0TWB3DZ" = "1" /* Revision of Intraluminal Device in Bladder, Percutaneous Approach */
"0TWB3JZ" = "1" /* Revision of Synthetic Substitute in Bladder, Percutaneous Approach */
"0TWB3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Bladder, Percutaneous Approach */
"0TWB3LZ" = "1" /* Revision of Artificial Sphincter in Bladder, Percutaneous Approach */
"0TWB3MZ" = "1" /* Revision of Stimulator Lead in Bladder, Percutaneous Approach */
"0TWB40Z" = "1" /* Revision of Drainage Device in Bladder, Percutaneous Endoscopic Approach */
"0TWB42Z" = "1" /* Revision of Monitoring Device in Bladder, Percutaneous Endoscopic Approach */
"0TWB43Z" = "1" /* Revision of Infusion Device in Bladder, Percutaneous Endoscopic Approach */
"0TWB47Z" = "1" /* Revision of Autologous Tissue Substitute in Bladder, Percutaneous Endoscopic Approach */
"0TWB4CZ" = "1" /* Revision of Extraluminal Device in Bladder, Percutaneous Endoscopic Approach */
"0TWB4DZ" = "1" /* Revision of Intraluminal Device in Bladder, Percutaneous Endoscopic Approach */
"0TWB4JZ" = "1" /* Revision of Synthetic Substitute in Bladder, Percutaneous Endoscopic Approach */
"0TWB4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Bladder, Percutaneous Endoscopic Approach */
"0TWB4LZ" = "1" /* Revision of Artificial Sphincter in Bladder, Percutaneous Endoscopic Approach */
"0TWB4MZ" = "1" /* Revision of Stimulator Lead in Bladder, Percutaneous Endoscopic Approach */
"0TWB70Z" = "1" /* Revision of Drainage Device in Bladder, Via Natural or Artificial Opening */
"0TWB72Z" = "1" /* Revision of Monitoring Device in Bladder, Via Natural or Artificial Opening */
"0TWB73Z" = "1" /* Revision of Infusion Device in Bladder, Via Natural or Artificial Opening */
"0TWB77Z" = "1" /* Revision of Autologous Tissue Substitute in Bladder, Via Natural or Artificial Opening */
"0TWB7CZ" = "1" /* Revision of Extraluminal Device in Bladder, Via Natural or Artificial Opening */
"0TWB7DZ" = "1" /* Revision of Intraluminal Device in Bladder, Via Natural or Artificial Opening */
"0TWB7JZ" = "1" /* Revision of Synthetic Substitute in Bladder, Via Natural or Artificial Opening */
"0TWB7KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Bladder, Via Natural or Artificial Opening */
"0TWB7LZ" = "1" /* Revision of Artificial Sphincter in Bladder, Via Natural or Artificial Opening */
"0TWB7MZ" = "1" /* Revision of Stimulator Lead in Bladder, Via Natural or Artificial Opening */
"0TWB80Z" = "1" /* Revision of Drainage Device in Bladder, Via Natural or Artificial Opening Endoscopic */
"0TWB82Z" = "1" /* Revision of Monitoring Device in Bladder, Via Natural or Artificial Opening Endoscopic */
"0TWB83Z" = "1" /* Revision of Infusion Device in Bladder, Via Natural or Artificial Opening Endoscopic */
"0TWB87Z" = "1" /* Revision of Autologous Tissue Substitute in Bladder, Via Natural or Artificial Opening Endoscopic */
"0TWB8CZ" = "1" /* Revision of Extraluminal Device in Bladder, Via Natural or Artificial Opening Endoscopic */
"0TWB8DZ" = "1" /* Revision of Intraluminal Device in Bladder, Via Natural or Artificial Opening Endoscopic */
"0TWB8JZ" = "1" /* Revision of Synthetic Substitute in Bladder, Via Natural or Artificial Opening Endoscopic */
"0TWB8KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Bladder, Via Natural or Artificial Opening Endoscopic */
"0TWB8LZ" = "1" /* Revision of Artificial Sphincter in Bladder, Via Natural or Artificial Opening Endoscopic */
"0TWB8MZ" = "1" /* Revision of Stimulator Lead in Bladder, Via Natural or Artificial Opening Endoscopic */
"0TWD00Z" = "1" /* Revision of Drainage Device in Urethra, Open Approach */
"0TWD02Z" = "1" /* Revision of Monitoring Device in Urethra, Open Approach */
"0TWD03Z" = "1" /* Revision of Infusion Device in Urethra, Open Approach */
"0TWD07Z" = "1" /* Revision of Autologous Tissue Substitute in Urethra, Open Approach */
"0TWD0CZ" = "1" /* Revision of Extraluminal Device in Urethra, Open Approach */
"0TWD0DZ" = "1" /* Revision of Intraluminal Device in Urethra, Open Approach */
"0TWD0JZ" = "1" /* Revision of Synthetic Substitute in Urethra, Open Approach */
"0TWD0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Urethra, Open Approach */
"0TWD0LZ" = "1" /* Revision of Artificial Sphincter in Urethra, Open Approach */
"0TWD30Z" = "1" /* Revision of Drainage Device in Urethra, Percutaneous Approach */
"0TWD32Z" = "1" /* Revision of Monitoring Device in Urethra, Percutaneous Approach */
"0TWD33Z" = "1" /* Revision of Infusion Device in Urethra, Percutaneous Approach */
"0TWD37Z" = "1" /* Revision of Autologous Tissue Substitute in Urethra, Percutaneous Approach */
"0TWD3CZ" = "1" /* Revision of Extraluminal Device in Urethra, Percutaneous Approach */
"0TWD3DZ" = "1" /* Revision of Intraluminal Device in Urethra, Percutaneous Approach */
"0TWD3JZ" = "1" /* Revision of Synthetic Substitute in Urethra, Percutaneous Approach */
"0TWD3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Urethra, Percutaneous Approach */
"0TWD3LZ" = "1" /* Revision of Artificial Sphincter in Urethra, Percutaneous Approach */
"0TWD40Z" = "1" /* Revision of Drainage Device in Urethra, Percutaneous Endoscopic Approach */
"0TWD42Z" = "1" /* Revision of Monitoring Device in Urethra, Percutaneous Endoscopic Approach */
"0TWD43Z" = "1" /* Revision of Infusion Device in Urethra, Percutaneous Endoscopic Approach */
"0TWD47Z" = "1" /* Revision of Autologous Tissue Substitute in Urethra, Percutaneous Endoscopic Approach */
"0TWD4CZ" = "1" /* Revision of Extraluminal Device in Urethra, Percutaneous Endoscopic Approach */
"0TWD4DZ" = "1" /* Revision of Intraluminal Device in Urethra, Percutaneous Endoscopic Approach */
"0TWD4JZ" = "1" /* Revision of Synthetic Substitute in Urethra, Percutaneous Endoscopic Approach */
"0TWD4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Urethra, Percutaneous Endoscopic Approach */
"0TWD4LZ" = "1" /* Revision of Artificial Sphincter in Urethra, Percutaneous Endoscopic Approach */
"0TWD70Z" = "1" /* Revision of Drainage Device in Urethra, Via Natural or Artificial Opening */
"0TWD72Z" = "1" /* Revision of Monitoring Device in Urethra, Via Natural or Artificial Opening */
"0TWD73Z" = "1" /* Revision of Infusion Device in Urethra, Via Natural or Artificial Opening */
"0TWD77Z" = "1" /* Revision of Autologous Tissue Substitute in Urethra, Via Natural or Artificial Opening */
"0TWD7CZ" = "1" /* Revision of Extraluminal Device in Urethra, Via Natural or Artificial Opening */
"0TWD7DZ" = "1" /* Revision of Intraluminal Device in Urethra, Via Natural or Artificial Opening */
"0TWD7JZ" = "1" /* Revision of Synthetic Substitute in Urethra, Via Natural or Artificial Opening */
"0TWD7KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Urethra, Via Natural or Artificial Opening */
"0TWD7LZ" = "1" /* Revision of Artificial Sphincter in Urethra, Via Natural or Artificial Opening */
"0TWD80Z" = "1" /* Revision of Drainage Device in Urethra, Via Natural or Artificial Opening Endoscopic */
"0TWD82Z" = "1" /* Revision of Monitoring Device in Urethra, Via Natural or Artificial Opening Endoscopic */
"0TWD83Z" = "1" /* Revision of Infusion Device in Urethra, Via Natural or Artificial Opening Endoscopic */
"0TWD87Z" = "1" /* Revision of Autologous Tissue Substitute in Urethra, Via Natural or Artificial Opening Endoscopic */
"0TWD8CZ" = "1" /* Revision of Extraluminal Device in Urethra, Via Natural or Artificial Opening Endoscopic */
"0TWD8DZ" = "1" /* Revision of Intraluminal Device in Urethra, Via Natural or Artificial Opening Endoscopic */
"0TWD8JZ" = "1" /* Revision of Synthetic Substitute in Urethra, Via Natural or Artificial Opening Endoscopic */
"0TWD8KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Urethra, Via Natural or Artificial Opening Endoscopic */
"0TWD8LZ" = "1" /* Revision of Artificial Sphincter in Urethra, Via Natural or Artificial Opening Endoscopic */
"0TY00Z0" = "1" /* Transplantation of Right Kidney, Allogeneic, Open Approach */
"0TY00Z1" = "1" /* Transplantation of Right Kidney, Syngeneic, Open Approach */
"0TY00Z2" = "1" /* Transplantation of Right Kidney, Zooplastic, Open Approach */
"0TY10Z0" = "1" /* Transplantation of Left Kidney, Allogeneic, Open Approach */
"0TY10Z1" = "1" /* Transplantation of Left Kidney, Syngeneic, Open Approach */
"0TY10Z2" = "1" /* Transplantation of Left Kidney, Zooplastic, Open Approach */
"0U15075" = "1" /* Bypass Right Fallopian Tube to Right Fallopian Tube with Autologous Tissue Substitute, Open Approach */
"0U15076" = "1" /* Bypass Right Fallopian Tube to Left Fallopian Tube with Autologous Tissue Substitute, Open Approach */
"0U15079" = "1" /* Bypass Right Fallopian Tube to Uterus with Autologous Tissue Substitute, Open Approach */
"0U150J5" = "1" /* Bypass Right Fallopian Tube to Right Fallopian Tube with Synthetic Substitute, Open Approach */
"0U150J6" = "1" /* Bypass Right Fallopian Tube to Left Fallopian Tube with Synthetic Substitute, Open Approach */
"0U150J9" = "1" /* Bypass Right Fallopian Tube to Uterus with Synthetic Substitute, Open Approach */
"0U150K5" = "1" /* Bypass Right Fallopian Tube to Right Fallopian Tube with Nonautologous Tissue Substitute, Open Approach */
"0U150K6" = "1" /* Bypass Right Fallopian Tube to Left Fallopian Tube with Nonautologous Tissue Substitute, Open Approach */
"0U150K9" = "1" /* Bypass Right Fallopian Tube to Uterus with Nonautologous Tissue Substitute, Open Approach */
"0U150Z5" = "1" /* Bypass Right Fallopian Tube to Right Fallopian Tube, Open Approach */
"0U150Z6" = "1" /* Bypass Right Fallopian Tube to Left Fallopian Tube, Open Approach */
"0U150Z9" = "1" /* Bypass Right Fallopian Tube to Uterus, Open Approach */
"0U15475" = "1" /* Bypass Right Fallopian Tube to Right Fallopian Tube with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U15476" = "1" /* Bypass Right Fallopian Tube to Left Fallopian Tube with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U15479" = "1" /* Bypass Right Fallopian Tube to Uterus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U154J5" = "1" /* Bypass Right Fallopian Tube to Right Fallopian Tube with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0U154J6" = "1" /* Bypass Right Fallopian Tube to Left Fallopian Tube with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0U154J9" = "1" /* Bypass Right Fallopian Tube to Uterus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0U154K5" = "1" /* Bypass Right Fallopian Tube to Right Fallopian Tube with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U154K6" = "1" /* Bypass Right Fallopian Tube to Left Fallopian Tube with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U154K9" = "1" /* Bypass Right Fallopian Tube to Uterus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U154Z5" = "1" /* Bypass Right Fallopian Tube to Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0U154Z6" = "1" /* Bypass Right Fallopian Tube to Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0U154Z9" = "1" /* Bypass Right Fallopian Tube to Uterus, Percutaneous Endoscopic Approach */
"0U16075" = "1" /* Bypass Left Fallopian Tube to Right Fallopian Tube with Autologous Tissue Substitute, Open Approach */
"0U16076" = "1" /* Bypass Left Fallopian Tube to Left Fallopian Tube with Autologous Tissue Substitute, Open Approach */
"0U16079" = "1" /* Bypass Left Fallopian Tube to Uterus with Autologous Tissue Substitute, Open Approach */
"0U160J5" = "1" /* Bypass Left Fallopian Tube to Right Fallopian Tube with Synthetic Substitute, Open Approach */
"0U160J6" = "1" /* Bypass Left Fallopian Tube to Left Fallopian Tube with Synthetic Substitute, Open Approach */
"0U160J9" = "1" /* Bypass Left Fallopian Tube to Uterus with Synthetic Substitute, Open Approach */
"0U160K5" = "1" /* Bypass Left Fallopian Tube to Right Fallopian Tube with Nonautologous Tissue Substitute, Open Approach */
"0U160K6" = "1" /* Bypass Left Fallopian Tube to Left Fallopian Tube with Nonautologous Tissue Substitute, Open Approach */
"0U160K9" = "1" /* Bypass Left Fallopian Tube to Uterus with Nonautologous Tissue Substitute, Open Approach */
"0U160Z5" = "1" /* Bypass Left Fallopian Tube to Right Fallopian Tube, Open Approach */
"0U160Z6" = "1" /* Bypass Left Fallopian Tube to Left Fallopian Tube, Open Approach */
"0U160Z9" = "1" /* Bypass Left Fallopian Tube to Uterus, Open Approach */
"0U16475" = "1" /* Bypass Left Fallopian Tube to Right Fallopian Tube with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U16476" = "1" /* Bypass Left Fallopian Tube to Left Fallopian Tube with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U16479" = "1" /* Bypass Left Fallopian Tube to Uterus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U164J5" = "1" /* Bypass Left Fallopian Tube to Right Fallopian Tube with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0U164J6" = "1" /* Bypass Left Fallopian Tube to Left Fallopian Tube with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0U164J9" = "1" /* Bypass Left Fallopian Tube to Uterus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0U164K5" = "1" /* Bypass Left Fallopian Tube to Right Fallopian Tube with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U164K6" = "1" /* Bypass Left Fallopian Tube to Left Fallopian Tube with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U164K9" = "1" /* Bypass Left Fallopian Tube to Uterus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0U164Z5" = "1" /* Bypass Left Fallopian Tube to Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0U164Z6" = "1" /* Bypass Left Fallopian Tube to Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0U164Z9" = "1" /* Bypass Left Fallopian Tube to Uterus, Percutaneous Endoscopic Approach */
"0U500ZZ" = "1" /* Destruction of Right Ovary, Open Approach */
"0U503ZZ" = "1" /* Destruction of Right Ovary, Percutaneous Approach */
"0U504ZZ" = "1" /* Destruction of Right Ovary, Percutaneous Endoscopic Approach */
"0U510ZZ" = "1" /* Destruction of Left Ovary, Open Approach */
"0U513ZZ" = "1" /* Destruction of Left Ovary, Percutaneous Approach */
"0U514ZZ" = "1" /* Destruction of Left Ovary, Percutaneous Endoscopic Approach */
"0U520ZZ" = "1" /* Destruction of Bilateral Ovaries, Open Approach */
"0U523ZZ" = "1" /* Destruction of Bilateral Ovaries, Percutaneous Approach */
"0U524ZZ" = "1" /* Destruction of Bilateral Ovaries, Percutaneous Endoscopic Approach */
"0U540ZZ" = "1" /* Destruction of Uterine Supporting Structure, Open Approach */
"0U543ZZ" = "1" /* Destruction of Uterine Supporting Structure, Percutaneous Approach */
"0U544ZZ" = "1" /* Destruction of Uterine Supporting Structure, Percutaneous Endoscopic Approach */
"0U550ZZ" = "1" /* Destruction of Right Fallopian Tube, Open Approach */
"0U553ZZ" = "1" /* Destruction of Right Fallopian Tube, Percutaneous Approach */
"0U554ZZ" = "1" /* Destruction of Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0U557ZZ" = "1" /* Destruction of Right Fallopian Tube, Via Natural or Artificial Opening */
"0U558ZZ" = "1" /* Destruction of Right Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0U560ZZ" = "1" /* Destruction of Left Fallopian Tube, Open Approach */
"0U563ZZ" = "1" /* Destruction of Left Fallopian Tube, Percutaneous Approach */
"0U564ZZ" = "1" /* Destruction of Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0U567ZZ" = "1" /* Destruction of Left Fallopian Tube, Via Natural or Artificial Opening */
"0U568ZZ" = "1" /* Destruction of Left Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0U570ZZ" = "1" /* Destruction of Bilateral Fallopian Tubes, Open Approach */
"0U573ZZ" = "1" /* Destruction of Bilateral Fallopian Tubes, Percutaneous Approach */
"0U574ZZ" = "1" /* Destruction of Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0U577ZZ" = "1" /* Destruction of Bilateral Fallopian Tubes, Via Natural or Artificial Opening */
"0U578ZZ" = "1" /* Destruction of Bilateral Fallopian Tubes, Via Natural or Artificial Opening Endoscopic */
"0U590ZZ" = "1" /* Destruction of Uterus, Open Approach */
"0U593ZZ" = "1" /* Destruction of Uterus, Percutaneous Approach */
"0U594ZZ" = "1" /* Destruction of Uterus, Percutaneous Endoscopic Approach */
"0U597ZZ" = "1" /* Destruction of Uterus, Via Natural or Artificial Opening */
"0U598ZZ" = "1" /* Destruction of Uterus, Via Natural or Artificial Opening Endoscopic */
"0U5B0ZZ" = "1" /* Destruction of Endometrium, Open Approach */
"0U5B3ZZ" = "1" /* Destruction of Endometrium, Percutaneous Approach */
"0U5B4ZZ" = "1" /* Destruction of Endometrium, Percutaneous Endoscopic Approach */
"0U5B7ZZ" = "1" /* Destruction of Endometrium, Via Natural or Artificial Opening */
"0U5B8ZZ" = "1" /* Destruction of Endometrium, Via Natural or Artificial Opening Endoscopic */
"0U5C0ZZ" = "1" /* Destruction of Cervix, Open Approach */
"0U5C3ZZ" = "1" /* Destruction of Cervix, Percutaneous Approach */
"0U5C4ZZ" = "1" /* Destruction of Cervix, Percutaneous Endoscopic Approach */
"0U5C7ZZ" = "1" /* Destruction of Cervix, Via Natural or Artificial Opening */
"0U5C8ZZ" = "1" /* Destruction of Cervix, Via Natural or Artificial Opening Endoscopic */
"0U5F0ZZ" = "1" /* Destruction of Cul-de-sac, Open Approach */
"0U5F3ZZ" = "1" /* Destruction of Cul-de-sac, Percutaneous Approach */
"0U5F4ZZ" = "1" /* Destruction of Cul-de-sac, Percutaneous Endoscopic Approach */
"0U5F7ZZ" = "1" /* Destruction of Cul-de-sac, Via Natural or Artificial Opening */
"0U5F8ZZ" = "1" /* Destruction of Cul-de-sac, Via Natural or Artificial Opening Endoscopic */
"0U5G0ZZ" = "1" /* Destruction of Vagina, Open Approach */
"0U5G3ZZ" = "1" /* Destruction of Vagina, Percutaneous Approach */
"0U5G4ZZ" = "1" /* Destruction of Vagina, Percutaneous Endoscopic Approach */
"0U5G7ZZ" = "1" /* Destruction of Vagina, Via Natural or Artificial Opening */
"0U5G8ZZ" = "1" /* Destruction of Vagina, Via Natural or Artificial Opening Endoscopic */
"0U5GXZZ" = "1" /* Destruction of Vagina, External Approach */
"0U5J0ZZ" = "1" /* Destruction of Clitoris, Open Approach */
"0U5JXZZ" = "1" /* Destruction of Clitoris, External Approach */
"0U5K0ZZ" = "1" /* Destruction of Hymen, Open Approach */
"0U5K3ZZ" = "1" /* Destruction of Hymen, Percutaneous Approach */
"0U5K4ZZ" = "1" /* Destruction of Hymen, Percutaneous Endoscopic Approach */
"0U5K7ZZ" = "1" /* Destruction of Hymen, Via Natural or Artificial Opening */
"0U5K8ZZ" = "1" /* Destruction of Hymen, Via Natural or Artificial Opening Endoscopic */
"0U5KXZZ" = "1" /* Destruction of Hymen, External Approach */
"0U5L0ZZ" = "1" /* Destruction of Vestibular Gland, Open Approach */
"0U5LXZZ" = "1" /* Destruction of Vestibular Gland, External Approach */
"0U5M0ZZ" = "1" /* Destruction of Vulva, Open Approach */
"0U5MXZZ" = "1" /* Destruction of Vulva, External Approach */
"0U750DZ" = "1" /* Dilation of Right Fallopian Tube with Intraluminal Device, Open Approach */
"0U750ZZ" = "1" /* Dilation of Right Fallopian Tube, Open Approach */
"0U753DZ" = "1" /* Dilation of Right Fallopian Tube with Intraluminal Device, Percutaneous Approach */
"0U753ZZ" = "1" /* Dilation of Right Fallopian Tube, Percutaneous Approach */
"0U754DZ" = "1" /* Dilation of Right Fallopian Tube with Intraluminal Device, Percutaneous Endoscopic Approach */
"0U754ZZ" = "1" /* Dilation of Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0U757DZ" = "1" /* Dilation of Right Fallopian Tube with Intraluminal Device, Via Natural or Artificial Opening */
"0U757ZZ" = "1" /* Dilation of Right Fallopian Tube, Via Natural or Artificial Opening */
"0U758DZ" = "1" /* Dilation of Right Fallopian Tube with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0U758ZZ" = "1" /* Dilation of Right Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0U760DZ" = "1" /* Dilation of Left Fallopian Tube with Intraluminal Device, Open Approach */
"0U760ZZ" = "1" /* Dilation of Left Fallopian Tube, Open Approach */
"0U763DZ" = "1" /* Dilation of Left Fallopian Tube with Intraluminal Device, Percutaneous Approach */
"0U763ZZ" = "1" /* Dilation of Left Fallopian Tube, Percutaneous Approach */
"0U764DZ" = "1" /* Dilation of Left Fallopian Tube with Intraluminal Device, Percutaneous Endoscopic Approach */
"0U764ZZ" = "1" /* Dilation of Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0U767DZ" = "1" /* Dilation of Left Fallopian Tube with Intraluminal Device, Via Natural or Artificial Opening */
"0U767ZZ" = "1" /* Dilation of Left Fallopian Tube, Via Natural or Artificial Opening */
"0U768DZ" = "1" /* Dilation of Left Fallopian Tube with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0U768ZZ" = "1" /* Dilation of Left Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0U770DZ" = "1" /* Dilation of Bilateral Fallopian Tubes with Intraluminal Device, Open Approach */
"0U770ZZ" = "1" /* Dilation of Bilateral Fallopian Tubes, Open Approach */
"0U773DZ" = "1" /* Dilation of Bilateral Fallopian Tubes with Intraluminal Device, Percutaneous Approach */
"0U773ZZ" = "1" /* Dilation of Bilateral Fallopian Tubes, Percutaneous Approach */
"0U774DZ" = "1" /* Dilation of Bilateral Fallopian Tubes with Intraluminal Device, Percutaneous Endoscopic Approach */
"0U774ZZ" = "1" /* Dilation of Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0U777DZ" = "1" /* Dilation of Bilateral Fallopian Tubes with Intraluminal Device, Via Natural or Artificial Opening */
"0U777ZZ" = "1" /* Dilation of Bilateral Fallopian Tubes, Via Natural or Artificial Opening */
"0U778DZ" = "1" /* Dilation of Bilateral Fallopian Tubes with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0U778ZZ" = "1" /* Dilation of Bilateral Fallopian Tubes, Via Natural or Artificial Opening Endoscopic */
"0U790DZ" = "1" /* Dilation of Uterus with Intraluminal Device, Open Approach */
"0U790ZZ" = "1" /* Dilation of Uterus, Open Approach */
"0U793DZ" = "1" /* Dilation of Uterus with Intraluminal Device, Percutaneous Approach */
"0U793ZZ" = "1" /* Dilation of Uterus, Percutaneous Approach */
"0U794DZ" = "1" /* Dilation of Uterus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0U794ZZ" = "1" /* Dilation of Uterus, Percutaneous Endoscopic Approach */
"0U797DZ" = "1" /* Dilation of Uterus with Intraluminal Device, Via Natural or Artificial Opening */
"0U797ZZ" = "1" /* Dilation of Uterus, Via Natural or Artificial Opening */
"0U798DZ" = "1" /* Dilation of Uterus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0U798ZZ" = "1" /* Dilation of Uterus, Via Natural or Artificial Opening Endoscopic */
"0U7G0DZ" = "1" /* Dilation of Vagina with Intraluminal Device, Open Approach */
"0U7G0ZZ" = "1" /* Dilation of Vagina, Open Approach */
"0U7G3DZ" = "1" /* Dilation of Vagina with Intraluminal Device, Percutaneous Approach */
"0U7G3ZZ" = "1" /* Dilation of Vagina, Percutaneous Approach */
"0U7G4DZ" = "1" /* Dilation of Vagina with Intraluminal Device, Percutaneous Endoscopic Approach */
"0U7G4ZZ" = "1" /* Dilation of Vagina, Percutaneous Endoscopic Approach */
"0U7K0DZ" = "1" /* Dilation of Hymen with Intraluminal Device, Open Approach */
"0U7K0ZZ" = "1" /* Dilation of Hymen, Open Approach */
"0U7K3DZ" = "1" /* Dilation of Hymen with Intraluminal Device, Percutaneous Approach */
"0U7K3ZZ" = "1" /* Dilation of Hymen, Percutaneous Approach */
"0U7K4DZ" = "1" /* Dilation of Hymen with Intraluminal Device, Percutaneous Endoscopic Approach */
"0U7K4ZZ" = "1" /* Dilation of Hymen, Percutaneous Endoscopic Approach */
"0U7K7DZ" = "1" /* Dilation of Hymen with Intraluminal Device, Via Natural or Artificial Opening */
"0U7K7ZZ" = "1" /* Dilation of Hymen, Via Natural or Artificial Opening */
"0U7K8DZ" = "1" /* Dilation of Hymen with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0U7K8ZZ" = "1" /* Dilation of Hymen, Via Natural or Artificial Opening Endoscopic */
"0U7KXDZ" = "1" /* Dilation of Hymen with Intraluminal Device, External Approach */
"0U7KXZZ" = "1" /* Dilation of Hymen, External Approach */
"0U800ZZ" = "1" /* Division of Right Ovary, Open Approach */
"0U803ZZ" = "1" /* Division of Right Ovary, Percutaneous Approach */
"0U804ZZ" = "1" /* Division of Right Ovary, Percutaneous Endoscopic Approach */
"0U810ZZ" = "1" /* Division of Left Ovary, Open Approach */
"0U813ZZ" = "1" /* Division of Left Ovary, Percutaneous Approach */
"0U814ZZ" = "1" /* Division of Left Ovary, Percutaneous Endoscopic Approach */
"0U820ZZ" = "1" /* Division of Bilateral Ovaries, Open Approach */
"0U823ZZ" = "1" /* Division of Bilateral Ovaries, Percutaneous Approach */
"0U824ZZ" = "1" /* Division of Bilateral Ovaries, Percutaneous Endoscopic Approach */
"0U840ZZ" = "1" /* Division of Uterine Supporting Structure, Open Approach */
"0U843ZZ" = "1" /* Division of Uterine Supporting Structure, Percutaneous Approach */
"0U844ZZ" = "1" /* Division of Uterine Supporting Structure, Percutaneous Endoscopic Approach */
"0U9000Z" = "1" /* Drainage of Right Ovary with Drainage Device, Open Approach */
"0U900ZX" = "1" /* Drainage of Right Ovary, Open Approach, Diagnostic */
"0U900ZZ" = "1" /* Drainage of Right Ovary, Open Approach */
"0U9040Z" = "1" /* Drainage of Right Ovary with Drainage Device, Percutaneous Endoscopic Approach */
"0U904ZX" = "1" /* Drainage of Right Ovary, Percutaneous Endoscopic Approach, Diagnostic */
"0U904ZZ" = "1" /* Drainage of Right Ovary, Percutaneous Endoscopic Approach */
"0U90XZZ" = "1" /* Drainage of Right Ovary, External Approach */
"0U9100Z" = "1" /* Drainage of Left Ovary with Drainage Device, Open Approach */
"0U910ZX" = "1" /* Drainage of Left Ovary, Open Approach, Diagnostic */
"0U910ZZ" = "1" /* Drainage of Left Ovary, Open Approach */
"0U9140Z" = "1" /* Drainage of Left Ovary with Drainage Device, Percutaneous Endoscopic Approach */
"0U914ZX" = "1" /* Drainage of Left Ovary, Percutaneous Endoscopic Approach, Diagnostic */
"0U914ZZ" = "1" /* Drainage of Left Ovary, Percutaneous Endoscopic Approach */
"0U91XZZ" = "1" /* Drainage of Left Ovary, External Approach */
"0U9200Z" = "1" /* Drainage of Bilateral Ovaries with Drainage Device, Open Approach */
"0U920ZX" = "1" /* Drainage of Bilateral Ovaries, Open Approach, Diagnostic */
"0U920ZZ" = "1" /* Drainage of Bilateral Ovaries, Open Approach */
"0U9240Z" = "1" /* Drainage of Bilateral Ovaries with Drainage Device, Percutaneous Endoscopic Approach */
"0U924ZX" = "1" /* Drainage of Bilateral Ovaries, Percutaneous Endoscopic Approach, Diagnostic */
"0U924ZZ" = "1" /* Drainage of Bilateral Ovaries, Percutaneous Endoscopic Approach */
"0U92XZZ" = "1" /* Drainage of Bilateral Ovaries, External Approach */
"0U9400Z" = "1" /* Drainage of Uterine Supporting Structure with Drainage Device, Open Approach */
"0U940ZX" = "1" /* Drainage of Uterine Supporting Structure, Open Approach, Diagnostic */
"0U940ZZ" = "1" /* Drainage of Uterine Supporting Structure, Open Approach */
"0U9440Z" = "1" /* Drainage of Uterine Supporting Structure with Drainage Device, Percutaneous Endoscopic Approach */
"0U944ZX" = "1" /* Drainage of Uterine Supporting Structure, Percutaneous Endoscopic Approach, Diagnostic */
"0U944ZZ" = "1" /* Drainage of Uterine Supporting Structure, Percutaneous Endoscopic Approach */
"0U9500Z" = "1" /* Drainage of Right Fallopian Tube with Drainage Device, Open Approach */
"0U950ZX" = "1" /* Drainage of Right Fallopian Tube, Open Approach, Diagnostic */
"0U950ZZ" = "1" /* Drainage of Right Fallopian Tube, Open Approach */
"0U9540Z" = "1" /* Drainage of Right Fallopian Tube with Drainage Device, Percutaneous Endoscopic Approach */
"0U954ZX" = "1" /* Drainage of Right Fallopian Tube, Percutaneous Endoscopic Approach, Diagnostic */
"0U9570Z" = "1" /* Drainage of Right Fallopian Tube with Drainage Device, Via Natural or Artificial Opening */
"0U957ZX" = "1" /* Drainage of Right Fallopian Tube, Via Natural or Artificial Opening, Diagnostic */
"0U9580Z" = "1" /* Drainage of Right Fallopian Tube with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0U958ZX" = "1" /* Drainage of Right Fallopian Tube, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0U9600Z" = "1" /* Drainage of Left Fallopian Tube with Drainage Device, Open Approach */
"0U960ZX" = "1" /* Drainage of Left Fallopian Tube, Open Approach, Diagnostic */
"0U960ZZ" = "1" /* Drainage of Left Fallopian Tube, Open Approach */
"0U9640Z" = "1" /* Drainage of Left Fallopian Tube with Drainage Device, Percutaneous Endoscopic Approach */
"0U964ZX" = "1" /* Drainage of Left Fallopian Tube, Percutaneous Endoscopic Approach, Diagnostic */
"0U9670Z" = "1" /* Drainage of Left Fallopian Tube with Drainage Device, Via Natural or Artificial Opening */
"0U967ZX" = "1" /* Drainage of Left Fallopian Tube, Via Natural or Artificial Opening, Diagnostic */
"0U9680Z" = "1" /* Drainage of Left Fallopian Tube with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0U968ZX" = "1" /* Drainage of Left Fallopian Tube, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0U9700Z" = "1" /* Drainage of Bilateral Fallopian Tubes with Drainage Device, Open Approach */
"0U970ZX" = "1" /* Drainage of Bilateral Fallopian Tubes, Open Approach, Diagnostic */
"0U970ZZ" = "1" /* Drainage of Bilateral Fallopian Tubes, Open Approach */
"0U9740Z" = "1" /* Drainage of Bilateral Fallopian Tubes with Drainage Device, Percutaneous Endoscopic Approach */
"0U974ZX" = "1" /* Drainage of Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach, Diagnostic */
"0U9770Z" = "1" /* Drainage of Bilateral Fallopian Tubes with Drainage Device, Via Natural or Artificial Opening */
"0U977ZX" = "1" /* Drainage of Bilateral Fallopian Tubes, Via Natural or Artificial Opening, Diagnostic */
"0U9780Z" = "1" /* Drainage of Bilateral Fallopian Tubes with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0U978ZX" = "1" /* Drainage of Bilateral Fallopian Tubes, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0U9900Z" = "1" /* Drainage of Uterus with Drainage Device, Open Approach */
"0U990ZX" = "1" /* Drainage of Uterus, Open Approach, Diagnostic */
"0U990ZZ" = "1" /* Drainage of Uterus, Open Approach */
"0U9940Z" = "1" /* Drainage of Uterus with Drainage Device, Percutaneous Endoscopic Approach */
"0U994ZX" = "1" /* Drainage of Uterus, Percutaneous Endoscopic Approach, Diagnostic */
"0U994ZZ" = "1" /* Drainage of Uterus, Percutaneous Endoscopic Approach */
"0U9970Z" = "1" /* Drainage of Uterus with Drainage Device, Via Natural or Artificial Opening */
"0U997ZX" = "1" /* Drainage of Uterus, Via Natural or Artificial Opening, Diagnostic */
"0U997ZZ" = "1" /* Drainage of Uterus, Via Natural or Artificial Opening */
"0U9980Z" = "1" /* Drainage of Uterus with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0U998ZX" = "1" /* Drainage of Uterus, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0U998ZZ" = "1" /* Drainage of Uterus, Via Natural or Artificial Opening Endoscopic */
"0U9C00Z" = "1" /* Drainage of Cervix with Drainage Device, Open Approach */
"0U9C0ZX" = "1" /* Drainage of Cervix, Open Approach, Diagnostic */
"0U9C0ZZ" = "1" /* Drainage of Cervix, Open Approach */
"0U9C40Z" = "1" /* Drainage of Cervix with Drainage Device, Percutaneous Endoscopic Approach */
"0U9C4ZX" = "1" /* Drainage of Cervix, Percutaneous Endoscopic Approach, Diagnostic */
"0U9C4ZZ" = "1" /* Drainage of Cervix, Percutaneous Endoscopic Approach */
"0U9C70Z" = "1" /* Drainage of Cervix with Drainage Device, Via Natural or Artificial Opening */
"0U9C7ZX" = "1" /* Drainage of Cervix, Via Natural or Artificial Opening, Diagnostic */
"0U9C7ZZ" = "1" /* Drainage of Cervix, Via Natural or Artificial Opening */
"0U9C80Z" = "1" /* Drainage of Cervix with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0U9C8ZX" = "1" /* Drainage of Cervix, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0U9C8ZZ" = "1" /* Drainage of Cervix, Via Natural or Artificial Opening Endoscopic */
"0U9F00Z" = "1" /* Drainage of Cul-de-sac with Drainage Device, Open Approach */
"0U9F0ZX" = "1" /* Drainage of Cul-de-sac, Open Approach, Diagnostic */
"0U9F0ZZ" = "1" /* Drainage of Cul-de-sac, Open Approach */
"0U9F4ZX" = "1" /* Drainage of Cul-de-sac, Percutaneous Endoscopic Approach, Diagnostic */
"0U9F70Z" = "1" /* Drainage of Cul-de-sac with Drainage Device, Via Natural or Artificial Opening */
"0U9F7ZX" = "1" /* Drainage of Cul-de-sac, Via Natural or Artificial Opening, Diagnostic */
"0U9F7ZZ" = "1" /* Drainage of Cul-de-sac, Via Natural or Artificial Opening */
"0U9F80Z" = "1" /* Drainage of Cul-de-sac with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0U9F8ZX" = "1" /* Drainage of Cul-de-sac, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0U9F8ZZ" = "1" /* Drainage of Cul-de-sac, Via Natural or Artificial Opening Endoscopic */
"0U9G00Z" = "1" /* Drainage of Vagina with Drainage Device, Open Approach */
"0U9G0ZX" = "1" /* Drainage of Vagina, Open Approach, Diagnostic */
"0U9G0ZZ" = "1" /* Drainage of Vagina, Open Approach */
"0U9G40Z" = "1" /* Drainage of Vagina with Drainage Device, Percutaneous Endoscopic Approach */
"0U9G4ZX" = "1" /* Drainage of Vagina, Percutaneous Endoscopic Approach, Diagnostic */
"0U9G4ZZ" = "1" /* Drainage of Vagina, Percutaneous Endoscopic Approach */
"0U9G70Z" = "1" /* Drainage of Vagina with Drainage Device, Via Natural or Artificial Opening */
"0U9G7ZX" = "1" /* Drainage of Vagina, Via Natural or Artificial Opening, Diagnostic */
"0U9G7ZZ" = "1" /* Drainage of Vagina, Via Natural or Artificial Opening */
"0U9G80Z" = "1" /* Drainage of Vagina with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0U9G8ZX" = "1" /* Drainage of Vagina, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0U9G8ZZ" = "1" /* Drainage of Vagina, Via Natural or Artificial Opening Endoscopic */
"0U9GX0Z" = "1" /* Drainage of Vagina with Drainage Device, External Approach */
"0U9GXZX" = "1" /* Drainage of Vagina, External Approach, Diagnostic */
"0U9GXZZ" = "1" /* Drainage of Vagina, External Approach */
"0U9J00Z" = "1" /* Drainage of Clitoris with Drainage Device, Open Approach */
"0U9J0ZX" = "1" /* Drainage of Clitoris, Open Approach, Diagnostic */
"0U9J0ZZ" = "1" /* Drainage of Clitoris, Open Approach */
"0U9JX0Z" = "1" /* Drainage of Clitoris with Drainage Device, External Approach */
"0U9JXZX" = "1" /* Drainage of Clitoris, External Approach, Diagnostic */
"0U9JXZZ" = "1" /* Drainage of Clitoris, External Approach */
"0U9K0ZX" = "1" /* Drainage of Hymen, Open Approach, Diagnostic */
"0U9K4ZX" = "1" /* Drainage of Hymen, Percutaneous Endoscopic Approach, Diagnostic */
"0U9K7ZX" = "1" /* Drainage of Hymen, Via Natural or Artificial Opening, Diagnostic */
"0U9K8ZX" = "1" /* Drainage of Hymen, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0U9KXZX" = "1" /* Drainage of Hymen, External Approach, Diagnostic */
"0U9L0ZX" = "1" /* Drainage of Vestibular Gland, Open Approach, Diagnostic */
"0U9LXZX" = "1" /* Drainage of Vestibular Gland, External Approach, Diagnostic */
"0U9M00Z" = "1" /* Drainage of Vulva with Drainage Device, Open Approach */
"0U9M0ZX" = "1" /* Drainage of Vulva, Open Approach, Diagnostic */
"0U9M0ZZ" = "1" /* Drainage of Vulva, Open Approach */
"0U9MX0Z" = "1" /* Drainage of Vulva with Drainage Device, External Approach */
"0U9MXZX" = "1" /* Drainage of Vulva, External Approach, Diagnostic */
"0U9MXZZ" = "1" /* Drainage of Vulva, External Approach */
"0UB00ZX" = "1" /* Excision of Right Ovary, Open Approach, Diagnostic */
"0UB00ZZ" = "1" /* Excision of Right Ovary, Open Approach */
"0UB03ZX" = "1" /* Excision of Right Ovary, Percutaneous Approach, Diagnostic */
"0UB03ZZ" = "1" /* Excision of Right Ovary, Percutaneous Approach */
"0UB04ZX" = "1" /* Excision of Right Ovary, Percutaneous Endoscopic Approach, Diagnostic */
"0UB04ZZ" = "1" /* Excision of Right Ovary, Percutaneous Endoscopic Approach */
"0UB07ZX" = "1" /* Excision of Right Ovary, Via Natural or Artificial Opening, Diagnostic */
"0UB07ZZ" = "1" /* Excision of Right Ovary, Via Natural or Artificial Opening */
"0UB08ZX" = "1" /* Excision of Right Ovary, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0UB08ZZ" = "1" /* Excision of Right Ovary, Via Natural or Artificial Opening Endoscopic */
"0UB10ZX" = "1" /* Excision of Left Ovary, Open Approach, Diagnostic */
"0UB10ZZ" = "1" /* Excision of Left Ovary, Open Approach */
"0UB13ZX" = "1" /* Excision of Left Ovary, Percutaneous Approach, Diagnostic */
"0UB13ZZ" = "1" /* Excision of Left Ovary, Percutaneous Approach */
"0UB14ZX" = "1" /* Excision of Left Ovary, Percutaneous Endoscopic Approach, Diagnostic */
"0UB14ZZ" = "1" /* Excision of Left Ovary, Percutaneous Endoscopic Approach */
"0UB17ZX" = "1" /* Excision of Left Ovary, Via Natural or Artificial Opening, Diagnostic */
"0UB17ZZ" = "1" /* Excision of Left Ovary, Via Natural or Artificial Opening */
"0UB18ZX" = "1" /* Excision of Left Ovary, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0UB18ZZ" = "1" /* Excision of Left Ovary, Via Natural or Artificial Opening Endoscopic */
"0UB20ZX" = "1" /* Excision of Bilateral Ovaries, Open Approach, Diagnostic */
"0UB20ZZ" = "1" /* Excision of Bilateral Ovaries, Open Approach */
"0UB23ZX" = "1" /* Excision of Bilateral Ovaries, Percutaneous Approach, Diagnostic */
"0UB23ZZ" = "1" /* Excision of Bilateral Ovaries, Percutaneous Approach */
"0UB24ZX" = "1" /* Excision of Bilateral Ovaries, Percutaneous Endoscopic Approach, Diagnostic */
"0UB24ZZ" = "1" /* Excision of Bilateral Ovaries, Percutaneous Endoscopic Approach */
"0UB27ZX" = "1" /* Excision of Bilateral Ovaries, Via Natural or Artificial Opening, Diagnostic */
"0UB27ZZ" = "1" /* Excision of Bilateral Ovaries, Via Natural or Artificial Opening */
"0UB28ZX" = "1" /* Excision of Bilateral Ovaries, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0UB28ZZ" = "1" /* Excision of Bilateral Ovaries, Via Natural or Artificial Opening Endoscopic */
"0UB40ZX" = "1" /* Excision of Uterine Supporting Structure, Open Approach, Diagnostic */
"0UB40ZZ" = "1" /* Excision of Uterine Supporting Structure, Open Approach */
"0UB43ZX" = "1" /* Excision of Uterine Supporting Structure, Percutaneous Approach, Diagnostic */
"0UB43ZZ" = "1" /* Excision of Uterine Supporting Structure, Percutaneous Approach */
"0UB44ZX" = "1" /* Excision of Uterine Supporting Structure, Percutaneous Endoscopic Approach, Diagnostic */
"0UB44ZZ" = "1" /* Excision of Uterine Supporting Structure, Percutaneous Endoscopic Approach */
"0UB47ZX" = "1" /* Excision of Uterine Supporting Structure, Via Natural or Artificial Opening, Diagnostic */
"0UB47ZZ" = "1" /* Excision of Uterine Supporting Structure, Via Natural or Artificial Opening */
"0UB48ZX" = "1" /* Excision of Uterine Supporting Structure, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0UB48ZZ" = "1" /* Excision of Uterine Supporting Structure, Via Natural or Artificial Opening Endoscopic */
"0UB50ZX" = "1" /* Excision of Right Fallopian Tube, Open Approach, Diagnostic */
"0UB50ZZ" = "1" /* Excision of Right Fallopian Tube, Open Approach */
"0UB53ZX" = "1" /* Excision of Right Fallopian Tube, Percutaneous Approach, Diagnostic */
"0UB53ZZ" = "1" /* Excision of Right Fallopian Tube, Percutaneous Approach */
"0UB54ZX" = "1" /* Excision of Right Fallopian Tube, Percutaneous Endoscopic Approach, Diagnostic */
"0UB54ZZ" = "1" /* Excision of Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0UB57ZX" = "1" /* Excision of Right Fallopian Tube, Via Natural or Artificial Opening, Diagnostic */
"0UB57ZZ" = "1" /* Excision of Right Fallopian Tube, Via Natural or Artificial Opening */
"0UB58ZX" = "1" /* Excision of Right Fallopian Tube, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0UB58ZZ" = "1" /* Excision of Right Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UB60ZX" = "1" /* Excision of Left Fallopian Tube, Open Approach, Diagnostic */
"0UB60ZZ" = "1" /* Excision of Left Fallopian Tube, Open Approach */
"0UB63ZX" = "1" /* Excision of Left Fallopian Tube, Percutaneous Approach, Diagnostic */
"0UB63ZZ" = "1" /* Excision of Left Fallopian Tube, Percutaneous Approach */
"0UB64ZX" = "1" /* Excision of Left Fallopian Tube, Percutaneous Endoscopic Approach, Diagnostic */
"0UB64ZZ" = "1" /* Excision of Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0UB67ZX" = "1" /* Excision of Left Fallopian Tube, Via Natural or Artificial Opening, Diagnostic */
"0UB67ZZ" = "1" /* Excision of Left Fallopian Tube, Via Natural or Artificial Opening */
"0UB68ZX" = "1" /* Excision of Left Fallopian Tube, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0UB68ZZ" = "1" /* Excision of Left Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UB70ZX" = "1" /* Excision of Bilateral Fallopian Tubes, Open Approach, Diagnostic */
"0UB70ZZ" = "1" /* Excision of Bilateral Fallopian Tubes, Open Approach */
"0UB73ZX" = "1" /* Excision of Bilateral Fallopian Tubes, Percutaneous Approach, Diagnostic */
"0UB73ZZ" = "1" /* Excision of Bilateral Fallopian Tubes, Percutaneous Approach */
"0UB74ZX" = "1" /* Excision of Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach, Diagnostic */
"0UB74ZZ" = "1" /* Excision of Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0UB77ZX" = "1" /* Excision of Bilateral Fallopian Tubes, Via Natural or Artificial Opening, Diagnostic */
"0UB77ZZ" = "1" /* Excision of Bilateral Fallopian Tubes, Via Natural or Artificial Opening */
"0UB78ZX" = "1" /* Excision of Bilateral Fallopian Tubes, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0UB78ZZ" = "1" /* Excision of Bilateral Fallopian Tubes, Via Natural or Artificial Opening Endoscopic */
"0UB90ZX" = "1" /* Excision of Uterus, Open Approach, Diagnostic */
"0UB90ZZ" = "1" /* Excision of Uterus, Open Approach */
"0UB93ZX" = "1" /* Excision of Uterus, Percutaneous Approach, Diagnostic */
"0UB93ZZ" = "1" /* Excision of Uterus, Percutaneous Approach */
"0UB94ZX" = "1" /* Excision of Uterus, Percutaneous Endoscopic Approach, Diagnostic */
"0UB94ZZ" = "1" /* Excision of Uterus, Percutaneous Endoscopic Approach */
"0UB97ZX" = "1" /* Excision of Uterus, Via Natural or Artificial Opening, Diagnostic */
"0UB97ZZ" = "1" /* Excision of Uterus, Via Natural or Artificial Opening */
"0UB98ZX" = "1" /* Excision of Uterus, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0UB98ZZ" = "1" /* Excision of Uterus, Via Natural or Artificial Opening Endoscopic */
"0UBC0ZX" = "1" /* Excision of Cervix, Open Approach, Diagnostic */
"0UBC0ZZ" = "1" /* Excision of Cervix, Open Approach */
"0UBC3ZX" = "1" /* Excision of Cervix, Percutaneous Approach, Diagnostic */
"0UBC3ZZ" = "1" /* Excision of Cervix, Percutaneous Approach */
"0UBC4ZX" = "1" /* Excision of Cervix, Percutaneous Endoscopic Approach, Diagnostic */
"0UBC4ZZ" = "1" /* Excision of Cervix, Percutaneous Endoscopic Approach */
"0UBC7ZX" = "1" /* Excision of Cervix, Via Natural or Artificial Opening, Diagnostic */
"0UBC7ZZ" = "1" /* Excision of Cervix, Via Natural or Artificial Opening */
"0UBC8ZX" = "1" /* Excision of Cervix, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0UBC8ZZ" = "1" /* Excision of Cervix, Via Natural or Artificial Opening Endoscopic */
"0UBF0ZX" = "1" /* Excision of Cul-de-sac, Open Approach, Diagnostic */
"0UBF0ZZ" = "1" /* Excision of Cul-de-sac, Open Approach */
"0UBF3ZX" = "1" /* Excision of Cul-de-sac, Percutaneous Approach, Diagnostic */
"0UBF3ZZ" = "1" /* Excision of Cul-de-sac, Percutaneous Approach */
"0UBF4ZX" = "1" /* Excision of Cul-de-sac, Percutaneous Endoscopic Approach, Diagnostic */
"0UBF4ZZ" = "1" /* Excision of Cul-de-sac, Percutaneous Endoscopic Approach */
"0UBF7ZX" = "1" /* Excision of Cul-de-sac, Via Natural or Artificial Opening, Diagnostic */
"0UBF7ZZ" = "1" /* Excision of Cul-de-sac, Via Natural or Artificial Opening */
"0UBF8ZX" = "1" /* Excision of Cul-de-sac, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0UBF8ZZ" = "1" /* Excision of Cul-de-sac, Via Natural or Artificial Opening Endoscopic */
"0UBG0ZX" = "1" /* Excision of Vagina, Open Approach, Diagnostic */
"0UBG0ZZ" = "1" /* Excision of Vagina, Open Approach */
"0UBG3ZX" = "1" /* Excision of Vagina, Percutaneous Approach, Diagnostic */
"0UBG3ZZ" = "1" /* Excision of Vagina, Percutaneous Approach */
"0UBG4ZX" = "1" /* Excision of Vagina, Percutaneous Endoscopic Approach, Diagnostic */
"0UBG4ZZ" = "1" /* Excision of Vagina, Percutaneous Endoscopic Approach */
"0UBG7ZX" = "1" /* Excision of Vagina, Via Natural or Artificial Opening, Diagnostic */
"0UBG7ZZ" = "1" /* Excision of Vagina, Via Natural or Artificial Opening */
"0UBG8ZX" = "1" /* Excision of Vagina, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0UBG8ZZ" = "1" /* Excision of Vagina, Via Natural or Artificial Opening Endoscopic */
"0UBGXZX" = "1" /* Excision of Vagina, External Approach, Diagnostic */
"0UBGXZZ" = "1" /* Excision of Vagina, External Approach */
"0UBJ0ZX" = "1" /* Excision of Clitoris, Open Approach, Diagnostic */
"0UBJ0ZZ" = "1" /* Excision of Clitoris, Open Approach */
"0UBJXZX" = "1" /* Excision of Clitoris, External Approach, Diagnostic */
"0UBJXZZ" = "1" /* Excision of Clitoris, External Approach */
"0UBK0ZX" = "1" /* Excision of Hymen, Open Approach, Diagnostic */
"0UBK0ZZ" = "1" /* Excision of Hymen, Open Approach */
"0UBK3ZX" = "1" /* Excision of Hymen, Percutaneous Approach, Diagnostic */
"0UBK3ZZ" = "1" /* Excision of Hymen, Percutaneous Approach */
"0UBK4ZX" = "1" /* Excision of Hymen, Percutaneous Endoscopic Approach, Diagnostic */
"0UBK4ZZ" = "1" /* Excision of Hymen, Percutaneous Endoscopic Approach */
"0UBK7ZX" = "1" /* Excision of Hymen, Via Natural or Artificial Opening, Diagnostic */
"0UBK7ZZ" = "1" /* Excision of Hymen, Via Natural or Artificial Opening */
"0UBK8ZX" = "1" /* Excision of Hymen, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0UBK8ZZ" = "1" /* Excision of Hymen, Via Natural or Artificial Opening Endoscopic */
"0UBKXZX" = "1" /* Excision of Hymen, External Approach, Diagnostic */
"0UBKXZZ" = "1" /* Excision of Hymen, External Approach */
"0UBL0ZX" = "1" /* Excision of Vestibular Gland, Open Approach, Diagnostic */
"0UBL0ZZ" = "1" /* Excision of Vestibular Gland, Open Approach */
"0UBLXZX" = "1" /* Excision of Vestibular Gland, External Approach, Diagnostic */
"0UBLXZZ" = "1" /* Excision of Vestibular Gland, External Approach */
"0UBM0ZX" = "1" /* Excision of Vulva, Open Approach, Diagnostic */
"0UBM0ZZ" = "1" /* Excision of Vulva, Open Approach */
"0UBMXZX" = "1" /* Excision of Vulva, External Approach, Diagnostic */
"0UBMXZZ" = "1" /* Excision of Vulva, External Approach */
"0UC00ZZ" = "1" /* Extirpation of Matter from Right Ovary, Open Approach */
"0UC03ZZ" = "1" /* Extirpation of Matter from Right Ovary, Percutaneous Approach */
"0UC04ZZ" = "1" /* Extirpation of Matter from Right Ovary, Percutaneous Endoscopic Approach */
"0UC10ZZ" = "1" /* Extirpation of Matter from Left Ovary, Open Approach */
"0UC13ZZ" = "1" /* Extirpation of Matter from Left Ovary, Percutaneous Approach */
"0UC14ZZ" = "1" /* Extirpation of Matter from Left Ovary, Percutaneous Endoscopic Approach */
"0UC20ZZ" = "1" /* Extirpation of Matter from Bilateral Ovaries, Open Approach */
"0UC23ZZ" = "1" /* Extirpation of Matter from Bilateral Ovaries, Percutaneous Approach */
"0UC24ZZ" = "1" /* Extirpation of Matter from Bilateral Ovaries, Percutaneous Endoscopic Approach */
"0UC40ZZ" = "1" /* Extirpation of Matter from Uterine Supporting Structure, Open Approach */
"0UC43ZZ" = "1" /* Extirpation of Matter from Uterine Supporting Structure, Percutaneous Approach */
"0UC44ZZ" = "1" /* Extirpation of Matter from Uterine Supporting Structure, Percutaneous Endoscopic Approach */
"0UC50ZZ" = "1" /* Extirpation of Matter from Right Fallopian Tube, Open Approach */
"0UC53ZZ" = "1" /* Extirpation of Matter from Right Fallopian Tube, Percutaneous Approach */
"0UC54ZZ" = "1" /* Extirpation of Matter from Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0UC57ZZ" = "1" /* Extirpation of Matter from Right Fallopian Tube, Via Natural or Artificial Opening */
"0UC58ZZ" = "1" /* Extirpation of Matter from Right Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UC60ZZ" = "1" /* Extirpation of Matter from Left Fallopian Tube, Open Approach */
"0UC63ZZ" = "1" /* Extirpation of Matter from Left Fallopian Tube, Percutaneous Approach */
"0UC64ZZ" = "1" /* Extirpation of Matter from Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0UC67ZZ" = "1" /* Extirpation of Matter from Left Fallopian Tube, Via Natural or Artificial Opening */
"0UC68ZZ" = "1" /* Extirpation of Matter from Left Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UC70ZZ" = "1" /* Extirpation of Matter from Bilateral Fallopian Tubes, Open Approach */
"0UC73ZZ" = "1" /* Extirpation of Matter from Bilateral Fallopian Tubes, Percutaneous Approach */
"0UC74ZZ" = "1" /* Extirpation of Matter from Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0UC77ZZ" = "1" /* Extirpation of Matter from Bilateral Fallopian Tubes, Via Natural or Artificial Opening */
"0UC78ZZ" = "1" /* Extirpation of Matter from Bilateral Fallopian Tubes, Via Natural or Artificial Opening Endoscopic */
"0UC90ZZ" = "1" /* Extirpation of Matter from Uterus, Open Approach */
"0UC93ZZ" = "1" /* Extirpation of Matter from Uterus, Percutaneous Approach */
"0UC94ZZ" = "1" /* Extirpation of Matter from Uterus, Percutaneous Endoscopic Approach */
"0UCB0ZZ" = "1" /* Extirpation of Matter from Endometrium, Open Approach */
"0UCB3ZZ" = "1" /* Extirpation of Matter from Endometrium, Percutaneous Approach */
"0UCB4ZZ" = "1" /* Extirpation of Matter from Endometrium, Percutaneous Endoscopic Approach */
"0UCB7ZZ" = "1" /* Extirpation of Matter from Endometrium, Via Natural or Artificial Opening */
"0UCB8ZZ" = "1" /* Extirpation of Matter from Endometrium, Via Natural or Artificial Opening Endoscopic */
"0UCC0ZZ" = "1" /* Extirpation of Matter from Cervix, Open Approach */
"0UCC3ZZ" = "1" /* Extirpation of Matter from Cervix, Percutaneous Approach */
"0UCC4ZZ" = "1" /* Extirpation of Matter from Cervix, Percutaneous Endoscopic Approach */
"0UCC7ZZ" = "1" /* Extirpation of Matter from Cervix, Via Natural or Artificial Opening */
"0UCC8ZZ" = "1" /* Extirpation of Matter from Cervix, Via Natural or Artificial Opening Endoscopic */
"0UCF0ZZ" = "1" /* Extirpation of Matter from Cul-de-sac, Open Approach */
"0UCF3ZZ" = "1" /* Extirpation of Matter from Cul-de-sac, Percutaneous Approach */
"0UCF4ZZ" = "1" /* Extirpation of Matter from Cul-de-sac, Percutaneous Endoscopic Approach */
"0UCF7ZZ" = "1" /* Extirpation of Matter from Cul-de-sac, Via Natural or Artificial Opening */
"0UCF8ZZ" = "1" /* Extirpation of Matter from Cul-de-sac, Via Natural or Artificial Opening Endoscopic */
"0UCG0ZZ" = "1" /* Extirpation of Matter from Vagina, Open Approach */
"0UCG3ZZ" = "1" /* Extirpation of Matter from Vagina, Percutaneous Approach */
"0UCG4ZZ" = "1" /* Extirpation of Matter from Vagina, Percutaneous Endoscopic Approach */
"0UCJ0ZZ" = "1" /* Extirpation of Matter from Clitoris, Open Approach */
"0UCJXZZ" = "1" /* Extirpation of Matter from Clitoris, External Approach */
"0UCL0ZZ" = "1" /* Extirpation of Matter from Vestibular Gland, Open Approach */
"0UCLXZZ" = "1" /* Extirpation of Matter from Vestibular Gland, External Approach */
"0UCM0ZZ" = "1" /* Extirpation of Matter from Vulva, Open Approach */
"0UDB7ZX" = "1" /* Extraction of Endometrium, Via Natural or Artificial Opening, Diagnostic */
"0UDB7ZZ" = "1" /* Extraction of Endometrium, Via Natural or Artificial Opening */
"0UDB8ZX" = "1" /* Extraction of Endometrium, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0UDB8ZZ" = "1" /* Extraction of Endometrium, Via Natural or Artificial Opening Endoscopic */
"0UDN0ZZ" = "1" /* Extraction of Ova, Open */
"0UDN3ZZ" = "1" /* Extraction of Ova, Percutaneous */
"0UDN4ZZ" = "1" /* Extraction of Ova, Percutaneous Endoscopic */
"0UF50ZZ" = "1" /* Fragmentation in Right Fallopian Tube, Open Approach */
"0UF53ZZ" = "1" /* Fragmentation in Right Fallopian Tube, Percutaneous Approach */
"0UF54ZZ" = "1" /* Fragmentation in Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0UF57ZZ" = "1" /* Fragmentation in Right Fallopian Tube, Via Natural or Artificial Opening */
"0UF58ZZ" = "1" /* Fragmentation in Right Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UF60ZZ" = "1" /* Fragmentation in Left Fallopian Tube, Open Approach */
"0UF63ZZ" = "1" /* Fragmentation in Left Fallopian Tube, Percutaneous Approach */
"0UF64ZZ" = "1" /* Fragmentation in Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0UF67ZZ" = "1" /* Fragmentation in Left Fallopian Tube, Via Natural or Artificial Opening */
"0UF68ZZ" = "1" /* Fragmentation in Left Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UF70ZZ" = "1" /* Fragmentation in Bilateral Fallopian Tubes, Open Approach */
"0UF73ZZ" = "1" /* Fragmentation in Bilateral Fallopian Tubes, Percutaneous Approach */
"0UF74ZZ" = "1" /* Fragmentation in Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0UF77ZZ" = "1" /* Fragmentation in Bilateral Fallopian Tubes, Via Natural or Artificial Opening */
"0UF78ZZ" = "1" /* Fragmentation in Bilateral Fallopian Tubes, Via Natural or Artificial Opening Endoscopic */
"0UF90ZZ" = "1" /* Fragmentation in Uterus, Open Approach */
"0UF93ZZ" = "1" /* Fragmentation in Uterus, Percutaneous Approach */
"0UF94ZZ" = "1" /* Fragmentation in Uterus, Percutaneous Endoscopic Approach */
"0UF97ZZ" = "1" /* Fragmentation in Uterus, Via Natural or Artificial Opening */
"0UF98ZZ" = "1" /* Fragmentation in Uterus, Via Natural or Artificial Opening Endoscopic */
"0UHC01Z" = "1" /* Insertion of Radioactive Element into Cervix, Open Approach */
"0UHC31Z" = "1" /* Insertion of Radioactive Element into Cervix, Percutaneous Approach */
"0UHC41Z" = "1" /* Insertion of Radioactive Element into Cervix, Percutaneous Endoscopic Approach */
"0UHC71Z" = "1" /* Insertion of Radioactive Element into Cervix, Via Natural or Artificial Opening */
"0UHC81Z" = "1" /* Insertion of Radioactive Element into Cervix, Via Natural or Artificial Opening Endoscopic */
"0UHG01Z" = "1" /* Insertion of Radioactive Element into Vagina, Open Approach */
"0UHG31Z" = "1" /* Insertion of Radioactive Element into Vagina, Percutaneous Approach */
"0UHG41Z" = "1" /* Insertion of Radioactive Element into Vagina, Percutaneous Endoscopic Approach */
"0UHG71Z" = "1" /* Insertion of Radioactive Element into Vagina, Via Natural or Artificial Opening */
"0UHG81Z" = "1" /* Insertion of Radioactive Element into Vagina, Via Natural or Artificial Opening Endoscopic */
"0UHGX1Z" = "1" /* Insertion of Radioactive Element into Vagina, External Approach */
"0UHH03Z" = "1" /* Insertion of Infusion Device into Vagina and Cul-de-sac, Open Approach */
"0UHH33Z" = "1" /* Insertion of Infusion Device into Vagina and Cul-de-sac, Percutaneous Approach */
"0UHH43Z" = "1" /* Insertion of Infusion Device into Vagina and Cul-de-sac, Percutaneous Endoscopic Approach */
"0UJ30ZZ" = "1" /* Inspection of Ovary, Open Approach */
"0UJ34ZZ" = "1" /* Inspection of Ovary, Percutaneous Endoscopic Approach */
"0UJ80ZZ" = "1" /* Inspection of Fallopian Tube, Open Approach */
"0UJ84ZZ" = "1" /* Inspection of Fallopian Tube, Percutaneous Endoscopic Approach */
"0UJD0ZZ" = "1" /* Inspection of Uterus and Cervix, Open Approach */
"0UJD4ZZ" = "1" /* Inspection of Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UJH0ZZ" = "1" /* Inspection of Vagina and Cul-de-sac, Open Approach */
"0UJH4ZZ" = "1" /* Inspection of Vagina and Cul-de-sac, Percutaneous Endoscopic Approach */
"0UJM0ZZ" = "1" /* Inspection of Vulva, Open Approach */
"0UL50CZ" = "1" /* Occlusion of Right Fallopian Tube with Extraluminal Device, Open Approach */
"0UL50DZ" = "1" /* Occlusion of Right Fallopian Tube with Intraluminal Device, Open Approach */
"0UL50ZZ" = "1" /* Occlusion of Right Fallopian Tube, Open Approach */
"0UL53CZ" = "1" /* Occlusion of Right Fallopian Tube with Extraluminal Device, Percutaneous Approach */
"0UL53DZ" = "1" /* Occlusion of Right Fallopian Tube with Intraluminal Device, Percutaneous Approach */
"0UL53ZZ" = "1" /* Occlusion of Right Fallopian Tube, Percutaneous Approach */
"0UL54CZ" = "1" /* Occlusion of Right Fallopian Tube with Extraluminal Device, Percutaneous Endoscopic Approach */
"0UL54DZ" = "1" /* Occlusion of Right Fallopian Tube with Intraluminal Device, Percutaneous Endoscopic Approach */
"0UL54ZZ" = "1" /* Occlusion of Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0UL57DZ" = "1" /* Occlusion of Right Fallopian Tube with Intraluminal Device, Via Natural or Artificial Opening */
"0UL57ZZ" = "1" /* Occlusion of Right Fallopian Tube, Via Natural or Artificial Opening */
"0UL58DZ" = "1" /* Occlusion of Right Fallopian Tube with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0UL58ZZ" = "1" /* Occlusion of Right Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UL60CZ" = "1" /* Occlusion of Left Fallopian Tube with Extraluminal Device, Open Approach */
"0UL60DZ" = "1" /* Occlusion of Left Fallopian Tube with Intraluminal Device, Open Approach */
"0UL60ZZ" = "1" /* Occlusion of Left Fallopian Tube, Open Approach */
"0UL63CZ" = "1" /* Occlusion of Left Fallopian Tube with Extraluminal Device, Percutaneous Approach */
"0UL63DZ" = "1" /* Occlusion of Left Fallopian Tube with Intraluminal Device, Percutaneous Approach */
"0UL63ZZ" = "1" /* Occlusion of Left Fallopian Tube, Percutaneous Approach */
"0UL64CZ" = "1" /* Occlusion of Left Fallopian Tube with Extraluminal Device, Percutaneous Endoscopic Approach */
"0UL64DZ" = "1" /* Occlusion of Left Fallopian Tube with Intraluminal Device, Percutaneous Endoscopic Approach */
"0UL64ZZ" = "1" /* Occlusion of Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0UL67DZ" = "1" /* Occlusion of Left Fallopian Tube with Intraluminal Device, Via Natural or Artificial Opening */
"0UL67ZZ" = "1" /* Occlusion of Left Fallopian Tube, Via Natural or Artificial Opening */
"0UL68DZ" = "1" /* Occlusion of Left Fallopian Tube with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0UL68ZZ" = "1" /* Occlusion of Left Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UL70CZ" = "1" /* Occlusion of Bilateral Fallopian Tubes with Extraluminal Device, Open Approach */
"0UL70DZ" = "1" /* Occlusion of Bilateral Fallopian Tubes with Intraluminal Device, Open Approach */
"0UL70ZZ" = "1" /* Occlusion of Bilateral Fallopian Tubes, Open Approach */
"0UL73CZ" = "1" /* Occlusion of Bilateral Fallopian Tubes with Extraluminal Device, Percutaneous Approach */
"0UL73DZ" = "1" /* Occlusion of Bilateral Fallopian Tubes with Intraluminal Device, Percutaneous Approach */
"0UL73ZZ" = "1" /* Occlusion of Bilateral Fallopian Tubes, Percutaneous Approach */
"0UL74CZ" = "1" /* Occlusion of Bilateral Fallopian Tubes with Extraluminal Device, Percutaneous Endoscopic Approach */
"0UL74DZ" = "1" /* Occlusion of Bilateral Fallopian Tubes with Intraluminal Device, Percutaneous Endoscopic Approach */
"0UL74ZZ" = "1" /* Occlusion of Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0UL77DZ" = "1" /* Occlusion of Bilateral Fallopian Tubes with Intraluminal Device, Via Natural or Artificial Opening */
"0UL77ZZ" = "1" /* Occlusion of Bilateral Fallopian Tubes, Via Natural or Artificial Opening */
"0UL78DZ" = "1" /* Occlusion of Bilateral Fallopian Tubes with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0UL78ZZ" = "1" /* Occlusion of Bilateral Fallopian Tubes, Via Natural or Artificial Opening Endoscopic */
"0ULF7DZ" = "1" /* Occlusion of Cul-de-sac with Intraluminal Device, Via Natural or Artificial Opening */
"0ULF7ZZ" = "1" /* Occlusion of Cul-de-sac, Via Natural or Artificial Opening */
"0ULF8DZ" = "1" /* Occlusion of Cul-de-sac with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0ULF8ZZ" = "1" /* Occlusion of Cul-de-sac, Via Natural or Artificial Opening Endoscopic */
"0ULG7DZ" = "1" /* Occlusion of Vagina with Intraluminal Device, Via Natural or Artificial Opening */
"0ULG7ZZ" = "1" /* Occlusion of Vagina, Via Natural or Artificial Opening */
"0ULG8DZ" = "1" /* Occlusion of Vagina with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0ULG8ZZ" = "1" /* Occlusion of Vagina, Via Natural or Artificial Opening Endoscopic */
"0UM00ZZ" = "1" /* Reattachment of Right Ovary, Open Approach */
"0UM04ZZ" = "1" /* Reattachment of Right Ovary, Percutaneous Endoscopic Approach */
"0UM10ZZ" = "1" /* Reattachment of Left Ovary, Open Approach */
"0UM14ZZ" = "1" /* Reattachment of Left Ovary, Percutaneous Endoscopic Approach */
"0UM20ZZ" = "1" /* Reattachment of Bilateral Ovaries, Open Approach */
"0UM24ZZ" = "1" /* Reattachment of Bilateral Ovaries, Percutaneous Endoscopic Approach */
"0UM40ZZ" = "1" /* Reattachment of Uterine Supporting Structure, Open Approach */
"0UM44ZZ" = "1" /* Reattachment of Uterine Supporting Structure, Percutaneous Endoscopic Approach */
"0UM50ZZ" = "1" /* Reattachment of Right Fallopian Tube, Open Approach */
"0UM54ZZ" = "1" /* Reattachment of Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0UM60ZZ" = "1" /* Reattachment of Left Fallopian Tube, Open Approach */
"0UM64ZZ" = "1" /* Reattachment of Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0UM70ZZ" = "1" /* Reattachment of Bilateral Fallopian Tubes, Open Approach */
"0UM74ZZ" = "1" /* Reattachment of Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0UM90ZZ" = "1" /* Reattachment of Uterus, Open Approach */
"0UM94ZZ" = "1" /* Reattachment of Uterus, Percutaneous Endoscopic Approach */
"0UMC0ZZ" = "1" /* Reattachment of Cervix, Open Approach */
"0UMC4ZZ" = "1" /* Reattachment of Cervix, Percutaneous Endoscopic Approach */
"0UMF0ZZ" = "1" /* Reattachment of Cul-de-sac, Open Approach */
"0UMF4ZZ" = "1" /* Reattachment of Cul-de-sac, Percutaneous Endoscopic Approach */
"0UMG0ZZ" = "1" /* Reattachment of Vagina, Open Approach */
"0UMG4ZZ" = "1" /* Reattachment of Vagina, Percutaneous Endoscopic Approach */
"0UMJXZZ" = "1" /* Reattachment of Clitoris, External Approach */
"0UMK0ZZ" = "1" /* Reattachment of Hymen, Open Approach */
"0UMK4ZZ" = "1" /* Reattachment of Hymen, Percutaneous Endoscopic Approach */
"0UMKXZZ" = "1" /* Reattachment of Hymen, External Approach */
"0UMMXZZ" = "1" /* Reattachment of Vulva, External Approach */
"0UN00ZZ" = "1" /* Release Right Ovary, Open Approach */
"0UN03ZZ" = "1" /* Release Right Ovary, Percutaneous Approach */
"0UN04ZZ" = "1" /* Release Right Ovary, Percutaneous Endoscopic Approach */
"0UN10ZZ" = "1" /* Release Left Ovary, Open Approach */
"0UN13ZZ" = "1" /* Release Left Ovary, Percutaneous Approach */
"0UN14ZZ" = "1" /* Release Left Ovary, Percutaneous Endoscopic Approach */
"0UN20ZZ" = "1" /* Release Bilateral Ovaries, Open Approach */
"0UN23ZZ" = "1" /* Release Bilateral Ovaries, Percutaneous Approach */
"0UN24ZZ" = "1" /* Release Bilateral Ovaries, Percutaneous Endoscopic Approach */
"0UN40ZZ" = "1" /* Release Uterine Supporting Structure, Open Approach */
"0UN43ZZ" = "1" /* Release Uterine Supporting Structure, Percutaneous Approach */
"0UN44ZZ" = "1" /* Release Uterine Supporting Structure, Percutaneous Endoscopic Approach */
"0UN50ZZ" = "1" /* Release Right Fallopian Tube, Open Approach */
"0UN53ZZ" = "1" /* Release Right Fallopian Tube, Percutaneous Approach */
"0UN54ZZ" = "1" /* Release Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0UN57ZZ" = "1" /* Release Right Fallopian Tube, Via Natural or Artificial Opening */
"0UN58ZZ" = "1" /* Release Right Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UN60ZZ" = "1" /* Release Left Fallopian Tube, Open Approach */
"0UN63ZZ" = "1" /* Release Left Fallopian Tube, Percutaneous Approach */
"0UN64ZZ" = "1" /* Release Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0UN67ZZ" = "1" /* Release Left Fallopian Tube, Via Natural or Artificial Opening */
"0UN68ZZ" = "1" /* Release Left Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UN70ZZ" = "1" /* Release Bilateral Fallopian Tubes, Open Approach */
"0UN73ZZ" = "1" /* Release Bilateral Fallopian Tubes, Percutaneous Approach */
"0UN74ZZ" = "1" /* Release Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0UN77ZZ" = "1" /* Release Bilateral Fallopian Tubes, Via Natural or Artificial Opening */
"0UN78ZZ" = "1" /* Release Bilateral Fallopian Tubes, Via Natural or Artificial Opening Endoscopic */
"0UN90ZZ" = "1" /* Release Uterus, Open Approach */
"0UN93ZZ" = "1" /* Release Uterus, Percutaneous Approach */
"0UN94ZZ" = "1" /* Release Uterus, Percutaneous Endoscopic Approach */
"0UN97ZZ" = "1" /* Release Uterus, Via Natural or Artificial Opening */
"0UN98ZZ" = "1" /* Release Uterus, Via Natural or Artificial Opening Endoscopic */
"0UNC0ZZ" = "1" /* Release Cervix, Open Approach */
"0UNC3ZZ" = "1" /* Release Cervix, Percutaneous Approach */
"0UNC4ZZ" = "1" /* Release Cervix, Percutaneous Endoscopic Approach */
"0UNC7ZZ" = "1" /* Release Cervix, Via Natural or Artificial Opening */
"0UNC8ZZ" = "1" /* Release Cervix, Via Natural or Artificial Opening Endoscopic */
"0UNF0ZZ" = "1" /* Release Cul-de-sac, Open Approach */
"0UNF3ZZ" = "1" /* Release Cul-de-sac, Percutaneous Approach */
"0UNF4ZZ" = "1" /* Release Cul-de-sac, Percutaneous Endoscopic Approach */
"0UNF7ZZ" = "1" /* Release Cul-de-sac, Via Natural or Artificial Opening */
"0UNF8ZZ" = "1" /* Release Cul-de-sac, Via Natural or Artificial Opening Endoscopic */
"0UNG0ZZ" = "1" /* Release Vagina, Open Approach */
"0UNG3ZZ" = "1" /* Release Vagina, Percutaneous Approach */
"0UNG4ZZ" = "1" /* Release Vagina, Percutaneous Endoscopic Approach */
"0UNG7ZZ" = "1" /* Release Vagina, Via Natural or Artificial Opening */
"0UNG8ZZ" = "1" /* Release Vagina, Via Natural or Artificial Opening Endoscopic */
"0UNGXZZ" = "1" /* Release Vagina, External Approach */
"0UNJ0ZZ" = "1" /* Release Clitoris, Open Approach */
"0UNJXZZ" = "1" /* Release Clitoris, External Approach */
"0UNK0ZZ" = "1" /* Release Hymen, Open Approach */
"0UNK3ZZ" = "1" /* Release Hymen, Percutaneous Approach */
"0UNK4ZZ" = "1" /* Release Hymen, Percutaneous Endoscopic Approach */
"0UNK7ZZ" = "1" /* Release Hymen, Via Natural or Artificial Opening */
"0UNK8ZZ" = "1" /* Release Hymen, Via Natural or Artificial Opening Endoscopic */
"0UNKXZZ" = "1" /* Release Hymen, External Approach */
"0UNL0ZZ" = "1" /* Release Vestibular Gland, Open Approach */
"0UNLXZZ" = "1" /* Release Vestibular Gland, External Approach */
"0UNM0ZZ" = "1" /* Release Vulva, Open Approach */
"0UNMXZZ" = "1" /* Release Vulva, External Approach */
"0UP300Z" = "1" /* Removal of Drainage Device from Ovary, Open Approach */
"0UP303Z" = "1" /* Removal of Infusion Device from Ovary, Open Approach */
"0UP330Z" = "1" /* Removal of Drainage Device from Ovary, Percutaneous Approach */
"0UP333Z" = "1" /* Removal of Infusion Device from Ovary, Percutaneous Approach */
"0UP340Z" = "1" /* Removal of Drainage Device from Ovary, Percutaneous Endoscopic Approach */
"0UP343Z" = "1" /* Removal of Infusion Device from Ovary, Percutaneous Endoscopic Approach */
"0UP800Z" = "1" /* Removal of Drainage Device from Fallopian Tube, Open Approach */
"0UP803Z" = "1" /* Removal of Infusion Device from Fallopian Tube, Open Approach */
"0UP807Z" = "1" /* Removal of Autologous Tissue Substitute from Fallopian Tube, Open Approach */
"0UP80CZ" = "1" /* Removal of Extraluminal Device from Fallopian Tube, Open Approach */
"0UP80DZ" = "1" /* Removal of Intraluminal Device from Fallopian Tube, Open Approach */
"0UP80JZ" = "1" /* Removal of Synthetic Substitute from Fallopian Tube, Open Approach */
"0UP80KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Fallopian Tube, Open Approach */
"0UP830Z" = "1" /* Removal of Drainage Device from Fallopian Tube, Percutaneous Approach */
"0UP833Z" = "1" /* Removal of Infusion Device from Fallopian Tube, Percutaneous Approach */
"0UP837Z" = "1" /* Removal of Autologous Tissue Substitute from Fallopian Tube, Percutaneous Approach */
"0UP83CZ" = "1" /* Removal of Extraluminal Device from Fallopian Tube, Percutaneous Approach */
"0UP83DZ" = "1" /* Removal of Intraluminal Device from Fallopian Tube, Percutaneous Approach */
"0UP83JZ" = "1" /* Removal of Synthetic Substitute from Fallopian Tube, Percutaneous Approach */
"0UP83KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Fallopian Tube, Percutaneous Approach */
"0UP840Z" = "1" /* Removal of Drainage Device from Fallopian Tube, Percutaneous Endoscopic Approach */
"0UP843Z" = "1" /* Removal of Infusion Device from Fallopian Tube, Percutaneous Endoscopic Approach */
"0UP847Z" = "1" /* Removal of Autologous Tissue Substitute from Fallopian Tube, Percutaneous Endoscopic Approach */
"0UP84CZ" = "1" /* Removal of Extraluminal Device from Fallopian Tube, Percutaneous Endoscopic Approach */
"0UP84DZ" = "1" /* Removal of Intraluminal Device from Fallopian Tube, Percutaneous Endoscopic Approach */
"0UP84JZ" = "1" /* Removal of Synthetic Substitute from Fallopian Tube, Percutaneous Endoscopic Approach */
"0UP84KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Fallopian Tube, Percutaneous Endoscopic Approach */
"0UP877Z" = "1" /* Removal of Autologous Tissue Substitute from Fallopian Tube, Via Natural or Artificial Opening */
"0UP87CZ" = "1" /* Removal of Extraluminal Device from Fallopian Tube, Via Natural or Artificial Opening */
"0UP87JZ" = "1" /* Removal of Synthetic Substitute from Fallopian Tube, Via Natural or Artificial Opening */
"0UP87KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Fallopian Tube, Via Natural or Artificial Opening */
"0UP887Z" = "1" /* Removal of Autologous Tissue Substitute from Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UP88CZ" = "1" /* Removal of Extraluminal Device from Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UP88JZ" = "1" /* Removal of Synthetic Substitute from Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UP88KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UPD00Z" = "1" /* Removal of Drainage Device from Uterus and Cervix, Open Approach */
"0UPD01Z" = "1" /* Removal of Radioactive Element from Uterus and Cervix, Open Approach */
"0UPD03Z" = "1" /* Removal of Infusion Device from Uterus and Cervix, Open Approach */
"0UPD07Z" = "1" /* Removal of Autologous Tissue Substitute from Uterus and Cervix, Open Approach */
"0UPD0CZ" = "1" /* Removal of Extraluminal Device from Uterus and Cervix, Open Approach */
"0UPD0DZ" = "1" /* Removal of Intraluminal Device from Uterus and Cervix, Open Approach */
"0UPD0HZ" = "1" /* Removal of Contraceptive Device from Uterus and Cervix, Open Approach */
"0UPD0JZ" = "1" /* Removal of Synthetic Substitute from Uterus and Cervix, Open Approach */
"0UPD0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Uterus and Cervix, Open Approach */
"0UPD30Z" = "1" /* Removal of Drainage Device from Uterus and Cervix, Percutaneous Approach */
"0UPD31Z" = "1" /* Removal of Radioactive Element from Uterus and Cervix, Percutaneous Approach */
"0UPD33Z" = "1" /* Removal of Infusion Device from Uterus and Cervix, Percutaneous Approach */
"0UPD37Z" = "1" /* Removal of Autologous Tissue Substitute from Uterus and Cervix, Percutaneous Approach */
"0UPD3DZ" = "1" /* Removal of Intraluminal Device from Uterus and Cervix, Percutaneous Approach */
"0UPD3HZ" = "1" /* Removal of Contraceptive Device from Uterus and Cervix, Percutaneous Approach */
"0UPD3JZ" = "1" /* Removal of Synthetic Substitute from Uterus and Cervix, Percutaneous Approach */
"0UPD3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Uterus and Cervix, Percutaneous Approach */
"0UPD40Z" = "1" /* Removal of Drainage Device from Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UPD41Z" = "1" /* Removal of Radioactive Element from Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UPD43Z" = "1" /* Removal of Infusion Device from Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UPD47Z" = "1" /* Removal of Autologous Tissue Substitute from Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UPD4DZ" = "1" /* Removal of Intraluminal Device from Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UPD4HZ" = "1" /* Removal of Contraceptive Device from Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UPD4JZ" = "1" /* Removal of Synthetic Substitute from Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UPD4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UPD71Z" = "1" /* Removal of Radioactive Element from Uterus and Cervix, Via Natural or Artificial Opening */
"0UPD77Z" = "1" /* Removal of Autologous Tissue Substitute from Uterus and Cervix, Via Natural or Artificial Opening */
"0UPD7JZ" = "1" /* Removal of Synthetic Substitute from Uterus and Cervix, Via Natural or Artificial Opening */
"0UPD7KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Uterus and Cervix, Via Natural or Artificial Opening */
"0UPD81Z" = "1" /* Removal of Radioactive Element from Uterus and Cervix, Via Natural or Artificial Opening Endoscopic */
"0UPD87Z" = "1" /* Removal of Autologous Tissue Substitute from Uterus and Cervix, Via Natural or Artificial Opening Endoscopic */
"0UPD8JZ" = "1" /* Removal of Synthetic Substitute from Uterus and Cervix, Via Natural or Artificial Opening Endoscopic */
"0UPD8KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Uterus and Cervix, Via Natural or Artificial Opening Endoscopic */
"0UPH00Z" = "1" /* Removal of Drainage Device from Vagina and Cul-de-sac, Open Approach */
"0UPH01Z" = "1" /* Removal of Radioactive Element from Vagina and Cul-de-sac, Open Approach */
"0UPH03Z" = "1" /* Removal of Infusion Device from Vagina and Cul-de-sac, Open Approach */
"0UPH07Z" = "1" /* Removal of Autologous Tissue Substitute from Vagina and Cul-de-sac, Open Approach */
"0UPH0DZ" = "1" /* Removal of Intraluminal Device from Vagina and Cul-de-sac, Open Approach */
"0UPH0JZ" = "1" /* Removal of Synthetic Substitute from Vagina and Cul-de-sac, Open Approach */
"0UPH0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Vagina and Cul-de-sac, Open Approach */
"0UPH30Z" = "1" /* Removal of Drainage Device from Vagina and Cul-de-sac, Percutaneous Approach */
"0UPH31Z" = "1" /* Removal of Radioactive Element from Vagina and Cul-de-sac, Percutaneous Approach */
"0UPH33Z" = "1" /* Removal of Infusion Device from Vagina and Cul-de-sac, Percutaneous Approach */
"0UPH37Z" = "1" /* Removal of Autologous Tissue Substitute from Vagina and Cul-de-sac, Percutaneous Approach */
"0UPH3DZ" = "1" /* Removal of Intraluminal Device from Vagina and Cul-de-sac, Percutaneous Approach */
"0UPH3JZ" = "1" /* Removal of Synthetic Substitute from Vagina and Cul-de-sac, Percutaneous Approach */
"0UPH3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Vagina and Cul-de-sac, Percutaneous Approach */
"0UPH40Z" = "1" /* Removal of Drainage Device from Vagina and Cul-de-sac, Percutaneous Endoscopic Approach */
"0UPH41Z" = "1" /* Removal of Radioactive Element from Vagina and Cul-de-sac, Percutaneous Endoscopic Approach */
"0UPH43Z" = "1" /* Removal of Infusion Device from Vagina and Cul-de-sac, Percutaneous Endoscopic Approach */
"0UPH47Z" = "1" /* Removal of Autologous Tissue Substitute from Vagina and Cul-de-sac, Percutaneous Endoscopic Approach */
"0UPH4DZ" = "1" /* Removal of Intraluminal Device from Vagina and Cul-de-sac, Percutaneous Endoscopic Approach */
"0UPH4JZ" = "1" /* Removal of Synthetic Substitute from Vagina and Cul-de-sac, Percutaneous Endoscopic Approach */
"0UPH4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Vagina and Cul-de-sac, Percutaneous Endoscopic Approach */
"0UPH71Z" = "1" /* Removal of Radioactive Element from Vagina and Cul-de-sac, Via Natural or Artificial Opening */
"0UPH77Z" = "1" /* Removal of Autologous Tissue Substitute from Vagina and Cul-de-sac, Via Natural or Artificial Opening */
"0UPH7JZ" = "1" /* Removal of Synthetic Substitute from Vagina and Cul-de-sac, Via Natural or Artificial Opening */
"0UPH7KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Vagina and Cul-de-sac, Via Natural or Artificial Opening */
"0UPH81Z" = "1" /* Removal of Radioactive Element from Vagina and Cul-de-sac, Via Natural or Artificial Opening Endoscopic */
"0UPH87Z" = "1" /* Removal of Autologous Tissue Substitute from Vagina and Cul-de-sac, Via Natural or Artificial Opening Endoscopic */
"0UPH8JZ" = "1" /* Removal of Synthetic Substitute from Vagina and Cul-de-sac, Via Natural or Artificial Opening Endoscopic */
"0UPH8KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Vagina and Cul-de-sac, Via Natural or Artificial Opening Endoscopic */
"0UPM00Z" = "1" /* Removal of Drainage Device from Vulva, Open Approach */
"0UPM07Z" = "1" /* Removal of Autologous Tissue Substitute from Vulva, Open Approach */
"0UPM0JZ" = "1" /* Removal of Synthetic Substitute from Vulva, Open Approach */
"0UPM0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Vulva, Open Approach */
"0UQ00ZZ" = "1" /* Repair Right Ovary, Open Approach */
"0UQ03ZZ" = "1" /* Repair Right Ovary, Percutaneous Approach */
"0UQ04ZZ" = "1" /* Repair Right Ovary, Percutaneous Endoscopic Approach */
"0UQ10ZZ" = "1" /* Repair Left Ovary, Open Approach */
"0UQ13ZZ" = "1" /* Repair Left Ovary, Percutaneous Approach */
"0UQ14ZZ" = "1" /* Repair Left Ovary, Percutaneous Endoscopic Approach */
"0UQ20ZZ" = "1" /* Repair Bilateral Ovaries, Open Approach */
"0UQ23ZZ" = "1" /* Repair Bilateral Ovaries, Percutaneous Approach */
"0UQ24ZZ" = "1" /* Repair Bilateral Ovaries, Percutaneous Endoscopic Approach */
"0UQ40ZZ" = "1" /* Repair Uterine Supporting Structure, Open Approach */
"0UQ43ZZ" = "1" /* Repair Uterine Supporting Structure, Percutaneous Approach */
"0UQ44ZZ" = "1" /* Repair Uterine Supporting Structure, Percutaneous Endoscopic Approach */
"0UQ50ZZ" = "1" /* Repair Right Fallopian Tube, Open Approach */
"0UQ53ZZ" = "1" /* Repair Right Fallopian Tube, Percutaneous Approach */
"0UQ54ZZ" = "1" /* Repair Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0UQ57ZZ" = "1" /* Repair Right Fallopian Tube, Via Natural or Artificial Opening */
"0UQ58ZZ" = "1" /* Repair Right Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UQ60ZZ" = "1" /* Repair Left Fallopian Tube, Open Approach */
"0UQ63ZZ" = "1" /* Repair Left Fallopian Tube, Percutaneous Approach */
"0UQ64ZZ" = "1" /* Repair Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0UQ67ZZ" = "1" /* Repair Left Fallopian Tube, Via Natural or Artificial Opening */
"0UQ68ZZ" = "1" /* Repair Left Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UQ70ZZ" = "1" /* Repair Bilateral Fallopian Tubes, Open Approach */
"0UQ73ZZ" = "1" /* Repair Bilateral Fallopian Tubes, Percutaneous Approach */
"0UQ74ZZ" = "1" /* Repair Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0UQ77ZZ" = "1" /* Repair Bilateral Fallopian Tubes, Via Natural or Artificial Opening */
"0UQ78ZZ" = "1" /* Repair Bilateral Fallopian Tubes, Via Natural or Artificial Opening Endoscopic */
"0UQ90ZZ" = "1" /* Repair Uterus, Open Approach */
"0UQ93ZZ" = "1" /* Repair Uterus, Percutaneous Approach */
"0UQ94ZZ" = "1" /* Repair Uterus, Percutaneous Endoscopic Approach */
"0UQ97ZZ" = "1" /* Repair Uterus, Via Natural or Artificial Opening */
"0UQ98ZZ" = "1" /* Repair Uterus, Via Natural or Artificial Opening Endoscopic */
"0UQC0ZZ" = "1" /* Repair Cervix, Open Approach */
"0UQC3ZZ" = "1" /* Repair Cervix, Percutaneous Approach */
"0UQC4ZZ" = "1" /* Repair Cervix, Percutaneous Endoscopic Approach */
"0UQC7ZZ" = "1" /* Repair Cervix, Via Natural or Artificial Opening */
"0UQC8ZZ" = "1" /* Repair Cervix, Via Natural or Artificial Opening Endoscopic */
"0UQF0ZZ" = "1" /* Repair Cul-de-sac, Open Approach */
"0UQF3ZZ" = "1" /* Repair Cul-de-sac, Percutaneous Approach */
"0UQF4ZZ" = "1" /* Repair Cul-de-sac, Percutaneous Endoscopic Approach */
"0UQF7ZZ" = "1" /* Repair Cul-de-sac, Via Natural or Artificial Opening */
"0UQF8ZZ" = "1" /* Repair Cul-de-sac, Via Natural or Artificial Opening Endoscopic */
"0UQG0ZZ" = "1" /* Repair Vagina, Open Approach */
"0UQG3ZZ" = "1" /* Repair Vagina, Percutaneous Approach */
"0UQG4ZZ" = "1" /* Repair Vagina, Percutaneous Endoscopic Approach */
"0UQG8ZZ" = "1" /* Repair Vagina, Via Natural or Artificial Opening Endoscopic */
"0UQJ0ZZ" = "1" /* Repair Clitoris, Open Approach */
"0UQJXZZ" = "1" /* Repair Clitoris, External Approach */
"0UQK0ZZ" = "1" /* Repair Hymen, Open Approach */
"0UQK3ZZ" = "1" /* Repair Hymen, Percutaneous Approach */
"0UQK4ZZ" = "1" /* Repair Hymen, Percutaneous Endoscopic Approach */
"0UQK7ZZ" = "1" /* Repair Hymen, Via Natural or Artificial Opening */
"0UQK8ZZ" = "1" /* Repair Hymen, Via Natural or Artificial Opening Endoscopic */
"0UQKXZZ" = "1" /* Repair Hymen, External Approach */
"0UQL0ZZ" = "1" /* Repair Vestibular Gland, Open Approach */
"0UQLXZZ" = "1" /* Repair Vestibular Gland, External Approach */
"0UQM0ZZ" = "1" /* Repair Vulva, Open Approach */
"0US00ZZ" = "1" /* Reposition Right Ovary, Open Approach */
"0US04ZZ" = "1" /* Reposition Right Ovary, Percutaneous Endoscopic Approach */
"0US10ZZ" = "1" /* Reposition Left Ovary, Open Approach */
"0US14ZZ" = "1" /* Reposition Left Ovary, Percutaneous Endoscopic Approach */
"0US20ZZ" = "1" /* Reposition Bilateral Ovaries, Open Approach */
"0US24ZZ" = "1" /* Reposition Bilateral Ovaries, Percutaneous Endoscopic Approach */
"0US40ZZ" = "1" /* Reposition Uterine Supporting Structure, Open Approach */
"0US44ZZ" = "1" /* Reposition Uterine Supporting Structure, Percutaneous Endoscopic Approach */
"0US50ZZ" = "1" /* Reposition Right Fallopian Tube, Open Approach */
"0US54ZZ" = "1" /* Reposition Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0US60ZZ" = "1" /* Reposition Left Fallopian Tube, Open Approach */
"0US64ZZ" = "1" /* Reposition Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0US70ZZ" = "1" /* Reposition Bilateral Fallopian Tubes, Open Approach */
"0US74ZZ" = "1" /* Reposition Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0US90ZZ" = "1" /* Reposition Uterus, Open Approach */
"0US94ZZ" = "1" /* Reposition Uterus, Percutaneous Endoscopic Approach */
"0USC0ZZ" = "1" /* Reposition Cervix, Open Approach */
"0USC4ZZ" = "1" /* Reposition Cervix, Percutaneous Endoscopic Approach */
"0USF0ZZ" = "1" /* Reposition Cul-de-sac, Open Approach */
"0USF4ZZ" = "1" /* Reposition Cul-de-sac, Percutaneous Endoscopic Approach */
"0USG0ZZ" = "1" /* Reposition Vagina, Open Approach */
"0USG4ZZ" = "1" /* Reposition Vagina, Percutaneous Endoscopic Approach */
"0USGXZZ" = "1" /* Reposition Vagina, External Approach */
"0UT00ZZ" = "1" /* Resection of Right Ovary, Open Approach */
"0UT04ZZ" = "1" /* Resection of Right Ovary, Percutaneous Endoscopic Approach */
"0UT07ZZ" = "1" /* Resection of Right Ovary, Via Natural or Artificial Opening */
"0UT08ZZ" = "1" /* Resection of Right Ovary, Via Natural or Artificial Opening Endoscopic */
"0UT0FZZ" = "1" /* Resection of Right Ovary, Via Natural or Artificial Opening With Percutaneous Endoscopic Assistance */
"0UT10ZZ" = "1" /* Resection of Left Ovary, Open Approach */
"0UT14ZZ" = "1" /* Resection of Left Ovary, Percutaneous Endoscopic Approach */
"0UT17ZZ" = "1" /* Resection of Left Ovary, Via Natural or Artificial Opening */
"0UT18ZZ" = "1" /* Resection of Left Ovary, Via Natural or Artificial Opening Endoscopic */
"0UT1FZZ" = "1" /* Resection of Left Ovary, Via Natural or Artificial Opening With Percutaneous Endoscopic Assistance */
"0UT20ZZ" = "1" /* Resection of Bilateral Ovaries, Open Approach */
"0UT24ZZ" = "1" /* Resection of Bilateral Ovaries, Percutaneous Endoscopic Approach */
"0UT27ZZ" = "1" /* Resection of Bilateral Ovaries, Via Natural or Artificial Opening */
"0UT28ZZ" = "1" /* Resection of Bilateral Ovaries, Via Natural or Artificial Opening Endoscopic */
"0UT2FZZ" = "1" /* Resection of Bilateral Ovaries, Via Natural or Artificial Opening With Percutaneous Endoscopic Assistance */
"0UT40ZZ" = "1" /* Resection of Uterine Supporting Structure, Open Approach */
"0UT44ZZ" = "1" /* Resection of Uterine Supporting Structure, Percutaneous Endoscopic Approach */
"0UT47ZZ" = "1" /* Resection of Uterine Supporting Structure, Via Natural or Artificial Opening */
"0UT48ZZ" = "1" /* Resection of Uterine Supporting Structure, Via Natural or Artificial Opening Endoscopic */
"0UT50ZZ" = "1" /* Resection of Right Fallopian Tube, Open Approach */
"0UT54ZZ" = "1" /* Resection of Right Fallopian Tube, Percutaneous Endoscopic Approach */
"0UT57ZZ" = "1" /* Resection of Right Fallopian Tube, Via Natural or Artificial Opening */
"0UT58ZZ" = "1" /* Resection of Right Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UT5FZZ" = "1" /* Resection of Right Fallopian Tube, Via Natural or Artificial Opening With Percutaneous Endoscopic Assistance */
"0UT60ZZ" = "1" /* Resection of Left Fallopian Tube, Open Approach */
"0UT64ZZ" = "1" /* Resection of Left Fallopian Tube, Percutaneous Endoscopic Approach */
"0UT67ZZ" = "1" /* Resection of Left Fallopian Tube, Via Natural or Artificial Opening */
"0UT68ZZ" = "1" /* Resection of Left Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UT6FZZ" = "1" /* Resection of Left Fallopian Tube, Via Natural or Artificial Opening With Percutaneous Endoscopic Assistance */
"0UT70ZZ" = "1" /* Resection of Bilateral Fallopian Tubes, Open Approach */
"0UT74ZZ" = "1" /* Resection of Bilateral Fallopian Tubes, Percutaneous Endoscopic Approach */
"0UT77ZZ" = "1" /* Resection of Bilateral Fallopian Tubes, Via Natural or Artificial Opening */
"0UT78ZZ" = "1" /* Resection of Bilateral Fallopian Tubes, Via Natural or Artificial Opening Endoscopic */
"0UT7FZZ" = "1" /* Resection of Bilateral Fallopian Tubes, Via Natural or Artificial Opening With Percutaneous Endoscopic Assistance */
"0UT90ZZ" = "1" /* Resection of Uterus, Open Approach */
"0UT94ZZ" = "1" /* Resection of Uterus, Percutaneous Endoscopic Approach */
"0UT97ZZ" = "1" /* Resection of Uterus, Via Natural or Artificial Opening */
"0UT98ZZ" = "1" /* Resection of Uterus, Via Natural or Artificial Opening Endoscopic */
"0UT9FZZ" = "1" /* Resection of Uterus, Via Natural or Artificial Opening With Percutaneous Endoscopic Assistance */
"0UTC0ZZ" = "1" /* Resection of Cervix, Open Approach */
"0UTC4ZZ" = "1" /* Resection of Cervix, Percutaneous Endoscopic Approach */
"0UTC7ZZ" = "1" /* Resection of Cervix, Via Natural or Artificial Opening */
"0UTC8ZZ" = "1" /* Resection of Cervix, Via Natural or Artificial Opening Endoscopic */
"0UTF0ZZ" = "1" /* Resection of Cul-de-sac, Open Approach */
"0UTF4ZZ" = "1" /* Resection of Cul-de-sac, Percutaneous Endoscopic Approach */
"0UTF7ZZ" = "1" /* Resection of Cul-de-sac, Via Natural or Artificial Opening */
"0UTF8ZZ" = "1" /* Resection of Cul-de-sac, Via Natural or Artificial Opening Endoscopic */
"0UTG0ZZ" = "1" /* Resection of Vagina, Open Approach */
"0UTG4ZZ" = "1" /* Resection of Vagina, Percutaneous Endoscopic Approach */
"0UTG7ZZ" = "1" /* Resection of Vagina, Via Natural or Artificial Opening */
"0UTG8ZZ" = "1" /* Resection of Vagina, Via Natural or Artificial Opening Endoscopic */
"0UTJ0ZZ" = "1" /* Resection of Clitoris, Open Approach */
"0UTJXZZ" = "1" /* Resection of Clitoris, External Approach */
"0UTK0ZZ" = "1" /* Resection of Hymen, Open Approach */
"0UTK4ZZ" = "1" /* Resection of Hymen, Percutaneous Endoscopic Approach */
"0UTK7ZZ" = "1" /* Resection of Hymen, Via Natural or Artificial Opening */
"0UTK8ZZ" = "1" /* Resection of Hymen, Via Natural or Artificial Opening Endoscopic */
"0UTKXZZ" = "1" /* Resection of Hymen, External Approach */
"0UTL0ZZ" = "1" /* Resection of Vestibular Gland, Open Approach */
"0UTLXZZ" = "1" /* Resection of Vestibular Gland, External Approach */
"0UTM0ZZ" = "1" /* Resection of Vulva, Open Approach */
"0UTMXZZ" = "1" /* Resection of Vulva, External Approach */
"0UU407Z" = "1" /* Supplement Uterine Supporting Structure with Autologous Tissue Substitute, Open Approach */
"0UU40JZ" = "1" /* Supplement Uterine Supporting Structure with Synthetic Substitute, Open Approach */
"0UU40KZ" = "1" /* Supplement Uterine Supporting Structure with Nonautologous Tissue Substitute, Open Approach */
"0UU447Z" = "1" /* Supplement Uterine Supporting Structure with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0UU44JZ" = "1" /* Supplement Uterine Supporting Structure with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0UU44KZ" = "1" /* Supplement Uterine Supporting Structure with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0UU507Z" = "1" /* Supplement Right Fallopian Tube with Autologous Tissue Substitute, Open Approach */
"0UU50JZ" = "1" /* Supplement Right Fallopian Tube with Synthetic Substitute, Open Approach */
"0UU50KZ" = "1" /* Supplement Right Fallopian Tube with Nonautologous Tissue Substitute, Open Approach */
"0UU547Z" = "1" /* Supplement Right Fallopian Tube with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0UU54JZ" = "1" /* Supplement Right Fallopian Tube with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0UU54KZ" = "1" /* Supplement Right Fallopian Tube with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0UU577Z" = "1" /* Supplement Right Fallopian Tube with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0UU57JZ" = "1" /* Supplement Right Fallopian Tube with Synthetic Substitute, Via Natural or Artificial Opening */
"0UU57KZ" = "1" /* Supplement Right Fallopian Tube with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0UU587Z" = "1" /* Supplement Right Fallopian Tube with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0UU58JZ" = "1" /* Supplement Right Fallopian Tube with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0UU58KZ" = "1" /* Supplement Right Fallopian Tube with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0UU607Z" = "1" /* Supplement Left Fallopian Tube with Autologous Tissue Substitute, Open Approach */
"0UU60JZ" = "1" /* Supplement Left Fallopian Tube with Synthetic Substitute, Open Approach */
"0UU60KZ" = "1" /* Supplement Left Fallopian Tube with Nonautologous Tissue Substitute, Open Approach */
"0UU647Z" = "1" /* Supplement Left Fallopian Tube with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0UU64JZ" = "1" /* Supplement Left Fallopian Tube with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0UU64KZ" = "1" /* Supplement Left Fallopian Tube with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0UU677Z" = "1" /* Supplement Left Fallopian Tube with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0UU67JZ" = "1" /* Supplement Left Fallopian Tube with Synthetic Substitute, Via Natural or Artificial Opening */
"0UU67KZ" = "1" /* Supplement Left Fallopian Tube with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0UU687Z" = "1" /* Supplement Left Fallopian Tube with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0UU68JZ" = "1" /* Supplement Left Fallopian Tube with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0UU68KZ" = "1" /* Supplement Left Fallopian Tube with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0UU707Z" = "1" /* Supplement Bilateral Fallopian Tubes with Autologous Tissue Substitute, Open Approach */
"0UU70JZ" = "1" /* Supplement Bilateral Fallopian Tubes with Synthetic Substitute, Open Approach */
"0UU70KZ" = "1" /* Supplement Bilateral Fallopian Tubes with Nonautologous Tissue Substitute, Open Approach */
"0UU747Z" = "1" /* Supplement Bilateral Fallopian Tubes with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0UU74JZ" = "1" /* Supplement Bilateral Fallopian Tubes with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0UU74KZ" = "1" /* Supplement Bilateral Fallopian Tubes with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0UU777Z" = "1" /* Supplement Bilateral Fallopian Tubes with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0UU77JZ" = "1" /* Supplement Bilateral Fallopian Tubes with Synthetic Substitute, Via Natural or Artificial Opening */
"0UU77KZ" = "1" /* Supplement Bilateral Fallopian Tubes with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0UU787Z" = "1" /* Supplement Bilateral Fallopian Tubes with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0UU78JZ" = "1" /* Supplement Bilateral Fallopian Tubes with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0UU78KZ" = "1" /* Supplement Bilateral Fallopian Tubes with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0UUF07Z" = "1" /* Supplement Cul-de-sac with Autologous Tissue Substitute, Open Approach */
"0UUF0JZ" = "1" /* Supplement Cul-de-sac with Synthetic Substitute, Open Approach */
"0UUF0KZ" = "1" /* Supplement Cul-de-sac with Nonautologous Tissue Substitute, Open Approach */
"0UUF47Z" = "1" /* Supplement Cul-de-sac with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0UUF4JZ" = "1" /* Supplement Cul-de-sac with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0UUF4KZ" = "1" /* Supplement Cul-de-sac with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0UUF77Z" = "1" /* Supplement Cul-de-sac with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0UUF7JZ" = "1" /* Supplement Cul-de-sac with Synthetic Substitute, Via Natural or Artificial Opening */
"0UUF7KZ" = "1" /* Supplement Cul-de-sac with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0UUF87Z" = "1" /* Supplement Cul-de-sac with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0UUF8JZ" = "1" /* Supplement Cul-de-sac with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0UUF8KZ" = "1" /* Supplement Cul-de-sac with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0UUG07Z" = "1" /* Supplement Vagina with Autologous Tissue Substitute, Open Approach */
"0UUG0JZ" = "1" /* Supplement Vagina with Synthetic Substitute, Open Approach */
"0UUG0KZ" = "1" /* Supplement Vagina with Nonautologous Tissue Substitute, Open Approach */
"0UUG47Z" = "1" /* Supplement Vagina with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0UUG4JZ" = "1" /* Supplement Vagina with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0UUG4KZ" = "1" /* Supplement Vagina with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0UUG77Z" = "1" /* Supplement Vagina with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0UUG7JZ" = "1" /* Supplement Vagina with Synthetic Substitute, Via Natural or Artificial Opening */
"0UUG7KZ" = "1" /* Supplement Vagina with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0UUG87Z" = "1" /* Supplement Vagina with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0UUG8JZ" = "1" /* Supplement Vagina with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0UUG8KZ" = "1" /* Supplement Vagina with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0UUGX7Z" = "1" /* Supplement Vagina with Autologous Tissue Substitute, External Approach */
"0UUGXJZ" = "1" /* Supplement Vagina with Synthetic Substitute, External Approach */
"0UUGXKZ" = "1" /* Supplement Vagina with Nonautologous Tissue Substitute, External Approach */
"0UUJ07Z" = "1" /* Supplement Clitoris with Autologous Tissue Substitute, Open Approach */
"0UUJ0JZ" = "1" /* Supplement Clitoris with Synthetic Substitute, Open Approach */
"0UUJ0KZ" = "1" /* Supplement Clitoris with Nonautologous Tissue Substitute, Open Approach */
"0UUJX7Z" = "1" /* Supplement Clitoris with Autologous Tissue Substitute, External Approach */
"0UUJXJZ" = "1" /* Supplement Clitoris with Synthetic Substitute, External Approach */
"0UUJXKZ" = "1" /* Supplement Clitoris with Nonautologous Tissue Substitute, External Approach */
"0UUK07Z" = "1" /* Supplement Hymen with Autologous Tissue Substitute, Open Approach */
"0UUK0JZ" = "1" /* Supplement Hymen with Synthetic Substitute, Open Approach */
"0UUK0KZ" = "1" /* Supplement Hymen with Nonautologous Tissue Substitute, Open Approach */
"0UUK47Z" = "1" /* Supplement Hymen with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0UUK4JZ" = "1" /* Supplement Hymen with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0UUK4KZ" = "1" /* Supplement Hymen with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0UUK77Z" = "1" /* Supplement Hymen with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0UUK7JZ" = "1" /* Supplement Hymen with Synthetic Substitute, Via Natural or Artificial Opening */
"0UUK7KZ" = "1" /* Supplement Hymen with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0UUK87Z" = "1" /* Supplement Hymen with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0UUK8JZ" = "1" /* Supplement Hymen with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0UUK8KZ" = "1" /* Supplement Hymen with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0UUKX7Z" = "1" /* Supplement Hymen with Autologous Tissue Substitute, External Approach */
"0UUKXJZ" = "1" /* Supplement Hymen with Synthetic Substitute, External Approach */
"0UUKXKZ" = "1" /* Supplement Hymen with Nonautologous Tissue Substitute, External Approach */
"0UUM07Z" = "1" /* Supplement Vulva with Autologous Tissue Substitute, Open Approach */
"0UUM0JZ" = "1" /* Supplement Vulva with Synthetic Substitute, Open Approach */
"0UUM0KZ" = "1" /* Supplement Vulva with Nonautologous Tissue Substitute, Open Approach */
"0UUMX7Z" = "1" /* Supplement Vulva with Autologous Tissue Substitute, External Approach */
"0UUMXJZ" = "1" /* Supplement Vulva with Synthetic Substitute, External Approach */
"0UUMXKZ" = "1" /* Supplement Vulva with Nonautologous Tissue Substitute, External Approach */
"0UVC0CZ" = "1" /* Restriction of Cervix with Extraluminal Device, Open Approach */
"0UVC0DZ" = "1" /* Restriction of Cervix with Intraluminal Device, Open Approach */
"0UVC0ZZ" = "1" /* Restriction of Cervix, Open Approach */
"0UVC3CZ" = "1" /* Restriction of Cervix with Extraluminal Device, Percutaneous Approach */
"0UVC3DZ" = "1" /* Restriction of Cervix with Intraluminal Device, Percutaneous Approach */
"0UVC3ZZ" = "1" /* Restriction of Cervix, Percutaneous Approach */
"0UVC4CZ" = "1" /* Restriction of Cervix with Extraluminal Device, Percutaneous Endoscopic Approach */
"0UVC4DZ" = "1" /* Restriction of Cervix with Intraluminal Device, Percutaneous Endoscopic Approach */
"0UVC4ZZ" = "1" /* Restriction of Cervix, Percutaneous Endoscopic Approach */
"0UVC7DZ" = "1" /* Restriction of Cervix with Intraluminal Device, Via Natural or Artificial Opening */
"0UVC7ZZ" = "1" /* Restriction of Cervix, Via Natural or Artificial Opening */
"0UVC8DZ" = "1" /* Restriction of Cervix with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0UVC8ZZ" = "1" /* Restriction of Cervix, Via Natural or Artificial Opening Endoscopic */
"0UW300Z" = "1" /* Revision of Drainage Device in Ovary, Open Approach */
"0UW303Z" = "1" /* Revision of Infusion Device in Ovary, Open Approach */
"0UW330Z" = "1" /* Revision of Drainage Device in Ovary, Percutaneous Approach */
"0UW333Z" = "1" /* Revision of Infusion Device in Ovary, Percutaneous Approach */
"0UW340Z" = "1" /* Revision of Drainage Device in Ovary, Percutaneous Endoscopic Approach */
"0UW343Z" = "1" /* Revision of Infusion Device in Ovary, Percutaneous Endoscopic Approach */
"0UW800Z" = "1" /* Revision of Drainage Device in Fallopian Tube, Open Approach */
"0UW803Z" = "1" /* Revision of Infusion Device in Fallopian Tube, Open Approach */
"0UW807Z" = "1" /* Revision of Autologous Tissue Substitute in Fallopian Tube, Open Approach */
"0UW80CZ" = "1" /* Revision of Extraluminal Device in Fallopian Tube, Open Approach */
"0UW80DZ" = "1" /* Revision of Intraluminal Device in Fallopian Tube, Open Approach */
"0UW80JZ" = "1" /* Revision of Synthetic Substitute in Fallopian Tube, Open Approach */
"0UW80KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Fallopian Tube, Open Approach */
"0UW830Z" = "1" /* Revision of Drainage Device in Fallopian Tube, Percutaneous Approach */
"0UW833Z" = "1" /* Revision of Infusion Device in Fallopian Tube, Percutaneous Approach */
"0UW837Z" = "1" /* Revision of Autologous Tissue Substitute in Fallopian Tube, Percutaneous Approach */
"0UW83CZ" = "1" /* Revision of Extraluminal Device in Fallopian Tube, Percutaneous Approach */
"0UW83DZ" = "1" /* Revision of Intraluminal Device in Fallopian Tube, Percutaneous Approach */
"0UW83JZ" = "1" /* Revision of Synthetic Substitute in Fallopian Tube, Percutaneous Approach */
"0UW83KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Fallopian Tube, Percutaneous Approach */
"0UW840Z" = "1" /* Revision of Drainage Device in Fallopian Tube, Percutaneous Endoscopic Approach */
"0UW843Z" = "1" /* Revision of Infusion Device in Fallopian Tube, Percutaneous Endoscopic Approach */
"0UW847Z" = "1" /* Revision of Autologous Tissue Substitute in Fallopian Tube, Percutaneous Endoscopic Approach */
"0UW84CZ" = "1" /* Revision of Extraluminal Device in Fallopian Tube, Percutaneous Endoscopic Approach */
"0UW84DZ" = "1" /* Revision of Intraluminal Device in Fallopian Tube, Percutaneous Endoscopic Approach */
"0UW84JZ" = "1" /* Revision of Synthetic Substitute in Fallopian Tube, Percutaneous Endoscopic Approach */
"0UW84KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Fallopian Tube, Percutaneous Endoscopic Approach */
"0UW870Z" = "1" /* Revision of Drainage Device in Fallopian Tube, Via Natural or Artificial Opening */
"0UW873Z" = "1" /* Revision of Infusion Device in Fallopian Tube, Via Natural or Artificial Opening */
"0UW877Z" = "1" /* Revision of Autologous Tissue Substitute in Fallopian Tube, Via Natural or Artificial Opening */
"0UW87CZ" = "1" /* Revision of Extraluminal Device in Fallopian Tube, Via Natural or Artificial Opening */
"0UW87DZ" = "1" /* Revision of Intraluminal Device in Fallopian Tube, Via Natural or Artificial Opening */
"0UW87JZ" = "1" /* Revision of Synthetic Substitute in Fallopian Tube, Via Natural or Artificial Opening */
"0UW87KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Fallopian Tube, Via Natural or Artificial Opening */
"0UW880Z" = "1" /* Revision of Drainage Device in Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UW883Z" = "1" /* Revision of Infusion Device in Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UW887Z" = "1" /* Revision of Autologous Tissue Substitute in Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UW88CZ" = "1" /* Revision of Extraluminal Device in Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UW88DZ" = "1" /* Revision of Intraluminal Device in Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UW88JZ" = "1" /* Revision of Synthetic Substitute in Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UW88KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Fallopian Tube, Via Natural or Artificial Opening Endoscopic */
"0UWD00Z" = "1" /* Revision of Drainage Device in Uterus and Cervix, Open Approach */
"0UWD01Z" = "1" /* Revision of Radioactive Element in Uterus and Cervix, Open Approach */
"0UWD03Z" = "1" /* Revision of Infusion Device in Uterus and Cervix, Open Approach */
"0UWD07Z" = "1" /* Revision of Autologous Tissue Substitute in Uterus and Cervix, Open Approach */
"0UWD0CZ" = "1" /* Revision of Extraluminal Device in Uterus and Cervix, Open Approach */
"0UWD0DZ" = "1" /* Revision of Intraluminal Device in Uterus and Cervix, Open Approach */
"0UWD0HZ" = "1" /* Revision of Contraceptive Device in Uterus and Cervix, Open Approach */
"0UWD0JZ" = "1" /* Revision of Synthetic Substitute in Uterus and Cervix, Open Approach */
"0UWD0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Uterus and Cervix, Open Approach */
"0UWD30Z" = "1" /* Revision of Drainage Device in Uterus and Cervix, Percutaneous Approach */
"0UWD31Z" = "1" /* Revision of Radioactive Element in Uterus and Cervix, Percutaneous Approach */
"0UWD33Z" = "1" /* Revision of Infusion Device in Uterus and Cervix, Percutaneous Approach */
"0UWD37Z" = "1" /* Revision of Autologous Tissue Substitute in Uterus and Cervix, Percutaneous Approach */
"0UWD3CZ" = "1" /* Revision of Extraluminal Device in Uterus and Cervix, Percutaneous Approach */
"0UWD3DZ" = "1" /* Revision of Intraluminal Device in Uterus and Cervix, Percutaneous Approach */
"0UWD3HZ" = "1" /* Revision of Contraceptive Device in Uterus and Cervix, Percutaneous Approach */
"0UWD3JZ" = "1" /* Revision of Synthetic Substitute in Uterus and Cervix, Percutaneous Approach */
"0UWD3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Uterus and Cervix, Percutaneous Approach */
"0UWD40Z" = "1" /* Revision of Drainage Device in Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UWD41Z" = "1" /* Revision of Radioactive Element in Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UWD43Z" = "1" /* Revision of Infusion Device in Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UWD47Z" = "1" /* Revision of Autologous Tissue Substitute in Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UWD4CZ" = "1" /* Revision of Extraluminal Device in Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UWD4DZ" = "1" /* Revision of Intraluminal Device in Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UWD4HZ" = "1" /* Revision of Contraceptive Device in Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UWD4JZ" = "1" /* Revision of Synthetic Substitute in Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UWD4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Uterus and Cervix, Percutaneous Endoscopic Approach */
"0UWD70Z" = "1" /* Revision of Drainage Device in Uterus and Cervix, Via Natural or Artificial Opening */
"0UWD71Z" = "1" /* Revision of Radioactive Element in Uterus and Cervix, Via Natural or Artificial Opening */
"0UWD73Z" = "1" /* Revision of Infusion Device in Uterus and Cervix, Via Natural or Artificial Opening */
"0UWD77Z" = "1" /* Revision of Autologous Tissue Substitute in Uterus and Cervix, Via Natural or Artificial Opening */
"0UWD7CZ" = "1" /* Revision of Extraluminal Device in Uterus and Cervix, Via Natural or Artificial Opening */
"0UWD7DZ" = "1" /* Revision of Intraluminal Device in Uterus and Cervix, Via Natural or Artificial Opening */
"0UWD7HZ" = "1" /* Revision of Contraceptive Device in Uterus and Cervix, Via Natural or Artificial Opening */
"0UWD7JZ" = "1" /* Revision of Synthetic Substitute in Uterus and Cervix, Via Natural or Artificial Opening */
"0UWD7KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Uterus and Cervix, Via Natural or Artificial Opening */
"0UWD80Z" = "1" /* Revision of Drainage Device in Uterus and Cervix, Via Natural or Artificial Opening Endoscopic */
"0UWD81Z" = "1" /* Revision of Radioactive Element in Uterus and Cervix, Via Natural or Artificial Opening Endoscopic */
"0UWD83Z" = "1" /* Revision of Infusion Device in Uterus and Cervix, Via Natural or Artificial Opening Endoscopic */
"0UWD87Z" = "1" /* Revision of Autologous Tissue Substitute in Uterus and Cervix, Via Natural or Artificial Opening Endoscopic */
"0UWD8CZ" = "1" /* Revision of Extraluminal Device in Uterus and Cervix, Via Natural or Artificial Opening Endoscopic */
"0UWD8DZ" = "1" /* Revision of Intraluminal Device in Uterus and Cervix, Via Natural or Artificial Opening Endoscopic */
"0UWD8HZ" = "1" /* Revision of Contraceptive Device in Uterus and Cervix, Via Natural or Artificial Opening Endoscopic */
"0UWD8JZ" = "1" /* Revision of Synthetic Substitute in Uterus and Cervix, Via Natural or Artificial Opening Endoscopic */
"0UWD8KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Uterus and Cervix, Via Natural or Artificial Opening Endoscopic */
"0UWH00Z" = "1" /* Revision of Drainage Device in Vagina and Cul-de-sac, Open Approach */
"0UWH01Z" = "1" /* Revision of Radioactive Element in Vagina and Cul-de-sac, Open Approach */
"0UWH03Z" = "1" /* Revision of Infusion Device in Vagina and Cul-de-sac, Open Approach */
"0UWH07Z" = "1" /* Revision of Autologous Tissue Substitute in Vagina and Cul-de-sac, Open Approach */
"0UWH0DZ" = "1" /* Revision of Intraluminal Device in Vagina and Cul-de-sac, Open Approach */
"0UWH0JZ" = "1" /* Revision of Synthetic Substitute in Vagina and Cul-de-sac, Open Approach */
"0UWH0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Vagina and Cul-de-sac, Open Approach */
"0UWH30Z" = "1" /* Revision of Drainage Device in Vagina and Cul-de-sac, Percutaneous Approach */
"0UWH31Z" = "1" /* Revision of Radioactive Element in Vagina and Cul-de-sac, Percutaneous Approach */
"0UWH33Z" = "1" /* Revision of Infusion Device in Vagina and Cul-de-sac, Percutaneous Approach */
"0UWH37Z" = "1" /* Revision of Autologous Tissue Substitute in Vagina and Cul-de-sac, Percutaneous Approach */
"0UWH3DZ" = "1" /* Revision of Intraluminal Device in Vagina and Cul-de-sac, Percutaneous Approach */
"0UWH3JZ" = "1" /* Revision of Synthetic Substitute in Vagina and Cul-de-sac, Percutaneous Approach */
"0UWH3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Vagina and Cul-de-sac, Percutaneous Approach */
"0UWH40Z" = "1" /* Revision of Drainage Device in Vagina and Cul-de-sac, Percutaneous Endoscopic Approach */
"0UWH41Z" = "1" /* Revision of Radioactive Element in Vagina and Cul-de-sac, Percutaneous Endoscopic Approach */
"0UWH43Z" = "1" /* Revision of Infusion Device in Vagina and Cul-de-sac, Percutaneous Endoscopic Approach */
"0UWH47Z" = "1" /* Revision of Autologous Tissue Substitute in Vagina and Cul-de-sac, Percutaneous Endoscopic Approach */
"0UWH4DZ" = "1" /* Revision of Intraluminal Device in Vagina and Cul-de-sac, Percutaneous Endoscopic Approach */
"0UWH4JZ" = "1" /* Revision of Synthetic Substitute in Vagina and Cul-de-sac, Percutaneous Endoscopic Approach */
"0UWH4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Vagina and Cul-de-sac, Percutaneous Endoscopic Approach */
"0UWH70Z" = "1" /* Revision of Drainage Device in Vagina and Cul-de-sac, Via Natural or Artificial Opening */
"0UWH71Z" = "1" /* Revision of Radioactive Element in Vagina and Cul-de-sac, Via Natural or Artificial Opening */
"0UWH73Z" = "1" /* Revision of Infusion Device in Vagina and Cul-de-sac, Via Natural or Artificial Opening */
"0UWH77Z" = "1" /* Revision of Autologous Tissue Substitute in Vagina and Cul-de-sac, Via Natural or Artificial Opening */
"0UWH7DZ" = "1" /* Revision of Intraluminal Device in Vagina and Cul-de-sac, Via Natural or Artificial Opening */
"0UWH7JZ" = "1" /* Revision of Synthetic Substitute in Vagina and Cul-de-sac, Via Natural or Artificial Opening */
"0UWH7KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Vagina and Cul-de-sac, Via Natural or Artificial Opening */
"0UWH80Z" = "1" /* Revision of Drainage Device in Vagina and Cul-de-sac, Via Natural or Artificial Opening Endoscopic */
"0UWH81Z" = "1" /* Revision of Radioactive Element in Vagina and Cul-de-sac, Via Natural or Artificial Opening Endoscopic */
"0UWH83Z" = "1" /* Revision of Infusion Device in Vagina and Cul-de-sac, Via Natural or Artificial Opening Endoscopic */
"0UWH87Z" = "1" /* Revision of Autologous Tissue Substitute in Vagina and Cul-de-sac, Via Natural or Artificial Opening Endoscopic */
"0UWH8DZ" = "1" /* Revision of Intraluminal Device in Vagina and Cul-de-sac, Via Natural or Artificial Opening Endoscopic */
"0UWH8JZ" = "1" /* Revision of Synthetic Substitute in Vagina and Cul-de-sac, Via Natural or Artificial Opening Endoscopic */
"0UWH8KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Vagina and Cul-de-sac, Via Natural or Artificial Opening Endoscopic */
"0UWM00Z" = "1" /* Revision of Drainage Device in Vulva, Open Approach */
"0UWM07Z" = "1" /* Revision of Autologous Tissue Substitute in Vulva, Open Approach */
"0UWM0JZ" = "1" /* Revision of Synthetic Substitute in Vulva, Open Approach */
"0UWM0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Vulva, Open Approach */
"0UY00Z0" = "1" /* Transplantation of Right Ovary, Allogeneic, Open Approach */
"0UY00Z1" = "1" /* Transplantation of Right Ovary, Syngeneic, Open Approach */
"0UY00Z2" = "1" /* Transplantation of Right Ovary, Zooplastic, Open Approach */
"0UY10Z0" = "1" /* Transplantation of Left Ovary, Allogeneic, Open Approach */
"0UY10Z1" = "1" /* Transplantation of Left Ovary, Syngeneic, Open Approach */
"0UY10Z2" = "1" /* Transplantation of Left Ovary, Zooplastic, Open Approach */
"0V1N07J" = "1" /* Bypass Right Vas Deferens to Right Epididymis with Autologous Tissue Substitute, Open Approach */
"0V1N07K" = "1" /* Bypass Right Vas Deferens to Left Epididymis with Autologous Tissue Substitute, Open Approach */
"0V1N07N" = "1" /* Bypass Right Vas Deferens to Right Vas Deferens with Autologous Tissue Substitute, Open Approach */
"0V1N07P" = "1" /* Bypass Right Vas Deferens to Left Vas Deferens with Autologous Tissue Substitute, Open Approach */
"0V1N0JJ" = "1" /* Bypass Right Vas Deferens to Right Epididymis with Synthetic Substitute, Open Approach */
"0V1N0JK" = "1" /* Bypass Right Vas Deferens to Left Epididymis with Synthetic Substitute, Open Approach */
"0V1N0JN" = "1" /* Bypass Right Vas Deferens to Right Vas Deferens with Synthetic Substitute, Open Approach */
"0V1N0JP" = "1" /* Bypass Right Vas Deferens to Left Vas Deferens with Synthetic Substitute, Open Approach */
"0V1N0KJ" = "1" /* Bypass Right Vas Deferens to Right Epididymis with Nonautologous Tissue Substitute, Open Approach */
"0V1N0KK" = "1" /* Bypass Right Vas Deferens to Left Epididymis with Nonautologous Tissue Substitute, Open Approach */
"0V1N0KN" = "1" /* Bypass Right Vas Deferens to Right Vas Deferens with Nonautologous Tissue Substitute, Open Approach */
"0V1N0KP" = "1" /* Bypass Right Vas Deferens to Left Vas Deferens with Nonautologous Tissue Substitute, Open Approach */
"0V1N0ZJ" = "1" /* Bypass Right Vas Deferens to Right Epididymis, Open Approach */
"0V1N0ZK" = "1" /* Bypass Right Vas Deferens to Left Epididymis, Open Approach */
"0V1N0ZN" = "1" /* Bypass Right Vas Deferens to Right Vas Deferens, Open Approach */
"0V1N0ZP" = "1" /* Bypass Right Vas Deferens to Left Vas Deferens, Open Approach */
"0V1N47J" = "1" /* Bypass Right Vas Deferens to Right Epididymis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1N47K" = "1" /* Bypass Right Vas Deferens to Left Epididymis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1N47N" = "1" /* Bypass Right Vas Deferens to Right Vas Deferens with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1N47P" = "1" /* Bypass Right Vas Deferens to Left Vas Deferens with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1N4JJ" = "1" /* Bypass Right Vas Deferens to Right Epididymis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0V1N4JK" = "1" /* Bypass Right Vas Deferens to Left Epididymis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0V1N4JN" = "1" /* Bypass Right Vas Deferens to Right Vas Deferens with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0V1N4JP" = "1" /* Bypass Right Vas Deferens to Left Vas Deferens with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0V1N4KJ" = "1" /* Bypass Right Vas Deferens to Right Epididymis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1N4KK" = "1" /* Bypass Right Vas Deferens to Left Epididymis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1N4KN" = "1" /* Bypass Right Vas Deferens to Right Vas Deferens with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1N4KP" = "1" /* Bypass Right Vas Deferens to Left Vas Deferens with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1N4ZJ" = "1" /* Bypass Right Vas Deferens to Right Epididymis, Percutaneous Endoscopic Approach */
"0V1N4ZK" = "1" /* Bypass Right Vas Deferens to Left Epididymis, Percutaneous Endoscopic Approach */
"0V1N4ZN" = "1" /* Bypass Right Vas Deferens to Right Vas Deferens, Percutaneous Endoscopic Approach */
"0V1N4ZP" = "1" /* Bypass Right Vas Deferens to Left Vas Deferens, Percutaneous Endoscopic Approach */
"0V1P07J" = "1" /* Bypass Left Vas Deferens to Right Epididymis with Autologous Tissue Substitute, Open Approach */
"0V1P07K" = "1" /* Bypass Left Vas Deferens to Left Epididymis with Autologous Tissue Substitute, Open Approach */
"0V1P07N" = "1" /* Bypass Left Vas Deferens to Right Vas Deferens with Autologous Tissue Substitute, Open Approach */
"0V1P07P" = "1" /* Bypass Left Vas Deferens to Left Vas Deferens with Autologous Tissue Substitute, Open Approach */
"0V1P0JJ" = "1" /* Bypass Left Vas Deferens to Right Epididymis with Synthetic Substitute, Open Approach */
"0V1P0JK" = "1" /* Bypass Left Vas Deferens to Left Epididymis with Synthetic Substitute, Open Approach */
"0V1P0JN" = "1" /* Bypass Left Vas Deferens to Right Vas Deferens with Synthetic Substitute, Open Approach */
"0V1P0JP" = "1" /* Bypass Left Vas Deferens to Left Vas Deferens with Synthetic Substitute, Open Approach */
"0V1P0KJ" = "1" /* Bypass Left Vas Deferens to Right Epididymis with Nonautologous Tissue Substitute, Open Approach */
"0V1P0KK" = "1" /* Bypass Left Vas Deferens to Left Epididymis with Nonautologous Tissue Substitute, Open Approach */
"0V1P0KN" = "1" /* Bypass Left Vas Deferens to Right Vas Deferens with Nonautologous Tissue Substitute, Open Approach */
"0V1P0KP" = "1" /* Bypass Left Vas Deferens to Left Vas Deferens with Nonautologous Tissue Substitute, Open Approach */
"0V1P0ZJ" = "1" /* Bypass Left Vas Deferens to Right Epididymis, Open Approach */
"0V1P0ZK" = "1" /* Bypass Left Vas Deferens to Left Epididymis, Open Approach */
"0V1P0ZN" = "1" /* Bypass Left Vas Deferens to Right Vas Deferens, Open Approach */
"0V1P0ZP" = "1" /* Bypass Left Vas Deferens to Left Vas Deferens, Open Approach */
"0V1P47J" = "1" /* Bypass Left Vas Deferens to Right Epididymis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1P47K" = "1" /* Bypass Left Vas Deferens to Left Epididymis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1P47N" = "1" /* Bypass Left Vas Deferens to Right Vas Deferens with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1P47P" = "1" /* Bypass Left Vas Deferens to Left Vas Deferens with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1P4JJ" = "1" /* Bypass Left Vas Deferens to Right Epididymis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0V1P4JK" = "1" /* Bypass Left Vas Deferens to Left Epididymis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0V1P4JN" = "1" /* Bypass Left Vas Deferens to Right Vas Deferens with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0V1P4JP" = "1" /* Bypass Left Vas Deferens to Left Vas Deferens with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0V1P4KJ" = "1" /* Bypass Left Vas Deferens to Right Epididymis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1P4KK" = "1" /* Bypass Left Vas Deferens to Left Epididymis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1P4KN" = "1" /* Bypass Left Vas Deferens to Right Vas Deferens with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1P4KP" = "1" /* Bypass Left Vas Deferens to Left Vas Deferens with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1P4ZJ" = "1" /* Bypass Left Vas Deferens to Right Epididymis, Percutaneous Endoscopic Approach */
"0V1P4ZK" = "1" /* Bypass Left Vas Deferens to Left Epididymis, Percutaneous Endoscopic Approach */
"0V1P4ZN" = "1" /* Bypass Left Vas Deferens to Right Vas Deferens, Percutaneous Endoscopic Approach */
"0V1P4ZP" = "1" /* Bypass Left Vas Deferens to Left Vas Deferens, Percutaneous Endoscopic Approach */
"0V1Q07J" = "1" /* Bypass Bilateral Vas Deferens to Right Epididymis with Autologous Tissue Substitute, Open Approach */
"0V1Q07K" = "1" /* Bypass Bilateral Vas Deferens to Left Epididymis with Autologous Tissue Substitute, Open Approach */
"0V1Q07N" = "1" /* Bypass Bilateral Vas Deferens to Right Vas Deferens with Autologous Tissue Substitute, Open Approach */
"0V1Q07P" = "1" /* Bypass Bilateral Vas Deferens to Left Vas Deferens with Autologous Tissue Substitute, Open Approach */
"0V1Q0JJ" = "1" /* Bypass Bilateral Vas Deferens to Right Epididymis with Synthetic Substitute, Open Approach */
"0V1Q0JK" = "1" /* Bypass Bilateral Vas Deferens to Left Epididymis with Synthetic Substitute, Open Approach */
"0V1Q0JN" = "1" /* Bypass Bilateral Vas Deferens to Right Vas Deferens with Synthetic Substitute, Open Approach */
"0V1Q0JP" = "1" /* Bypass Bilateral Vas Deferens to Left Vas Deferens with Synthetic Substitute, Open Approach */
"0V1Q0KJ" = "1" /* Bypass Bilateral Vas Deferens to Right Epididymis with Nonautologous Tissue Substitute, Open Approach */
"0V1Q0KK" = "1" /* Bypass Bilateral Vas Deferens to Left Epididymis with Nonautologous Tissue Substitute, Open Approach */
"0V1Q0KN" = "1" /* Bypass Bilateral Vas Deferens to Right Vas Deferens with Nonautologous Tissue Substitute, Open Approach */
"0V1Q0KP" = "1" /* Bypass Bilateral Vas Deferens to Left Vas Deferens with Nonautologous Tissue Substitute, Open Approach */
"0V1Q0ZJ" = "1" /* Bypass Bilateral Vas Deferens to Right Epididymis, Open Approach */
"0V1Q0ZK" = "1" /* Bypass Bilateral Vas Deferens to Left Epididymis, Open Approach */
"0V1Q0ZN" = "1" /* Bypass Bilateral Vas Deferens to Right Vas Deferens, Open Approach */
"0V1Q0ZP" = "1" /* Bypass Bilateral Vas Deferens to Left Vas Deferens, Open Approach */
"0V1Q47J" = "1" /* Bypass Bilateral Vas Deferens to Right Epididymis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1Q47K" = "1" /* Bypass Bilateral Vas Deferens to Left Epididymis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1Q47N" = "1" /* Bypass Bilateral Vas Deferens to Right Vas Deferens with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1Q47P" = "1" /* Bypass Bilateral Vas Deferens to Left Vas Deferens with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1Q4JJ" = "1" /* Bypass Bilateral Vas Deferens to Right Epididymis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0V1Q4JK" = "1" /* Bypass Bilateral Vas Deferens to Left Epididymis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0V1Q4JN" = "1" /* Bypass Bilateral Vas Deferens to Right Vas Deferens with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0V1Q4JP" = "1" /* Bypass Bilateral Vas Deferens to Left Vas Deferens with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0V1Q4KJ" = "1" /* Bypass Bilateral Vas Deferens to Right Epididymis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1Q4KK" = "1" /* Bypass Bilateral Vas Deferens to Left Epididymis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1Q4KN" = "1" /* Bypass Bilateral Vas Deferens to Right Vas Deferens with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1Q4KP" = "1" /* Bypass Bilateral Vas Deferens to Left Vas Deferens with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0V1Q4ZJ" = "1" /* Bypass Bilateral Vas Deferens to Right Epididymis, Percutaneous Endoscopic Approach */
"0V1Q4ZK" = "1" /* Bypass Bilateral Vas Deferens to Left Epididymis, Percutaneous Endoscopic Approach */
"0V1Q4ZN" = "1" /* Bypass Bilateral Vas Deferens to Right Vas Deferens, Percutaneous Endoscopic Approach */
"0V1Q4ZP" = "1" /* Bypass Bilateral Vas Deferens to Left Vas Deferens, Percutaneous Endoscopic Approach */
"0V500ZZ" = "1" /* Destruction of Prostate, Open Approach */
"0V503ZZ" = "1" /* Destruction of Prostate, Percutaneous Approach */
"0V504ZZ" = "1" /* Destruction of Prostate, Percutaneous Endoscopic Approach */
"0V507ZZ" = "1" /* Destruction of Prostate, Via Natural or Artificial Opening */
"0V508ZZ" = "1" /* Destruction of Prostate, Via Natural or Artificial Opening Endoscopic */
"0V510ZZ" = "1" /* Destruction of Right Seminal Vesicle, Open Approach */
"0V513ZZ" = "1" /* Destruction of Right Seminal Vesicle, Percutaneous Approach */
"0V514ZZ" = "1" /* Destruction of Right Seminal Vesicle, Percutaneous Endoscopic Approach */
"0V520ZZ" = "1" /* Destruction of Left Seminal Vesicle, Open Approach */
"0V523ZZ" = "1" /* Destruction of Left Seminal Vesicle, Percutaneous Approach */
"0V524ZZ" = "1" /* Destruction of Left Seminal Vesicle, Percutaneous Endoscopic Approach */
"0V530ZZ" = "1" /* Destruction of Bilateral Seminal Vesicles, Open Approach */
"0V533ZZ" = "1" /* Destruction of Bilateral Seminal Vesicles, Percutaneous Approach */
"0V534ZZ" = "1" /* Destruction of Bilateral Seminal Vesicles, Percutaneous Endoscopic Approach */
"0V560ZZ" = "1" /* Destruction of Right Tunica Vaginalis, Open Approach */
"0V563ZZ" = "1" /* Destruction of Right Tunica Vaginalis, Percutaneous Approach */
"0V564ZZ" = "1" /* Destruction of Right Tunica Vaginalis, Percutaneous Endoscopic Approach */
"0V570ZZ" = "1" /* Destruction of Left Tunica Vaginalis, Open Approach */
"0V573ZZ" = "1" /* Destruction of Left Tunica Vaginalis, Percutaneous Approach */
"0V574ZZ" = "1" /* Destruction of Left Tunica Vaginalis, Percutaneous Endoscopic Approach */
"0V590ZZ" = "1" /* Destruction of Right Testis, Open Approach */
"0V593ZZ" = "1" /* Destruction of Right Testis, Percutaneous Approach */
"0V594ZZ" = "1" /* Destruction of Right Testis, Percutaneous Endoscopic Approach */
"0V5B0ZZ" = "1" /* Destruction of Left Testis, Open Approach */
"0V5B3ZZ" = "1" /* Destruction of Left Testis, Percutaneous Approach */
"0V5B4ZZ" = "1" /* Destruction of Left Testis, Percutaneous Endoscopic Approach */
"0V5C0ZZ" = "1" /* Destruction of Bilateral Testes, Open Approach */
"0V5C3ZZ" = "1" /* Destruction of Bilateral Testes, Percutaneous Approach */
"0V5C4ZZ" = "1" /* Destruction of Bilateral Testes, Percutaneous Endoscopic Approach */
"0V5F0ZZ" = "1" /* Destruction of Right Spermatic Cord, Open Approach */
"0V5F3ZZ" = "1" /* Destruction of Right Spermatic Cord, Percutaneous Approach */
"0V5F4ZZ" = "1" /* Destruction of Right Spermatic Cord, Percutaneous Endoscopic Approach */
"0V5G0ZZ" = "1" /* Destruction of Left Spermatic Cord, Open Approach */
"0V5G3ZZ" = "1" /* Destruction of Left Spermatic Cord, Percutaneous Approach */
"0V5G4ZZ" = "1" /* Destruction of Left Spermatic Cord, Percutaneous Endoscopic Approach */
"0V5H0ZZ" = "1" /* Destruction of Bilateral Spermatic Cords, Open Approach */
"0V5H3ZZ" = "1" /* Destruction of Bilateral Spermatic Cords, Percutaneous Approach */
"0V5H4ZZ" = "1" /* Destruction of Bilateral Spermatic Cords, Percutaneous Endoscopic Approach */
"0V5J0ZZ" = "1" /* Destruction of Right Epididymis, Open Approach */
"0V5J3ZZ" = "1" /* Destruction of Right Epididymis, Percutaneous Approach */
"0V5J4ZZ" = "1" /* Destruction of Right Epididymis, Percutaneous Endoscopic Approach */
"0V5K0ZZ" = "1" /* Destruction of Left Epididymis, Open Approach */
"0V5K3ZZ" = "1" /* Destruction of Left Epididymis, Percutaneous Approach */
"0V5K4ZZ" = "1" /* Destruction of Left Epididymis, Percutaneous Endoscopic Approach */
"0V5L0ZZ" = "1" /* Destruction of Bilateral Epididymis, Open Approach */
"0V5L3ZZ" = "1" /* Destruction of Bilateral Epididymis, Percutaneous Approach */
"0V5L4ZZ" = "1" /* Destruction of Bilateral Epididymis, Percutaneous Endoscopic Approach */
"0V5S0ZZ" = "1" /* Destruction of Penis, Open Approach */
"0V5S3ZZ" = "1" /* Destruction of Penis, Percutaneous Approach */
"0V5S4ZZ" = "1" /* Destruction of Penis, Percutaneous Endoscopic Approach */
"0V5SXZZ" = "1" /* Destruction of Penis, External Approach */
"0V5T0ZZ" = "1" /* Destruction of Prepuce, Open Approach */
"0V5T3ZZ" = "1" /* Destruction of Prepuce, Percutaneous Approach */
"0V5T4ZZ" = "1" /* Destruction of Prepuce, Percutaneous Endoscopic Approach */
"0V5TXZZ" = "1" /* Destruction of Prepuce, External Approach */
"0V7N0DZ" = "1" /* Dilation of Right Vas Deferens with Intraluminal Device, Open Approach */
"0V7N0ZZ" = "1" /* Dilation of Right Vas Deferens, Open Approach */
"0V7N3DZ" = "1" /* Dilation of Right Vas Deferens with Intraluminal Device, Percutaneous Approach */
"0V7N3ZZ" = "1" /* Dilation of Right Vas Deferens, Percutaneous Approach */
"0V7N4DZ" = "1" /* Dilation of Right Vas Deferens with Intraluminal Device, Percutaneous Endoscopic Approach */
"0V7N4ZZ" = "1" /* Dilation of Right Vas Deferens, Percutaneous Endoscopic Approach */
"0V7P0DZ" = "1" /* Dilation of Left Vas Deferens with Intraluminal Device, Open Approach */
"0V7P0ZZ" = "1" /* Dilation of Left Vas Deferens, Open Approach */
"0V7P3DZ" = "1" /* Dilation of Left Vas Deferens with Intraluminal Device, Percutaneous Approach */
"0V7P3ZZ" = "1" /* Dilation of Left Vas Deferens, Percutaneous Approach */
"0V7P4DZ" = "1" /* Dilation of Left Vas Deferens with Intraluminal Device, Percutaneous Endoscopic Approach */
"0V7P4ZZ" = "1" /* Dilation of Left Vas Deferens, Percutaneous Endoscopic Approach */
"0V7Q0DZ" = "1" /* Dilation of Bilateral Vas Deferens with Intraluminal Device, Open Approach */
"0V7Q0ZZ" = "1" /* Dilation of Bilateral Vas Deferens, Open Approach */
"0V7Q3DZ" = "1" /* Dilation of Bilateral Vas Deferens with Intraluminal Device, Percutaneous Approach */
"0V7Q3ZZ" = "1" /* Dilation of Bilateral Vas Deferens, Percutaneous Approach */
"0V7Q4DZ" = "1" /* Dilation of Bilateral Vas Deferens with Intraluminal Device, Percutaneous Endoscopic Approach */
"0V7Q4ZZ" = "1" /* Dilation of Bilateral Vas Deferens, Percutaneous Endoscopic Approach */
"0V9000Z" = "1" /* Drainage of Prostate with Drainage Device, Open Approach */
"0V900ZX" = "1" /* Drainage of Prostate, Open Approach, Diagnostic */
"0V900ZZ" = "1" /* Drainage of Prostate, Open Approach */
"0V9070Z" = "1" /* Drainage of Prostate with Drainage Device, Via Natural or Artificial Opening */
"0V907ZZ" = "1" /* Drainage of Prostate, Via Natural or Artificial Opening */
"0V9080Z" = "1" /* Drainage of Prostate with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0V908ZZ" = "1" /* Drainage of Prostate, Via Natural or Artificial Opening Endoscopic */
"0V9100Z" = "1" /* Drainage of Right Seminal Vesicle with Drainage Device, Open Approach */
"0V910ZX" = "1" /* Drainage of Right Seminal Vesicle, Open Approach, Diagnostic */
"0V910ZZ" = "1" /* Drainage of Right Seminal Vesicle, Open Approach */
"0V9200Z" = "1" /* Drainage of Left Seminal Vesicle with Drainage Device, Open Approach */
"0V920ZX" = "1" /* Drainage of Left Seminal Vesicle, Open Approach, Diagnostic */
"0V920ZZ" = "1" /* Drainage of Left Seminal Vesicle, Open Approach */
"0V9300Z" = "1" /* Drainage of Bilateral Seminal Vesicles with Drainage Device, Open Approach */
"0V930ZX" = "1" /* Drainage of Bilateral Seminal Vesicles, Open Approach, Diagnostic */
"0V930ZZ" = "1" /* Drainage of Bilateral Seminal Vesicles, Open Approach */
"0V9900Z" = "1" /* Drainage of Right Testis with Drainage Device, Open Approach */
"0V990ZX" = "1" /* Drainage of Right Testis, Open Approach, Diagnostic */
"0V990ZZ" = "1" /* Drainage of Right Testis, Open Approach */
"0V9B00Z" = "1" /* Drainage of Left Testis with Drainage Device, Open Approach */
"0V9B0ZX" = "1" /* Drainage of Left Testis, Open Approach, Diagnostic */
"0V9B0ZZ" = "1" /* Drainage of Left Testis, Open Approach */
"0V9C00Z" = "1" /* Drainage of Bilateral Testes with Drainage Device, Open Approach */
"0V9C0ZX" = "1" /* Drainage of Bilateral Testes, Open Approach, Diagnostic */
"0V9C0ZZ" = "1" /* Drainage of Bilateral Testes, Open Approach */
"0V9J00Z" = "1" /* Drainage of Right Epididymis with Drainage Device, Open Approach */
"0V9J0ZZ" = "1" /* Drainage of Right Epididymis, Open Approach */
"0V9J40Z" = "1" /* Drainage of Right Epididymis with Drainage Device, Percutaneous Endoscopic Approach */
"0V9J4ZZ" = "1" /* Drainage of Right Epididymis, Percutaneous Endoscopic Approach */
"0V9K00Z" = "1" /* Drainage of Left Epididymis with Drainage Device, Open Approach */
"0V9K0ZZ" = "1" /* Drainage of Left Epididymis, Open Approach */
"0V9K40Z" = "1" /* Drainage of Left Epididymis with Drainage Device, Percutaneous Endoscopic Approach */
"0V9K4ZZ" = "1" /* Drainage of Left Epididymis, Percutaneous Endoscopic Approach */
"0V9L00Z" = "1" /* Drainage of Bilateral Epididymis with Drainage Device, Open Approach */
"0V9L0ZZ" = "1" /* Drainage of Bilateral Epididymis, Open Approach */
"0V9L40Z" = "1" /* Drainage of Bilateral Epididymis with Drainage Device, Percutaneous Endoscopic Approach */
"0V9L4ZZ" = "1" /* Drainage of Bilateral Epididymis, Percutaneous Endoscopic Approach */
"0V9S00Z" = "1" /* Drainage of Penis with Drainage Device, Open Approach */
"0V9S0ZX" = "1" /* Drainage of Penis, Open Approach, Diagnostic */
"0V9S0ZZ" = "1" /* Drainage of Penis, Open Approach */
"0V9S40Z" = "1" /* Drainage of Penis with Drainage Device, Percutaneous Endoscopic Approach */
"0V9S4ZX" = "1" /* Drainage of Penis, Percutaneous Endoscopic Approach, Diagnostic */
"0V9S4ZZ" = "1" /* Drainage of Penis, Percutaneous Endoscopic Approach */
"0V9SX0Z" = "1" /* Drainage of Penis with Drainage Device, External Approach */
"0V9SXZX" = "1" /* Drainage of Penis, External Approach, Diagnostic */
"0V9SXZZ" = "1" /* Drainage of Penis, External Approach */
"0V9T00Z" = "1" /* Drainage of Prepuce with Drainage Device, Open Approach */
"0V9T0ZX" = "1" /* Drainage of Prepuce, Open Approach, Diagnostic */
"0V9T0ZZ" = "1" /* Drainage of Prepuce, Open Approach */
"0V9T40Z" = "1" /* Drainage of Prepuce with Drainage Device, Percutaneous Endoscopic Approach */
"0V9T4ZX" = "1" /* Drainage of Prepuce, Percutaneous Endoscopic Approach, Diagnostic */
"0V9T4ZZ" = "1" /* Drainage of Prepuce, Percutaneous Endoscopic Approach */
"0V9TX0Z" = "1" /* Drainage of Prepuce with Drainage Device, External Approach */
"0V9TXZX" = "1" /* Drainage of Prepuce, External Approach, Diagnostic */
"0V9TXZZ" = "1" /* Drainage of Prepuce, External Approach */
"0VB00ZX" = "1" /* Excision of Prostate, Open Approach, Diagnostic */
"0VB00ZZ" = "1" /* Excision of Prostate, Open Approach */
"0VB03ZZ" = "1" /* Excision of Prostate, Percutaneous Approach */
"0VB04ZZ" = "1" /* Excision of Prostate, Percutaneous Endoscopic Approach */
"0VB07ZZ" = "1" /* Excision of Prostate, Via Natural or Artificial Opening */
"0VB08ZZ" = "1" /* Excision of Prostate, Via Natural or Artificial Opening Endoscopic */
"0VB10ZX" = "1" /* Excision of Right Seminal Vesicle, Open Approach, Diagnostic */
"0VB10ZZ" = "1" /* Excision of Right Seminal Vesicle, Open Approach */
"0VB13ZZ" = "1" /* Excision of Right Seminal Vesicle, Percutaneous Approach */
"0VB14ZZ" = "1" /* Excision of Right Seminal Vesicle, Percutaneous Endoscopic Approach */
"0VB20ZX" = "1" /* Excision of Left Seminal Vesicle, Open Approach, Diagnostic */
"0VB20ZZ" = "1" /* Excision of Left Seminal Vesicle, Open Approach */
"0VB23ZZ" = "1" /* Excision of Left Seminal Vesicle, Percutaneous Approach */
"0VB24ZZ" = "1" /* Excision of Left Seminal Vesicle, Percutaneous Endoscopic Approach */
"0VB30ZX" = "1" /* Excision of Bilateral Seminal Vesicles, Open Approach, Diagnostic */
"0VB30ZZ" = "1" /* Excision of Bilateral Seminal Vesicles, Open Approach */
"0VB33ZZ" = "1" /* Excision of Bilateral Seminal Vesicles, Percutaneous Approach */
"0VB34ZZ" = "1" /* Excision of Bilateral Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VB60ZZ" = "1" /* Excision of Right Tunica Vaginalis, Open Approach */
"0VB63ZZ" = "1" /* Excision of Right Tunica Vaginalis, Percutaneous Approach */
"0VB64ZZ" = "1" /* Excision of Right Tunica Vaginalis, Percutaneous Endoscopic Approach */
"0VB70ZZ" = "1" /* Excision of Left Tunica Vaginalis, Open Approach */
"0VB73ZZ" = "1" /* Excision of Left Tunica Vaginalis, Percutaneous Approach */
"0VB74ZZ" = "1" /* Excision of Left Tunica Vaginalis, Percutaneous Endoscopic Approach */
"0VB90ZX" = "1" /* Excision of Right Testis, Open Approach, Diagnostic */
"0VB90ZZ" = "1" /* Excision of Right Testis, Open Approach */
"0VB93ZZ" = "1" /* Excision of Right Testis, Percutaneous Approach */
"0VB94ZZ" = "1" /* Excision of Right Testis, Percutaneous Endoscopic Approach */
"0VBB0ZX" = "1" /* Excision of Left Testis, Open Approach, Diagnostic */
"0VBB0ZZ" = "1" /* Excision of Left Testis, Open Approach */
"0VBB3ZZ" = "1" /* Excision of Left Testis, Percutaneous Approach */
"0VBB4ZZ" = "1" /* Excision of Left Testis, Percutaneous Endoscopic Approach */
"0VBC0ZX" = "1" /* Excision of Bilateral Testes, Open Approach, Diagnostic */
"0VBC0ZZ" = "1" /* Excision of Bilateral Testes, Open Approach */
"0VBC3ZZ" = "1" /* Excision of Bilateral Testes, Percutaneous Approach */
"0VBC4ZZ" = "1" /* Excision of Bilateral Testes, Percutaneous Endoscopic Approach */
"0VBF0ZZ" = "1" /* Excision of Right Spermatic Cord, Open Approach */
"0VBF3ZZ" = "1" /* Excision of Right Spermatic Cord, Percutaneous Approach */
"0VBF4ZZ" = "1" /* Excision of Right Spermatic Cord, Percutaneous Endoscopic Approach */
"0VBG0ZZ" = "1" /* Excision of Left Spermatic Cord, Open Approach */
"0VBG3ZZ" = "1" /* Excision of Left Spermatic Cord, Percutaneous Approach */
"0VBG4ZZ" = "1" /* Excision of Left Spermatic Cord, Percutaneous Endoscopic Approach */
"0VBH0ZZ" = "1" /* Excision of Bilateral Spermatic Cords, Open Approach */
"0VBH3ZZ" = "1" /* Excision of Bilateral Spermatic Cords, Percutaneous Approach */
"0VBH4ZZ" = "1" /* Excision of Bilateral Spermatic Cords, Percutaneous Endoscopic Approach */
"0VBJ0ZZ" = "1" /* Excision of Right Epididymis, Open Approach */
"0VBJ3ZZ" = "1" /* Excision of Right Epididymis, Percutaneous Approach */
"0VBJ4ZZ" = "1" /* Excision of Right Epididymis, Percutaneous Endoscopic Approach */
"0VBK0ZZ" = "1" /* Excision of Left Epididymis, Open Approach */
"0VBK3ZZ" = "1" /* Excision of Left Epididymis, Percutaneous Approach */
"0VBK4ZZ" = "1" /* Excision of Left Epididymis, Percutaneous Endoscopic Approach */
"0VBL0ZZ" = "1" /* Excision of Bilateral Epididymis, Open Approach */
"0VBL3ZZ" = "1" /* Excision of Bilateral Epididymis, Percutaneous Approach */
"0VBL4ZZ" = "1" /* Excision of Bilateral Epididymis, Percutaneous Endoscopic Approach */
"0VBS0ZX" = "1" /* Excision of Penis, Open Approach, Diagnostic */
"0VBS0ZZ" = "1" /* Excision of Penis, Open Approach */
"0VBS3ZX" = "1" /* Excision of Penis, Percutaneous Approach, Diagnostic */
"0VBS3ZZ" = "1" /* Excision of Penis, Percutaneous Approach */
"0VBS4ZX" = "1" /* Excision of Penis, Percutaneous Endoscopic Approach, Diagnostic */
"0VBS4ZZ" = "1" /* Excision of Penis, Percutaneous Endoscopic Approach */
"0VBSXZX" = "1" /* Excision of Penis, External Approach, Diagnostic */
"0VBSXZZ" = "1" /* Excision of Penis, External Approach */
"0VBT0ZX" = "1" /* Excision of Prepuce, Open Approach, Diagnostic */
"0VBT0ZZ" = "1" /* Excision of Prepuce, Open Approach */
"0VBT3ZX" = "1" /* Excision of Prepuce, Percutaneous Approach, Diagnostic */
"0VBT3ZZ" = "1" /* Excision of Prepuce, Percutaneous Approach */
"0VBT4ZX" = "1" /* Excision of Prepuce, Percutaneous Endoscopic Approach, Diagnostic */
"0VBT4ZZ" = "1" /* Excision of Prepuce, Percutaneous Endoscopic Approach */
"0VBTXZX" = "1" /* Excision of Prepuce, External Approach, Diagnostic */
"0VBTXZZ" = "1" /* Excision of Prepuce, External Approach */
"0VC00ZZ" = "1" /* Extirpation of Matter from Prostate, Open Approach */
"0VC03ZZ" = "1" /* Extirpation of Matter from Prostate, Percutaneous Approach */
"0VC04ZZ" = "1" /* Extirpation of Matter from Prostate, Percutaneous Endoscopic Approach */
"0VC07ZZ" = "1" /* Extirpation of Matter from Prostate, Via Natural or Artificial Opening */
"0VC08ZZ" = "1" /* Extirpation of Matter from Prostate, Via Natural or Artificial Opening Endoscopic */
"0VC10ZZ" = "1" /* Extirpation of Matter from Right Seminal Vesicle, Open Approach */
"0VC13ZZ" = "1" /* Extirpation of Matter from Right Seminal Vesicle, Percutaneous Approach */
"0VC14ZZ" = "1" /* Extirpation of Matter from Right Seminal Vesicle, Percutaneous Endoscopic Approach */
"0VC20ZZ" = "1" /* Extirpation of Matter from Left Seminal Vesicle, Open Approach */
"0VC23ZZ" = "1" /* Extirpation of Matter from Left Seminal Vesicle, Percutaneous Approach */
"0VC24ZZ" = "1" /* Extirpation of Matter from Left Seminal Vesicle, Percutaneous Endoscopic Approach */
"0VC30ZZ" = "1" /* Extirpation of Matter from Bilateral Seminal Vesicles, Open Approach */
"0VC33ZZ" = "1" /* Extirpation of Matter from Bilateral Seminal Vesicles, Percutaneous Approach */
"0VC34ZZ" = "1" /* Extirpation of Matter from Bilateral Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VC90ZZ" = "1" /* Extirpation of Matter from Right Testis, Open Approach */
"0VC93ZZ" = "1" /* Extirpation of Matter from Right Testis, Percutaneous Approach */
"0VC94ZZ" = "1" /* Extirpation of Matter from Right Testis, Percutaneous Endoscopic Approach */
"0VCB0ZZ" = "1" /* Extirpation of Matter from Left Testis, Open Approach */
"0VCB3ZZ" = "1" /* Extirpation of Matter from Left Testis, Percutaneous Approach */
"0VCB4ZZ" = "1" /* Extirpation of Matter from Left Testis, Percutaneous Endoscopic Approach */
"0VCC0ZZ" = "1" /* Extirpation of Matter from Bilateral Testes, Open Approach */
"0VCC3ZZ" = "1" /* Extirpation of Matter from Bilateral Testes, Percutaneous Approach */
"0VCC4ZZ" = "1" /* Extirpation of Matter from Bilateral Testes, Percutaneous Endoscopic Approach */
"0VCF0ZZ" = "1" /* Extirpation of Matter from Right Spermatic Cord, Open Approach */
"0VCF3ZZ" = "1" /* Extirpation of Matter from Right Spermatic Cord, Percutaneous Approach */
"0VCF4ZZ" = "1" /* Extirpation of Matter from Right Spermatic Cord, Percutaneous Endoscopic Approach */
"0VCG0ZZ" = "1" /* Extirpation of Matter from Left Spermatic Cord, Open Approach */
"0VCG3ZZ" = "1" /* Extirpation of Matter from Left Spermatic Cord, Percutaneous Approach */
"0VCG4ZZ" = "1" /* Extirpation of Matter from Left Spermatic Cord, Percutaneous Endoscopic Approach */
"0VCH0ZZ" = "1" /* Extirpation of Matter from Bilateral Spermatic Cords, Open Approach */
"0VCH3ZZ" = "1" /* Extirpation of Matter from Bilateral Spermatic Cords, Percutaneous Approach */
"0VCH4ZZ" = "1" /* Extirpation of Matter from Bilateral Spermatic Cords, Percutaneous Endoscopic Approach */
"0VCJ0ZZ" = "1" /* Extirpation of Matter from Right Epididymis, Open Approach */
"0VCJ3ZZ" = "1" /* Extirpation of Matter from Right Epididymis, Percutaneous Approach */
"0VCJ4ZZ" = "1" /* Extirpation of Matter from Right Epididymis, Percutaneous Endoscopic Approach */
"0VCK0ZZ" = "1" /* Extirpation of Matter from Left Epididymis, Open Approach */
"0VCK3ZZ" = "1" /* Extirpation of Matter from Left Epididymis, Percutaneous Approach */
"0VCK4ZZ" = "1" /* Extirpation of Matter from Left Epididymis, Percutaneous Endoscopic Approach */
"0VCL0ZZ" = "1" /* Extirpation of Matter from Bilateral Epididymis, Open Approach */
"0VCL3ZZ" = "1" /* Extirpation of Matter from Bilateral Epididymis, Percutaneous Approach */
"0VCL4ZZ" = "1" /* Extirpation of Matter from Bilateral Epididymis, Percutaneous Endoscopic Approach */
"0VCS0ZZ" = "1" /* Extirpation of Matter from Penis, Open Approach */
"0VCS3ZZ" = "1" /* Extirpation of Matter from Penis, Percutaneous Approach */
"0VCS4ZZ" = "1" /* Extirpation of Matter from Penis, Percutaneous Endoscopic Approach */
"0VCT0ZZ" = "1" /* Extirpation of Matter from Prepuce, Open Approach */
"0VCT3ZZ" = "1" /* Extirpation of Matter from Prepuce, Percutaneous Approach */
"0VCT4ZZ" = "1" /* Extirpation of Matter from Prepuce, Percutaneous Endoscopic Approach */
"0VCTXZZ" = "1" /* Extirpation of Matter from Prepuce, External Approach */
"0VH001Z" = "1" /* Insertion of Radioactive Element into Prostate, Open Approach */
"0VH031Z" = "1" /* Insertion of Radioactive Element into Prostate, Percutaneous Approach */
"0VH041Z" = "1" /* Insertion of Radioactive Element into Prostate, Percutaneous Endoscopic Approach */
"0VH071Z" = "1" /* Insertion of Radioactive Element into Prostate, Via Natural or Artificial Opening */
"0VH081Z" = "1" /* Insertion of Radioactive Element into Prostate, Via Natural or Artificial Opening Endoscopic */
"0VJ40ZZ" = "1" /* Inspection of Prostate and Seminal Vesicles, Open Approach */
"0VJ44ZZ" = "1" /* Inspection of Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VJD0ZZ" = "1" /* Inspection of Testis, Open Approach */
"0VJD4ZZ" = "1" /* Inspection of Testis, Percutaneous Endoscopic Approach */
"0VJM0ZZ" = "1" /* Inspection of Epididymis and Spermatic Cord, Open Approach */
"0VJM4ZZ" = "1" /* Inspection of Epididymis and Spermatic Cord, Percutaneous Endoscopic Approach */
"0VJR0ZZ" = "1" /* Inspection of Vas Deferens, Open Approach */
"0VJR4ZZ" = "1" /* Inspection of Vas Deferens, Percutaneous Endoscopic Approach */
"0VLN0DZ" = "1" /* Occlusion of Right Vas Deferens with Intraluminal Device, Open Approach */
"0VLN3DZ" = "1" /* Occlusion of Right Vas Deferens with Intraluminal Device, Percutaneous Approach */
"0VLN4DZ" = "1" /* Occlusion of Right Vas Deferens with Intraluminal Device, Percutaneous Endoscopic Approach */
"0VLP0DZ" = "1" /* Occlusion of Left Vas Deferens with Intraluminal Device, Open Approach */
"0VLP3DZ" = "1" /* Occlusion of Left Vas Deferens with Intraluminal Device, Percutaneous Approach */
"0VLP4DZ" = "1" /* Occlusion of Left Vas Deferens with Intraluminal Device, Percutaneous Endoscopic Approach */
"0VLQ0DZ" = "1" /* Occlusion of Bilateral Vas Deferens with Intraluminal Device, Open Approach */
"0VLQ3DZ" = "1" /* Occlusion of Bilateral Vas Deferens with Intraluminal Device, Percutaneous Approach */
"0VLQ4DZ" = "1" /* Occlusion of Bilateral Vas Deferens with Intraluminal Device, Percutaneous Endoscopic Approach */
"0VM5XZZ" = "1" /* Reattachment of Scrotum, External Approach */
"0VM60ZZ" = "1" /* Reattachment of Right Tunica Vaginalis, Open Approach */
"0VM64ZZ" = "1" /* Reattachment of Right Tunica Vaginalis, Percutaneous Endoscopic Approach */
"0VM70ZZ" = "1" /* Reattachment of Left Tunica Vaginalis, Open Approach */
"0VM74ZZ" = "1" /* Reattachment of Left Tunica Vaginalis, Percutaneous Endoscopic Approach */
"0VM90ZZ" = "1" /* Reattachment of Right Testis, Open Approach */
"0VM94ZZ" = "1" /* Reattachment of Right Testis, Percutaneous Endoscopic Approach */
"0VMB0ZZ" = "1" /* Reattachment of Left Testis, Open Approach */
"0VMB4ZZ" = "1" /* Reattachment of Left Testis, Percutaneous Endoscopic Approach */
"0VMC0ZZ" = "1" /* Reattachment of Bilateral Testes, Open Approach */
"0VMC4ZZ" = "1" /* Reattachment of Bilateral Testes, Percutaneous Endoscopic Approach */
"0VMF0ZZ" = "1" /* Reattachment of Right Spermatic Cord, Open Approach */
"0VMF4ZZ" = "1" /* Reattachment of Right Spermatic Cord, Percutaneous Endoscopic Approach */
"0VMG0ZZ" = "1" /* Reattachment of Left Spermatic Cord, Open Approach */
"0VMG4ZZ" = "1" /* Reattachment of Left Spermatic Cord, Percutaneous Endoscopic Approach */
"0VMH0ZZ" = "1" /* Reattachment of Bilateral Spermatic Cords, Open Approach */
"0VMH4ZZ" = "1" /* Reattachment of Bilateral Spermatic Cords, Percutaneous Endoscopic Approach */
"0VMSXZZ" = "1" /* Reattachment of Penis, External Approach */
"0VN00ZZ" = "1" /* Release Prostate, Open Approach */
"0VN03ZZ" = "1" /* Release Prostate, Percutaneous Approach */
"0VN04ZZ" = "1" /* Release Prostate, Percutaneous Endoscopic Approach */
"0VN07ZZ" = "1" /* Release Prostate, Via Natural or Artificial Opening */
"0VN08ZZ" = "1" /* Release Prostate, Via Natural or Artificial Opening Endoscopic */
"0VN10ZZ" = "1" /* Release Right Seminal Vesicle, Open Approach */
"0VN13ZZ" = "1" /* Release Right Seminal Vesicle, Percutaneous Approach */
"0VN14ZZ" = "1" /* Release Right Seminal Vesicle, Percutaneous Endoscopic Approach */
"0VN20ZZ" = "1" /* Release Left Seminal Vesicle, Open Approach */
"0VN23ZZ" = "1" /* Release Left Seminal Vesicle, Percutaneous Approach */
"0VN24ZZ" = "1" /* Release Left Seminal Vesicle, Percutaneous Endoscopic Approach */
"0VN30ZZ" = "1" /* Release Bilateral Seminal Vesicles, Open Approach */
"0VN33ZZ" = "1" /* Release Bilateral Seminal Vesicles, Percutaneous Approach */
"0VN34ZZ" = "1" /* Release Bilateral Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VN50ZZ" = "1" /* Release Scrotum, Open Approach */
"0VN53ZZ" = "1" /* Release Scrotum, Percutaneous Approach */
"0VN54ZZ" = "1" /* Release Scrotum, Percutaneous Endoscopic Approach */
"0VN5XZZ" = "1" /* Release Scrotum, External Approach */
"0VN60ZZ" = "1" /* Release Right Tunica Vaginalis, Open Approach */
"0VN63ZZ" = "1" /* Release Right Tunica Vaginalis, Percutaneous Approach */
"0VN64ZZ" = "1" /* Release Right Tunica Vaginalis, Percutaneous Endoscopic Approach */
"0VN70ZZ" = "1" /* Release Left Tunica Vaginalis, Open Approach */
"0VN73ZZ" = "1" /* Release Left Tunica Vaginalis, Percutaneous Approach */
"0VN74ZZ" = "1" /* Release Left Tunica Vaginalis, Percutaneous Endoscopic Approach */
"0VNF0ZZ" = "1" /* Release Right Spermatic Cord, Open Approach */
"0VNF3ZZ" = "1" /* Release Right Spermatic Cord, Percutaneous Approach */
"0VNF4ZZ" = "1" /* Release Right Spermatic Cord, Percutaneous Endoscopic Approach */
"0VNG0ZZ" = "1" /* Release Left Spermatic Cord, Open Approach */
"0VNG3ZZ" = "1" /* Release Left Spermatic Cord, Percutaneous Approach */
"0VNG4ZZ" = "1" /* Release Left Spermatic Cord, Percutaneous Endoscopic Approach */
"0VNH0ZZ" = "1" /* Release Bilateral Spermatic Cords, Open Approach */
"0VNH3ZZ" = "1" /* Release Bilateral Spermatic Cords, Percutaneous Approach */
"0VNH4ZZ" = "1" /* Release Bilateral Spermatic Cords, Percutaneous Endoscopic Approach */
"0VNJ0ZZ" = "1" /* Release Right Epididymis, Open Approach */
"0VNJ3ZZ" = "1" /* Release Right Epididymis, Percutaneous Approach */
"0VNJ4ZZ" = "1" /* Release Right Epididymis, Percutaneous Endoscopic Approach */
"0VNK0ZZ" = "1" /* Release Left Epididymis, Open Approach */
"0VNK3ZZ" = "1" /* Release Left Epididymis, Percutaneous Approach */
"0VNK4ZZ" = "1" /* Release Left Epididymis, Percutaneous Endoscopic Approach */
"0VNL0ZZ" = "1" /* Release Bilateral Epididymis, Open Approach */
"0VNL3ZZ" = "1" /* Release Bilateral Epididymis, Percutaneous Approach */
"0VNL4ZZ" = "1" /* Release Bilateral Epididymis, Percutaneous Endoscopic Approach */
"0VNN0ZZ" = "1" /* Release Right Vas Deferens, Open Approach */
"0VNN3ZZ" = "1" /* Release Right Vas Deferens, Percutaneous Approach */
"0VNN4ZZ" = "1" /* Release Right Vas Deferens, Percutaneous Endoscopic Approach */
"0VNP0ZZ" = "1" /* Release Left Vas Deferens, Open Approach */
"0VNP3ZZ" = "1" /* Release Left Vas Deferens, Percutaneous Approach */
"0VNP4ZZ" = "1" /* Release Left Vas Deferens, Percutaneous Endoscopic Approach */
"0VNQ0ZZ" = "1" /* Release Bilateral Vas Deferens, Open Approach */
"0VNQ3ZZ" = "1" /* Release Bilateral Vas Deferens, Percutaneous Approach */
"0VNQ4ZZ" = "1" /* Release Bilateral Vas Deferens, Percutaneous Endoscopic Approach */
"0VNS0ZZ" = "1" /* Release Penis, Open Approach */
"0VNS3ZZ" = "1" /* Release Penis, Percutaneous Approach */
"0VNS4ZZ" = "1" /* Release Penis, Percutaneous Endoscopic Approach */
"0VNSXZZ" = "1" /* Release Penis, External Approach */
"0VP400Z" = "1" /* Removal of Drainage Device from Prostate and Seminal Vesicles, Open Approach */
"0VP401Z" = "1" /* Removal of Radioactive Element from Prostate and Seminal Vesicles, Open Approach */
"0VP403Z" = "1" /* Removal of Infusion Device from Prostate and Seminal Vesicles, Open Approach */
"0VP407Z" = "1" /* Removal of Autologous Tissue Substitute from Prostate and Seminal Vesicles, Open Approach */
"0VP40JZ" = "1" /* Removal of Synthetic Substitute from Prostate and Seminal Vesicles, Open Approach */
"0VP40KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Prostate and Seminal Vesicles, Open Approach */
"0VP430Z" = "1" /* Removal of Drainage Device from Prostate and Seminal Vesicles, Percutaneous Approach */
"0VP431Z" = "1" /* Removal of Radioactive Element from Prostate and Seminal Vesicles, Percutaneous Approach */
"0VP433Z" = "1" /* Removal of Infusion Device from Prostate and Seminal Vesicles, Percutaneous Approach */
"0VP437Z" = "1" /* Removal of Autologous Tissue Substitute from Prostate and Seminal Vesicles, Percutaneous Approach */
"0VP43JZ" = "1" /* Removal of Synthetic Substitute from Prostate and Seminal Vesicles, Percutaneous Approach */
"0VP43KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Prostate and Seminal Vesicles, Percutaneous Approach */
"0VP440Z" = "1" /* Removal of Drainage Device from Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VP441Z" = "1" /* Removal of Radioactive Element from Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VP443Z" = "1" /* Removal of Infusion Device from Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VP447Z" = "1" /* Removal of Autologous Tissue Substitute from Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VP44JZ" = "1" /* Removal of Synthetic Substitute from Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VP44KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VP471Z" = "1" /* Removal of Radioactive Element from Prostate and Seminal Vesicles, Via Natural or Artificial Opening */
"0VP477Z" = "1" /* Removal of Autologous Tissue Substitute from Prostate and Seminal Vesicles, Via Natural or Artificial Opening */
"0VP47JZ" = "1" /* Removal of Synthetic Substitute from Prostate and Seminal Vesicles, Via Natural or Artificial Opening */
"0VP47KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Prostate and Seminal Vesicles, Via Natural or Artificial Opening */
"0VP481Z" = "1" /* Removal of Radioactive Element from Prostate and Seminal Vesicles, Via Natural or Artificial Opening Endoscopic */
"0VP487Z" = "1" /* Removal of Autologous Tissue Substitute from Prostate and Seminal Vesicles, Via Natural or Artificial Opening Endoscopic */
"0VP48JZ" = "1" /* Removal of Synthetic Substitute from Prostate and Seminal Vesicles, Via Natural or Artificial Opening Endoscopic */
"0VP48KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Prostate and Seminal Vesicles, Via Natural or Artificial Opening Endoscopic */
"0VPD00Z" = "1" /* Removal of Drainage Device from Testis, Open Approach */
"0VPD03Z" = "1" /* Removal of Infusion Device from Testis, Open Approach */
"0VPD07Z" = "1" /* Removal of Autologous Tissue Substitute from Testis, Open Approach */
"0VPD0JZ" = "1" /* Removal of Synthetic Substitute from Testis, Open Approach */
"0VPD0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Testis, Open Approach */
"0VPD30Z" = "1" /* Removal of Drainage Device from Testis, Percutaneous Approach */
"0VPD33Z" = "1" /* Removal of Infusion Device from Testis, Percutaneous Approach */
"0VPD37Z" = "1" /* Removal of Autologous Tissue Substitute from Testis, Percutaneous Approach */
"0VPD3JZ" = "1" /* Removal of Synthetic Substitute from Testis, Percutaneous Approach */
"0VPD3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Testis, Percutaneous Approach */
"0VPD40Z" = "1" /* Removal of Drainage Device from Testis, Percutaneous Endoscopic Approach */
"0VPD43Z" = "1" /* Removal of Infusion Device from Testis, Percutaneous Endoscopic Approach */
"0VPD47Z" = "1" /* Removal of Autologous Tissue Substitute from Testis, Percutaneous Endoscopic Approach */
"0VPD4JZ" = "1" /* Removal of Synthetic Substitute from Testis, Percutaneous Endoscopic Approach */
"0VPD4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Testis, Percutaneous Endoscopic Approach */
"0VPD77Z" = "1" /* Removal of Autologous Tissue Substitute from Testis, Via Natural or Artificial Opening */
"0VPD7JZ" = "1" /* Removal of Synthetic Substitute from Testis, Via Natural or Artificial Opening */
"0VPD7KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Testis, Via Natural or Artificial Opening */
"0VPD87Z" = "1" /* Removal of Autologous Tissue Substitute from Testis, Via Natural or Artificial Opening Endoscopic */
"0VPD8JZ" = "1" /* Removal of Synthetic Substitute from Testis, Via Natural or Artificial Opening Endoscopic */
"0VPD8KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Testis, Via Natural or Artificial Opening Endoscopic */
"0VPM00Z" = "1" /* Removal of Drainage Device from Epididymis and Spermatic Cord, Open Approach */
"0VPM03Z" = "1" /* Removal of Infusion Device from Epididymis and Spermatic Cord, Open Approach */
"0VPM07Z" = "1" /* Removal of Autologous Tissue Substitute from Epididymis and Spermatic Cord, Open Approach */
"0VPM0CZ" = "1" /* Removal of Extraluminal Device from Epididymis and Spermatic Cord, Open Approach */
"0VPM0JZ" = "1" /* Removal of Synthetic Substitute from Epididymis and Spermatic Cord, Open Approach */
"0VPM0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Epididymis and Spermatic Cord, Open Approach */
"0VPM30Z" = "1" /* Removal of Drainage Device from Epididymis and Spermatic Cord, Percutaneous Approach */
"0VPM33Z" = "1" /* Removal of Infusion Device from Epididymis and Spermatic Cord, Percutaneous Approach */
"0VPM37Z" = "1" /* Removal of Autologous Tissue Substitute from Epididymis and Spermatic Cord, Percutaneous Approach */
"0VPM3CZ" = "1" /* Removal of Extraluminal Device from Epididymis and Spermatic Cord, Percutaneous Approach */
"0VPM3JZ" = "1" /* Removal of Synthetic Substitute from Epididymis and Spermatic Cord, Percutaneous Approach */
"0VPM3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Epididymis and Spermatic Cord, Percutaneous Approach */
"0VPM40Z" = "1" /* Removal of Drainage Device from Epididymis and Spermatic Cord, Percutaneous Endoscopic Approach */
"0VPM43Z" = "1" /* Removal of Infusion Device from Epididymis and Spermatic Cord, Percutaneous Endoscopic Approach */
"0VPM47Z" = "1" /* Removal of Autologous Tissue Substitute from Epididymis and Spermatic Cord, Percutaneous Endoscopic Approach */
"0VPM4CZ" = "1" /* Removal of Extraluminal Device from Epididymis and Spermatic Cord, Percutaneous Endoscopic Approach */
"0VPM4JZ" = "1" /* Removal of Synthetic Substitute from Epididymis and Spermatic Cord, Percutaneous Endoscopic Approach */
"0VPM4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Epididymis and Spermatic Cord, Percutaneous Endoscopic Approach */
"0VPM77Z" = "1" /* Removal of Autologous Tissue Substitute from Epididymis and Spermatic Cord, Via Natural or Artificial Opening */
"0VPM7CZ" = "1" /* Removal of Extraluminal Device from Epididymis and Spermatic Cord, Via Natural or Artificial Opening */
"0VPM7JZ" = "1" /* Removal of Synthetic Substitute from Epididymis and Spermatic Cord, Via Natural or Artificial Opening */
"0VPM7KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Epididymis and Spermatic Cord, Via Natural or Artificial Opening */
"0VPM87Z" = "1" /* Removal of Autologous Tissue Substitute from Epididymis and Spermatic Cord, Via Natural or Artificial Opening Endoscopic */
"0VPM8CZ" = "1" /* Removal of Extraluminal Device from Epididymis and Spermatic Cord, Via Natural or Artificial Opening Endoscopic */
"0VPM8JZ" = "1" /* Removal of Synthetic Substitute from Epididymis and Spermatic Cord, Via Natural or Artificial Opening Endoscopic */
"0VPM8KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Epididymis and Spermatic Cord, Via Natural or Artificial Opening Endoscopic */
"0VPR0DZ" = "1" /* Removal of Intraluminal Device from Vas Deferens, Open Approach */
"0VPR3DZ" = "1" /* Removal of Intraluminal Device from Vas Deferens, Percutaneous Approach */
"0VPR4DZ" = "1" /* Removal of Intraluminal Device from Vas Deferens, Percutaneous Endoscopic Approach */
"0VPS00Z" = "1" /* Removal of Drainage Device from Penis, Open Approach */
"0VPS03Z" = "1" /* Removal of Infusion Device from Penis, Open Approach */
"0VPS07Z" = "1" /* Removal of Autologous Tissue Substitute from Penis, Open Approach */
"0VPS0JZ" = "1" /* Removal of Synthetic Substitute from Penis, Open Approach */
"0VPS0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Penis, Open Approach */
"0VPS30Z" = "1" /* Removal of Drainage Device from Penis, Percutaneous Approach */
"0VPS33Z" = "1" /* Removal of Infusion Device from Penis, Percutaneous Approach */
"0VPS37Z" = "1" /* Removal of Autologous Tissue Substitute from Penis, Percutaneous Approach */
"0VPS3JZ" = "1" /* Removal of Synthetic Substitute from Penis, Percutaneous Approach */
"0VPS3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Penis, Percutaneous Approach */
"0VPS40Z" = "1" /* Removal of Drainage Device from Penis, Percutaneous Endoscopic Approach */
"0VPS43Z" = "1" /* Removal of Infusion Device from Penis, Percutaneous Endoscopic Approach */
"0VPS47Z" = "1" /* Removal of Autologous Tissue Substitute from Penis, Percutaneous Endoscopic Approach */
"0VPS4JZ" = "1" /* Removal of Synthetic Substitute from Penis, Percutaneous Endoscopic Approach */
"0VPS4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Penis, Percutaneous Endoscopic Approach */
"0VPS77Z" = "1" /* Removal of Autologous Tissue Substitute from Penis, Via Natural or Artificial Opening */
"0VPS7JZ" = "1" /* Removal of Synthetic Substitute from Penis, Via Natural or Artificial Opening */
"0VPS7KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Penis, Via Natural or Artificial Opening */
"0VPS87Z" = "1" /* Removal of Autologous Tissue Substitute from Penis, Via Natural or Artificial Opening Endoscopic */
"0VPS8JZ" = "1" /* Removal of Synthetic Substitute from Penis, Via Natural or Artificial Opening Endoscopic */
"0VPS8KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Penis, Via Natural or Artificial Opening Endoscopic */
"0VQ00ZZ" = "1" /* Repair Prostate, Open Approach */
"0VQ03ZZ" = "1" /* Repair Prostate, Percutaneous Approach */
"0VQ04ZZ" = "1" /* Repair Prostate, Percutaneous Endoscopic Approach */
"0VQ07ZZ" = "1" /* Repair Prostate, Via Natural or Artificial Opening */
"0VQ08ZZ" = "1" /* Repair Prostate, Via Natural or Artificial Opening Endoscopic */
"0VQ10ZZ" = "1" /* Repair Right Seminal Vesicle, Open Approach */
"0VQ13ZZ" = "1" /* Repair Right Seminal Vesicle, Percutaneous Approach */
"0VQ14ZZ" = "1" /* Repair Right Seminal Vesicle, Percutaneous Endoscopic Approach */
"0VQ20ZZ" = "1" /* Repair Left Seminal Vesicle, Open Approach */
"0VQ23ZZ" = "1" /* Repair Left Seminal Vesicle, Percutaneous Approach */
"0VQ24ZZ" = "1" /* Repair Left Seminal Vesicle, Percutaneous Endoscopic Approach */
"0VQ30ZZ" = "1" /* Repair Bilateral Seminal Vesicles, Open Approach */
"0VQ33ZZ" = "1" /* Repair Bilateral Seminal Vesicles, Percutaneous Approach */
"0VQ34ZZ" = "1" /* Repair Bilateral Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VQ90ZZ" = "1" /* Repair Right Testis, Open Approach */
"0VQ93ZZ" = "1" /* Repair Right Testis, Percutaneous Approach */
"0VQ94ZZ" = "1" /* Repair Right Testis, Percutaneous Endoscopic Approach */
"0VQB0ZZ" = "1" /* Repair Left Testis, Open Approach */
"0VQB3ZZ" = "1" /* Repair Left Testis, Percutaneous Approach */
"0VQB4ZZ" = "1" /* Repair Left Testis, Percutaneous Endoscopic Approach */
"0VQC0ZZ" = "1" /* Repair Bilateral Testes, Open Approach */
"0VQC3ZZ" = "1" /* Repair Bilateral Testes, Percutaneous Approach */
"0VQC4ZZ" = "1" /* Repair Bilateral Testes, Percutaneous Endoscopic Approach */
"0VQF0ZZ" = "1" /* Repair Right Spermatic Cord, Open Approach */
"0VQF3ZZ" = "1" /* Repair Right Spermatic Cord, Percutaneous Approach */
"0VQF4ZZ" = "1" /* Repair Right Spermatic Cord, Percutaneous Endoscopic Approach */
"0VQG0ZZ" = "1" /* Repair Left Spermatic Cord, Open Approach */
"0VQG3ZZ" = "1" /* Repair Left Spermatic Cord, Percutaneous Approach */
"0VQG4ZZ" = "1" /* Repair Left Spermatic Cord, Percutaneous Endoscopic Approach */
"0VQH0ZZ" = "1" /* Repair Bilateral Spermatic Cords, Open Approach */
"0VQH3ZZ" = "1" /* Repair Bilateral Spermatic Cords, Percutaneous Approach */
"0VQH4ZZ" = "1" /* Repair Bilateral Spermatic Cords, Percutaneous Endoscopic Approach */
"0VQJ0ZZ" = "1" /* Repair Right Epididymis, Open Approach */
"0VQJ3ZZ" = "1" /* Repair Right Epididymis, Percutaneous Approach */
"0VQJ4ZZ" = "1" /* Repair Right Epididymis, Percutaneous Endoscopic Approach */
"0VQK0ZZ" = "1" /* Repair Left Epididymis, Open Approach */
"0VQK3ZZ" = "1" /* Repair Left Epididymis, Percutaneous Approach */
"0VQK4ZZ" = "1" /* Repair Left Epididymis, Percutaneous Endoscopic Approach */
"0VQL0ZZ" = "1" /* Repair Bilateral Epididymis, Open Approach */
"0VQL3ZZ" = "1" /* Repair Bilateral Epididymis, Percutaneous Approach */
"0VQL4ZZ" = "1" /* Repair Bilateral Epididymis, Percutaneous Endoscopic Approach */
"0VQN0ZZ" = "1" /* Repair Right Vas Deferens, Open Approach */
"0VQN3ZZ" = "1" /* Repair Right Vas Deferens, Percutaneous Approach */
"0VQN4ZZ" = "1" /* Repair Right Vas Deferens, Percutaneous Endoscopic Approach */
"0VQP0ZZ" = "1" /* Repair Left Vas Deferens, Open Approach */
"0VQP3ZZ" = "1" /* Repair Left Vas Deferens, Percutaneous Approach */
"0VQP4ZZ" = "1" /* Repair Left Vas Deferens, Percutaneous Endoscopic Approach */
"0VQQ0ZZ" = "1" /* Repair Bilateral Vas Deferens, Open Approach */
"0VQQ3ZZ" = "1" /* Repair Bilateral Vas Deferens, Percutaneous Approach */
"0VQQ4ZZ" = "1" /* Repair Bilateral Vas Deferens, Percutaneous Endoscopic Approach */
"0VQS0ZZ" = "1" /* Repair Penis, Open Approach */
"0VQS3ZZ" = "1" /* Repair Penis, Percutaneous Approach */
"0VQS4ZZ" = "1" /* Repair Penis, Percutaneous Endoscopic Approach */
"0VQSXZZ" = "1" /* Repair Penis, External Approach */
"0VQT0ZZ" = "1" /* Repair Prepuce, Open Approach */
"0VQT3ZZ" = "1" /* Repair Prepuce, Percutaneous Approach */
"0VQT4ZZ" = "1" /* Repair Prepuce, Percutaneous Endoscopic Approach */
"0VQTXZZ" = "1" /* Repair Prepuce, External Approach */
"0VR90JZ" = "1" /* Replacement of Right Testis with Synthetic Substitute, Open Approach */
"0VRB0JZ" = "1" /* Replacement of Left Testis with Synthetic Substitute, Open Approach */
"0VRC0JZ" = "1" /* Replacement of Bilateral Testes with Synthetic Substitute, Open Approach */
"0VS90ZZ" = "1" /* Reposition Right Testis, Open Approach */
"0VS93ZZ" = "1" /* Reposition Right Testis, Percutaneous Approach */
"0VS94ZZ" = "1" /* Reposition Right Testis, Percutaneous Endoscopic Approach */
"0VSB0ZZ" = "1" /* Reposition Left Testis, Open Approach */
"0VSB3ZZ" = "1" /* Reposition Left Testis, Percutaneous Approach */
"0VSB4ZZ" = "1" /* Reposition Left Testis, Percutaneous Endoscopic Approach */
"0VSC0ZZ" = "1" /* Reposition Bilateral Testes, Open Approach */
"0VSC3ZZ" = "1" /* Reposition Bilateral Testes, Percutaneous Approach */
"0VSC4ZZ" = "1" /* Reposition Bilateral Testes, Percutaneous Endoscopic Approach */
"0VSF0ZZ" = "1" /* Reposition Right Spermatic Cord, Open Approach */
"0VSF3ZZ" = "1" /* Reposition Right Spermatic Cord, Percutaneous Approach */
"0VSF4ZZ" = "1" /* Reposition Right Spermatic Cord, Percutaneous Endoscopic Approach */
"0VSG0ZZ" = "1" /* Reposition Left Spermatic Cord, Open Approach */
"0VSG3ZZ" = "1" /* Reposition Left Spermatic Cord, Percutaneous Approach */
"0VSG4ZZ" = "1" /* Reposition Left Spermatic Cord, Percutaneous Endoscopic Approach */
"0VSH0ZZ" = "1" /* Reposition Bilateral Spermatic Cords, Open Approach */
"0VSH3ZZ" = "1" /* Reposition Bilateral Spermatic Cords, Percutaneous Approach */
"0VSH4ZZ" = "1" /* Reposition Bilateral Spermatic Cords, Percutaneous Endoscopic Approach */
"0VT00ZZ" = "1" /* Resection of Prostate, Open Approach */
"0VT04ZZ" = "1" /* Resection of Prostate, Percutaneous Endoscopic Approach */
"0VT07ZZ" = "1" /* Resection of Prostate, Via Natural or Artificial Opening */
"0VT08ZZ" = "1" /* Resection of Prostate, Via Natural or Artificial Opening Endoscopic */
"0VT10ZZ" = "1" /* Resection of Right Seminal Vesicle, Open Approach */
"0VT14ZZ" = "1" /* Resection of Right Seminal Vesicle, Percutaneous Endoscopic Approach */
"0VT20ZZ" = "1" /* Resection of Left Seminal Vesicle, Open Approach */
"0VT24ZZ" = "1" /* Resection of Left Seminal Vesicle, Percutaneous Endoscopic Approach */
"0VT30ZZ" = "1" /* Resection of Bilateral Seminal Vesicles, Open Approach */
"0VT34ZZ" = "1" /* Resection of Bilateral Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VT60ZZ" = "1" /* Resection of Right Tunica Vaginalis, Open Approach */
"0VT64ZZ" = "1" /* Resection of Right Tunica Vaginalis, Percutaneous Endoscopic Approach */
"0VT70ZZ" = "1" /* Resection of Left Tunica Vaginalis, Open Approach */
"0VT74ZZ" = "1" /* Resection of Left Tunica Vaginalis, Percutaneous Endoscopic Approach */
"0VT90ZZ" = "1" /* Resection of Right Testis, Open Approach */
"0VT94ZZ" = "1" /* Resection of Right Testis, Percutaneous Endoscopic Approach */
"0VTB0ZZ" = "1" /* Resection of Left Testis, Open Approach */
"0VTB4ZZ" = "1" /* Resection of Left Testis, Percutaneous Endoscopic Approach */
"0VTC0ZZ" = "1" /* Resection of Bilateral Testes, Open Approach */
"0VTC4ZZ" = "1" /* Resection of Bilateral Testes, Percutaneous Endoscopic Approach */
"0VTF0ZZ" = "1" /* Resection of Right Spermatic Cord, Open Approach */
"0VTF4ZZ" = "1" /* Resection of Right Spermatic Cord, Percutaneous Endoscopic Approach */
"0VTG0ZZ" = "1" /* Resection of Left Spermatic Cord, Open Approach */
"0VTG4ZZ" = "1" /* Resection of Left Spermatic Cord, Percutaneous Endoscopic Approach */
"0VTH0ZZ" = "1" /* Resection of Bilateral Spermatic Cords, Open Approach */
"0VTH4ZZ" = "1" /* Resection of Bilateral Spermatic Cords, Percutaneous Endoscopic Approach */
"0VTJ0ZZ" = "1" /* Resection of Right Epididymis, Open Approach */
"0VTJ4ZZ" = "1" /* Resection of Right Epididymis, Percutaneous Endoscopic Approach */
"0VTK0ZZ" = "1" /* Resection of Left Epididymis, Open Approach */
"0VTK4ZZ" = "1" /* Resection of Left Epididymis, Percutaneous Endoscopic Approach */
"0VTL0ZZ" = "1" /* Resection of Bilateral Epididymis, Open Approach */
"0VTL4ZZ" = "1" /* Resection of Bilateral Epididymis, Percutaneous Endoscopic Approach */
"0VTS0ZZ" = "1" /* Resection of Penis, Open Approach */
"0VTS4ZZ" = "1" /* Resection of Penis, Percutaneous Endoscopic Approach */
"0VTSXZZ" = "1" /* Resection of Penis, External Approach */
"0VU107Z" = "1" /* Supplement Right Seminal Vesicle with Autologous Tissue Substitute, Open Approach */
"0VU10JZ" = "1" /* Supplement Right Seminal Vesicle with Synthetic Substitute, Open Approach */
"0VU10KZ" = "1" /* Supplement Right Seminal Vesicle with Nonautologous Tissue Substitute, Open Approach */
"0VU147Z" = "1" /* Supplement Right Seminal Vesicle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VU14JZ" = "1" /* Supplement Right Seminal Vesicle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0VU14KZ" = "1" /* Supplement Right Seminal Vesicle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VU207Z" = "1" /* Supplement Left Seminal Vesicle with Autologous Tissue Substitute, Open Approach */
"0VU20JZ" = "1" /* Supplement Left Seminal Vesicle with Synthetic Substitute, Open Approach */
"0VU20KZ" = "1" /* Supplement Left Seminal Vesicle with Nonautologous Tissue Substitute, Open Approach */
"0VU247Z" = "1" /* Supplement Left Seminal Vesicle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VU24JZ" = "1" /* Supplement Left Seminal Vesicle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0VU24KZ" = "1" /* Supplement Left Seminal Vesicle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VU307Z" = "1" /* Supplement Bilateral Seminal Vesicles with Autologous Tissue Substitute, Open Approach */
"0VU30JZ" = "1" /* Supplement Bilateral Seminal Vesicles with Synthetic Substitute, Open Approach */
"0VU30KZ" = "1" /* Supplement Bilateral Seminal Vesicles with Nonautologous Tissue Substitute, Open Approach */
"0VU347Z" = "1" /* Supplement Bilateral Seminal Vesicles with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VU34JZ" = "1" /* Supplement Bilateral Seminal Vesicles with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0VU34KZ" = "1" /* Supplement Bilateral Seminal Vesicles with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VU507Z" = "1" /* Supplement Scrotum with Autologous Tissue Substitute, Open Approach */
"0VU50JZ" = "1" /* Supplement Scrotum with Synthetic Substitute, Open Approach */
"0VU50KZ" = "1" /* Supplement Scrotum with Nonautologous Tissue Substitute, Open Approach */
"0VU547Z" = "1" /* Supplement Scrotum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VU54JZ" = "1" /* Supplement Scrotum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0VU54KZ" = "1" /* Supplement Scrotum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VU5X7Z" = "1" /* Supplement Scrotum with Autologous Tissue Substitute, External Approach */
"0VU5XJZ" = "1" /* Supplement Scrotum with Synthetic Substitute, External Approach */
"0VU5XKZ" = "1" /* Supplement Scrotum with Nonautologous Tissue Substitute, External Approach */
"0VU607Z" = "1" /* Supplement Right Tunica Vaginalis with Autologous Tissue Substitute, Open Approach */
"0VU60JZ" = "1" /* Supplement Right Tunica Vaginalis with Synthetic Substitute, Open Approach */
"0VU60KZ" = "1" /* Supplement Right Tunica Vaginalis with Nonautologous Tissue Substitute, Open Approach */
"0VU647Z" = "1" /* Supplement Right Tunica Vaginalis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VU64JZ" = "1" /* Supplement Right Tunica Vaginalis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0VU64KZ" = "1" /* Supplement Right Tunica Vaginalis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VU707Z" = "1" /* Supplement Left Tunica Vaginalis with Autologous Tissue Substitute, Open Approach */
"0VU70JZ" = "1" /* Supplement Left Tunica Vaginalis with Synthetic Substitute, Open Approach */
"0VU70KZ" = "1" /* Supplement Left Tunica Vaginalis with Nonautologous Tissue Substitute, Open Approach */
"0VU747Z" = "1" /* Supplement Left Tunica Vaginalis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VU74JZ" = "1" /* Supplement Left Tunica Vaginalis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0VU74KZ" = "1" /* Supplement Left Tunica Vaginalis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VU907Z" = "1" /* Supplement Right Testis with Autologous Tissue Substitute, Open Approach */
"0VU90JZ" = "1" /* Supplement Right Testis with Synthetic Substitute, Open Approach */
"0VU90KZ" = "1" /* Supplement Right Testis with Nonautologous Tissue Substitute, Open Approach */
"0VUB07Z" = "1" /* Supplement Left Testis with Autologous Tissue Substitute, Open Approach */
"0VUB0JZ" = "1" /* Supplement Left Testis with Synthetic Substitute, Open Approach */
"0VUB0KZ" = "1" /* Supplement Left Testis with Nonautologous Tissue Substitute, Open Approach */
"0VUC07Z" = "1" /* Supplement Bilateral Testes with Autologous Tissue Substitute, Open Approach */
"0VUC0JZ" = "1" /* Supplement Bilateral Testes with Synthetic Substitute, Open Approach */
"0VUC0KZ" = "1" /* Supplement Bilateral Testes with Nonautologous Tissue Substitute, Open Approach */
"0VUF07Z" = "1" /* Supplement Right Spermatic Cord with Autologous Tissue Substitute, Open Approach */
"0VUF0JZ" = "1" /* Supplement Right Spermatic Cord with Synthetic Substitute, Open Approach */
"0VUF0KZ" = "1" /* Supplement Right Spermatic Cord with Nonautologous Tissue Substitute, Open Approach */
"0VUF47Z" = "1" /* Supplement Right Spermatic Cord with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VUF4JZ" = "1" /* Supplement Right Spermatic Cord with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0VUF4KZ" = "1" /* Supplement Right Spermatic Cord with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VUG07Z" = "1" /* Supplement Left Spermatic Cord with Autologous Tissue Substitute, Open Approach */
"0VUG0JZ" = "1" /* Supplement Left Spermatic Cord with Synthetic Substitute, Open Approach */
"0VUG0KZ" = "1" /* Supplement Left Spermatic Cord with Nonautologous Tissue Substitute, Open Approach */
"0VUG47Z" = "1" /* Supplement Left Spermatic Cord with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VUG4JZ" = "1" /* Supplement Left Spermatic Cord with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0VUG4KZ" = "1" /* Supplement Left Spermatic Cord with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VUH07Z" = "1" /* Supplement Bilateral Spermatic Cords with Autologous Tissue Substitute, Open Approach */
"0VUH0JZ" = "1" /* Supplement Bilateral Spermatic Cords with Synthetic Substitute, Open Approach */
"0VUH0KZ" = "1" /* Supplement Bilateral Spermatic Cords with Nonautologous Tissue Substitute, Open Approach */
"0VUH47Z" = "1" /* Supplement Bilateral Spermatic Cords with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VUH4JZ" = "1" /* Supplement Bilateral Spermatic Cords with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0VUH4KZ" = "1" /* Supplement Bilateral Spermatic Cords with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VUJ07Z" = "1" /* Supplement Right Epididymis with Autologous Tissue Substitute, Open Approach */
"0VUJ0JZ" = "1" /* Supplement Right Epididymis with Synthetic Substitute, Open Approach */
"0VUJ0KZ" = "1" /* Supplement Right Epididymis with Nonautologous Tissue Substitute, Open Approach */
"0VUJ47Z" = "1" /* Supplement Right Epididymis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VUJ4JZ" = "1" /* Supplement Right Epididymis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0VUJ4KZ" = "1" /* Supplement Right Epididymis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VUK07Z" = "1" /* Supplement Left Epididymis with Autologous Tissue Substitute, Open Approach */
"0VUK0JZ" = "1" /* Supplement Left Epididymis with Synthetic Substitute, Open Approach */
"0VUK0KZ" = "1" /* Supplement Left Epididymis with Nonautologous Tissue Substitute, Open Approach */
"0VUK47Z" = "1" /* Supplement Left Epididymis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VUK4JZ" = "1" /* Supplement Left Epididymis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0VUK4KZ" = "1" /* Supplement Left Epididymis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VUL07Z" = "1" /* Supplement Bilateral Epididymis with Autologous Tissue Substitute, Open Approach */
"0VUL0JZ" = "1" /* Supplement Bilateral Epididymis with Synthetic Substitute, Open Approach */
"0VUL0KZ" = "1" /* Supplement Bilateral Epididymis with Nonautologous Tissue Substitute, Open Approach */
"0VUL47Z" = "1" /* Supplement Bilateral Epididymis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VUL4JZ" = "1" /* Supplement Bilateral Epididymis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0VUL4KZ" = "1" /* Supplement Bilateral Epididymis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VUN07Z" = "1" /* Supplement Right Vas Deferens with Autologous Tissue Substitute, Open Approach */
"0VUN0JZ" = "1" /* Supplement Right Vas Deferens with Synthetic Substitute, Open Approach */
"0VUN0KZ" = "1" /* Supplement Right Vas Deferens with Nonautologous Tissue Substitute, Open Approach */
"0VUN47Z" = "1" /* Supplement Right Vas Deferens with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VUN4JZ" = "1" /* Supplement Right Vas Deferens with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0VUN4KZ" = "1" /* Supplement Right Vas Deferens with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VUP07Z" = "1" /* Supplement Left Vas Deferens with Autologous Tissue Substitute, Open Approach */
"0VUP0JZ" = "1" /* Supplement Left Vas Deferens with Synthetic Substitute, Open Approach */
"0VUP0KZ" = "1" /* Supplement Left Vas Deferens with Nonautologous Tissue Substitute, Open Approach */
"0VUP47Z" = "1" /* Supplement Left Vas Deferens with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VUP4JZ" = "1" /* Supplement Left Vas Deferens with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0VUP4KZ" = "1" /* Supplement Left Vas Deferens with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VUQ07Z" = "1" /* Supplement Bilateral Vas Deferens with Autologous Tissue Substitute, Open Approach */
"0VUQ0JZ" = "1" /* Supplement Bilateral Vas Deferens with Synthetic Substitute, Open Approach */
"0VUQ0KZ" = "1" /* Supplement Bilateral Vas Deferens with Nonautologous Tissue Substitute, Open Approach */
"0VUQ47Z" = "1" /* Supplement Bilateral Vas Deferens with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VUQ4JZ" = "1" /* Supplement Bilateral Vas Deferens with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0VUQ4KZ" = "1" /* Supplement Bilateral Vas Deferens with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VUS07Z" = "1" /* Supplement Penis with Autologous Tissue Substitute, Open Approach */
"0VUS0JZ" = "1" /* Supplement Penis with Synthetic Substitute, Open Approach */
"0VUS0KZ" = "1" /* Supplement Penis with Nonautologous Tissue Substitute, Open Approach */
"0VUS47Z" = "1" /* Supplement Penis with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VUS4JZ" = "1" /* Supplement Penis with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0VUS4KZ" = "1" /* Supplement Penis with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VUT07Z" = "1" /* Supplement Prepuce with Autologous Tissue Substitute, Open Approach */
"0VUT0JZ" = "1" /* Supplement Prepuce with Synthetic Substitute, Open Approach */
"0VUT0KZ" = "1" /* Supplement Prepuce with Nonautologous Tissue Substitute, Open Approach */
"0VUT47Z" = "1" /* Supplement Prepuce with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VUT4JZ" = "1" /* Supplement Prepuce with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0VUT4KZ" = "1" /* Supplement Prepuce with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0VUTX7Z" = "1" /* Supplement Prepuce with Autologous Tissue Substitute, External Approach */
"0VUTXJZ" = "1" /* Supplement Prepuce with Synthetic Substitute, External Approach */
"0VUTXKZ" = "1" /* Supplement Prepuce with Nonautologous Tissue Substitute, External Approach */
"0VW400Z" = "1" /* Revision of Drainage Device in Prostate and Seminal Vesicles, Open Approach */
"0VW403Z" = "1" /* Revision of Infusion Device in Prostate and Seminal Vesicles, Open Approach */
"0VW407Z" = "1" /* Revision of Autologous Tissue Substitute in Prostate and Seminal Vesicles, Open Approach */
"0VW40JZ" = "1" /* Revision of Synthetic Substitute in Prostate and Seminal Vesicles, Open Approach */
"0VW40KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Prostate and Seminal Vesicles, Open Approach */
"0VW430Z" = "1" /* Revision of Drainage Device in Prostate and Seminal Vesicles, Percutaneous Approach */
"0VW433Z" = "1" /* Revision of Infusion Device in Prostate and Seminal Vesicles, Percutaneous Approach */
"0VW437Z" = "1" /* Revision of Autologous Tissue Substitute in Prostate and Seminal Vesicles, Percutaneous Approach */
"0VW43JZ" = "1" /* Revision of Synthetic Substitute in Prostate and Seminal Vesicles, Percutaneous Approach */
"0VW43KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Prostate and Seminal Vesicles, Percutaneous Approach */
"0VW440Z" = "1" /* Revision of Drainage Device in Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VW443Z" = "1" /* Revision of Infusion Device in Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VW447Z" = "1" /* Revision of Autologous Tissue Substitute in Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VW44JZ" = "1" /* Revision of Synthetic Substitute in Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VW44KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Prostate and Seminal Vesicles, Percutaneous Endoscopic Approach */
"0VW470Z" = "1" /* Revision of Drainage Device in Prostate and Seminal Vesicles, Via Natural or Artificial Opening */
"0VW473Z" = "1" /* Revision of Infusion Device in Prostate and Seminal Vesicles, Via Natural or Artificial Opening */
"0VW477Z" = "1" /* Revision of Autologous Tissue Substitute in Prostate and Seminal Vesicles, Via Natural or Artificial Opening */
"0VW47JZ" = "1" /* Revision of Synthetic Substitute in Prostate and Seminal Vesicles, Via Natural or Artificial Opening */
"0VW47KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Prostate and Seminal Vesicles, Via Natural or Artificial Opening */
"0VW480Z" = "1" /* Revision of Drainage Device in Prostate and Seminal Vesicles, Via Natural or Artificial Opening Endoscopic */
"0VW483Z" = "1" /* Revision of Infusion Device in Prostate and Seminal Vesicles, Via Natural or Artificial Opening Endoscopic */
"0VW487Z" = "1" /* Revision of Autologous Tissue Substitute in Prostate and Seminal Vesicles, Via Natural or Artificial Opening Endoscopic */
"0VW48JZ" = "1" /* Revision of Synthetic Substitute in Prostate and Seminal Vesicles, Via Natural or Artificial Opening Endoscopic */
"0VW48KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Prostate and Seminal Vesicles, Via Natural or Artificial Opening Endoscopic */
"0VWD00Z" = "1" /* Revision of Drainage Device in Testis, Open Approach */
"0VWD03Z" = "1" /* Revision of Infusion Device in Testis, Open Approach */
"0VWD07Z" = "1" /* Revision of Autologous Tissue Substitute in Testis, Open Approach */
"0VWD0JZ" = "1" /* Revision of Synthetic Substitute in Testis, Open Approach */
"0VWD0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Testis, Open Approach */
"0VWD30Z" = "1" /* Revision of Drainage Device in Testis, Percutaneous Approach */
"0VWD33Z" = "1" /* Revision of Infusion Device in Testis, Percutaneous Approach */
"0VWD37Z" = "1" /* Revision of Autologous Tissue Substitute in Testis, Percutaneous Approach */
"0VWD3JZ" = "1" /* Revision of Synthetic Substitute in Testis, Percutaneous Approach */
"0VWD3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Testis, Percutaneous Approach */
"0VWD40Z" = "1" /* Revision of Drainage Device in Testis, Percutaneous Endoscopic Approach */
"0VWD43Z" = "1" /* Revision of Infusion Device in Testis, Percutaneous Endoscopic Approach */
"0VWD47Z" = "1" /* Revision of Autologous Tissue Substitute in Testis, Percutaneous Endoscopic Approach */
"0VWD4JZ" = "1" /* Revision of Synthetic Substitute in Testis, Percutaneous Endoscopic Approach */
"0VWD4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Testis, Percutaneous Endoscopic Approach */
"0VWD70Z" = "1" /* Revision of Drainage Device in Testis, Via Natural or Artificial Opening */
"0VWD73Z" = "1" /* Revision of Infusion Device in Testis, Via Natural or Artificial Opening */
"0VWD77Z" = "1" /* Revision of Autologous Tissue Substitute in Testis, Via Natural or Artificial Opening */
"0VWD7JZ" = "1" /* Revision of Synthetic Substitute in Testis, Via Natural or Artificial Opening */
"0VWD7KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Testis, Via Natural or Artificial Opening */
"0VWD80Z" = "1" /* Revision of Drainage Device in Testis, Via Natural or Artificial Opening Endoscopic */
"0VWD83Z" = "1" /* Revision of Infusion Device in Testis, Via Natural or Artificial Opening Endoscopic */
"0VWD87Z" = "1" /* Revision of Autologous Tissue Substitute in Testis, Via Natural or Artificial Opening Endoscopic */
"0VWD8JZ" = "1" /* Revision of Synthetic Substitute in Testis, Via Natural or Artificial Opening Endoscopic */
"0VWD8KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Testis, Via Natural or Artificial Opening Endoscopic */
"0VWM00Z" = "1" /* Revision of Drainage Device in Epididymis and Spermatic Cord, Open Approach */
"0VWM03Z" = "1" /* Revision of Infusion Device in Epididymis and Spermatic Cord, Open Approach */
"0VWM07Z" = "1" /* Revision of Autologous Tissue Substitute in Epididymis and Spermatic Cord, Open Approach */
"0VWM0CZ" = "1" /* Revision of Extraluminal Device in Epididymis and Spermatic Cord, Open Approach */
"0VWM0JZ" = "1" /* Revision of Synthetic Substitute in Epididymis and Spermatic Cord, Open Approach */
"0VWM0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Epididymis and Spermatic Cord, Open Approach */
"0VWM30Z" = "1" /* Revision of Drainage Device in Epididymis and Spermatic Cord, Percutaneous Approach */
"0VWM33Z" = "1" /* Revision of Infusion Device in Epididymis and Spermatic Cord, Percutaneous Approach */
"0VWM37Z" = "1" /* Revision of Autologous Tissue Substitute in Epididymis and Spermatic Cord, Percutaneous Approach */
"0VWM3CZ" = "1" /* Revision of Extraluminal Device in Epididymis and Spermatic Cord, Percutaneous Approach */
"0VWM3JZ" = "1" /* Revision of Synthetic Substitute in Epididymis and Spermatic Cord, Percutaneous Approach */
"0VWM3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Epididymis and Spermatic Cord, Percutaneous Approach */
"0VWM40Z" = "1" /* Revision of Drainage Device in Epididymis and Spermatic Cord, Percutaneous Endoscopic Approach */
"0VWM43Z" = "1" /* Revision of Infusion Device in Epididymis and Spermatic Cord, Percutaneous Endoscopic Approach */
"0VWM47Z" = "1" /* Revision of Autologous Tissue Substitute in Epididymis and Spermatic Cord, Percutaneous Endoscopic Approach */
"0VWM4CZ" = "1" /* Revision of Extraluminal Device in Epididymis and Spermatic Cord, Percutaneous Endoscopic Approach */
"0VWM4JZ" = "1" /* Revision of Synthetic Substitute in Epididymis and Spermatic Cord, Percutaneous Endoscopic Approach */
"0VWM4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Epididymis and Spermatic Cord, Percutaneous Endoscopic Approach */
"0VWM70Z" = "1" /* Revision of Drainage Device in Epididymis and Spermatic Cord, Via Natural or Artificial Opening */
"0VWM73Z" = "1" /* Revision of Infusion Device in Epididymis and Spermatic Cord, Via Natural or Artificial Opening */
"0VWM77Z" = "1" /* Revision of Autologous Tissue Substitute in Epididymis and Spermatic Cord, Via Natural or Artificial Opening */
"0VWM7CZ" = "1" /* Revision of Extraluminal Device in Epididymis and Spermatic Cord, Via Natural or Artificial Opening */
"0VWM7JZ" = "1" /* Revision of Synthetic Substitute in Epididymis and Spermatic Cord, Via Natural or Artificial Opening */
"0VWM7KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Epididymis and Spermatic Cord, Via Natural or Artificial Opening */
"0VWM80Z" = "1" /* Revision of Drainage Device in Epididymis and Spermatic Cord, Via Natural or Artificial Opening Endoscopic */
"0VWM83Z" = "1" /* Revision of Infusion Device in Epididymis and Spermatic Cord, Via Natural or Artificial Opening Endoscopic */
"0VWM87Z" = "1" /* Revision of Autologous Tissue Substitute in Epididymis and Spermatic Cord, Via Natural or Artificial Opening Endoscopic */
"0VWM8CZ" = "1" /* Revision of Extraluminal Device in Epididymis and Spermatic Cord, Via Natural or Artificial Opening Endoscopic */
"0VWM8JZ" = "1" /* Revision of Synthetic Substitute in Epididymis and Spermatic Cord, Via Natural or Artificial Opening Endoscopic */
"0VWM8KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Epididymis and Spermatic Cord, Via Natural or Artificial Opening Endoscopic */
"0VWS00Z" = "1" /* Revision of Drainage Device in Penis, Open Approach */
"0VWS03Z" = "1" /* Revision of Infusion Device in Penis, Open Approach */
"0VWS07Z" = "1" /* Revision of Autologous Tissue Substitute in Penis, Open Approach */
"0VWS0JZ" = "1" /* Revision of Synthetic Substitute in Penis, Open Approach */
"0VWS0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Penis, Open Approach */
"0VWS30Z" = "1" /* Revision of Drainage Device in Penis, Percutaneous Approach */
"0VWS33Z" = "1" /* Revision of Infusion Device in Penis, Percutaneous Approach */
"0VWS37Z" = "1" /* Revision of Autologous Tissue Substitute in Penis, Percutaneous Approach */
"0VWS3JZ" = "1" /* Revision of Synthetic Substitute in Penis, Percutaneous Approach */
"0VWS3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Penis, Percutaneous Approach */
"0VWS40Z" = "1" /* Revision of Drainage Device in Penis, Percutaneous Endoscopic Approach */
"0VWS43Z" = "1" /* Revision of Infusion Device in Penis, Percutaneous Endoscopic Approach */
"0VWS47Z" = "1" /* Revision of Autologous Tissue Substitute in Penis, Percutaneous Endoscopic Approach */
"0VWS4JZ" = "1" /* Revision of Synthetic Substitute in Penis, Percutaneous Endoscopic Approach */
"0VWS4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Penis, Percutaneous Endoscopic Approach */
"0VWS70Z" = "1" /* Revision of Drainage Device in Penis, Via Natural or Artificial Opening */
"0VWS73Z" = "1" /* Revision of Infusion Device in Penis, Via Natural or Artificial Opening */
"0VWS77Z" = "1" /* Revision of Autologous Tissue Substitute in Penis, Via Natural or Artificial Opening */
"0VWS7JZ" = "1" /* Revision of Synthetic Substitute in Penis, Via Natural or Artificial Opening */
"0VWS7KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Penis, Via Natural or Artificial Opening */
"0VWS80Z" = "1" /* Revision of Drainage Device in Penis, Via Natural or Artificial Opening Endoscopic */
"0VWS83Z" = "1" /* Revision of Infusion Device in Penis, Via Natural or Artificial Opening Endoscopic */
"0VWS87Z" = "1" /* Revision of Autologous Tissue Substitute in Penis, Via Natural or Artificial Opening Endoscopic */
"0VWS8JZ" = "1" /* Revision of Synthetic Substitute in Penis, Via Natural or Artificial Opening Endoscopic */
"0VWS8KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Penis, Via Natural or Artificial Opening Endoscopic */
"0W0007Z" = "1" /* Alteration of Head with Autologous Tissue Substitute, Open Approach */
"0W000JZ" = "1" /* Alteration of Head with Synthetic Substitute, Open Approach */
"0W000KZ" = "1" /* Alteration of Head with Nonautologous Tissue Substitute, Open Approach */
"0W000ZZ" = "1" /* Alteration of Head, Open Approach */
"0W0037Z" = "1" /* Alteration of Head with Autologous Tissue Substitute, Percutaneous Approach */
"0W003JZ" = "1" /* Alteration of Head with Synthetic Substitute, Percutaneous Approach */
"0W003KZ" = "1" /* Alteration of Head with Nonautologous Tissue Substitute, Percutaneous Approach */
"0W003ZZ" = "1" /* Alteration of Head, Percutaneous Approach */
"0W0047Z" = "1" /* Alteration of Head with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W004JZ" = "1" /* Alteration of Head with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W004KZ" = "1" /* Alteration of Head with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W004ZZ" = "1" /* Alteration of Head, Percutaneous Endoscopic Approach */
"0W0207Z" = "1" /* Alteration of Face with Autologous Tissue Substitute, Open Approach */
"0W020JZ" = "1" /* Alteration of Face with Synthetic Substitute, Open Approach */
"0W020KZ" = "1" /* Alteration of Face with Nonautologous Tissue Substitute, Open Approach */
"0W020ZZ" = "1" /* Alteration of Face, Open Approach */
"0W0237Z" = "1" /* Alteration of Face with Autologous Tissue Substitute, Percutaneous Approach */
"0W023JZ" = "1" /* Alteration of Face with Synthetic Substitute, Percutaneous Approach */
"0W023KZ" = "1" /* Alteration of Face with Nonautologous Tissue Substitute, Percutaneous Approach */
"0W023ZZ" = "1" /* Alteration of Face, Percutaneous Approach */
"0W0247Z" = "1" /* Alteration of Face with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W024JZ" = "1" /* Alteration of Face with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W024KZ" = "1" /* Alteration of Face with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W024ZZ" = "1" /* Alteration of Face, Percutaneous Endoscopic Approach */
"0W0407Z" = "1" /* Alteration of Upper Jaw with Autologous Tissue Substitute, Open Approach */
"0W040JZ" = "1" /* Alteration of Upper Jaw with Synthetic Substitute, Open Approach */
"0W040KZ" = "1" /* Alteration of Upper Jaw with Nonautologous Tissue Substitute, Open Approach */
"0W040ZZ" = "1" /* Alteration of Upper Jaw, Open Approach */
"0W0437Z" = "1" /* Alteration of Upper Jaw with Autologous Tissue Substitute, Percutaneous Approach */
"0W043JZ" = "1" /* Alteration of Upper Jaw with Synthetic Substitute, Percutaneous Approach */
"0W043KZ" = "1" /* Alteration of Upper Jaw with Nonautologous Tissue Substitute, Percutaneous Approach */
"0W043ZZ" = "1" /* Alteration of Upper Jaw, Percutaneous Approach */
"0W0447Z" = "1" /* Alteration of Upper Jaw with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W044JZ" = "1" /* Alteration of Upper Jaw with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W044KZ" = "1" /* Alteration of Upper Jaw with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W044ZZ" = "1" /* Alteration of Upper Jaw, Percutaneous Endoscopic Approach */
"0W0507Z" = "1" /* Alteration of Lower Jaw with Autologous Tissue Substitute, Open Approach */
"0W050JZ" = "1" /* Alteration of Lower Jaw with Synthetic Substitute, Open Approach */
"0W050KZ" = "1" /* Alteration of Lower Jaw with Nonautologous Tissue Substitute, Open Approach */
"0W050ZZ" = "1" /* Alteration of Lower Jaw, Open Approach */
"0W0537Z" = "1" /* Alteration of Lower Jaw with Autologous Tissue Substitute, Percutaneous Approach */
"0W053JZ" = "1" /* Alteration of Lower Jaw with Synthetic Substitute, Percutaneous Approach */
"0W053KZ" = "1" /* Alteration of Lower Jaw with Nonautologous Tissue Substitute, Percutaneous Approach */
"0W053ZZ" = "1" /* Alteration of Lower Jaw, Percutaneous Approach */
"0W0547Z" = "1" /* Alteration of Lower Jaw with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W054JZ" = "1" /* Alteration of Lower Jaw with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W054KZ" = "1" /* Alteration of Lower Jaw with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W054ZZ" = "1" /* Alteration of Lower Jaw, Percutaneous Endoscopic Approach */
"0W0607Z" = "1" /* Alteration of Neck with Autologous Tissue Substitute, Open Approach */
"0W060JZ" = "1" /* Alteration of Neck with Synthetic Substitute, Open Approach */
"0W060KZ" = "1" /* Alteration of Neck with Nonautologous Tissue Substitute, Open Approach */
"0W060ZZ" = "1" /* Alteration of Neck, Open Approach */
"0W0637Z" = "1" /* Alteration of Neck with Autologous Tissue Substitute, Percutaneous Approach */
"0W063JZ" = "1" /* Alteration of Neck with Synthetic Substitute, Percutaneous Approach */
"0W063KZ" = "1" /* Alteration of Neck with Nonautologous Tissue Substitute, Percutaneous Approach */
"0W063ZZ" = "1" /* Alteration of Neck, Percutaneous Approach */
"0W0647Z" = "1" /* Alteration of Neck with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W064JZ" = "1" /* Alteration of Neck with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W064KZ" = "1" /* Alteration of Neck with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W064ZZ" = "1" /* Alteration of Neck, Percutaneous Endoscopic Approach */
"0W0807Z" = "1" /* Alteration of Chest Wall with Autologous Tissue Substitute, Open Approach */
"0W080JZ" = "1" /* Alteration of Chest Wall with Synthetic Substitute, Open Approach */
"0W080KZ" = "1" /* Alteration of Chest Wall with Nonautologous Tissue Substitute, Open Approach */
"0W080ZZ" = "1" /* Alteration of Chest Wall, Open Approach */
"0W0837Z" = "1" /* Alteration of Chest Wall with Autologous Tissue Substitute, Percutaneous Approach */
"0W083JZ" = "1" /* Alteration of Chest Wall with Synthetic Substitute, Percutaneous Approach */
"0W083KZ" = "1" /* Alteration of Chest Wall with Nonautologous Tissue Substitute, Percutaneous Approach */
"0W083ZZ" = "1" /* Alteration of Chest Wall, Percutaneous Approach */
"0W0847Z" = "1" /* Alteration of Chest Wall with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W084JZ" = "1" /* Alteration of Chest Wall with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W084KZ" = "1" /* Alteration of Chest Wall with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W084ZZ" = "1" /* Alteration of Chest Wall, Percutaneous Endoscopic Approach */
"0W0F07Z" = "1" /* Alteration of Abdominal Wall with Autologous Tissue Substitute, Open Approach */
"0W0F0JZ" = "1" /* Alteration of Abdominal Wall with Synthetic Substitute, Open Approach */
"0W0F0KZ" = "1" /* Alteration of Abdominal Wall with Nonautologous Tissue Substitute, Open Approach */
"0W0F0ZZ" = "1" /* Alteration of Abdominal Wall, Open Approach */
"0W0F37Z" = "1" /* Alteration of Abdominal Wall with Autologous Tissue Substitute, Percutaneous Approach */
"0W0F3JZ" = "1" /* Alteration of Abdominal Wall with Synthetic Substitute, Percutaneous Approach */
"0W0F3KZ" = "1" /* Alteration of Abdominal Wall with Nonautologous Tissue Substitute, Percutaneous Approach */
"0W0F3ZZ" = "1" /* Alteration of Abdominal Wall, Percutaneous Approach */
"0W0F47Z" = "1" /* Alteration of Abdominal Wall with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W0F4JZ" = "1" /* Alteration of Abdominal Wall with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W0F4KZ" = "1" /* Alteration of Abdominal Wall with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W0F4ZZ" = "1" /* Alteration of Abdominal Wall, Percutaneous Endoscopic Approach */
"0W0K07Z" = "1" /* Alteration of Upper Back with Autologous Tissue Substitute, Open Approach */
"0W0K0JZ" = "1" /* Alteration of Upper Back with Synthetic Substitute, Open Approach */
"0W0K0KZ" = "1" /* Alteration of Upper Back with Nonautologous Tissue Substitute, Open Approach */
"0W0K0ZZ" = "1" /* Alteration of Upper Back, Open Approach */
"0W0K37Z" = "1" /* Alteration of Upper Back with Autologous Tissue Substitute, Percutaneous Approach */
"0W0K3JZ" = "1" /* Alteration of Upper Back with Synthetic Substitute, Percutaneous Approach */
"0W0K3KZ" = "1" /* Alteration of Upper Back with Nonautologous Tissue Substitute, Percutaneous Approach */
"0W0K3ZZ" = "1" /* Alteration of Upper Back, Percutaneous Approach */
"0W0K47Z" = "1" /* Alteration of Upper Back with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W0K4JZ" = "1" /* Alteration of Upper Back with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W0K4KZ" = "1" /* Alteration of Upper Back with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W0K4ZZ" = "1" /* Alteration of Upper Back, Percutaneous Endoscopic Approach */
"0W0L07Z" = "1" /* Alteration of Lower Back with Autologous Tissue Substitute, Open Approach */
"0W0L0JZ" = "1" /* Alteration of Lower Back with Synthetic Substitute, Open Approach */
"0W0L0KZ" = "1" /* Alteration of Lower Back with Nonautologous Tissue Substitute, Open Approach */
"0W0L0ZZ" = "1" /* Alteration of Lower Back, Open Approach */
"0W0L37Z" = "1" /* Alteration of Lower Back with Autologous Tissue Substitute, Percutaneous Approach */
"0W0L3JZ" = "1" /* Alteration of Lower Back with Synthetic Substitute, Percutaneous Approach */
"0W0L3KZ" = "1" /* Alteration of Lower Back with Nonautologous Tissue Substitute, Percutaneous Approach */
"0W0L3ZZ" = "1" /* Alteration of Lower Back, Percutaneous Approach */
"0W0L47Z" = "1" /* Alteration of Lower Back with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W0L4JZ" = "1" /* Alteration of Lower Back with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W0L4KZ" = "1" /* Alteration of Lower Back with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W0L4ZZ" = "1" /* Alteration of Lower Back, Percutaneous Endoscopic Approach */
"0W0M07Z" = "1" /* Alteration of Male Perineum with Autologous Tissue Substitute, Open Approach */
"0W0M0JZ" = "1" /* Alteration of Male Perineum with Synthetic Substitute, Open Approach */
"0W0M0KZ" = "1" /* Alteration of Male Perineum with Nonautologous Tissue Substitute, Open Approach */
"0W0M0ZZ" = "1" /* Alteration of Male Perineum, Open Approach */
"0W0M37Z" = "1" /* Alteration of Male Perineum with Autologous Tissue Substitute, Percutaneous Approach */
"0W0M3JZ" = "1" /* Alteration of Male Perineum with Synthetic Substitute, Percutaneous Approach */
"0W0M3KZ" = "1" /* Alteration of Male Perineum with Nonautologous Tissue Substitute, Percutaneous Approach */
"0W0M3ZZ" = "1" /* Alteration of Male Perineum, Percutaneous Approach */
"0W0M47Z" = "1" /* Alteration of Male Perineum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W0M4JZ" = "1" /* Alteration of Male Perineum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W0M4KZ" = "1" /* Alteration of Male Perineum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W0M4ZZ" = "1" /* Alteration of Male Perineum, Percutaneous Endoscopic Approach */
"0W0N07Z" = "1" /* Alteration of Female Perineum with Autologous Tissue Substitute, Open Approach */
"0W0N0JZ" = "1" /* Alteration of Female Perineum with Synthetic Substitute, Open Approach */
"0W0N0KZ" = "1" /* Alteration of Female Perineum with Nonautologous Tissue Substitute, Open Approach */
"0W0N0ZZ" = "1" /* Alteration of Female Perineum, Open Approach */
"0W0N37Z" = "1" /* Alteration of Female Perineum with Autologous Tissue Substitute, Percutaneous Approach */
"0W0N3JZ" = "1" /* Alteration of Female Perineum with Synthetic Substitute, Percutaneous Approach */
"0W0N3KZ" = "1" /* Alteration of Female Perineum with Nonautologous Tissue Substitute, Percutaneous Approach */
"0W0N3ZZ" = "1" /* Alteration of Female Perineum, Percutaneous Approach */
"0W0N47Z" = "1" /* Alteration of Female Perineum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W0N4JZ" = "1" /* Alteration of Female Perineum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W0N4KZ" = "1" /* Alteration of Female Perineum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0W0N4ZZ" = "1" /* Alteration of Female Perineum, Percutaneous Endoscopic Approach */
"0W110J9" = "1" /* Bypass Cranial Cavity to Right Pleural Cavity with Synthetic Substitute, Open Approach */
"0W110JB" = "1" /* Bypass Cranial Cavity to Left Pleural Cavity with Synthetic Substitute, Open Approach */
"0W110JG" = "1" /* Bypass Cranial Cavity to Peritoneal Cavity with Synthetic Substitute, Open Approach */
"0W110JJ" = "1" /* Bypass Cranial Cavity to Pelvic Cavity with Synthetic Substitute, Open Approach */
"0W190J9" = "1" /* Bypass Right Pleural Cavity to Right Pleural Cavity with Synthetic Substitute, Open Approach */
"0W190JB" = "1" /* Bypass Right Pleural Cavity to Left Pleural Cavity with Synthetic Substitute, Open Approach */
"0W190JJ" = "1" /* Bypass Right Pleural Cavity to Pelvic Cavity with Synthetic Substitute, Open Approach */
"0W194J9" = "1" /* Bypass Right Pleural Cavity to Right Pleural Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W194JB" = "1" /* Bypass Right Pleural Cavity to Left Pleural Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W194JJ" = "1" /* Bypass Right Pleural Cavity to Pelvic Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1B0J9" = "1" /* Bypass Left Pleural Cavity to Right Pleural Cavity with Synthetic Substitute, Open Approach */
"0W1B0JB" = "1" /* Bypass Left Pleural Cavity to Left Pleural Cavity with Synthetic Substitute, Open Approach */
"0W1B0JJ" = "1" /* Bypass Left Pleural Cavity to Pelvic Cavity with Synthetic Substitute, Open Approach */
"0W1B4J9" = "1" /* Bypass Left Pleural Cavity to Right Pleural Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1B4JB" = "1" /* Bypass Left Pleural Cavity to Left Pleural Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1B4JJ" = "1" /* Bypass Left Pleural Cavity to Pelvic Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1G0J4" = "1" /* Bypass Peritoneal Cavity to Cutaneous with Synthetic Substitute, Open Approach */
"0W1G0JY" = "1" /* Bypass Peritoneal Cavity to Lower Vein with Synthetic Substitute, Open Approach */
"0W1G3J4" = "1" /* Bypass Peritoneal Cavity to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0W1G4J4" = "1" /* Bypass Peritoneal Cavity to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1G4JY" = "1" /* Bypass Peritoneal Cavity to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1J0J9" = "1" /* Bypass Pelvic Cavity to Right Pleural Cavity with Synthetic Substitute, Open Approach */
"0W1J0JB" = "1" /* Bypass Pelvic Cavity to Left Pleural Cavity with Synthetic Substitute, Open Approach */
"0W1J0JG" = "1" /* Bypass Pelvic Cavity to Peritoneal Cavity with Synthetic Substitute, Open Approach */
"0W1J0JJ" = "1" /* Bypass Pelvic Cavity to Pelvic Cavity with Synthetic Substitute, Open Approach */
"0W1J4J9" = "1" /* Bypass Pelvic Cavity to Right Pleural Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1J4JB" = "1" /* Bypass Pelvic Cavity to Left Pleural Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1J4JG" = "1" /* Bypass Pelvic Cavity to Peritoneal Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1J4JJ" = "1" /* Bypass Pelvic Cavity to Pelvic Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W300ZZ" = "1" /* Control Bleeding in Head, Open Approach */
"0W303ZZ" = "1" /* Control Bleeding in Head, Percutaneous Approach */
"0W304ZZ" = "1" /* Control Bleeding in Head, Percutaneous Endoscopic Approach */
"0W310ZZ" = "1" /* Control Bleeding in Cranial Cavity, Open Approach */
"0W313ZZ" = "1" /* Control Bleeding in Cranial Cavity, Percutaneous Approach */
"0W314ZZ" = "1" /* Control Bleeding in Cranial Cavity, Percutaneous Endoscopic Approach */
"0W320ZZ" = "1" /* Control Bleeding in Face, Open Approach */
"0W323ZZ" = "1" /* Control Bleeding in Face, Percutaneous Approach */
"0W324ZZ" = "1" /* Control Bleeding in Face, Percutaneous Endoscopic Approach */
"0W330ZZ" = "1" /* Control Bleeding in Oral Cavity and Throat, Open Approach */
"0W333ZZ" = "1" /* Control Bleeding in Oral Cavity and Throat, Percutaneous Approach */
"0W334ZZ" = "1" /* Control Bleeding in Oral Cavity and Throat, Percutaneous Endoscopic Approach */
"0W337ZZ" = "1" /* Control Bleeding in Oral Cavity and Throat, Via Natural or Artificial Opening */
"0W338ZZ" = "1" /* Control Bleeding in Oral Cavity and Throat, Via Natural or Artificial Opening Endoscopic */
"0W33XZZ" = "1" /* Control Bleeding in Oral Cavity and Throat, External Approach */
"0W340ZZ" = "1" /* Control Bleeding in Upper Jaw, Open Approach */
"0W343ZZ" = "1" /* Control Bleeding in Upper Jaw, Percutaneous Approach */
"0W344ZZ" = "1" /* Control Bleeding in Upper Jaw, Percutaneous Endoscopic Approach */
"0W350ZZ" = "1" /* Control Bleeding in Lower Jaw, Open Approach */
"0W353ZZ" = "1" /* Control Bleeding in Lower Jaw, Percutaneous Approach */
"0W354ZZ" = "1" /* Control Bleeding in Lower Jaw, Percutaneous Endoscopic Approach */
"0W360ZZ" = "1" /* Control Bleeding in Neck, Open Approach */
"0W363ZZ" = "1" /* Control Bleeding in Neck, Percutaneous Approach */
"0W364ZZ" = "1" /* Control Bleeding in Neck, Percutaneous Endoscopic Approach */
"0W380ZZ" = "1" /* Control Bleeding in Chest Wall, Open Approach */
"0W383ZZ" = "1" /* Control Bleeding in Chest Wall, Percutaneous Approach */
"0W384ZZ" = "1" /* Control Bleeding in Chest Wall, Percutaneous Endoscopic Approach */
"0W390ZZ" = "1" /* Control Bleeding in Right Pleural Cavity, Open Approach */
"0W393ZZ" = "1" /* Control Bleeding in Right Pleural Cavity, Percutaneous Approach */
"0W394ZZ" = "1" /* Control Bleeding in Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0W3B0ZZ" = "1" /* Control Bleeding in Left Pleural Cavity, Open Approach */
"0W3B3ZZ" = "1" /* Control Bleeding in Left Pleural Cavity, Percutaneous Approach */
"0W3B4ZZ" = "1" /* Control Bleeding in Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0W3C0ZZ" = "1" /* Control Bleeding in Mediastinum, Open Approach */
"0W3C3ZZ" = "1" /* Control Bleeding in Mediastinum, Percutaneous Approach */
"0W3C4ZZ" = "1" /* Control Bleeding in Mediastinum, Percutaneous Endoscopic Approach */
"0W3D0ZZ" = "1" /* Control Bleeding in Pericardial Cavity, Open Approach */
"0W3D3ZZ" = "1" /* Control Bleeding in Pericardial Cavity, Percutaneous Approach */
"0W3D4ZZ" = "1" /* Control Bleeding in Pericardial Cavity, Percutaneous Endoscopic Approach */
"0W3F0ZZ" = "1" /* Control Bleeding in Abdominal Wall, Open Approach */
"0W3F3ZZ" = "1" /* Control Bleeding in Abdominal Wall, Percutaneous Approach */
"0W3F4ZZ" = "1" /* Control Bleeding in Abdominal Wall, Percutaneous Endoscopic Approach */
"0W3G3ZZ" = "1" /* Control Bleeding in Peritoneal Cavity, Percutaneous Approach */
"0W3G4ZZ" = "1" /* Control Bleeding in Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0W3H0ZZ" = "1" /* Control Bleeding in Retroperitoneum, Open Approach */
"0W3H3ZZ" = "1" /* Control Bleeding in Retroperitoneum, Percutaneous Approach */
"0W3H4ZZ" = "1" /* Control Bleeding in Retroperitoneum, Percutaneous Endoscopic Approach */
"0W3J0ZZ" = "1" /* Control Bleeding in Pelvic Cavity, Open Approach */
"0W3J3ZZ" = "1" /* Control Bleeding in Pelvic Cavity, Percutaneous Approach */
"0W3J4ZZ" = "1" /* Control Bleeding in Pelvic Cavity, Percutaneous Endoscopic Approach */
"0W3K0ZZ" = "1" /* Control Bleeding in Upper Back, Open Approach */
"0W3K3ZZ" = "1" /* Control Bleeding in Upper Back, Percutaneous Approach */
"0W3K4ZZ" = "1" /* Control Bleeding in Upper Back, Percutaneous Endoscopic Approach */
"0W3L0ZZ" = "1" /* Control Bleeding in Lower Back, Open Approach */
"0W3L3ZZ" = "1" /* Control Bleeding in Lower Back, Percutaneous Approach */
"0W3L4ZZ" = "1" /* Control Bleeding in Lower Back, Percutaneous Endoscopic Approach */
"0W3M0ZZ" = "1" /* Control Bleeding in Male Perineum, Open Approach */
"0W3M3ZZ" = "1" /* Control Bleeding in Male Perineum, Percutaneous Approach */
"0W3M4ZZ" = "1" /* Control Bleeding in Male Perineum, Percutaneous Endoscopic Approach */
"0W3N0ZZ" = "1" /* Control Bleeding in Female Perineum, Open Approach */
"0W3N3ZZ" = "1" /* Control Bleeding in Female Perineum, Percutaneous Approach */
"0W3N4ZZ" = "1" /* Control Bleeding in Female Perineum, Percutaneous Endoscopic Approach */
"0W3P0ZZ" = "1" /* Control Bleeding in Gastrointestinal Tract, Open Approach */
"0W3P3ZZ" = "1" /* Control Bleeding in Gastrointestinal Tract, Percutaneous Approach */
"0W3P4ZZ" = "1" /* Control Bleeding in Gastrointestinal Tract, Percutaneous Endoscopic Approach */
"0W3P7ZZ" = "1" /* Control Bleeding in Gastrointestinal Tract, Via Natural or Artificial Opening */
"0W3Q0ZZ" = "1" /* Control Bleeding in Respiratory Tract, Open Approach */
"0W3Q3ZZ" = "1" /* Control Bleeding in Respiratory Tract, Percutaneous Approach */
"0W3Q4ZZ" = "1" /* Control Bleeding in Respiratory Tract, Percutaneous Endoscopic Approach */
"0W3Q7ZZ" = "1" /* Control Bleeding in Respiratory Tract, Via Natural or Artificial Opening */
"0W3Q8ZZ" = "1" /* Control Bleeding in Respiratory Tract, Via Natural or Artificial Opening Endoscopic */
"0W3R0ZZ" = "1" /* Control Bleeding in Genitourinary Tract, Open Approach */
"0W3R3ZZ" = "1" /* Control Bleeding in Genitourinary Tract, Percutaneous Approach */
"0W3R4ZZ" = "1" /* Control Bleeding in Genitourinary Tract, Percutaneous Endoscopic Approach */
"0W3R7ZZ" = "1" /* Control Bleeding in Genitourinary Tract, Via Natural or Artificial Opening */
"0W3R8ZZ" = "1" /* Control Bleeding in Genitourinary Tract, Via Natural or Artificial Opening Endoscopic */
"0W4M070" = "1" /* Creation of Vagina in Male Perineum with Autologous Tissue Substitute, Open Approach */
"0W4M0J0" = "1" /* Creation of Vagina in Male Perineum with Synthetic Substitute, Open Approach */
"0W4M0K0" = "1" /* Creation of Vagina in Male Perineum with Nonautologous Tissue Substitute, Open Approach */
"0W4M0Z0" = "1" /* Creation of Vagina in Male Perineum, Open Approach */
"0W4N071" = "1" /* Creation of Penis in Female Perineum with Autologous Tissue Substitute, Open Approach */
"0W4N0J1" = "1" /* Creation of Penis in Female Perineum with Synthetic Substitute, Open Approach */
"0W4N0K1" = "1" /* Creation of Penis in Female Perineum with Nonautologous Tissue Substitute, Open Approach */
"0W4N0Z1" = "1" /* Creation of Penis in Female Perineum, Open Approach */
"0W9100Z" = "1" /* Drainage of Cranial Cavity with Drainage Device, Open Approach */
"0W910ZX" = "1" /* Drainage of Cranial Cavity, Open Approach, Diagnostic */
"0W910ZZ" = "1" /* Drainage of Cranial Cavity, Open Approach */
"0W9200Z" = "1" /* Drainage of Face with Drainage Device, Open Approach */
"0W920ZZ" = "1" /* Drainage of Face, Open Approach */
"0W9240Z" = "1" /* Drainage of Face with Drainage Device, Percutaneous Endoscopic Approach */
"0W924ZZ" = "1" /* Drainage of Face, Percutaneous Endoscopic Approach */
"0W9300Z" = "1" /* Drainage of Oral Cavity and Throat with Drainage Device, Open Approach */
"0W930ZZ" = "1" /* Drainage of Oral Cavity and Throat, Open Approach */
"0W9340Z" = "1" /* Drainage of Oral Cavity and Throat with Drainage Device, Percutaneous Endoscopic Approach */
"0W934ZZ" = "1" /* Drainage of Oral Cavity and Throat, Percutaneous Endoscopic Approach */
"0W9400Z" = "1" /* Drainage of Upper Jaw with Drainage Device, Open Approach */
"0W940ZZ" = "1" /* Drainage of Upper Jaw, Open Approach */
"0W9440Z" = "1" /* Drainage of Upper Jaw with Drainage Device, Percutaneous Endoscopic Approach */
"0W944ZZ" = "1" /* Drainage of Upper Jaw, Percutaneous Endoscopic Approach */
"0W9500Z" = "1" /* Drainage of Lower Jaw with Drainage Device, Open Approach */
"0W950ZZ" = "1" /* Drainage of Lower Jaw, Open Approach */
"0W9540Z" = "1" /* Drainage of Lower Jaw with Drainage Device, Percutaneous Endoscopic Approach */
"0W954ZZ" = "1" /* Drainage of Lower Jaw, Percutaneous Endoscopic Approach */
"0W9600Z" = "1" /* Drainage of Neck with Drainage Device, Open Approach */
"0W960ZZ" = "1" /* Drainage of Neck, Open Approach */
"0W9640Z" = "1" /* Drainage of Neck with Drainage Device, Percutaneous Endoscopic Approach */
"0W964ZZ" = "1" /* Drainage of Neck, Percutaneous Endoscopic Approach */
"0W9940Z" = "1" /* Drainage of right pleural cavity with drainage device, percutaneous endoscopic approach */
"0W994ZZ" = "1" /* Drainage of right pleural cavity, percutaneous endoscopic approach */
"0W9B40Z" = "1" /* Drainage of left pleural cavity with drainage device, percutaneous endoscopic approach */
"0W9B4ZZ" = "1" /* Drainage of left pleural cavity, percutaneous endoscopic approach */
"0W9C00Z" = "1" /* Drainage of Mediastinum with Drainage Device, Open Approach */
"0W9C0ZX" = "1" /* Drainage of Mediastinum, Open Approach, Diagnostic */
"0W9C0ZZ" = "1" /* Drainage of Mediastinum, Open Approach */
"0W9C40Z" = "1" /* Drainage of Mediastinum with Drainage Device, Percutaneous Endoscopic Approach */
"0W9C4ZZ" = "1" /* Drainage of Mediastinum, Percutaneous Endoscopic Approach */
"0W9D00Z" = "1" /* Drainage of Pericardial Cavity with Drainage Device, Open Approach */
"0W9D0ZX" = "1" /* Drainage of Pericardial Cavity, Open Approach, Diagnostic */
"0W9D0ZZ" = "1" /* Drainage of Pericardial Cavity, Open Approach */
"0W9F00Z" = "1" /* Drainage of Abdominal Wall with Drainage Device, Open Approach */
"0W9F0ZX" = "1" /* Drainage of Abdominal Wall, Open Approach, Diagnostic */
"0W9F0ZZ" = "1" /* Drainage of Abdominal Wall, Open Approach */
"0W9F4ZX" = "1" /* Drainage of Abdominal Wall, Percutaneous Endoscopic Approach, Diagnostic */
"0W9G00Z" = "1" /* Drainage of Peritoneal Cavity with Drainage Device, Open Approach */
"0W9G0ZX" = "1" /* Drainage of Peritoneal Cavity, Open Approach, Diagnostic */
"0W9G0ZZ" = "1" /* Drainage of Peritoneal Cavity, Open Approach */
"0W9G4ZX" = "1" /* Drainage of Peritoneal Cavity, Percutaneous Endoscopic Approach, Diagnostic */
"0W9H00Z" = "1" /* Drainage of Retroperitoneum with Drainage Device, Open Approach */
"0W9H0ZX" = "1" /* Drainage of Retroperitoneum, Open Approach, Diagnostic */
"0W9H0ZZ" = "1" /* Drainage of Retroperitoneum, Open Approach */
"0W9H40Z" = "1" /* Drainage of Retroperitoneum with Drainage Device, Percutaneous Endoscopic Approach */
"0W9H4ZX" = "1" /* Drainage of Retroperitoneum, Percutaneous Endoscopic Approach, Diagnostic */
"0W9H4ZZ" = "1" /* Drainage of Retroperitoneum, Percutaneous Endoscopic Approach */
"0W9J00Z" = "1" /* Drainage of Pelvic Cavity with Drainage Device, Open Approach */
"0W9J0ZX" = "1" /* Drainage of Pelvic Cavity, Open Approach, Diagnostic */
"0W9J0ZZ" = "1" /* Drainage of Pelvic Cavity, Open Approach */
"0W9J40Z" = "1" /* Drainage of Pelvic Cavity with Drainage Device, Percutaneous Endoscopic Approach */
"0W9J4ZX" = "1" /* Drainage of Pelvic Cavity, Percutaneous Endoscopic Approach, Diagnostic */
"0W9J4ZZ" = "1" /* Drainage of Pelvic Cavity, Percutaneous Endoscopic Approach */
"0W9N00Z" = "1" /* Drainage of Female Perineum with Drainage Device, Open Approach */
"0W9N0ZZ" = "1" /* Drainage of Female Perineum, Open Approach */
"0W9N40Z" = "1" /* Drainage of Female Perineum with Drainage Device, Percutaneous Endoscopic Approach */
"0W9N4ZZ" = "1" /* Drainage of Female Perineum, Percutaneous Endoscopic Approach */
"0WB00ZZ" = "1" /* Excision of Head, Open Approach */
"0WB03ZZ" = "1" /* Excision of Head, Percutaneous Approach */
"0WB04ZZ" = "1" /* Excision of Head, Percutaneous Endoscopic Approach */
"0WB0XZZ" = "1" /* Excision of Head, External Approach */
"0WB20ZZ" = "1" /* Excision of Face, Open Approach */
"0WB23ZZ" = "1" /* Excision of Face, Percutaneous Approach */
"0WB24ZZ" = "1" /* Excision of Face, Percutaneous Endoscopic Approach */
"0WB2XZZ" = "1" /* Excision of Face, External Approach */
"0WB40ZZ" = "1" /* Excision of Upper Jaw, Open Approach */
"0WB43ZZ" = "1" /* Excision of Upper Jaw, Percutaneous Approach */
"0WB44ZZ" = "1" /* Excision of Upper Jaw, Percutaneous Endoscopic Approach */
"0WB4XZZ" = "1" /* Excision of Upper Jaw, External Approach */
"0WB50ZZ" = "1" /* Excision of Lower Jaw, Open Approach */
"0WB53ZZ" = "1" /* Excision of Lower Jaw, Percutaneous Approach */
"0WB54ZZ" = "1" /* Excision of Lower Jaw, Percutaneous Endoscopic Approach */
"0WB5XZZ" = "1" /* Excision of Lower Jaw, External Approach */
"0WB60ZZ" = "1" /* Excision of Neck, Open Approach */
"0WB63ZZ" = "1" /* Excision of Neck, Percutaneous Approach */
"0WB64ZZ" = "1" /* Excision of Neck, Percutaneous Endoscopic Approach */
"0WB6XZ2" = "1" /* Excision of Neck, Stoma, External Approach */
"0WB6XZZ" = "1" /* Excision of Neck, External Approach */
"0WB80ZZ" = "1" /* Excision of Chest Wall, Open Approach */
"0WB83ZZ" = "1" /* Excision of Chest Wall, Percutaneous Approach */
"0WB84ZZ" = "1" /* Excision of Chest Wall, Percutaneous Endoscopic Approach */
"0WB8XZZ" = "1" /* Excision of Chest Wall, External Approach */
"0WBC0ZX" = "1" /* Excision of Mediastinum, Open Approach, Diagnostic */
"0WBC0ZZ" = "1" /* Excision of Mediastinum, Open Approach */
"0WBC3ZZ" = "1" /* Excision of Mediastinum, Percutaneous Approach */
"0WBC4ZZ" = "1" /* Excision of Mediastinum, Percutaneous Endoscopic Approach */
"0WBF0ZX" = "1" /* Excision of Abdominal Wall, Open Approach, Diagnostic */
"0WBF0ZZ" = "1" /* Excision of Abdominal Wall, Open Approach */
"0WBF3ZX" = "1" /* Excision of Abdominal Wall, Percutaneous Approach, Diagnostic */
"0WBF3ZZ" = "1" /* Excision of Abdominal Wall, Percutaneous Approach */
"0WBF4ZX" = "1" /* Excision of Abdominal Wall, Percutaneous Endoscopic Approach, Diagnostic */
"0WBF4ZZ" = "1" /* Excision of Abdominal Wall, Percutaneous Endoscopic Approach */
"0WBFXZ2" = "1" /* Excision of Abdominal Wall, Stoma, External Approach */
"0WBFXZX" = "1" /* Excision of Abdominal Wall, External Approach, Diagnostic */
"0WBFXZZ" = "1" /* Excision of Abdominal Wall, External Approach */
"0WBH0ZX" = "1" /* Excision of Retroperitoneum, Open Approach, Diagnostic */
"0WBH0ZZ" = "1" /* Excision of Retroperitoneum, Open Approach */
"0WBH3ZZ" = "1" /* Excision of Retroperitoneum, Percutaneous Approach */
"0WBH4ZZ" = "1" /* Excision of Retroperitoneum, Percutaneous Endoscopic Approach */
"0WBK0ZZ" = "1" /* Excision of Upper Back, Open Approach */
"0WBK3ZZ" = "1" /* Excision of Upper Back, Percutaneous Approach */
"0WBK4ZZ" = "1" /* Excision of Upper Back, Percutaneous Endoscopic Approach */
"0WBKXZZ" = "1" /* Excision of Upper Back, External Approach */
"0WBL0ZZ" = "1" /* Excision of Lower Back, Open Approach */
"0WBL3ZZ" = "1" /* Excision of Lower Back, Percutaneous Approach */
"0WBL4ZZ" = "1" /* Excision of Lower Back, Percutaneous Endoscopic Approach */
"0WBLXZZ" = "1" /* Excision of Lower Back, External Approach */
"0WBM0ZZ" = "1" /* Excision of Male Perineum, Open Approach */
"0WBM3ZZ" = "1" /* Excision of Male Perineum, Percutaneous Approach */
"0WBM4ZZ" = "1" /* Excision of Male Perineum, Percutaneous Endoscopic Approach */
"0WBMXZZ" = "1" /* Excision of Male Perineum, External Approach */
"0WBN0ZX" = "1" /* Excision of Female Perineum, Open Approach, Diagnostic */
"0WBN0ZZ" = "1" /* Excision of Female Perineum, Open Approach */
"0WBN3ZX" = "1" /* Excision of Female Perineum, Percutaneous Approach, Diagnostic */
"0WBN3ZZ" = "1" /* Excision of Female Perineum, Percutaneous Approach */
"0WBN4ZX" = "1" /* Excision of Female Perineum, Percutaneous Endoscopic Approach, Diagnostic */
"0WBN4ZZ" = "1" /* Excision of Female Perineum, Percutaneous Endoscopic Approach */
"0WBNXZX" = "1" /* Excision of Female Perineum, External Approach, Diagnostic */
"0WBNXZZ" = "1" /* Excision of Female Perineum, External Approach */
"0WC10ZZ" = "1" /* Extirpation of Matter from Cranial Cavity, Open Approach */
"0WC13ZZ" = "1" /* Extirpation of Matter from Cranial Cavity, Percutaneous Approach */
"0WC14ZZ" = "1" /* Extirpation of Matter from Cranial Cavity, Percutaneous Endoscopic Approach */
"0WC30ZZ" = "1" /* Extirpation of Matter from Oral Cavity and Throat, Open Approach */
"0WC33ZZ" = "1" /* Extirpation of Matter from Oral Cavity and Throat, Percutaneous Approach */
"0WC34ZZ" = "1" /* Extirpation of Matter from Oral Cavity and Throat, Percutaneous Endoscopic Approach */
"0WCC0ZZ" = "1" /* Extirpation of Matter from Mediastinum, Open Approach */
"0WCC3ZZ" = "1" /* Extirpation of Matter from Mediastinum, Percutaneous Approach */
"0WCC4ZZ" = "1" /* Extirpation of Matter from Mediastinum, Percutaneous Endoscopic Approach */
"0WCD0ZZ" = "1" /* Extirpation of Matter from Pericardial Cavity, Open Approach */
"0WCD3ZZ" = "1" /* Extirpation of Matter from Pericardial Cavity, Percutaneous Approach */
"0WCD4ZZ" = "1" /* Extirpation of Matter from Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WCG0ZZ" = "1" /* Extirpation of Matter from Peritoneal Cavity, Open Approach */
"0WCG3ZZ" = "1" /* Extirpation of Matter from Peritoneal Cavity, Percutaneous Approach */
"0WCG4ZZ" = "1" /* Extirpation of Matter from Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WCJ0ZZ" = "1" /* Extirpation of Matter from Pelvic Cavity, Open Approach */
"0WCJ3ZZ" = "1" /* Extirpation of Matter from Pelvic Cavity, Percutaneous Approach */
"0WCJ4ZZ" = "1" /* Extirpation of Matter from Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WCP0ZZ" = "1" /* Extirpation of Matter from Gastrointestinal Tract, Open Approach */
"0WCP3ZZ" = "1" /* Extirpation of Matter from Gastrointestinal Tract, Percutaneous Approach */
"0WCP4ZZ" = "1" /* Extirpation of Matter from Gastrointestinal Tract, Percutaneous Endoscopic Approach */
"0WCQ7ZZ" = "1" /* Extirpation of Matter from Respiratory Tract, Via Natural or Artificial Opening */
"0WCQ8ZZ" = "1" /* Extirpation of Matter from Respiratory Tract, Via Natural or Artificial Opening Endoscopic */
"0WCR0ZZ" = "1" /* Extirpation of Matter from Genitourinary Tract, Open Approach */
"0WCR3ZZ" = "1" /* Extirpation of Matter from Genitourinary Tract, Percutaneous Approach */
"0WCR4ZZ" = "1" /* Extirpation of Matter from Genitourinary Tract, Percutaneous Endoscopic Approach */
"0WF10ZZ" = "1" /* Fragmentation in Cranial Cavity, Open Approach */
"0WF13ZZ" = "1" /* Fragmentation in Cranial Cavity, Percutaneous Approach */
"0WF14ZZ" = "1" /* Fragmentation in Cranial Cavity, Percutaneous Endoscopic Approach */
"0WF30ZZ" = "1" /* Fragmentation in Oral Cavity and Throat, Open Approach */
"0WF33ZZ" = "1" /* Fragmentation in Oral Cavity and Throat, Percutaneous Approach */
"0WF34ZZ" = "1" /* Fragmentation in Oral Cavity and Throat, Percutaneous Endoscopic Approach */
"0WF90ZZ" = "1" /* Fragmentation in Right Pleural Cavity, Open Approach */
"0WF93ZZ" = "1" /* Fragmentation in Right Pleural Cavity, Percutaneous Approach */
"0WF94ZZ" = "1" /* Fragmentation in Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0WFB0ZZ" = "1" /* Fragmentation in Left Pleural Cavity, Open Approach */
"0WFB3ZZ" = "1" /* Fragmentation in Left Pleural Cavity, Percutaneous Approach */
"0WFB4ZZ" = "1" /* Fragmentation in Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0WFC0ZZ" = "1" /* Fragmentation in Mediastinum, Open Approach */
"0WFC3ZZ" = "1" /* Fragmentation in Mediastinum, Percutaneous Approach */
"0WFC4ZZ" = "1" /* Fragmentation in Mediastinum, Percutaneous Endoscopic Approach */
"0WFD0ZZ" = "1" /* Fragmentation in Pericardial Cavity, Open Approach */
"0WFD3ZZ" = "1" /* Fragmentation in Pericardial Cavity, Percutaneous Approach */
"0WFD4ZZ" = "1" /* Fragmentation in Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WFDXZZ" = "1" /* Fragmentation in Pericardial Cavity, External Approach */
"0WFG0ZZ" = "1" /* Fragmentation in Peritoneal Cavity, Open Approach */
"0WFG3ZZ" = "1" /* Fragmentation in Peritoneal Cavity, Percutaneous Approach */
"0WFG4ZZ" = "1" /* Fragmentation in Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WFQ0ZZ" = "1" /* Fragmentation in Respiratory Tract, Open Approach */
"0WFQ3ZZ" = "1" /* Fragmentation in Respiratory Tract, Percutaneous Approach */
"0WFQ4ZZ" = "1" /* Fragmentation in Respiratory Tract, Percutaneous Endoscopic Approach */
"0WFQ7ZZ" = "1" /* Fragmentation in Respiratory Tract, Via Natural or Artificial Opening */
"0WFQ8ZZ" = "1" /* Fragmentation in Respiratory Tract, Via Natural or Artificial Opening Endoscopic */
"0WH001Z" = "1" /* Insertion of Radioactive Element into Head, Open Approach */
"0WH031Z" = "1" /* Insertion of Radioactive Element into Head, Percutaneous Approach */
"0WH041Z" = "1" /* Insertion of Radioactive Element into Head, Percutaneous Endoscopic Approach */
"0WH101Z" = "1" /* Insertion of Radioactive Element into Cranial Cavity, Open Approach */
"0WH10YZ" = "1" /* Insertion of Other Device into Cranial Cavity, Open Approach */
"0WH131Z" = "1" /* Insertion of Radioactive Element into Cranial Cavity, Percutaneous Approach */
"0WH13YZ" = "1" /* Insertion of Other Device into Cranial Cavity, Percutaneous Approach */
"0WH141Z" = "1" /* Insertion of Radioactive Element into Cranial Cavity, Percutaneous Endoscopic Approach */
"0WH14YZ" = "1" /* Insertion of Other Device into Cranial Cavity, Percutaneous Endoscopic Approach */
"0WH201Z" = "1" /* Insertion of Radioactive Element into Face, Open Approach */
"0WH231Z" = "1" /* Insertion of Radioactive Element into Face, Percutaneous Approach */
"0WH241Z" = "1" /* Insertion of Radioactive Element into Face, Percutaneous Endoscopic Approach */
"0WH301Z" = "1" /* Insertion of Radioactive Element into Oral Cavity and Throat, Open Approach */
"0WH303Z" = "1" /* Insertion of Infusion Device into Oral Cavity and Throat, Open Approach */
"0WH30YZ" = "1" /* Insertion of Other Device into Oral Cavity and Throat, Open Approach */
"0WH331Z" = "1" /* Insertion of Radioactive Element into Oral Cavity and Throat, Percutaneous Approach */
"0WH333Z" = "1" /* Insertion of Infusion Device into Oral Cavity and Throat, Percutaneous Approach */
"0WH33YZ" = "1" /* Insertion of Other Device into Oral Cavity and Throat, Percutaneous Approach */
"0WH341Z" = "1" /* Insertion of Radioactive Element into Oral Cavity and Throat, Percutaneous Endoscopic Approach */
"0WH343Z" = "1" /* Insertion of Infusion Device into Oral Cavity and Throat, Percutaneous Endoscopic Approach */
"0WH34YZ" = "1" /* Insertion of Other Device into Oral Cavity and Throat, Percutaneous Endoscopic Approach */
"0WH401Z" = "1" /* Insertion of Radioactive Element into Upper Jaw, Open Approach */
"0WH431Z" = "1" /* Insertion of Radioactive Element into Upper Jaw, Percutaneous Approach */
"0WH441Z" = "1" /* Insertion of Radioactive Element into Upper Jaw, Percutaneous Endoscopic Approach */
"0WH501Z" = "1" /* Insertion of Radioactive Element into Lower Jaw, Open Approach */
"0WH531Z" = "1" /* Insertion of Radioactive Element into Lower Jaw, Percutaneous Approach */
"0WH541Z" = "1" /* Insertion of Radioactive Element into Lower Jaw, Percutaneous Endoscopic Approach */
"0WH601Z" = "1" /* Insertion of Radioactive Element into Neck, Open Approach */
"0WH631Z" = "1" /* Insertion of Radioactive Element into Neck, Percutaneous Approach */
"0WH641Z" = "1" /* Insertion of Radioactive Element into Neck, Percutaneous Endoscopic Approach */
"0WH801Z" = "1" /* Insertion of Radioactive Element into Chest Wall, Open Approach */
"0WH831Z" = "1" /* Insertion of Radioactive Element into Chest Wall, Percutaneous Approach */
"0WH841Z" = "1" /* Insertion of Radioactive Element into Chest Wall, Percutaneous Endoscopic Approach */
"0WH901Z" = "1" /* Insertion of Radioactive Element into Right Pleural Cavity, Open Approach */
"0WH931Z" = "1" /* Insertion of Radioactive Element into Right Pleural Cavity, Percutaneous Approach */
"0WH941Z" = "1" /* Insertion of Radioactive Element into Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0WHB01Z" = "1" /* Insertion of Radioactive Element into Left Pleural Cavity, Open Approach */
"0WHB31Z" = "1" /* Insertion of Radioactive Element into Left Pleural Cavity, Percutaneous Approach */
"0WHB41Z" = "1" /* Insertion of Radioactive Element into Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0WHC01Z" = "1" /* Insertion of Radioactive Element into Mediastinum, Open Approach */
"0WHC03Z" = "1" /* Insertion of Infusion Device into Mediastinum, Open Approach */
"0WHC0YZ" = "1" /* Insertion of Other Device into Mediastinum, Open Approach */
"0WHC31Z" = "1" /* Insertion of Radioactive Element into Mediastinum, Percutaneous Approach */
"0WHC33Z" = "1" /* Insertion of Infusion Device into Mediastinum, Percutaneous Approach */
"0WHC3YZ" = "1" /* Insertion of Other Device into Mediastinum, Percutaneous Approach */
"0WHC41Z" = "1" /* Insertion of Radioactive Element into Mediastinum, Percutaneous Endoscopic Approach */
"0WHC43Z" = "1" /* Insertion of Infusion Device into Mediastinum, Percutaneous Endoscopic Approach */
"0WHC4YZ" = "1" /* Insertion of Other Device into Mediastinum, Percutaneous Endoscopic Approach */
"0WHD01Z" = "1" /* Insertion of Radioactive Element into Pericardial Cavity, Open Approach */
"0WHD03Z" = "1" /* Insertion of Infusion Device into Pericardial Cavity, Open Approach */
"0WHD0YZ" = "1" /* Insertion of Other Device into Pericardial Cavity, Open Approach */
"0WHD31Z" = "1" /* Insertion of Radioactive Element into Pericardial Cavity, Percutaneous Approach */
"0WHD33Z" = "1" /* Insertion of Infusion Device into Pericardial Cavity, Percutaneous Approach */
"0WHD3YZ" = "1" /* Insertion of Other Device into Pericardial Cavity, Percutaneous Approach */
"0WHD41Z" = "1" /* Insertion of Radioactive Element into Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WHD43Z" = "1" /* Insertion of Infusion Device into Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WHD4YZ" = "1" /* Insertion of Other Device into Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WHF01Z" = "1" /* Insertion of Radioactive Element into Abdominal Wall, Open Approach */
"0WHF03Z" = "1" /* Insertion of Infusion Device into Abdominal Wall, Open Approach */
"0WHF0YZ" = "1" /* Insertion of Other Device into Abdominal Wall, Open Approach */
"0WHF31Z" = "1" /* Insertion of Radioactive Element into Abdominal Wall, Percutaneous Approach */
"0WHF33Z" = "1" /* Insertion of Infusion Device into Abdominal Wall, Percutaneous Approach */
"0WHF3YZ" = "1" /* Insertion of Other Device into Abdominal Wall, Percutaneous Approach */
"0WHF41Z" = "1" /* Insertion of Radioactive Element into Abdominal Wall, Percutaneous Endoscopic Approach */
"0WHF43Z" = "1" /* Insertion of Infusion Device into Abdominal Wall, Percutaneous Endoscopic Approach */
"0WHF4YZ" = "1" /* Insertion of Other Device into Abdominal Wall, Percutaneous Endoscopic Approach */
"0WHG01Z" = "1" /* Insertion of Radioactive Element into Peritoneal Cavity, Open Approach */
"0WHG03Z" = "1" /* Insertion of Infusion Device into Peritoneal Cavity, Open Approach */
"0WHG0YZ" = "1" /* Insertion of Other Device into Peritoneal Cavity, Open Approach */
"0WHG31Z" = "1" /* Insertion of Radioactive Element into Peritoneal Cavity, Percutaneous Approach */
"0WHG33Z" = "1" /* Insertion of Infusion Device into Peritoneal Cavity, Percutaneous Approach */
"0WHG3YZ" = "1" /* Insertion of Other Device into Peritoneal Cavity, Percutaneous Approach */
"0WHG41Z" = "1" /* Insertion of Radioactive Element into Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WHG43Z" = "1" /* Insertion of Infusion Device into Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WHG4YZ" = "1" /* Insertion of Other Device into Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WHH01Z" = "1" /* Insertion of Radioactive Element into Retroperitoneum, Open Approach */
"0WHH03Z" = "1" /* Insertion of Infusion Device into Retroperitoneum, Open Approach */
"0WHH0YZ" = "1" /* Insertion of Other Device into Retroperitoneum, Open Approach */
"0WHH31Z" = "1" /* Insertion of Radioactive Element into Retroperitoneum, Percutaneous Approach */
"0WHH33Z" = "1" /* Insertion of Infusion Device into Retroperitoneum, Percutaneous Approach */
"0WHH3YZ" = "1" /* Insertion of Other Device into Retroperitoneum, Percutaneous Approach */
"0WHH41Z" = "1" /* Insertion of Radioactive Element into Retroperitoneum, Percutaneous Endoscopic Approach */
"0WHH43Z" = "1" /* Insertion of Infusion Device into Retroperitoneum, Percutaneous Endoscopic Approach */
"0WHH4YZ" = "1" /* Insertion of Other Device into Retroperitoneum, Percutaneous Endoscopic Approach */
"0WHJ01Z" = "1" /* Insertion of Radioactive Element into Pelvic Cavity, Open Approach */
"0WHJ03Z" = "1" /* Insertion of Infusion Device into Pelvic Cavity, Open Approach */
"0WHJ0YZ" = "1" /* Insertion of Other Device into Pelvic Cavity, Open Approach */
"0WHJ31Z" = "1" /* Insertion of Radioactive Element into Pelvic Cavity, Percutaneous Approach */
"0WHJ33Z" = "1" /* Insertion of Infusion Device into Pelvic Cavity, Percutaneous Approach */
"0WHJ3YZ" = "1" /* Insertion of Other Device into Pelvic Cavity, Percutaneous Approach */
"0WHJ41Z" = "1" /* Insertion of Radioactive Element into Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WHJ43Z" = "1" /* Insertion of Infusion Device into Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WHJ4YZ" = "1" /* Insertion of Other Device into Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WHK01Z" = "1" /* Insertion of Radioactive Element into Upper Back, Open Approach */
"0WHK31Z" = "1" /* Insertion of Radioactive Element into Upper Back, Percutaneous Approach */
"0WHK41Z" = "1" /* Insertion of Radioactive Element into Upper Back, Percutaneous Endoscopic Approach */
"0WHL01Z" = "1" /* Insertion of Radioactive Element into Lower Back, Open Approach */
"0WHL31Z" = "1" /* Insertion of Radioactive Element into Lower Back, Percutaneous Approach */
"0WHL41Z" = "1" /* Insertion of Radioactive Element into Lower Back, Percutaneous Endoscopic Approach */
"0WHM01Z" = "1" /* Insertion of Radioactive Element into Male Perineum, Open Approach */
"0WHM31Z" = "1" /* Insertion of Radioactive Element into Male Perineum, Percutaneous Approach */
"0WHM41Z" = "1" /* Insertion of Radioactive Element into Male Perineum, Percutaneous Endoscopic Approach */
"0WHN01Z" = "1" /* Insertion of Radioactive Element into Female Perineum, Open Approach */
"0WHN03Z" = "1" /* Insertion of Infusion Device into Female Perineum, Open Approach */
"0WHN0YZ" = "1" /* Insertion of Other Device into Female Perineum, Open Approach */
"0WHN31Z" = "1" /* Insertion of Radioactive Element into Female Perineum, Percutaneous Approach */
"0WHN33Z" = "1" /* Insertion of Infusion Device into Female Perineum, Percutaneous Approach */
"0WHN3YZ" = "1" /* Insertion of Other Device into Female Perineum, Percutaneous Approach */
"0WHN41Z" = "1" /* Insertion of Radioactive Element into Female Perineum, Percutaneous Endoscopic Approach */
"0WHN43Z" = "1" /* Insertion of Infusion Device into Female Perineum, Percutaneous Endoscopic Approach */
"0WHN4YZ" = "1" /* Insertion of Other Device into Female Perineum, Percutaneous Endoscopic Approach */
"0WHP01Z" = "1" /* Insertion of Radioactive Element into Gastrointestinal Tract, Open Approach */
"0WHP03Z" = "1" /* Insertion of Infusion Device into Gastrointestinal Tract, Open Approach */
"0WHP31Z" = "1" /* Insertion of Radioactive Element into Gastrointestinal Tract, Percutaneous Approach */
"0WHP41Z" = "1" /* Insertion of Radioactive Element into Gastrointestinal Tract, Percutaneous Endoscopic Approach */
"0WHP71Z" = "1" /* Insertion of Radioactive Element into Gastrointestinal Tract, Via Natural or Artificial Opening */
"0WHP81Z" = "1" /* Insertion of Radioactive Element into Gastrointestinal Tract, Via Natural or Artificial Opening Endoscopic */
"0WHQ01Z" = "1" /* Insertion of Radioactive Element into Respiratory Tract, Open Approach */
"0WHQ31Z" = "1" /* Insertion of Radioactive Element into Respiratory Tract, Percutaneous Approach */
"0WHQ33Z" = "1" /* Insertion of Infusion Device into Respiratory Tract, Percutaneous Approach */
"0WHQ3YZ" = "1" /* Insertion of Other Device into Respiratory Tract, Percutaneous Approach */
"0WHQ41Z" = "1" /* Insertion of Radioactive Element into Respiratory Tract, Percutaneous Endoscopic Approach */
"0WHQ43Z" = "1" /* Insertion of Infusion Device into Respiratory Tract, Percutaneous Endoscopic Approach */
"0WHQ4YZ" = "1" /* Insertion of Other Device into Respiratory Tract, Percutaneous Endoscopic Approach */
"0WHQ71Z" = "1" /* Insertion of Radioactive Element into Respiratory Tract, Via Natural or Artificial Opening */
"0WHQ81Z" = "1" /* Insertion of Radioactive Element into Respiratory Tract, Via Natural or Artificial Opening Endoscopic */
"0WHR01Z" = "1" /* Insertion of Radioactive Element into Genitourinary Tract, Open Approach */
"0WHR31Z" = "1" /* Insertion of Radioactive Element into Genitourinary Tract, Percutaneous Approach */
"0WHR41Z" = "1" /* Insertion of Radioactive Element into Genitourinary Tract, Percutaneous Endoscopic Approach */
"0WHR71Z" = "1" /* Insertion of Radioactive Element into Genitourinary Tract, Via Natural or Artificial Opening */
"0WHR81Z" = "1" /* Insertion of Radioactive Element into Genitourinary Tract, Via Natural or Artificial Opening Endoscopic */
"0WJ10ZZ" = "1" /* Inspection of Cranial Cavity, Open Approach */
"0WJ14ZZ" = "1" /* Inspection of Cranial Cavity, Percutaneous Endoscopic Approach */
"0WJ60ZZ" = "1" /* Inspection of Neck, Open Approach */
"0WJ64ZZ" = "1" /* Inspection of Neck, Percutaneous Endoscopic Approach */
"0WJ80ZZ" = "1" /* Inspection of Chest Wall, Open Approach */
"0WJ84ZZ" = "1" /* Inspection of Chest Wall, Percutaneous Endoscopic Approach */
"0WJ90ZZ" = "1" /* Inspection of Right Pleural Cavity, Open Approach */
"0WJ94ZZ" = "1" /* Inspection of Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0WJB0ZZ" = "1" /* Inspection of Left Pleural Cavity, Open Approach */
"0WJB4ZZ" = "1" /* Inspection of Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0WJC0ZZ" = "1" /* Inspection of Mediastinum, Open Approach */
"0WJC4ZZ" = "1" /* Inspection of Mediastinum, Percutaneous Endoscopic Approach */
"0WJD4ZZ" = "1" /* Inspection of Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WJF0ZZ" = "1" /* Inspection of Abdominal Wall, Open Approach */
"0WJF4ZZ" = "1" /* Inspection of Abdominal Wall, Percutaneous Endoscopic Approach */
"0WJG0ZZ" = "1" /* Inspection of Peritoneal Cavity, Open Approach */
"0WJG4ZZ" = "1" /* Inspection of Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WJH0ZZ" = "1" /* Inspection of Retroperitoneum, Open Approach */
"0WJH4ZZ" = "1" /* Inspection of Retroperitoneum, Percutaneous Endoscopic Approach */
"0WJJ0ZZ" = "1" /* Inspection of Pelvic Cavity, Open Approach */
"0WJJ4ZZ" = "1" /* Inspection of Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WJN0ZZ" = "1" /* Inspection of Female Perineum, Open Approach */
"0WJN4ZZ" = "1" /* Inspection of Female Perineum, Percutaneous Endoscopic Approach */
"0WJP0ZZ" = "1" /* Inspection of Gastrointestinal Tract, Open Approach */
"0WJP4ZZ" = "1" /* Inspection of Gastrointestinal Tract, Percutaneous Endoscopic Approach */
"0WJQ0ZZ" = "1" /* Inspection of Respiratory Tract, Open Approach */
"0WJQ4ZZ" = "1" /* Inspection of Respiratory Tract, Percutaneous Endoscopic Approach */
"0WJR0ZZ" = "1" /* Inspection of Genitourinary Tract, Open Approach */
"0WJR4ZZ" = "1" /* Inspection of Genitourinary Tract, Percutaneous Endoscopic Approach */
"0WM20ZZ" = "1" /* Reattachment of Face, Open Approach */
"0WM40ZZ" = "1" /* Reattachment of Upper Jaw, Open Approach */
"0WM50ZZ" = "1" /* Reattachment of Lower Jaw, Open Approach */
"0WM60ZZ" = "1" /* Reattachment of Neck, Open Approach */
"0WM80ZZ" = "1" /* Reattachment of Chest Wall, Open Approach */
"0WMF0ZZ" = "1" /* Reattachment of Abdominal Wall, Open Approach */
"0WMK0ZZ" = "1" /* Reattachment of Upper Back, Open Approach */
"0WML0ZZ" = "1" /* Reattachment of Lower Back, Open Approach */
"0WMM0ZZ" = "1" /* Reattachment of Male Perineum, Open Approach */
"0WMN0ZZ" = "1" /* Reattachment of Female Perineum, Open Approach */
"0WP100Z" = "1" /* Removal of Drainage Device from Cranial Cavity, Open Approach */
"0WP101Z" = "1" /* Removal of Radioactive Element from Cranial Cavity, Open Approach */
"0WP10JZ" = "1" /* Removal of Synthetic Substitute from Cranial Cavity, Open Approach */
"0WP10YZ" = "1" /* Removal of Other Device from Cranial Cavity, Open Approach */
"0WP130Z" = "1" /* Removal of Drainage Device from Cranial Cavity, Percutaneous Approach */
"0WP131Z" = "1" /* Removal of Radioactive Element from Cranial Cavity, Percutaneous Approach */
"0WP13JZ" = "1" /* Removal of Synthetic Substitute from Cranial Cavity, Percutaneous Approach */
"0WP13YZ" = "1" /* Removal of Other Device from Cranial Cavity, Percutaneous Approach */
"0WP140Z" = "1" /* Removal of Drainage Device from Cranial Cavity, Percutaneous Endoscopic Approach */
"0WP141Z" = "1" /* Removal of Radioactive Element from Cranial Cavity, Percutaneous Endoscopic Approach */
"0WP14JZ" = "1" /* Removal of Synthetic Substitute from Cranial Cavity, Percutaneous Endoscopic Approach */
"0WP14YZ" = "1" /* Removal of Other Device from Cranial Cavity, Percutaneous Endoscopic Approach */
"0WPC00Z" = "1" /* Removal of Drainage Device from Mediastinum, Open Approach */
"0WPC01Z" = "1" /* Removal of Radioactive Element from Mediastinum, Open Approach */
"0WPC03Z" = "1" /* Removal of Infusion Device from Mediastinum, Open Approach */
"0WPC07Z" = "1" /* Removal of Autologous Tissue Substitute from Mediastinum, Open Approach */
"0WPC0JZ" = "1" /* Removal of Synthetic Substitute from Mediastinum, Open Approach */
"0WPC0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Mediastinum, Open Approach */
"0WPC0YZ" = "1" /* Removal of Other Device from Mediastinum, Open Approach */
"0WPC30Z" = "1" /* Removal of Drainage Device from Mediastinum, Percutaneous Approach */
"0WPC31Z" = "1" /* Removal of Radioactive Element from Mediastinum, Percutaneous Approach */
"0WPC33Z" = "1" /* Removal of Infusion Device from Mediastinum, Percutaneous Approach */
"0WPC37Z" = "1" /* Removal of Autologous Tissue Substitute from Mediastinum, Percutaneous Approach */
"0WPC3JZ" = "1" /* Removal of Synthetic Substitute from Mediastinum, Percutaneous Approach */
"0WPC3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Mediastinum, Percutaneous Approach */
"0WPC3YZ" = "1" /* Removal of Other Device from Mediastinum, Percutaneous Approach */
"0WPC40Z" = "1" /* Removal of Drainage Device from Mediastinum, Percutaneous Endoscopic Approach */
"0WPC41Z" = "1" /* Removal of Radioactive Element from Mediastinum, Percutaneous Endoscopic Approach */
"0WPC43Z" = "1" /* Removal of Infusion Device from Mediastinum, Percutaneous Endoscopic Approach */
"0WPC47Z" = "1" /* Removal of Autologous Tissue Substitute from Mediastinum, Percutaneous Endoscopic Approach */
"0WPC4JZ" = "1" /* Removal of Synthetic Substitute from Mediastinum, Percutaneous Endoscopic Approach */
"0WPC4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Mediastinum, Percutaneous Endoscopic Approach */
"0WPC4YZ" = "1" /* Removal of Other Device from Mediastinum, Percutaneous Endoscopic Approach */
"0WPD00Z" = "1" /* Removal of Drainage Device from Pericardial Cavity, Open Approach */
"0WPD01Z" = "1" /* Removal of Radioactive Element from Pericardial Cavity, Open Approach */
"0WPD03Z" = "1" /* Removal of Infusion Device from Pericardial Cavity, Open Approach */
"0WPD0YZ" = "1" /* Removal of Other Device from Pericardial Cavity, Open Approach */
"0WPD30Z" = "1" /* Removal of Drainage Device from Pericardial Cavity, Percutaneous Approach */
"0WPD31Z" = "1" /* Removal of Radioactive Element from Pericardial Cavity, Percutaneous Approach */
"0WPD33Z" = "1" /* Removal of Infusion Device from Pericardial Cavity, Percutaneous Approach */
"0WPD3YZ" = "1" /* Removal of Other Device from Pericardial Cavity, Percutaneous Approach */
"0WPD40Z" = "1" /* Removal of Drainage Device from Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WPD41Z" = "1" /* Removal of Radioactive Element from Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WPD43Z" = "1" /* Removal of Infusion Device from Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WPD4YZ" = "1" /* Removal of Other Device from Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WPF00Z" = "1" /* Removal of Drainage Device from Abdominal Wall, Open Approach */
"0WPF01Z" = "1" /* Removal of Radioactive Element from Abdominal Wall, Open Approach */
"0WPF03Z" = "1" /* Removal of Infusion Device from Abdominal Wall, Open Approach */
"0WPF07Z" = "1" /* Removal of Autologous Tissue Substitute from Abdominal Wall, Open Approach */
"0WPF0JZ" = "1" /* Removal of Synthetic Substitute from Abdominal Wall, Open Approach */
"0WPF0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Abdominal Wall, Open Approach */
"0WPF0YZ" = "1" /* Removal of Other Device from Abdominal Wall, Open Approach */
"0WPF30Z" = "1" /* Removal of Drainage Device from Abdominal Wall, Percutaneous Approach */
"0WPF31Z" = "1" /* Removal of Radioactive Element from Abdominal Wall, Percutaneous Approach */
"0WPF33Z" = "1" /* Removal of Infusion Device from Abdominal Wall, Percutaneous Approach */
"0WPF37Z" = "1" /* Removal of Autologous Tissue Substitute from Abdominal Wall, Percutaneous Approach */
"0WPF3JZ" = "1" /* Removal of Synthetic Substitute from Abdominal Wall, Percutaneous Approach */
"0WPF3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Abdominal Wall, Percutaneous Approach */
"0WPF3YZ" = "1" /* Removal of Other Device from Abdominal Wall, Percutaneous Approach */
"0WPF40Z" = "1" /* Removal of Drainage Device from Abdominal Wall, Percutaneous Endoscopic Approach */
"0WPF41Z" = "1" /* Removal of Radioactive Element from Abdominal Wall, Percutaneous Endoscopic Approach */
"0WPF43Z" = "1" /* Removal of Infusion Device from Abdominal Wall, Percutaneous Endoscopic Approach */
"0WPF47Z" = "1" /* Removal of Autologous Tissue Substitute from Abdominal Wall, Percutaneous Endoscopic Approach */
"0WPF4JZ" = "1" /* Removal of Synthetic Substitute from Abdominal Wall, Percutaneous Endoscopic Approach */
"0WPF4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Abdominal Wall, Percutaneous Endoscopic Approach */
"0WPF4YZ" = "1" /* Removal of Other Device from Abdominal Wall, Percutaneous Endoscopic Approach */
"0WPG00Z" = "1" /* Removal of Drainage Device from Peritoneal Cavity, Open Approach */
"0WPG01Z" = "1" /* Removal of Radioactive Element from Peritoneal Cavity, Open Approach */
"0WPG03Z" = "1" /* Removal of Infusion Device from Peritoneal Cavity, Open Approach */
"0WPG0JZ" = "1" /* Removal of Synthetic Substitute from Peritoneal Cavity, Open Approach */
"0WPG0YZ" = "1" /* Removal of Other Device from Peritoneal Cavity, Open Approach */
"0WPG30Z" = "1" /* Removal of Drainage Device from Peritoneal Cavity, Percutaneous Approach */
"0WPG31Z" = "1" /* Removal of Radioactive Element from Peritoneal Cavity, Percutaneous Approach */
"0WPG33Z" = "1" /* Removal of Infusion Device from Peritoneal Cavity, Percutaneous Approach */
"0WPG3JZ" = "1" /* Removal of Synthetic Substitute from Peritoneal Cavity, Percutaneous Approach */
"0WPG3YZ" = "1" /* Removal of Other Device from Peritoneal Cavity, Percutaneous Approach */
"0WPG40Z" = "1" /* Removal of Drainage Device from Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WPG41Z" = "1" /* Removal of Radioactive Element from Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WPG43Z" = "1" /* Removal of Infusion Device from Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WPG4JZ" = "1" /* Removal of Synthetic Substitute from Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WPG4YZ" = "1" /* Removal of Other Device from Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WPH00Z" = "1" /* Removal of Drainage Device from Retroperitoneum, Open Approach */
"0WPH01Z" = "1" /* Removal of Radioactive Element from Retroperitoneum, Open Approach */
"0WPH03Z" = "1" /* Removal of Infusion Device from Retroperitoneum, Open Approach */
"0WPH0YZ" = "1" /* Removal of Other Device from Retroperitoneum, Open Approach */
"0WPH30Z" = "1" /* Removal of Drainage Device from Retroperitoneum, Percutaneous Approach */
"0WPH31Z" = "1" /* Removal of Radioactive Element from Retroperitoneum, Percutaneous Approach */
"0WPH33Z" = "1" /* Removal of Infusion Device from Retroperitoneum, Percutaneous Approach */
"0WPH3YZ" = "1" /* Removal of Other Device from Retroperitoneum, Percutaneous Approach */
"0WPH40Z" = "1" /* Removal of Drainage Device from Retroperitoneum, Percutaneous Endoscopic Approach */
"0WPH41Z" = "1" /* Removal of Radioactive Element from Retroperitoneum, Percutaneous Endoscopic Approach */
"0WPH43Z" = "1" /* Removal of Infusion Device from Retroperitoneum, Percutaneous Endoscopic Approach */
"0WPH4YZ" = "1" /* Removal of Other Device from Retroperitoneum, Percutaneous Endoscopic Approach */
"0WPM07Z" = "1" /* Removal of Autologous Tissue Substitute from Male Perineum, Open Approach */
"0WPM0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Male Perineum, Open Approach */
"0WPM37Z" = "1" /* Removal of Autologous Tissue Substitute from Male Perineum, Percutaneous Approach */
"0WPM3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Male Perineum, Percutaneous Approach */
"0WPM47Z" = "1" /* Removal of Autologous Tissue Substitute from Male Perineum, Percutaneous Endoscopic Approach */
"0WPM4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Male Perineum, Percutaneous Endoscopic Approach */
"0WPMX7Z" = "1" /* Removal of Autologous Tissue Substitute from Male Perineum, External Approach */
"0WPMXJZ" = "1" /* Removal of Synthetic Substitute from Male Perineum, External Approach */
"0WPMXKZ" = "1" /* Removal of Nonautologous Tissue Substitute from Male Perineum, External Approach */
"0WPN00Z" = "1" /* Removal of Drainage Device from Female Perineum, Open Approach */
"0WPN01Z" = "1" /* Removal of Radioactive Element from Female Perineum, Open Approach */
"0WPN03Z" = "1" /* Removal of Infusion Device from Female Perineum, Open Approach */
"0WPN07Z" = "1" /* Removal of Autologous Tissue Substitute from Female Perineum, Open Approach */
"0WPN0JZ" = "1" /* Removal of Synthetic Substitute from Female Perineum, Open Approach */
"0WPN0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Female Perineum, Open Approach */
"0WPN0YZ" = "1" /* Removal of Other Device from Female Perineum, Open Approach */
"0WPN30Z" = "1" /* Removal of Drainage Device from Female Perineum, Percutaneous Approach */
"0WPN31Z" = "1" /* Removal of Radioactive Element from Female Perineum, Percutaneous Approach */
"0WPN33Z" = "1" /* Removal of Infusion Device from Female Perineum, Percutaneous Approach */
"0WPN37Z" = "1" /* Removal of Autologous Tissue Substitute from Female Perineum, Percutaneous Approach */
"0WPN3JZ" = "1" /* Removal of Synthetic Substitute from Female Perineum, Percutaneous Approach */
"0WPN3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Female Perineum, Percutaneous Approach */
"0WPN3YZ" = "1" /* Removal of Other Device from Female Perineum, Percutaneous Approach */
"0WPN40Z" = "1" /* Removal of Drainage Device from Female Perineum, Percutaneous Endoscopic Approach */
"0WPN41Z" = "1" /* Removal of Radioactive Element from Female Perineum, Percutaneous Endoscopic Approach */
"0WPN43Z" = "1" /* Removal of Infusion Device from Female Perineum, Percutaneous Endoscopic Approach */
"0WPN47Z" = "1" /* Removal of Autologous Tissue Substitute from Female Perineum, Percutaneous Endoscopic Approach */
"0WPN4JZ" = "1" /* Removal of Synthetic Substitute from Female Perineum, Percutaneous Endoscopic Approach */
"0WPN4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Female Perineum, Percutaneous Endoscopic Approach */
"0WPN4YZ" = "1" /* Removal of Other Device from Female Perineum, Percutaneous Endoscopic Approach */
"0WPP01Z" = "1" /* Removal of Radioactive Element from Gastrointestinal Tract, Open Approach */
"0WPP03Z" = "1" /* Removal of Infusion Device from Gastrointestinal Tract, Open Approach */
"0WPP0YZ" = "1" /* Removal of Other Device from Gastrointestinal Tract, Open Approach */
"0WPQ31Z" = "1" /* Removal of Radioactive Element from Respiratory Tract, Percutaneous Approach */
"0WPQ33Z" = "1" /* Removal of Infusion Device from Respiratory Tract, Percutaneous Approach */
"0WPQ3YZ" = "1" /* Removal of Other Device from Respiratory Tract, Percutaneous Approach */
"0WPQ41Z" = "1" /* Removal of Radioactive Element from Respiratory Tract, Percutaneous Endoscopic Approach */
"0WPQ43Z" = "1" /* Removal of Infusion Device from Respiratory Tract, Percutaneous Endoscopic Approach */
"0WPQ4YZ" = "1" /* Removal of Other Device from Respiratory Tract, Percutaneous Endoscopic Approach */
"0WPQ71Z" = "1" /* Removal of Radioactive Element from Respiratory Tract, Via Natural or Artificial Opening */
"0WPQ7YZ" = "1" /* Removal of Other Device from Respiratory Tract, Via Natural or Artificial Opening */
"0WPQ81Z" = "1" /* Removal of Radioactive Element from Respiratory Tract, Via Natural or Artificial Opening Endoscopic */
"0WQ00ZZ" = "1" /* Repair Head, Open Approach */
"0WQ03ZZ" = "1" /* Repair Head, Percutaneous Approach */
"0WQ04ZZ" = "1" /* Repair Head, Percutaneous Endoscopic Approach */
"0WQ0XZZ" = "1" /* Repair Head, External Approach */
"0WQ20ZZ" = "1" /* Repair Face, Open Approach */
"0WQ23ZZ" = "1" /* Repair Face, Percutaneous Approach */
"0WQ24ZZ" = "1" /* Repair Face, Percutaneous Endoscopic Approach */
"0WQ2XZZ" = "1" /* Repair Face, External Approach */
"0WQ40ZZ" = "1" /* Repair Upper Jaw, Open Approach */
"0WQ43ZZ" = "1" /* Repair Upper Jaw, Percutaneous Approach */
"0WQ44ZZ" = "1" /* Repair Upper Jaw, Percutaneous Endoscopic Approach */
"0WQ4XZZ" = "1" /* Repair Upper Jaw, External Approach */
"0WQ50ZZ" = "1" /* Repair Lower Jaw, Open Approach */
"0WQ53ZZ" = "1" /* Repair Lower Jaw, Percutaneous Approach */
"0WQ54ZZ" = "1" /* Repair Lower Jaw, Percutaneous Endoscopic Approach */
"0WQ5XZZ" = "1" /* Repair Lower Jaw, External Approach */
"0WQ60ZZ" = "1" /* Repair Neck, Open Approach */
"0WQ63ZZ" = "1" /* Repair Neck, Percutaneous Approach */
"0WQ64ZZ" = "1" /* Repair Neck, Percutaneous Endoscopic Approach */
"0WQ6XZ2" = "1" /* Repair Neck, Stoma, External Approach */
"0WQ6XZZ" = "1" /* Repair Neck, External Approach */
"0WQ80ZZ" = "1" /* Repair Chest Wall, Open Approach */
"0WQ83ZZ" = "1" /* Repair Chest Wall, Percutaneous Approach */
"0WQ84ZZ" = "1" /* Repair Chest Wall, Percutaneous Endoscopic Approach */
"0WQ8XZZ" = "1" /* Repair Chest Wall, External Approach */
"0WQC0ZZ" = "1" /* Repair Mediastinum, Open Approach */
"0WQC3ZZ" = "1" /* Repair Mediastinum, Percutaneous Approach */
"0WQC4ZZ" = "1" /* Repair Mediastinum, Percutaneous Endoscopic Approach */
"0WQF0ZZ" = "1" /* Repair Abdominal Wall, Open Approach */
"0WQF3ZZ" = "1" /* Repair Abdominal Wall, Percutaneous Approach */
"0WQF4ZZ" = "1" /* Repair Abdominal Wall, Percutaneous Endoscopic Approach */
"0WQFXZ2" = "1" /* Repair Abdominal Wall, Stoma, External Approach */
"0WQFXZZ" = "1" /* Repair Abdominal Wall, External Approach */
"0WQK0ZZ" = "1" /* Repair Upper Back, Open Approach */
"0WQK3ZZ" = "1" /* Repair Upper Back, Percutaneous Approach */
"0WQK4ZZ" = "1" /* Repair Upper Back, Percutaneous Endoscopic Approach */
"0WQKXZZ" = "1" /* Repair Upper Back, External Approach */
"0WQL0ZZ" = "1" /* Repair Lower Back, Open Approach */
"0WQL3ZZ" = "1" /* Repair Lower Back, Percutaneous Approach */
"0WQL4ZZ" = "1" /* Repair Lower Back, Percutaneous Endoscopic Approach */
"0WQLXZZ" = "1" /* Repair Lower Back, External Approach */
"0WQM0ZZ" = "1" /* Repair Male Perineum, Open Approach */
"0WQM3ZZ" = "1" /* Repair Male Perineum, Percutaneous Approach */
"0WQM4ZZ" = "1" /* Repair Male Perineum, Percutaneous Endoscopic Approach */
"0WQMXZZ" = "1" /* Repair Male Perineum, External Approach */
"0WQN0ZZ" = "1" /* Repair Female Perineum, Open Approach */
"0WQN3ZZ" = "1" /* Repair Female Perineum, Percutaneous Approach */
"0WQN4ZZ" = "1" /* Repair Female Perineum, Percutaneous Endoscopic Approach */
"0WU007Z" = "1" /* Supplement Head with Autologous Tissue Substitute, Open Approach */
"0WU00JZ" = "1" /* Supplement Head with Synthetic Substitute, Open Approach */
"0WU00KZ" = "1" /* Supplement Head with Nonautologous Tissue Substitute, Open Approach */
"0WU047Z" = "1" /* Supplement Head with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WU04JZ" = "1" /* Supplement Head with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0WU04KZ" = "1" /* Supplement Head with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WU207Z" = "1" /* Supplement Face with Autologous Tissue Substitute, Open Approach */
"0WU20JZ" = "1" /* Supplement Face with Synthetic Substitute, Open Approach */
"0WU20KZ" = "1" /* Supplement Face with Nonautologous Tissue Substitute, Open Approach */
"0WU247Z" = "1" /* Supplement Face with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WU24JZ" = "1" /* Supplement Face with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0WU24KZ" = "1" /* Supplement Face with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WU407Z" = "1" /* Supplement Upper Jaw with Autologous Tissue Substitute, Open Approach */
"0WU40JZ" = "1" /* Supplement Upper Jaw with Synthetic Substitute, Open Approach */
"0WU40KZ" = "1" /* Supplement Upper Jaw with Nonautologous Tissue Substitute, Open Approach */
"0WU447Z" = "1" /* Supplement Upper Jaw with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WU44JZ" = "1" /* Supplement Upper Jaw with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0WU44KZ" = "1" /* Supplement Upper Jaw with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WU507Z" = "1" /* Supplement Lower Jaw with Autologous Tissue Substitute, Open Approach */
"0WU50JZ" = "1" /* Supplement Lower Jaw with Synthetic Substitute, Open Approach */
"0WU50KZ" = "1" /* Supplement Lower Jaw with Nonautologous Tissue Substitute, Open Approach */
"0WU547Z" = "1" /* Supplement Lower Jaw with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WU54JZ" = "1" /* Supplement Lower Jaw with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0WU54KZ" = "1" /* Supplement Lower Jaw with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WU607Z" = "1" /* Supplement Neck with Autologous Tissue Substitute, Open Approach */
"0WU60JZ" = "1" /* Supplement Neck with Synthetic Substitute, Open Approach */
"0WU60KZ" = "1" /* Supplement Neck with Nonautologous Tissue Substitute, Open Approach */
"0WU647Z" = "1" /* Supplement Neck with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WU64JZ" = "1" /* Supplement Neck with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0WU64KZ" = "1" /* Supplement Neck with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WU807Z" = "1" /* Supplement Chest Wall with Autologous Tissue Substitute, Open Approach */
"0WU80JZ" = "1" /* Supplement Chest Wall with Synthetic Substitute, Open Approach */
"0WU80KZ" = "1" /* Supplement Chest Wall with Nonautologous Tissue Substitute, Open Approach */
"0WU847Z" = "1" /* Supplement Chest Wall with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WU84JZ" = "1" /* Supplement Chest Wall with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0WU84KZ" = "1" /* Supplement Chest Wall with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WUC07Z" = "1" /* Supplement Mediastinum with Autologous Tissue Substitute, Open Approach */
"0WUC0JZ" = "1" /* Supplement Mediastinum with Synthetic Substitute, Open Approach */
"0WUC0KZ" = "1" /* Supplement Mediastinum with Nonautologous Tissue Substitute, Open Approach */
"0WUC47Z" = "1" /* Supplement Mediastinum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WUC4JZ" = "1" /* Supplement Mediastinum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0WUC4KZ" = "1" /* Supplement Mediastinum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WUF07Z" = "1" /* Supplement Abdominal Wall with Autologous Tissue Substitute, Open Approach */
"0WUF0JZ" = "1" /* Supplement Abdominal Wall with Synthetic Substitute, Open Approach */
"0WUF0KZ" = "1" /* Supplement Abdominal Wall with Nonautologous Tissue Substitute, Open Approach */
"0WUF47Z" = "1" /* Supplement Abdominal Wall with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WUF4JZ" = "1" /* Supplement Abdominal Wall with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0WUF4KZ" = "1" /* Supplement Abdominal Wall with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WUK07Z" = "1" /* Supplement Upper Back with Autologous Tissue Substitute, Open Approach */
"0WUK0JZ" = "1" /* Supplement Upper Back with Synthetic Substitute, Open Approach */
"0WUK0KZ" = "1" /* Supplement Upper Back with Nonautologous Tissue Substitute, Open Approach */
"0WUK47Z" = "1" /* Supplement Upper Back with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WUK4JZ" = "1" /* Supplement Upper Back with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0WUK4KZ" = "1" /* Supplement Upper Back with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WUL07Z" = "1" /* Supplement Lower Back with Autologous Tissue Substitute, Open Approach */
"0WUL0JZ" = "1" /* Supplement Lower Back with Synthetic Substitute, Open Approach */
"0WUL0KZ" = "1" /* Supplement Lower Back with Nonautologous Tissue Substitute, Open Approach */
"0WUL47Z" = "1" /* Supplement Lower Back with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WUL4JZ" = "1" /* Supplement Lower Back with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0WUL4KZ" = "1" /* Supplement Lower Back with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WUM07Z" = "1" /* Supplement Male Perineum with Autologous Tissue Substitute, Open Approach */
"0WUM0JZ" = "1" /* Supplement Male Perineum with Synthetic Substitute, Open Approach */
"0WUM0KZ" = "1" /* Supplement Male Perineum with Nonautologous Tissue Substitute, Open Approach */
"0WUM47Z" = "1" /* Supplement Male Perineum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WUM4JZ" = "1" /* Supplement Male Perineum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0WUM4KZ" = "1" /* Supplement Male Perineum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WUN07Z" = "1" /* Supplement Female Perineum with Autologous Tissue Substitute, Open Approach */
"0WUN0JZ" = "1" /* Supplement Female Perineum with Synthetic Substitute, Open Approach */
"0WUN0KZ" = "1" /* Supplement Female Perineum with Nonautologous Tissue Substitute, Open Approach */
"0WUN47Z" = "1" /* Supplement Female Perineum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WUN4JZ" = "1" /* Supplement Female Perineum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0WUN4KZ" = "1" /* Supplement Female Perineum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WW100Z" = "1" /* Revision of Drainage Device in Cranial Cavity, Open Approach */
"0WW101Z" = "1" /* Revision of Radioactive Element in Cranial Cavity, Open Approach */
"0WW103Z" = "1" /* Revision of Infusion Device in Cranial Cavity, Open Approach */
"0WW10JZ" = "1" /* Revision of Synthetic Substitute in Cranial Cavity, Open Approach */
"0WW10YZ" = "1" /* Revision of Other Device in Cranial Cavity, Open Approach */
"0WW130Z" = "1" /* Revision of Drainage Device in Cranial Cavity, Percutaneous Approach */
"0WW131Z" = "1" /* Revision of Radioactive Element in Cranial Cavity, Percutaneous Approach */
"0WW133Z" = "1" /* Revision of Infusion Device in Cranial Cavity, Percutaneous Approach */
"0WW13JZ" = "1" /* Revision of Synthetic Substitute in Cranial Cavity, Percutaneous Approach */
"0WW13YZ" = "1" /* Revision of Other Device in Cranial Cavity, Percutaneous Approach */
"0WW140Z" = "1" /* Revision of Drainage Device in Cranial Cavity, Percutaneous Endoscopic Approach */
"0WW141Z" = "1" /* Revision of Radioactive Element in Cranial Cavity, Percutaneous Endoscopic Approach */
"0WW143Z" = "1" /* Revision of Infusion Device in Cranial Cavity, Percutaneous Endoscopic Approach */
"0WW14JZ" = "1" /* Revision of Synthetic Substitute in Cranial Cavity, Percutaneous Endoscopic Approach */
"0WW14YZ" = "1" /* Revision of Other Device in Cranial Cavity, Percutaneous Endoscopic Approach */
"0WWC00Z" = "1" /* Revision of Drainage Device in Mediastinum, Open Approach */
"0WWC01Z" = "1" /* Revision of Radioactive Element in Mediastinum, Open Approach */
"0WWC03Z" = "1" /* Revision of Infusion Device in Mediastinum, Open Approach */
"0WWC07Z" = "1" /* Revision of Autologous Tissue Substitute in Mediastinum, Open Approach */
"0WWC0JZ" = "1" /* Revision of Synthetic Substitute in Mediastinum, Open Approach */
"0WWC0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mediastinum, Open Approach */
"0WWC0YZ" = "1" /* Revision of Other Device in Mediastinum, Open Approach */
"0WWC30Z" = "1" /* Revision of Drainage Device in Mediastinum, Percutaneous Approach */
"0WWC31Z" = "1" /* Revision of Radioactive Element in Mediastinum, Percutaneous Approach */
"0WWC33Z" = "1" /* Revision of Infusion Device in Mediastinum, Percutaneous Approach */
"0WWC37Z" = "1" /* Revision of Autologous Tissue Substitute in Mediastinum, Percutaneous Approach */
"0WWC3JZ" = "1" /* Revision of Synthetic Substitute in Mediastinum, Percutaneous Approach */
"0WWC3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mediastinum, Percutaneous Approach */
"0WWC3YZ" = "1" /* Revision of Other Device in Mediastinum, Percutaneous Approach */
"0WWC40Z" = "1" /* Revision of Drainage Device in Mediastinum, Percutaneous Endoscopic Approach */
"0WWC41Z" = "1" /* Revision of Radioactive Element in Mediastinum, Percutaneous Endoscopic Approach */
"0WWC43Z" = "1" /* Revision of Infusion Device in Mediastinum, Percutaneous Endoscopic Approach */
"0WWC47Z" = "1" /* Revision of Autologous Tissue Substitute in Mediastinum, Percutaneous Endoscopic Approach */
"0WWC4JZ" = "1" /* Revision of Synthetic Substitute in Mediastinum, Percutaneous Endoscopic Approach */
"0WWC4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mediastinum, Percutaneous Endoscopic Approach */
"0WWC4YZ" = "1" /* Revision of Other Device in Mediastinum, Percutaneous Endoscopic Approach */
"0WWD00Z" = "1" /* Revision of Drainage Device in Pericardial Cavity, Open Approach */
"0WWD01Z" = "1" /* Revision of Radioactive Element in Pericardial Cavity, Open Approach */
"0WWD03Z" = "1" /* Revision of Infusion Device in Pericardial Cavity, Open Approach */
"0WWD0YZ" = "1" /* Revision of Other Device in Pericardial Cavity, Open Approach */
"0WWD30Z" = "1" /* Revision of Drainage Device in Pericardial Cavity, Percutaneous Approach */
"0WWD31Z" = "1" /* Revision of Radioactive Element in Pericardial Cavity, Percutaneous Approach */
"0WWD33Z" = "1" /* Revision of Infusion Device in Pericardial Cavity, Percutaneous Approach */
"0WWD3YZ" = "1" /* Revision of Other Device in Pericardial Cavity, Percutaneous Approach */
"0WWD40Z" = "1" /* Revision of Drainage Device in Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WWD41Z" = "1" /* Revision of Radioactive Element in Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WWD43Z" = "1" /* Revision of Infusion Device in Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WWD4YZ" = "1" /* Revision of Other Device in Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WWF00Z" = "1" /* Revision of Drainage Device in Abdominal Wall, Open Approach */
"0WWF01Z" = "1" /* Revision of Radioactive Element in Abdominal Wall, Open Approach */
"0WWF03Z" = "1" /* Revision of Infusion Device in Abdominal Wall, Open Approach */
"0WWF07Z" = "1" /* Revision of Autologous Tissue Substitute in Abdominal Wall, Open Approach */
"0WWF0JZ" = "1" /* Revision of Synthetic Substitute in Abdominal Wall, Open Approach */
"0WWF0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Abdominal Wall, Open Approach */
"0WWF0YZ" = "1" /* Revision of Other Device in Abdominal Wall, Open Approach */
"0WWF30Z" = "1" /* Revision of Drainage Device in Abdominal Wall, Percutaneous Approach */
"0WWF31Z" = "1" /* Revision of Radioactive Element in Abdominal Wall, Percutaneous Approach */
"0WWF33Z" = "1" /* Revision of Infusion Device in Abdominal Wall, Percutaneous Approach */
"0WWF37Z" = "1" /* Revision of Autologous Tissue Substitute in Abdominal Wall, Percutaneous Approach */
"0WWF3JZ" = "1" /* Revision of Synthetic Substitute in Abdominal Wall, Percutaneous Approach */
"0WWF3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Abdominal Wall, Percutaneous Approach */
"0WWF3YZ" = "1" /* Revision of Other Device in Abdominal Wall, Percutaneous Approach */
"0WWF40Z" = "1" /* Revision of Drainage Device in Abdominal Wall, Percutaneous Endoscopic Approach */
"0WWF41Z" = "1" /* Revision of Radioactive Element in Abdominal Wall, Percutaneous Endoscopic Approach */
"0WWF43Z" = "1" /* Revision of Infusion Device in Abdominal Wall, Percutaneous Endoscopic Approach */
"0WWF47Z" = "1" /* Revision of Autologous Tissue Substitute in Abdominal Wall, Percutaneous Endoscopic Approach */
"0WWF4JZ" = "1" /* Revision of Synthetic Substitute in Abdominal Wall, Percutaneous Endoscopic Approach */
"0WWF4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Abdominal Wall, Percutaneous Endoscopic Approach */
"0WWF4YZ" = "1" /* Revision of Other Device in Abdominal Wall, Percutaneous Endoscopic Approach */
"0WWG00Z" = "1" /* Revision of Drainage Device in Peritoneal Cavity, Open Approach */
"0WWG01Z" = "1" /* Revision of Radioactive Element in Peritoneal Cavity, Open Approach */
"0WWG03Z" = "1" /* Revision of Infusion Device in Peritoneal Cavity, Open Approach */
"0WWG0JZ" = "1" /* Revision of Synthetic Substitute in Peritoneal Cavity, Open Approach */
"0WWG0YZ" = "1" /* Revision of Other Device in Peritoneal Cavity, Open Approach */
"0WWG30Z" = "1" /* Revision of Drainage Device in Peritoneal Cavity, Percutaneous Approach */
"0WWG31Z" = "1" /* Revision of Radioactive Element in Peritoneal Cavity, Percutaneous Approach */
"0WWG33Z" = "1" /* Revision of Infusion Device in Peritoneal Cavity, Percutaneous Approach */
"0WWG3JZ" = "1" /* Revision of Synthetic Substitute in Peritoneal Cavity, Percutaneous Approach */
"0WWG3YZ" = "1" /* Revision of Other Device in Peritoneal Cavity, Percutaneous Approach */
"0WWG40Z" = "1" /* Revision of Drainage Device in Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WWG41Z" = "1" /* Revision of Radioactive Element in Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WWG43Z" = "1" /* Revision of Infusion Device in Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WWG4JZ" = "1" /* Revision of Synthetic Substitute in Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WWG4YZ" = "1" /* Revision of Other Device in Peritoneal Cavity, Percutaneous Endoscopic Approach */
"0WWH00Z" = "1" /* Revision of Drainage Device in Retroperitoneum, Open Approach */
"0WWH01Z" = "1" /* Revision of Radioactive Element in Retroperitoneum, Open Approach */
"0WWH03Z" = "1" /* Revision of Infusion Device in Retroperitoneum, Open Approach */
"0WWH0YZ" = "1" /* Revision of Other Device in Retroperitoneum, Open Approach */
"0WWH30Z" = "1" /* Revision of Drainage Device in Retroperitoneum, Percutaneous Approach */
"0WWH31Z" = "1" /* Revision of Radioactive Element in Retroperitoneum, Percutaneous Approach */
"0WWH33Z" = "1" /* Revision of Infusion Device in Retroperitoneum, Percutaneous Approach */
"0WWH3YZ" = "1" /* Revision of Other Device in Retroperitoneum, Percutaneous Approach */
"0WWH40Z" = "1" /* Revision of Drainage Device in Retroperitoneum, Percutaneous Endoscopic Approach */
"0WWH41Z" = "1" /* Revision of Radioactive Element in Retroperitoneum, Percutaneous Endoscopic Approach */
"0WWH43Z" = "1" /* Revision of Infusion Device in Retroperitoneum, Percutaneous Endoscopic Approach */
"0WWH4YZ" = "1" /* Revision of Other Device in Retroperitoneum, Percutaneous Endoscopic Approach */
"0WWJ00Z" = "1" /* Revision of Drainage Device in Pelvic Cavity, Open Approach */
"0WWJ01Z" = "1" /* Revision of Radioactive Element in Pelvic Cavity, Open Approach */
"0WWJ03Z" = "1" /* Revision of Infusion Device in Pelvic Cavity, Open Approach */
"0WWJ0JZ" = "1" /* Revision of Synthetic Substitute in Pelvic Cavity, Open Approach */
"0WWJ0YZ" = "1" /* Revision of Other Device in Pelvic Cavity, Open Approach */
"0WWJ30Z" = "1" /* Revision of Drainage Device in Pelvic Cavity, Percutaneous Approach */
"0WWJ31Z" = "1" /* Revision of Radioactive Element in Pelvic Cavity, Percutaneous Approach */
"0WWJ33Z" = "1" /* Revision of Infusion Device in Pelvic Cavity, Percutaneous Approach */
"0WWJ3JZ" = "1" /* Revision of Synthetic Substitute in Pelvic Cavity, Percutaneous Approach */
"0WWJ3YZ" = "1" /* Revision of Other Device in Pelvic Cavity, Percutaneous Approach */
"0WWJ40Z" = "1" /* Revision of Drainage Device in Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WWJ41Z" = "1" /* Revision of Radioactive Element in Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WWJ43Z" = "1" /* Revision of Infusion Device in Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WWJ4JZ" = "1" /* Revision of Synthetic Substitute in Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WWJ4YZ" = "1" /* Revision of Other Device in Pelvic Cavity, Percutaneous Endoscopic Approach */
"0WWM07Z" = "1" /* Revision of Autologous Tissue Substitute in Male Perineum, Open Approach */
"0WWM0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Male Perineum, Open Approach */
"0WWM37Z" = "1" /* Revision of Autologous Tissue Substitute in Male Perineum, Percutaneous Approach */
"0WWM3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Male Perineum, Percutaneous Approach */
"0WWM47Z" = "1" /* Revision of Autologous Tissue Substitute in Male Perineum, Percutaneous Endoscopic Approach */
"0WWM4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Male Perineum, Percutaneous Endoscopic Approach */
"0WWN00Z" = "1" /* Revision of Drainage Device in Female Perineum, Open Approach */
"0WWN01Z" = "1" /* Revision of Radioactive Element in Female Perineum, Open Approach */
"0WWN03Z" = "1" /* Revision of Infusion Device in Female Perineum, Open Approach */
"0WWN07Z" = "1" /* Revision of Autologous Tissue Substitute in Female Perineum, Open Approach */
"0WWN0JZ" = "1" /* Revision of Synthetic Substitute in Female Perineum, Open Approach */
"0WWN0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Female Perineum, Open Approach */
"0WWN0YZ" = "1" /* Revision of Other Device in Female Perineum, Open Approach */
"0WWN30Z" = "1" /* Revision of Drainage Device in Female Perineum, Percutaneous Approach */
"0WWN31Z" = "1" /* Revision of Radioactive Element in Female Perineum, Percutaneous Approach */
"0WWN33Z" = "1" /* Revision of Infusion Device in Female Perineum, Percutaneous Approach */
"0WWN37Z" = "1" /* Revision of Autologous Tissue Substitute in Female Perineum, Percutaneous Approach */
"0WWN3JZ" = "1" /* Revision of Synthetic Substitute in Female Perineum, Percutaneous Approach */
"0WWN3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Female Perineum, Percutaneous Approach */
"0WWN3YZ" = "1" /* Revision of Other Device in Female Perineum, Percutaneous Approach */
"0WWN40Z" = "1" /* Revision of Drainage Device in Female Perineum, Percutaneous Endoscopic Approach */
"0WWN41Z" = "1" /* Revision of Radioactive Element in Female Perineum, Percutaneous Endoscopic Approach */
"0WWN43Z" = "1" /* Revision of Infusion Device in Female Perineum, Percutaneous Endoscopic Approach */
"0WWN47Z" = "1" /* Revision of Autologous Tissue Substitute in Female Perineum, Percutaneous Endoscopic Approach */
"0WWN4JZ" = "1" /* Revision of Synthetic Substitute in Female Perineum, Percutaneous Endoscopic Approach */
"0WWN4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Female Perineum, Percutaneous Endoscopic Approach */
"0WWN4YZ" = "1" /* Revision of Other Device in Female Perineum, Percutaneous Endoscopic Approach */
"0WWP01Z" = "1" /* Revision of Radioactive Element in Gastrointestinal Tract, Open Approach */
"0WWP03Z" = "1" /* Revision of Infusion Device in Gastrointestinal Tract, Open Approach */
"0WWP0YZ" = "1" /* Revision of Other Device in Gastrointestinal Tract, Open Approach */
"0WWQ31Z" = "1" /* Revision of Radioactive Element in Respiratory Tract, Percutaneous Approach */
"0WWQ33Z" = "1" /* Revision of Infusion Device in Respiratory Tract, Percutaneous Approach */
"0WWQ3YZ" = "1" /* Revision of Other Device in Respiratory Tract, Percutaneous Approach */
"0WWQ41Z" = "1" /* Revision of Radioactive Element in Respiratory Tract, Percutaneous Endoscopic Approach */
"0WWQ43Z" = "1" /* Revision of Infusion Device in Respiratory Tract, Percutaneous Endoscopic Approach */
"0WWQ4YZ" = "1" /* Revision of Other Device in Respiratory Tract, Percutaneous Endoscopic Approach */
"0WWQ71Z" = "1" /* Revision of Radioactive Element in Respiratory Tract, Via Natural or Artificial Opening */
"0WWQ73Z" = "1" /* Revision of Infusion Device in Respiratory Tract, Via Natural or Artificial Opening */
"0WWQ7YZ" = "1" /* Revision of Other Device in Respiratory Tract, Via Natural or Artificial Opening */
"0WWQ81Z" = "1" /* Revision of Radioactive Element in Respiratory Tract, Via Natural or Artificial Opening Endoscopic */
"0WWQ83Z" = "1" /* Revision of Infusion Device in Respiratory Tract, Via Natural or Artificial Opening Endoscopic */
"0WWQ8YZ" = "1" /* Revision of Other Device in Respiratory Tract, Via Natural or Artificial Opening Endoscopic */
"0WY20Z0" = "1" /* Transplantation of Face, Allogeneic, Open Approach */
"0WY20Z1" = "1" /* Transplantation of Face, Syngeneic, Open Approach */
"0X0207Z" = "1" /* Alteration of Right Shoulder Region with Autologous Tissue Substitute, Open Approach */
"0X020JZ" = "1" /* Alteration of Right Shoulder Region with Synthetic Substitute, Open Approach */
"0X020KZ" = "1" /* Alteration of Right Shoulder Region with Nonautologous Tissue Substitute, Open Approach */
"0X020ZZ" = "1" /* Alteration of Right Shoulder Region, Open Approach */
"0X0237Z" = "1" /* Alteration of Right Shoulder Region with Autologous Tissue Substitute, Percutaneous Approach */
"0X023JZ" = "1" /* Alteration of Right Shoulder Region with Synthetic Substitute, Percutaneous Approach */
"0X023KZ" = "1" /* Alteration of Right Shoulder Region with Nonautologous Tissue Substitute, Percutaneous Approach */
"0X023ZZ" = "1" /* Alteration of Right Shoulder Region, Percutaneous Approach */
"0X0247Z" = "1" /* Alteration of Right Shoulder Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X024JZ" = "1" /* Alteration of Right Shoulder Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0X024KZ" = "1" /* Alteration of Right Shoulder Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X024ZZ" = "1" /* Alteration of Right Shoulder Region, Percutaneous Endoscopic Approach */
"0X0307Z" = "1" /* Alteration of Left Shoulder Region with Autologous Tissue Substitute, Open Approach */
"0X030JZ" = "1" /* Alteration of Left Shoulder Region with Synthetic Substitute, Open Approach */
"0X030KZ" = "1" /* Alteration of Left Shoulder Region with Nonautologous Tissue Substitute, Open Approach */
"0X030ZZ" = "1" /* Alteration of Left Shoulder Region, Open Approach */
"0X0337Z" = "1" /* Alteration of Left Shoulder Region with Autologous Tissue Substitute, Percutaneous Approach */
"0X033JZ" = "1" /* Alteration of Left Shoulder Region with Synthetic Substitute, Percutaneous Approach */
"0X033KZ" = "1" /* Alteration of Left Shoulder Region with Nonautologous Tissue Substitute, Percutaneous Approach */
"0X033ZZ" = "1" /* Alteration of Left Shoulder Region, Percutaneous Approach */
"0X0347Z" = "1" /* Alteration of Left Shoulder Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X034JZ" = "1" /* Alteration of Left Shoulder Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0X034KZ" = "1" /* Alteration of Left Shoulder Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X034ZZ" = "1" /* Alteration of Left Shoulder Region, Percutaneous Endoscopic Approach */
"0X0407Z" = "1" /* Alteration of Right Axilla with Autologous Tissue Substitute, Open Approach */
"0X040JZ" = "1" /* Alteration of Right Axilla with Synthetic Substitute, Open Approach */
"0X040KZ" = "1" /* Alteration of Right Axilla with Nonautologous Tissue Substitute, Open Approach */
"0X040ZZ" = "1" /* Alteration of Right Axilla, Open Approach */
"0X0437Z" = "1" /* Alteration of Right Axilla with Autologous Tissue Substitute, Percutaneous Approach */
"0X043JZ" = "1" /* Alteration of Right Axilla with Synthetic Substitute, Percutaneous Approach */
"0X043KZ" = "1" /* Alteration of Right Axilla with Nonautologous Tissue Substitute, Percutaneous Approach */
"0X043ZZ" = "1" /* Alteration of Right Axilla, Percutaneous Approach */
"0X0447Z" = "1" /* Alteration of Right Axilla with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X044JZ" = "1" /* Alteration of Right Axilla with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0X044KZ" = "1" /* Alteration of Right Axilla with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X044ZZ" = "1" /* Alteration of Right Axilla, Percutaneous Endoscopic Approach */
"0X0507Z" = "1" /* Alteration of Left Axilla with Autologous Tissue Substitute, Open Approach */
"0X050JZ" = "1" /* Alteration of Left Axilla with Synthetic Substitute, Open Approach */
"0X050KZ" = "1" /* Alteration of Left Axilla with Nonautologous Tissue Substitute, Open Approach */
"0X050ZZ" = "1" /* Alteration of Left Axilla, Open Approach */
"0X0537Z" = "1" /* Alteration of Left Axilla with Autologous Tissue Substitute, Percutaneous Approach */
"0X053JZ" = "1" /* Alteration of Left Axilla with Synthetic Substitute, Percutaneous Approach */
"0X053KZ" = "1" /* Alteration of Left Axilla with Nonautologous Tissue Substitute, Percutaneous Approach */
"0X053ZZ" = "1" /* Alteration of Left Axilla, Percutaneous Approach */
"0X0547Z" = "1" /* Alteration of Left Axilla with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X054JZ" = "1" /* Alteration of Left Axilla with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0X054KZ" = "1" /* Alteration of Left Axilla with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X054ZZ" = "1" /* Alteration of Left Axilla, Percutaneous Endoscopic Approach */
"0X0607Z" = "1" /* Alteration of Right Upper Extremity with Autologous Tissue Substitute, Open Approach */
"0X060JZ" = "1" /* Alteration of Right Upper Extremity with Synthetic Substitute, Open Approach */
"0X060KZ" = "1" /* Alteration of Right Upper Extremity with Nonautologous Tissue Substitute, Open Approach */
"0X060ZZ" = "1" /* Alteration of Right Upper Extremity, Open Approach */
"0X0637Z" = "1" /* Alteration of Right Upper Extremity with Autologous Tissue Substitute, Percutaneous Approach */
"0X063JZ" = "1" /* Alteration of Right Upper Extremity with Synthetic Substitute, Percutaneous Approach */
"0X063KZ" = "1" /* Alteration of Right Upper Extremity with Nonautologous Tissue Substitute, Percutaneous Approach */
"0X063ZZ" = "1" /* Alteration of Right Upper Extremity, Percutaneous Approach */
"0X0647Z" = "1" /* Alteration of Right Upper Extremity with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X064JZ" = "1" /* Alteration of Right Upper Extremity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0X064KZ" = "1" /* Alteration of Right Upper Extremity with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X064ZZ" = "1" /* Alteration of Right Upper Extremity, Percutaneous Endoscopic Approach */
"0X0707Z" = "1" /* Alteration of Left Upper Extremity with Autologous Tissue Substitute, Open Approach */
"0X070JZ" = "1" /* Alteration of Left Upper Extremity with Synthetic Substitute, Open Approach */
"0X070KZ" = "1" /* Alteration of Left Upper Extremity with Nonautologous Tissue Substitute, Open Approach */
"0X070ZZ" = "1" /* Alteration of Left Upper Extremity, Open Approach */
"0X0737Z" = "1" /* Alteration of Left Upper Extremity with Autologous Tissue Substitute, Percutaneous Approach */
"0X073JZ" = "1" /* Alteration of Left Upper Extremity with Synthetic Substitute, Percutaneous Approach */
"0X073KZ" = "1" /* Alteration of Left Upper Extremity with Nonautologous Tissue Substitute, Percutaneous Approach */
"0X073ZZ" = "1" /* Alteration of Left Upper Extremity, Percutaneous Approach */
"0X0747Z" = "1" /* Alteration of Left Upper Extremity with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X074JZ" = "1" /* Alteration of Left Upper Extremity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0X074KZ" = "1" /* Alteration of Left Upper Extremity with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X074ZZ" = "1" /* Alteration of Left Upper Extremity, Percutaneous Endoscopic Approach */
"0X0807Z" = "1" /* Alteration of Right Upper Arm with Autologous Tissue Substitute, Open Approach */
"0X080JZ" = "1" /* Alteration of Right Upper Arm with Synthetic Substitute, Open Approach */
"0X080KZ" = "1" /* Alteration of Right Upper Arm with Nonautologous Tissue Substitute, Open Approach */
"0X080ZZ" = "1" /* Alteration of Right Upper Arm, Open Approach */
"0X0837Z" = "1" /* Alteration of Right Upper Arm with Autologous Tissue Substitute, Percutaneous Approach */
"0X083JZ" = "1" /* Alteration of Right Upper Arm with Synthetic Substitute, Percutaneous Approach */
"0X083KZ" = "1" /* Alteration of Right Upper Arm with Nonautologous Tissue Substitute, Percutaneous Approach */
"0X083ZZ" = "1" /* Alteration of Right Upper Arm, Percutaneous Approach */
"0X0847Z" = "1" /* Alteration of Right Upper Arm with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X084JZ" = "1" /* Alteration of Right Upper Arm with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0X084KZ" = "1" /* Alteration of Right Upper Arm with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X084ZZ" = "1" /* Alteration of Right Upper Arm, Percutaneous Endoscopic Approach */
"0X0907Z" = "1" /* Alteration of Left Upper Arm with Autologous Tissue Substitute, Open Approach */
"0X090JZ" = "1" /* Alteration of Left Upper Arm with Synthetic Substitute, Open Approach */
"0X090KZ" = "1" /* Alteration of Left Upper Arm with Nonautologous Tissue Substitute, Open Approach */
"0X090ZZ" = "1" /* Alteration of Left Upper Arm, Open Approach */
"0X0937Z" = "1" /* Alteration of Left Upper Arm with Autologous Tissue Substitute, Percutaneous Approach */
"0X093JZ" = "1" /* Alteration of Left Upper Arm with Synthetic Substitute, Percutaneous Approach */
"0X093KZ" = "1" /* Alteration of Left Upper Arm with Nonautologous Tissue Substitute, Percutaneous Approach */
"0X093ZZ" = "1" /* Alteration of Left Upper Arm, Percutaneous Approach */
"0X0947Z" = "1" /* Alteration of Left Upper Arm with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X094JZ" = "1" /* Alteration of Left Upper Arm with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0X094KZ" = "1" /* Alteration of Left Upper Arm with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X094ZZ" = "1" /* Alteration of Left Upper Arm, Percutaneous Endoscopic Approach */
"0X0B07Z" = "1" /* Alteration of Right Elbow Region with Autologous Tissue Substitute, Open Approach */
"0X0B0JZ" = "1" /* Alteration of Right Elbow Region with Synthetic Substitute, Open Approach */
"0X0B0KZ" = "1" /* Alteration of Right Elbow Region with Nonautologous Tissue Substitute, Open Approach */
"0X0B0ZZ" = "1" /* Alteration of Right Elbow Region, Open Approach */
"0X0B37Z" = "1" /* Alteration of Right Elbow Region with Autologous Tissue Substitute, Percutaneous Approach */
"0X0B3JZ" = "1" /* Alteration of Right Elbow Region with Synthetic Substitute, Percutaneous Approach */
"0X0B3KZ" = "1" /* Alteration of Right Elbow Region with Nonautologous Tissue Substitute, Percutaneous Approach */
"0X0B3ZZ" = "1" /* Alteration of Right Elbow Region, Percutaneous Approach */
"0X0B47Z" = "1" /* Alteration of Right Elbow Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X0B4JZ" = "1" /* Alteration of Right Elbow Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0X0B4KZ" = "1" /* Alteration of Right Elbow Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X0B4ZZ" = "1" /* Alteration of Right Elbow Region, Percutaneous Endoscopic Approach */
"0X0C07Z" = "1" /* Alteration of Left Elbow Region with Autologous Tissue Substitute, Open Approach */
"0X0C0JZ" = "1" /* Alteration of Left Elbow Region with Synthetic Substitute, Open Approach */
"0X0C0KZ" = "1" /* Alteration of Left Elbow Region with Nonautologous Tissue Substitute, Open Approach */
"0X0C0ZZ" = "1" /* Alteration of Left Elbow Region, Open Approach */
"0X0C37Z" = "1" /* Alteration of Left Elbow Region with Autologous Tissue Substitute, Percutaneous Approach */
"0X0C3JZ" = "1" /* Alteration of Left Elbow Region with Synthetic Substitute, Percutaneous Approach */
"0X0C3KZ" = "1" /* Alteration of Left Elbow Region with Nonautologous Tissue Substitute, Percutaneous Approach */
"0X0C3ZZ" = "1" /* Alteration of Left Elbow Region, Percutaneous Approach */
"0X0C47Z" = "1" /* Alteration of Left Elbow Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X0C4JZ" = "1" /* Alteration of Left Elbow Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0X0C4KZ" = "1" /* Alteration of Left Elbow Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X0C4ZZ" = "1" /* Alteration of Left Elbow Region, Percutaneous Endoscopic Approach */
"0X0D07Z" = "1" /* Alteration of Right Lower Arm with Autologous Tissue Substitute, Open Approach */
"0X0D0JZ" = "1" /* Alteration of Right Lower Arm with Synthetic Substitute, Open Approach */
"0X0D0KZ" = "1" /* Alteration of Right Lower Arm with Nonautologous Tissue Substitute, Open Approach */
"0X0D0ZZ" = "1" /* Alteration of Right Lower Arm, Open Approach */
"0X0D37Z" = "1" /* Alteration of Right Lower Arm with Autologous Tissue Substitute, Percutaneous Approach */
"0X0D3JZ" = "1" /* Alteration of Right Lower Arm with Synthetic Substitute, Percutaneous Approach */
"0X0D3KZ" = "1" /* Alteration of Right Lower Arm with Nonautologous Tissue Substitute, Percutaneous Approach */
"0X0D3ZZ" = "1" /* Alteration of Right Lower Arm, Percutaneous Approach */
"0X0D47Z" = "1" /* Alteration of Right Lower Arm with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X0D4JZ" = "1" /* Alteration of Right Lower Arm with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0X0D4KZ" = "1" /* Alteration of Right Lower Arm with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X0D4ZZ" = "1" /* Alteration of Right Lower Arm, Percutaneous Endoscopic Approach */
"0X0F07Z" = "1" /* Alteration of Left Lower Arm with Autologous Tissue Substitute, Open Approach */
"0X0F0JZ" = "1" /* Alteration of Left Lower Arm with Synthetic Substitute, Open Approach */
"0X0F0KZ" = "1" /* Alteration of Left Lower Arm with Nonautologous Tissue Substitute, Open Approach */
"0X0F0ZZ" = "1" /* Alteration of Left Lower Arm, Open Approach */
"0X0F37Z" = "1" /* Alteration of Left Lower Arm with Autologous Tissue Substitute, Percutaneous Approach */
"0X0F3JZ" = "1" /* Alteration of Left Lower Arm with Synthetic Substitute, Percutaneous Approach */
"0X0F3KZ" = "1" /* Alteration of Left Lower Arm with Nonautologous Tissue Substitute, Percutaneous Approach */
"0X0F3ZZ" = "1" /* Alteration of Left Lower Arm, Percutaneous Approach */
"0X0F47Z" = "1" /* Alteration of Left Lower Arm with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X0F4JZ" = "1" /* Alteration of Left Lower Arm with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0X0F4KZ" = "1" /* Alteration of Left Lower Arm with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X0F4ZZ" = "1" /* Alteration of Left Lower Arm, Percutaneous Endoscopic Approach */
"0X0G07Z" = "1" /* Alteration of Right Wrist Region with Autologous Tissue Substitute, Open Approach */
"0X0G0JZ" = "1" /* Alteration of Right Wrist Region with Synthetic Substitute, Open Approach */
"0X0G0KZ" = "1" /* Alteration of Right Wrist Region with Nonautologous Tissue Substitute, Open Approach */
"0X0G0ZZ" = "1" /* Alteration of Right Wrist Region, Open Approach */
"0X0G37Z" = "1" /* Alteration of Right Wrist Region with Autologous Tissue Substitute, Percutaneous Approach */
"0X0G3JZ" = "1" /* Alteration of Right Wrist Region with Synthetic Substitute, Percutaneous Approach */
"0X0G3KZ" = "1" /* Alteration of Right Wrist Region with Nonautologous Tissue Substitute, Percutaneous Approach */
"0X0G3ZZ" = "1" /* Alteration of Right Wrist Region, Percutaneous Approach */
"0X0G47Z" = "1" /* Alteration of Right Wrist Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X0G4JZ" = "1" /* Alteration of Right Wrist Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0X0G4KZ" = "1" /* Alteration of Right Wrist Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X0G4ZZ" = "1" /* Alteration of Right Wrist Region, Percutaneous Endoscopic Approach */
"0X0H07Z" = "1" /* Alteration of Left Wrist Region with Autologous Tissue Substitute, Open Approach */
"0X0H0JZ" = "1" /* Alteration of Left Wrist Region with Synthetic Substitute, Open Approach */
"0X0H0KZ" = "1" /* Alteration of Left Wrist Region with Nonautologous Tissue Substitute, Open Approach */
"0X0H0ZZ" = "1" /* Alteration of Left Wrist Region, Open Approach */
"0X0H37Z" = "1" /* Alteration of Left Wrist Region with Autologous Tissue Substitute, Percutaneous Approach */
"0X0H3JZ" = "1" /* Alteration of Left Wrist Region with Synthetic Substitute, Percutaneous Approach */
"0X0H3KZ" = "1" /* Alteration of Left Wrist Region with Nonautologous Tissue Substitute, Percutaneous Approach */
"0X0H3ZZ" = "1" /* Alteration of Left Wrist Region, Percutaneous Approach */
"0X0H47Z" = "1" /* Alteration of Left Wrist Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X0H4JZ" = "1" /* Alteration of Left Wrist Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0X0H4KZ" = "1" /* Alteration of Left Wrist Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0X0H4ZZ" = "1" /* Alteration of Left Wrist Region, Percutaneous Endoscopic Approach */
"0X320ZZ" = "1" /* Control Bleeding in Right Shoulder Region, Open Approach */
"0X323ZZ" = "1" /* Control Bleeding in Right Shoulder Region, Percutaneous Approach */
"0X324ZZ" = "1" /* Control Bleeding in Right Shoulder Region, Percutaneous Endoscopic Approach */
"0X330ZZ" = "1" /* Control Bleeding in Left Shoulder Region, Open Approach */
"0X333ZZ" = "1" /* Control Bleeding in Left Shoulder Region, Percutaneous Approach */
"0X334ZZ" = "1" /* Control Bleeding in Left Shoulder Region, Percutaneous Endoscopic Approach */
"0X340ZZ" = "1" /* Control Bleeding in Right Axilla, Open Approach */
"0X343ZZ" = "1" /* Control Bleeding in Right Axilla, Percutaneous Approach */
"0X344ZZ" = "1" /* Control Bleeding in Right Axilla, Percutaneous Endoscopic Approach */
"0X350ZZ" = "1" /* Control Bleeding in Left Axilla, Open Approach */
"0X353ZZ" = "1" /* Control Bleeding in Left Axilla, Percutaneous Approach */
"0X354ZZ" = "1" /* Control Bleeding in Left Axilla, Percutaneous Endoscopic Approach */
"0X360ZZ" = "1" /* Control Bleeding in Right Upper Extremity, Open Approach */
"0X363ZZ" = "1" /* Control Bleeding in Right Upper Extremity, Percutaneous Approach */
"0X364ZZ" = "1" /* Control Bleeding in Right Upper Extremity, Percutaneous Endoscopic Approach */
"0X370ZZ" = "1" /* Control Bleeding in Left Upper Extremity, Open Approach */
"0X373ZZ" = "1" /* Control Bleeding in Left Upper Extremity, Percutaneous Approach */
"0X374ZZ" = "1" /* Control Bleeding in Left Upper Extremity, Percutaneous Endoscopic Approach */
"0X380ZZ" = "1" /* Control Bleeding in Right Upper Arm, Open Approach */
"0X383ZZ" = "1" /* Control Bleeding in Right Upper Arm, Percutaneous Approach */
"0X384ZZ" = "1" /* Control Bleeding in Right Upper Arm, Percutaneous Endoscopic Approach */
"0X390ZZ" = "1" /* Control Bleeding in Left Upper Arm, Open Approach */
"0X393ZZ" = "1" /* Control Bleeding in Left Upper Arm, Percutaneous Approach */
"0X394ZZ" = "1" /* Control Bleeding in Left Upper Arm, Percutaneous Endoscopic Approach */
"0X3B0ZZ" = "1" /* Control Bleeding in Right Elbow Region, Open Approach */
"0X3B3ZZ" = "1" /* Control Bleeding in Right Elbow Region, Percutaneous Approach */
"0X3B4ZZ" = "1" /* Control Bleeding in Right Elbow Region, Percutaneous Endoscopic Approach */
"0X3C0ZZ" = "1" /* Control Bleeding in Left Elbow Region, Open Approach */
"0X3C3ZZ" = "1" /* Control Bleeding in Left Elbow Region, Percutaneous Approach */
"0X3C4ZZ" = "1" /* Control Bleeding in Left Elbow Region, Percutaneous Endoscopic Approach */
"0X3D0ZZ" = "1" /* Control Bleeding in Right Lower Arm, Open Approach */
"0X3D3ZZ" = "1" /* Control Bleeding in Right Lower Arm, Percutaneous Approach */
"0X3D4ZZ" = "1" /* Control Bleeding in Right Lower Arm, Percutaneous Endoscopic Approach */
"0X3F0ZZ" = "1" /* Control Bleeding in Left Lower Arm, Open Approach */
"0X3F3ZZ" = "1" /* Control Bleeding in Left Lower Arm, Percutaneous Approach */
"0X3F4ZZ" = "1" /* Control Bleeding in Left Lower Arm, Percutaneous Endoscopic Approach */
"0X3G0ZZ" = "1" /* Control Bleeding in Right Wrist Region, Open Approach */
"0X3G3ZZ" = "1" /* Control Bleeding in Right Wrist Region, Percutaneous Approach */
"0X3G4ZZ" = "1" /* Control Bleeding in Right Wrist Region, Percutaneous Endoscopic Approach */
"0X3H0ZZ" = "1" /* Control Bleeding in Left Wrist Region, Open Approach */
"0X3H3ZZ" = "1" /* Control Bleeding in Left Wrist Region, Percutaneous Approach */
"0X3H4ZZ" = "1" /* Control Bleeding in Left Wrist Region, Percutaneous Endoscopic Approach */
"0X3J0ZZ" = "1" /* Control Bleeding in Right Hand, Open Approach */
"0X3J3ZZ" = "1" /* Control Bleeding in Right Hand, Percutaneous Approach */
"0X3J4ZZ" = "1" /* Control Bleeding in Right Hand, Percutaneous Endoscopic Approach */
"0X3K0ZZ" = "1" /* Control Bleeding in Left Hand, Open Approach */
"0X3K3ZZ" = "1" /* Control Bleeding in Left Hand, Percutaneous Approach */
"0X3K4ZZ" = "1" /* Control Bleeding in Left Hand, Percutaneous Endoscopic Approach */
"0X600ZZ" = "1" /* Detachment at Right Forequarter, Open Approach */
"0X610ZZ" = "1" /* Detachment at Left Forequarter, Open Approach */
"0X620ZZ" = "1" /* Detachment at Right Shoulder Region, Open Approach */
"0X630ZZ" = "1" /* Detachment at Left Shoulder Region, Open Approach */
"0X680Z1" = "1" /* Detachment at Right Upper Arm, High, Open Approach */
"0X680Z2" = "1" /* Detachment at Right Upper Arm, Mid, Open Approach */
"0X680Z3" = "1" /* Detachment at Right Upper Arm, Low, Open Approach */
"0X690Z1" = "1" /* Detachment at Left Upper Arm, High, Open Approach */
"0X690Z2" = "1" /* Detachment at Left Upper Arm, Mid, Open Approach */
"0X690Z3" = "1" /* Detachment at Left Upper Arm, Low, Open Approach */
"0X6B0ZZ" = "1" /* Detachment at Right Elbow Region, Open Approach */
"0X6C0ZZ" = "1" /* Detachment at Left Elbow Region, Open Approach */
"0X6D0Z1" = "1" /* Detachment at Right Lower Arm, High, Open Approach */
"0X6D0Z2" = "1" /* Detachment at Right Lower Arm, Mid, Open Approach */
"0X6D0Z3" = "1" /* Detachment at Right Lower Arm, Low, Open Approach */
"0X6F0Z1" = "1" /* Detachment at Left Lower Arm, High, Open Approach */
"0X6F0Z2" = "1" /* Detachment at Left Lower Arm, Mid, Open Approach */
"0X6F0Z3" = "1" /* Detachment at Left Lower Arm, Low, Open Approach */
"0X6J0Z0" = "1" /* Detachment at Right Hand, Complete, Open Approach */
"0X6J0Z4" = "1" /* Detachment at Right Hand, Complete 1st Ray, Open Approach */
"0X6J0Z5" = "1" /* Detachment at Right Hand, Complete 2nd Ray, Open Approach */
"0X6J0Z6" = "1" /* Detachment at Right Hand, Complete 3rd Ray, Open Approach */
"0X6J0Z7" = "1" /* Detachment at Right Hand, Complete 4th Ray, Open Approach */
"0X6J0Z8" = "1" /* Detachment at Right Hand, Complete 5th Ray, Open Approach */
"0X6J0Z9" = "1" /* Detachment at Right Hand, Partial 1st Ray, Open Approach */
"0X6J0ZB" = "1" /* Detachment at Right Hand, Partial 2nd Ray, Open Approach */
"0X6J0ZC" = "1" /* Detachment at Right Hand, Partial 3rd Ray, Open Approach */
"0X6J0ZD" = "1" /* Detachment at Right Hand, Partial 4th Ray, Open Approach */
"0X6J0ZF" = "1" /* Detachment at Right Hand, Partial 5th Ray, Open Approach */
"0X6K0Z0" = "1" /* Detachment at Left Hand, Complete, Open Approach */
"0X6K0Z4" = "1" /* Detachment at Left Hand, Complete 1st Ray, Open Approach */
"0X6K0Z5" = "1" /* Detachment at Left Hand, Complete 2nd Ray, Open Approach */
"0X6K0Z6" = "1" /* Detachment at Left Hand, Complete 3rd Ray, Open Approach */
"0X6K0Z7" = "1" /* Detachment at Left Hand, Complete 4th Ray, Open Approach */
"0X6K0Z8" = "1" /* Detachment at Left Hand, Complete 5th Ray, Open Approach */
"0X6K0Z9" = "1" /* Detachment at Left Hand, Partial 1st Ray, Open Approach */
"0X6K0ZB" = "1" /* Detachment at Left Hand, Partial 2nd Ray, Open Approach */
"0X6K0ZC" = "1" /* Detachment at Left Hand, Partial 3rd Ray, Open Approach */
"0X6K0ZD" = "1" /* Detachment at Left Hand, Partial 4th Ray, Open Approach */
"0X6K0ZF" = "1" /* Detachment at Left Hand, Partial 5th Ray, Open Approach */
"0X6L0Z0" = "1" /* Detachment at Right Thumb, Complete, Open Approach */
"0X6L0Z1" = "1" /* Detachment at Right Thumb, High, Open Approach */
"0X6L0Z2" = "1" /* Detachment at Right Thumb, Mid, Open Approach */
"0X6L0Z3" = "1" /* Detachment at Right Thumb, Low, Open Approach */
"0X6M0Z0" = "1" /* Detachment at Left Thumb, Complete, Open Approach */
"0X6M0Z1" = "1" /* Detachment at Left Thumb, High, Open Approach */
"0X6M0Z2" = "1" /* Detachment at Left Thumb, Mid, Open Approach */
"0X6M0Z3" = "1" /* Detachment at Left Thumb, Low, Open Approach */
"0X6N0Z0" = "1" /* Detachment at Right Index Finger, Complete, Open Approach */
"0X6N0Z1" = "1" /* Detachment at Right Index Finger, High, Open Approach */
"0X6N0Z2" = "1" /* Detachment at Right Index Finger, Mid, Open Approach */
"0X6N0Z3" = "1" /* Detachment at Right Index Finger, Low, Open Approach */
"0X6P0Z0" = "1" /* Detachment at Left Index Finger, Complete, Open Approach */
"0X6P0Z1" = "1" /* Detachment at Left Index Finger, High, Open Approach */
"0X6P0Z2" = "1" /* Detachment at Left Index Finger, Mid, Open Approach */
"0X6P0Z3" = "1" /* Detachment at Left Index Finger, Low, Open Approach */
"0X6Q0Z0" = "1" /* Detachment at Right Middle Finger, Complete, Open Approach */
"0X6Q0Z1" = "1" /* Detachment at Right Middle Finger, High, Open Approach */
"0X6Q0Z2" = "1" /* Detachment at Right Middle Finger, Mid, Open Approach */
"0X6Q0Z3" = "1" /* Detachment at Right Middle Finger, Low, Open Approach */
"0X6R0Z0" = "1" /* Detachment at Left Middle Finger, Complete, Open Approach */
"0X6R0Z1" = "1" /* Detachment at Left Middle Finger, High, Open Approach */
"0X6R0Z2" = "1" /* Detachment at Left Middle Finger, Mid, Open Approach */
"0X6R0Z3" = "1" /* Detachment at Left Middle Finger, Low, Open Approach */
"0X6S0Z0" = "1" /* Detachment at Right Ring Finger, Complete, Open Approach */
"0X6S0Z1" = "1" /* Detachment at Right Ring Finger, High, Open Approach */
"0X6S0Z2" = "1" /* Detachment at Right Ring Finger, Mid, Open Approach */
"0X6S0Z3" = "1" /* Detachment at Right Ring Finger, Low, Open Approach */
"0X6T0Z0" = "1" /* Detachment at Left Ring Finger, Complete, Open Approach */
"0X6T0Z1" = "1" /* Detachment at Left Ring Finger, High, Open Approach */
"0X6T0Z2" = "1" /* Detachment at Left Ring Finger, Mid, Open Approach */
"0X6T0Z3" = "1" /* Detachment at Left Ring Finger, Low, Open Approach */
"0X6V0Z0" = "1" /* Detachment at Right Little Finger, Complete, Open Approach */
"0X6V0Z1" = "1" /* Detachment at Right Little Finger, High, Open Approach */
"0X6V0Z2" = "1" /* Detachment at Right Little Finger, Mid, Open Approach */
"0X6V0Z3" = "1" /* Detachment at Right Little Finger, Low, Open Approach */
"0X6W0Z0" = "1" /* Detachment at Left Little Finger, Complete, Open Approach */
"0X6W0Z1" = "1" /* Detachment at Left Little Finger, High, Open Approach */
"0X6W0Z2" = "1" /* Detachment at Left Little Finger, Mid, Open Approach */
"0X6W0Z3" = "1" /* Detachment at Left Little Finger, Low, Open Approach */
"0XB20ZZ" = "1" /* Excision of Right Shoulder Region, Open Approach */
"0XB23ZZ" = "1" /* Excision of Right Shoulder Region, Percutaneous Approach */
"0XB24ZZ" = "1" /* Excision of Right Shoulder Region, Percutaneous Endoscopic Approach */
"0XB30ZZ" = "1" /* Excision of Left Shoulder Region, Open Approach */
"0XB33ZZ" = "1" /* Excision of Left Shoulder Region, Percutaneous Approach */
"0XB34ZZ" = "1" /* Excision of Left Shoulder Region, Percutaneous Endoscopic Approach */
"0XB40ZZ" = "1" /* Excision of Right Axilla, Open Approach */
"0XB43ZZ" = "1" /* Excision of Right Axilla, Percutaneous Approach */
"0XB44ZZ" = "1" /* Excision of Right Axilla, Percutaneous Endoscopic Approach */
"0XB50ZZ" = "1" /* Excision of Left Axilla, Open Approach */
"0XB53ZZ" = "1" /* Excision of Left Axilla, Percutaneous Approach */
"0XB54ZZ" = "1" /* Excision of Left Axilla, Percutaneous Endoscopic Approach */
"0XB60ZZ" = "1" /* Excision of Right Upper Extremity, Open Approach */
"0XB63ZZ" = "1" /* Excision of Right Upper Extremity, Percutaneous Approach */
"0XB64ZZ" = "1" /* Excision of Right Upper Extremity, Percutaneous Endoscopic Approach */
"0XB70ZZ" = "1" /* Excision of Left Upper Extremity, Open Approach */
"0XB73ZZ" = "1" /* Excision of Left Upper Extremity, Percutaneous Approach */
"0XB74ZZ" = "1" /* Excision of Left Upper Extremity, Percutaneous Endoscopic Approach */
"0XB80ZZ" = "1" /* Excision of Right Upper Arm, Open Approach */
"0XB83ZZ" = "1" /* Excision of Right Upper Arm, Percutaneous Approach */
"0XB84ZZ" = "1" /* Excision of Right Upper Arm, Percutaneous Endoscopic Approach */
"0XB90ZZ" = "1" /* Excision of Left Upper Arm, Open Approach */
"0XB93ZZ" = "1" /* Excision of Left Upper Arm, Percutaneous Approach */
"0XB94ZZ" = "1" /* Excision of Left Upper Arm, Percutaneous Endoscopic Approach */
"0XBB0ZZ" = "1" /* Excision of Right Elbow Region, Open Approach */
"0XBB3ZZ" = "1" /* Excision of Right Elbow Region, Percutaneous Approach */
"0XBB4ZZ" = "1" /* Excision of Right Elbow Region, Percutaneous Endoscopic Approach */
"0XBC0ZZ" = "1" /* Excision of Left Elbow Region, Open Approach */
"0XBC3ZZ" = "1" /* Excision of Left Elbow Region, Percutaneous Approach */
"0XBC4ZZ" = "1" /* Excision of Left Elbow Region, Percutaneous Endoscopic Approach */
"0XBD0ZZ" = "1" /* Excision of Right Lower Arm, Open Approach */
"0XBD3ZZ" = "1" /* Excision of Right Lower Arm, Percutaneous Approach */
"0XBD4ZZ" = "1" /* Excision of Right Lower Arm, Percutaneous Endoscopic Approach */
"0XBF0ZZ" = "1" /* Excision of Left Lower Arm, Open Approach */
"0XBF3ZZ" = "1" /* Excision of Left Lower Arm, Percutaneous Approach */
"0XBF4ZZ" = "1" /* Excision of Left Lower Arm, Percutaneous Endoscopic Approach */
"0XBG0ZZ" = "1" /* Excision of Right Wrist Region, Open Approach */
"0XBG3ZZ" = "1" /* Excision of Right Wrist Region, Percutaneous Approach */
"0XBG4ZZ" = "1" /* Excision of Right Wrist Region, Percutaneous Endoscopic Approach */
"0XBH0ZZ" = "1" /* Excision of Left Wrist Region, Open Approach */
"0XBH3ZZ" = "1" /* Excision of Left Wrist Region, Percutaneous Approach */
"0XBH4ZZ" = "1" /* Excision of Left Wrist Region, Percutaneous Endoscopic Approach */
"0XBJ0ZZ" = "1" /* Excision of Right Hand, Open Approach */
"0XBJ3ZZ" = "1" /* Excision of Right Hand, Percutaneous Approach */
"0XBJ4ZZ" = "1" /* Excision of Right Hand, Percutaneous Endoscopic Approach */
"0XBK0ZZ" = "1" /* Excision of Left Hand, Open Approach */
"0XBK3ZZ" = "1" /* Excision of Left Hand, Percutaneous Approach */
"0XBK4ZZ" = "1" /* Excision of Left Hand, Percutaneous Endoscopic Approach */
"0XH201Z" = "1" /* Insertion of Radioactive Element into Right Shoulder Region, Open Approach */
"0XH231Z" = "1" /* Insertion of Radioactive Element into Right Shoulder Region, Percutaneous Approach */
"0XH241Z" = "1" /* Insertion of Radioactive Element into Right Shoulder Region, Percutaneous Endoscopic Approach */
"0XH301Z" = "1" /* Insertion of Radioactive Element into Left Shoulder Region, Open Approach */
"0XH331Z" = "1" /* Insertion of Radioactive Element into Left Shoulder Region, Percutaneous Approach */
"0XH341Z" = "1" /* Insertion of Radioactive Element into Left Shoulder Region, Percutaneous Endoscopic Approach */
"0XH401Z" = "1" /* Insertion of Radioactive Element into Right Axilla, Open Approach */
"0XH431Z" = "1" /* Insertion of Radioactive Element into Right Axilla, Percutaneous Approach */
"0XH441Z" = "1" /* Insertion of Radioactive Element into Right Axilla, Percutaneous Endoscopic Approach */
"0XH501Z" = "1" /* Insertion of Radioactive Element into Left Axilla, Open Approach */
"0XH531Z" = "1" /* Insertion of Radioactive Element into Left Axilla, Percutaneous Approach */
"0XH541Z" = "1" /* Insertion of Radioactive Element into Left Axilla, Percutaneous Endoscopic Approach */
"0XH601Z" = "1" /* Insertion of Radioactive Element into Right Upper Extremity, Open Approach */
"0XH631Z" = "1" /* Insertion of Radioactive Element into Right Upper Extremity, Percutaneous Approach */
"0XH641Z" = "1" /* Insertion of Radioactive Element into Right Upper Extremity, Percutaneous Endoscopic Approach */
"0XH701Z" = "1" /* Insertion of Radioactive Element into Left Upper Extremity, Open Approach */
"0XH731Z" = "1" /* Insertion of Radioactive Element into Left Upper Extremity, Percutaneous Approach */
"0XH741Z" = "1" /* Insertion of Radioactive Element into Left Upper Extremity, Percutaneous Endoscopic Approach */
"0XH801Z" = "1" /* Insertion of Radioactive Element into Right Upper Arm, Open Approach */
"0XH831Z" = "1" /* Insertion of Radioactive Element into Right Upper Arm, Percutaneous Approach */
"0XH841Z" = "1" /* Insertion of Radioactive Element into Right Upper Arm, Percutaneous Endoscopic Approach */
"0XH901Z" = "1" /* Insertion of Radioactive Element into Left Upper Arm, Open Approach */
"0XH931Z" = "1" /* Insertion of Radioactive Element into Left Upper Arm, Percutaneous Approach */
"0XH941Z" = "1" /* Insertion of Radioactive Element into Left Upper Arm, Percutaneous Endoscopic Approach */
"0XHB01Z" = "1" /* Insertion of Radioactive Element into Right Elbow Region, Open Approach */
"0XHB31Z" = "1" /* Insertion of Radioactive Element into Right Elbow Region, Percutaneous Approach */
"0XHB41Z" = "1" /* Insertion of Radioactive Element into Right Elbow Region, Percutaneous Endoscopic Approach */
"0XHC01Z" = "1" /* Insertion of Radioactive Element into Left Elbow Region, Open Approach */
"0XHC31Z" = "1" /* Insertion of Radioactive Element into Left Elbow Region, Percutaneous Approach */
"0XHC41Z" = "1" /* Insertion of Radioactive Element into Left Elbow Region, Percutaneous Endoscopic Approach */
"0XHD01Z" = "1" /* Insertion of Radioactive Element into Right Lower Arm, Open Approach */
"0XHD31Z" = "1" /* Insertion of Radioactive Element into Right Lower Arm, Percutaneous Approach */
"0XHD41Z" = "1" /* Insertion of Radioactive Element into Right Lower Arm, Percutaneous Endoscopic Approach */
"0XHF01Z" = "1" /* Insertion of Radioactive Element into Left Lower Arm, Open Approach */
"0XHF31Z" = "1" /* Insertion of Radioactive Element into Left Lower Arm, Percutaneous Approach */
"0XHF41Z" = "1" /* Insertion of Radioactive Element into Left Lower Arm, Percutaneous Endoscopic Approach */
"0XHG01Z" = "1" /* Insertion of Radioactive Element into Right Wrist Region, Open Approach */
"0XHG31Z" = "1" /* Insertion of Radioactive Element into Right Wrist Region, Percutaneous Approach */
"0XHG41Z" = "1" /* Insertion of Radioactive Element into Right Wrist Region, Percutaneous Endoscopic Approach */
"0XHH01Z" = "1" /* Insertion of Radioactive Element into Left Wrist Region, Open Approach */
"0XHH31Z" = "1" /* Insertion of Radioactive Element into Left Wrist Region, Percutaneous Approach */
"0XHH41Z" = "1" /* Insertion of Radioactive Element into Left Wrist Region, Percutaneous Endoscopic Approach */
"0XHJ01Z" = "1" /* Insertion of Radioactive Element into Right Hand, Open Approach */
"0XHJ31Z" = "1" /* Insertion of Radioactive Element into Right Hand, Percutaneous Approach */
"0XHJ41Z" = "1" /* Insertion of Radioactive Element into Right Hand, Percutaneous Endoscopic Approach */
"0XHK01Z" = "1" /* Insertion of Radioactive Element into Left Hand, Open Approach */
"0XHK31Z" = "1" /* Insertion of Radioactive Element into Left Hand, Percutaneous Approach */
"0XHK41Z" = "1" /* Insertion of Radioactive Element into Left Hand, Percutaneous Endoscopic Approach */
"0XJJ4ZZ" = "1" /* Inspection of Right Hand, Percutaneous Endoscopic Approach */
"0XJK4ZZ" = "1" /* Inspection of Left Hand, Percutaneous Endoscopic Approach */
"0XM00ZZ" = "1" /* Reattachment of Right Forequarter, Open Approach */
"0XM10ZZ" = "1" /* Reattachment of Left Forequarter, Open Approach */
"0XM20ZZ" = "1" /* Reattachment of Right Shoulder Region, Open Approach */
"0XM30ZZ" = "1" /* Reattachment of Left Shoulder Region, Open Approach */
"0XM40ZZ" = "1" /* Reattachment of Right Axilla, Open Approach */
"0XM50ZZ" = "1" /* Reattachment of Left Axilla, Open Approach */
"0XM60ZZ" = "1" /* Reattachment of Right Upper Extremity, Open Approach */
"0XM70ZZ" = "1" /* Reattachment of Left Upper Extremity, Open Approach */
"0XM80ZZ" = "1" /* Reattachment of Right Upper Arm, Open Approach */
"0XM90ZZ" = "1" /* Reattachment of Left Upper Arm, Open Approach */
"0XMB0ZZ" = "1" /* Reattachment of Right Elbow Region, Open Approach */
"0XMC0ZZ" = "1" /* Reattachment of Left Elbow Region, Open Approach */
"0XMD0ZZ" = "1" /* Reattachment of Right Lower Arm, Open Approach */
"0XMF0ZZ" = "1" /* Reattachment of Left Lower Arm, Open Approach */
"0XMG0ZZ" = "1" /* Reattachment of Right Wrist Region, Open Approach */
"0XMH0ZZ" = "1" /* Reattachment of Left Wrist Region, Open Approach */
"0XMJ0ZZ" = "1" /* Reattachment of Right Hand, Open Approach */
"0XMK0ZZ" = "1" /* Reattachment of Left Hand, Open Approach */
"0XML0ZZ" = "1" /* Reattachment of Right Thumb, Open Approach */
"0XMM0ZZ" = "1" /* Reattachment of Left Thumb, Open Approach */
"0XMN0ZZ" = "1" /* Reattachment of Right Index Finger, Open Approach */
"0XMP0ZZ" = "1" /* Reattachment of Left Index Finger, Open Approach */
"0XMQ0ZZ" = "1" /* Reattachment of Right Middle Finger, Open Approach */
"0XMR0ZZ" = "1" /* Reattachment of Left Middle Finger, Open Approach */
"0XMS0ZZ" = "1" /* Reattachment of Right Ring Finger, Open Approach */
"0XMT0ZZ" = "1" /* Reattachment of Left Ring Finger, Open Approach */
"0XMV0ZZ" = "1" /* Reattachment of Right Little Finger, Open Approach */
"0XMW0ZZ" = "1" /* Reattachment of Left Little Finger, Open Approach */
"0XQ20ZZ" = "1" /* Repair Right Shoulder Region, Open Approach */
"0XQ23ZZ" = "1" /* Repair Right Shoulder Region, Percutaneous Approach */
"0XQ24ZZ" = "1" /* Repair Right Shoulder Region, Percutaneous Endoscopic Approach */
"0XQ2XZZ" = "1" /* Repair Right Shoulder Region, External Approach */
"0XQ30ZZ" = "1" /* Repair Left Shoulder Region, Open Approach */
"0XQ33ZZ" = "1" /* Repair Left Shoulder Region, Percutaneous Approach */
"0XQ34ZZ" = "1" /* Repair Left Shoulder Region, Percutaneous Endoscopic Approach */
"0XQ3XZZ" = "1" /* Repair Left Shoulder Region, External Approach */
"0XQ40ZZ" = "1" /* Repair Right Axilla, Open Approach */
"0XQ43ZZ" = "1" /* Repair Right Axilla, Percutaneous Approach */
"0XQ44ZZ" = "1" /* Repair Right Axilla, Percutaneous Endoscopic Approach */
"0XQ4XZZ" = "1" /* Repair Right Axilla, External Approach */
"0XQ50ZZ" = "1" /* Repair Left Axilla, Open Approach */
"0XQ53ZZ" = "1" /* Repair Left Axilla, Percutaneous Approach */
"0XQ54ZZ" = "1" /* Repair Left Axilla, Percutaneous Endoscopic Approach */
"0XQ5XZZ" = "1" /* Repair Left Axilla, External Approach */
"0XQ60ZZ" = "1" /* Repair Right Upper Extremity, Open Approach */
"0XQ63ZZ" = "1" /* Repair Right Upper Extremity, Percutaneous Approach */
"0XQ64ZZ" = "1" /* Repair Right Upper Extremity, Percutaneous Endoscopic Approach */
"0XQ6XZZ" = "1" /* Repair Right Upper Extremity, External Approach */
"0XQ70ZZ" = "1" /* Repair Left Upper Extremity, Open Approach */
"0XQ73ZZ" = "1" /* Repair Left Upper Extremity, Percutaneous Approach */
"0XQ74ZZ" = "1" /* Repair Left Upper Extremity, Percutaneous Endoscopic Approach */
"0XQ7XZZ" = "1" /* Repair Left Upper Extremity, External Approach */
"0XQ80ZZ" = "1" /* Repair Right Upper Arm, Open Approach */
"0XQ83ZZ" = "1" /* Repair Right Upper Arm, Percutaneous Approach */
"0XQ84ZZ" = "1" /* Repair Right Upper Arm, Percutaneous Endoscopic Approach */
"0XQ8XZZ" = "1" /* Repair Right Upper Arm, External Approach */
"0XQ90ZZ" = "1" /* Repair Left Upper Arm, Open Approach */
"0XQ93ZZ" = "1" /* Repair Left Upper Arm, Percutaneous Approach */
"0XQ94ZZ" = "1" /* Repair Left Upper Arm, Percutaneous Endoscopic Approach */
"0XQ9XZZ" = "1" /* Repair Left Upper Arm, External Approach */
"0XQB0ZZ" = "1" /* Repair Right Elbow Region, Open Approach */
"0XQB3ZZ" = "1" /* Repair Right Elbow Region, Percutaneous Approach */
"0XQB4ZZ" = "1" /* Repair Right Elbow Region, Percutaneous Endoscopic Approach */
"0XQBXZZ" = "1" /* Repair Right Elbow Region, External Approach */
"0XQC0ZZ" = "1" /* Repair Left Elbow Region, Open Approach */
"0XQC3ZZ" = "1" /* Repair Left Elbow Region, Percutaneous Approach */
"0XQC4ZZ" = "1" /* Repair Left Elbow Region, Percutaneous Endoscopic Approach */
"0XQCXZZ" = "1" /* Repair Left Elbow Region, External Approach */
"0XQD0ZZ" = "1" /* Repair Right Lower Arm, Open Approach */
"0XQD3ZZ" = "1" /* Repair Right Lower Arm, Percutaneous Approach */
"0XQD4ZZ" = "1" /* Repair Right Lower Arm, Percutaneous Endoscopic Approach */
"0XQDXZZ" = "1" /* Repair Right Lower Arm, External Approach */
"0XQF0ZZ" = "1" /* Repair Left Lower Arm, Open Approach */
"0XQF3ZZ" = "1" /* Repair Left Lower Arm, Percutaneous Approach */
"0XQF4ZZ" = "1" /* Repair Left Lower Arm, Percutaneous Endoscopic Approach */
"0XQFXZZ" = "1" /* Repair Left Lower Arm, External Approach */
"0XQG0ZZ" = "1" /* Repair Right Wrist Region, Open Approach */
"0XQG3ZZ" = "1" /* Repair Right Wrist Region, Percutaneous Approach */
"0XQG4ZZ" = "1" /* Repair Right Wrist Region, Percutaneous Endoscopic Approach */
"0XQGXZZ" = "1" /* Repair Right Wrist Region, External Approach */
"0XQH0ZZ" = "1" /* Repair Left Wrist Region, Open Approach */
"0XQH3ZZ" = "1" /* Repair Left Wrist Region, Percutaneous Approach */
"0XQH4ZZ" = "1" /* Repair Left Wrist Region, Percutaneous Endoscopic Approach */
"0XQHXZZ" = "1" /* Repair Left Wrist Region, External Approach */
"0XQJ0ZZ" = "1" /* Repair Right Hand, Open Approach */
"0XQJ3ZZ" = "1" /* Repair Right Hand, Percutaneous Approach */
"0XQJ4ZZ" = "1" /* Repair Right Hand, Percutaneous Endoscopic Approach */
"0XQJXZZ" = "1" /* Repair Right Hand, External Approach */
"0XQK0ZZ" = "1" /* Repair Left Hand, Open Approach */
"0XQK3ZZ" = "1" /* Repair Left Hand, Percutaneous Approach */
"0XQK4ZZ" = "1" /* Repair Left Hand, Percutaneous Endoscopic Approach */
"0XQKXZZ" = "1" /* Repair Left Hand, External Approach */
"0XQL0ZZ" = "1" /* Repair Right Thumb, Open Approach */
"0XQL3ZZ" = "1" /* Repair Right Thumb, Percutaneous Approach */
"0XQL4ZZ" = "1" /* Repair Right Thumb, Percutaneous Endoscopic Approach */
"0XQLXZZ" = "1" /* Repair Right Thumb, External Approach */
"0XQM0ZZ" = "1" /* Repair Left Thumb, Open Approach */
"0XQM3ZZ" = "1" /* Repair Left Thumb, Percutaneous Approach */
"0XQM4ZZ" = "1" /* Repair Left Thumb, Percutaneous Endoscopic Approach */
"0XQMXZZ" = "1" /* Repair Left Thumb, External Approach */
"0XQN0ZZ" = "1" /* Repair Right Index Finger, Open Approach */
"0XQN3ZZ" = "1" /* Repair Right Index Finger, Percutaneous Approach */
"0XQN4ZZ" = "1" /* Repair Right Index Finger, Percutaneous Endoscopic Approach */
"0XQNXZZ" = "1" /* Repair Right Index Finger, External Approach */
"0XQP0ZZ" = "1" /* Repair Left Index Finger, Open Approach */
"0XQP3ZZ" = "1" /* Repair Left Index Finger, Percutaneous Approach */
"0XQP4ZZ" = "1" /* Repair Left Index Finger, Percutaneous Endoscopic Approach */
"0XQPXZZ" = "1" /* Repair Left Index Finger, External Approach */
"0XQQ0ZZ" = "1" /* Repair Right Middle Finger, Open Approach */
"0XQQ3ZZ" = "1" /* Repair Right Middle Finger, Percutaneous Approach */
"0XQQ4ZZ" = "1" /* Repair Right Middle Finger, Percutaneous Endoscopic Approach */
"0XQQXZZ" = "1" /* Repair Right Middle Finger, External Approach */
"0XQR0ZZ" = "1" /* Repair Left Middle Finger, Open Approach */
"0XQR3ZZ" = "1" /* Repair Left Middle Finger, Percutaneous Approach */
"0XQR4ZZ" = "1" /* Repair Left Middle Finger, Percutaneous Endoscopic Approach */
"0XQRXZZ" = "1" /* Repair Left Middle Finger, External Approach */
"0XQS0ZZ" = "1" /* Repair Right Ring Finger, Open Approach */
"0XQS3ZZ" = "1" /* Repair Right Ring Finger, Percutaneous Approach */
"0XQS4ZZ" = "1" /* Repair Right Ring Finger, Percutaneous Endoscopic Approach */
"0XQSXZZ" = "1" /* Repair Right Ring Finger, External Approach */
"0XQT0ZZ" = "1" /* Repair Left Ring Finger, Open Approach */
"0XQT3ZZ" = "1" /* Repair Left Ring Finger, Percutaneous Approach */
"0XQT4ZZ" = "1" /* Repair Left Ring Finger, Percutaneous Endoscopic Approach */
"0XQTXZZ" = "1" /* Repair Left Ring Finger, External Approach */
"0XQV0ZZ" = "1" /* Repair Right Little Finger, Open Approach */
"0XQV3ZZ" = "1" /* Repair Right Little Finger, Percutaneous Approach */
"0XQV4ZZ" = "1" /* Repair Right Little Finger, Percutaneous Endoscopic Approach */
"0XQVXZZ" = "1" /* Repair Right Little Finger, External Approach */
"0XQW0ZZ" = "1" /* Repair Left Little Finger, Open Approach */
"0XQW3ZZ" = "1" /* Repair Left Little Finger, Percutaneous Approach */
"0XQW4ZZ" = "1" /* Repair Left Little Finger, Percutaneous Endoscopic Approach */
"0XQWXZZ" = "1" /* Repair Left Little Finger, External Approach */
"0XRL07N" = "1" /* Replacement of Right Thumb with Right Toe, Autologous Tissue Substitute, Open Approach */
"0XRL07P" = "1" /* Replacement of Right Thumb with Left Toe, Autologous Tissue Substitute, Open Approach */
"0XRL47N" = "1" /* Replacement of Right Thumb with Right Toe, Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XRL47P" = "1" /* Replacement of Right Thumb with Left Toe, Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XRM07N" = "1" /* Replacement of Left Thumb with Right Toe, Autologous Tissue Substitute, Open Approach */
"0XRM07P" = "1" /* Replacement of Left Thumb with Left Toe, Autologous Tissue Substitute, Open Approach */
"0XRM47N" = "1" /* Replacement of Left Thumb with Right Toe, Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XRM47P" = "1" /* Replacement of Left Thumb with Left Toe, Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XU207Z" = "1" /* Supplement Right Shoulder Region with Autologous Tissue Substitute, Open Approach */
"0XU20JZ" = "1" /* Supplement Right Shoulder Region with Synthetic Substitute, Open Approach */
"0XU20KZ" = "1" /* Supplement Right Shoulder Region with Nonautologous Tissue Substitute, Open Approach */
"0XU247Z" = "1" /* Supplement Right Shoulder Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XU24JZ" = "1" /* Supplement Right Shoulder Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XU24KZ" = "1" /* Supplement Right Shoulder Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XU307Z" = "1" /* Supplement Left Shoulder Region with Autologous Tissue Substitute, Open Approach */
"0XU30JZ" = "1" /* Supplement Left Shoulder Region with Synthetic Substitute, Open Approach */
"0XU30KZ" = "1" /* Supplement Left Shoulder Region with Nonautologous Tissue Substitute, Open Approach */
"0XU347Z" = "1" /* Supplement Left Shoulder Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XU34JZ" = "1" /* Supplement Left Shoulder Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XU34KZ" = "1" /* Supplement Left Shoulder Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XU407Z" = "1" /* Supplement Right Axilla with Autologous Tissue Substitute, Open Approach */
"0XU40JZ" = "1" /* Supplement Right Axilla with Synthetic Substitute, Open Approach */
"0XU40KZ" = "1" /* Supplement Right Axilla with Nonautologous Tissue Substitute, Open Approach */
"0XU447Z" = "1" /* Supplement Right Axilla with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XU44JZ" = "1" /* Supplement Right Axilla with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XU44KZ" = "1" /* Supplement Right Axilla with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XU507Z" = "1" /* Supplement Left Axilla with Autologous Tissue Substitute, Open Approach */
"0XU50JZ" = "1" /* Supplement Left Axilla with Synthetic Substitute, Open Approach */
"0XU50KZ" = "1" /* Supplement Left Axilla with Nonautologous Tissue Substitute, Open Approach */
"0XU547Z" = "1" /* Supplement Left Axilla with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XU54JZ" = "1" /* Supplement Left Axilla with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XU54KZ" = "1" /* Supplement Left Axilla with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XU607Z" = "1" /* Supplement Right Upper Extremity with Autologous Tissue Substitute, Open Approach */
"0XU60JZ" = "1" /* Supplement Right Upper Extremity with Synthetic Substitute, Open Approach */
"0XU60KZ" = "1" /* Supplement Right Upper Extremity with Nonautologous Tissue Substitute, Open Approach */
"0XU647Z" = "1" /* Supplement Right Upper Extremity with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XU64JZ" = "1" /* Supplement Right Upper Extremity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XU64KZ" = "1" /* Supplement Right Upper Extremity with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XU707Z" = "1" /* Supplement Left Upper Extremity with Autologous Tissue Substitute, Open Approach */
"0XU70JZ" = "1" /* Supplement Left Upper Extremity with Synthetic Substitute, Open Approach */
"0XU70KZ" = "1" /* Supplement Left Upper Extremity with Nonautologous Tissue Substitute, Open Approach */
"0XU747Z" = "1" /* Supplement Left Upper Extremity with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XU74JZ" = "1" /* Supplement Left Upper Extremity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XU74KZ" = "1" /* Supplement Left Upper Extremity with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XU807Z" = "1" /* Supplement Right Upper Arm with Autologous Tissue Substitute, Open Approach */
"0XU80JZ" = "1" /* Supplement Right Upper Arm with Synthetic Substitute, Open Approach */
"0XU80KZ" = "1" /* Supplement Right Upper Arm with Nonautologous Tissue Substitute, Open Approach */
"0XU847Z" = "1" /* Supplement Right Upper Arm with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XU84JZ" = "1" /* Supplement Right Upper Arm with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XU84KZ" = "1" /* Supplement Right Upper Arm with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XU907Z" = "1" /* Supplement Left Upper Arm with Autologous Tissue Substitute, Open Approach */
"0XU90JZ" = "1" /* Supplement Left Upper Arm with Synthetic Substitute, Open Approach */
"0XU90KZ" = "1" /* Supplement Left Upper Arm with Nonautologous Tissue Substitute, Open Approach */
"0XU947Z" = "1" /* Supplement Left Upper Arm with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XU94JZ" = "1" /* Supplement Left Upper Arm with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XU94KZ" = "1" /* Supplement Left Upper Arm with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUB07Z" = "1" /* Supplement Right Elbow Region with Autologous Tissue Substitute, Open Approach */
"0XUB0JZ" = "1" /* Supplement Right Elbow Region with Synthetic Substitute, Open Approach */
"0XUB0KZ" = "1" /* Supplement Right Elbow Region with Nonautologous Tissue Substitute, Open Approach */
"0XUB47Z" = "1" /* Supplement Right Elbow Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUB4JZ" = "1" /* Supplement Right Elbow Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XUB4KZ" = "1" /* Supplement Right Elbow Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUC07Z" = "1" /* Supplement Left Elbow Region with Autologous Tissue Substitute, Open Approach */
"0XUC0JZ" = "1" /* Supplement Left Elbow Region with Synthetic Substitute, Open Approach */
"0XUC0KZ" = "1" /* Supplement Left Elbow Region with Nonautologous Tissue Substitute, Open Approach */
"0XUC47Z" = "1" /* Supplement Left Elbow Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUC4JZ" = "1" /* Supplement Left Elbow Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XUC4KZ" = "1" /* Supplement Left Elbow Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUD07Z" = "1" /* Supplement Right Lower Arm with Autologous Tissue Substitute, Open Approach */
"0XUD0JZ" = "1" /* Supplement Right Lower Arm with Synthetic Substitute, Open Approach */
"0XUD0KZ" = "1" /* Supplement Right Lower Arm with Nonautologous Tissue Substitute, Open Approach */
"0XUD47Z" = "1" /* Supplement Right Lower Arm with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUD4JZ" = "1" /* Supplement Right Lower Arm with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XUD4KZ" = "1" /* Supplement Right Lower Arm with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUF07Z" = "1" /* Supplement Left Lower Arm with Autologous Tissue Substitute, Open Approach */
"0XUF0JZ" = "1" /* Supplement Left Lower Arm with Synthetic Substitute, Open Approach */
"0XUF0KZ" = "1" /* Supplement Left Lower Arm with Nonautologous Tissue Substitute, Open Approach */
"0XUF47Z" = "1" /* Supplement Left Lower Arm with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUF4JZ" = "1" /* Supplement Left Lower Arm with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XUF4KZ" = "1" /* Supplement Left Lower Arm with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUG07Z" = "1" /* Supplement Right Wrist Region with Autologous Tissue Substitute, Open Approach */
"0XUG0JZ" = "1" /* Supplement Right Wrist Region with Synthetic Substitute, Open Approach */
"0XUG0KZ" = "1" /* Supplement Right Wrist Region with Nonautologous Tissue Substitute, Open Approach */
"0XUG47Z" = "1" /* Supplement Right Wrist Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUG4JZ" = "1" /* Supplement Right Wrist Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XUG4KZ" = "1" /* Supplement Right Wrist Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUH07Z" = "1" /* Supplement Left Wrist Region with Autologous Tissue Substitute, Open Approach */
"0XUH0JZ" = "1" /* Supplement Left Wrist Region with Synthetic Substitute, Open Approach */
"0XUH0KZ" = "1" /* Supplement Left Wrist Region with Nonautologous Tissue Substitute, Open Approach */
"0XUH47Z" = "1" /* Supplement Left Wrist Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUH4JZ" = "1" /* Supplement Left Wrist Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XUH4KZ" = "1" /* Supplement Left Wrist Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUJ07Z" = "1" /* Supplement Right Hand with Autologous Tissue Substitute, Open Approach */
"0XUJ0JZ" = "1" /* Supplement Right Hand with Synthetic Substitute, Open Approach */
"0XUJ0KZ" = "1" /* Supplement Right Hand with Nonautologous Tissue Substitute, Open Approach */
"0XUJ47Z" = "1" /* Supplement Right Hand with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUJ4JZ" = "1" /* Supplement Right Hand with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XUJ4KZ" = "1" /* Supplement Right Hand with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUK07Z" = "1" /* Supplement Left Hand with Autologous Tissue Substitute, Open Approach */
"0XUK0JZ" = "1" /* Supplement Left Hand with Synthetic Substitute, Open Approach */
"0XUK0KZ" = "1" /* Supplement Left Hand with Nonautologous Tissue Substitute, Open Approach */
"0XUK47Z" = "1" /* Supplement Left Hand with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUK4JZ" = "1" /* Supplement Left Hand with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XUK4KZ" = "1" /* Supplement Left Hand with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUL07Z" = "1" /* Supplement Right Thumb with Autologous Tissue Substitute, Open Approach */
"0XUL0JZ" = "1" /* Supplement Right Thumb with Synthetic Substitute, Open Approach */
"0XUL0KZ" = "1" /* Supplement Right Thumb with Nonautologous Tissue Substitute, Open Approach */
"0XUL47Z" = "1" /* Supplement Right Thumb with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUL4JZ" = "1" /* Supplement Right Thumb with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XUL4KZ" = "1" /* Supplement Right Thumb with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUM07Z" = "1" /* Supplement Left Thumb with Autologous Tissue Substitute, Open Approach */
"0XUM0JZ" = "1" /* Supplement Left Thumb with Synthetic Substitute, Open Approach */
"0XUM0KZ" = "1" /* Supplement Left Thumb with Nonautologous Tissue Substitute, Open Approach */
"0XUM47Z" = "1" /* Supplement Left Thumb with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUM4JZ" = "1" /* Supplement Left Thumb with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XUM4KZ" = "1" /* Supplement Left Thumb with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUN07Z" = "1" /* Supplement Right Index Finger with Autologous Tissue Substitute, Open Approach */
"0XUN0JZ" = "1" /* Supplement Right Index Finger with Synthetic Substitute, Open Approach */
"0XUN0KZ" = "1" /* Supplement Right Index Finger with Nonautologous Tissue Substitute, Open Approach */
"0XUN47Z" = "1" /* Supplement Right Index Finger with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUN4JZ" = "1" /* Supplement Right Index Finger with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XUN4KZ" = "1" /* Supplement Right Index Finger with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUP07Z" = "1" /* Supplement Left Index Finger with Autologous Tissue Substitute, Open Approach */
"0XUP0JZ" = "1" /* Supplement Left Index Finger with Synthetic Substitute, Open Approach */
"0XUP0KZ" = "1" /* Supplement Left Index Finger with Nonautologous Tissue Substitute, Open Approach */
"0XUP47Z" = "1" /* Supplement Left Index Finger with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUP4JZ" = "1" /* Supplement Left Index Finger with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XUP4KZ" = "1" /* Supplement Left Index Finger with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUQ07Z" = "1" /* Supplement Right Middle Finger with Autologous Tissue Substitute, Open Approach */
"0XUQ0JZ" = "1" /* Supplement Right Middle Finger with Synthetic Substitute, Open Approach */
"0XUQ0KZ" = "1" /* Supplement Right Middle Finger with Nonautologous Tissue Substitute, Open Approach */
"0XUQ47Z" = "1" /* Supplement Right Middle Finger with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUQ4JZ" = "1" /* Supplement Right Middle Finger with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XUQ4KZ" = "1" /* Supplement Right Middle Finger with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUR07Z" = "1" /* Supplement Left Middle Finger with Autologous Tissue Substitute, Open Approach */
"0XUR0JZ" = "1" /* Supplement Left Middle Finger with Synthetic Substitute, Open Approach */
"0XUR0KZ" = "1" /* Supplement Left Middle Finger with Nonautologous Tissue Substitute, Open Approach */
"0XUR47Z" = "1" /* Supplement Left Middle Finger with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUR4JZ" = "1" /* Supplement Left Middle Finger with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XUR4KZ" = "1" /* Supplement Left Middle Finger with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUS07Z" = "1" /* Supplement Right Ring Finger with Autologous Tissue Substitute, Open Approach */
"0XUS0JZ" = "1" /* Supplement Right Ring Finger with Synthetic Substitute, Open Approach */
"0XUS0KZ" = "1" /* Supplement Right Ring Finger with Nonautologous Tissue Substitute, Open Approach */
"0XUS47Z" = "1" /* Supplement Right Ring Finger with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUS4JZ" = "1" /* Supplement Right Ring Finger with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XUS4KZ" = "1" /* Supplement Right Ring Finger with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUT07Z" = "1" /* Supplement Left Ring Finger with Autologous Tissue Substitute, Open Approach */
"0XUT0JZ" = "1" /* Supplement Left Ring Finger with Synthetic Substitute, Open Approach */
"0XUT0KZ" = "1" /* Supplement Left Ring Finger with Nonautologous Tissue Substitute, Open Approach */
"0XUT47Z" = "1" /* Supplement Left Ring Finger with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUT4JZ" = "1" /* Supplement Left Ring Finger with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XUT4KZ" = "1" /* Supplement Left Ring Finger with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUV07Z" = "1" /* Supplement Right Little Finger with Autologous Tissue Substitute, Open Approach */
"0XUV0JZ" = "1" /* Supplement Right Little Finger with Synthetic Substitute, Open Approach */
"0XUV0KZ" = "1" /* Supplement Right Little Finger with Nonautologous Tissue Substitute, Open Approach */
"0XUV47Z" = "1" /* Supplement Right Little Finger with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUV4JZ" = "1" /* Supplement Right Little Finger with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XUV4KZ" = "1" /* Supplement Right Little Finger with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUW07Z" = "1" /* Supplement Left Little Finger with Autologous Tissue Substitute, Open Approach */
"0XUW0JZ" = "1" /* Supplement Left Little Finger with Synthetic Substitute, Open Approach */
"0XUW0KZ" = "1" /* Supplement Left Little Finger with Nonautologous Tissue Substitute, Open Approach */
"0XUW47Z" = "1" /* Supplement Left Little Finger with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XUW4JZ" = "1" /* Supplement Left Little Finger with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0XUW4KZ" = "1" /* Supplement Left Little Finger with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0XXN0ZL" = "1" /* Transfer Right Index Finger to Right Thumb, Open Approach */
"0XXP0ZM" = "1" /* Transfer Left Index Finger to Left Thumb, Open Approach */
"0XYJ0Z0" = "1" /* Transplantation of Right Hand, Allogeneic, Open Approach */
"0XYJ0Z1" = "1" /* Transplantation of Right Hand, Syngeneic, Open Approach */
"0XYK0Z0" = "1" /* Transplantation of Left Hand, Allogeneic, Open Approach */
"0XYK0Z1" = "1" /* Transplantation of Left Hand, Syngeneic, Open Approach */
"0Y0007Z" = "1" /* Alteration of Right Buttock with Autologous Tissue Substitute, Open Approach */
"0Y000JZ" = "1" /* Alteration of Right Buttock with Synthetic Substitute, Open Approach */
"0Y000KZ" = "1" /* Alteration of Right Buttock with Nonautologous Tissue Substitute, Open Approach */
"0Y000ZZ" = "1" /* Alteration of Right Buttock, Open Approach */
"0Y0037Z" = "1" /* Alteration of Right Buttock with Autologous Tissue Substitute, Percutaneous Approach */
"0Y003JZ" = "1" /* Alteration of Right Buttock with Synthetic Substitute, Percutaneous Approach */
"0Y003KZ" = "1" /* Alteration of Right Buttock with Nonautologous Tissue Substitute, Percutaneous Approach */
"0Y003ZZ" = "1" /* Alteration of Right Buttock, Percutaneous Approach */
"0Y0047Z" = "1" /* Alteration of Right Buttock with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y004JZ" = "1" /* Alteration of Right Buttock with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0Y004KZ" = "1" /* Alteration of Right Buttock with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y004ZZ" = "1" /* Alteration of Right Buttock, Percutaneous Endoscopic Approach */
"0Y0107Z" = "1" /* Alteration of Left Buttock with Autologous Tissue Substitute, Open Approach */
"0Y010JZ" = "1" /* Alteration of Left Buttock with Synthetic Substitute, Open Approach */
"0Y010KZ" = "1" /* Alteration of Left Buttock with Nonautologous Tissue Substitute, Open Approach */
"0Y010ZZ" = "1" /* Alteration of Left Buttock, Open Approach */
"0Y0137Z" = "1" /* Alteration of Left Buttock with Autologous Tissue Substitute, Percutaneous Approach */
"0Y013JZ" = "1" /* Alteration of Left Buttock with Synthetic Substitute, Percutaneous Approach */
"0Y013KZ" = "1" /* Alteration of Left Buttock with Nonautologous Tissue Substitute, Percutaneous Approach */
"0Y013ZZ" = "1" /* Alteration of Left Buttock, Percutaneous Approach */
"0Y0147Z" = "1" /* Alteration of Left Buttock with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y014JZ" = "1" /* Alteration of Left Buttock with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0Y014KZ" = "1" /* Alteration of Left Buttock with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y014ZZ" = "1" /* Alteration of Left Buttock, Percutaneous Endoscopic Approach */
"0Y0907Z" = "1" /* Alteration of Right Lower Extremity with Autologous Tissue Substitute, Open Approach */
"0Y090JZ" = "1" /* Alteration of Right Lower Extremity with Synthetic Substitute, Open Approach */
"0Y090KZ" = "1" /* Alteration of Right Lower Extremity with Nonautologous Tissue Substitute, Open Approach */
"0Y090ZZ" = "1" /* Alteration of Right Lower Extremity, Open Approach */
"0Y0937Z" = "1" /* Alteration of Right Lower Extremity with Autologous Tissue Substitute, Percutaneous Approach */
"0Y093JZ" = "1" /* Alteration of Right Lower Extremity with Synthetic Substitute, Percutaneous Approach */
"0Y093KZ" = "1" /* Alteration of Right Lower Extremity with Nonautologous Tissue Substitute, Percutaneous Approach */
"0Y093ZZ" = "1" /* Alteration of Right Lower Extremity, Percutaneous Approach */
"0Y0947Z" = "1" /* Alteration of Right Lower Extremity with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y094JZ" = "1" /* Alteration of Right Lower Extremity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0Y094KZ" = "1" /* Alteration of Right Lower Extremity with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y094ZZ" = "1" /* Alteration of Right Lower Extremity, Percutaneous Endoscopic Approach */
"0Y0B07Z" = "1" /* Alteration of Left Lower Extremity with Autologous Tissue Substitute, Open Approach */
"0Y0B0JZ" = "1" /* Alteration of Left Lower Extremity with Synthetic Substitute, Open Approach */
"0Y0B0KZ" = "1" /* Alteration of Left Lower Extremity with Nonautologous Tissue Substitute, Open Approach */
"0Y0B0ZZ" = "1" /* Alteration of Left Lower Extremity, Open Approach */
"0Y0B37Z" = "1" /* Alteration of Left Lower Extremity with Autologous Tissue Substitute, Percutaneous Approach */
"0Y0B3JZ" = "1" /* Alteration of Left Lower Extremity with Synthetic Substitute, Percutaneous Approach */
"0Y0B3KZ" = "1" /* Alteration of Left Lower Extremity with Nonautologous Tissue Substitute, Percutaneous Approach */
"0Y0B3ZZ" = "1" /* Alteration of Left Lower Extremity, Percutaneous Approach */
"0Y0B47Z" = "1" /* Alteration of Left Lower Extremity with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y0B4JZ" = "1" /* Alteration of Left Lower Extremity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0Y0B4KZ" = "1" /* Alteration of Left Lower Extremity with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y0B4ZZ" = "1" /* Alteration of Left Lower Extremity, Percutaneous Endoscopic Approach */
"0Y0C07Z" = "1" /* Alteration of Right Upper Leg with Autologous Tissue Substitute, Open Approach */
"0Y0C0JZ" = "1" /* Alteration of Right Upper Leg with Synthetic Substitute, Open Approach */
"0Y0C0KZ" = "1" /* Alteration of Right Upper Leg with Nonautologous Tissue Substitute, Open Approach */
"0Y0C0ZZ" = "1" /* Alteration of Right Upper Leg, Open Approach */
"0Y0C37Z" = "1" /* Alteration of Right Upper Leg with Autologous Tissue Substitute, Percutaneous Approach */
"0Y0C3JZ" = "1" /* Alteration of Right Upper Leg with Synthetic Substitute, Percutaneous Approach */
"0Y0C3KZ" = "1" /* Alteration of Right Upper Leg with Nonautologous Tissue Substitute, Percutaneous Approach */
"0Y0C3ZZ" = "1" /* Alteration of Right Upper Leg, Percutaneous Approach */
"0Y0C47Z" = "1" /* Alteration of Right Upper Leg with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y0C4JZ" = "1" /* Alteration of Right Upper Leg with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0Y0C4KZ" = "1" /* Alteration of Right Upper Leg with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y0C4ZZ" = "1" /* Alteration of Right Upper Leg, Percutaneous Endoscopic Approach */
"0Y0D07Z" = "1" /* Alteration of Left Upper Leg with Autologous Tissue Substitute, Open Approach */
"0Y0D0JZ" = "1" /* Alteration of Left Upper Leg with Synthetic Substitute, Open Approach */
"0Y0D0KZ" = "1" /* Alteration of Left Upper Leg with Nonautologous Tissue Substitute, Open Approach */
"0Y0D0ZZ" = "1" /* Alteration of Left Upper Leg, Open Approach */
"0Y0D37Z" = "1" /* Alteration of Left Upper Leg with Autologous Tissue Substitute, Percutaneous Approach */
"0Y0D3JZ" = "1" /* Alteration of Left Upper Leg with Synthetic Substitute, Percutaneous Approach */
"0Y0D3KZ" = "1" /* Alteration of Left Upper Leg with Nonautologous Tissue Substitute, Percutaneous Approach */
"0Y0D3ZZ" = "1" /* Alteration of Left Upper Leg, Percutaneous Approach */
"0Y0D47Z" = "1" /* Alteration of Left Upper Leg with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y0D4JZ" = "1" /* Alteration of Left Upper Leg with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0Y0D4KZ" = "1" /* Alteration of Left Upper Leg with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y0D4ZZ" = "1" /* Alteration of Left Upper Leg, Percutaneous Endoscopic Approach */
"0Y0F07Z" = "1" /* Alteration of Right Knee Region with Autologous Tissue Substitute, Open Approach */
"0Y0F0JZ" = "1" /* Alteration of Right Knee Region with Synthetic Substitute, Open Approach */
"0Y0F0KZ" = "1" /* Alteration of Right Knee Region with Nonautologous Tissue Substitute, Open Approach */
"0Y0F0ZZ" = "1" /* Alteration of Right Knee Region, Open Approach */
"0Y0F37Z" = "1" /* Alteration of Right Knee Region with Autologous Tissue Substitute, Percutaneous Approach */
"0Y0F3JZ" = "1" /* Alteration of Right Knee Region with Synthetic Substitute, Percutaneous Approach */
"0Y0F3KZ" = "1" /* Alteration of Right Knee Region with Nonautologous Tissue Substitute, Percutaneous Approach */
"0Y0F3ZZ" = "1" /* Alteration of Right Knee Region, Percutaneous Approach */
"0Y0F47Z" = "1" /* Alteration of Right Knee Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y0F4JZ" = "1" /* Alteration of Right Knee Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0Y0F4KZ" = "1" /* Alteration of Right Knee Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y0F4ZZ" = "1" /* Alteration of Right Knee Region, Percutaneous Endoscopic Approach */
"0Y0G07Z" = "1" /* Alteration of Left Knee Region with Autologous Tissue Substitute, Open Approach */
"0Y0G0JZ" = "1" /* Alteration of Left Knee Region with Synthetic Substitute, Open Approach */
"0Y0G0KZ" = "1" /* Alteration of Left Knee Region with Nonautologous Tissue Substitute, Open Approach */
"0Y0G0ZZ" = "1" /* Alteration of Left Knee Region, Open Approach */
"0Y0G37Z" = "1" /* Alteration of Left Knee Region with Autologous Tissue Substitute, Percutaneous Approach */
"0Y0G3JZ" = "1" /* Alteration of Left Knee Region with Synthetic Substitute, Percutaneous Approach */
"0Y0G3KZ" = "1" /* Alteration of Left Knee Region with Nonautologous Tissue Substitute, Percutaneous Approach */
"0Y0G3ZZ" = "1" /* Alteration of Left Knee Region, Percutaneous Approach */
"0Y0G47Z" = "1" /* Alteration of Left Knee Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y0G4JZ" = "1" /* Alteration of Left Knee Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0Y0G4KZ" = "1" /* Alteration of Left Knee Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y0G4ZZ" = "1" /* Alteration of Left Knee Region, Percutaneous Endoscopic Approach */
"0Y0H07Z" = "1" /* Alteration of Right Lower Leg with Autologous Tissue Substitute, Open Approach */
"0Y0H0JZ" = "1" /* Alteration of Right Lower Leg with Synthetic Substitute, Open Approach */
"0Y0H0KZ" = "1" /* Alteration of Right Lower Leg with Nonautologous Tissue Substitute, Open Approach */
"0Y0H0ZZ" = "1" /* Alteration of Right Lower Leg, Open Approach */
"0Y0H37Z" = "1" /* Alteration of Right Lower Leg with Autologous Tissue Substitute, Percutaneous Approach */
"0Y0H3JZ" = "1" /* Alteration of Right Lower Leg with Synthetic Substitute, Percutaneous Approach */
"0Y0H3KZ" = "1" /* Alteration of Right Lower Leg with Nonautologous Tissue Substitute, Percutaneous Approach */
"0Y0H3ZZ" = "1" /* Alteration of Right Lower Leg, Percutaneous Approach */
"0Y0H47Z" = "1" /* Alteration of Right Lower Leg with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y0H4JZ" = "1" /* Alteration of Right Lower Leg with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0Y0H4KZ" = "1" /* Alteration of Right Lower Leg with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y0H4ZZ" = "1" /* Alteration of Right Lower Leg, Percutaneous Endoscopic Approach */
"0Y0J07Z" = "1" /* Alteration of Left Lower Leg with Autologous Tissue Substitute, Open Approach */
"0Y0J0JZ" = "1" /* Alteration of Left Lower Leg with Synthetic Substitute, Open Approach */
"0Y0J0KZ" = "1" /* Alteration of Left Lower Leg with Nonautologous Tissue Substitute, Open Approach */
"0Y0J0ZZ" = "1" /* Alteration of Left Lower Leg, Open Approach */
"0Y0J37Z" = "1" /* Alteration of Left Lower Leg with Autologous Tissue Substitute, Percutaneous Approach */
"0Y0J3JZ" = "1" /* Alteration of Left Lower Leg with Synthetic Substitute, Percutaneous Approach */
"0Y0J3KZ" = "1" /* Alteration of Left Lower Leg with Nonautologous Tissue Substitute, Percutaneous Approach */
"0Y0J3ZZ" = "1" /* Alteration of Left Lower Leg, Percutaneous Approach */
"0Y0J47Z" = "1" /* Alteration of Left Lower Leg with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y0J4JZ" = "1" /* Alteration of Left Lower Leg with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0Y0J4KZ" = "1" /* Alteration of Left Lower Leg with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y0J4ZZ" = "1" /* Alteration of Left Lower Leg, Percutaneous Endoscopic Approach */
"0Y0K07Z" = "1" /* Alteration of Right Ankle Region with Autologous Tissue Substitute, Open Approach */
"0Y0K0JZ" = "1" /* Alteration of Right Ankle Region with Synthetic Substitute, Open Approach */
"0Y0K0KZ" = "1" /* Alteration of Right Ankle Region with Nonautologous Tissue Substitute, Open Approach */
"0Y0K0ZZ" = "1" /* Alteration of Right Ankle Region, Open Approach */
"0Y0K37Z" = "1" /* Alteration of Right Ankle Region with Autologous Tissue Substitute, Percutaneous Approach */
"0Y0K3JZ" = "1" /* Alteration of Right Ankle Region with Synthetic Substitute, Percutaneous Approach */
"0Y0K3KZ" = "1" /* Alteration of Right Ankle Region with Nonautologous Tissue Substitute, Percutaneous Approach */
"0Y0K3ZZ" = "1" /* Alteration of Right Ankle Region, Percutaneous Approach */
"0Y0K47Z" = "1" /* Alteration of Right Ankle Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y0K4JZ" = "1" /* Alteration of Right Ankle Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0Y0K4KZ" = "1" /* Alteration of Right Ankle Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y0K4ZZ" = "1" /* Alteration of Right Ankle Region, Percutaneous Endoscopic Approach */
"0Y0L07Z" = "1" /* Alteration of Left Ankle Region with Autologous Tissue Substitute, Open Approach */
"0Y0L0JZ" = "1" /* Alteration of Left Ankle Region with Synthetic Substitute, Open Approach */
"0Y0L0KZ" = "1" /* Alteration of Left Ankle Region with Nonautologous Tissue Substitute, Open Approach */
"0Y0L0ZZ" = "1" /* Alteration of Left Ankle Region, Open Approach */
"0Y0L37Z" = "1" /* Alteration of Left Ankle Region with Autologous Tissue Substitute, Percutaneous Approach */
"0Y0L3JZ" = "1" /* Alteration of Left Ankle Region with Synthetic Substitute, Percutaneous Approach */
"0Y0L3KZ" = "1" /* Alteration of Left Ankle Region with Nonautologous Tissue Substitute, Percutaneous Approach */
"0Y0L3ZZ" = "1" /* Alteration of Left Ankle Region, Percutaneous Approach */
"0Y0L47Z" = "1" /* Alteration of Left Ankle Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y0L4JZ" = "1" /* Alteration of Left Ankle Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0Y0L4KZ" = "1" /* Alteration of Left Ankle Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0Y0L4ZZ" = "1" /* Alteration of Left Ankle Region, Percutaneous Endoscopic Approach */
"0Y300ZZ" = "1" /* Control Bleeding in Right Buttock, Open Approach */
"0Y303ZZ" = "1" /* Control Bleeding in Right Buttock, Percutaneous Approach */
"0Y304ZZ" = "1" /* Control Bleeding in Right Buttock, Percutaneous Endoscopic Approach */
"0Y310ZZ" = "1" /* Control Bleeding in Left Buttock, Open Approach */
"0Y313ZZ" = "1" /* Control Bleeding in Left Buttock, Percutaneous Approach */
"0Y314ZZ" = "1" /* Control Bleeding in Left Buttock, Percutaneous Endoscopic Approach */
"0Y350ZZ" = "1" /* Control Bleeding in Right Inguinal Region, Open Approach */
"0Y353ZZ" = "1" /* Control Bleeding in Right Inguinal Region, Percutaneous Approach */
"0Y354ZZ" = "1" /* Control Bleeding in Right Inguinal Region, Percutaneous Endoscopic Approach */
"0Y360ZZ" = "1" /* Control Bleeding in Left Inguinal Region, Open Approach */
"0Y363ZZ" = "1" /* Control Bleeding in Left Inguinal Region, Percutaneous Approach */
"0Y364ZZ" = "1" /* Control Bleeding in Left Inguinal Region, Percutaneous Endoscopic Approach */
"0Y370ZZ" = "1" /* Control Bleeding in Right Femoral Region, Open Approach */
"0Y373ZZ" = "1" /* Control Bleeding in Right Femoral Region, Percutaneous Approach */
"0Y374ZZ" = "1" /* Control Bleeding in Right Femoral Region, Percutaneous Endoscopic Approach */
"0Y380ZZ" = "1" /* Control Bleeding in Left Femoral Region, Open Approach */
"0Y383ZZ" = "1" /* Control Bleeding in Left Femoral Region, Percutaneous Approach */
"0Y384ZZ" = "1" /* Control Bleeding in Left Femoral Region, Percutaneous Endoscopic Approach */
"0Y390ZZ" = "1" /* Control Bleeding in Right Lower Extremity, Open Approach */
"0Y393ZZ" = "1" /* Control Bleeding in Right Lower Extremity, Percutaneous Approach */
"0Y394ZZ" = "1" /* Control Bleeding in Right Lower Extremity, Percutaneous Endoscopic Approach */
"0Y3B0ZZ" = "1" /* Control Bleeding in Left Lower Extremity, Open Approach */
"0Y3B3ZZ" = "1" /* Control Bleeding in Left Lower Extremity, Percutaneous Approach */
"0Y3B4ZZ" = "1" /* Control Bleeding in Left Lower Extremity, Percutaneous Endoscopic Approach */
"0Y3C0ZZ" = "1" /* Control Bleeding in Right Upper Leg, Open Approach */
"0Y3C3ZZ" = "1" /* Control Bleeding in Right Upper Leg, Percutaneous Approach */
"0Y3C4ZZ" = "1" /* Control Bleeding in Right Upper Leg, Percutaneous Endoscopic Approach */
"0Y3D0ZZ" = "1" /* Control Bleeding in Left Upper Leg, Open Approach */
"0Y3D3ZZ" = "1" /* Control Bleeding in Left Upper Leg, Percutaneous Approach */
"0Y3D4ZZ" = "1" /* Control Bleeding in Left Upper Leg, Percutaneous Endoscopic Approach */
"0Y3F0ZZ" = "1" /* Control Bleeding in Right Knee Region, Open Approach */
"0Y3F3ZZ" = "1" /* Control Bleeding in Right Knee Region, Percutaneous Approach */
"0Y3F4ZZ" = "1" /* Control Bleeding in Right Knee Region, Percutaneous Endoscopic Approach */
"0Y3G0ZZ" = "1" /* Control Bleeding in Left Knee Region, Open Approach */
"0Y3G3ZZ" = "1" /* Control Bleeding in Left Knee Region, Percutaneous Approach */
"0Y3G4ZZ" = "1" /* Control Bleeding in Left Knee Region, Percutaneous Endoscopic Approach */
"0Y3H0ZZ" = "1" /* Control Bleeding in Right Lower Leg, Open Approach */
"0Y3H3ZZ" = "1" /* Control Bleeding in Right Lower Leg, Percutaneous Approach */
"0Y3H4ZZ" = "1" /* Control Bleeding in Right Lower Leg, Percutaneous Endoscopic Approach */
"0Y3J0ZZ" = "1" /* Control Bleeding in Left Lower Leg, Open Approach */
"0Y3J3ZZ" = "1" /* Control Bleeding in Left Lower Leg, Percutaneous Approach */
"0Y3J4ZZ" = "1" /* Control Bleeding in Left Lower Leg, Percutaneous Endoscopic Approach */
"0Y3K0ZZ" = "1" /* Control Bleeding in Right Ankle Region, Open Approach */
"0Y3K3ZZ" = "1" /* Control Bleeding in Right Ankle Region, Percutaneous Approach */
"0Y3K4ZZ" = "1" /* Control Bleeding in Right Ankle Region, Percutaneous Endoscopic Approach */
"0Y3L0ZZ" = "1" /* Control Bleeding in Left Ankle Region, Open Approach */
"0Y3L3ZZ" = "1" /* Control Bleeding in Left Ankle Region, Percutaneous Approach */
"0Y3L4ZZ" = "1" /* Control Bleeding in Left Ankle Region, Percutaneous Endoscopic Approach */
"0Y3M0ZZ" = "1" /* Control Bleeding in Right Foot, Open Approach */
"0Y3M3ZZ" = "1" /* Control Bleeding in Right Foot, Percutaneous Approach */
"0Y3M4ZZ" = "1" /* Control Bleeding in Right Foot, Percutaneous Endoscopic Approach */
"0Y3N0ZZ" = "1" /* Control Bleeding in Left Foot, Open Approach */
"0Y3N3ZZ" = "1" /* Control Bleeding in Left Foot, Percutaneous Approach */
"0Y3N4ZZ" = "1" /* Control Bleeding in Left Foot, Percutaneous Endoscopic Approach */
"0Y620ZZ" = "1" /* Detachment at Right Hindquarter, Open Approach */
"0Y630ZZ" = "1" /* Detachment at Left Hindquarter, Open Approach */
"0Y640ZZ" = "1" /* Detachment at Bilateral Hindquarter, Open Approach */
"0Y670ZZ" = "1" /* Detachment at Right Femoral Region, Open Approach */
"0Y680ZZ" = "1" /* Detachment at Left Femoral Region, Open Approach */
"0Y6C0Z1" = "1" /* Detachment at Right Upper Leg, High, Open Approach */
"0Y6C0Z2" = "1" /* Detachment at Right Upper Leg, Mid, Open Approach */
"0Y6C0Z3" = "1" /* Detachment at Right Upper Leg, Low, Open Approach */
"0Y6D0Z1" = "1" /* Detachment at Left Upper Leg, High, Open Approach */
"0Y6D0Z2" = "1" /* Detachment at Left Upper Leg, Mid, Open Approach */
"0Y6D0Z3" = "1" /* Detachment at Left Upper Leg, Low, Open Approach */
"0Y6F0ZZ" = "1" /* Detachment at Right Knee Region, Open Approach */
"0Y6G0ZZ" = "1" /* Detachment at Left Knee Region, Open Approach */
"0Y6H0Z1" = "1" /* Detachment at Right Lower Leg, High, Open Approach */
"0Y6H0Z2" = "1" /* Detachment at Right Lower Leg, Mid, Open Approach */
"0Y6H0Z3" = "1" /* Detachment at Right Lower Leg, Low, Open Approach */
"0Y6J0Z1" = "1" /* Detachment at Left Lower Leg, High, Open Approach */
"0Y6J0Z2" = "1" /* Detachment at Left Lower Leg, Mid, Open Approach */
"0Y6J0Z3" = "1" /* Detachment at Left Lower Leg, Low, Open Approach */
"0Y6M0Z0" = "1" /* Detachment at Right Foot, Complete, Open Approach */
"0Y6M0Z4" = "1" /* Detachment at Right Foot, Complete 1st Ray, Open Approach */
"0Y6M0Z5" = "1" /* Detachment at Right Foot, Complete 2nd Ray, Open Approach */
"0Y6M0Z6" = "1" /* Detachment at Right Foot, Complete 3rd Ray, Open Approach */
"0Y6M0Z7" = "1" /* Detachment at Right Foot, Complete 4th Ray, Open Approach */
"0Y6M0Z8" = "1" /* Detachment at Right Foot, Complete 5th Ray, Open Approach */
"0Y6M0Z9" = "1" /* Detachment at Right Foot, Partial 1st Ray, Open Approach */
"0Y6M0ZB" = "1" /* Detachment at Right Foot, Partial 2nd Ray, Open Approach */
"0Y6M0ZC" = "1" /* Detachment at Right Foot, Partial 3rd Ray, Open Approach */
"0Y6M0ZD" = "1" /* Detachment at Right Foot, Partial 4th Ray, Open Approach */
"0Y6M0ZF" = "1" /* Detachment at Right Foot, Partial 5th Ray, Open Approach */
"0Y6N0Z0" = "1" /* Detachment at Left Foot, Complete, Open Approach */
"0Y6N0Z4" = "1" /* Detachment at Left Foot, Complete 1st Ray, Open Approach */
"0Y6N0Z5" = "1" /* Detachment at Left Foot, Complete 2nd Ray, Open Approach */
"0Y6N0Z6" = "1" /* Detachment at Left Foot, Complete 3rd Ray, Open Approach */
"0Y6N0Z7" = "1" /* Detachment at Left Foot, Complete 4th Ray, Open Approach */
"0Y6N0Z8" = "1" /* Detachment at Left Foot, Complete 5th Ray, Open Approach */
"0Y6N0Z9" = "1" /* Detachment at Left Foot, Partial 1st Ray, Open Approach */
"0Y6N0ZB" = "1" /* Detachment at Left Foot, Partial 2nd Ray, Open Approach */
"0Y6N0ZC" = "1" /* Detachment at Left Foot, Partial 3rd Ray, Open Approach */
"0Y6N0ZD" = "1" /* Detachment at Left Foot, Partial 4th Ray, Open Approach */
"0Y6N0ZF" = "1" /* Detachment at Left Foot, Partial 5th Ray, Open Approach */
"0Y6P0Z0" = "1" /* Detachment at Right 1st Toe, Complete, Open Approach */
"0Y6P0Z1" = "1" /* Detachment at Right 1st Toe, High, Open Approach */
"0Y6P0Z2" = "1" /* Detachment at Right 1st Toe, Mid, Open Approach */
"0Y6P0Z3" = "1" /* Detachment at Right 1st Toe, Low, Open Approach */
"0Y6Q0Z0" = "1" /* Detachment at Left 1st Toe, Complete, Open Approach */
"0Y6Q0Z1" = "1" /* Detachment at Left 1st Toe, High, Open Approach */
"0Y6Q0Z2" = "1" /* Detachment at Left 1st Toe, Mid, Open Approach */
"0Y6Q0Z3" = "1" /* Detachment at Left 1st Toe, Low, Open Approach */
"0Y6R0Z0" = "1" /* Detachment at Right 2nd Toe, Complete, Open Approach */
"0Y6R0Z1" = "1" /* Detachment at Right 2nd Toe, High, Open Approach */
"0Y6R0Z2" = "1" /* Detachment at Right 2nd Toe, Mid, Open Approach */
"0Y6R0Z3" = "1" /* Detachment at Right 2nd Toe, Low, Open Approach */
"0Y6S0Z0" = "1" /* Detachment at Left 2nd Toe, Complete, Open Approach */
"0Y6S0Z1" = "1" /* Detachment at Left 2nd Toe, High, Open Approach */
"0Y6S0Z2" = "1" /* Detachment at Left 2nd Toe, Mid, Open Approach */
"0Y6S0Z3" = "1" /* Detachment at Left 2nd Toe, Low, Open Approach */
"0Y6T0Z0" = "1" /* Detachment at Right 3rd Toe, Complete, Open Approach */
"0Y6T0Z1" = "1" /* Detachment at Right 3rd Toe, High, Open Approach */
"0Y6T0Z2" = "1" /* Detachment at Right 3rd Toe, Mid, Open Approach */
"0Y6T0Z3" = "1" /* Detachment at Right 3rd Toe, Low, Open Approach */
"0Y6U0Z0" = "1" /* Detachment at Left 3rd Toe, Complete, Open Approach */
"0Y6U0Z1" = "1" /* Detachment at Left 3rd Toe, High, Open Approach */
"0Y6U0Z2" = "1" /* Detachment at Left 3rd Toe, Mid, Open Approach */
"0Y6U0Z3" = "1" /* Detachment at Left 3rd Toe, Low, Open Approach */
"0Y6V0Z0" = "1" /* Detachment at Right 4th Toe, Complete, Open Approach */
"0Y6V0Z1" = "1" /* Detachment at Right 4th Toe, High, Open Approach */
"0Y6V0Z2" = "1" /* Detachment at Right 4th Toe, Mid, Open Approach */
"0Y6V0Z3" = "1" /* Detachment at Right 4th Toe, Low, Open Approach */
"0Y6W0Z0" = "1" /* Detachment at Left 4th Toe, Complete, Open Approach */
"0Y6W0Z1" = "1" /* Detachment at Left 4th Toe, High, Open Approach */
"0Y6W0Z2" = "1" /* Detachment at Left 4th Toe, Mid, Open Approach */
"0Y6W0Z3" = "1" /* Detachment at Left 4th Toe, Low, Open Approach */
"0Y6X0Z0" = "1" /* Detachment at Right 5th Toe, Complete, Open Approach */
"0Y6X0Z1" = "1" /* Detachment at Right 5th Toe, High, Open Approach */
"0Y6X0Z2" = "1" /* Detachment at Right 5th Toe, Mid, Open Approach */
"0Y6X0Z3" = "1" /* Detachment at Right 5th Toe, Low, Open Approach */
"0Y6Y0Z0" = "1" /* Detachment at Left 5th Toe, Complete, Open Approach */
"0Y6Y0Z1" = "1" /* Detachment at Left 5th Toe, High, Open Approach */
"0Y6Y0Z2" = "1" /* Detachment at Left 5th Toe, Mid, Open Approach */
"0Y6Y0Z3" = "1" /* Detachment at Left 5th Toe, Low, Open Approach */
"0Y9500Z" = "1" /* Drainage of Right Inguinal Region with Drainage Device, Open Approach */
"0Y950ZX" = "1" /* Drainage of Right Inguinal Region, Open Approach, Diagnostic */
"0Y950ZZ" = "1" /* Drainage of Right Inguinal Region, Open Approach */
"0Y9540Z" = "1" /* Drainage of Right Inguinal Region with Drainage Device, Percutaneous Endoscopic Approach */
"0Y954ZX" = "1" /* Drainage of Right Inguinal Region, Percutaneous Endoscopic Approach, Diagnostic */
"0Y954ZZ" = "1" /* Drainage of Right Inguinal Region, Percutaneous Endoscopic Approach */
"0Y9600Z" = "1" /* Drainage of Left Inguinal Region with Drainage Device, Open Approach */
"0Y960ZX" = "1" /* Drainage of Left Inguinal Region, Open Approach, Diagnostic */
"0Y960ZZ" = "1" /* Drainage of Left Inguinal Region, Open Approach */
"0Y9640Z" = "1" /* Drainage of Left Inguinal Region with Drainage Device, Percutaneous Endoscopic Approach */
"0Y964ZX" = "1" /* Drainage of Left Inguinal Region, Percutaneous Endoscopic Approach, Diagnostic */
"0Y964ZZ" = "1" /* Drainage of Left Inguinal Region, Percutaneous Endoscopic Approach */
"0YB00ZZ" = "1" /* Excision of Right Buttock, Open Approach */
"0YB03ZZ" = "1" /* Excision of Right Buttock, Percutaneous Approach */
"0YB04ZZ" = "1" /* Excision of Right Buttock, Percutaneous Endoscopic Approach */
"0YB10ZZ" = "1" /* Excision of Left Buttock, Open Approach */
"0YB13ZZ" = "1" /* Excision of Left Buttock, Percutaneous Approach */
"0YB14ZZ" = "1" /* Excision of Left Buttock, Percutaneous Endoscopic Approach */
"0YB50ZX" = "1" /* Excision of Right Inguinal Region, Open Approach, Diagnostic */
"0YB50ZZ" = "1" /* Excision of Right Inguinal Region, Open Approach */
"0YB53ZX" = "1" /* Excision of Right Inguinal Region, Percutaneous Approach, Diagnostic */
"0YB53ZZ" = "1" /* Excision of Right Inguinal Region, Percutaneous Approach */
"0YB54ZX" = "1" /* Excision of Right Inguinal Region, Percutaneous Endoscopic Approach, Diagnostic */
"0YB54ZZ" = "1" /* Excision of Right Inguinal Region, Percutaneous Endoscopic Approach */
"0YB60ZX" = "1" /* Excision of Left Inguinal Region, Open Approach, Diagnostic */
"0YB60ZZ" = "1" /* Excision of Left Inguinal Region, Open Approach */
"0YB63ZX" = "1" /* Excision of Left Inguinal Region, Percutaneous Approach, Diagnostic */
"0YB63ZZ" = "1" /* Excision of Left Inguinal Region, Percutaneous Approach */
"0YB64ZX" = "1" /* Excision of Left Inguinal Region, Percutaneous Endoscopic Approach, Diagnostic */
"0YB64ZZ" = "1" /* Excision of Left Inguinal Region, Percutaneous Endoscopic Approach */
"0YB70ZX" = "1" /* Excision of Right Femoral Region, Open Approach, Diagnostic */
"0YB70ZZ" = "1" /* Excision of Right Femoral Region, Open Approach */
"0YB73ZX" = "1" /* Excision of Right Femoral Region, Percutaneous Approach, Diagnostic */
"0YB73ZZ" = "1" /* Excision of Right Femoral Region, Percutaneous Approach */
"0YB74ZX" = "1" /* Excision of Right Femoral Region, Percutaneous Endoscopic Approach, Diagnostic */
"0YB74ZZ" = "1" /* Excision of Right Femoral Region, Percutaneous Endoscopic Approach */
"0YB80ZX" = "1" /* Excision of Left Femoral Region, Open Approach, Diagnostic */
"0YB80ZZ" = "1" /* Excision of Left Femoral Region, Open Approach */
"0YB83ZX" = "1" /* Excision of Left Femoral Region, Percutaneous Approach, Diagnostic */
"0YB83ZZ" = "1" /* Excision of Left Femoral Region, Percutaneous Approach */
"0YB84ZX" = "1" /* Excision of Left Femoral Region, Percutaneous Endoscopic Approach, Diagnostic */
"0YB84ZZ" = "1" /* Excision of Left Femoral Region, Percutaneous Endoscopic Approach */
"0YB90ZZ" = "1" /* Excision of Right Lower Extremity, Open Approach */
"0YB93ZZ" = "1" /* Excision of Right Lower Extremity, Percutaneous Approach */
"0YB94ZZ" = "1" /* Excision of Right Lower Extremity, Percutaneous Endoscopic Approach */
"0YBB0ZZ" = "1" /* Excision of Left Lower Extremity, Open Approach */
"0YBB3ZZ" = "1" /* Excision of Left Lower Extremity, Percutaneous Approach */
"0YBB4ZZ" = "1" /* Excision of Left Lower Extremity, Percutaneous Endoscopic Approach */
"0YBC0ZZ" = "1" /* Excision of Right Upper Leg, Open Approach */
"0YBC3ZZ" = "1" /* Excision of Right Upper Leg, Percutaneous Approach */
"0YBC4ZZ" = "1" /* Excision of Right Upper Leg, Percutaneous Endoscopic Approach */
"0YBD0ZZ" = "1" /* Excision of Left Upper Leg, Open Approach */
"0YBD3ZZ" = "1" /* Excision of Left Upper Leg, Percutaneous Approach */
"0YBD4ZZ" = "1" /* Excision of Left Upper Leg, Percutaneous Endoscopic Approach */
"0YBF0ZZ" = "1" /* Excision of Right Knee Region, Open Approach */
"0YBF3ZZ" = "1" /* Excision of Right Knee Region, Percutaneous Approach */
"0YBF4ZZ" = "1" /* Excision of Right Knee Region, Percutaneous Endoscopic Approach */
"0YBG0ZZ" = "1" /* Excision of Left Knee Region, Open Approach */
"0YBG3ZZ" = "1" /* Excision of Left Knee Region, Percutaneous Approach */
"0YBG4ZZ" = "1" /* Excision of Left Knee Region, Percutaneous Endoscopic Approach */
"0YBH0ZZ" = "1" /* Excision of Right Lower Leg, Open Approach */
"0YBH3ZZ" = "1" /* Excision of Right Lower Leg, Percutaneous Approach */
"0YBH4ZZ" = "1" /* Excision of Right Lower Leg, Percutaneous Endoscopic Approach */
"0YBJ0ZZ" = "1" /* Excision of Left Lower Leg, Open Approach */
"0YBJ3ZZ" = "1" /* Excision of Left Lower Leg, Percutaneous Approach */
"0YBJ4ZZ" = "1" /* Excision of Left Lower Leg, Percutaneous Endoscopic Approach */
"0YBK0ZZ" = "1" /* Excision of Right Ankle Region, Open Approach */
"0YBK3ZZ" = "1" /* Excision of Right Ankle Region, Percutaneous Approach */
"0YBK4ZZ" = "1" /* Excision of Right Ankle Region, Percutaneous Endoscopic Approach */
"0YBL0ZZ" = "1" /* Excision of Left Ankle Region, Open Approach */
"0YBL3ZZ" = "1" /* Excision of Left Ankle Region, Percutaneous Approach */
"0YBL4ZZ" = "1" /* Excision of Left Ankle Region, Percutaneous Endoscopic Approach */
"0YBM0ZZ" = "1" /* Excision of Right Foot, Open Approach */
"0YBM3ZZ" = "1" /* Excision of Right Foot, Percutaneous Approach */
"0YBM4ZZ" = "1" /* Excision of Right Foot, Percutaneous Endoscopic Approach */
"0YBN0ZZ" = "1" /* Excision of Left Foot, Open Approach */
"0YBN3ZZ" = "1" /* Excision of Left Foot, Percutaneous Approach */
"0YBN4ZZ" = "1" /* Excision of Left Foot, Percutaneous Endoscopic Approach */
"0YH001Z" = "1" /* Insertion of Radioactive Element into Right Buttock, Open Approach */
"0YH031Z" = "1" /* Insertion of Radioactive Element into Right Buttock, Percutaneous Approach */
"0YH041Z" = "1" /* Insertion of Radioactive Element into Right Buttock, Percutaneous Endoscopic Approach */
"0YH101Z" = "1" /* Insertion of Radioactive Element into Left Buttock, Open Approach */
"0YH131Z" = "1" /* Insertion of Radioactive Element into Left Buttock, Percutaneous Approach */
"0YH141Z" = "1" /* Insertion of Radioactive Element into Left Buttock, Percutaneous Endoscopic Approach */
"0YH501Z" = "1" /* Insertion of Radioactive Element into Right Inguinal Region, Open Approach */
"0YH531Z" = "1" /* Insertion of Radioactive Element into Right Inguinal Region, Percutaneous Approach */
"0YH541Z" = "1" /* Insertion of Radioactive Element into Right Inguinal Region, Percutaneous Endoscopic Approach */
"0YH601Z" = "1" /* Insertion of Radioactive Element into Left Inguinal Region, Open Approach */
"0YH631Z" = "1" /* Insertion of Radioactive Element into Left Inguinal Region, Percutaneous Approach */
"0YH641Z" = "1" /* Insertion of Radioactive Element into Left Inguinal Region, Percutaneous Endoscopic Approach */
"0YH701Z" = "1" /* Insertion of Radioactive Element into Right Femoral Region, Open Approach */
"0YH731Z" = "1" /* Insertion of Radioactive Element into Right Femoral Region, Percutaneous Approach */
"0YH741Z" = "1" /* Insertion of Radioactive Element into Right Femoral Region, Percutaneous Endoscopic Approach */
"0YH801Z" = "1" /* Insertion of Radioactive Element into Left Femoral Region, Open Approach */
"0YH831Z" = "1" /* Insertion of Radioactive Element into Left Femoral Region, Percutaneous Approach */
"0YH841Z" = "1" /* Insertion of Radioactive Element into Left Femoral Region, Percutaneous Endoscopic Approach */
"0YH901Z" = "1" /* Insertion of Radioactive Element into Right Lower Extremity, Open Approach */
"0YH931Z" = "1" /* Insertion of Radioactive Element into Right Lower Extremity, Percutaneous Approach */
"0YH941Z" = "1" /* Insertion of Radioactive Element into Right Lower Extremity, Percutaneous Endoscopic Approach */
"0YHB01Z" = "1" /* Insertion of Radioactive Element into Left Lower Extremity, Open Approach */
"0YHB31Z" = "1" /* Insertion of Radioactive Element into Left Lower Extremity, Percutaneous Approach */
"0YHB41Z" = "1" /* Insertion of Radioactive Element into Left Lower Extremity, Percutaneous Endoscopic Approach */
"0YHC01Z" = "1" /* Insertion of Radioactive Element into Right Upper Leg, Open Approach */
"0YHC31Z" = "1" /* Insertion of Radioactive Element into Right Upper Leg, Percutaneous Approach */
"0YHC41Z" = "1" /* Insertion of Radioactive Element into Right Upper Leg, Percutaneous Endoscopic Approach */
"0YHD01Z" = "1" /* Insertion of Radioactive Element into Left Upper Leg, Open Approach */
"0YHD31Z" = "1" /* Insertion of Radioactive Element into Left Upper Leg, Percutaneous Approach */
"0YHD41Z" = "1" /* Insertion of Radioactive Element into Left Upper Leg, Percutaneous Endoscopic Approach */
"0YHF01Z" = "1" /* Insertion of Radioactive Element into Right Knee Region, Open Approach */
"0YHF31Z" = "1" /* Insertion of Radioactive Element into Right Knee Region, Percutaneous Approach */
"0YHF41Z" = "1" /* Insertion of Radioactive Element into Right Knee Region, Percutaneous Endoscopic Approach */
"0YHG01Z" = "1" /* Insertion of Radioactive Element into Left Knee Region, Open Approach */
"0YHG31Z" = "1" /* Insertion of Radioactive Element into Left Knee Region, Percutaneous Approach */
"0YHG41Z" = "1" /* Insertion of Radioactive Element into Left Knee Region, Percutaneous Endoscopic Approach */
"0YHH01Z" = "1" /* Insertion of Radioactive Element into Right Lower Leg, Open Approach */
"0YHH31Z" = "1" /* Insertion of Radioactive Element into Right Lower Leg, Percutaneous Approach */
"0YHH41Z" = "1" /* Insertion of Radioactive Element into Right Lower Leg, Percutaneous Endoscopic Approach */
"0YHJ01Z" = "1" /* Insertion of Radioactive Element into Left Lower Leg, Open Approach */
"0YHJ31Z" = "1" /* Insertion of Radioactive Element into Left Lower Leg, Percutaneous Approach */
"0YHJ41Z" = "1" /* Insertion of Radioactive Element into Left Lower Leg, Percutaneous Endoscopic Approach */
"0YHK01Z" = "1" /* Insertion of Radioactive Element into Right Ankle Region, Open Approach */
"0YHK31Z" = "1" /* Insertion of Radioactive Element into Right Ankle Region, Percutaneous Approach */
"0YHK41Z" = "1" /* Insertion of Radioactive Element into Right Ankle Region, Percutaneous Endoscopic Approach */
"0YHL01Z" = "1" /* Insertion of Radioactive Element into Left Ankle Region, Open Approach */
"0YHL31Z" = "1" /* Insertion of Radioactive Element into Left Ankle Region, Percutaneous Approach */
"0YHL41Z" = "1" /* Insertion of Radioactive Element into Left Ankle Region, Percutaneous Endoscopic Approach */
"0YHM01Z" = "1" /* Insertion of Radioactive Element into Right Foot, Open Approach */
"0YHM31Z" = "1" /* Insertion of Radioactive Element into Right Foot, Percutaneous Approach */
"0YHM41Z" = "1" /* Insertion of Radioactive Element into Right Foot, Percutaneous Endoscopic Approach */
"0YHN01Z" = "1" /* Insertion of Radioactive Element into Left Foot, Open Approach */
"0YHN31Z" = "1" /* Insertion of Radioactive Element into Left Foot, Percutaneous Approach */
"0YHN41Z" = "1" /* Insertion of Radioactive Element into Left Foot, Percutaneous Endoscopic Approach */
"0YJ50ZZ" = "1" /* Inspection of Right Inguinal Region, Open Approach */
"0YJ54ZZ" = "1" /* Inspection of Right Inguinal Region, Percutaneous Endoscopic Approach */
"0YJ60ZZ" = "1" /* Inspection of Left Inguinal Region, Open Approach */
"0YJ64ZZ" = "1" /* Inspection of Left Inguinal Region, Percutaneous Endoscopic Approach */
"0YJ70ZZ" = "1" /* Inspection of Right Femoral Region, Open Approach */
"0YJ74ZZ" = "1" /* Inspection of Right Femoral Region, Percutaneous Endoscopic Approach */
"0YJ84ZZ" = "1" /* Inspection of Left Femoral Region, Percutaneous Endoscopic Approach */
"0YJA0ZZ" = "1" /* Inspection of Bilateral Inguinal Region, Open Approach */
"0YJA4ZZ" = "1" /* Inspection of Bilateral Inguinal Region, Percutaneous Endoscopic Approach */
"0YJE4ZZ" = "1" /* Inspection of Bilateral Femoral Region, Percutaneous Endoscopic Approach */
"0YM00ZZ" = "1" /* Reattachment of Right Buttock, Open Approach */
"0YM10ZZ" = "1" /* Reattachment of Left Buttock, Open Approach */
"0YM20ZZ" = "1" /* Reattachment of Right Hindquarter, Open Approach */
"0YM30ZZ" = "1" /* Reattachment of Left Hindquarter, Open Approach */
"0YM40ZZ" = "1" /* Reattachment of Bilateral Hindquarter, Open Approach */
"0YM50ZZ" = "1" /* Reattachment of Right Inguinal Region, Open Approach */
"0YM60ZZ" = "1" /* Reattachment of Left Inguinal Region, Open Approach */
"0YM70ZZ" = "1" /* Reattachment of Right Femoral Region, Open Approach */
"0YM80ZZ" = "1" /* Reattachment of Left Femoral Region, Open Approach */
"0YM90ZZ" = "1" /* Reattachment of Right Lower Extremity, Open Approach */
"0YMB0ZZ" = "1" /* Reattachment of Left Lower Extremity, Open Approach */
"0YMC0ZZ" = "1" /* Reattachment of Right Upper Leg, Open Approach */
"0YMD0ZZ" = "1" /* Reattachment of Left Upper Leg, Open Approach */
"0YMF0ZZ" = "1" /* Reattachment of Right Knee Region, Open Approach */
"0YMG0ZZ" = "1" /* Reattachment of Left Knee Region, Open Approach */
"0YMH0ZZ" = "1" /* Reattachment of Right Lower Leg, Open Approach */
"0YMJ0ZZ" = "1" /* Reattachment of Left Lower Leg, Open Approach */
"0YMK0ZZ" = "1" /* Reattachment of Right Ankle Region, Open Approach */
"0YML0ZZ" = "1" /* Reattachment of Left Ankle Region, Open Approach */
"0YMM0ZZ" = "1" /* Reattachment of Right Foot, Open Approach */
"0YMN0ZZ" = "1" /* Reattachment of Left Foot, Open Approach */
"0YMP0ZZ" = "1" /* Reattachment of Right 1st Toe, Open Approach */
"0YMQ0ZZ" = "1" /* Reattachment of Left 1st Toe, Open Approach */
"0YMR0ZZ" = "1" /* Reattachment of Right 2nd Toe, Open Approach */
"0YMS0ZZ" = "1" /* Reattachment of Left 2nd Toe, Open Approach */
"0YMT0ZZ" = "1" /* Reattachment of Right 3rd Toe, Open Approach */
"0YMU0ZZ" = "1" /* Reattachment of Left 3rd Toe, Open Approach */
"0YMV0ZZ" = "1" /* Reattachment of Right 4th Toe, Open Approach */
"0YMW0ZZ" = "1" /* Reattachment of Left 4th Toe, Open Approach */
"0YMX0ZZ" = "1" /* Reattachment of Right 5th Toe, Open Approach */
"0YMY0ZZ" = "1" /* Reattachment of Left 5th Toe, Open Approach */
"0YQ00ZZ" = "1" /* Repair Right Buttock, Open Approach */
"0YQ03ZZ" = "1" /* Repair Right Buttock, Percutaneous Approach */
"0YQ04ZZ" = "1" /* Repair Right Buttock, Percutaneous Endoscopic Approach */
"0YQ0XZZ" = "1" /* Repair Right Buttock, External Approach */
"0YQ10ZZ" = "1" /* Repair Left Buttock, Open Approach */
"0YQ13ZZ" = "1" /* Repair Left Buttock, Percutaneous Approach */
"0YQ14ZZ" = "1" /* Repair Left Buttock, Percutaneous Endoscopic Approach */
"0YQ1XZZ" = "1" /* Repair Left Buttock, External Approach */
"0YQ50ZZ" = "1" /* Repair Right Inguinal Region, Open Approach */
"0YQ53ZZ" = "1" /* Repair Right Inguinal Region, Percutaneous Approach */
"0YQ54ZZ" = "1" /* Repair Right Inguinal Region, Percutaneous Endoscopic Approach */
"0YQ60ZZ" = "1" /* Repair Left Inguinal Region, Open Approach */
"0YQ63ZZ" = "1" /* Repair Left Inguinal Region, Percutaneous Approach */
"0YQ64ZZ" = "1" /* Repair Left Inguinal Region, Percutaneous Endoscopic Approach */
"0YQ70ZZ" = "1" /* Repair Right Femoral Region, Open Approach */
"0YQ73ZZ" = "1" /* Repair Right Femoral Region, Percutaneous Approach */
"0YQ74ZZ" = "1" /* Repair Right Femoral Region, Percutaneous Endoscopic Approach */
"0YQ80ZZ" = "1" /* Repair Left Femoral Region, Open Approach */
"0YQ83ZZ" = "1" /* Repair Left Femoral Region, Percutaneous Approach */
"0YQ84ZZ" = "1" /* Repair Left Femoral Region, Percutaneous Endoscopic Approach */
"0YQ90ZZ" = "1" /* Repair Right Lower Extremity, Open Approach */
"0YQ93ZZ" = "1" /* Repair Right Lower Extremity, Percutaneous Approach */
"0YQ94ZZ" = "1" /* Repair Right Lower Extremity, Percutaneous Endoscopic Approach */
"0YQ9XZZ" = "1" /* Repair Right Lower Extremity, External Approach */
"0YQA0ZZ" = "1" /* Repair Bilateral Inguinal Region, Open Approach */
"0YQA3ZZ" = "1" /* Repair Bilateral Inguinal Region, Percutaneous Approach */
"0YQA4ZZ" = "1" /* Repair Bilateral Inguinal Region, Percutaneous Endoscopic Approach */
"0YQB0ZZ" = "1" /* Repair Left Lower Extremity, Open Approach */
"0YQB3ZZ" = "1" /* Repair Left Lower Extremity, Percutaneous Approach */
"0YQB4ZZ" = "1" /* Repair Left Lower Extremity, Percutaneous Endoscopic Approach */
"0YQBXZZ" = "1" /* Repair Left Lower Extremity, External Approach */
"0YQC0ZZ" = "1" /* Repair Right Upper Leg, Open Approach */
"0YQC3ZZ" = "1" /* Repair Right Upper Leg, Percutaneous Approach */
"0YQC4ZZ" = "1" /* Repair Right Upper Leg, Percutaneous Endoscopic Approach */
"0YQCXZZ" = "1" /* Repair Right Upper Leg, External Approach */
"0YQD0ZZ" = "1" /* Repair Left Upper Leg, Open Approach */
"0YQD3ZZ" = "1" /* Repair Left Upper Leg, Percutaneous Approach */
"0YQD4ZZ" = "1" /* Repair Left Upper Leg, Percutaneous Endoscopic Approach */
"0YQDXZZ" = "1" /* Repair Left Upper Leg, External Approach */
"0YQE0ZZ" = "1" /* Repair Bilateral Femoral Region, Open Approach */
"0YQE3ZZ" = "1" /* Repair Bilateral Femoral Region, Percutaneous Approach */
"0YQE4ZZ" = "1" /* Repair Bilateral Femoral Region, Percutaneous Endoscopic Approach */
"0YQF0ZZ" = "1" /* Repair Right Knee Region, Open Approach */
"0YQF3ZZ" = "1" /* Repair Right Knee Region, Percutaneous Approach */
"0YQF4ZZ" = "1" /* Repair Right Knee Region, Percutaneous Endoscopic Approach */
"0YQFXZZ" = "1" /* Repair Right Knee Region, External Approach */
"0YQG0ZZ" = "1" /* Repair Left Knee Region, Open Approach */
"0YQG3ZZ" = "1" /* Repair Left Knee Region, Percutaneous Approach */
"0YQG4ZZ" = "1" /* Repair Left Knee Region, Percutaneous Endoscopic Approach */
"0YQGXZZ" = "1" /* Repair Left Knee Region, External Approach */
"0YQH0ZZ" = "1" /* Repair Right Lower Leg, Open Approach */
"0YQH3ZZ" = "1" /* Repair Right Lower Leg, Percutaneous Approach */
"0YQH4ZZ" = "1" /* Repair Right Lower Leg, Percutaneous Endoscopic Approach */
"0YQHXZZ" = "1" /* Repair Right Lower Leg, External Approach */
"0YQJ0ZZ" = "1" /* Repair Left Lower Leg, Open Approach */
"0YQJ3ZZ" = "1" /* Repair Left Lower Leg, Percutaneous Approach */
"0YQJ4ZZ" = "1" /* Repair Left Lower Leg, Percutaneous Endoscopic Approach */
"0YQJXZZ" = "1" /* Repair Left Lower Leg, External Approach */
"0YQK0ZZ" = "1" /* Repair Right Ankle Region, Open Approach */
"0YQK3ZZ" = "1" /* Repair Right Ankle Region, Percutaneous Approach */
"0YQK4ZZ" = "1" /* Repair Right Ankle Region, Percutaneous Endoscopic Approach */
"0YQKXZZ" = "1" /* Repair Right Ankle Region, External Approach */
"0YQL0ZZ" = "1" /* Repair Left Ankle Region, Open Approach */
"0YQL3ZZ" = "1" /* Repair Left Ankle Region, Percutaneous Approach */
"0YQL4ZZ" = "1" /* Repair Left Ankle Region, Percutaneous Endoscopic Approach */
"0YQLXZZ" = "1" /* Repair Left Ankle Region, External Approach */
"0YQM0ZZ" = "1" /* Repair Right Foot, Open Approach */
"0YQM3ZZ" = "1" /* Repair Right Foot, Percutaneous Approach */
"0YQM4ZZ" = "1" /* Repair Right Foot, Percutaneous Endoscopic Approach */
"0YQMXZZ" = "1" /* Repair Right Foot, External Approach */
"0YQN0ZZ" = "1" /* Repair Left Foot, Open Approach */
"0YQN3ZZ" = "1" /* Repair Left Foot, Percutaneous Approach */
"0YQN4ZZ" = "1" /* Repair Left Foot, Percutaneous Endoscopic Approach */
"0YQNXZZ" = "1" /* Repair Left Foot, External Approach */
"0YQP0ZZ" = "1" /* Repair Right 1st Toe, Open Approach */
"0YQP3ZZ" = "1" /* Repair Right 1st Toe, Percutaneous Approach */
"0YQP4ZZ" = "1" /* Repair Right 1st Toe, Percutaneous Endoscopic Approach */
"0YQPXZZ" = "1" /* Repair Right 1st Toe, External Approach */
"0YQQ0ZZ" = "1" /* Repair Left 1st Toe, Open Approach */
"0YQQ3ZZ" = "1" /* Repair Left 1st Toe, Percutaneous Approach */
"0YQQ4ZZ" = "1" /* Repair Left 1st Toe, Percutaneous Endoscopic Approach */
"0YQQXZZ" = "1" /* Repair Left 1st Toe, External Approach */
"0YQR0ZZ" = "1" /* Repair Right 2nd Toe, Open Approach */
"0YQR3ZZ" = "1" /* Repair Right 2nd Toe, Percutaneous Approach */
"0YQR4ZZ" = "1" /* Repair Right 2nd Toe, Percutaneous Endoscopic Approach */
"0YQRXZZ" = "1" /* Repair Right 2nd Toe, External Approach */
"0YQS0ZZ" = "1" /* Repair Left 2nd Toe, Open Approach */
"0YQS3ZZ" = "1" /* Repair Left 2nd Toe, Percutaneous Approach */
"0YQS4ZZ" = "1" /* Repair Left 2nd Toe, Percutaneous Endoscopic Approach */
"0YQSXZZ" = "1" /* Repair Left 2nd Toe, External Approach */
"0YQT0ZZ" = "1" /* Repair Right 3rd Toe, Open Approach */
"0YQT3ZZ" = "1" /* Repair Right 3rd Toe, Percutaneous Approach */
"0YQT4ZZ" = "1" /* Repair Right 3rd Toe, Percutaneous Endoscopic Approach */
"0YQTXZZ" = "1" /* Repair Right 3rd Toe, External Approach */
"0YQU0ZZ" = "1" /* Repair Left 3rd Toe, Open Approach */
"0YQU3ZZ" = "1" /* Repair Left 3rd Toe, Percutaneous Approach */
"0YQU4ZZ" = "1" /* Repair Left 3rd Toe, Percutaneous Endoscopic Approach */
"0YQUXZZ" = "1" /* Repair Left 3rd Toe, External Approach */
"0YQV0ZZ" = "1" /* Repair Right 4th Toe, Open Approach */
"0YQV3ZZ" = "1" /* Repair Right 4th Toe, Percutaneous Approach */
"0YQV4ZZ" = "1" /* Repair Right 4th Toe, Percutaneous Endoscopic Approach */
"0YQVXZZ" = "1" /* Repair Right 4th Toe, External Approach */
"0YQW0ZZ" = "1" /* Repair Left 4th Toe, Open Approach */
"0YQW3ZZ" = "1" /* Repair Left 4th Toe, Percutaneous Approach */
"0YQW4ZZ" = "1" /* Repair Left 4th Toe, Percutaneous Endoscopic Approach */
"0YQWXZZ" = "1" /* Repair Left 4th Toe, External Approach */
"0YQX0ZZ" = "1" /* Repair Right 5th Toe, Open Approach */
"0YQX3ZZ" = "1" /* Repair Right 5th Toe, Percutaneous Approach */
"0YQX4ZZ" = "1" /* Repair Right 5th Toe, Percutaneous Endoscopic Approach */
"0YQXXZZ" = "1" /* Repair Right 5th Toe, External Approach */
"0YQY0ZZ" = "1" /* Repair Left 5th Toe, Open Approach */
"0YQY3ZZ" = "1" /* Repair Left 5th Toe, Percutaneous Approach */
"0YQY4ZZ" = "1" /* Repair Left 5th Toe, Percutaneous Endoscopic Approach */
"0YQYXZZ" = "1" /* Repair Left 5th Toe, External Approach */
"0YU007Z" = "1" /* Supplement Right Buttock with Autologous Tissue Substitute, Open Approach */
"0YU00JZ" = "1" /* Supplement Right Buttock with Synthetic Substitute, Open Approach */
"0YU00KZ" = "1" /* Supplement Right Buttock with Nonautologous Tissue Substitute, Open Approach */
"0YU047Z" = "1" /* Supplement Right Buttock with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YU04JZ" = "1" /* Supplement Right Buttock with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YU04KZ" = "1" /* Supplement Right Buttock with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YU107Z" = "1" /* Supplement Left Buttock with Autologous Tissue Substitute, Open Approach */
"0YU10JZ" = "1" /* Supplement Left Buttock with Synthetic Substitute, Open Approach */
"0YU10KZ" = "1" /* Supplement Left Buttock with Nonautologous Tissue Substitute, Open Approach */
"0YU147Z" = "1" /* Supplement Left Buttock with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YU14JZ" = "1" /* Supplement Left Buttock with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YU14KZ" = "1" /* Supplement Left Buttock with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YU507Z" = "1" /* Supplement Right Inguinal Region with Autologous Tissue Substitute, Open Approach */
"0YU50JZ" = "1" /* Supplement Right Inguinal Region with Synthetic Substitute, Open Approach */
"0YU50KZ" = "1" /* Supplement Right Inguinal Region with Nonautologous Tissue Substitute, Open Approach */
"0YU547Z" = "1" /* Supplement Right Inguinal Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YU54JZ" = "1" /* Supplement Right Inguinal Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YU54KZ" = "1" /* Supplement Right Inguinal Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YU607Z" = "1" /* Supplement Left Inguinal Region with Autologous Tissue Substitute, Open Approach */
"0YU60JZ" = "1" /* Supplement Left Inguinal Region with Synthetic Substitute, Open Approach */
"0YU60KZ" = "1" /* Supplement Left Inguinal Region with Nonautologous Tissue Substitute, Open Approach */
"0YU647Z" = "1" /* Supplement Left Inguinal Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YU64JZ" = "1" /* Supplement Left Inguinal Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YU64KZ" = "1" /* Supplement Left Inguinal Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YU707Z" = "1" /* Supplement Right Femoral Region with Autologous Tissue Substitute, Open Approach */
"0YU70JZ" = "1" /* Supplement Right Femoral Region with Synthetic Substitute, Open Approach */
"0YU70KZ" = "1" /* Supplement Right Femoral Region with Nonautologous Tissue Substitute, Open Approach */
"0YU747Z" = "1" /* Supplement Right Femoral Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YU74JZ" = "1" /* Supplement Right Femoral Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YU74KZ" = "1" /* Supplement Right Femoral Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YU807Z" = "1" /* Supplement Left Femoral Region with Autologous Tissue Substitute, Open Approach */
"0YU80JZ" = "1" /* Supplement Left Femoral Region with Synthetic Substitute, Open Approach */
"0YU80KZ" = "1" /* Supplement Left Femoral Region with Nonautologous Tissue Substitute, Open Approach */
"0YU847Z" = "1" /* Supplement Left Femoral Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YU84JZ" = "1" /* Supplement Left Femoral Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YU84KZ" = "1" /* Supplement Left Femoral Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YU907Z" = "1" /* Supplement Right Lower Extremity with Autologous Tissue Substitute, Open Approach */
"0YU90JZ" = "1" /* Supplement Right Lower Extremity with Synthetic Substitute, Open Approach */
"0YU90KZ" = "1" /* Supplement Right Lower Extremity with Nonautologous Tissue Substitute, Open Approach */
"0YU947Z" = "1" /* Supplement Right Lower Extremity with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YU94JZ" = "1" /* Supplement Right Lower Extremity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YU94KZ" = "1" /* Supplement Right Lower Extremity with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUA07Z" = "1" /* Supplement Bilateral Inguinal Region with Autologous Tissue Substitute, Open Approach */
"0YUA0JZ" = "1" /* Supplement Bilateral Inguinal Region with Synthetic Substitute, Open Approach */
"0YUA0KZ" = "1" /* Supplement Bilateral Inguinal Region with Nonautologous Tissue Substitute, Open Approach */
"0YUA47Z" = "1" /* Supplement Bilateral Inguinal Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUA4JZ" = "1" /* Supplement Bilateral Inguinal Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUA4KZ" = "1" /* Supplement Bilateral Inguinal Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUB07Z" = "1" /* Supplement Left Lower Extremity with Autologous Tissue Substitute, Open Approach */
"0YUB0JZ" = "1" /* Supplement Left Lower Extremity with Synthetic Substitute, Open Approach */
"0YUB0KZ" = "1" /* Supplement Left Lower Extremity with Nonautologous Tissue Substitute, Open Approach */
"0YUB47Z" = "1" /* Supplement Left Lower Extremity with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUB4JZ" = "1" /* Supplement Left Lower Extremity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUB4KZ" = "1" /* Supplement Left Lower Extremity with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUC07Z" = "1" /* Supplement Right Upper Leg with Autologous Tissue Substitute, Open Approach */
"0YUC0JZ" = "1" /* Supplement Right Upper Leg with Synthetic Substitute, Open Approach */
"0YUC0KZ" = "1" /* Supplement Right Upper Leg with Nonautologous Tissue Substitute, Open Approach */
"0YUC47Z" = "1" /* Supplement Right Upper Leg with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUC4JZ" = "1" /* Supplement Right Upper Leg with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUC4KZ" = "1" /* Supplement Right Upper Leg with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUD07Z" = "1" /* Supplement Left Upper Leg with Autologous Tissue Substitute, Open Approach */
"0YUD0JZ" = "1" /* Supplement Left Upper Leg with Synthetic Substitute, Open Approach */
"0YUD0KZ" = "1" /* Supplement Left Upper Leg with Nonautologous Tissue Substitute, Open Approach */
"0YUD47Z" = "1" /* Supplement Left Upper Leg with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUD4JZ" = "1" /* Supplement Left Upper Leg with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUD4KZ" = "1" /* Supplement Left Upper Leg with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUE07Z" = "1" /* Supplement Bilateral Femoral Region with Autologous Tissue Substitute, Open Approach */
"0YUE0JZ" = "1" /* Supplement Bilateral Femoral Region with Synthetic Substitute, Open Approach */
"0YUE0KZ" = "1" /* Supplement Bilateral Femoral Region with Nonautologous Tissue Substitute, Open Approach */
"0YUE47Z" = "1" /* Supplement Bilateral Femoral Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUE4JZ" = "1" /* Supplement Bilateral Femoral Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUE4KZ" = "1" /* Supplement Bilateral Femoral Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUF07Z" = "1" /* Supplement Right Knee Region with Autologous Tissue Substitute, Open Approach */
"0YUF0JZ" = "1" /* Supplement Right Knee Region with Synthetic Substitute, Open Approach */
"0YUF0KZ" = "1" /* Supplement Right Knee Region with Nonautologous Tissue Substitute, Open Approach */
"0YUF47Z" = "1" /* Supplement Right Knee Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUF4JZ" = "1" /* Supplement Right Knee Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUF4KZ" = "1" /* Supplement Right Knee Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUG07Z" = "1" /* Supplement Left Knee Region with Autologous Tissue Substitute, Open Approach */
"0YUG0JZ" = "1" /* Supplement Left Knee Region with Synthetic Substitute, Open Approach */
"0YUG0KZ" = "1" /* Supplement Left Knee Region with Nonautologous Tissue Substitute, Open Approach */
"0YUG47Z" = "1" /* Supplement Left Knee Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUG4JZ" = "1" /* Supplement Left Knee Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUG4KZ" = "1" /* Supplement Left Knee Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUH07Z" = "1" /* Supplement Right Lower Leg with Autologous Tissue Substitute, Open Approach */
"0YUH0JZ" = "1" /* Supplement Right Lower Leg with Synthetic Substitute, Open Approach */
"0YUH0KZ" = "1" /* Supplement Right Lower Leg with Nonautologous Tissue Substitute, Open Approach */
"0YUH47Z" = "1" /* Supplement Right Lower Leg with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUH4JZ" = "1" /* Supplement Right Lower Leg with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUH4KZ" = "1" /* Supplement Right Lower Leg with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUJ07Z" = "1" /* Supplement Left Lower Leg with Autologous Tissue Substitute, Open Approach */
"0YUJ0JZ" = "1" /* Supplement Left Lower Leg with Synthetic Substitute, Open Approach */
"0YUJ0KZ" = "1" /* Supplement Left Lower Leg with Nonautologous Tissue Substitute, Open Approach */
"0YUJ47Z" = "1" /* Supplement Left Lower Leg with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUJ4JZ" = "1" /* Supplement Left Lower Leg with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUJ4KZ" = "1" /* Supplement Left Lower Leg with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUK07Z" = "1" /* Supplement Right Ankle Region with Autologous Tissue Substitute, Open Approach */
"0YUK0JZ" = "1" /* Supplement Right Ankle Region with Synthetic Substitute, Open Approach */
"0YUK0KZ" = "1" /* Supplement Right Ankle Region with Nonautologous Tissue Substitute, Open Approach */
"0YUK47Z" = "1" /* Supplement Right Ankle Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUK4JZ" = "1" /* Supplement Right Ankle Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUK4KZ" = "1" /* Supplement Right Ankle Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUL07Z" = "1" /* Supplement Left Ankle Region with Autologous Tissue Substitute, Open Approach */
"0YUL0JZ" = "1" /* Supplement Left Ankle Region with Synthetic Substitute, Open Approach */
"0YUL0KZ" = "1" /* Supplement Left Ankle Region with Nonautologous Tissue Substitute, Open Approach */
"0YUL47Z" = "1" /* Supplement Left Ankle Region with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUL4JZ" = "1" /* Supplement Left Ankle Region with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUL4KZ" = "1" /* Supplement Left Ankle Region with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUM07Z" = "1" /* Supplement Right Foot with Autologous Tissue Substitute, Open Approach */
"0YUM0JZ" = "1" /* Supplement Right Foot with Synthetic Substitute, Open Approach */
"0YUM0KZ" = "1" /* Supplement Right Foot with Nonautologous Tissue Substitute, Open Approach */
"0YUM47Z" = "1" /* Supplement Right Foot with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUM4JZ" = "1" /* Supplement Right Foot with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUM4KZ" = "1" /* Supplement Right Foot with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUN07Z" = "1" /* Supplement Left Foot with Autologous Tissue Substitute, Open Approach */
"0YUN0JZ" = "1" /* Supplement Left Foot with Synthetic Substitute, Open Approach */
"0YUN0KZ" = "1" /* Supplement Left Foot with Nonautologous Tissue Substitute, Open Approach */
"0YUN47Z" = "1" /* Supplement Left Foot with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUN4JZ" = "1" /* Supplement Left Foot with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUN4KZ" = "1" /* Supplement Left Foot with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUP07Z" = "1" /* Supplement Right 1st Toe with Autologous Tissue Substitute, Open Approach */
"0YUP0JZ" = "1" /* Supplement Right 1st Toe with Synthetic Substitute, Open Approach */
"0YUP0KZ" = "1" /* Supplement Right 1st Toe with Nonautologous Tissue Substitute, Open Approach */
"0YUP47Z" = "1" /* Supplement Right 1st Toe with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUP4JZ" = "1" /* Supplement Right 1st Toe with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUP4KZ" = "1" /* Supplement Right 1st Toe with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUQ07Z" = "1" /* Supplement Left 1st Toe with Autologous Tissue Substitute, Open Approach */
"0YUQ0JZ" = "1" /* Supplement Left 1st Toe with Synthetic Substitute, Open Approach */
"0YUQ0KZ" = "1" /* Supplement Left 1st Toe with Nonautologous Tissue Substitute, Open Approach */
"0YUQ47Z" = "1" /* Supplement Left 1st Toe with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUQ4JZ" = "1" /* Supplement Left 1st Toe with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUQ4KZ" = "1" /* Supplement Left 1st Toe with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUR07Z" = "1" /* Supplement Right 2nd Toe with Autologous Tissue Substitute, Open Approach */
"0YUR0JZ" = "1" /* Supplement Right 2nd Toe with Synthetic Substitute, Open Approach */
"0YUR0KZ" = "1" /* Supplement Right 2nd Toe with Nonautologous Tissue Substitute, Open Approach */
"0YUR47Z" = "1" /* Supplement Right 2nd Toe with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUR4JZ" = "1" /* Supplement Right 2nd Toe with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUR4KZ" = "1" /* Supplement Right 2nd Toe with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUS07Z" = "1" /* Supplement Left 2nd Toe with Autologous Tissue Substitute, Open Approach */
"0YUS0JZ" = "1" /* Supplement Left 2nd Toe with Synthetic Substitute, Open Approach */
"0YUS0KZ" = "1" /* Supplement Left 2nd Toe with Nonautologous Tissue Substitute, Open Approach */
"0YUS47Z" = "1" /* Supplement Left 2nd Toe with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUS4JZ" = "1" /* Supplement Left 2nd Toe with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUS4KZ" = "1" /* Supplement Left 2nd Toe with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUT07Z" = "1" /* Supplement Right 3rd Toe with Autologous Tissue Substitute, Open Approach */
"0YUT0JZ" = "1" /* Supplement Right 3rd Toe with Synthetic Substitute, Open Approach */
"0YUT0KZ" = "1" /* Supplement Right 3rd Toe with Nonautologous Tissue Substitute, Open Approach */
"0YUT47Z" = "1" /* Supplement Right 3rd Toe with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUT4JZ" = "1" /* Supplement Right 3rd Toe with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUT4KZ" = "1" /* Supplement Right 3rd Toe with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUU07Z" = "1" /* Supplement Left 3rd Toe with Autologous Tissue Substitute, Open Approach */
"0YUU0JZ" = "1" /* Supplement Left 3rd Toe with Synthetic Substitute, Open Approach */
"0YUU0KZ" = "1" /* Supplement Left 3rd Toe with Nonautologous Tissue Substitute, Open Approach */
"0YUU47Z" = "1" /* Supplement Left 3rd Toe with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUU4JZ" = "1" /* Supplement Left 3rd Toe with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUU4KZ" = "1" /* Supplement Left 3rd Toe with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUV07Z" = "1" /* Supplement Right 4th Toe with Autologous Tissue Substitute, Open Approach */
"0YUV0JZ" = "1" /* Supplement Right 4th Toe with Synthetic Substitute, Open Approach */
"0YUV0KZ" = "1" /* Supplement Right 4th Toe with Nonautologous Tissue Substitute, Open Approach */
"0YUV47Z" = "1" /* Supplement Right 4th Toe with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUV4JZ" = "1" /* Supplement Right 4th Toe with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUV4KZ" = "1" /* Supplement Right 4th Toe with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUW07Z" = "1" /* Supplement Left 4th Toe with Autologous Tissue Substitute, Open Approach */
"0YUW0JZ" = "1" /* Supplement Left 4th Toe with Synthetic Substitute, Open Approach */
"0YUW0KZ" = "1" /* Supplement Left 4th Toe with Nonautologous Tissue Substitute, Open Approach */
"0YUW47Z" = "1" /* Supplement Left 4th Toe with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUW4JZ" = "1" /* Supplement Left 4th Toe with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUW4KZ" = "1" /* Supplement Left 4th Toe with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUX07Z" = "1" /* Supplement Right 5th Toe with Autologous Tissue Substitute, Open Approach */
"0YUX0JZ" = "1" /* Supplement Right 5th Toe with Synthetic Substitute, Open Approach */
"0YUX0KZ" = "1" /* Supplement Right 5th Toe with Nonautologous Tissue Substitute, Open Approach */
"0YUX47Z" = "1" /* Supplement Right 5th Toe with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUX4JZ" = "1" /* Supplement Right 5th Toe with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUX4KZ" = "1" /* Supplement Right 5th Toe with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUY07Z" = "1" /* Supplement Left 5th Toe with Autologous Tissue Substitute, Open Approach */
"0YUY0JZ" = "1" /* Supplement Left 5th Toe with Synthetic Substitute, Open Approach */
"0YUY0KZ" = "1" /* Supplement Left 5th Toe with Nonautologous Tissue Substitute, Open Approach */
"0YUY47Z" = "1" /* Supplement Left 5th Toe with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0YUY4JZ" = "1" /* Supplement Left 5th Toe with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0YUY4KZ" = "1" /* Supplement Left 5th Toe with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"10A00ZZ" = "1" /* Abortion of Products of Conception, Open Approach */
"10A03ZZ" = "1" /* Abortion of Products of Conception, Percutaneous Approach */
"10A04ZZ" = "1" /* Abortion of Products of Conception, Percutaneous Endoscopic Approach */
"10A07ZZ" = "1" /* Abortion of Products of Conception, Via Natural or Artificial Opening */
"10A08ZZ" = "1" /* Abortion of Products of Conception, Via Natural or Artificial Opening Endoscopic */
"10D00Z0" = "1" /* Extraction of Products of Conception, Classical, Open Approach */
"10D00Z1" = "1" /* Extraction of Products of Conception, Low Cervical, Open Approach */
"10D00Z2" = "1" /* Extraction of Products of Conception, Extraperitoneal, Open Approach */
"10D17ZZ" = "1" /* Extraction of Products of Conception, Retained, Via Natural or Artificial Opening */
"10D18ZZ" = "1" /* Extraction of Products of Conception, Retained, Via Natural or Artificial Opening Endoscopic */
"10D27ZZ" = "1" /* Extraction of Products of Conception, Ectopic, Via Natural or Artificial Opening */
"10D28ZZ" = "1" /* Extraction of Products of Conception, Ectopic, Via Natural or Artificial Opening Endoscopic */
"10H003Z" = "1" /* Insertion of Monitoring Electrode into Products of Conception, Open Approach */
"10H00YZ" = "1" /* Insertion of Other Device into Products of Conception, Open Approach */
"10P003Z" = "1" /* Removal of Monitoring Electrode from Products of Conception, Open Approach */
"10P00YZ" = "1" /* Removal of Other Device from Products of Conception, Open Approach */
"10S20ZZ" = "1" /* Reposition Products of Conception, Ectopic, Open Approach */
"10S23ZZ" = "1" /* Reposition Products of Conception, Ectopic, Percutaneous Approach */
"10S24ZZ" = "1" /* Reposition Products of Conception, Ectopic, Percutaneous Endoscopic Approach */
"10S27ZZ" = "1" /* Reposition Products of Conception, Ectopic, Via Natural or Artificial Opening */
"10S28ZZ" = "1" /* Reposition Products of Conception, Ectopic, Via Natural or Artificial Opening Endoscopic */
"10T20ZZ" = "1" /* Resection of Products of Conception, Ectopic, Open Approach */
"10T23ZZ" = "1" /* Resection of Products of Conception, Ectopic, Percutaneous Approach */
"10T24ZZ" = "1" /* Resection of Products of Conception, Ectopic, Percutaneous Endoscopic Approach */
"10T27ZZ" = "1" /* Resection of Products of Conception, Ectopic, Via Natural or Artificial Opening */
"10T28ZZ" = "1" /* Resection of Products of Conception, Ectopic, Via Natural or Artificial Opening Endoscopic */
"3E030TZ" = "1" /* Introduction of Destructive Agent into Peripheral Vein, Open Approach */
"3E040TZ" = "1" /* Introduction of Destructive Agent into Central Vein, Open Approach */
"4A0605Z" = "1" /* Measurement of Lymphatic Flow, Open Approach */
"4A060BZ" = "1" /* Measurement of Lymphatic Pressure, Open Approach */
"4A0C45Z" = "1" /* Measurement of Biliary Flow, Percutaneous Endoscopic Approach */
"4A0C4BZ" = "1" /* Measurement of Biliary Pressure, Percutaneous Endoscopic Approach */
"4A1605Z" = "1" /* Monitoring of Lymphatic Flow, Open Approach */
"4A160BZ" = "1" /* Monitoring of Lymphatic Pressure, Open Approach */
"5A02110" = "1" /* Assistance with Cardiac Output using Balloon Pump, Intermittent */
"5A02116" = "1" /* Assistance with Cardiac Output using Other Pump, Intermittent */
"5A0211D" = "1" /* Assistance with Cardiac Output using Impeller Pump, Intermittent */
"5A02210" = "1" /* Assistance with Cardiac Output using Balloon Pump, Continuous */
"5A02216" = "1" /* Assistance with Cardiac Output using Other Pump, Continuous */
"5A0221D" = "1" /* Assistance with Cardiac Output using Impeller Pump, Continuous */
"5A15223" = "1" /* Extracorporeal Membrane Oxygenation, Continuous */
"6AB50BZ" = "1" /* Perfusion of Circulatory Donor Organ, Single */
"6ABB0BZ" = "1" /* Perfusion of Respiratory System Donor Organ, Single */
"6ABF0BZ" = "1" /* Perfusion of Hepatobiliary System and Pancreas Donor Organ, Single */
"6ABT0BZ" = "1" /* Perfusion of Urinary System Donor Organ, Single */
"D0Y0KZZ" = "1" /* Laser Interstitial Thermal Therapy of Brain */
"D0Y1KZZ" = "1" /* Laser Interstitial Thermal Therapy of Brain Stem */
"D0Y6KZZ" = "1" /* Laser Interstitial Thermal Therapy of Spinal Cord */
"D0Y7KZZ" = "1" /* Laser Interstitial Thermal Therapy of Peripheral Nerve */
"DBY0KZZ" = "1" /* Laser Interstitial Thermal Therapy of Trachea */
"DBY1KZZ" = "1" /* Laser Interstitial Thermal Therapy of Bronchus */
"DBY2KZZ" = "1" /* Laser Interstitial Thermal Therapy of Lung */
"DBY5KZZ" = "1" /* Laser Interstitial Thermal Therapy of Pleura */
"DBY6KZZ" = "1" /* Laser Interstitial Thermal Therapy of Mediastinum */
"DBY7KZZ" = "1" /* Laser Interstitial Thermal Therapy of Chest Wall */
"DBY8KZZ" = "1" /* Laser Interstitial Thermal Therapy of Diaphragm */
"DDY0KZZ" = "1" /* Laser Interstitial Thermal Therapy of Esophagus */
"DDY1KZZ" = "1" /* Laser Interstitial Thermal Therapy of Stomach */
"DDY2KZZ" = "1" /* Laser Interstitial Thermal Therapy of Duodenum */
"DDY3KZZ" = "1" /* Laser Interstitial Thermal Therapy of Jejunum */
"DDY4KZZ" = "1" /* Laser Interstitial Thermal Therapy of Ileum */
"DDY5KZZ" = "1" /* Laser Interstitial Thermal Therapy of Colon */
"DDY7KZZ" = "1" /* Laser Interstitial Thermal Therapy of Rectum */
"DDY8KZZ" = "1" /* Laser Interstitial Thermal Therapy of Anus */
"DFY0KZZ" = "1" /* Laser Interstitial Thermal Therapy of Liver */
"DFY1KZZ" = "1" /* Laser Interstitial Thermal Therapy of Gallbladder */
"DFY2KZZ" = "1" /* Laser Interstitial Thermal Therapy of Bile Ducts */
"DFY3KZZ" = "1" /* Laser Interstitial Thermal Therapy of Pancreas */
"DGY0KZZ" = "1" /* Laser Interstitial Thermal Therapy of Pituitary Gland */
"DGY1KZZ" = "1" /* Laser Interstitial Thermal Therapy of Pineal Body */
"DGY2KZZ" = "1" /* Laser Interstitial Thermal Therapy of Adrenal Glands */
"DGY4KZZ" = "1" /* Laser Interstitial Thermal Therapy of Parathyroid Glands */
"DGY5KZZ" = "1" /* Laser Interstitial Thermal Therapy of Thyroid */
"DMY0KZZ" = "1" /* Laser Interstitial Thermal Therapy of Left Breast */
"DMY1KZZ" = "1" /* Laser Interstitial Thermal Therapy of Right Breast */
"DVY0KZZ" = "1" /* Laser Interstitial Thermal Therapy of Prostate */
"X2A5312" = "1" /* Cerebral Embolic Filtration, Dual Filter in Innominate Artery and Left Common Carotid Artery, Percutaneous Approach, New Technology Group 2 */
"X2C0361" = "1" /* Extirpation of Matter from Coronary Artery, One Artery using Orbital Atherectomy Technology, Percutaneous Approach, New Technology Group 1 */
"X2C1361" = "1" /* Extirpation of Matter from Coronary Artery, Two Arteries using Orbital Atherectomy Technology, Percutaneous Approach, New Technology Group 1 */
"X2C2361" = "1" /* Extirpation of Matter from Coronary Artery, Three Arteries using Orbital Atherectomy Technology, Percutaneous Approach, New Technology Group 1 */
"X2C3361" = "1" /* Extirpation of Matter from Coronary Artery, Four or More Arteries using Orbital Atherectomy Technology, Percutaneous Approach, New Technology Group 1 */
"X2RF032" = "1" /* Replacement of Aortic Valve using Zooplastic Tissue, Rapid Deployment Technique, Open Approach, New Technology Group 2 */
"X2RF332" = "1" /* Replacement of Aortic Valve using Zooplastic Tissue, Rapid Deployment Technique, Percutaneous Approach, New Technology Group 2 */
"X2RF432" = "1" /* Replacement of Aortic Valve using Zooplastic Tissue, Rapid Deployment Technique, Percutaneous Endoscopic Approach, New Technology Group 2 */
"XHRPXL2" = "1" /* Replacement of Skin using Porcine Liver Derived Skin Substitute, External Approach, New Technology Group 2 */
"XNS0032" = "1" /* Reposition of Lumbar Vertebra using Magnetically Controlled Growth Rod(s), Open Approach, New Technology Group 2 */
"XNS0432" = "1" /* Reposition of Lumbar Vertebra using Magnetically Controlled Growth Rod(s), Percutaneous Endoscopic Approach, New Technology Group 2 */
"XNS3032" = "1" /* Reposition of Cervical Vertebra using Magnetically Controlled Growth Rod(s), Open Approach, New Technology Group 2 */
"XNS3432" = "1" /* Reposition of Cervical Vertebra using Magnetically Controlled Growth Rod(s), Percutaneous Endoscopic Approach, New Technology Group 2 */
"XNS4032" = "1" /* Reposition of Thoracic Vertebra using Magnetically Controlled Growth Rod(s), Open Approach, New Technology Group 2 */
"XNS4432" = "1" /* Reposition of Thoracic Vertebra using Magnetically Controlled Growth Rod(s), Percutaneous Endoscopic Approach, New Technology Group 2 */
"XR2G021" = "1" /* Monitoring of Right Knee Joint using Intraoperative Knee Replacement Sensor, Open Approach, New Technology Group 1 */
"XR2H021" = "1" /* Monitoring of Left Knee Joint using Intraoperative Knee Replacement Sensor, Open Approach, New Technology Group 1 */
"XRG0092" = "1" /* Fusion of Occipital-cervical Joint using Nanotextured Surface Interbody Fusion Device, Open Approach, New Technology Group 2 */
"XRG1092" = "1" /* Fusion of Cervical Vertebral Joint using Nanotextured Surface Interbody Fusion Device, Open Approach, New Technology Group 2 */
"XRG2092" = "1" /* Fusion of 2 or more Cervical Vertebral Joints using Nanotextured Surface Interbody Fusion Device, Open Approach, New Technology Group 2 */
"XRG4092" = "1" /* Fusion of Cervicothoracic Vertebral Joint using Nanotextured Surface Interbody Fusion Device, Open Approach, New Technology Group 2 */
"XRG6092" = "1" /* Fusion of Thoracic Vertebral Joint using Nanotextured Surface Interbody Fusion Device, Open Approach, New Technology Group 2 */
"XRG7092" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints using Nanotextured Surface Interbody Fusion Device, Open Approach, New Technology Group 2 */
"XRG8092" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints using Nanotextured Surface Interbody Fusion Device, Open Approach, New Technology Group 2 */
"XRGA092" = "1" /* Fusion of Thoracolumbar Vertebral Joint using Nanotextured Surface Interbody Fusion Device, Open Approach, New Technology Group 2 */
"XRGB092" = "1" /* Fusion of Lumbar Vertebral Joint using Nanotextured Surface Interbody Fusion Device, Open Approach, New Technology Group 2 */
"XRGC092" = "1" /* Fusion of 2 or more Lumbar Vertebral Joints using Nanotextured Surface Interbody Fusion Device, Open Approach, New Technology Group 2 */
"XRGD092" = "1" /* Fusion of Lumbosacral Joint using Nanotextured Surface Interbody Fusion Device, Open Approach, New Technology Group 2 */
Other = "0"
;

/* Procedure codeset THORAIP last updated 161203 for ICD10 v70rev0 */
Value $THORAIP
"01520ZZ" = "1" /* Destruction of Phrenic Nerve, Open Approach */
"01523ZZ" = "1" /* Destruction of Phrenic Nerve, Percutaneous Approach */
"01524ZZ" = "1" /* Destruction of Phrenic Nerve, Percutaneous Endoscopic Approach */
"015K0ZZ" = "1" /* Destruction of Head and Neck Sympathetic Nerve, Open Approach */
"015K3ZZ" = "1" /* Destruction of Head and Neck Sympathetic Nerve, Percutaneous Approach */
"015K4ZZ" = "1" /* Destruction of Head and Neck Sympathetic Nerve, Percutaneous Endoscopic Approach */
"015L0ZZ" = "1" /* Destruction of Thoracic Sympathetic Nerve, Open Approach */
"015L3ZZ" = "1" /* Destruction of Thoracic Sympathetic Nerve, Percutaneous Approach */
"015L4ZZ" = "1" /* Destruction of Thoracic Sympathetic Nerve, Percutaneous Endoscopic Approach */
"015M0ZZ" = "1" /* Destruction of Abdominal Sympathetic Nerve, Open Approach */
"015M3ZZ" = "1" /* Destruction of Abdominal Sympathetic Nerve, Percutaneous Approach */
"015M4ZZ" = "1" /* Destruction of Abdominal Sympathetic Nerve, Percutaneous Endoscopic Approach */
"015N0ZZ" = "1" /* Destruction of Lumbar Sympathetic Nerve, Open Approach */
"015N3ZZ" = "1" /* Destruction of Lumbar Sympathetic Nerve, Percutaneous Approach */
"015N4ZZ" = "1" /* Destruction of Lumbar Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01BK0ZZ" = "1" /* Excision of Head and Neck Sympathetic Nerve, Open Approach */
"01BK3ZZ" = "1" /* Excision of Head and Neck Sympathetic Nerve, Percutaneous Approach */
"01BK4ZZ" = "1" /* Excision of Head and Neck Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01BL0ZZ" = "1" /* Excision of Thoracic Sympathetic Nerve, Open Approach */
"01BL3ZZ" = "1" /* Excision of Thoracic Sympathetic Nerve, Percutaneous Approach */
"01BL4ZZ" = "1" /* Excision of Thoracic Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01BM0ZZ" = "1" /* Excision of Abdominal Sympathetic Nerve, Open Approach */
"01BM3ZZ" = "1" /* Excision of Abdominal Sympathetic Nerve, Percutaneous Approach */
"01BM4ZZ" = "1" /* Excision of Abdominal Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01BN0ZZ" = "1" /* Excision of Lumbar Sympathetic Nerve, Open Approach */
"01BN3ZZ" = "1" /* Excision of Lumbar Sympathetic Nerve, Percutaneous Approach */
"01BN4ZZ" = "1" /* Excision of Lumbar Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01DK0ZZ" = "1" /* Extraction of Head and Neck Sympathetic Nerve, Open Approach */
"01DK3ZZ" = "1" /* Extraction of Head and Neck Sympathetic Nerve, Percutaneous Approach */
"01DK4ZZ" = "1" /* Extraction of Head and Neck Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01DL0ZZ" = "1" /* Extraction of Thoracic Sympathetic Nerve, Open Approach */
"01DL3ZZ" = "1" /* Extraction of Thoracic Sympathetic Nerve, Percutaneous Approach */
"01DL4ZZ" = "1" /* Extraction of Thoracic Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01DM0ZZ" = "1" /* Extraction of Abdominal Sympathetic Nerve, Open Approach */
"01DM3ZZ" = "1" /* Extraction of Abdominal Sympathetic Nerve, Percutaneous Approach */
"01DM4ZZ" = "1" /* Extraction of Abdominal Sympathetic Nerve, Percutaneous Endoscopic Approach */
"01DN0ZZ" = "1" /* Extraction of Lumbar Sympathetic Nerve, Open Approach */
"01DN3ZZ" = "1" /* Extraction of Lumbar Sympathetic Nerve, Percutaneous Approach */
"01DN4ZZ" = "1" /* Extraction of Lumbar Sympathetic Nerve, Percutaneous Endoscopic Approach */
"02JA0ZZ" = "1" /* Inspection of Heart, Open Approach */
"02JA4ZZ" = "1" /* Inspection of Heart, Percutaneous Endoscopic Approach */
"02JY0ZZ" = "1" /* Inspection of Great Vessel, Open Approach */
"02JY4ZZ" = "1" /* Inspection of Great Vessel, Percutaneous Endoscopic Approach */
"02YA0Z0" = "1" /* Transplantation of Heart, Allogeneic, Open Approach */
"02YA0Z1" = "1" /* Transplantation of Heart, Syngeneic, Open Approach */
"02YA0Z2" = "1" /* Transplantation of Heart, Zooplastic, Open Approach */
"075K0ZZ" = "1" /* Destruction of Thoracic Duct, Open Approach */
"075K3ZZ" = "1" /* Destruction of Thoracic Duct, Percutaneous Approach */
"075K4ZZ" = "1" /* Destruction of Thoracic Duct, Percutaneous Endoscopic Approach */
"075L0ZZ" = "1" /* Destruction of Cisterna Chyli, Open Approach */
"075L3ZZ" = "1" /* Destruction of Cisterna Chyli, Percutaneous Approach */
"075L4ZZ" = "1" /* Destruction of Cisterna Chyli, Percutaneous Endoscopic Approach */
"075M0ZZ" = "1" /* Destruction of Thymus, Open Approach */
"075M3ZZ" = "1" /* Destruction of Thymus, Percutaneous Approach */
"075M4ZZ" = "1" /* Destruction of Thymus, Percutaneous Endoscopic Approach */
"079K00Z" = "1" /* Drainage of Thoracic Duct with Drainage Device, Open Approach */
"079K0ZZ" = "1" /* Drainage of Thoracic Duct, Open Approach */
"079K30Z" = "1" /* Drainage of Thoracic Duct with Drainage Device, Percutaneous Approach */
"079K3ZZ" = "1" /* Drainage of Thoracic Duct, Percutaneous Approach */
"079K40Z" = "1" /* Drainage of Thoracic Duct with Drainage Device, Percutaneous Endoscopic Approach */
"079K4ZZ" = "1" /* Drainage of Thoracic Duct, Percutaneous Endoscopic Approach */
"079L00Z" = "1" /* Drainage of Cisterna Chyli with Drainage Device, Open Approach */
"079L0ZZ" = "1" /* Drainage of Cisterna Chyli, Open Approach */
"079L30Z" = "1" /* Drainage of Cisterna Chyli with Drainage Device, Percutaneous Approach */
"079L3ZZ" = "1" /* Drainage of Cisterna Chyli, Percutaneous Approach */
"079L40Z" = "1" /* Drainage of Cisterna Chyli with Drainage Device, Percutaneous Endoscopic Approach */
"079L4ZZ" = "1" /* Drainage of Cisterna Chyli, Percutaneous Endoscopic Approach */
"07BK0ZZ" = "1" /* Excision of Thoracic Duct, Open Approach */
"07BK3ZZ" = "1" /* Excision of Thoracic Duct, Percutaneous Approach */
"07BK4ZZ" = "1" /* Excision of Thoracic Duct, Percutaneous Endoscopic Approach */
"07BL0ZZ" = "1" /* Excision of Cisterna Chyli, Open Approach */
"07BL3ZZ" = "1" /* Excision of Cisterna Chyli, Percutaneous Approach */
"07BL4ZZ" = "1" /* Excision of Cisterna Chyli, Percutaneous Endoscopic Approach */
"07BM0ZZ" = "1" /* Excision of Thymus, Open Approach */
"07BM3ZZ" = "1" /* Excision of Thymus, Percutaneous Approach */
"07BM4ZZ" = "1" /* Excision of Thymus, Percutaneous Endoscopic Approach */
"07LK0CZ" = "1" /* Occlusion of Thoracic Duct with Extraluminal Device, Open Approach */
"07LK0DZ" = "1" /* Occlusion of Thoracic Duct with Intraluminal Device, Open Approach */
"07LK0ZZ" = "1" /* Occlusion of Thoracic Duct, Open Approach */
"07LK3CZ" = "1" /* Occlusion of Thoracic Duct with Extraluminal Device, Percutaneous Approach */
"07LK3DZ" = "1" /* Occlusion of Thoracic Duct with Intraluminal Device, Percutaneous Approach */
"07LK3ZZ" = "1" /* Occlusion of Thoracic Duct, Percutaneous Approach */
"07LK4CZ" = "1" /* Occlusion of Thoracic Duct with Extraluminal Device, Percutaneous Endoscopic Approach */
"07LK4DZ" = "1" /* Occlusion of Thoracic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"07LK4ZZ" = "1" /* Occlusion of Thoracic Duct, Percutaneous Endoscopic Approach */
"07LL0CZ" = "1" /* Occlusion of Cisterna Chyli with Extraluminal Device, Open Approach */
"07LL0DZ" = "1" /* Occlusion of Cisterna Chyli with Intraluminal Device, Open Approach */
"07LL0ZZ" = "1" /* Occlusion of Cisterna Chyli, Open Approach */
"07LL3CZ" = "1" /* Occlusion of Cisterna Chyli with Extraluminal Device, Percutaneous Approach */
"07LL3DZ" = "1" /* Occlusion of Cisterna Chyli with Intraluminal Device, Percutaneous Approach */
"07LL3ZZ" = "1" /* Occlusion of Cisterna Chyli, Percutaneous Approach */
"07LL4CZ" = "1" /* Occlusion of Cisterna Chyli with Extraluminal Device, Percutaneous Endoscopic Approach */
"07LL4DZ" = "1" /* Occlusion of Cisterna Chyli with Intraluminal Device, Percutaneous Endoscopic Approach */
"07LL4ZZ" = "1" /* Occlusion of Cisterna Chyli, Percutaneous Endoscopic Approach */
"07NK0ZZ" = "1" /* Release Thoracic Duct, Open Approach */
"07NK3ZZ" = "1" /* Release Thoracic Duct, Percutaneous Approach */
"07NK4ZZ" = "1" /* Release Thoracic Duct, Percutaneous Endoscopic Approach */
"07NL0ZZ" = "1" /* Release Cisterna Chyli, Open Approach */
"07NL3ZZ" = "1" /* Release Cisterna Chyli, Percutaneous Approach */
"07NL4ZZ" = "1" /* Release Cisterna Chyli, Percutaneous Endoscopic Approach */
"07PK00Z" = "1" /* Removal of Drainage Device from Thoracic Duct, Open Approach */
"07PK03Z" = "1" /* Removal of Infusion Device from Thoracic Duct, Open Approach */
"07PK0CZ" = "1" /* Removal of Extraluminal Device from Thoracic Duct, Open Approach */
"07PK0DZ" = "1" /* Removal of Intraluminal Device from Thoracic Duct, Open Approach */
"07PK30Z" = "1" /* Removal of Drainage Device from Thoracic Duct, Percutaneous Approach */
"07PK33Z" = "1" /* Removal of Infusion Device from Thoracic Duct, Percutaneous Approach */
"07PK3CZ" = "1" /* Removal of Extraluminal Device from Thoracic Duct, Percutaneous Approach */
"07PK3DZ" = "1" /* Removal of Intraluminal Device from Thoracic Duct, Percutaneous Approach */
"07PK40Z" = "1" /* Removal of Drainage Device from Thoracic Duct, Percutaneous Endoscopic Approach */
"07PK43Z" = "1" /* Removal of Infusion Device from Thoracic Duct, Percutaneous Endoscopic Approach */
"07PK4CZ" = "1" /* Removal of Extraluminal Device from Thoracic Duct, Percutaneous Endoscopic Approach */
"07PK4DZ" = "1" /* Removal of Intraluminal Device from Thoracic Duct, Percutaneous Endoscopic Approach */
"07PL00Z" = "1" /* Removal of Drainage Device from Cisterna Chyli, Open Approach */
"07PL03Z" = "1" /* Removal of Infusion Device from Cisterna Chyli, Open Approach */
"07PL0CZ" = "1" /* Removal of Extraluminal Device from Cisterna Chyli, Open Approach */
"07PL0DZ" = "1" /* Removal of Intraluminal Device from Cisterna Chyli, Open Approach */
"07PL30Z" = "1" /* Removal of Drainage Device from Cisterna Chyli, Percutaneous Approach */
"07PL33Z" = "1" /* Removal of Infusion Device from Cisterna Chyli, Percutaneous Approach */
"07PL3CZ" = "1" /* Removal of Extraluminal Device from Cisterna Chyli, Percutaneous Approach */
"07PL3DZ" = "1" /* Removal of Intraluminal Device from Cisterna Chyli, Percutaneous Approach */
"07PL40Z" = "1" /* Removal of Drainage Device from Cisterna Chyli, Percutaneous Endoscopic Approach */
"07PL43Z" = "1" /* Removal of Infusion Device from Cisterna Chyli, Percutaneous Endoscopic Approach */
"07PL4CZ" = "1" /* Removal of Extraluminal Device from Cisterna Chyli, Percutaneous Endoscopic Approach */
"07PL4DZ" = "1" /* Removal of Intraluminal Device from Cisterna Chyli, Percutaneous Endoscopic Approach */
"07QK0ZZ" = "1" /* Repair Thoracic Duct, Open Approach */
"07QK3ZZ" = "1" /* Repair Thoracic Duct, Percutaneous Approach */
"07QK4ZZ" = "1" /* Repair Thoracic Duct, Percutaneous Endoscopic Approach */
"07QL0ZZ" = "1" /* Repair Cisterna Chyli, Open Approach */
"07QL3ZZ" = "1" /* Repair Cisterna Chyli, Percutaneous Approach */
"07QL4ZZ" = "1" /* Repair Cisterna Chyli, Percutaneous Endoscopic Approach */
"07TK0ZZ" = "1" /* Resection of Thoracic Duct, Open Approach */
"07TK4ZZ" = "1" /* Resection of Thoracic Duct, Percutaneous Endoscopic Approach */
"07TL0ZZ" = "1" /* Resection of Cisterna Chyli, Open Approach */
"07TL4ZZ" = "1" /* Resection of Cisterna Chyli, Percutaneous Endoscopic Approach */
"07TM0ZZ" = "1" /* Resection of Thymus, Open Approach */
"07TM4ZZ" = "1" /* Resection of Thymus, Percutaneous Endoscopic Approach */
"07UK07Z" = "1" /* Supplement Thoracic Duct with Autologous Tissue Substitute, Open Approach */
"07UK0JZ" = "1" /* Supplement Thoracic Duct with Synthetic Substitute, Open Approach */
"07UK0KZ" = "1" /* Supplement Thoracic Duct with Nonautologous Tissue Substitute, Open Approach */
"07UK47Z" = "1" /* Supplement Thoracic Duct with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UK4JZ" = "1" /* Supplement Thoracic Duct with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07UK4KZ" = "1" /* Supplement Thoracic Duct with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UL07Z" = "1" /* Supplement Cisterna Chyli with Autologous Tissue Substitute, Open Approach */
"07UL0JZ" = "1" /* Supplement Cisterna Chyli with Synthetic Substitute, Open Approach */
"07UL0KZ" = "1" /* Supplement Cisterna Chyli with Nonautologous Tissue Substitute, Open Approach */
"07UL47Z" = "1" /* Supplement Cisterna Chyli with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07UL4JZ" = "1" /* Supplement Cisterna Chyli with Synthetic Substitute, Percutaneous Endoscopic Approach */
"07UL4KZ" = "1" /* Supplement Cisterna Chyli with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"07VK0CZ" = "1" /* Restriction of Thoracic Duct with Extraluminal Device, Open Approach */
"07VK0DZ" = "1" /* Restriction of Thoracic Duct with Intraluminal Device, Open Approach */
"07VK0ZZ" = "1" /* Restriction of Thoracic Duct, Open Approach */
"07VK3CZ" = "1" /* Restriction of Thoracic Duct with Extraluminal Device, Percutaneous Approach */
"07VK3DZ" = "1" /* Restriction of Thoracic Duct with Intraluminal Device, Percutaneous Approach */
"07VK3ZZ" = "1" /* Restriction of Thoracic Duct, Percutaneous Approach */
"07VK4CZ" = "1" /* Restriction of Thoracic Duct with Extraluminal Device, Percutaneous Endoscopic Approach */
"07VK4DZ" = "1" /* Restriction of Thoracic Duct with Intraluminal Device, Percutaneous Endoscopic Approach */
"07VK4ZZ" = "1" /* Restriction of Thoracic Duct, Percutaneous Endoscopic Approach */
"07VL0CZ" = "1" /* Restriction of Cisterna Chyli with Extraluminal Device, Open Approach */
"07VL0DZ" = "1" /* Restriction of Cisterna Chyli with Intraluminal Device, Open Approach */
"07VL0ZZ" = "1" /* Restriction of Cisterna Chyli, Open Approach */
"07VL3CZ" = "1" /* Restriction of Cisterna Chyli with Extraluminal Device, Percutaneous Approach */
"07VL3DZ" = "1" /* Restriction of Cisterna Chyli with Intraluminal Device, Percutaneous Approach */
"07VL3ZZ" = "1" /* Restriction of Cisterna Chyli, Percutaneous Approach */
"07VL4CZ" = "1" /* Restriction of Cisterna Chyli with Extraluminal Device, Percutaneous Endoscopic Approach */
"07VL4DZ" = "1" /* Restriction of Cisterna Chyli with Intraluminal Device, Percutaneous Endoscopic Approach */
"07VL4ZZ" = "1" /* Restriction of Cisterna Chyli, Percutaneous Endoscopic Approach */
"07WK00Z" = "1" /* Revision of Drainage Device in Thoracic Duct, Open Approach */
"07WK03Z" = "1" /* Revision of Infusion Device in Thoracic Duct, Open Approach */
"07WK0CZ" = "1" /* Revision of Extraluminal Device in Thoracic Duct, Open Approach */
"07WK0DZ" = "1" /* Revision of Intraluminal Device in Thoracic Duct, Open Approach */
"07WK30Z" = "1" /* Revision of Drainage Device in Thoracic Duct, Percutaneous Approach */
"07WK33Z" = "1" /* Revision of Infusion Device in Thoracic Duct, Percutaneous Approach */
"07WK3CZ" = "1" /* Revision of Extraluminal Device in Thoracic Duct, Percutaneous Approach */
"07WK3DZ" = "1" /* Revision of Intraluminal Device in Thoracic Duct, Percutaneous Approach */
"07WK40Z" = "1" /* Revision of Drainage Device in Thoracic Duct, Percutaneous Endoscopic Approach */
"07WK43Z" = "1" /* Revision of Infusion Device in Thoracic Duct, Percutaneous Endoscopic Approach */
"07WK4CZ" = "1" /* Revision of Extraluminal Device in Thoracic Duct, Percutaneous Endoscopic Approach */
"07WK4DZ" = "1" /* Revision of Intraluminal Device in Thoracic Duct, Percutaneous Endoscopic Approach */
"07WL00Z" = "1" /* Revision of Drainage Device in Cisterna Chyli, Open Approach */
"07WL03Z" = "1" /* Revision of Infusion Device in Cisterna Chyli, Open Approach */
"07WL0CZ" = "1" /* Revision of Extraluminal Device in Cisterna Chyli, Open Approach */
"07WL0DZ" = "1" /* Revision of Intraluminal Device in Cisterna Chyli, Open Approach */
"07WL30Z" = "1" /* Revision of Drainage Device in Cisterna Chyli, Percutaneous Approach */
"07WL33Z" = "1" /* Revision of Infusion Device in Cisterna Chyli, Percutaneous Approach */
"07WL3CZ" = "1" /* Revision of Extraluminal Device in Cisterna Chyli, Percutaneous Approach */
"07WL3DZ" = "1" /* Revision of Intraluminal Device in Cisterna Chyli, Percutaneous Approach */
"07WL40Z" = "1" /* Revision of Drainage Device in Cisterna Chyli, Percutaneous Endoscopic Approach */
"07WL43Z" = "1" /* Revision of Infusion Device in Cisterna Chyli, Percutaneous Endoscopic Approach */
"07WL4CZ" = "1" /* Revision of Extraluminal Device in Cisterna Chyli, Percutaneous Endoscopic Approach */
"07WL4DZ" = "1" /* Revision of Intraluminal Device in Cisterna Chyli, Percutaneous Endoscopic Approach */
"0B110F4" = "1" /* Bypass Trachea to Cutaneous with Tracheostomy Device, Open Approach */
"0B110Z4" = "1" /* Bypass Trachea to Cutaneous, Open Approach */
"0B113F4" = "1" /* Bypass Trachea to Cutaneous with Tracheostomy Device, Percutaneous Approach */
"0B113Z4" = "1" /* Bypass Trachea to Cutaneous, Percutaneous Approach */
"0B114F4" = "1" /* Bypass Trachea to Cutaneous with Tracheostomy Device, Percutaneous Endoscopic Approach */
"0B114Z4" = "1" /* Bypass Trachea to Cutaneous, Percutaneous Endoscopic Approach */
"0B530ZZ" = "1" /* Destruction of Right Main Bronchus, Open Approach */
"0B533ZZ" = "1" /* Destruction of Right Main Bronchus, Percutaneous Approach */
"0B537ZZ" = "1" /* Destruction of Right Main Bronchus, Via Natural or Artificial Opening */
"0B538ZZ" = "1" /* Destruction of Right Main Bronchus, Via Natural or Artificial Opening Endoscopic */
"0B540ZZ" = "1" /* Destruction of Right Upper Lobe Bronchus, Open Approach */
"0B543ZZ" = "1" /* Destruction of Right Upper Lobe Bronchus, Percutaneous Approach */
"0B547ZZ" = "1" /* Destruction of Right Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0B548ZZ" = "1" /* Destruction of Right Upper Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0B550ZZ" = "1" /* Destruction of Right Middle Lobe Bronchus, Open Approach */
"0B553ZZ" = "1" /* Destruction of Right Middle Lobe Bronchus, Percutaneous Approach */
"0B557ZZ" = "1" /* Destruction of Right Middle Lobe Bronchus, Via Natural or Artificial Opening */
"0B558ZZ" = "1" /* Destruction of Right Middle Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0B560ZZ" = "1" /* Destruction of Right Lower Lobe Bronchus, Open Approach */
"0B563ZZ" = "1" /* Destruction of Right Lower Lobe Bronchus, Percutaneous Approach */
"0B567ZZ" = "1" /* Destruction of Right Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0B568ZZ" = "1" /* Destruction of Right Lower Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0B570ZZ" = "1" /* Destruction of Left Main Bronchus, Open Approach */
"0B573ZZ" = "1" /* Destruction of Left Main Bronchus, Percutaneous Approach */
"0B577ZZ" = "1" /* Destruction of Left Main Bronchus, Via Natural or Artificial Opening */
"0B578ZZ" = "1" /* Destruction of Left Main Bronchus, Via Natural or Artificial Opening Endoscopic */
"0B580ZZ" = "1" /* Destruction of Left Upper Lobe Bronchus, Open Approach */
"0B583ZZ" = "1" /* Destruction of Left Upper Lobe Bronchus, Percutaneous Approach */
"0B587ZZ" = "1" /* Destruction of Left Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0B588ZZ" = "1" /* Destruction of Left Upper Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0B590ZZ" = "1" /* Destruction of Lingula Bronchus, Open Approach */
"0B593ZZ" = "1" /* Destruction of Lingula Bronchus, Percutaneous Approach */
"0B597ZZ" = "1" /* Destruction of Lingula Bronchus, Via Natural or Artificial Opening */
"0B598ZZ" = "1" /* Destruction of Lingula Bronchus, Via Natural or Artificial Opening Endoscopic */
"0B5B0ZZ" = "1" /* Destruction of Left Lower Lobe Bronchus, Open Approach */
"0B5B3ZZ" = "1" /* Destruction of Left Lower Lobe Bronchus, Percutaneous Approach */
"0B5B7ZZ" = "1" /* Destruction of Left Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0B5B8ZZ" = "1" /* Destruction of Left Lower Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0B5C0ZZ" = "1" /* Destruction of Right Upper Lung Lobe, Open Approach */
"0B5C3ZZ" = "1" /* Destruction of Right Upper Lung Lobe, Percutaneous Approach */
"0B5C4ZZ" = "1" /* Destruction of Right Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0B5C7ZZ" = "1" /* Destruction of Right Upper Lung Lobe, Via Natural or Artificial Opening */
"0B5C8ZZ" = "1" /* Destruction of Right Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0B5D0ZZ" = "1" /* Destruction of Right Middle Lung Lobe, Open Approach */
"0B5D3ZZ" = "1" /* Destruction of Right Middle Lung Lobe, Percutaneous Approach */
"0B5D4ZZ" = "1" /* Destruction of Right Middle Lung Lobe, Percutaneous Endoscopic Approach */
"0B5D7ZZ" = "1" /* Destruction of Right Middle Lung Lobe, Via Natural or Artificial Opening */
"0B5D8ZZ" = "1" /* Destruction of Right Middle Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0B5F0ZZ" = "1" /* Destruction of Right Lower Lung Lobe, Open Approach */
"0B5F3ZZ" = "1" /* Destruction of Right Lower Lung Lobe, Percutaneous Approach */
"0B5F4ZZ" = "1" /* Destruction of Right Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0B5F7ZZ" = "1" /* Destruction of Right Lower Lung Lobe, Via Natural or Artificial Opening */
"0B5F8ZZ" = "1" /* Destruction of Right Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0B5G0ZZ" = "1" /* Destruction of Left Upper Lung Lobe, Open Approach */
"0B5G3ZZ" = "1" /* Destruction of Left Upper Lung Lobe, Percutaneous Approach */
"0B5G4ZZ" = "1" /* Destruction of Left Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0B5G7ZZ" = "1" /* Destruction of Left Upper Lung Lobe, Via Natural or Artificial Opening */
"0B5G8ZZ" = "1" /* Destruction of Left Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0B5H0ZZ" = "1" /* Destruction of Lung Lingula, Open Approach */
"0B5H3ZZ" = "1" /* Destruction of Lung Lingula, Percutaneous Approach */
"0B5H4ZZ" = "1" /* Destruction of Lung Lingula, Percutaneous Endoscopic Approach */
"0B5H7ZZ" = "1" /* Destruction of Lung Lingula, Via Natural or Artificial Opening */
"0B5H8ZZ" = "1" /* Destruction of Lung Lingula, Via Natural or Artificial Opening Endoscopic */
"0B5J0ZZ" = "1" /* Destruction of Left Lower Lung Lobe, Open Approach */
"0B5J3ZZ" = "1" /* Destruction of Left Lower Lung Lobe, Percutaneous Approach */
"0B5J4ZZ" = "1" /* Destruction of Left Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0B5J7ZZ" = "1" /* Destruction of Left Lower Lung Lobe, Via Natural or Artificial Opening */
"0B5J8ZZ" = "1" /* Destruction of Left Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0B5K0ZZ" = "1" /* Destruction of Right Lung, Open Approach */
"0B5K3ZZ" = "1" /* Destruction of Right Lung, Percutaneous Approach */
"0B5K4ZZ" = "1" /* Destruction of Right Lung, Percutaneous Endoscopic Approach */
"0B5K7ZZ" = "1" /* Destruction of Right Lung, Via Natural or Artificial Opening */
"0B5K8ZZ" = "1" /* Destruction of Right Lung, Via Natural or Artificial Opening Endoscopic */
"0B5L0ZZ" = "1" /* Destruction of Left Lung, Open Approach */
"0B5L3ZZ" = "1" /* Destruction of Left Lung, Percutaneous Approach */
"0B5L4ZZ" = "1" /* Destruction of Left Lung, Percutaneous Endoscopic Approach */
"0B5L7ZZ" = "1" /* Destruction of Left Lung, Via Natural or Artificial Opening */
"0B5L8ZZ" = "1" /* Destruction of Left Lung, Via Natural or Artificial Opening Endoscopic */
"0B5M0ZZ" = "1" /* Destruction of Bilateral Lungs, Open Approach */
"0B5M3ZZ" = "1" /* Destruction of Bilateral Lungs, Percutaneous Approach */
"0B5M4ZZ" = "1" /* Destruction of Bilateral Lungs, Percutaneous Endoscopic Approach */
"0B5M7ZZ" = "1" /* Destruction of Bilateral Lungs, Via Natural or Artificial Opening */
"0B5M8ZZ" = "1" /* Destruction of Bilateral Lungs, Via Natural or Artificial Opening Endoscopic */
"0B5R0ZZ" = "1" /* Destruction of Right Diaphragm, Open Approach */
"0B5R3ZZ" = "1" /* Destruction of Right Diaphragm, Percutaneous Approach */
"0B5R4ZZ" = "1" /* Destruction of Right Diaphragm, Percutaneous Endoscopic Approach */
"0B5S0ZZ" = "1" /* Destruction of Left Diaphragm, Open Approach */
"0B5S3ZZ" = "1" /* Destruction of Left Diaphragm, Percutaneous Approach */
"0B5S4ZZ" = "1" /* Destruction of Left Diaphragm, Percutaneous Endoscopic Approach */
"0B710DZ" = "1" /* Dilation of Trachea with Intraluminal Device, Open Approach */
"0B710ZZ" = "1" /* Dilation of Trachea, Open Approach */
"0B713DZ" = "1" /* Dilation of Trachea with Intraluminal Device, Percutaneous Approach */
"0B713ZZ" = "1" /* Dilation of Trachea, Percutaneous Approach */
"0B714DZ" = "1" /* Dilation of Trachea with Intraluminal Device, Percutaneous Endoscopic Approach */
"0B714ZZ" = "1" /* Dilation of Trachea, Percutaneous Endoscopic Approach */
"0B717DZ" = "1" /* Dilation of Trachea with Intraluminal Device, Via Natural or Artificial Opening */
"0B717ZZ" = "1" /* Dilation of Trachea, Via Natural or Artificial Opening */
"0B718DZ" = "1" /* Dilation of Trachea with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0B718ZZ" = "1" /* Dilation of Trachea, Via Natural or Artificial Opening Endoscopic */
"0B720DZ" = "1" /* Dilation of Carina with Intraluminal Device, Open Approach */
"0B720ZZ" = "1" /* Dilation of Carina, Open Approach */
"0B723DZ" = "1" /* Dilation of Carina with Intraluminal Device, Percutaneous Approach */
"0B723ZZ" = "1" /* Dilation of Carina, Percutaneous Approach */
"0B724DZ" = "1" /* Dilation of Carina with Intraluminal Device, Percutaneous Endoscopic Approach */
"0B724ZZ" = "1" /* Dilation of Carina, Percutaneous Endoscopic Approach */
"0B727DZ" = "1" /* Dilation of Carina with Intraluminal Device, Via Natural or Artificial Opening */
"0B727ZZ" = "1" /* Dilation of Carina, Via Natural or Artificial Opening */
"0B728DZ" = "1" /* Dilation of Carina with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0B728ZZ" = "1" /* Dilation of Carina, Via Natural or Artificial Opening Endoscopic */
"0B910ZX" = "1" /* Drainage of Trachea, Open Approach, Diagnostic */
"0B920ZX" = "1" /* Drainage of Carina, Open Approach, Diagnostic */
"0B9300Z" = "1" /* Drainage of Right Main Bronchus with Drainage Device, Open Approach */
"0B930ZX" = "1" /* Drainage of Right Main Bronchus, Open Approach, Diagnostic */
"0B930ZZ" = "1" /* Drainage of Right Main Bronchus, Open Approach */
"0B9330Z" = "1" /* Drainage of Right Main Bronchus with Drainage Device, Percutaneous Approach */
"0B933ZZ" = "1" /* Drainage of Right Main Bronchus, Percutaneous Approach */
"0B9340Z" = "1" /* Drainage of Right Main Bronchus with Drainage Device, Percutaneous Endoscopic Approach */
"0B934ZZ" = "1" /* Drainage of Right Main Bronchus, Percutaneous Endoscopic Approach */
"0B9370Z" = "1" /* Drainage of Right Main Bronchus with Drainage Device, Via Natural or Artificial Opening */
"0B937ZZ" = "1" /* Drainage of Right Main Bronchus, Via Natural or Artificial Opening */
"0B9380Z" = "1" /* Drainage of Right Main Bronchus with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B938ZZ" = "1" /* Drainage of Right Main Bronchus, Via Natural or Artificial Opening Endoscopic */
"0B9400Z" = "1" /* Drainage of Right Upper Lobe Bronchus with Drainage Device, Open Approach */
"0B940ZX" = "1" /* Drainage of Right Upper Lobe Bronchus, Open Approach, Diagnostic */
"0B940ZZ" = "1" /* Drainage of Right Upper Lobe Bronchus, Open Approach */
"0B9430Z" = "1" /* Drainage of Right Upper Lobe Bronchus with Drainage Device, Percutaneous Approach */
"0B943ZZ" = "1" /* Drainage of Right Upper Lobe Bronchus, Percutaneous Approach */
"0B9440Z" = "1" /* Drainage of Right Upper Lobe Bronchus with Drainage Device, Percutaneous Endoscopic Approach */
"0B944ZZ" = "1" /* Drainage of Right Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0B9470Z" = "1" /* Drainage of Right Upper Lobe Bronchus with Drainage Device, Via Natural or Artificial Opening */
"0B947ZZ" = "1" /* Drainage of Right Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0B9480Z" = "1" /* Drainage of Right Upper Lobe Bronchus with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B948ZZ" = "1" /* Drainage of Right Upper Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0B9500Z" = "1" /* Drainage of Right Middle Lobe Bronchus with Drainage Device, Open Approach */
"0B950ZX" = "1" /* Drainage of Right Middle Lobe Bronchus, Open Approach, Diagnostic */
"0B950ZZ" = "1" /* Drainage of Right Middle Lobe Bronchus, Open Approach */
"0B9530Z" = "1" /* Drainage of Right Middle Lobe Bronchus with Drainage Device, Percutaneous Approach */
"0B953ZZ" = "1" /* Drainage of Right Middle Lobe Bronchus, Percutaneous Approach */
"0B9540Z" = "1" /* Drainage of Right Middle Lobe Bronchus with Drainage Device, Percutaneous Endoscopic Approach */
"0B954ZZ" = "1" /* Drainage of Right Middle Lobe Bronchus, Percutaneous Endoscopic Approach */
"0B9570Z" = "1" /* Drainage of Right Middle Lobe Bronchus with Drainage Device, Via Natural or Artificial Opening */
"0B957ZZ" = "1" /* Drainage of Right Middle Lobe Bronchus, Via Natural or Artificial Opening */
"0B9580Z" = "1" /* Drainage of Right Middle Lobe Bronchus with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B958ZZ" = "1" /* Drainage of Right Middle Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0B9600Z" = "1" /* Drainage of Right Lower Lobe Bronchus with Drainage Device, Open Approach */
"0B960ZX" = "1" /* Drainage of Right Lower Lobe Bronchus, Open Approach, Diagnostic */
"0B960ZZ" = "1" /* Drainage of Right Lower Lobe Bronchus, Open Approach */
"0B9630Z" = "1" /* Drainage of Right Lower Lobe Bronchus with Drainage Device, Percutaneous Approach */
"0B963ZZ" = "1" /* Drainage of Right Lower Lobe Bronchus, Percutaneous Approach */
"0B9640Z" = "1" /* Drainage of Right Lower Lobe Bronchus with Drainage Device, Percutaneous Endoscopic Approach */
"0B964ZZ" = "1" /* Drainage of Right Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0B9670Z" = "1" /* Drainage of Right Lower Lobe Bronchus with Drainage Device, Via Natural or Artificial Opening */
"0B967ZZ" = "1" /* Drainage of Right Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0B9680Z" = "1" /* Drainage of Right Lower Lobe Bronchus with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B968ZZ" = "1" /* Drainage of Right Lower Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0B9700Z" = "1" /* Drainage of Left Main Bronchus with Drainage Device, Open Approach */
"0B970ZX" = "1" /* Drainage of Left Main Bronchus, Open Approach, Diagnostic */
"0B970ZZ" = "1" /* Drainage of Left Main Bronchus, Open Approach */
"0B9730Z" = "1" /* Drainage of Left Main Bronchus with Drainage Device, Percutaneous Approach */
"0B973ZZ" = "1" /* Drainage of Left Main Bronchus, Percutaneous Approach */
"0B9740Z" = "1" /* Drainage of Left Main Bronchus with Drainage Device, Percutaneous Endoscopic Approach */
"0B974ZZ" = "1" /* Drainage of Left Main Bronchus, Percutaneous Endoscopic Approach */
"0B9770Z" = "1" /* Drainage of Left Main Bronchus with Drainage Device, Via Natural or Artificial Opening */
"0B977ZZ" = "1" /* Drainage of Left Main Bronchus, Via Natural or Artificial Opening */
"0B9780Z" = "1" /* Drainage of Left Main Bronchus with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B978ZZ" = "1" /* Drainage of Left Main Bronchus, Via Natural or Artificial Opening Endoscopic */
"0B9800Z" = "1" /* Drainage of Left Upper Lobe Bronchus with Drainage Device, Open Approach */
"0B980ZX" = "1" /* Drainage of Left Upper Lobe Bronchus, Open Approach, Diagnostic */
"0B980ZZ" = "1" /* Drainage of Left Upper Lobe Bronchus, Open Approach */
"0B9830Z" = "1" /* Drainage of Left Upper Lobe Bronchus with Drainage Device, Percutaneous Approach */
"0B983ZZ" = "1" /* Drainage of Left Upper Lobe Bronchus, Percutaneous Approach */
"0B9840Z" = "1" /* Drainage of Left Upper Lobe Bronchus with Drainage Device, Percutaneous Endoscopic Approach */
"0B984ZZ" = "1" /* Drainage of Left Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0B9870Z" = "1" /* Drainage of Left Upper Lobe Bronchus with Drainage Device, Via Natural or Artificial Opening */
"0B987ZZ" = "1" /* Drainage of Left Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0B9880Z" = "1" /* Drainage of Left Upper Lobe Bronchus with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B988ZZ" = "1" /* Drainage of Left Upper Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0B9900Z" = "1" /* Drainage of Lingula Bronchus with Drainage Device, Open Approach */
"0B990ZX" = "1" /* Drainage of Lingula Bronchus, Open Approach, Diagnostic */
"0B990ZZ" = "1" /* Drainage of Lingula Bronchus, Open Approach */
"0B9930Z" = "1" /* Drainage of Lingula Bronchus with Drainage Device, Percutaneous Approach */
"0B993ZZ" = "1" /* Drainage of Lingula Bronchus, Percutaneous Approach */
"0B9940Z" = "1" /* Drainage of Lingula Bronchus with Drainage Device, Percutaneous Endoscopic Approach */
"0B994ZZ" = "1" /* Drainage of Lingula Bronchus, Percutaneous Endoscopic Approach */
"0B9970Z" = "1" /* Drainage of Lingula Bronchus with Drainage Device, Via Natural or Artificial Opening */
"0B997ZZ" = "1" /* Drainage of Lingula Bronchus, Via Natural or Artificial Opening */
"0B9980Z" = "1" /* Drainage of Lingula Bronchus with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B998ZZ" = "1" /* Drainage of Lingula Bronchus, Via Natural or Artificial Opening Endoscopic */
"0B9B00Z" = "1" /* Drainage of Left Lower Lobe Bronchus with Drainage Device, Open Approach */
"0B9B0ZX" = "1" /* Drainage of Left Lower Lobe Bronchus, Open Approach, Diagnostic */
"0B9B0ZZ" = "1" /* Drainage of Left Lower Lobe Bronchus, Open Approach */
"0B9B30Z" = "1" /* Drainage of Left Lower Lobe Bronchus with Drainage Device, Percutaneous Approach */
"0B9B3ZZ" = "1" /* Drainage of Left Lower Lobe Bronchus, Percutaneous Approach */
"0B9B40Z" = "1" /* Drainage of Left Lower Lobe Bronchus with Drainage Device, Percutaneous Endoscopic Approach */
"0B9B4ZZ" = "1" /* Drainage of Left Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0B9B70Z" = "1" /* Drainage of Left Lower Lobe Bronchus with Drainage Device, Via Natural or Artificial Opening */
"0B9B7ZZ" = "1" /* Drainage of Left Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0B9B80Z" = "1" /* Drainage of Left Lower Lobe Bronchus with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B9B8ZZ" = "1" /* Drainage of Left Lower Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0B9C00Z" = "1" /* Drainage of Right Upper Lung Lobe with Drainage Device, Open Approach */
"0B9C0ZZ" = "1" /* Drainage of Right Upper Lung Lobe, Open Approach */
"0B9C30Z" = "1" /* Drainage of Right Upper Lung Lobe with Drainage Device, Percutaneous Approach */
"0B9C3ZZ" = "1" /* Drainage of Right Upper Lung Lobe, Percutaneous Approach */
"0B9C40Z" = "1" /* Drainage of Right Upper Lung Lobe with Drainage Device, Percutaneous Endoscopic Approach */
"0B9C4ZZ" = "1" /* Drainage of Right Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0B9C70Z" = "1" /* Drainage of Right Upper Lung Lobe with Drainage Device, Via Natural or Artificial Opening */
"0B9C7ZZ" = "1" /* Drainage of Right Upper Lung Lobe, Via Natural or Artificial Opening */
"0B9C80Z" = "1" /* Drainage of Right Upper Lung Lobe with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B9C8ZX" = "1" /* Drainage of Right Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0B9C8ZZ" = "1" /* Drainage of Right Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0B9D00Z" = "1" /* Drainage of Right Middle Lung Lobe with Drainage Device, Open Approach */
"0B9D0ZZ" = "1" /* Drainage of Right Middle Lung Lobe, Open Approach */
"0B9D30Z" = "1" /* Drainage of Right Middle Lung Lobe with Drainage Device, Percutaneous Approach */
"0B9D3ZZ" = "1" /* Drainage of Right Middle Lung Lobe, Percutaneous Approach */
"0B9D40Z" = "1" /* Drainage of Right Middle Lung Lobe with Drainage Device, Percutaneous Endoscopic Approach */
"0B9D4ZZ" = "1" /* Drainage of Right Middle Lung Lobe, Percutaneous Endoscopic Approach */
"0B9D70Z" = "1" /* Drainage of Right Middle Lung Lobe with Drainage Device, Via Natural or Artificial Opening */
"0B9D7ZZ" = "1" /* Drainage of Right Middle Lung Lobe, Via Natural or Artificial Opening */
"0B9D80Z" = "1" /* Drainage of Right Middle Lung Lobe with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B9D8ZX" = "1" /* Drainage of Right Middle Lung Lobe, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0B9D8ZZ" = "1" /* Drainage of Right Middle Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0B9F00Z" = "1" /* Drainage of Right Lower Lung Lobe with Drainage Device, Open Approach */
"0B9F0ZZ" = "1" /* Drainage of Right Lower Lung Lobe, Open Approach */
"0B9F30Z" = "1" /* Drainage of Right Lower Lung Lobe with Drainage Device, Percutaneous Approach */
"0B9F3ZZ" = "1" /* Drainage of Right Lower Lung Lobe, Percutaneous Approach */
"0B9F40Z" = "1" /* Drainage of Right Lower Lung Lobe with Drainage Device, Percutaneous Endoscopic Approach */
"0B9F4ZZ" = "1" /* Drainage of Right Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0B9F70Z" = "1" /* Drainage of Right Lower Lung Lobe with Drainage Device, Via Natural or Artificial Opening */
"0B9F7ZZ" = "1" /* Drainage of Right Lower Lung Lobe, Via Natural or Artificial Opening */
"0B9F80Z" = "1" /* Drainage of Right Lower Lung Lobe with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B9F8ZX" = "1" /* Drainage of Right Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0B9F8ZZ" = "1" /* Drainage of Right Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0B9G00Z" = "1" /* Drainage of Left Upper Lung Lobe with Drainage Device, Open Approach */
"0B9G0ZZ" = "1" /* Drainage of Left Upper Lung Lobe, Open Approach */
"0B9G30Z" = "1" /* Drainage of Left Upper Lung Lobe with Drainage Device, Percutaneous Approach */
"0B9G3ZZ" = "1" /* Drainage of Left Upper Lung Lobe, Percutaneous Approach */
"0B9G40Z" = "1" /* Drainage of Left Upper Lung Lobe with Drainage Device, Percutaneous Endoscopic Approach */
"0B9G4ZZ" = "1" /* Drainage of Left Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0B9G70Z" = "1" /* Drainage of Left Upper Lung Lobe with Drainage Device, Via Natural or Artificial Opening */
"0B9G7ZZ" = "1" /* Drainage of Left Upper Lung Lobe, Via Natural or Artificial Opening */
"0B9G80Z" = "1" /* Drainage of Left Upper Lung Lobe with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B9G8ZX" = "1" /* Drainage of Left Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0B9G8ZZ" = "1" /* Drainage of Left Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0B9H00Z" = "1" /* Drainage of Lung Lingula with Drainage Device, Open Approach */
"0B9H0ZZ" = "1" /* Drainage of Lung Lingula, Open Approach */
"0B9H30Z" = "1" /* Drainage of Lung Lingula with Drainage Device, Percutaneous Approach */
"0B9H3ZZ" = "1" /* Drainage of Lung Lingula, Percutaneous Approach */
"0B9H40Z" = "1" /* Drainage of Lung Lingula with Drainage Device, Percutaneous Endoscopic Approach */
"0B9H4ZZ" = "1" /* Drainage of Lung Lingula, Percutaneous Endoscopic Approach */
"0B9H70Z" = "1" /* Drainage of Lung Lingula with Drainage Device, Via Natural or Artificial Opening */
"0B9H7ZZ" = "1" /* Drainage of Lung Lingula, Via Natural or Artificial Opening */
"0B9H80Z" = "1" /* Drainage of Lung Lingula with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B9H8ZX" = "1" /* Drainage of Lung Lingula, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0B9H8ZZ" = "1" /* Drainage of Lung Lingula, Via Natural or Artificial Opening Endoscopic */
"0B9J00Z" = "1" /* Drainage of Left Lower Lung Lobe with Drainage Device, Open Approach */
"0B9J0ZZ" = "1" /* Drainage of Left Lower Lung Lobe, Open Approach */
"0B9J30Z" = "1" /* Drainage of Left Lower Lung Lobe with Drainage Device, Percutaneous Approach */
"0B9J3ZZ" = "1" /* Drainage of Left Lower Lung Lobe, Percutaneous Approach */
"0B9J40Z" = "1" /* Drainage of Left Lower Lung Lobe with Drainage Device, Percutaneous Endoscopic Approach */
"0B9J4ZZ" = "1" /* Drainage of Left Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0B9J70Z" = "1" /* Drainage of Left Lower Lung Lobe with Drainage Device, Via Natural or Artificial Opening */
"0B9J7ZZ" = "1" /* Drainage of Left Lower Lung Lobe, Via Natural or Artificial Opening */
"0B9J80Z" = "1" /* Drainage of Left Lower Lung Lobe with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B9J8ZX" = "1" /* Drainage of Left Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0B9J8ZZ" = "1" /* Drainage of Left Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0B9K00Z" = "1" /* Drainage of Right Lung with Drainage Device, Open Approach */
"0B9K0ZZ" = "1" /* Drainage of Right Lung, Open Approach */
"0B9K30Z" = "1" /* Drainage of Right Lung with Drainage Device, Percutaneous Approach */
"0B9K3ZZ" = "1" /* Drainage of Right Lung, Percutaneous Approach */
"0B9K40Z" = "1" /* Drainage of Right Lung with Drainage Device, Percutaneous Endoscopic Approach */
"0B9K4ZZ" = "1" /* Drainage of Right Lung, Percutaneous Endoscopic Approach */
"0B9K70Z" = "1" /* Drainage of Right Lung with Drainage Device, Via Natural or Artificial Opening */
"0B9K7ZZ" = "1" /* Drainage of Right Lung, Via Natural or Artificial Opening */
"0B9K80Z" = "1" /* Drainage of Right Lung with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B9K8ZX" = "1" /* Drainage of Right Lung, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0B9K8ZZ" = "1" /* Drainage of Right Lung, Via Natural or Artificial Opening Endoscopic */
"0B9L00Z" = "1" /* Drainage of Left Lung with Drainage Device, Open Approach */
"0B9L0ZZ" = "1" /* Drainage of Left Lung, Open Approach */
"0B9L30Z" = "1" /* Drainage of Left Lung with Drainage Device, Percutaneous Approach */
"0B9L3ZZ" = "1" /* Drainage of Left Lung, Percutaneous Approach */
"0B9L40Z" = "1" /* Drainage of Left Lung with Drainage Device, Percutaneous Endoscopic Approach */
"0B9L4ZZ" = "1" /* Drainage of Left Lung, Percutaneous Endoscopic Approach */
"0B9L70Z" = "1" /* Drainage of Left Lung with Drainage Device, Via Natural or Artificial Opening */
"0B9L7ZZ" = "1" /* Drainage of Left Lung, Via Natural or Artificial Opening */
"0B9L80Z" = "1" /* Drainage of Left Lung with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B9L8ZX" = "1" /* Drainage of Left Lung, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0B9L8ZZ" = "1" /* Drainage of Left Lung, Via Natural or Artificial Opening Endoscopic */
"0B9M00Z" = "1" /* Drainage of Bilateral Lungs with Drainage Device, Open Approach */
"0B9M0ZZ" = "1" /* Drainage of Bilateral Lungs, Open Approach */
"0B9M30Z" = "1" /* Drainage of Bilateral Lungs with Drainage Device, Percutaneous Approach */
"0B9M3ZZ" = "1" /* Drainage of Bilateral Lungs, Percutaneous Approach */
"0B9M40Z" = "1" /* Drainage of Bilateral Lungs with Drainage Device, Percutaneous Endoscopic Approach */
"0B9M4ZZ" = "1" /* Drainage of Bilateral Lungs, Percutaneous Endoscopic Approach */
"0B9M70Z" = "1" /* Drainage of Bilateral Lungs with Drainage Device, Via Natural or Artificial Opening */
"0B9M7ZZ" = "1" /* Drainage of Bilateral Lungs, Via Natural or Artificial Opening */
"0B9M80Z" = "1" /* Drainage of Bilateral Lungs with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0B9M8ZX" = "1" /* Drainage of Bilateral Lungs, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0B9M8ZZ" = "1" /* Drainage of Bilateral Lungs, Via Natural or Artificial Opening Endoscopic */
"0B9N00Z" = "1" /* Drainage of Right Pleura with Drainage Device, Open Approach */
"0B9N0ZZ" = "1" /* Drainage of Right Pleura, Open Approach */
"0B9N30Z" = "1" /* Drainage of Right Pleura with Drainage Device, Percutaneous Approach */
"0B9P00Z" = "1" /* Drainage of Left Pleura with Drainage Device, Open Approach */
"0B9P0ZZ" = "1" /* Drainage of Left Pleura, Open Approach */
"0B9P30Z" = "1" /* Drainage of Left Pleura with Drainage Device, Percutaneous Approach */
"0B9R00Z" = "1" /* Drainage of Right Diaphragm with Drainage Device, Open Approach */
"0B9R0ZX" = "1" /* Drainage of Right Diaphragm, Open Approach, Diagnostic */
"0B9R0ZZ" = "1" /* Drainage of Right Diaphragm, Open Approach */
"0B9R30Z" = "1" /* Drainage of Right Diaphragm with Drainage Device, Percutaneous Approach */
"0B9R3ZX" = "1" /* Drainage of Right Diaphragm, Percutaneous Approach, Diagnostic */
"0B9R3ZZ" = "1" /* Drainage of Right Diaphragm, Percutaneous Approach */
"0B9R40Z" = "1" /* Drainage of Right Diaphragm with Drainage Device, Percutaneous Endoscopic Approach */
"0B9R4ZX" = "1" /* Drainage of Right Diaphragm, Percutaneous Endoscopic Approach, Diagnostic */
"0B9R4ZZ" = "1" /* Drainage of Right Diaphragm, Percutaneous Endoscopic Approach */
"0B9S00Z" = "1" /* Drainage of Left Diaphragm with Drainage Device, Open Approach */
"0B9S0ZX" = "1" /* Drainage of Left Diaphragm, Open Approach, Diagnostic */
"0B9S0ZZ" = "1" /* Drainage of Left Diaphragm, Open Approach */
"0B9S30Z" = "1" /* Drainage of Left Diaphragm with Drainage Device, Percutaneous Approach */
"0B9S3ZX" = "1" /* Drainage of Left Diaphragm, Percutaneous Approach, Diagnostic */
"0B9S3ZZ" = "1" /* Drainage of Left Diaphragm, Percutaneous Approach */
"0B9S40Z" = "1" /* Drainage of Left Diaphragm with Drainage Device, Percutaneous Endoscopic Approach */
"0B9S4ZX" = "1" /* Drainage of Left Diaphragm, Percutaneous Endoscopic Approach, Diagnostic */
"0B9S4ZZ" = "1" /* Drainage of Left Diaphragm, Percutaneous Endoscopic Approach */
"0BB10ZX" = "1" /* Excision of Trachea, Open Approach, Diagnostic */
"0BB20ZX" = "1" /* Excision of Carina, Open Approach, Diagnostic */
"0BB30ZX" = "1" /* Excision of Right Main Bronchus, Open Approach, Diagnostic */
"0BB30ZZ" = "1" /* Excision of Right Main Bronchus, Open Approach */
"0BB33ZZ" = "1" /* Excision of Right Main Bronchus, Percutaneous Approach */
"0BB37ZZ" = "1" /* Excision of Right Main Bronchus, Via Natural or Artificial Opening */
"0BB40ZX" = "1" /* Excision of Right Upper Lobe Bronchus, Open Approach, Diagnostic */
"0BB40ZZ" = "1" /* Excision of Right Upper Lobe Bronchus, Open Approach */
"0BB43ZZ" = "1" /* Excision of Right Upper Lobe Bronchus, Percutaneous Approach */
"0BB47ZZ" = "1" /* Excision of Right Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BB50ZX" = "1" /* Excision of Right Middle Lobe Bronchus, Open Approach, Diagnostic */
"0BB50ZZ" = "1" /* Excision of Right Middle Lobe Bronchus, Open Approach */
"0BB53ZZ" = "1" /* Excision of Right Middle Lobe Bronchus, Percutaneous Approach */
"0BB57ZZ" = "1" /* Excision of Right Middle Lobe Bronchus, Via Natural or Artificial Opening */
"0BB60ZX" = "1" /* Excision of Right Lower Lobe Bronchus, Open Approach, Diagnostic */
"0BB60ZZ" = "1" /* Excision of Right Lower Lobe Bronchus, Open Approach */
"0BB63ZZ" = "1" /* Excision of Right Lower Lobe Bronchus, Percutaneous Approach */
"0BB67ZZ" = "1" /* Excision of Right Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BB70ZX" = "1" /* Excision of Left Main Bronchus, Open Approach, Diagnostic */
"0BB70ZZ" = "1" /* Excision of Left Main Bronchus, Open Approach */
"0BB73ZZ" = "1" /* Excision of Left Main Bronchus, Percutaneous Approach */
"0BB77ZZ" = "1" /* Excision of Left Main Bronchus, Via Natural or Artificial Opening */
"0BB80ZX" = "1" /* Excision of Left Upper Lobe Bronchus, Open Approach, Diagnostic */
"0BB80ZZ" = "1" /* Excision of Left Upper Lobe Bronchus, Open Approach */
"0BB83ZZ" = "1" /* Excision of Left Upper Lobe Bronchus, Percutaneous Approach */
"0BB87ZZ" = "1" /* Excision of Left Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BB90ZX" = "1" /* Excision of Lingula Bronchus, Open Approach, Diagnostic */
"0BB90ZZ" = "1" /* Excision of Lingula Bronchus, Open Approach */
"0BB93ZZ" = "1" /* Excision of Lingula Bronchus, Percutaneous Approach */
"0BB97ZZ" = "1" /* Excision of Lingula Bronchus, Via Natural or Artificial Opening */
"0BBB0ZX" = "1" /* Excision of Left Lower Lobe Bronchus, Open Approach, Diagnostic */
"0BBB0ZZ" = "1" /* Excision of Left Lower Lobe Bronchus, Open Approach */
"0BBB3ZZ" = "1" /* Excision of Left Lower Lobe Bronchus, Percutaneous Approach */
"0BBB7ZZ" = "1" /* Excision of Left Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BBC0ZZ" = "1" /* Excision of Right Upper Lung Lobe, Open Approach */
"0BBC3ZZ" = "1" /* Excision of Right Upper Lung Lobe, Percutaneous Approach */
"0BBC4ZX" = "1" /* Excision of Right Upper Lung Lobe, Percutaneous Endoscopic Approach, Diagnostic */
"0BBC4ZZ" = "1" /* Excision of Right Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BBC7ZX" = "1" /* Excision of Right Upper Lung Lobe, Via Natural or Artificial Opening, Diagnostic */
"0BBC7ZZ" = "1" /* Excision of Right Upper Lung Lobe, Via Natural or Artificial Opening */
"0BBC8ZX" = "1" /* Excision of Right Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0BBC8ZZ" = "1" /* Excision of Right Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BBD0ZZ" = "1" /* Excision of Right Middle Lung Lobe, Open Approach */
"0BBD3ZZ" = "1" /* Excision of Right Middle Lung Lobe, Percutaneous Approach */
"0BBD4ZX" = "1" /* Excision of Right Middle Lung Lobe, Percutaneous Endoscopic Approach, Diagnostic */
"0BBD4ZZ" = "1" /* Excision of Right Middle Lung Lobe, Percutaneous Endoscopic Approach */
"0BBD7ZX" = "1" /* Excision of Right Middle Lung Lobe, Via Natural or Artificial Opening, Diagnostic */
"0BBD7ZZ" = "1" /* Excision of Right Middle Lung Lobe, Via Natural or Artificial Opening */
"0BBD8ZX" = "1" /* Excision of Right Middle Lung Lobe, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0BBD8ZZ" = "1" /* Excision of Right Middle Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BBF0ZZ" = "1" /* Excision of Right Lower Lung Lobe, Open Approach */
"0BBF3ZZ" = "1" /* Excision of Right Lower Lung Lobe, Percutaneous Approach */
"0BBF4ZX" = "1" /* Excision of Right Lower Lung Lobe, Percutaneous Endoscopic Approach, Diagnostic */
"0BBF4ZZ" = "1" /* Excision of Right Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BBF7ZX" = "1" /* Excision of Right Lower Lung Lobe, Via Natural or Artificial Opening, Diagnostic */
"0BBF7ZZ" = "1" /* Excision of Right Lower Lung Lobe, Via Natural or Artificial Opening */
"0BBF8ZX" = "1" /* Excision of Right Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0BBF8ZZ" = "1" /* Excision of Right Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BBG0ZZ" = "1" /* Excision of Left Upper Lung Lobe, Open Approach */
"0BBG3ZZ" = "1" /* Excision of Left Upper Lung Lobe, Percutaneous Approach */
"0BBG4ZX" = "1" /* Excision of Left Upper Lung Lobe, Percutaneous Endoscopic Approach, Diagnostic */
"0BBG4ZZ" = "1" /* Excision of Left Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BBG7ZX" = "1" /* Excision of Left Upper Lung Lobe, Via Natural or Artificial Opening, Diagnostic */
"0BBG7ZZ" = "1" /* Excision of Left Upper Lung Lobe, Via Natural or Artificial Opening */
"0BBG8ZX" = "1" /* Excision of Left Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0BBG8ZZ" = "1" /* Excision of Left Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BBH0ZZ" = "1" /* Excision of Lung Lingula, Open Approach */
"0BBH3ZZ" = "1" /* Excision of Lung Lingula, Percutaneous Approach */
"0BBH4ZX" = "1" /* Excision of Lung Lingula, Percutaneous Endoscopic Approach, Diagnostic */
"0BBH4ZZ" = "1" /* Excision of Lung Lingula, Percutaneous Endoscopic Approach */
"0BBH7ZX" = "1" /* Excision of Lung Lingula, Via Natural or Artificial Opening, Diagnostic */
"0BBH7ZZ" = "1" /* Excision of Lung Lingula, Via Natural or Artificial Opening */
"0BBH8ZX" = "1" /* Excision of Lung Lingula, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0BBH8ZZ" = "1" /* Excision of Lung Lingula, Via Natural or Artificial Opening Endoscopic */
"0BBJ0ZZ" = "1" /* Excision of Left Lower Lung Lobe, Open Approach */
"0BBJ3ZZ" = "1" /* Excision of Left Lower Lung Lobe, Percutaneous Approach */
"0BBJ4ZX" = "1" /* Excision of Left Lower Lung Lobe, Percutaneous Endoscopic Approach, Diagnostic */
"0BBJ4ZZ" = "1" /* Excision of Left Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BBJ7ZX" = "1" /* Excision of Left Lower Lung Lobe, Via Natural or Artificial Opening, Diagnostic */
"0BBJ7ZZ" = "1" /* Excision of Left Lower Lung Lobe, Via Natural or Artificial Opening */
"0BBJ8ZX" = "1" /* Excision of Left Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0BBJ8ZZ" = "1" /* Excision of Left Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BBK0ZZ" = "1" /* Excision of Right Lung, Open Approach */
"0BBK3ZZ" = "1" /* Excision of Right Lung, Percutaneous Approach */
"0BBK4ZX" = "1" /* Excision of Right Lung, Percutaneous Endoscopic Approach, Diagnostic */
"0BBK4ZZ" = "1" /* Excision of Right Lung, Percutaneous Endoscopic Approach */
"0BBK7ZX" = "1" /* Excision of Right Lung, Via Natural or Artificial Opening, Diagnostic */
"0BBK7ZZ" = "1" /* Excision of Right Lung, Via Natural or Artificial Opening */
"0BBK8ZX" = "1" /* Excision of Right Lung, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0BBK8ZZ" = "1" /* Excision of Right Lung, Via Natural or Artificial Opening Endoscopic */
"0BBL0ZZ" = "1" /* Excision of Left Lung, Open Approach */
"0BBL3ZZ" = "1" /* Excision of Left Lung, Percutaneous Approach */
"0BBL4ZX" = "1" /* Excision of Left Lung, Percutaneous Endoscopic Approach, Diagnostic */
"0BBL4ZZ" = "1" /* Excision of Left Lung, Percutaneous Endoscopic Approach */
"0BBL7ZX" = "1" /* Excision of Left Lung, Via Natural or Artificial Opening, Diagnostic */
"0BBL7ZZ" = "1" /* Excision of Left Lung, Via Natural or Artificial Opening */
"0BBL8ZX" = "1" /* Excision of Left Lung, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0BBL8ZZ" = "1" /* Excision of Left Lung, Via Natural or Artificial Opening Endoscopic */
"0BBM0ZZ" = "1" /* Excision of Bilateral Lungs, Open Approach */
"0BBM3ZZ" = "1" /* Excision of Bilateral Lungs, Percutaneous Approach */
"0BBM4ZX" = "1" /* Excision of Bilateral Lungs, Percutaneous Endoscopic Approach, Diagnostic */
"0BBM4ZZ" = "1" /* Excision of Bilateral Lungs, Percutaneous Endoscopic Approach */
"0BBM7ZX" = "1" /* Excision of Bilateral Lungs, Via Natural or Artificial Opening, Diagnostic */
"0BBM7ZZ" = "1" /* Excision of Bilateral Lungs, Via Natural or Artificial Opening */
"0BBM8ZX" = "1" /* Excision of Bilateral Lungs, Via Natural or Artificial Opening Endoscopic, Diagnostic */
"0BBM8ZZ" = "1" /* Excision of Bilateral Lungs, Via Natural or Artificial Opening Endoscopic */
"0BBN0ZZ" = "1" /* Excision of Right Pleura, Open Approach */
"0BBN3ZZ" = "1" /* Excision of Right Pleura, Percutaneous Approach */
"0BBN4ZX" = "1" /* Excision of Right Pleura, Percutaneous Endoscopic Approach, Diagnostic */
"0BBN4ZZ" = "1" /* Excision of Right Pleura, Percutaneous Endoscopic Approach */
"0BBP0ZZ" = "1" /* Excision of Left Pleura, Open Approach */
"0BBP3ZZ" = "1" /* Excision of Left Pleura, Percutaneous Approach */
"0BBP4ZX" = "1" /* Excision of Left Pleura, Percutaneous Endoscopic Approach, Diagnostic */
"0BBP4ZZ" = "1" /* Excision of Left Pleura, Percutaneous Endoscopic Approach */
"0BBR0ZX" = "1" /* Excision of Right Diaphragm, Open Approach, Diagnostic */
"0BBR0ZZ" = "1" /* Excision of Right Diaphragm, Open Approach */
"0BBR3ZX" = "1" /* Excision of Right Diaphragm, Percutaneous Approach, Diagnostic */
"0BBR3ZZ" = "1" /* Excision of Right Diaphragm, Percutaneous Approach */
"0BBR4ZX" = "1" /* Excision of Right Diaphragm, Percutaneous Endoscopic Approach, Diagnostic */
"0BBR4ZZ" = "1" /* Excision of Right Diaphragm, Percutaneous Endoscopic Approach */
"0BBS0ZX" = "1" /* Excision of Left Diaphragm, Open Approach, Diagnostic */
"0BBS0ZZ" = "1" /* Excision of Left Diaphragm, Open Approach */
"0BBS3ZX" = "1" /* Excision of Left Diaphragm, Percutaneous Approach, Diagnostic */
"0BBS3ZZ" = "1" /* Excision of Left Diaphragm, Percutaneous Approach */
"0BBS4ZX" = "1" /* Excision of Left Diaphragm, Percutaneous Endoscopic Approach, Diagnostic */
"0BBS4ZZ" = "1" /* Excision of Left Diaphragm, Percutaneous Endoscopic Approach */
"0BC30ZZ" = "1" /* Extirpation of Matter from Right Main Bronchus, Open Approach */
"0BC33ZZ" = "1" /* Extirpation of Matter from Right Main Bronchus, Percutaneous Approach */
"0BC34ZZ" = "1" /* Extirpation of Matter from Right Main Bronchus, Percutaneous Endoscopic Approach */
"0BC40ZZ" = "1" /* Extirpation of Matter from Right Upper Lobe Bronchus, Open Approach */
"0BC43ZZ" = "1" /* Extirpation of Matter from Right Upper Lobe Bronchus, Percutaneous Approach */
"0BC44ZZ" = "1" /* Extirpation of Matter from Right Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BC50ZZ" = "1" /* Extirpation of Matter from Right Middle Lobe Bronchus, Open Approach */
"0BC53ZZ" = "1" /* Extirpation of Matter from Right Middle Lobe Bronchus, Percutaneous Approach */
"0BC54ZZ" = "1" /* Extirpation of Matter from Right Middle Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BC60ZZ" = "1" /* Extirpation of Matter from Right Lower Lobe Bronchus, Open Approach */
"0BC63ZZ" = "1" /* Extirpation of Matter from Right Lower Lobe Bronchus, Percutaneous Approach */
"0BC64ZZ" = "1" /* Extirpation of Matter from Right Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BC70ZZ" = "1" /* Extirpation of Matter from Left Main Bronchus, Open Approach */
"0BC73ZZ" = "1" /* Extirpation of Matter from Left Main Bronchus, Percutaneous Approach */
"0BC74ZZ" = "1" /* Extirpation of Matter from Left Main Bronchus, Percutaneous Endoscopic Approach */
"0BC80ZZ" = "1" /* Extirpation of Matter from Left Upper Lobe Bronchus, Open Approach */
"0BC83ZZ" = "1" /* Extirpation of Matter from Left Upper Lobe Bronchus, Percutaneous Approach */
"0BC84ZZ" = "1" /* Extirpation of Matter from Left Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BC90ZZ" = "1" /* Extirpation of Matter from Lingula Bronchus, Open Approach */
"0BC93ZZ" = "1" /* Extirpation of Matter from Lingula Bronchus, Percutaneous Approach */
"0BC94ZZ" = "1" /* Extirpation of Matter from Lingula Bronchus, Percutaneous Endoscopic Approach */
"0BCB0ZZ" = "1" /* Extirpation of Matter from Left Lower Lobe Bronchus, Open Approach */
"0BCB3ZZ" = "1" /* Extirpation of Matter from Left Lower Lobe Bronchus, Percutaneous Approach */
"0BCB4ZZ" = "1" /* Extirpation of Matter from Left Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BCC0ZZ" = "1" /* Extirpation of Matter from Right Upper Lung Lobe, Open Approach */
"0BCC3ZZ" = "1" /* Extirpation of Matter from Right Upper Lung Lobe, Percutaneous Approach */
"0BCC4ZZ" = "1" /* Extirpation of Matter from Right Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BCC7ZZ" = "1" /* Extirpation of Matter from Right Upper Lung Lobe, Via Natural or Artificial Opening */
"0BCC8ZZ" = "1" /* Extirpation of Matter from Right Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BCD0ZZ" = "1" /* Extirpation of Matter from Right Middle Lung Lobe, Open Approach */
"0BCD3ZZ" = "1" /* Extirpation of Matter from Right Middle Lung Lobe, Percutaneous Approach */
"0BCD4ZZ" = "1" /* Extirpation of Matter from Right Middle Lung Lobe, Percutaneous Endoscopic Approach */
"0BCD7ZZ" = "1" /* Extirpation of Matter from Right Middle Lung Lobe, Via Natural or Artificial Opening */
"0BCD8ZZ" = "1" /* Extirpation of Matter from Right Middle Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BCF0ZZ" = "1" /* Extirpation of Matter from Right Lower Lung Lobe, Open Approach */
"0BCF3ZZ" = "1" /* Extirpation of Matter from Right Lower Lung Lobe, Percutaneous Approach */
"0BCF4ZZ" = "1" /* Extirpation of Matter from Right Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BCF7ZZ" = "1" /* Extirpation of Matter from Right Lower Lung Lobe, Via Natural or Artificial Opening */
"0BCF8ZZ" = "1" /* Extirpation of Matter from Right Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BCG0ZZ" = "1" /* Extirpation of Matter from Left Upper Lung Lobe, Open Approach */
"0BCG3ZZ" = "1" /* Extirpation of Matter from Left Upper Lung Lobe, Percutaneous Approach */
"0BCG4ZZ" = "1" /* Extirpation of Matter from Left Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BCG7ZZ" = "1" /* Extirpation of Matter from Left Upper Lung Lobe, Via Natural or Artificial Opening */
"0BCG8ZZ" = "1" /* Extirpation of Matter from Left Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BCH0ZZ" = "1" /* Extirpation of Matter from Lung Lingula, Open Approach */
"0BCH3ZZ" = "1" /* Extirpation of Matter from Lung Lingula, Percutaneous Approach */
"0BCH4ZZ" = "1" /* Extirpation of Matter from Lung Lingula, Percutaneous Endoscopic Approach */
"0BCH7ZZ" = "1" /* Extirpation of Matter from Lung Lingula, Via Natural or Artificial Opening */
"0BCH8ZZ" = "1" /* Extirpation of Matter from Lung Lingula, Via Natural or Artificial Opening Endoscopic */
"0BCJ0ZZ" = "1" /* Extirpation of Matter from Left Lower Lung Lobe, Open Approach */
"0BCJ3ZZ" = "1" /* Extirpation of Matter from Left Lower Lung Lobe, Percutaneous Approach */
"0BCJ4ZZ" = "1" /* Extirpation of Matter from Left Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BCJ7ZZ" = "1" /* Extirpation of Matter from Left Lower Lung Lobe, Via Natural or Artificial Opening */
"0BCJ8ZZ" = "1" /* Extirpation of Matter from Left Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BCK0ZZ" = "1" /* Extirpation of Matter from Right Lung, Open Approach */
"0BCK3ZZ" = "1" /* Extirpation of Matter from Right Lung, Percutaneous Approach */
"0BCK4ZZ" = "1" /* Extirpation of Matter from Right Lung, Percutaneous Endoscopic Approach */
"0BCK7ZZ" = "1" /* Extirpation of Matter from Right Lung, Via Natural or Artificial Opening */
"0BCK8ZZ" = "1" /* Extirpation of Matter from Right Lung, Via Natural or Artificial Opening Endoscopic */
"0BCL0ZZ" = "1" /* Extirpation of Matter from Left Lung, Open Approach */
"0BCL3ZZ" = "1" /* Extirpation of Matter from Left Lung, Percutaneous Approach */
"0BCL4ZZ" = "1" /* Extirpation of Matter from Left Lung, Percutaneous Endoscopic Approach */
"0BCL7ZZ" = "1" /* Extirpation of Matter from Left Lung, Via Natural or Artificial Opening */
"0BCL8ZZ" = "1" /* Extirpation of Matter from Left Lung, Via Natural or Artificial Opening Endoscopic */
"0BCM0ZZ" = "1" /* Extirpation of Matter from Bilateral Lungs, Open Approach */
"0BCM3ZZ" = "1" /* Extirpation of Matter from Bilateral Lungs, Percutaneous Approach */
"0BCM4ZZ" = "1" /* Extirpation of Matter from Bilateral Lungs, Percutaneous Endoscopic Approach */
"0BCM7ZZ" = "1" /* Extirpation of Matter from Bilateral Lungs, Via Natural or Artificial Opening */
"0BCM8ZZ" = "1" /* Extirpation of Matter from Bilateral Lungs, Via Natural or Artificial Opening Endoscopic */
"0BCN0ZZ" = "1" /* Extirpation of Matter from Right Pleura, Open Approach */
"0BCN3ZZ" = "1" /* Extirpation of Matter from Right Pleura, Percutaneous Approach */
"0BCN4ZZ" = "1" /* Extirpation of Matter from Right Pleura, Percutaneous Endoscopic Approach */
"0BCP0ZZ" = "1" /* Extirpation of Matter from Left Pleura, Open Approach */
"0BCP3ZZ" = "1" /* Extirpation of Matter from Left Pleura, Percutaneous Approach */
"0BCP4ZZ" = "1" /* Extirpation of Matter from Left Pleura, Percutaneous Endoscopic Approach */
"0BCR0ZZ" = "1" /* Extirpation of Matter from Right Diaphragm, Open Approach */
"0BCR3ZZ" = "1" /* Extirpation of Matter from Right Diaphragm, Percutaneous Approach */
"0BCR4ZZ" = "1" /* Extirpation of Matter from Right Diaphragm, Percutaneous Endoscopic Approach */
"0BCS0ZZ" = "1" /* Extirpation of Matter from Left Diaphragm, Open Approach */
"0BCS3ZZ" = "1" /* Extirpation of Matter from Left Diaphragm, Percutaneous Approach */
"0BCS4ZZ" = "1" /* Extirpation of Matter from Left Diaphragm, Percutaneous Endoscopic Approach */
"0BDN0ZX" = "1" /* Extraction of Right Pleura, Open Approach, Diagnostic */
"0BDN0ZZ" = "1" /* Extraction of Right Pleura, Open Approach */
"0BDN3ZX" = "1" /* Extraction of Right Pleura, Percutaneous Approach, Diagnostic */
"0BDN3ZZ" = "1" /* Extraction of Right Pleura, Percutaneous Approach */
"0BDN4ZX" = "1" /* Extraction of Right Pleura, Percutaneous Endoscopic Approach, Diagnostic */
"0BDN4ZZ" = "1" /* Extraction of Right Pleura, Percutaneous Endoscopic Approach */
"0BDP0ZX" = "1" /* Extraction of Left Pleura, Open Approach, Diagnostic */
"0BDP0ZZ" = "1" /* Extraction of Left Pleura, Open Approach */
"0BDP3ZX" = "1" /* Extraction of Left Pleura, Percutaneous Approach, Diagnostic */
"0BDP3ZZ" = "1" /* Extraction of Left Pleura, Percutaneous Approach */
"0BDP4ZX" = "1" /* Extraction of Left Pleura, Percutaneous Endoscopic Approach, Diagnostic */
"0BDP4ZZ" = "1" /* Extraction of Left Pleura, Percutaneous Endoscopic Approach */
"0BF10ZZ" = "1" /* Fragmentation in Trachea, Open Approach */
"0BF13ZZ" = "1" /* Fragmentation in Trachea, Percutaneous Approach */
"0BF14ZZ" = "1" /* Fragmentation in Trachea, Percutaneous Endoscopic Approach */
"0BF17ZZ" = "1" /* Fragmentation in Trachea, Via Natural or Artificial Opening */
"0BF18ZZ" = "1" /* Fragmentation in Trachea, Via Natural or Artificial Opening Endoscopic */
"0BF20ZZ" = "1" /* Fragmentation in Carina, Open Approach */
"0BF23ZZ" = "1" /* Fragmentation in Carina, Percutaneous Approach */
"0BF24ZZ" = "1" /* Fragmentation in Carina, Percutaneous Endoscopic Approach */
"0BF27ZZ" = "1" /* Fragmentation in Carina, Via Natural or Artificial Opening */
"0BF28ZZ" = "1" /* Fragmentation in Carina, Via Natural or Artificial Opening Endoscopic */
"0BF30ZZ" = "1" /* Fragmentation in Right Main Bronchus, Open Approach */
"0BF33ZZ" = "1" /* Fragmentation in Right Main Bronchus, Percutaneous Approach */
"0BF34ZZ" = "1" /* Fragmentation in Right Main Bronchus, Percutaneous Endoscopic Approach */
"0BF37ZZ" = "1" /* Fragmentation in Right Main Bronchus, Via Natural or Artificial Opening */
"0BF38ZZ" = "1" /* Fragmentation in Right Main Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BF40ZZ" = "1" /* Fragmentation in Right Upper Lobe Bronchus, Open Approach */
"0BF43ZZ" = "1" /* Fragmentation in Right Upper Lobe Bronchus, Percutaneous Approach */
"0BF44ZZ" = "1" /* Fragmentation in Right Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BF47ZZ" = "1" /* Fragmentation in Right Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BF48ZZ" = "1" /* Fragmentation in Right Upper Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BF50ZZ" = "1" /* Fragmentation in Right Middle Lobe Bronchus, Open Approach */
"0BF53ZZ" = "1" /* Fragmentation in Right Middle Lobe Bronchus, Percutaneous Approach */
"0BF54ZZ" = "1" /* Fragmentation in Right Middle Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BF57ZZ" = "1" /* Fragmentation in Right Middle Lobe Bronchus, Via Natural or Artificial Opening */
"0BF58ZZ" = "1" /* Fragmentation in Right Middle Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BF60ZZ" = "1" /* Fragmentation in Right Lower Lobe Bronchus, Open Approach */
"0BF63ZZ" = "1" /* Fragmentation in Right Lower Lobe Bronchus, Percutaneous Approach */
"0BF64ZZ" = "1" /* Fragmentation in Right Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BF67ZZ" = "1" /* Fragmentation in Right Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BF68ZZ" = "1" /* Fragmentation in Right Lower Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BF70ZZ" = "1" /* Fragmentation in Left Main Bronchus, Open Approach */
"0BF73ZZ" = "1" /* Fragmentation in Left Main Bronchus, Percutaneous Approach */
"0BF74ZZ" = "1" /* Fragmentation in Left Main Bronchus, Percutaneous Endoscopic Approach */
"0BF77ZZ" = "1" /* Fragmentation in Left Main Bronchus, Via Natural or Artificial Opening */
"0BF78ZZ" = "1" /* Fragmentation in Left Main Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BF80ZZ" = "1" /* Fragmentation in Left Upper Lobe Bronchus, Open Approach */
"0BF83ZZ" = "1" /* Fragmentation in Left Upper Lobe Bronchus, Percutaneous Approach */
"0BF84ZZ" = "1" /* Fragmentation in Left Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BF87ZZ" = "1" /* Fragmentation in Left Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BF88ZZ" = "1" /* Fragmentation in Left Upper Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BF90ZZ" = "1" /* Fragmentation in Lingula Bronchus, Open Approach */
"0BF93ZZ" = "1" /* Fragmentation in Lingula Bronchus, Percutaneous Approach */
"0BF94ZZ" = "1" /* Fragmentation in Lingula Bronchus, Percutaneous Endoscopic Approach */
"0BF97ZZ" = "1" /* Fragmentation in Lingula Bronchus, Via Natural or Artificial Opening */
"0BF98ZZ" = "1" /* Fragmentation in Lingula Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BFB0ZZ" = "1" /* Fragmentation in Left Lower Lobe Bronchus, Open Approach */
"0BFB3ZZ" = "1" /* Fragmentation in Left Lower Lobe Bronchus, Percutaneous Approach */
"0BFB4ZZ" = "1" /* Fragmentation in Left Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BFB7ZZ" = "1" /* Fragmentation in Left Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BFB8ZZ" = "1" /* Fragmentation in Left Lower Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BH002Z" = "1" /* Insertion of Monitoring Device into Tracheobronchial Tree, Open Approach */
"0BH003Z" = "1" /* Insertion of Infusion Device into Tracheobronchial Tree, Open Approach */
"0BH00DZ" = "1" /* Insertion of Intraluminal Device into Tracheobronchial Tree, Open Approach */
"0BH032Z" = "1" /* Insertion of Monitoring Device into Tracheobronchial Tree, Percutaneous Approach */
"0BH033Z" = "1" /* Insertion of Infusion Device into Tracheobronchial Tree, Percutaneous Approach */
"0BH03DZ" = "1" /* Insertion of Intraluminal Device into Tracheobronchial Tree, Percutaneous Approach */
"0BH042Z" = "1" /* Insertion of Monitoring Device into Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BH043Z" = "1" /* Insertion of Infusion Device into Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BH04DZ" = "1" /* Insertion of Intraluminal Device into Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BH30GZ" = "1" /* Insertion of Endobronchial Valve into Right Main Bronchus, Open Approach */
"0BH33GZ" = "1" /* Insertion of Endobronchial Valve into Right Main Bronchus, Percutaneous Approach */
"0BH34GZ" = "1" /* Insertion of Endobronchial Valve into Right Main Bronchus, Percutaneous Endoscopic Approach */
"0BH37GZ" = "1" /* Insertion of Endobronchial Valve into Right Main Bronchus, Via Natural or Artificial Opening */
"0BH40GZ" = "1" /* Insertion of Endobronchial Valve into Right Upper Lobe Bronchus, Open Approach */
"0BH43GZ" = "1" /* Insertion of Endobronchial Valve into Right Upper Lobe Bronchus, Percutaneous Approach */
"0BH44GZ" = "1" /* Insertion of Endobronchial Valve into Right Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BH47GZ" = "1" /* Insertion of Endobronchial Valve into Right Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BH50GZ" = "1" /* Insertion of Endobronchial Valve into Right Middle Lobe Bronchus, Open Approach */
"0BH53GZ" = "1" /* Insertion of Endobronchial Valve into Right Middle Lobe Bronchus, Percutaneous Approach */
"0BH54GZ" = "1" /* Insertion of Endobronchial Valve into Right Middle Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BH57GZ" = "1" /* Insertion of Endobronchial Valve into Right Middle Lobe Bronchus, Via Natural or Artificial Opening */
"0BH60GZ" = "1" /* Insertion of Endobronchial Valve into Right Lower Lobe Bronchus, Open Approach */
"0BH63GZ" = "1" /* Insertion of Endobronchial Valve into Right Lower Lobe Bronchus, Percutaneous Approach */
"0BH64GZ" = "1" /* Insertion of Endobronchial Valve into Right Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BH67GZ" = "1" /* Insertion of Endobronchial Valve into Right Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BH70GZ" = "1" /* Insertion of Endobronchial Valve into Left Main Bronchus, Open Approach */
"0BH73GZ" = "1" /* Insertion of Endobronchial Valve into Left Main Bronchus, Percutaneous Approach */
"0BH74GZ" = "1" /* Insertion of Endobronchial Valve into Left Main Bronchus, Percutaneous Endoscopic Approach */
"0BH77GZ" = "1" /* Insertion of Endobronchial Valve into Left Main Bronchus, Via Natural or Artificial Opening */
"0BH80GZ" = "1" /* Insertion of Endobronchial Valve into Left Upper Lobe Bronchus, Open Approach */
"0BH83GZ" = "1" /* Insertion of Endobronchial Valve into Left Upper Lobe Bronchus, Percutaneous Approach */
"0BH84GZ" = "1" /* Insertion of Endobronchial Valve into Left Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BH87GZ" = "1" /* Insertion of Endobronchial Valve into Left Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BH90GZ" = "1" /* Insertion of Endobronchial Valve into Lingula Bronchus, Open Approach */
"0BH93GZ" = "1" /* Insertion of Endobronchial Valve into Lingula Bronchus, Percutaneous Approach */
"0BH94GZ" = "1" /* Insertion of Endobronchial Valve into Lingula Bronchus, Percutaneous Endoscopic Approach */
"0BH97GZ" = "1" /* Insertion of Endobronchial Valve into Lingula Bronchus, Via Natural or Artificial Opening */
"0BHB0GZ" = "1" /* Insertion of Endobronchial Valve into Left Lower Lobe Bronchus, Open Approach */
"0BHB3GZ" = "1" /* Insertion of Endobronchial Valve into Left Lower Lobe Bronchus, Percutaneous Approach */
"0BHB4GZ" = "1" /* Insertion of Endobronchial Valve into Left Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BHB7GZ" = "1" /* Insertion of Endobronchial Valve into Left Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BHK02Z" = "1" /* Insertion of Monitoring Device into Right Lung, Open Approach */
"0BHK03Z" = "1" /* Insertion of Infusion Device into Right Lung, Open Approach */
"0BHK32Z" = "1" /* Insertion of Monitoring Device into Right Lung, Percutaneous Approach */
"0BHK33Z" = "1" /* Insertion of Infusion Device into Right Lung, Percutaneous Approach */
"0BHK42Z" = "1" /* Insertion of Monitoring Device into Right Lung, Percutaneous Endoscopic Approach */
"0BHK43Z" = "1" /* Insertion of Infusion Device into Right Lung, Percutaneous Endoscopic Approach */
"0BHK72Z" = "1" /* Insertion of Monitoring Device into Right Lung, Via Natural or Artificial Opening */
"0BHK73Z" = "1" /* Insertion of Infusion Device into Right Lung, Via Natural or Artificial Opening */
"0BHK82Z" = "1" /* Insertion of Monitoring Device into Right Lung, Via Natural or Artificial Opening Endoscopic */
"0BHK83Z" = "1" /* Insertion of Infusion Device into Right Lung, Via Natural or Artificial Opening Endoscopic */
"0BHL02Z" = "1" /* Insertion of Monitoring Device into Left Lung, Open Approach */
"0BHL03Z" = "1" /* Insertion of Infusion Device into Left Lung, Open Approach */
"0BHL32Z" = "1" /* Insertion of Monitoring Device into Left Lung, Percutaneous Approach */
"0BHL33Z" = "1" /* Insertion of Infusion Device into Left Lung, Percutaneous Approach */
"0BHL42Z" = "1" /* Insertion of Monitoring Device into Left Lung, Percutaneous Endoscopic Approach */
"0BHL43Z" = "1" /* Insertion of Infusion Device into Left Lung, Percutaneous Endoscopic Approach */
"0BHL72Z" = "1" /* Insertion of Monitoring Device into Left Lung, Via Natural or Artificial Opening */
"0BHL73Z" = "1" /* Insertion of Infusion Device into Left Lung, Via Natural or Artificial Opening */
"0BHL82Z" = "1" /* Insertion of Monitoring Device into Left Lung, Via Natural or Artificial Opening Endoscopic */
"0BHL83Z" = "1" /* Insertion of Infusion Device into Left Lung, Via Natural or Artificial Opening Endoscopic */
"0BHR02Z" = "1" /* Insertion of Monitoring Device into Right Diaphragm, Open Approach */
"0BHR0MZ" = "1" /* Insertion of Diaphragmatic Pacemaker Lead into Right Diaphragm, Open Approach */
"0BHR32Z" = "1" /* Insertion of Monitoring Device into Right Diaphragm, Percutaneous Approach */
"0BHR3MZ" = "1" /* Insertion of Diaphragmatic Pacemaker Lead into Right Diaphragm, Percutaneous Approach */
"0BHR42Z" = "1" /* Insertion of Monitoring Device into Right Diaphragm, Percutaneous Endoscopic Approach */
"0BHR4MZ" = "1" /* Insertion of Diaphragmatic Pacemaker Lead into Right Diaphragm, Percutaneous Endoscopic Approach */
"0BHS02Z" = "1" /* Insertion of Monitoring Device into Left Diaphragm, Open Approach */
"0BHS0MZ" = "1" /* Insertion of Diaphragmatic Pacemaker Lead into Left Diaphragm, Open Approach */
"0BHS32Z" = "1" /* Insertion of Monitoring Device into Left Diaphragm, Percutaneous Approach */
"0BHS3MZ" = "1" /* Insertion of Diaphragmatic Pacemaker Lead into Left Diaphragm, Percutaneous Approach */
"0BHS42Z" = "1" /* Insertion of Monitoring Device into Left Diaphragm, Percutaneous Endoscopic Approach */
"0BHS4MZ" = "1" /* Insertion of Diaphragmatic Pacemaker Lead into Left Diaphragm, Percutaneous Endoscopic Approach */
"0BJ00ZZ" = "1" /* Inspection of Tracheobronchial Tree, Open Approach */
"0BJ03ZZ" = "1" /* Inspection of Tracheobronchial Tree, Percutaneous Approach */
"0BJ04ZZ" = "1" /* Inspection of Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BJ07ZZ" = "1" /* Inspection of Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BJ0XZZ" = "1" /* Inspection of Tracheobronchial Tree, External Approach */
"0BJ10ZZ" = "1" /* Inspection of Trachea, Open Approach */
"0BJK0ZZ" = "1" /* Inspection of Right Lung, Open Approach */
"0BJK3ZZ" = "1" /* Inspection of Right Lung, Percutaneous Approach */
"0BJK4ZZ" = "1" /* Inspection of Right Lung, Percutaneous Endoscopic Approach */
"0BJK7ZZ" = "1" /* Inspection of Right Lung, Via Natural or Artificial Opening */
"0BJKXZZ" = "1" /* Inspection of Right Lung, External Approach */
"0BJL0ZZ" = "1" /* Inspection of Left Lung, Open Approach */
"0BJL3ZZ" = "1" /* Inspection of Left Lung, Percutaneous Approach */
"0BJL4ZZ" = "1" /* Inspection of Left Lung, Percutaneous Endoscopic Approach */
"0BJL7ZZ" = "1" /* Inspection of Left Lung, Via Natural or Artificial Opening */
"0BJLXZZ" = "1" /* Inspection of Left Lung, External Approach */
"0BJQ0ZZ" = "1" /* Inspection of Pleura, Open Approach */
"0BJQ3ZZ" = "1" /* Inspection of Pleura, Percutaneous Approach */
"0BJQ4ZZ" = "1" /* Inspection of Pleura, Percutaneous Endoscopic Approach */
"0BJQ7ZZ" = "1" /* Inspection of Pleura, Via Natural or Artificial Opening */
"0BJQ8ZZ" = "1" /* Inspection of Pleura, Via Natural or Artificial Opening Endoscopic */
"0BJQXZZ" = "1" /* Inspection of Pleura, External Approach */
"0BJT0ZZ" = "1" /* Inspection of Diaphragm, Open Approach */
"0BJT3ZZ" = "1" /* Inspection of Diaphragm, Percutaneous Approach */
"0BJT4ZZ" = "1" /* Inspection of Diaphragm, Percutaneous Endoscopic Approach */
"0BJT7ZZ" = "1" /* Inspection of Diaphragm, Via Natural or Artificial Opening */
"0BJT8ZZ" = "1" /* Inspection of Diaphragm, Via Natural or Artificial Opening Endoscopic */
"0BJTXZZ" = "1" /* Inspection of Diaphragm, External Approach */
"0BL10CZ" = "1" /* Occlusion of Trachea with Extraluminal Device, Open Approach */
"0BL10DZ" = "1" /* Occlusion of Trachea with Intraluminal Device, Open Approach */
"0BL10ZZ" = "1" /* Occlusion of Trachea, Open Approach */
"0BL13CZ" = "1" /* Occlusion of Trachea with Extraluminal Device, Percutaneous Approach */
"0BL13DZ" = "1" /* Occlusion of Trachea with Intraluminal Device, Percutaneous Approach */
"0BL13ZZ" = "1" /* Occlusion of Trachea, Percutaneous Approach */
"0BL14CZ" = "1" /* Occlusion of Trachea with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BL14DZ" = "1" /* Occlusion of Trachea with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BL14ZZ" = "1" /* Occlusion of Trachea, Percutaneous Endoscopic Approach */
"0BL17DZ" = "1" /* Occlusion of Trachea with Intraluminal Device, Via Natural or Artificial Opening */
"0BL17ZZ" = "1" /* Occlusion of Trachea, Via Natural or Artificial Opening */
"0BL18DZ" = "1" /* Occlusion of Trachea with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BL18ZZ" = "1" /* Occlusion of Trachea, Via Natural or Artificial Opening Endoscopic */
"0BL20CZ" = "1" /* Occlusion of Carina with Extraluminal Device, Open Approach */
"0BL20DZ" = "1" /* Occlusion of Carina with Intraluminal Device, Open Approach */
"0BL20ZZ" = "1" /* Occlusion of Carina, Open Approach */
"0BL23CZ" = "1" /* Occlusion of Carina with Extraluminal Device, Percutaneous Approach */
"0BL23DZ" = "1" /* Occlusion of Carina with Intraluminal Device, Percutaneous Approach */
"0BL23ZZ" = "1" /* Occlusion of Carina, Percutaneous Approach */
"0BL24CZ" = "1" /* Occlusion of Carina with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BL24DZ" = "1" /* Occlusion of Carina with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BL24ZZ" = "1" /* Occlusion of Carina, Percutaneous Endoscopic Approach */
"0BL27DZ" = "1" /* Occlusion of Carina with Intraluminal Device, Via Natural or Artificial Opening */
"0BL27ZZ" = "1" /* Occlusion of Carina, Via Natural or Artificial Opening */
"0BL28DZ" = "1" /* Occlusion of Carina with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BL28ZZ" = "1" /* Occlusion of Carina, Via Natural or Artificial Opening Endoscopic */
"0BL30CZ" = "1" /* Occlusion of Right Main Bronchus with Extraluminal Device, Open Approach */
"0BL30DZ" = "1" /* Occlusion of Right Main Bronchus with Intraluminal Device, Open Approach */
"0BL30ZZ" = "1" /* Occlusion of Right Main Bronchus, Open Approach */
"0BL33CZ" = "1" /* Occlusion of Right Main Bronchus with Extraluminal Device, Percutaneous Approach */
"0BL33DZ" = "1" /* Occlusion of Right Main Bronchus with Intraluminal Device, Percutaneous Approach */
"0BL33ZZ" = "1" /* Occlusion of Right Main Bronchus, Percutaneous Approach */
"0BL34CZ" = "1" /* Occlusion of Right Main Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BL34DZ" = "1" /* Occlusion of Right Main Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BL34ZZ" = "1" /* Occlusion of Right Main Bronchus, Percutaneous Endoscopic Approach */
"0BL37DZ" = "1" /* Occlusion of Right Main Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BL37ZZ" = "1" /* Occlusion of Right Main Bronchus, Via Natural or Artificial Opening */
"0BL38DZ" = "1" /* Occlusion of Right Main Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BL38ZZ" = "1" /* Occlusion of Right Main Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BL40CZ" = "1" /* Occlusion of Right Upper Lobe Bronchus with Extraluminal Device, Open Approach */
"0BL40DZ" = "1" /* Occlusion of Right Upper Lobe Bronchus with Intraluminal Device, Open Approach */
"0BL40ZZ" = "1" /* Occlusion of Right Upper Lobe Bronchus, Open Approach */
"0BL43CZ" = "1" /* Occlusion of Right Upper Lobe Bronchus with Extraluminal Device, Percutaneous Approach */
"0BL43DZ" = "1" /* Occlusion of Right Upper Lobe Bronchus with Intraluminal Device, Percutaneous Approach */
"0BL43ZZ" = "1" /* Occlusion of Right Upper Lobe Bronchus, Percutaneous Approach */
"0BL44CZ" = "1" /* Occlusion of Right Upper Lobe Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BL44DZ" = "1" /* Occlusion of Right Upper Lobe Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BL44ZZ" = "1" /* Occlusion of Right Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BL47DZ" = "1" /* Occlusion of Right Upper Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BL47ZZ" = "1" /* Occlusion of Right Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BL48DZ" = "1" /* Occlusion of Right Upper Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BL48ZZ" = "1" /* Occlusion of Right Upper Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BL50CZ" = "1" /* Occlusion of Right Middle Lobe Bronchus with Extraluminal Device, Open Approach */
"0BL50DZ" = "1" /* Occlusion of Right Middle Lobe Bronchus with Intraluminal Device, Open Approach */
"0BL50ZZ" = "1" /* Occlusion of Right Middle Lobe Bronchus, Open Approach */
"0BL53CZ" = "1" /* Occlusion of Right Middle Lobe Bronchus with Extraluminal Device, Percutaneous Approach */
"0BL53DZ" = "1" /* Occlusion of Right Middle Lobe Bronchus with Intraluminal Device, Percutaneous Approach */
"0BL53ZZ" = "1" /* Occlusion of Right Middle Lobe Bronchus, Percutaneous Approach */
"0BL54CZ" = "1" /* Occlusion of Right Middle Lobe Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BL54DZ" = "1" /* Occlusion of Right Middle Lobe Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BL54ZZ" = "1" /* Occlusion of Right Middle Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BL57DZ" = "1" /* Occlusion of Right Middle Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BL57ZZ" = "1" /* Occlusion of Right Middle Lobe Bronchus, Via Natural or Artificial Opening */
"0BL58DZ" = "1" /* Occlusion of Right Middle Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BL58ZZ" = "1" /* Occlusion of Right Middle Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BL60CZ" = "1" /* Occlusion of Right Lower Lobe Bronchus with Extraluminal Device, Open Approach */
"0BL60DZ" = "1" /* Occlusion of Right Lower Lobe Bronchus with Intraluminal Device, Open Approach */
"0BL60ZZ" = "1" /* Occlusion of Right Lower Lobe Bronchus, Open Approach */
"0BL63CZ" = "1" /* Occlusion of Right Lower Lobe Bronchus with Extraluminal Device, Percutaneous Approach */
"0BL63DZ" = "1" /* Occlusion of Right Lower Lobe Bronchus with Intraluminal Device, Percutaneous Approach */
"0BL63ZZ" = "1" /* Occlusion of Right Lower Lobe Bronchus, Percutaneous Approach */
"0BL64CZ" = "1" /* Occlusion of Right Lower Lobe Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BL64DZ" = "1" /* Occlusion of Right Lower Lobe Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BL64ZZ" = "1" /* Occlusion of Right Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BL67DZ" = "1" /* Occlusion of Right Lower Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BL67ZZ" = "1" /* Occlusion of Right Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BL68DZ" = "1" /* Occlusion of Right Lower Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BL68ZZ" = "1" /* Occlusion of Right Lower Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BL70CZ" = "1" /* Occlusion of Left Main Bronchus with Extraluminal Device, Open Approach */
"0BL70DZ" = "1" /* Occlusion of Left Main Bronchus with Intraluminal Device, Open Approach */
"0BL70ZZ" = "1" /* Occlusion of Left Main Bronchus, Open Approach */
"0BL73CZ" = "1" /* Occlusion of Left Main Bronchus with Extraluminal Device, Percutaneous Approach */
"0BL73DZ" = "1" /* Occlusion of Left Main Bronchus with Intraluminal Device, Percutaneous Approach */
"0BL73ZZ" = "1" /* Occlusion of Left Main Bronchus, Percutaneous Approach */
"0BL74CZ" = "1" /* Occlusion of Left Main Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BL74DZ" = "1" /* Occlusion of Left Main Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BL74ZZ" = "1" /* Occlusion of Left Main Bronchus, Percutaneous Endoscopic Approach */
"0BL77DZ" = "1" /* Occlusion of Left Main Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BL77ZZ" = "1" /* Occlusion of Left Main Bronchus, Via Natural or Artificial Opening */
"0BL78DZ" = "1" /* Occlusion of Left Main Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BL78ZZ" = "1" /* Occlusion of Left Main Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BL80CZ" = "1" /* Occlusion of Left Upper Lobe Bronchus with Extraluminal Device, Open Approach */
"0BL80DZ" = "1" /* Occlusion of Left Upper Lobe Bronchus with Intraluminal Device, Open Approach */
"0BL80ZZ" = "1" /* Occlusion of Left Upper Lobe Bronchus, Open Approach */
"0BL83CZ" = "1" /* Occlusion of Left Upper Lobe Bronchus with Extraluminal Device, Percutaneous Approach */
"0BL83DZ" = "1" /* Occlusion of Left Upper Lobe Bronchus with Intraluminal Device, Percutaneous Approach */
"0BL83ZZ" = "1" /* Occlusion of Left Upper Lobe Bronchus, Percutaneous Approach */
"0BL84CZ" = "1" /* Occlusion of Left Upper Lobe Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BL84DZ" = "1" /* Occlusion of Left Upper Lobe Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BL84ZZ" = "1" /* Occlusion of Left Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BL87DZ" = "1" /* Occlusion of Left Upper Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BL87ZZ" = "1" /* Occlusion of Left Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BL88DZ" = "1" /* Occlusion of Left Upper Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BL88ZZ" = "1" /* Occlusion of Left Upper Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BL90CZ" = "1" /* Occlusion of Lingula Bronchus with Extraluminal Device, Open Approach */
"0BL90DZ" = "1" /* Occlusion of Lingula Bronchus with Intraluminal Device, Open Approach */
"0BL90ZZ" = "1" /* Occlusion of Lingula Bronchus, Open Approach */
"0BL93CZ" = "1" /* Occlusion of Lingula Bronchus with Extraluminal Device, Percutaneous Approach */
"0BL93DZ" = "1" /* Occlusion of Lingula Bronchus with Intraluminal Device, Percutaneous Approach */
"0BL93ZZ" = "1" /* Occlusion of Lingula Bronchus, Percutaneous Approach */
"0BL94CZ" = "1" /* Occlusion of Lingula Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BL94DZ" = "1" /* Occlusion of Lingula Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BL94ZZ" = "1" /* Occlusion of Lingula Bronchus, Percutaneous Endoscopic Approach */
"0BL97DZ" = "1" /* Occlusion of Lingula Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BL97ZZ" = "1" /* Occlusion of Lingula Bronchus, Via Natural or Artificial Opening */
"0BL98DZ" = "1" /* Occlusion of Lingula Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BL98ZZ" = "1" /* Occlusion of Lingula Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BLB0CZ" = "1" /* Occlusion of Left Lower Lobe Bronchus with Extraluminal Device, Open Approach */
"0BLB0DZ" = "1" /* Occlusion of Left Lower Lobe Bronchus with Intraluminal Device, Open Approach */
"0BLB0ZZ" = "1" /* Occlusion of Left Lower Lobe Bronchus, Open Approach */
"0BLB3CZ" = "1" /* Occlusion of Left Lower Lobe Bronchus with Extraluminal Device, Percutaneous Approach */
"0BLB3DZ" = "1" /* Occlusion of Left Lower Lobe Bronchus with Intraluminal Device, Percutaneous Approach */
"0BLB3ZZ" = "1" /* Occlusion of Left Lower Lobe Bronchus, Percutaneous Approach */
"0BLB4CZ" = "1" /* Occlusion of Left Lower Lobe Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BLB4DZ" = "1" /* Occlusion of Left Lower Lobe Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BLB4ZZ" = "1" /* Occlusion of Left Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BLB7DZ" = "1" /* Occlusion of Left Lower Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BLB7ZZ" = "1" /* Occlusion of Left Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BLB8DZ" = "1" /* Occlusion of Left Lower Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BLB8ZZ" = "1" /* Occlusion of Left Lower Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BM10ZZ" = "1" /* Reattachment of Trachea, Open Approach */
"0BM20ZZ" = "1" /* Reattachment of Carina, Open Approach */
"0BM30ZZ" = "1" /* Reattachment of Right Main Bronchus, Open Approach */
"0BM40ZZ" = "1" /* Reattachment of Right Upper Lobe Bronchus, Open Approach */
"0BM50ZZ" = "1" /* Reattachment of Right Middle Lobe Bronchus, Open Approach */
"0BM60ZZ" = "1" /* Reattachment of Right Lower Lobe Bronchus, Open Approach */
"0BM70ZZ" = "1" /* Reattachment of Left Main Bronchus, Open Approach */
"0BM80ZZ" = "1" /* Reattachment of Left Upper Lobe Bronchus, Open Approach */
"0BM90ZZ" = "1" /* Reattachment of Lingula Bronchus, Open Approach */
"0BMB0ZZ" = "1" /* Reattachment of Left Lower Lobe Bronchus, Open Approach */
"0BMC0ZZ" = "1" /* Reattachment of Right Upper Lung Lobe, Open Approach */
"0BMD0ZZ" = "1" /* Reattachment of Right Middle Lung Lobe, Open Approach */
"0BMF0ZZ" = "1" /* Reattachment of Right Lower Lung Lobe, Open Approach */
"0BMG0ZZ" = "1" /* Reattachment of Left Upper Lung Lobe, Open Approach */
"0BMH0ZZ" = "1" /* Reattachment of Lung Lingula, Open Approach */
"0BMJ0ZZ" = "1" /* Reattachment of Left Lower Lung Lobe, Open Approach */
"0BMK0ZZ" = "1" /* Reattachment of Right Lung, Open Approach */
"0BML0ZZ" = "1" /* Reattachment of Left Lung, Open Approach */
"0BMR0ZZ" = "1" /* Reattachment of Right Diaphragm, Open Approach */
"0BMS0ZZ" = "1" /* Reattachment of Left Diaphragm, Open Approach */
"0BN30ZZ" = "1" /* Release Right Main Bronchus, Open Approach */
"0BN33ZZ" = "1" /* Release Right Main Bronchus, Percutaneous Approach */
"0BN34ZZ" = "1" /* Release Right Main Bronchus, Percutaneous Endoscopic Approach */
"0BN37ZZ" = "1" /* Release Right Main Bronchus, Via Natural or Artificial Opening */
"0BN38ZZ" = "1" /* Release Right Main Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BN40ZZ" = "1" /* Release Right Upper Lobe Bronchus, Open Approach */
"0BN43ZZ" = "1" /* Release Right Upper Lobe Bronchus, Percutaneous Approach */
"0BN44ZZ" = "1" /* Release Right Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BN47ZZ" = "1" /* Release Right Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BN48ZZ" = "1" /* Release Right Upper Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BN50ZZ" = "1" /* Release Right Middle Lobe Bronchus, Open Approach */
"0BN53ZZ" = "1" /* Release Right Middle Lobe Bronchus, Percutaneous Approach */
"0BN54ZZ" = "1" /* Release Right Middle Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BN57ZZ" = "1" /* Release Right Middle Lobe Bronchus, Via Natural or Artificial Opening */
"0BN58ZZ" = "1" /* Release Right Middle Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BN60ZZ" = "1" /* Release Right Lower Lobe Bronchus, Open Approach */
"0BN63ZZ" = "1" /* Release Right Lower Lobe Bronchus, Percutaneous Approach */
"0BN64ZZ" = "1" /* Release Right Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BN67ZZ" = "1" /* Release Right Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BN68ZZ" = "1" /* Release Right Lower Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BN70ZZ" = "1" /* Release Left Main Bronchus, Open Approach */
"0BN73ZZ" = "1" /* Release Left Main Bronchus, Percutaneous Approach */
"0BN74ZZ" = "1" /* Release Left Main Bronchus, Percutaneous Endoscopic Approach */
"0BN77ZZ" = "1" /* Release Left Main Bronchus, Via Natural or Artificial Opening */
"0BN78ZZ" = "1" /* Release Left Main Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BN80ZZ" = "1" /* Release Left Upper Lobe Bronchus, Open Approach */
"0BN83ZZ" = "1" /* Release Left Upper Lobe Bronchus, Percutaneous Approach */
"0BN84ZZ" = "1" /* Release Left Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BN87ZZ" = "1" /* Release Left Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BN88ZZ" = "1" /* Release Left Upper Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BN90ZZ" = "1" /* Release Lingula Bronchus, Open Approach */
"0BN93ZZ" = "1" /* Release Lingula Bronchus, Percutaneous Approach */
"0BN94ZZ" = "1" /* Release Lingula Bronchus, Percutaneous Endoscopic Approach */
"0BN97ZZ" = "1" /* Release Lingula Bronchus, Via Natural or Artificial Opening */
"0BN98ZZ" = "1" /* Release Lingula Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BNB0ZZ" = "1" /* Release Left Lower Lobe Bronchus, Open Approach */
"0BNB3ZZ" = "1" /* Release Left Lower Lobe Bronchus, Percutaneous Approach */
"0BNB4ZZ" = "1" /* Release Left Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BNB7ZZ" = "1" /* Release Left Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BNB8ZZ" = "1" /* Release Left Lower Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BNC0ZZ" = "1" /* Release Right Upper Lung Lobe, Open Approach */
"0BNC3ZZ" = "1" /* Release Right Upper Lung Lobe, Percutaneous Approach */
"0BNC4ZZ" = "1" /* Release Right Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BNC7ZZ" = "1" /* Release Right Upper Lung Lobe, Via Natural or Artificial Opening */
"0BNC8ZZ" = "1" /* Release Right Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BND0ZZ" = "1" /* Release Right Middle Lung Lobe, Open Approach */
"0BND3ZZ" = "1" /* Release Right Middle Lung Lobe, Percutaneous Approach */
"0BND4ZZ" = "1" /* Release Right Middle Lung Lobe, Percutaneous Endoscopic Approach */
"0BND7ZZ" = "1" /* Release Right Middle Lung Lobe, Via Natural or Artificial Opening */
"0BND8ZZ" = "1" /* Release Right Middle Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BNF0ZZ" = "1" /* Release Right Lower Lung Lobe, Open Approach */
"0BNF3ZZ" = "1" /* Release Right Lower Lung Lobe, Percutaneous Approach */
"0BNF4ZZ" = "1" /* Release Right Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BNF7ZZ" = "1" /* Release Right Lower Lung Lobe, Via Natural or Artificial Opening */
"0BNF8ZZ" = "1" /* Release Right Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BNG0ZZ" = "1" /* Release Left Upper Lung Lobe, Open Approach */
"0BNG3ZZ" = "1" /* Release Left Upper Lung Lobe, Percutaneous Approach */
"0BNG4ZZ" = "1" /* Release Left Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BNG7ZZ" = "1" /* Release Left Upper Lung Lobe, Via Natural or Artificial Opening */
"0BNG8ZZ" = "1" /* Release Left Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BNH0ZZ" = "1" /* Release Lung Lingula, Open Approach */
"0BNH3ZZ" = "1" /* Release Lung Lingula, Percutaneous Approach */
"0BNH4ZZ" = "1" /* Release Lung Lingula, Percutaneous Endoscopic Approach */
"0BNH7ZZ" = "1" /* Release Lung Lingula, Via Natural or Artificial Opening */
"0BNH8ZZ" = "1" /* Release Lung Lingula, Via Natural or Artificial Opening Endoscopic */
"0BNJ0ZZ" = "1" /* Release Left Lower Lung Lobe, Open Approach */
"0BNJ3ZZ" = "1" /* Release Left Lower Lung Lobe, Percutaneous Approach */
"0BNJ4ZZ" = "1" /* Release Left Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BNJ7ZZ" = "1" /* Release Left Lower Lung Lobe, Via Natural or Artificial Opening */
"0BNJ8ZZ" = "1" /* Release Left Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BNK0ZZ" = "1" /* Release Right Lung, Open Approach */
"0BNK3ZZ" = "1" /* Release Right Lung, Percutaneous Approach */
"0BNK4ZZ" = "1" /* Release Right Lung, Percutaneous Endoscopic Approach */
"0BNK7ZZ" = "1" /* Release Right Lung, Via Natural or Artificial Opening */
"0BNK8ZZ" = "1" /* Release Right Lung, Via Natural or Artificial Opening Endoscopic */
"0BNL0ZZ" = "1" /* Release Left Lung, Open Approach */
"0BNL3ZZ" = "1" /* Release Left Lung, Percutaneous Approach */
"0BNL4ZZ" = "1" /* Release Left Lung, Percutaneous Endoscopic Approach */
"0BNL7ZZ" = "1" /* Release Left Lung, Via Natural or Artificial Opening */
"0BNL8ZZ" = "1" /* Release Left Lung, Via Natural or Artificial Opening Endoscopic */
"0BNM0ZZ" = "1" /* Release Bilateral Lungs, Open Approach */
"0BNM3ZZ" = "1" /* Release Bilateral Lungs, Percutaneous Approach */
"0BNM4ZZ" = "1" /* Release Bilateral Lungs, Percutaneous Endoscopic Approach */
"0BNM7ZZ" = "1" /* Release Bilateral Lungs, Via Natural or Artificial Opening */
"0BNM8ZZ" = "1" /* Release Bilateral Lungs, Via Natural or Artificial Opening Endoscopic */
"0BNN0ZZ" = "1" /* Release Right Pleura, Open Approach */
"0BNN3ZZ" = "1" /* Release Right Pleura, Percutaneous Approach */
"0BNN4ZZ" = "1" /* Release Right Pleura, Percutaneous Endoscopic Approach */
"0BNP0ZZ" = "1" /* Release Left Pleura, Open Approach */
"0BNP3ZZ" = "1" /* Release Left Pleura, Percutaneous Approach */
"0BNP4ZZ" = "1" /* Release Left Pleura, Percutaneous Endoscopic Approach */
"0BNR0ZZ" = "1" /* Release Right Diaphragm, Open Approach */
"0BNR3ZZ" = "1" /* Release Right Diaphragm, Percutaneous Approach */
"0BNR4ZZ" = "1" /* Release Right Diaphragm, Percutaneous Endoscopic Approach */
"0BNS0ZZ" = "1" /* Release Left Diaphragm, Open Approach */
"0BNS3ZZ" = "1" /* Release Left Diaphragm, Percutaneous Approach */
"0BNS4ZZ" = "1" /* Release Left Diaphragm, Percutaneous Endoscopic Approach */
"0BP000Z" = "1" /* Removal of Drainage Device from Tracheobronchial Tree, Open Approach */
"0BP001Z" = "1" /* Removal of Radioactive Element from Tracheobronchial Tree, Open Approach */
"0BP002Z" = "1" /* Removal of Monitoring Device from Tracheobronchial Tree, Open Approach */
"0BP00CZ" = "1" /* Removal of Extraluminal Device from Tracheobronchial Tree, Open Approach */
"0BP00DZ" = "1" /* Removal of Intraluminal Device from Tracheobronchial Tree, Open Approach */
"0BP00JZ" = "1" /* Removal of Synthetic Substitute from Tracheobronchial Tree, Open Approach */
"0BP00KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Tracheobronchial Tree, Open Approach */
"0BP030Z" = "1" /* Removal of Drainage Device from Tracheobronchial Tree, Percutaneous Approach */
"0BP031Z" = "1" /* Removal of Radioactive Element from Tracheobronchial Tree, Percutaneous Approach */
"0BP032Z" = "1" /* Removal of Monitoring Device from Tracheobronchial Tree, Percutaneous Approach */
"0BP03CZ" = "1" /* Removal of Extraluminal Device from Tracheobronchial Tree, Percutaneous Approach */
"0BP03DZ" = "1" /* Removal of Intraluminal Device from Tracheobronchial Tree, Percutaneous Approach */
"0BP03JZ" = "1" /* Removal of Synthetic Substitute from Tracheobronchial Tree, Percutaneous Approach */
"0BP03KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Tracheobronchial Tree, Percutaneous Approach */
"0BP040Z" = "1" /* Removal of Drainage Device from Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BP041Z" = "1" /* Removal of Radioactive Element from Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BP042Z" = "1" /* Removal of Monitoring Device from Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BP04CZ" = "1" /* Removal of Extraluminal Device from Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BP04DZ" = "1" /* Removal of Intraluminal Device from Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BP04JZ" = "1" /* Removal of Synthetic Substitute from Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BP04KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BP070Z" = "1" /* Removal of Drainage Device from Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BP071Z" = "1" /* Removal of Radioactive Element from Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BP072Z" = "1" /* Removal of Monitoring Device from Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BP07DZ" = "1" /* Removal of Intraluminal Device from Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BP080Z" = "1" /* Removal of Drainage Device from Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BP081Z" = "1" /* Removal of Radioactive Element from Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BP082Z" = "1" /* Removal of Monitoring Device from Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BP08DZ" = "1" /* Removal of Intraluminal Device from Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BPK00Z" = "1" /* Removal of Drainage Device from Right Lung, Open Approach */
"0BPK01Z" = "1" /* Removal of Radioactive Element from Right Lung, Open Approach */
"0BPK02Z" = "1" /* Removal of Monitoring Device from Right Lung, Open Approach */
"0BPK03Z" = "1" /* Removal of Infusion Device from Right Lung, Open Approach */
"0BPK30Z" = "1" /* Removal of Drainage Device from Right Lung, Percutaneous Approach */
"0BPK31Z" = "1" /* Removal of Radioactive Element from Right Lung, Percutaneous Approach */
"0BPK32Z" = "1" /* Removal of Monitoring Device from Right Lung, Percutaneous Approach */
"0BPK33Z" = "1" /* Removal of Infusion Device from Right Lung, Percutaneous Approach */
"0BPK40Z" = "1" /* Removal of Drainage Device from Right Lung, Percutaneous Endoscopic Approach */
"0BPK41Z" = "1" /* Removal of Radioactive Element from Right Lung, Percutaneous Endoscopic Approach */
"0BPK42Z" = "1" /* Removal of Monitoring Device from Right Lung, Percutaneous Endoscopic Approach */
"0BPK43Z" = "1" /* Removal of Infusion Device from Right Lung, Percutaneous Endoscopic Approach */
"0BPK70Z" = "1" /* Removal of Drainage Device from Right Lung, Via Natural or Artificial Opening */
"0BPK71Z" = "1" /* Removal of Radioactive Element from Right Lung, Via Natural or Artificial Opening */
"0BPK72Z" = "1" /* Removal of Monitoring Device from Right Lung, Via Natural or Artificial Opening */
"0BPK73Z" = "1" /* Removal of Infusion Device from Right Lung, Via Natural or Artificial Opening */
"0BPK80Z" = "1" /* Removal of Drainage Device from Right Lung, Via Natural or Artificial Opening Endoscopic */
"0BPK81Z" = "1" /* Removal of Radioactive Element from Right Lung, Via Natural or Artificial Opening Endoscopic */
"0BPK82Z" = "1" /* Removal of Monitoring Device from Right Lung, Via Natural or Artificial Opening Endoscopic */
"0BPK83Z" = "1" /* Removal of Infusion Device from Right Lung, Via Natural or Artificial Opening Endoscopic */
"0BPL00Z" = "1" /* Removal of Drainage Device from Left Lung, Open Approach */
"0BPL01Z" = "1" /* Removal of Radioactive Element from Left Lung, Open Approach */
"0BPL02Z" = "1" /* Removal of Monitoring Device from Left Lung, Open Approach */
"0BPL03Z" = "1" /* Removal of Infusion Device from Left Lung, Open Approach */
"0BPL30Z" = "1" /* Removal of Drainage Device from Left Lung, Percutaneous Approach */
"0BPL31Z" = "1" /* Removal of Radioactive Element from Left Lung, Percutaneous Approach */
"0BPL32Z" = "1" /* Removal of Monitoring Device from Left Lung, Percutaneous Approach */
"0BPL33Z" = "1" /* Removal of Infusion Device from Left Lung, Percutaneous Approach */
"0BPL40Z" = "1" /* Removal of Drainage Device from Left Lung, Percutaneous Endoscopic Approach */
"0BPL41Z" = "1" /* Removal of Radioactive Element from Left Lung, Percutaneous Endoscopic Approach */
"0BPL42Z" = "1" /* Removal of Monitoring Device from Left Lung, Percutaneous Endoscopic Approach */
"0BPL43Z" = "1" /* Removal of Infusion Device from Left Lung, Percutaneous Endoscopic Approach */
"0BPL70Z" = "1" /* Removal of Drainage Device from Left Lung, Via Natural or Artificial Opening */
"0BPL71Z" = "1" /* Removal of Radioactive Element from Left Lung, Via Natural or Artificial Opening */
"0BPL72Z" = "1" /* Removal of Monitoring Device from Left Lung, Via Natural or Artificial Opening */
"0BPL73Z" = "1" /* Removal of Infusion Device from Left Lung, Via Natural or Artificial Opening */
"0BPL80Z" = "1" /* Removal of Drainage Device from Left Lung, Via Natural or Artificial Opening Endoscopic */
"0BPL81Z" = "1" /* Removal of Radioactive Element from Left Lung, Via Natural or Artificial Opening Endoscopic */
"0BPL82Z" = "1" /* Removal of Monitoring Device from Left Lung, Via Natural or Artificial Opening Endoscopic */
"0BPL83Z" = "1" /* Removal of Infusion Device from Left Lung, Via Natural or Artificial Opening Endoscopic */
"0BPQ00Z" = "1" /* Removal of Drainage Device from Pleura, Open Approach */
"0BPQ01Z" = "1" /* Removal of Radioactive Element from Pleura, Open Approach */
"0BPQ02Z" = "1" /* Removal of Monitoring Device from Pleura, Open Approach */
"0BPQ30Z" = "1" /* Removal of Drainage Device from Pleura, Percutaneous Approach */
"0BPQ31Z" = "1" /* Removal of Radioactive Element from Pleura, Percutaneous Approach */
"0BPQ32Z" = "1" /* Removal of Monitoring Device from Pleura, Percutaneous Approach */
"0BPQ40Z" = "1" /* Removal of Drainage Device from Pleura, Percutaneous Endoscopic Approach */
"0BPQ41Z" = "1" /* Removal of Radioactive Element from Pleura, Percutaneous Endoscopic Approach */
"0BPQ42Z" = "1" /* Removal of Monitoring Device from Pleura, Percutaneous Endoscopic Approach */
"0BPQ70Z" = "1" /* Removal of Drainage Device from Pleura, Via Natural or Artificial Opening */
"0BPQ71Z" = "1" /* Removal of Radioactive Element from Pleura, Via Natural or Artificial Opening */
"0BPQ72Z" = "1" /* Removal of Monitoring Device from Pleura, Via Natural or Artificial Opening */
"0BPQ80Z" = "1" /* Removal of Drainage Device from Pleura, Via Natural or Artificial Opening Endoscopic */
"0BPQ81Z" = "1" /* Removal of Radioactive Element from Pleura, Via Natural or Artificial Opening Endoscopic */
"0BPQ82Z" = "1" /* Removal of Monitoring Device from Pleura, Via Natural or Artificial Opening Endoscopic */
"0BPT00Z" = "1" /* Removal of Drainage Device from Diaphragm, Open Approach */
"0BPT02Z" = "1" /* Removal of Monitoring Device from Diaphragm, Open Approach */
"0BPT07Z" = "1" /* Removal of Autologous Tissue Substitute from Diaphragm, Open Approach */
"0BPT0JZ" = "1" /* Removal of Synthetic Substitute from Diaphragm, Open Approach */
"0BPT0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Diaphragm, Open Approach */
"0BPT0MZ" = "1" /* Removal of Diaphragmatic Pacemaker Lead from Diaphragm, Open Approach */
"0BPT30Z" = "1" /* Removal of Drainage Device from Diaphragm, Percutaneous Approach */
"0BPT32Z" = "1" /* Removal of Monitoring Device from Diaphragm, Percutaneous Approach */
"0BPT37Z" = "1" /* Removal of Autologous Tissue Substitute from Diaphragm, Percutaneous Approach */
"0BPT3JZ" = "1" /* Removal of Synthetic Substitute from Diaphragm, Percutaneous Approach */
"0BPT3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Diaphragm, Percutaneous Approach */
"0BPT3MZ" = "1" /* Removal of Diaphragmatic Pacemaker Lead from Diaphragm, Percutaneous Approach */
"0BPT40Z" = "1" /* Removal of Drainage Device from Diaphragm, Percutaneous Endoscopic Approach */
"0BPT42Z" = "1" /* Removal of Monitoring Device from Diaphragm, Percutaneous Endoscopic Approach */
"0BPT47Z" = "1" /* Removal of Autologous Tissue Substitute from Diaphragm, Percutaneous Endoscopic Approach */
"0BPT4JZ" = "1" /* Removal of Synthetic Substitute from Diaphragm, Percutaneous Endoscopic Approach */
"0BPT4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Diaphragm, Percutaneous Endoscopic Approach */
"0BPT4MZ" = "1" /* Removal of Diaphragmatic Pacemaker Lead from Diaphragm, Percutaneous Endoscopic Approach */
"0BPT70Z" = "1" /* Removal of Drainage Device from Diaphragm, Via Natural or Artificial Opening */
"0BPT72Z" = "1" /* Removal of Monitoring Device from Diaphragm, Via Natural or Artificial Opening */
"0BPT77Z" = "1" /* Removal of Autologous Tissue Substitute from Diaphragm, Via Natural or Artificial Opening */
"0BPT7JZ" = "1" /* Removal of Synthetic Substitute from Diaphragm, Via Natural or Artificial Opening */
"0BPT7KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Diaphragm, Via Natural or Artificial Opening */
"0BPT7MZ" = "1" /* Removal of Diaphragmatic Pacemaker Lead from Diaphragm, Via Natural or Artificial Opening */
"0BPT80Z" = "1" /* Removal of Drainage Device from Diaphragm, Via Natural or Artificial Opening Endoscopic */
"0BPT82Z" = "1" /* Removal of Monitoring Device from Diaphragm, Via Natural or Artificial Opening Endoscopic */
"0BPT87Z" = "1" /* Removal of Autologous Tissue Substitute from Diaphragm, Via Natural or Artificial Opening Endoscopic */
"0BPT8JZ" = "1" /* Removal of Synthetic Substitute from Diaphragm, Via Natural or Artificial Opening Endoscopic */
"0BPT8KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Diaphragm, Via Natural or Artificial Opening Endoscopic */
"0BPT8MZ" = "1" /* Removal of Diaphragmatic Pacemaker Lead from Diaphragm, Via Natural or Artificial Opening Endoscopic */
"0BQ10ZZ" = "1" /* Repair Trachea, Open Approach */
"0BQ13ZZ" = "1" /* Repair Trachea, Percutaneous Approach */
"0BQ14ZZ" = "1" /* Repair Trachea, Percutaneous Endoscopic Approach */
"0BQ17ZZ" = "1" /* Repair Trachea, Via Natural or Artificial Opening */
"0BQ18ZZ" = "1" /* Repair Trachea, Via Natural or Artificial Opening Endoscopic */
"0BQ20ZZ" = "1" /* Repair Carina, Open Approach */
"0BQ23ZZ" = "1" /* Repair Carina, Percutaneous Approach */
"0BQ24ZZ" = "1" /* Repair Carina, Percutaneous Endoscopic Approach */
"0BQ27ZZ" = "1" /* Repair Carina, Via Natural or Artificial Opening */
"0BQ28ZZ" = "1" /* Repair Carina, Via Natural or Artificial Opening Endoscopic */
"0BQ30ZZ" = "1" /* Repair Right Main Bronchus, Open Approach */
"0BQ33ZZ" = "1" /* Repair Right Main Bronchus, Percutaneous Approach */
"0BQ34ZZ" = "1" /* Repair Right Main Bronchus, Percutaneous Endoscopic Approach */
"0BQ37ZZ" = "1" /* Repair Right Main Bronchus, Via Natural or Artificial Opening */
"0BQ38ZZ" = "1" /* Repair Right Main Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BQ40ZZ" = "1" /* Repair Right Upper Lobe Bronchus, Open Approach */
"0BQ43ZZ" = "1" /* Repair Right Upper Lobe Bronchus, Percutaneous Approach */
"0BQ44ZZ" = "1" /* Repair Right Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BQ47ZZ" = "1" /* Repair Right Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BQ48ZZ" = "1" /* Repair Right Upper Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BQ50ZZ" = "1" /* Repair Right Middle Lobe Bronchus, Open Approach */
"0BQ53ZZ" = "1" /* Repair Right Middle Lobe Bronchus, Percutaneous Approach */
"0BQ54ZZ" = "1" /* Repair Right Middle Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BQ57ZZ" = "1" /* Repair Right Middle Lobe Bronchus, Via Natural or Artificial Opening */
"0BQ58ZZ" = "1" /* Repair Right Middle Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BQ60ZZ" = "1" /* Repair Right Lower Lobe Bronchus, Open Approach */
"0BQ63ZZ" = "1" /* Repair Right Lower Lobe Bronchus, Percutaneous Approach */
"0BQ64ZZ" = "1" /* Repair Right Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BQ67ZZ" = "1" /* Repair Right Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BQ68ZZ" = "1" /* Repair Right Lower Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BQ70ZZ" = "1" /* Repair Left Main Bronchus, Open Approach */
"0BQ73ZZ" = "1" /* Repair Left Main Bronchus, Percutaneous Approach */
"0BQ74ZZ" = "1" /* Repair Left Main Bronchus, Percutaneous Endoscopic Approach */
"0BQ77ZZ" = "1" /* Repair Left Main Bronchus, Via Natural or Artificial Opening */
"0BQ78ZZ" = "1" /* Repair Left Main Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BQ80ZZ" = "1" /* Repair Left Upper Lobe Bronchus, Open Approach */
"0BQ83ZZ" = "1" /* Repair Left Upper Lobe Bronchus, Percutaneous Approach */
"0BQ84ZZ" = "1" /* Repair Left Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BQ87ZZ" = "1" /* Repair Left Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BQ88ZZ" = "1" /* Repair Left Upper Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BQ90ZZ" = "1" /* Repair Lingula Bronchus, Open Approach */
"0BQ93ZZ" = "1" /* Repair Lingula Bronchus, Percutaneous Approach */
"0BQ94ZZ" = "1" /* Repair Lingula Bronchus, Percutaneous Endoscopic Approach */
"0BQ97ZZ" = "1" /* Repair Lingula Bronchus, Via Natural or Artificial Opening */
"0BQ98ZZ" = "1" /* Repair Lingula Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BQB0ZZ" = "1" /* Repair Left Lower Lobe Bronchus, Open Approach */
"0BQB3ZZ" = "1" /* Repair Left Lower Lobe Bronchus, Percutaneous Approach */
"0BQB4ZZ" = "1" /* Repair Left Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BQB7ZZ" = "1" /* Repair Left Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BQB8ZZ" = "1" /* Repair Left Lower Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BQC0ZZ" = "1" /* Repair Right Upper Lung Lobe, Open Approach */
"0BQC3ZZ" = "1" /* Repair Right Upper Lung Lobe, Percutaneous Approach */
"0BQC4ZZ" = "1" /* Repair Right Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BQC7ZZ" = "1" /* Repair Right Upper Lung Lobe, Via Natural or Artificial Opening */
"0BQC8ZZ" = "1" /* Repair Right Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BQD0ZZ" = "1" /* Repair Right Middle Lung Lobe, Open Approach */
"0BQD3ZZ" = "1" /* Repair Right Middle Lung Lobe, Percutaneous Approach */
"0BQD4ZZ" = "1" /* Repair Right Middle Lung Lobe, Percutaneous Endoscopic Approach */
"0BQD7ZZ" = "1" /* Repair Right Middle Lung Lobe, Via Natural or Artificial Opening */
"0BQD8ZZ" = "1" /* Repair Right Middle Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BQF0ZZ" = "1" /* Repair Right Lower Lung Lobe, Open Approach */
"0BQF3ZZ" = "1" /* Repair Right Lower Lung Lobe, Percutaneous Approach */
"0BQF4ZZ" = "1" /* Repair Right Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BQF7ZZ" = "1" /* Repair Right Lower Lung Lobe, Via Natural or Artificial Opening */
"0BQF8ZZ" = "1" /* Repair Right Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BQG0ZZ" = "1" /* Repair Left Upper Lung Lobe, Open Approach */
"0BQG3ZZ" = "1" /* Repair Left Upper Lung Lobe, Percutaneous Approach */
"0BQG4ZZ" = "1" /* Repair Left Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BQG7ZZ" = "1" /* Repair Left Upper Lung Lobe, Via Natural or Artificial Opening */
"0BQG8ZZ" = "1" /* Repair Left Upper Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BQH0ZZ" = "1" /* Repair Lung Lingula, Open Approach */
"0BQH3ZZ" = "1" /* Repair Lung Lingula, Percutaneous Approach */
"0BQH4ZZ" = "1" /* Repair Lung Lingula, Percutaneous Endoscopic Approach */
"0BQH7ZZ" = "1" /* Repair Lung Lingula, Via Natural or Artificial Opening */
"0BQH8ZZ" = "1" /* Repair Lung Lingula, Via Natural or Artificial Opening Endoscopic */
"0BQJ0ZZ" = "1" /* Repair Left Lower Lung Lobe, Open Approach */
"0BQJ3ZZ" = "1" /* Repair Left Lower Lung Lobe, Percutaneous Approach */
"0BQJ4ZZ" = "1" /* Repair Left Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BQJ7ZZ" = "1" /* Repair Left Lower Lung Lobe, Via Natural or Artificial Opening */
"0BQJ8ZZ" = "1" /* Repair Left Lower Lung Lobe, Via Natural or Artificial Opening Endoscopic */
"0BQK0ZZ" = "1" /* Repair Right Lung, Open Approach */
"0BQK3ZZ" = "1" /* Repair Right Lung, Percutaneous Approach */
"0BQK4ZZ" = "1" /* Repair Right Lung, Percutaneous Endoscopic Approach */
"0BQK7ZZ" = "1" /* Repair Right Lung, Via Natural or Artificial Opening */
"0BQK8ZZ" = "1" /* Repair Right Lung, Via Natural or Artificial Opening Endoscopic */
"0BQL0ZZ" = "1" /* Repair Left Lung, Open Approach */
"0BQL3ZZ" = "1" /* Repair Left Lung, Percutaneous Approach */
"0BQL4ZZ" = "1" /* Repair Left Lung, Percutaneous Endoscopic Approach */
"0BQL7ZZ" = "1" /* Repair Left Lung, Via Natural or Artificial Opening */
"0BQL8ZZ" = "1" /* Repair Left Lung, Via Natural or Artificial Opening Endoscopic */
"0BQM0ZZ" = "1" /* Repair Bilateral Lungs, Open Approach */
"0BQM3ZZ" = "1" /* Repair Bilateral Lungs, Percutaneous Approach */
"0BQM4ZZ" = "1" /* Repair Bilateral Lungs, Percutaneous Endoscopic Approach */
"0BQM7ZZ" = "1" /* Repair Bilateral Lungs, Via Natural or Artificial Opening */
"0BQM8ZZ" = "1" /* Repair Bilateral Lungs, Via Natural or Artificial Opening Endoscopic */
"0BQN0ZZ" = "1" /* Repair Right Pleura, Open Approach */
"0BQN3ZZ" = "1" /* Repair Right Pleura, Percutaneous Approach */
"0BQN4ZZ" = "1" /* Repair Right Pleura, Percutaneous Endoscopic Approach */
"0BQP0ZZ" = "1" /* Repair Left Pleura, Open Approach */
"0BQP3ZZ" = "1" /* Repair Left Pleura, Percutaneous Approach */
"0BQP4ZZ" = "1" /* Repair Left Pleura, Percutaneous Endoscopic Approach */
"0BQR0ZZ" = "1" /* Repair Right Diaphragm, Open Approach */
"0BQR3ZZ" = "1" /* Repair Right Diaphragm, Percutaneous Approach */
"0BQR4ZZ" = "1" /* Repair Right Diaphragm, Percutaneous Endoscopic Approach */
"0BQS0ZZ" = "1" /* Repair Left Diaphragm, Open Approach */
"0BQS3ZZ" = "1" /* Repair Left Diaphragm, Percutaneous Approach */
"0BQS4ZZ" = "1" /* Repair Left Diaphragm, Percutaneous Endoscopic Approach */
"0BS10ZZ" = "1" /* Reposition Trachea, Open Approach */
"0BS20ZZ" = "1" /* Reposition Carina, Open Approach */
"0BS30ZZ" = "1" /* Reposition Right Main Bronchus, Open Approach */
"0BS40ZZ" = "1" /* Reposition Right Upper Lobe Bronchus, Open Approach */
"0BS50ZZ" = "1" /* Reposition Right Middle Lobe Bronchus, Open Approach */
"0BS60ZZ" = "1" /* Reposition Right Lower Lobe Bronchus, Open Approach */
"0BS70ZZ" = "1" /* Reposition Left Main Bronchus, Open Approach */
"0BS80ZZ" = "1" /* Reposition Left Upper Lobe Bronchus, Open Approach */
"0BS90ZZ" = "1" /* Reposition Lingula Bronchus, Open Approach */
"0BSB0ZZ" = "1" /* Reposition Left Lower Lobe Bronchus, Open Approach */
"0BSC0ZZ" = "1" /* Reposition Right Upper Lung Lobe, Open Approach */
"0BSD0ZZ" = "1" /* Reposition Right Middle Lung Lobe, Open Approach */
"0BSF0ZZ" = "1" /* Reposition Right Lower Lung Lobe, Open Approach */
"0BSG0ZZ" = "1" /* Reposition Left Upper Lung Lobe, Open Approach */
"0BSH0ZZ" = "1" /* Reposition Lung Lingula, Open Approach */
"0BSJ0ZZ" = "1" /* Reposition Left Lower Lung Lobe, Open Approach */
"0BSK0ZZ" = "1" /* Reposition Right Lung, Open Approach */
"0BSL0ZZ" = "1" /* Reposition Left Lung, Open Approach */
"0BSR0ZZ" = "1" /* Reposition Right Diaphragm, Open Approach */
"0BSS0ZZ" = "1" /* Reposition Left Diaphragm, Open Approach */
"0BT10ZZ" = "1" /* Resection of Trachea, Open Approach */
"0BT14ZZ" = "1" /* Resection of Trachea, Percutaneous Endoscopic Approach */
"0BT20ZZ" = "1" /* Resection of Carina, Open Approach */
"0BT24ZZ" = "1" /* Resection of Carina, Percutaneous Endoscopic Approach */
"0BT30ZZ" = "1" /* Resection of Right Main Bronchus, Open Approach */
"0BT34ZZ" = "1" /* Resection of Right Main Bronchus, Percutaneous Endoscopic Approach */
"0BT40ZZ" = "1" /* Resection of Right Upper Lobe Bronchus, Open Approach */
"0BT44ZZ" = "1" /* Resection of Right Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BT50ZZ" = "1" /* Resection of Right Middle Lobe Bronchus, Open Approach */
"0BT54ZZ" = "1" /* Resection of Right Middle Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BT60ZZ" = "1" /* Resection of Right Lower Lobe Bronchus, Open Approach */
"0BT64ZZ" = "1" /* Resection of Right Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BT70ZZ" = "1" /* Resection of Left Main Bronchus, Open Approach */
"0BT74ZZ" = "1" /* Resection of Left Main Bronchus, Percutaneous Endoscopic Approach */
"0BT80ZZ" = "1" /* Resection of Left Upper Lobe Bronchus, Open Approach */
"0BT84ZZ" = "1" /* Resection of Left Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BT90ZZ" = "1" /* Resection of Lingula Bronchus, Open Approach */
"0BT94ZZ" = "1" /* Resection of Lingula Bronchus, Percutaneous Endoscopic Approach */
"0BTB0ZZ" = "1" /* Resection of Left Lower Lobe Bronchus, Open Approach */
"0BTB4ZZ" = "1" /* Resection of Left Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BTC0ZZ" = "1" /* Resection of Right Upper Lung Lobe, Open Approach */
"0BTC4ZZ" = "1" /* Resection of Right Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BTD0ZZ" = "1" /* Resection of Right Middle Lung Lobe, Open Approach */
"0BTD4ZZ" = "1" /* Resection of Right Middle Lung Lobe, Percutaneous Endoscopic Approach */
"0BTF0ZZ" = "1" /* Resection of Right Lower Lung Lobe, Open Approach */
"0BTF4ZZ" = "1" /* Resection of Right Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BTG0ZZ" = "1" /* Resection of Left Upper Lung Lobe, Open Approach */
"0BTG4ZZ" = "1" /* Resection of Left Upper Lung Lobe, Percutaneous Endoscopic Approach */
"0BTH0ZZ" = "1" /* Resection of Lung Lingula, Open Approach */
"0BTH4ZZ" = "1" /* Resection of Lung Lingula, Percutaneous Endoscopic Approach */
"0BTJ0ZZ" = "1" /* Resection of Left Lower Lung Lobe, Open Approach */
"0BTJ4ZZ" = "1" /* Resection of Left Lower Lung Lobe, Percutaneous Endoscopic Approach */
"0BTK0ZZ" = "1" /* Resection of Right Lung, Open Approach */
"0BTK4ZZ" = "1" /* Resection of Right Lung, Percutaneous Endoscopic Approach */
"0BTL0ZZ" = "1" /* Resection of Left Lung, Open Approach */
"0BTL4ZZ" = "1" /* Resection of Left Lung, Percutaneous Endoscopic Approach */
"0BTM0ZZ" = "1" /* Resection of Bilateral Lungs, Open Approach */
"0BTM4ZZ" = "1" /* Resection of Bilateral Lungs, Percutaneous Endoscopic Approach */
"0BTR0ZZ" = "1" /* Resection of Right Diaphragm, Open Approach */
"0BTR4ZZ" = "1" /* Resection of Right Diaphragm, Percutaneous Endoscopic Approach */
"0BTS0ZZ" = "1" /* Resection of Left Diaphragm, Open Approach */
"0BTS4ZZ" = "1" /* Resection of Left Diaphragm, Percutaneous Endoscopic Approach */
"0BU107Z" = "1" /* Supplement Trachea with Autologous Tissue Substitute, Open Approach */
"0BU10JZ" = "1" /* Supplement Trachea with Synthetic Substitute, Open Approach */
"0BU10KZ" = "1" /* Supplement Trachea with Nonautologous Tissue Substitute, Open Approach */
"0BU147Z" = "1" /* Supplement Trachea with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU14JZ" = "1" /* Supplement Trachea with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BU14KZ" = "1" /* Supplement Trachea with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU207Z" = "1" /* Supplement Carina with Autologous Tissue Substitute, Open Approach */
"0BU20JZ" = "1" /* Supplement Carina with Synthetic Substitute, Open Approach */
"0BU20KZ" = "1" /* Supplement Carina with Nonautologous Tissue Substitute, Open Approach */
"0BU247Z" = "1" /* Supplement Carina with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU24JZ" = "1" /* Supplement Carina with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BU24KZ" = "1" /* Supplement Carina with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU307Z" = "1" /* Supplement Right Main Bronchus with Autologous Tissue Substitute, Open Approach */
"0BU30JZ" = "1" /* Supplement Right Main Bronchus with Synthetic Substitute, Open Approach */
"0BU30KZ" = "1" /* Supplement Right Main Bronchus with Nonautologous Tissue Substitute, Open Approach */
"0BU347Z" = "1" /* Supplement Right Main Bronchus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU34JZ" = "1" /* Supplement Right Main Bronchus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BU34KZ" = "1" /* Supplement Right Main Bronchus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU407Z" = "1" /* Supplement Right Upper Lobe Bronchus with Autologous Tissue Substitute, Open Approach */
"0BU40JZ" = "1" /* Supplement Right Upper Lobe Bronchus with Synthetic Substitute, Open Approach */
"0BU40KZ" = "1" /* Supplement Right Upper Lobe Bronchus with Nonautologous Tissue Substitute, Open Approach */
"0BU447Z" = "1" /* Supplement Right Upper Lobe Bronchus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU44JZ" = "1" /* Supplement Right Upper Lobe Bronchus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BU44KZ" = "1" /* Supplement Right Upper Lobe Bronchus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU507Z" = "1" /* Supplement Right Middle Lobe Bronchus with Autologous Tissue Substitute, Open Approach */
"0BU50JZ" = "1" /* Supplement Right Middle Lobe Bronchus with Synthetic Substitute, Open Approach */
"0BU50KZ" = "1" /* Supplement Right Middle Lobe Bronchus with Nonautologous Tissue Substitute, Open Approach */
"0BU547Z" = "1" /* Supplement Right Middle Lobe Bronchus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU54JZ" = "1" /* Supplement Right Middle Lobe Bronchus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BU54KZ" = "1" /* Supplement Right Middle Lobe Bronchus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU607Z" = "1" /* Supplement Right Lower Lobe Bronchus with Autologous Tissue Substitute, Open Approach */
"0BU60JZ" = "1" /* Supplement Right Lower Lobe Bronchus with Synthetic Substitute, Open Approach */
"0BU60KZ" = "1" /* Supplement Right Lower Lobe Bronchus with Nonautologous Tissue Substitute, Open Approach */
"0BU647Z" = "1" /* Supplement Right Lower Lobe Bronchus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU64JZ" = "1" /* Supplement Right Lower Lobe Bronchus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BU64KZ" = "1" /* Supplement Right Lower Lobe Bronchus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU707Z" = "1" /* Supplement Left Main Bronchus with Autologous Tissue Substitute, Open Approach */
"0BU70JZ" = "1" /* Supplement Left Main Bronchus with Synthetic Substitute, Open Approach */
"0BU70KZ" = "1" /* Supplement Left Main Bronchus with Nonautologous Tissue Substitute, Open Approach */
"0BU747Z" = "1" /* Supplement Left Main Bronchus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU74JZ" = "1" /* Supplement Left Main Bronchus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BU74KZ" = "1" /* Supplement Left Main Bronchus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU807Z" = "1" /* Supplement Left Upper Lobe Bronchus with Autologous Tissue Substitute, Open Approach */
"0BU80JZ" = "1" /* Supplement Left Upper Lobe Bronchus with Synthetic Substitute, Open Approach */
"0BU80KZ" = "1" /* Supplement Left Upper Lobe Bronchus with Nonautologous Tissue Substitute, Open Approach */
"0BU847Z" = "1" /* Supplement Left Upper Lobe Bronchus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU84JZ" = "1" /* Supplement Left Upper Lobe Bronchus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BU84KZ" = "1" /* Supplement Left Upper Lobe Bronchus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU907Z" = "1" /* Supplement Lingula Bronchus with Autologous Tissue Substitute, Open Approach */
"0BU90JZ" = "1" /* Supplement Lingula Bronchus with Synthetic Substitute, Open Approach */
"0BU90KZ" = "1" /* Supplement Lingula Bronchus with Nonautologous Tissue Substitute, Open Approach */
"0BU947Z" = "1" /* Supplement Lingula Bronchus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BU94JZ" = "1" /* Supplement Lingula Bronchus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BU94KZ" = "1" /* Supplement Lingula Bronchus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BUB07Z" = "1" /* Supplement Left Lower Lobe Bronchus with Autologous Tissue Substitute, Open Approach */
"0BUB0JZ" = "1" /* Supplement Left Lower Lobe Bronchus with Synthetic Substitute, Open Approach */
"0BUB0KZ" = "1" /* Supplement Left Lower Lobe Bronchus with Nonautologous Tissue Substitute, Open Approach */
"0BUB47Z" = "1" /* Supplement Left Lower Lobe Bronchus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BUB4JZ" = "1" /* Supplement Left Lower Lobe Bronchus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0BUB4KZ" = "1" /* Supplement Left Lower Lobe Bronchus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0BV10CZ" = "1" /* Restriction of Trachea with Extraluminal Device, Open Approach */
"0BV10DZ" = "1" /* Restriction of Trachea with Intraluminal Device, Open Approach */
"0BV10ZZ" = "1" /* Restriction of Trachea, Open Approach */
"0BV13CZ" = "1" /* Restriction of Trachea with Extraluminal Device, Percutaneous Approach */
"0BV13DZ" = "1" /* Restriction of Trachea with Intraluminal Device, Percutaneous Approach */
"0BV13ZZ" = "1" /* Restriction of Trachea, Percutaneous Approach */
"0BV14CZ" = "1" /* Restriction of Trachea with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BV14DZ" = "1" /* Restriction of Trachea with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BV14ZZ" = "1" /* Restriction of Trachea, Percutaneous Endoscopic Approach */
"0BV17DZ" = "1" /* Restriction of Trachea with Intraluminal Device, Via Natural or Artificial Opening */
"0BV17ZZ" = "1" /* Restriction of Trachea, Via Natural or Artificial Opening */
"0BV18DZ" = "1" /* Restriction of Trachea with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BV18ZZ" = "1" /* Restriction of Trachea, Via Natural or Artificial Opening Endoscopic */
"0BV20CZ" = "1" /* Restriction of Carina with Extraluminal Device, Open Approach */
"0BV20DZ" = "1" /* Restriction of Carina with Intraluminal Device, Open Approach */
"0BV20ZZ" = "1" /* Restriction of Carina, Open Approach */
"0BV23CZ" = "1" /* Restriction of Carina with Extraluminal Device, Percutaneous Approach */
"0BV23DZ" = "1" /* Restriction of Carina with Intraluminal Device, Percutaneous Approach */
"0BV23ZZ" = "1" /* Restriction of Carina, Percutaneous Approach */
"0BV24CZ" = "1" /* Restriction of Carina with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BV24DZ" = "1" /* Restriction of Carina with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BV24ZZ" = "1" /* Restriction of Carina, Percutaneous Endoscopic Approach */
"0BV27DZ" = "1" /* Restriction of Carina with Intraluminal Device, Via Natural or Artificial Opening */
"0BV27ZZ" = "1" /* Restriction of Carina, Via Natural or Artificial Opening */
"0BV28DZ" = "1" /* Restriction of Carina with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BV28ZZ" = "1" /* Restriction of Carina, Via Natural or Artificial Opening Endoscopic */
"0BV30CZ" = "1" /* Restriction of Right Main Bronchus with Extraluminal Device, Open Approach */
"0BV30DZ" = "1" /* Restriction of Right Main Bronchus with Intraluminal Device, Open Approach */
"0BV30ZZ" = "1" /* Restriction of Right Main Bronchus, Open Approach */
"0BV33CZ" = "1" /* Restriction of Right Main Bronchus with Extraluminal Device, Percutaneous Approach */
"0BV33DZ" = "1" /* Restriction of Right Main Bronchus with Intraluminal Device, Percutaneous Approach */
"0BV33ZZ" = "1" /* Restriction of Right Main Bronchus, Percutaneous Approach */
"0BV34CZ" = "1" /* Restriction of Right Main Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BV34DZ" = "1" /* Restriction of Right Main Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BV34ZZ" = "1" /* Restriction of Right Main Bronchus, Percutaneous Endoscopic Approach */
"0BV37DZ" = "1" /* Restriction of Right Main Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BV37ZZ" = "1" /* Restriction of Right Main Bronchus, Via Natural or Artificial Opening */
"0BV38DZ" = "1" /* Restriction of Right Main Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BV38ZZ" = "1" /* Restriction of Right Main Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BV40CZ" = "1" /* Restriction of Right Upper Lobe Bronchus with Extraluminal Device, Open Approach */
"0BV40DZ" = "1" /* Restriction of Right Upper Lobe Bronchus with Intraluminal Device, Open Approach */
"0BV40ZZ" = "1" /* Restriction of Right Upper Lobe Bronchus, Open Approach */
"0BV43CZ" = "1" /* Restriction of Right Upper Lobe Bronchus with Extraluminal Device, Percutaneous Approach */
"0BV43DZ" = "1" /* Restriction of Right Upper Lobe Bronchus with Intraluminal Device, Percutaneous Approach */
"0BV43ZZ" = "1" /* Restriction of Right Upper Lobe Bronchus, Percutaneous Approach */
"0BV44CZ" = "1" /* Restriction of Right Upper Lobe Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BV44DZ" = "1" /* Restriction of Right Upper Lobe Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BV44ZZ" = "1" /* Restriction of Right Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BV47DZ" = "1" /* Restriction of Right Upper Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BV47ZZ" = "1" /* Restriction of Right Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BV48DZ" = "1" /* Restriction of Right Upper Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BV48ZZ" = "1" /* Restriction of Right Upper Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BV50CZ" = "1" /* Restriction of Right Middle Lobe Bronchus with Extraluminal Device, Open Approach */
"0BV50DZ" = "1" /* Restriction of Right Middle Lobe Bronchus with Intraluminal Device, Open Approach */
"0BV50ZZ" = "1" /* Restriction of Right Middle Lobe Bronchus, Open Approach */
"0BV53CZ" = "1" /* Restriction of Right Middle Lobe Bronchus with Extraluminal Device, Percutaneous Approach */
"0BV53DZ" = "1" /* Restriction of Right Middle Lobe Bronchus with Intraluminal Device, Percutaneous Approach */
"0BV53ZZ" = "1" /* Restriction of Right Middle Lobe Bronchus, Percutaneous Approach */
"0BV54CZ" = "1" /* Restriction of Right Middle Lobe Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BV54DZ" = "1" /* Restriction of Right Middle Lobe Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BV54ZZ" = "1" /* Restriction of Right Middle Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BV57DZ" = "1" /* Restriction of Right Middle Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BV57ZZ" = "1" /* Restriction of Right Middle Lobe Bronchus, Via Natural or Artificial Opening */
"0BV58DZ" = "1" /* Restriction of Right Middle Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BV58ZZ" = "1" /* Restriction of Right Middle Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BV60CZ" = "1" /* Restriction of Right Lower Lobe Bronchus with Extraluminal Device, Open Approach */
"0BV60DZ" = "1" /* Restriction of Right Lower Lobe Bronchus with Intraluminal Device, Open Approach */
"0BV60ZZ" = "1" /* Restriction of Right Lower Lobe Bronchus, Open Approach */
"0BV63CZ" = "1" /* Restriction of Right Lower Lobe Bronchus with Extraluminal Device, Percutaneous Approach */
"0BV63DZ" = "1" /* Restriction of Right Lower Lobe Bronchus with Intraluminal Device, Percutaneous Approach */
"0BV63ZZ" = "1" /* Restriction of Right Lower Lobe Bronchus, Percutaneous Approach */
"0BV64CZ" = "1" /* Restriction of Right Lower Lobe Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BV64DZ" = "1" /* Restriction of Right Lower Lobe Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BV64ZZ" = "1" /* Restriction of Right Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BV67DZ" = "1" /* Restriction of Right Lower Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BV67ZZ" = "1" /* Restriction of Right Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BV68DZ" = "1" /* Restriction of Right Lower Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BV68ZZ" = "1" /* Restriction of Right Lower Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BV70CZ" = "1" /* Restriction of Left Main Bronchus with Extraluminal Device, Open Approach */
"0BV70DZ" = "1" /* Restriction of Left Main Bronchus with Intraluminal Device, Open Approach */
"0BV70ZZ" = "1" /* Restriction of Left Main Bronchus, Open Approach */
"0BV73CZ" = "1" /* Restriction of Left Main Bronchus with Extraluminal Device, Percutaneous Approach */
"0BV73DZ" = "1" /* Restriction of Left Main Bronchus with Intraluminal Device, Percutaneous Approach */
"0BV73ZZ" = "1" /* Restriction of Left Main Bronchus, Percutaneous Approach */
"0BV74CZ" = "1" /* Restriction of Left Main Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BV74DZ" = "1" /* Restriction of Left Main Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BV74ZZ" = "1" /* Restriction of Left Main Bronchus, Percutaneous Endoscopic Approach */
"0BV77DZ" = "1" /* Restriction of Left Main Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BV77ZZ" = "1" /* Restriction of Left Main Bronchus, Via Natural or Artificial Opening */
"0BV78DZ" = "1" /* Restriction of Left Main Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BV78ZZ" = "1" /* Restriction of Left Main Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BV80CZ" = "1" /* Restriction of Left Upper Lobe Bronchus with Extraluminal Device, Open Approach */
"0BV80DZ" = "1" /* Restriction of Left Upper Lobe Bronchus with Intraluminal Device, Open Approach */
"0BV80ZZ" = "1" /* Restriction of Left Upper Lobe Bronchus, Open Approach */
"0BV83CZ" = "1" /* Restriction of Left Upper Lobe Bronchus with Extraluminal Device, Percutaneous Approach */
"0BV83DZ" = "1" /* Restriction of Left Upper Lobe Bronchus with Intraluminal Device, Percutaneous Approach */
"0BV83ZZ" = "1" /* Restriction of Left Upper Lobe Bronchus, Percutaneous Approach */
"0BV84CZ" = "1" /* Restriction of Left Upper Lobe Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BV84DZ" = "1" /* Restriction of Left Upper Lobe Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BV84ZZ" = "1" /* Restriction of Left Upper Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BV87DZ" = "1" /* Restriction of Left Upper Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BV87ZZ" = "1" /* Restriction of Left Upper Lobe Bronchus, Via Natural or Artificial Opening */
"0BV88DZ" = "1" /* Restriction of Left Upper Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BV88ZZ" = "1" /* Restriction of Left Upper Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BV90CZ" = "1" /* Restriction of Lingula Bronchus with Extraluminal Device, Open Approach */
"0BV90DZ" = "1" /* Restriction of Lingula Bronchus with Intraluminal Device, Open Approach */
"0BV90ZZ" = "1" /* Restriction of Lingula Bronchus, Open Approach */
"0BV93CZ" = "1" /* Restriction of Lingula Bronchus with Extraluminal Device, Percutaneous Approach */
"0BV93DZ" = "1" /* Restriction of Lingula Bronchus with Intraluminal Device, Percutaneous Approach */
"0BV93ZZ" = "1" /* Restriction of Lingula Bronchus, Percutaneous Approach */
"0BV94CZ" = "1" /* Restriction of Lingula Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BV94DZ" = "1" /* Restriction of Lingula Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BV94ZZ" = "1" /* Restriction of Lingula Bronchus, Percutaneous Endoscopic Approach */
"0BV97DZ" = "1" /* Restriction of Lingula Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BV97ZZ" = "1" /* Restriction of Lingula Bronchus, Via Natural or Artificial Opening */
"0BV98DZ" = "1" /* Restriction of Lingula Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BV98ZZ" = "1" /* Restriction of Lingula Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BVB0CZ" = "1" /* Restriction of Left Lower Lobe Bronchus with Extraluminal Device, Open Approach */
"0BVB0DZ" = "1" /* Restriction of Left Lower Lobe Bronchus with Intraluminal Device, Open Approach */
"0BVB0ZZ" = "1" /* Restriction of Left Lower Lobe Bronchus, Open Approach */
"0BVB3CZ" = "1" /* Restriction of Left Lower Lobe Bronchus with Extraluminal Device, Percutaneous Approach */
"0BVB3DZ" = "1" /* Restriction of Left Lower Lobe Bronchus with Intraluminal Device, Percutaneous Approach */
"0BVB3ZZ" = "1" /* Restriction of Left Lower Lobe Bronchus, Percutaneous Approach */
"0BVB4CZ" = "1" /* Restriction of Left Lower Lobe Bronchus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0BVB4DZ" = "1" /* Restriction of Left Lower Lobe Bronchus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0BVB4ZZ" = "1" /* Restriction of Left Lower Lobe Bronchus, Percutaneous Endoscopic Approach */
"0BVB7DZ" = "1" /* Restriction of Left Lower Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening */
"0BVB7ZZ" = "1" /* Restriction of Left Lower Lobe Bronchus, Via Natural or Artificial Opening */
"0BVB8DZ" = "1" /* Restriction of Left Lower Lobe Bronchus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0BVB8ZZ" = "1" /* Restriction of Left Lower Lobe Bronchus, Via Natural or Artificial Opening Endoscopic */
"0BW000Z" = "1" /* Revision of Drainage Device in Tracheobronchial Tree, Open Approach */
"0BW002Z" = "1" /* Revision of Monitoring Device in Tracheobronchial Tree, Open Approach */
"0BW00CZ" = "1" /* Revision of Extraluminal Device in Tracheobronchial Tree, Open Approach */
"0BW00DZ" = "1" /* Revision of Intraluminal Device in Tracheobronchial Tree, Open Approach */
"0BW00JZ" = "1" /* Revision of Synthetic Substitute in Tracheobronchial Tree, Open Approach */
"0BW00KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Tracheobronchial Tree, Open Approach */
"0BW030Z" = "1" /* Revision of Drainage Device in Tracheobronchial Tree, Percutaneous Approach */
"0BW032Z" = "1" /* Revision of Monitoring Device in Tracheobronchial Tree, Percutaneous Approach */
"0BW03CZ" = "1" /* Revision of Extraluminal Device in Tracheobronchial Tree, Percutaneous Approach */
"0BW03DZ" = "1" /* Revision of Intraluminal Device in Tracheobronchial Tree, Percutaneous Approach */
"0BW03JZ" = "1" /* Revision of Synthetic Substitute in Tracheobronchial Tree, Percutaneous Approach */
"0BW03KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Tracheobronchial Tree, Percutaneous Approach */
"0BW040Z" = "1" /* Revision of Drainage Device in Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BW042Z" = "1" /* Revision of Monitoring Device in Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BW04CZ" = "1" /* Revision of Extraluminal Device in Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BW04DZ" = "1" /* Revision of Intraluminal Device in Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BW04JZ" = "1" /* Revision of Synthetic Substitute in Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BW04KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Tracheobronchial Tree, Percutaneous Endoscopic Approach */
"0BW070Z" = "1" /* Revision of Drainage Device in Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BW072Z" = "1" /* Revision of Monitoring Device in Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BW07DZ" = "1" /* Revision of Intraluminal Device in Tracheobronchial Tree, Via Natural or Artificial Opening */
"0BW080Z" = "1" /* Revision of Drainage Device in Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BW082Z" = "1" /* Revision of Monitoring Device in Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BW08DZ" = "1" /* Revision of Intraluminal Device in Tracheobronchial Tree, Via Natural or Artificial Opening Endoscopic */
"0BWK00Z" = "1" /* Revision of Drainage Device in Right Lung, Open Approach */
"0BWK02Z" = "1" /* Revision of Monitoring Device in Right Lung, Open Approach */
"0BWK03Z" = "1" /* Revision of Infusion Device in Right Lung, Open Approach */
"0BWK30Z" = "1" /* Revision of Drainage Device in Right Lung, Percutaneous Approach */
"0BWK32Z" = "1" /* Revision of Monitoring Device in Right Lung, Percutaneous Approach */
"0BWK33Z" = "1" /* Revision of Infusion Device in Right Lung, Percutaneous Approach */
"0BWK40Z" = "1" /* Revision of Drainage Device in Right Lung, Percutaneous Endoscopic Approach */
"0BWK42Z" = "1" /* Revision of Monitoring Device in Right Lung, Percutaneous Endoscopic Approach */
"0BWK43Z" = "1" /* Revision of Infusion Device in Right Lung, Percutaneous Endoscopic Approach */
"0BWK70Z" = "1" /* Revision of Drainage Device in Right Lung, Via Natural or Artificial Opening */
"0BWK72Z" = "1" /* Revision of Monitoring Device in Right Lung, Via Natural or Artificial Opening */
"0BWK73Z" = "1" /* Revision of Infusion Device in Right Lung, Via Natural or Artificial Opening */
"0BWK80Z" = "1" /* Revision of Drainage Device in Right Lung, Via Natural or Artificial Opening Endoscopic */
"0BWK82Z" = "1" /* Revision of Monitoring Device in Right Lung, Via Natural or Artificial Opening Endoscopic */
"0BWK83Z" = "1" /* Revision of Infusion Device in Right Lung, Via Natural or Artificial Opening Endoscopic */
"0BWL00Z" = "1" /* Revision of Drainage Device in Left Lung, Open Approach */
"0BWL02Z" = "1" /* Revision of Monitoring Device in Left Lung, Open Approach */
"0BWL03Z" = "1" /* Revision of Infusion Device in Left Lung, Open Approach */
"0BWL30Z" = "1" /* Revision of Drainage Device in Left Lung, Percutaneous Approach */
"0BWL32Z" = "1" /* Revision of Monitoring Device in Left Lung, Percutaneous Approach */
"0BWL33Z" = "1" /* Revision of Infusion Device in Left Lung, Percutaneous Approach */
"0BWL40Z" = "1" /* Revision of Drainage Device in Left Lung, Percutaneous Endoscopic Approach */
"0BWL42Z" = "1" /* Revision of Monitoring Device in Left Lung, Percutaneous Endoscopic Approach */
"0BWL43Z" = "1" /* Revision of Infusion Device in Left Lung, Percutaneous Endoscopic Approach */
"0BWL70Z" = "1" /* Revision of Drainage Device in Left Lung, Via Natural or Artificial Opening */
"0BWL72Z" = "1" /* Revision of Monitoring Device in Left Lung, Via Natural or Artificial Opening */
"0BWL73Z" = "1" /* Revision of Infusion Device in Left Lung, Via Natural or Artificial Opening */
"0BWL80Z" = "1" /* Revision of Drainage Device in Left Lung, Via Natural or Artificial Opening Endoscopic */
"0BWL82Z" = "1" /* Revision of Monitoring Device in Left Lung, Via Natural or Artificial Opening Endoscopic */
"0BWL83Z" = "1" /* Revision of Infusion Device in Left Lung, Via Natural or Artificial Opening Endoscopic */
"0BWQ00Z" = "1" /* Revision of Drainage Device in Pleura, Open Approach */
"0BWQ02Z" = "1" /* Revision of Monitoring Device in Pleura, Open Approach */
"0BWQ30Z" = "1" /* Revision of Drainage Device in Pleura, Percutaneous Approach */
"0BWQ32Z" = "1" /* Revision of Monitoring Device in Pleura, Percutaneous Approach */
"0BWQ40Z" = "1" /* Revision of Drainage Device in Pleura, Percutaneous Endoscopic Approach */
"0BWQ42Z" = "1" /* Revision of Monitoring Device in Pleura, Percutaneous Endoscopic Approach */
"0BWQ70Z" = "1" /* Revision of Drainage Device in Pleura, Via Natural or Artificial Opening */
"0BWQ72Z" = "1" /* Revision of Monitoring Device in Pleura, Via Natural or Artificial Opening */
"0BWQ80Z" = "1" /* Revision of Drainage Device in Pleura, Via Natural or Artificial Opening Endoscopic */
"0BWQ82Z" = "1" /* Revision of Monitoring Device in Pleura, Via Natural or Artificial Opening Endoscopic */
"0BWT00Z" = "1" /* Revision of Drainage Device in Diaphragm, Open Approach */
"0BWT02Z" = "1" /* Revision of Monitoring Device in Diaphragm, Open Approach */
"0BWT07Z" = "1" /* Revision of Autologous Tissue Substitute in Diaphragm, Open Approach */
"0BWT0JZ" = "1" /* Revision of Synthetic Substitute in Diaphragm, Open Approach */
"0BWT0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Diaphragm, Open Approach */
"0BWT0MZ" = "1" /* Revision of Diaphragmatic Pacemaker Lead in Diaphragm, Open Approach */
"0BWT30Z" = "1" /* Revision of Drainage Device in Diaphragm, Percutaneous Approach */
"0BWT32Z" = "1" /* Revision of Monitoring Device in Diaphragm, Percutaneous Approach */
"0BWT37Z" = "1" /* Revision of Autologous Tissue Substitute in Diaphragm, Percutaneous Approach */
"0BWT3JZ" = "1" /* Revision of Synthetic Substitute in Diaphragm, Percutaneous Approach */
"0BWT3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Diaphragm, Percutaneous Approach */
"0BWT3MZ" = "1" /* Revision of Diaphragmatic Pacemaker Lead in Diaphragm, Percutaneous Approach */
"0BWT40Z" = "1" /* Revision of Drainage Device in Diaphragm, Percutaneous Endoscopic Approach */
"0BWT42Z" = "1" /* Revision of Monitoring Device in Diaphragm, Percutaneous Endoscopic Approach */
"0BWT47Z" = "1" /* Revision of Autologous Tissue Substitute in Diaphragm, Percutaneous Endoscopic Approach */
"0BWT4JZ" = "1" /* Revision of Synthetic Substitute in Diaphragm, Percutaneous Endoscopic Approach */
"0BWT4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Diaphragm, Percutaneous Endoscopic Approach */
"0BWT4MZ" = "1" /* Revision of Diaphragmatic Pacemaker Lead in Diaphragm, Percutaneous Endoscopic Approach */
"0BWT70Z" = "1" /* Revision of Drainage Device in Diaphragm, Via Natural or Artificial Opening */
"0BWT72Z" = "1" /* Revision of Monitoring Device in Diaphragm, Via Natural or Artificial Opening */
"0BWT77Z" = "1" /* Revision of Autologous Tissue Substitute in Diaphragm, Via Natural or Artificial Opening */
"0BWT7JZ" = "1" /* Revision of Synthetic Substitute in Diaphragm, Via Natural or Artificial Opening */
"0BWT7KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Diaphragm, Via Natural or Artificial Opening */
"0BWT7MZ" = "1" /* Revision of Diaphragmatic Pacemaker Lead in Diaphragm, Via Natural or Artificial Opening */
"0BWT80Z" = "1" /* Revision of Drainage Device in Diaphragm, Via Natural or Artificial Opening Endoscopic */
"0BWT82Z" = "1" /* Revision of Monitoring Device in Diaphragm, Via Natural or Artificial Opening Endoscopic */
"0BWT87Z" = "1" /* Revision of Autologous Tissue Substitute in Diaphragm, Via Natural or Artificial Opening Endoscopic */
"0BWT8JZ" = "1" /* Revision of Synthetic Substitute in Diaphragm, Via Natural or Artificial Opening Endoscopic */
"0BWT8KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Diaphragm, Via Natural or Artificial Opening Endoscopic */
"0BWT8MZ" = "1" /* Revision of Diaphragmatic Pacemaker Lead in Diaphragm, Via Natural or Artificial Opening Endoscopic */
"0BYC0Z0" = "1" /* Transplantation of Right Upper Lung Lobe, Allogeneic, Open Approach */
"0BYC0Z1" = "1" /* Transplantation of Right Upper Lung Lobe, Syngeneic, Open Approach */
"0BYC0Z2" = "1" /* Transplantation of Right Upper Lung Lobe, Zooplastic, Open Approach */
"0BYD0Z0" = "1" /* Transplantation of Right Middle Lung Lobe, Allogeneic, Open Approach */
"0BYD0Z1" = "1" /* Transplantation of Right Middle Lung Lobe, Syngeneic, Open Approach */
"0BYD0Z2" = "1" /* Transplantation of Right Middle Lung Lobe, Zooplastic, Open Approach */
"0BYF0Z0" = "1" /* Transplantation of Right Lower Lung Lobe, Allogeneic, Open Approach */
"0BYF0Z1" = "1" /* Transplantation of Right Lower Lung Lobe, Syngeneic, Open Approach */
"0BYF0Z2" = "1" /* Transplantation of Right Lower Lung Lobe, Zooplastic, Open Approach */
"0BYG0Z0" = "1" /* Transplantation of Left Upper Lung Lobe, Allogeneic, Open Approach */
"0BYG0Z1" = "1" /* Transplantation of Left Upper Lung Lobe, Syngeneic, Open Approach */
"0BYG0Z2" = "1" /* Transplantation of Left Upper Lung Lobe, Zooplastic, Open Approach */
"0BYH0Z0" = "1" /* Transplantation of Lung Lingula, Allogeneic, Open Approach */
"0BYH0Z1" = "1" /* Transplantation of Lung Lingula, Syngeneic, Open Approach */
"0BYH0Z2" = "1" /* Transplantation of Lung Lingula, Zooplastic, Open Approach */
"0BYJ0Z0" = "1" /* Transplantation of Left Lower Lung Lobe, Allogeneic, Open Approach */
"0BYJ0Z1" = "1" /* Transplantation of Left Lower Lung Lobe, Syngeneic, Open Approach */
"0BYJ0Z2" = "1" /* Transplantation of Left Lower Lung Lobe, Zooplastic, Open Approach */
"0BYK0Z0" = "1" /* Transplantation of Right Lung, Allogeneic, Open Approach */
"0BYK0Z1" = "1" /* Transplantation of Right Lung, Syngeneic, Open Approach */
"0BYK0Z2" = "1" /* Transplantation of Right Lung, Zooplastic, Open Approach */
"0BYL0Z0" = "1" /* Transplantation of Left Lung, Allogeneic, Open Approach */
"0BYL0Z1" = "1" /* Transplantation of Left Lung, Syngeneic, Open Approach */
"0BYL0Z2" = "1" /* Transplantation of Left Lung, Zooplastic, Open Approach */
"0BYM0Z0" = "1" /* Transplantation of Bilateral Lungs, Allogeneic, Open Approach */
"0BYM0Z1" = "1" /* Transplantation of Bilateral Lungs, Syngeneic, Open Approach */
"0BYM0Z2" = "1" /* Transplantation of Bilateral Lungs, Zooplastic, Open Approach */
"0C9R0ZX" = "1" /* Drainage of Epiglottis, Open Approach, Diagnostic */
"0C9S0ZX" = "1" /* Drainage of Larynx, Open Approach, Diagnostic */
"0C9T0ZX" = "1" /* Drainage of Right Vocal Cord, Open Approach, Diagnostic */
"0C9V0ZX" = "1" /* Drainage of Left Vocal Cord, Open Approach, Diagnostic */
"0CBR0ZX" = "1" /* Excision of Epiglottis, Open Approach, Diagnostic */
"0CBS0ZX" = "1" /* Excision of Larynx, Open Approach, Diagnostic */
"0CBT0ZX" = "1" /* Excision of Right Vocal Cord, Open Approach, Diagnostic */
"0CBV0ZX" = "1" /* Excision of Left Vocal Cord, Open Approach, Diagnostic */
"0D11074" = "1" /* Bypass Upper Esophagus to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D11076" = "1" /* Bypass Upper Esophagus to Stomach with Autologous Tissue Substitute, Open Approach */
"0D11079" = "1" /* Bypass Upper Esophagus to Duodenum with Autologous Tissue Substitute, Open Approach */
"0D1107A" = "1" /* Bypass Upper Esophagus to Jejunum with Autologous Tissue Substitute, Open Approach */
"0D1107B" = "1" /* Bypass Upper Esophagus to Ileum with Autologous Tissue Substitute, Open Approach */
"0D110J4" = "1" /* Bypass Upper Esophagus to Cutaneous with Synthetic Substitute, Open Approach */
"0D110J6" = "1" /* Bypass Upper Esophagus to Stomach with Synthetic Substitute, Open Approach */
"0D110J9" = "1" /* Bypass Upper Esophagus to Duodenum with Synthetic Substitute, Open Approach */
"0D110JA" = "1" /* Bypass Upper Esophagus to Jejunum with Synthetic Substitute, Open Approach */
"0D110JB" = "1" /* Bypass Upper Esophagus to Ileum with Synthetic Substitute, Open Approach */
"0D110K4" = "1" /* Bypass Upper Esophagus to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D110K6" = "1" /* Bypass Upper Esophagus to Stomach with Nonautologous Tissue Substitute, Open Approach */
"0D110K9" = "1" /* Bypass Upper Esophagus to Duodenum with Nonautologous Tissue Substitute, Open Approach */
"0D110KA" = "1" /* Bypass Upper Esophagus to Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0D110KB" = "1" /* Bypass Upper Esophagus to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D110Z4" = "1" /* Bypass Upper Esophagus to Cutaneous, Open Approach */
"0D110Z6" = "1" /* Bypass Upper Esophagus to Stomach, Open Approach */
"0D110Z9" = "1" /* Bypass Upper Esophagus to Duodenum, Open Approach */
"0D110ZA" = "1" /* Bypass Upper Esophagus to Jejunum, Open Approach */
"0D110ZB" = "1" /* Bypass Upper Esophagus to Ileum, Open Approach */
"0D113J4" = "1" /* Bypass Upper Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D11474" = "1" /* Bypass Upper Esophagus to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D11476" = "1" /* Bypass Upper Esophagus to Stomach with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D11479" = "1" /* Bypass Upper Esophagus to Duodenum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1147A" = "1" /* Bypass Upper Esophagus to Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1147B" = "1" /* Bypass Upper Esophagus to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D114J4" = "1" /* Bypass Upper Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D114J6" = "1" /* Bypass Upper Esophagus to Stomach with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D114J9" = "1" /* Bypass Upper Esophagus to Duodenum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D114JA" = "1" /* Bypass Upper Esophagus to Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D114JB" = "1" /* Bypass Upper Esophagus to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D114K4" = "1" /* Bypass Upper Esophagus to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D114K6" = "1" /* Bypass Upper Esophagus to Stomach with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D114K9" = "1" /* Bypass Upper Esophagus to Duodenum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D114KA" = "1" /* Bypass Upper Esophagus to Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D114KB" = "1" /* Bypass Upper Esophagus to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D114Z4" = "1" /* Bypass Upper Esophagus to Cutaneous, Percutaneous Endoscopic Approach */
"0D114Z6" = "1" /* Bypass Upper Esophagus to Stomach, Percutaneous Endoscopic Approach */
"0D114Z9" = "1" /* Bypass Upper Esophagus to Duodenum, Percutaneous Endoscopic Approach */
"0D114ZA" = "1" /* Bypass Upper Esophagus to Jejunum, Percutaneous Endoscopic Approach */
"0D114ZB" = "1" /* Bypass Upper Esophagus to Ileum, Percutaneous Endoscopic Approach */
"0D11874" = "1" /* Bypass Upper Esophagus to Cutaneous with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D11876" = "1" /* Bypass Upper Esophagus to Stomach with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D11879" = "1" /* Bypass Upper Esophagus to Duodenum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1187A" = "1" /* Bypass Upper Esophagus to Jejunum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1187B" = "1" /* Bypass Upper Esophagus to Ileum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118J4" = "1" /* Bypass Upper Esophagus to Cutaneous with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118J6" = "1" /* Bypass Upper Esophagus to Stomach with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118J9" = "1" /* Bypass Upper Esophagus to Duodenum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118JA" = "1" /* Bypass Upper Esophagus to Jejunum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118JB" = "1" /* Bypass Upper Esophagus to Ileum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118K4" = "1" /* Bypass Upper Esophagus to Cutaneous with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118K6" = "1" /* Bypass Upper Esophagus to Stomach with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118K9" = "1" /* Bypass Upper Esophagus to Duodenum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118KA" = "1" /* Bypass Upper Esophagus to Jejunum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118KB" = "1" /* Bypass Upper Esophagus to Ileum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D118Z4" = "1" /* Bypass Upper Esophagus to Cutaneous, Via Natural or Artificial Opening Endoscopic */
"0D118Z6" = "1" /* Bypass Upper Esophagus to Stomach, Via Natural or Artificial Opening Endoscopic */
"0D118Z9" = "1" /* Bypass Upper Esophagus to Duodenum, Via Natural or Artificial Opening Endoscopic */
"0D118ZA" = "1" /* Bypass Upper Esophagus to Jejunum, Via Natural or Artificial Opening Endoscopic */
"0D118ZB" = "1" /* Bypass Upper Esophagus to Ileum, Via Natural or Artificial Opening Endoscopic */
"0D12074" = "1" /* Bypass Middle Esophagus to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D12076" = "1" /* Bypass Middle Esophagus to Stomach with Autologous Tissue Substitute, Open Approach */
"0D12079" = "1" /* Bypass Middle Esophagus to Duodenum with Autologous Tissue Substitute, Open Approach */
"0D1207A" = "1" /* Bypass Middle Esophagus to Jejunum with Autologous Tissue Substitute, Open Approach */
"0D1207B" = "1" /* Bypass Middle Esophagus to Ileum with Autologous Tissue Substitute, Open Approach */
"0D120J4" = "1" /* Bypass Middle Esophagus to Cutaneous with Synthetic Substitute, Open Approach */
"0D120J6" = "1" /* Bypass Middle Esophagus to Stomach with Synthetic Substitute, Open Approach */
"0D120J9" = "1" /* Bypass Middle Esophagus to Duodenum with Synthetic Substitute, Open Approach */
"0D120JA" = "1" /* Bypass Middle Esophagus to Jejunum with Synthetic Substitute, Open Approach */
"0D120JB" = "1" /* Bypass Middle Esophagus to Ileum with Synthetic Substitute, Open Approach */
"0D120K4" = "1" /* Bypass Middle Esophagus to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D120K6" = "1" /* Bypass Middle Esophagus to Stomach with Nonautologous Tissue Substitute, Open Approach */
"0D120K9" = "1" /* Bypass Middle Esophagus to Duodenum with Nonautologous Tissue Substitute, Open Approach */
"0D120KA" = "1" /* Bypass Middle Esophagus to Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0D120KB" = "1" /* Bypass Middle Esophagus to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D120Z4" = "1" /* Bypass Middle Esophagus to Cutaneous, Open Approach */
"0D120Z6" = "1" /* Bypass Middle Esophagus to Stomach, Open Approach */
"0D120Z9" = "1" /* Bypass Middle Esophagus to Duodenum, Open Approach */
"0D120ZA" = "1" /* Bypass Middle Esophagus to Jejunum, Open Approach */
"0D120ZB" = "1" /* Bypass Middle Esophagus to Ileum, Open Approach */
"0D123J4" = "1" /* Bypass Middle Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D12474" = "1" /* Bypass Middle Esophagus to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D12476" = "1" /* Bypass Middle Esophagus to Stomach with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D12479" = "1" /* Bypass Middle Esophagus to Duodenum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1247A" = "1" /* Bypass Middle Esophagus to Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1247B" = "1" /* Bypass Middle Esophagus to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D124J4" = "1" /* Bypass Middle Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D124J6" = "1" /* Bypass Middle Esophagus to Stomach with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D124J9" = "1" /* Bypass Middle Esophagus to Duodenum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D124JA" = "1" /* Bypass Middle Esophagus to Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D124JB" = "1" /* Bypass Middle Esophagus to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D124K4" = "1" /* Bypass Middle Esophagus to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D124K6" = "1" /* Bypass Middle Esophagus to Stomach with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D124K9" = "1" /* Bypass Middle Esophagus to Duodenum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D124KA" = "1" /* Bypass Middle Esophagus to Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D124KB" = "1" /* Bypass Middle Esophagus to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D124Z4" = "1" /* Bypass Middle Esophagus to Cutaneous, Percutaneous Endoscopic Approach */
"0D124Z6" = "1" /* Bypass Middle Esophagus to Stomach, Percutaneous Endoscopic Approach */
"0D124Z9" = "1" /* Bypass Middle Esophagus to Duodenum, Percutaneous Endoscopic Approach */
"0D124ZA" = "1" /* Bypass Middle Esophagus to Jejunum, Percutaneous Endoscopic Approach */
"0D124ZB" = "1" /* Bypass Middle Esophagus to Ileum, Percutaneous Endoscopic Approach */
"0D12874" = "1" /* Bypass Middle Esophagus to Cutaneous with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D12876" = "1" /* Bypass Middle Esophagus to Stomach with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D12879" = "1" /* Bypass Middle Esophagus to Duodenum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1287A" = "1" /* Bypass Middle Esophagus to Jejunum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1287B" = "1" /* Bypass Middle Esophagus to Ileum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128J4" = "1" /* Bypass Middle Esophagus to Cutaneous with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128J6" = "1" /* Bypass Middle Esophagus to Stomach with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128J9" = "1" /* Bypass Middle Esophagus to Duodenum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128JA" = "1" /* Bypass Middle Esophagus to Jejunum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128JB" = "1" /* Bypass Middle Esophagus to Ileum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128K4" = "1" /* Bypass Middle Esophagus to Cutaneous with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128K6" = "1" /* Bypass Middle Esophagus to Stomach with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128K9" = "1" /* Bypass Middle Esophagus to Duodenum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128KA" = "1" /* Bypass Middle Esophagus to Jejunum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128KB" = "1" /* Bypass Middle Esophagus to Ileum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D128Z4" = "1" /* Bypass Middle Esophagus to Cutaneous, Via Natural or Artificial Opening Endoscopic */
"0D128Z6" = "1" /* Bypass Middle Esophagus to Stomach, Via Natural or Artificial Opening Endoscopic */
"0D128Z9" = "1" /* Bypass Middle Esophagus to Duodenum, Via Natural or Artificial Opening Endoscopic */
"0D128ZA" = "1" /* Bypass Middle Esophagus to Jejunum, Via Natural or Artificial Opening Endoscopic */
"0D128ZB" = "1" /* Bypass Middle Esophagus to Ileum, Via Natural or Artificial Opening Endoscopic */
"0D13074" = "1" /* Bypass Lower Esophagus to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D13076" = "1" /* Bypass Lower Esophagus to Stomach with Autologous Tissue Substitute, Open Approach */
"0D13079" = "1" /* Bypass Lower Esophagus to Duodenum with Autologous Tissue Substitute, Open Approach */
"0D1307A" = "1" /* Bypass Lower Esophagus to Jejunum with Autologous Tissue Substitute, Open Approach */
"0D1307B" = "1" /* Bypass Lower Esophagus to Ileum with Autologous Tissue Substitute, Open Approach */
"0D130J4" = "1" /* Bypass Lower Esophagus to Cutaneous with Synthetic Substitute, Open Approach */
"0D130J6" = "1" /* Bypass Lower Esophagus to Stomach with Synthetic Substitute, Open Approach */
"0D130J9" = "1" /* Bypass Lower Esophagus to Duodenum with Synthetic Substitute, Open Approach */
"0D130JA" = "1" /* Bypass Lower Esophagus to Jejunum with Synthetic Substitute, Open Approach */
"0D130JB" = "1" /* Bypass Lower Esophagus to Ileum with Synthetic Substitute, Open Approach */
"0D130K4" = "1" /* Bypass Lower Esophagus to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D130K6" = "1" /* Bypass Lower Esophagus to Stomach with Nonautologous Tissue Substitute, Open Approach */
"0D130K9" = "1" /* Bypass Lower Esophagus to Duodenum with Nonautologous Tissue Substitute, Open Approach */
"0D130KA" = "1" /* Bypass Lower Esophagus to Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0D130KB" = "1" /* Bypass Lower Esophagus to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D130Z4" = "1" /* Bypass Lower Esophagus to Cutaneous, Open Approach */
"0D130Z6" = "1" /* Bypass Lower Esophagus to Stomach, Open Approach */
"0D130Z9" = "1" /* Bypass Lower Esophagus to Duodenum, Open Approach */
"0D130ZA" = "1" /* Bypass Lower Esophagus to Jejunum, Open Approach */
"0D130ZB" = "1" /* Bypass Lower Esophagus to Ileum, Open Approach */
"0D133J4" = "1" /* Bypass Lower Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D13474" = "1" /* Bypass Lower Esophagus to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D13476" = "1" /* Bypass Lower Esophagus to Stomach with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D13479" = "1" /* Bypass Lower Esophagus to Duodenum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1347A" = "1" /* Bypass Lower Esophagus to Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1347B" = "1" /* Bypass Lower Esophagus to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134J4" = "1" /* Bypass Lower Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D134J6" = "1" /* Bypass Lower Esophagus to Stomach with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D134J9" = "1" /* Bypass Lower Esophagus to Duodenum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D134JA" = "1" /* Bypass Lower Esophagus to Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D134JB" = "1" /* Bypass Lower Esophagus to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D134K4" = "1" /* Bypass Lower Esophagus to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134K6" = "1" /* Bypass Lower Esophagus to Stomach with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134K9" = "1" /* Bypass Lower Esophagus to Duodenum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134KA" = "1" /* Bypass Lower Esophagus to Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134KB" = "1" /* Bypass Lower Esophagus to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D134Z4" = "1" /* Bypass Lower Esophagus to Cutaneous, Percutaneous Endoscopic Approach */
"0D134Z6" = "1" /* Bypass Lower Esophagus to Stomach, Percutaneous Endoscopic Approach */
"0D134Z9" = "1" /* Bypass Lower Esophagus to Duodenum, Percutaneous Endoscopic Approach */
"0D134ZA" = "1" /* Bypass Lower Esophagus to Jejunum, Percutaneous Endoscopic Approach */
"0D134ZB" = "1" /* Bypass Lower Esophagus to Ileum, Percutaneous Endoscopic Approach */
"0D13874" = "1" /* Bypass Lower Esophagus to Cutaneous with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D13876" = "1" /* Bypass Lower Esophagus to Stomach with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D13879" = "1" /* Bypass Lower Esophagus to Duodenum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1387A" = "1" /* Bypass Lower Esophagus to Jejunum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1387B" = "1" /* Bypass Lower Esophagus to Ileum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138J4" = "1" /* Bypass Lower Esophagus to Cutaneous with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138J6" = "1" /* Bypass Lower Esophagus to Stomach with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138J9" = "1" /* Bypass Lower Esophagus to Duodenum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138JA" = "1" /* Bypass Lower Esophagus to Jejunum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138JB" = "1" /* Bypass Lower Esophagus to Ileum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138K4" = "1" /* Bypass Lower Esophagus to Cutaneous with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138K6" = "1" /* Bypass Lower Esophagus to Stomach with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138K9" = "1" /* Bypass Lower Esophagus to Duodenum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138KA" = "1" /* Bypass Lower Esophagus to Jejunum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138KB" = "1" /* Bypass Lower Esophagus to Ileum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D138Z4" = "1" /* Bypass Lower Esophagus to Cutaneous, Via Natural or Artificial Opening Endoscopic */
"0D138Z6" = "1" /* Bypass Lower Esophagus to Stomach, Via Natural or Artificial Opening Endoscopic */
"0D138Z9" = "1" /* Bypass Lower Esophagus to Duodenum, Via Natural or Artificial Opening Endoscopic */
"0D138ZA" = "1" /* Bypass Lower Esophagus to Jejunum, Via Natural or Artificial Opening Endoscopic */
"0D138ZB" = "1" /* Bypass Lower Esophagus to Ileum, Via Natural or Artificial Opening Endoscopic */
"0D15074" = "1" /* Bypass Esophagus to Cutaneous with Autologous Tissue Substitute, Open Approach */
"0D15076" = "1" /* Bypass Esophagus to Stomach with Autologous Tissue Substitute, Open Approach */
"0D15079" = "1" /* Bypass Esophagus to Duodenum with Autologous Tissue Substitute, Open Approach */
"0D1507A" = "1" /* Bypass Esophagus to Jejunum with Autologous Tissue Substitute, Open Approach */
"0D1507B" = "1" /* Bypass Esophagus to Ileum with Autologous Tissue Substitute, Open Approach */
"0D150J4" = "1" /* Bypass Esophagus to Cutaneous with Synthetic Substitute, Open Approach */
"0D150J6" = "1" /* Bypass Esophagus to Stomach with Synthetic Substitute, Open Approach */
"0D150J9" = "1" /* Bypass Esophagus to Duodenum with Synthetic Substitute, Open Approach */
"0D150JA" = "1" /* Bypass Esophagus to Jejunum with Synthetic Substitute, Open Approach */
"0D150JB" = "1" /* Bypass Esophagus to Ileum with Synthetic Substitute, Open Approach */
"0D150K4" = "1" /* Bypass Esophagus to Cutaneous with Nonautologous Tissue Substitute, Open Approach */
"0D150K6" = "1" /* Bypass Esophagus to Stomach with Nonautologous Tissue Substitute, Open Approach */
"0D150K9" = "1" /* Bypass Esophagus to Duodenum with Nonautologous Tissue Substitute, Open Approach */
"0D150KA" = "1" /* Bypass Esophagus to Jejunum with Nonautologous Tissue Substitute, Open Approach */
"0D150KB" = "1" /* Bypass Esophagus to Ileum with Nonautologous Tissue Substitute, Open Approach */
"0D150Z4" = "1" /* Bypass Esophagus to Cutaneous, Open Approach */
"0D150Z6" = "1" /* Bypass Esophagus to Stomach, Open Approach */
"0D150Z9" = "1" /* Bypass Esophagus to Duodenum, Open Approach */
"0D150ZA" = "1" /* Bypass Esophagus to Jejunum, Open Approach */
"0D150ZB" = "1" /* Bypass Esophagus to Ileum, Open Approach */
"0D153J4" = "1" /* Bypass Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0D15474" = "1" /* Bypass Esophagus to Cutaneous with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D15476" = "1" /* Bypass Esophagus to Stomach with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D15479" = "1" /* Bypass Esophagus to Duodenum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1547A" = "1" /* Bypass Esophagus to Jejunum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D1547B" = "1" /* Bypass Esophagus to Ileum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D154J4" = "1" /* Bypass Esophagus to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D154J6" = "1" /* Bypass Esophagus to Stomach with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D154J9" = "1" /* Bypass Esophagus to Duodenum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D154JA" = "1" /* Bypass Esophagus to Jejunum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D154JB" = "1" /* Bypass Esophagus to Ileum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0D154K4" = "1" /* Bypass Esophagus to Cutaneous with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D154K6" = "1" /* Bypass Esophagus to Stomach with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D154K9" = "1" /* Bypass Esophagus to Duodenum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D154KA" = "1" /* Bypass Esophagus to Jejunum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D154KB" = "1" /* Bypass Esophagus to Ileum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0D154Z4" = "1" /* Bypass Esophagus to Cutaneous, Percutaneous Endoscopic Approach */
"0D154Z6" = "1" /* Bypass Esophagus to Stomach, Percutaneous Endoscopic Approach */
"0D154Z9" = "1" /* Bypass Esophagus to Duodenum, Percutaneous Endoscopic Approach */
"0D154ZA" = "1" /* Bypass Esophagus to Jejunum, Percutaneous Endoscopic Approach */
"0D154ZB" = "1" /* Bypass Esophagus to Ileum, Percutaneous Endoscopic Approach */
"0D15874" = "1" /* Bypass Esophagus to Cutaneous with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D15876" = "1" /* Bypass Esophagus to Stomach with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D15879" = "1" /* Bypass Esophagus to Duodenum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1587A" = "1" /* Bypass Esophagus to Jejunum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D1587B" = "1" /* Bypass Esophagus to Ileum with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158J4" = "1" /* Bypass Esophagus to Cutaneous with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158J6" = "1" /* Bypass Esophagus to Stomach with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158J9" = "1" /* Bypass Esophagus to Duodenum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158JA" = "1" /* Bypass Esophagus to Jejunum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158JB" = "1" /* Bypass Esophagus to Ileum with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158K4" = "1" /* Bypass Esophagus to Cutaneous with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158K6" = "1" /* Bypass Esophagus to Stomach with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158K9" = "1" /* Bypass Esophagus to Duodenum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158KA" = "1" /* Bypass Esophagus to Jejunum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158KB" = "1" /* Bypass Esophagus to Ileum with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0D158Z4" = "1" /* Bypass Esophagus to Cutaneous, Via Natural or Artificial Opening Endoscopic */
"0D158Z6" = "1" /* Bypass Esophagus to Stomach, Via Natural or Artificial Opening Endoscopic */
"0D158Z9" = "1" /* Bypass Esophagus to Duodenum, Via Natural or Artificial Opening Endoscopic */
"0D158ZA" = "1" /* Bypass Esophagus to Jejunum, Via Natural or Artificial Opening Endoscopic */
"0D158ZB" = "1" /* Bypass Esophagus to Ileum, Via Natural or Artificial Opening Endoscopic */
"0D510ZZ" = "1" /* Destruction of Upper Esophagus, Open Approach */
"0D513ZZ" = "1" /* Destruction of Upper Esophagus, Percutaneous Approach */
"0D517ZZ" = "1" /* Destruction of Upper Esophagus, Via Natural or Artificial Opening */
"0D520ZZ" = "1" /* Destruction of Middle Esophagus, Open Approach */
"0D523ZZ" = "1" /* Destruction of Middle Esophagus, Percutaneous Approach */
"0D527ZZ" = "1" /* Destruction of Middle Esophagus, Via Natural or Artificial Opening */
"0D530ZZ" = "1" /* Destruction of Lower Esophagus, Open Approach */
"0D533ZZ" = "1" /* Destruction of Lower Esophagus, Percutaneous Approach */
"0D537ZZ" = "1" /* Destruction of Lower Esophagus, Via Natural or Artificial Opening */
"0D540ZZ" = "1" /* Destruction of Esophagogastric Junction, Open Approach */
"0D543ZZ" = "1" /* Destruction of Esophagogastric Junction, Percutaneous Approach */
"0D547ZZ" = "1" /* Destruction of Esophagogastric Junction, Via Natural or Artificial Opening */
"0D550ZZ" = "1" /* Destruction of Esophagus, Open Approach */
"0D553ZZ" = "1" /* Destruction of Esophagus, Percutaneous Approach */
"0D557ZZ" = "1" /* Destruction of Esophagus, Via Natural or Artificial Opening */
"0D710DZ" = "1" /* Dilation of Upper Esophagus with Intraluminal Device, Open Approach */
"0D710ZZ" = "1" /* Dilation of Upper Esophagus, Open Approach */
"0D713DZ" = "1" /* Dilation of Upper Esophagus with Intraluminal Device, Percutaneous Approach */
"0D713ZZ" = "1" /* Dilation of Upper Esophagus, Percutaneous Approach */
"0D714DZ" = "1" /* Dilation of Upper Esophagus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D714ZZ" = "1" /* Dilation of Upper Esophagus, Percutaneous Endoscopic Approach */
"0D720DZ" = "1" /* Dilation of Middle Esophagus with Intraluminal Device, Open Approach */
"0D720ZZ" = "1" /* Dilation of Middle Esophagus, Open Approach */
"0D723DZ" = "1" /* Dilation of Middle Esophagus with Intraluminal Device, Percutaneous Approach */
"0D723ZZ" = "1" /* Dilation of Middle Esophagus, Percutaneous Approach */
"0D724DZ" = "1" /* Dilation of Middle Esophagus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D724ZZ" = "1" /* Dilation of Middle Esophagus, Percutaneous Endoscopic Approach */
"0D730DZ" = "1" /* Dilation of Lower Esophagus with Intraluminal Device, Open Approach */
"0D730ZZ" = "1" /* Dilation of Lower Esophagus, Open Approach */
"0D733DZ" = "1" /* Dilation of Lower Esophagus with Intraluminal Device, Percutaneous Approach */
"0D733ZZ" = "1" /* Dilation of Lower Esophagus, Percutaneous Approach */
"0D734DZ" = "1" /* Dilation of Lower Esophagus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D734ZZ" = "1" /* Dilation of Lower Esophagus, Percutaneous Endoscopic Approach */
"0D740DZ" = "1" /* Dilation of Esophagogastric Junction with Intraluminal Device, Open Approach */
"0D740ZZ" = "1" /* Dilation of Esophagogastric Junction, Open Approach */
"0D743DZ" = "1" /* Dilation of Esophagogastric Junction with Intraluminal Device, Percutaneous Approach */
"0D743ZZ" = "1" /* Dilation of Esophagogastric Junction, Percutaneous Approach */
"0D744DZ" = "1" /* Dilation of Esophagogastric Junction with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D744ZZ" = "1" /* Dilation of Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0D750DZ" = "1" /* Dilation of Esophagus with Intraluminal Device, Open Approach */
"0D750ZZ" = "1" /* Dilation of Esophagus, Open Approach */
"0D753DZ" = "1" /* Dilation of Esophagus with Intraluminal Device, Percutaneous Approach */
"0D753ZZ" = "1" /* Dilation of Esophagus, Percutaneous Approach */
"0D754DZ" = "1" /* Dilation of Esophagus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0D754ZZ" = "1" /* Dilation of Esophagus, Percutaneous Endoscopic Approach */
"0D840ZZ" = "1" /* Division of Esophagogastric Junction, Open Approach */
"0D843ZZ" = "1" /* Division of Esophagogastric Junction, Percutaneous Approach */
"0D844ZZ" = "1" /* Division of Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0D847ZZ" = "1" /* Division of Esophagogastric Junction, Via Natural or Artificial Opening */
"0D848ZZ" = "1" /* Division of Esophagogastric Junction, Via Natural or Artificial Opening Endoscopic */
"0D9100Z" = "1" /* Drainage of Upper Esophagus with Drainage Device, Open Approach */
"0D910ZX" = "1" /* Drainage of Upper Esophagus, Open Approach, Diagnostic */
"0D910ZZ" = "1" /* Drainage of Upper Esophagus, Open Approach */
"0D9130Z" = "1" /* Drainage of Upper Esophagus with Drainage Device, Percutaneous Approach */
"0D913ZZ" = "1" /* Drainage of Upper Esophagus, Percutaneous Approach */
"0D9140Z" = "1" /* Drainage of Upper Esophagus with Drainage Device, Percutaneous Endoscopic Approach */
"0D914ZZ" = "1" /* Drainage of Upper Esophagus, Percutaneous Endoscopic Approach */
"0D9170Z" = "1" /* Drainage of Upper Esophagus with Drainage Device, Via Natural or Artificial Opening */
"0D917ZZ" = "1" /* Drainage of Upper Esophagus, Via Natural or Artificial Opening */
"0D9180Z" = "1" /* Drainage of Upper Esophagus with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0D918ZZ" = "1" /* Drainage of Upper Esophagus, Via Natural or Artificial Opening Endoscopic */
"0D9200Z" = "1" /* Drainage of Middle Esophagus with Drainage Device, Open Approach */
"0D920ZX" = "1" /* Drainage of Middle Esophagus, Open Approach, Diagnostic */
"0D920ZZ" = "1" /* Drainage of Middle Esophagus, Open Approach */
"0D9230Z" = "1" /* Drainage of Middle Esophagus with Drainage Device, Percutaneous Approach */
"0D923ZZ" = "1" /* Drainage of Middle Esophagus, Percutaneous Approach */
"0D9240Z" = "1" /* Drainage of Middle Esophagus with Drainage Device, Percutaneous Endoscopic Approach */
"0D924ZZ" = "1" /* Drainage of Middle Esophagus, Percutaneous Endoscopic Approach */
"0D9270Z" = "1" /* Drainage of Middle Esophagus with Drainage Device, Via Natural or Artificial Opening */
"0D927ZZ" = "1" /* Drainage of Middle Esophagus, Via Natural or Artificial Opening */
"0D9280Z" = "1" /* Drainage of Middle Esophagus with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0D928ZZ" = "1" /* Drainage of Middle Esophagus, Via Natural or Artificial Opening Endoscopic */
"0D9300Z" = "1" /* Drainage of Lower Esophagus with Drainage Device, Open Approach */
"0D930ZX" = "1" /* Drainage of Lower Esophagus, Open Approach, Diagnostic */
"0D930ZZ" = "1" /* Drainage of Lower Esophagus, Open Approach */
"0D9330Z" = "1" /* Drainage of Lower Esophagus with Drainage Device, Percutaneous Approach */
"0D933ZZ" = "1" /* Drainage of Lower Esophagus, Percutaneous Approach */
"0D9340Z" = "1" /* Drainage of Lower Esophagus with Drainage Device, Percutaneous Endoscopic Approach */
"0D934ZZ" = "1" /* Drainage of Lower Esophagus, Percutaneous Endoscopic Approach */
"0D9370Z" = "1" /* Drainage of Lower Esophagus with Drainage Device, Via Natural or Artificial Opening */
"0D937ZZ" = "1" /* Drainage of Lower Esophagus, Via Natural or Artificial Opening */
"0D9380Z" = "1" /* Drainage of Lower Esophagus with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0D938ZZ" = "1" /* Drainage of Lower Esophagus, Via Natural or Artificial Opening Endoscopic */
"0D9400Z" = "1" /* Drainage of Esophagogastric Junction with Drainage Device, Open Approach */
"0D940ZX" = "1" /* Drainage of Esophagogastric Junction, Open Approach, Diagnostic */
"0D940ZZ" = "1" /* Drainage of Esophagogastric Junction, Open Approach */
"0D9430Z" = "1" /* Drainage of Esophagogastric Junction with Drainage Device, Percutaneous Approach */
"0D943ZZ" = "1" /* Drainage of Esophagogastric Junction, Percutaneous Approach */
"0D9440Z" = "1" /* Drainage of Esophagogastric Junction with Drainage Device, Percutaneous Endoscopic Approach */
"0D944ZZ" = "1" /* Drainage of Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0D9470Z" = "1" /* Drainage of Esophagogastric Junction with Drainage Device, Via Natural or Artificial Opening */
"0D947ZZ" = "1" /* Drainage of Esophagogastric Junction, Via Natural or Artificial Opening */
"0D9480Z" = "1" /* Drainage of Esophagogastric Junction with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0D948ZZ" = "1" /* Drainage of Esophagogastric Junction, Via Natural or Artificial Opening Endoscopic */
"0D9500Z" = "1" /* Drainage of Esophagus with Drainage Device, Open Approach */
"0D950ZX" = "1" /* Drainage of Esophagus, Open Approach, Diagnostic */
"0D950ZZ" = "1" /* Drainage of Esophagus, Open Approach */
"0D9530Z" = "1" /* Drainage of Esophagus with Drainage Device, Percutaneous Approach */
"0D953ZZ" = "1" /* Drainage of Esophagus, Percutaneous Approach */
"0D9540Z" = "1" /* Drainage of Esophagus with Drainage Device, Percutaneous Endoscopic Approach */
"0D954ZZ" = "1" /* Drainage of Esophagus, Percutaneous Endoscopic Approach */
"0D9570Z" = "1" /* Drainage of Esophagus with Drainage Device, Via Natural or Artificial Opening */
"0D957ZZ" = "1" /* Drainage of Esophagus, Via Natural or Artificial Opening */
"0D9580Z" = "1" /* Drainage of Esophagus with Drainage Device, Via Natural or Artificial Opening Endoscopic */
"0D958ZZ" = "1" /* Drainage of Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DB10ZX" = "1" /* Excision of Upper Esophagus, Open Approach, Diagnostic */
"0DB10ZZ" = "1" /* Excision of Upper Esophagus, Open Approach */
"0DB13ZZ" = "1" /* Excision of Upper Esophagus, Percutaneous Approach */
"0DB17ZZ" = "1" /* Excision of Upper Esophagus, Via Natural or Artificial Opening */
"0DB20ZX" = "1" /* Excision of Middle Esophagus, Open Approach, Diagnostic */
"0DB20ZZ" = "1" /* Excision of Middle Esophagus, Open Approach */
"0DB23ZZ" = "1" /* Excision of Middle Esophagus, Percutaneous Approach */
"0DB27ZZ" = "1" /* Excision of Middle Esophagus, Via Natural or Artificial Opening */
"0DB30ZX" = "1" /* Excision of Lower Esophagus, Open Approach, Diagnostic */
"0DB30ZZ" = "1" /* Excision of Lower Esophagus, Open Approach */
"0DB33ZZ" = "1" /* Excision of Lower Esophagus, Percutaneous Approach */
"0DB37ZZ" = "1" /* Excision of Lower Esophagus, Via Natural or Artificial Opening */
"0DB40ZX" = "1" /* Excision of Esophagogastric Junction, Open Approach, Diagnostic */
"0DB40ZZ" = "1" /* Excision of Esophagogastric Junction, Open Approach */
"0DB43ZZ" = "1" /* Excision of Esophagogastric Junction, Percutaneous Approach */
"0DB44ZZ" = "1" /* Excision of Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0DB47ZZ" = "1" /* Excision of Esophagogastric Junction, Via Natural or Artificial Opening */
"0DB50ZX" = "1" /* Excision of Esophagus, Open Approach, Diagnostic */
"0DB50ZZ" = "1" /* Excision of Esophagus, Open Approach */
"0DB53ZZ" = "1" /* Excision of Esophagus, Percutaneous Approach */
"0DB57ZZ" = "1" /* Excision of Esophagus, Via Natural or Artificial Opening */
"0DC10ZZ" = "1" /* Extirpation of Matter from Upper Esophagus, Open Approach */
"0DC13ZZ" = "1" /* Extirpation of Matter from Upper Esophagus, Percutaneous Approach */
"0DC14ZZ" = "1" /* Extirpation of Matter from Upper Esophagus, Percutaneous Endoscopic Approach */
"0DC20ZZ" = "1" /* Extirpation of Matter from Middle Esophagus, Open Approach */
"0DC23ZZ" = "1" /* Extirpation of Matter from Middle Esophagus, Percutaneous Approach */
"0DC24ZZ" = "1" /* Extirpation of Matter from Middle Esophagus, Percutaneous Endoscopic Approach */
"0DC30ZZ" = "1" /* Extirpation of Matter from Lower Esophagus, Open Approach */
"0DC33ZZ" = "1" /* Extirpation of Matter from Lower Esophagus, Percutaneous Approach */
"0DC34ZZ" = "1" /* Extirpation of Matter from Lower Esophagus, Percutaneous Endoscopic Approach */
"0DC40ZZ" = "1" /* Extirpation of Matter from Esophagogastric Junction, Open Approach */
"0DC43ZZ" = "1" /* Extirpation of Matter from Esophagogastric Junction, Percutaneous Approach */
"0DC44ZZ" = "1" /* Extirpation of Matter from Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0DC50ZZ" = "1" /* Extirpation of Matter from Esophagus, Open Approach */
"0DC53ZZ" = "1" /* Extirpation of Matter from Esophagus, Percutaneous Approach */
"0DC54ZZ" = "1" /* Extirpation of Matter from Esophagus, Percutaneous Endoscopic Approach */
"0DF50ZZ" = "1" /* Fragmentation in Esophagus, Open Approach */
"0DF53ZZ" = "1" /* Fragmentation in Esophagus, Percutaneous Approach */
"0DF54ZZ" = "1" /* Fragmentation in Esophagus, Percutaneous Endoscopic Approach */
"0DF57ZZ" = "1" /* Fragmentation in Esophagus, Via Natural or Artificial Opening */
"0DF58ZZ" = "1" /* Fragmentation in Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DH502Z" = "1" /* Insertion of Monitoring Device into Esophagus, Open Approach */
"0DH503Z" = "1" /* Insertion of Infusion Device into Esophagus, Open Approach */
"0DH50DZ" = "1" /* Insertion of Intraluminal Device into Esophagus, Open Approach */
"0DH50UZ" = "1" /* Insertion of Feeding Device into Esophagus, Open Approach */
"0DH532Z" = "1" /* Insertion of Monitoring Device into Esophagus, Percutaneous Approach */
"0DH533Z" = "1" /* Insertion of Infusion Device into Esophagus, Percutaneous Approach */
"0DH53DZ" = "1" /* Insertion of Intraluminal Device into Esophagus, Percutaneous Approach */
"0DH53UZ" = "1" /* Insertion of Feeding Device into Esophagus, Percutaneous Approach */
"0DH542Z" = "1" /* Insertion of Monitoring Device into Esophagus, Percutaneous Endoscopic Approach */
"0DH543Z" = "1" /* Insertion of Infusion Device into Esophagus, Percutaneous Endoscopic Approach */
"0DH54DZ" = "1" /* Insertion of Intraluminal Device into Esophagus, Percutaneous Endoscopic Approach */
"0DH54UZ" = "1" /* Insertion of Feeding Device into Esophagus, Percutaneous Endoscopic Approach */
"0DH572Z" = "1" /* Insertion of Monitoring Device into Esophagus, Via Natural or Artificial Opening */
"0DH573Z" = "1" /* Insertion of Infusion Device into Esophagus, Via Natural or Artificial Opening */
"0DH57DZ" = "1" /* Insertion of Intraluminal Device into Esophagus, Via Natural or Artificial Opening */
"0DH57UZ" = "1" /* Insertion of Feeding Device into Esophagus, Via Natural or Artificial Opening */
"0DH582Z" = "1" /* Insertion of Monitoring Device into Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DH583Z" = "1" /* Insertion of Infusion Device into Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DH58DZ" = "1" /* Insertion of Intraluminal Device into Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DH58UZ" = "1" /* Insertion of Feeding Device into Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DJ04ZZ" = "1" /* Inspection of Upper Intestinal Tract, Percutaneous Endoscopic Approach */
"0DM50ZZ" = "1" /* Reattachment of Esophagus, Open Approach */
"0DM54ZZ" = "1" /* Reattachment of Esophagus, Percutaneous Endoscopic Approach */
"0DN10ZZ" = "1" /* Release Upper Esophagus, Open Approach */
"0DN13ZZ" = "1" /* Release Upper Esophagus, Percutaneous Approach */
"0DN14ZZ" = "1" /* Release Upper Esophagus, Percutaneous Endoscopic Approach */
"0DN17ZZ" = "1" /* Release Upper Esophagus, Via Natural or Artificial Opening */
"0DN18ZZ" = "1" /* Release Upper Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DN20ZZ" = "1" /* Release Middle Esophagus, Open Approach */
"0DN23ZZ" = "1" /* Release Middle Esophagus, Percutaneous Approach */
"0DN24ZZ" = "1" /* Release Middle Esophagus, Percutaneous Endoscopic Approach */
"0DN27ZZ" = "1" /* Release Middle Esophagus, Via Natural or Artificial Opening */
"0DN28ZZ" = "1" /* Release Middle Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DN30ZZ" = "1" /* Release Lower Esophagus, Open Approach */
"0DN33ZZ" = "1" /* Release Lower Esophagus, Percutaneous Approach */
"0DN34ZZ" = "1" /* Release Lower Esophagus, Percutaneous Endoscopic Approach */
"0DN37ZZ" = "1" /* Release Lower Esophagus, Via Natural or Artificial Opening */
"0DN38ZZ" = "1" /* Release Lower Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DN40ZZ" = "1" /* Release Esophagogastric Junction, Open Approach */
"0DN43ZZ" = "1" /* Release Esophagogastric Junction, Percutaneous Approach */
"0DN44ZZ" = "1" /* Release Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0DN47ZZ" = "1" /* Release Esophagogastric Junction, Via Natural or Artificial Opening */
"0DN48ZZ" = "1" /* Release Esophagogastric Junction, Via Natural or Artificial Opening Endoscopic */
"0DN50ZZ" = "1" /* Release Esophagus, Open Approach */
"0DN53ZZ" = "1" /* Release Esophagus, Percutaneous Approach */
"0DN54ZZ" = "1" /* Release Esophagus, Percutaneous Endoscopic Approach */
"0DN57ZZ" = "1" /* Release Esophagus, Via Natural or Artificial Opening */
"0DN58ZZ" = "1" /* Release Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DP501Z" = "1" /* Removal of Radioactive Element from Esophagus, Open Approach */
"0DP502Z" = "1" /* Removal of Monitoring Device from Esophagus, Open Approach */
"0DP503Z" = "1" /* Removal of Infusion Device from Esophagus, Open Approach */
"0DP50UZ" = "1" /* Removal of Feeding Device from Esophagus, Open Approach */
"0DP531Z" = "1" /* Removal of Radioactive Element from Esophagus, Percutaneous Approach */
"0DP532Z" = "1" /* Removal of Monitoring Device from Esophagus, Percutaneous Approach */
"0DP533Z" = "1" /* Removal of Infusion Device from Esophagus, Percutaneous Approach */
"0DP53UZ" = "1" /* Removal of Feeding Device from Esophagus, Percutaneous Approach */
"0DP541Z" = "1" /* Removal of Radioactive Element from Esophagus, Percutaneous Endoscopic Approach */
"0DP542Z" = "1" /* Removal of Monitoring Device from Esophagus, Percutaneous Endoscopic Approach */
"0DP543Z" = "1" /* Removal of Infusion Device from Esophagus, Percutaneous Endoscopic Approach */
"0DP54UZ" = "1" /* Removal of Feeding Device from Esophagus, Percutaneous Endoscopic Approach */
"0DP57DZ" = "1" /* Removal of Intraluminal Device from Esophagus, Via Natural or Artificial Opening */
"0DP58DZ" = "1" /* Removal of Intraluminal Device from Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DQ10ZZ" = "1" /* Repair Upper Esophagus, Open Approach */
"0DQ13ZZ" = "1" /* Repair Upper Esophagus, Percutaneous Approach */
"0DQ14ZZ" = "1" /* Repair Upper Esophagus, Percutaneous Endoscopic Approach */
"0DQ17ZZ" = "1" /* Repair Upper Esophagus, Via Natural or Artificial Opening */
"0DQ18ZZ" = "1" /* Repair Upper Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DQ20ZZ" = "1" /* Repair Middle Esophagus, Open Approach */
"0DQ23ZZ" = "1" /* Repair Middle Esophagus, Percutaneous Approach */
"0DQ24ZZ" = "1" /* Repair Middle Esophagus, Percutaneous Endoscopic Approach */
"0DQ27ZZ" = "1" /* Repair Middle Esophagus, Via Natural or Artificial Opening */
"0DQ28ZZ" = "1" /* Repair Middle Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DQ30ZZ" = "1" /* Repair Lower Esophagus, Open Approach */
"0DQ33ZZ" = "1" /* Repair Lower Esophagus, Percutaneous Approach */
"0DQ34ZZ" = "1" /* Repair Lower Esophagus, Percutaneous Endoscopic Approach */
"0DQ37ZZ" = "1" /* Repair Lower Esophagus, Via Natural or Artificial Opening */
"0DQ38ZZ" = "1" /* Repair Lower Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DQ40ZZ" = "1" /* Repair Esophagogastric Junction, Open Approach */
"0DQ43ZZ" = "1" /* Repair Esophagogastric Junction, Percutaneous Approach */
"0DQ44ZZ" = "1" /* Repair Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0DQ47ZZ" = "1" /* Repair Esophagogastric Junction, Via Natural or Artificial Opening */
"0DQ48ZZ" = "1" /* Repair Esophagogastric Junction, Via Natural or Artificial Opening Endoscopic */
"0DQ50ZZ" = "1" /* Repair Esophagus, Open Approach */
"0DQ53ZZ" = "1" /* Repair Esophagus, Percutaneous Approach */
"0DQ54ZZ" = "1" /* Repair Esophagus, Percutaneous Endoscopic Approach */
"0DQ57ZZ" = "1" /* Repair Esophagus, Via Natural or Artificial Opening */
"0DQ58ZZ" = "1" /* Repair Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DR507Z" = "1" /* Replacement of Esophagus with Autologous Tissue Substitute, Open Approach */
"0DR50JZ" = "1" /* Replacement of Esophagus with Synthetic Substitute, Open Approach */
"0DR50KZ" = "1" /* Replacement of Esophagus with Nonautologous Tissue Substitute, Open Approach */
"0DR547Z" = "1" /* Replacement of Esophagus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DR54JZ" = "1" /* Replacement of Esophagus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DR54KZ" = "1" /* Replacement of Esophagus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DR577Z" = "1" /* Replacement of Esophagus with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DR57JZ" = "1" /* Replacement of Esophagus with Synthetic Substitute, Via Natural or Artificial Opening */
"0DR57KZ" = "1" /* Replacement of Esophagus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DR587Z" = "1" /* Replacement of Esophagus with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DR58JZ" = "1" /* Replacement of Esophagus with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DR58KZ" = "1" /* Replacement of Esophagus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DS50ZZ" = "1" /* Reposition Esophagus, Open Approach */
"0DS54ZZ" = "1" /* Reposition Esophagus, Percutaneous Endoscopic Approach */
"0DS57ZZ" = "1" /* Reposition Esophagus, Via Natural or Artificial Opening */
"0DS58ZZ" = "1" /* Reposition Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DS5XZZ" = "1" /* Reposition Esophagus, External Approach */
"0DT10ZZ" = "1" /* Resection of Upper Esophagus, Open Approach */
"0DT14ZZ" = "1" /* Resection of Upper Esophagus, Percutaneous Endoscopic Approach */
"0DT17ZZ" = "1" /* Resection of Upper Esophagus, Via Natural or Artificial Opening */
"0DT18ZZ" = "1" /* Resection of Upper Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DT20ZZ" = "1" /* Resection of Middle Esophagus, Open Approach */
"0DT24ZZ" = "1" /* Resection of Middle Esophagus, Percutaneous Endoscopic Approach */
"0DT27ZZ" = "1" /* Resection of Middle Esophagus, Via Natural or Artificial Opening */
"0DT28ZZ" = "1" /* Resection of Middle Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DT30ZZ" = "1" /* Resection of Lower Esophagus, Open Approach */
"0DT34ZZ" = "1" /* Resection of Lower Esophagus, Percutaneous Endoscopic Approach */
"0DT37ZZ" = "1" /* Resection of Lower Esophagus, Via Natural or Artificial Opening */
"0DT38ZZ" = "1" /* Resection of Lower Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DT40ZZ" = "1" /* Resection of Esophagogastric Junction, Open Approach */
"0DT44ZZ" = "1" /* Resection of Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0DT47ZZ" = "1" /* Resection of Esophagogastric Junction, Via Natural or Artificial Opening */
"0DT48ZZ" = "1" /* Resection of Esophagogastric Junction, Via Natural or Artificial Opening Endoscopic */
"0DT50ZZ" = "1" /* Resection of Esophagus, Open Approach */
"0DT54ZZ" = "1" /* Resection of Esophagus, Percutaneous Endoscopic Approach */
"0DT57ZZ" = "1" /* Resection of Esophagus, Via Natural or Artificial Opening */
"0DT58ZZ" = "1" /* Resection of Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DT60ZZ" = "1" /* Resection of Stomach, Open Approach */
"0DT64ZZ" = "1" /* Resection of Stomach, Percutaneous Endoscopic Approach */
"0DT67ZZ" = "1" /* Resection of Stomach, Via Natural or Artificial Opening */
"0DT68ZZ" = "1" /* Resection of Stomach, Via Natural or Artificial Opening Endoscopic */
"0DU107Z" = "1" /* Supplement Upper Esophagus with Autologous Tissue Substitute, Open Approach */
"0DU10JZ" = "1" /* Supplement Upper Esophagus with Synthetic Substitute, Open Approach */
"0DU10KZ" = "1" /* Supplement Upper Esophagus with Nonautologous Tissue Substitute, Open Approach */
"0DU147Z" = "1" /* Supplement Upper Esophagus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU14JZ" = "1" /* Supplement Upper Esophagus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DU14KZ" = "1" /* Supplement Upper Esophagus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU177Z" = "1" /* Supplement Upper Esophagus with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU17JZ" = "1" /* Supplement Upper Esophagus with Synthetic Substitute, Via Natural or Artificial Opening */
"0DU17KZ" = "1" /* Supplement Upper Esophagus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU187Z" = "1" /* Supplement Upper Esophagus with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU18JZ" = "1" /* Supplement Upper Esophagus with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU18KZ" = "1" /* Supplement Upper Esophagus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU207Z" = "1" /* Supplement Middle Esophagus with Autologous Tissue Substitute, Open Approach */
"0DU20JZ" = "1" /* Supplement Middle Esophagus with Synthetic Substitute, Open Approach */
"0DU20KZ" = "1" /* Supplement Middle Esophagus with Nonautologous Tissue Substitute, Open Approach */
"0DU247Z" = "1" /* Supplement Middle Esophagus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU24JZ" = "1" /* Supplement Middle Esophagus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DU24KZ" = "1" /* Supplement Middle Esophagus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU277Z" = "1" /* Supplement Middle Esophagus with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU27JZ" = "1" /* Supplement Middle Esophagus with Synthetic Substitute, Via Natural or Artificial Opening */
"0DU27KZ" = "1" /* Supplement Middle Esophagus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU287Z" = "1" /* Supplement Middle Esophagus with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU28JZ" = "1" /* Supplement Middle Esophagus with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU28KZ" = "1" /* Supplement Middle Esophagus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU307Z" = "1" /* Supplement Lower Esophagus with Autologous Tissue Substitute, Open Approach */
"0DU30JZ" = "1" /* Supplement Lower Esophagus with Synthetic Substitute, Open Approach */
"0DU30KZ" = "1" /* Supplement Lower Esophagus with Nonautologous Tissue Substitute, Open Approach */
"0DU347Z" = "1" /* Supplement Lower Esophagus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU34JZ" = "1" /* Supplement Lower Esophagus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DU34KZ" = "1" /* Supplement Lower Esophagus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU377Z" = "1" /* Supplement Lower Esophagus with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU37JZ" = "1" /* Supplement Lower Esophagus with Synthetic Substitute, Via Natural or Artificial Opening */
"0DU37KZ" = "1" /* Supplement Lower Esophagus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU387Z" = "1" /* Supplement Lower Esophagus with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU38JZ" = "1" /* Supplement Lower Esophagus with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU38KZ" = "1" /* Supplement Lower Esophagus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU407Z" = "1" /* Supplement Esophagogastric Junction with Autologous Tissue Substitute, Open Approach */
"0DU40JZ" = "1" /* Supplement Esophagogastric Junction with Synthetic Substitute, Open Approach */
"0DU40KZ" = "1" /* Supplement Esophagogastric Junction with Nonautologous Tissue Substitute, Open Approach */
"0DU447Z" = "1" /* Supplement Esophagogastric Junction with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU44JZ" = "1" /* Supplement Esophagogastric Junction with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DU44KZ" = "1" /* Supplement Esophagogastric Junction with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU477Z" = "1" /* Supplement Esophagogastric Junction with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU47JZ" = "1" /* Supplement Esophagogastric Junction with Synthetic Substitute, Via Natural or Artificial Opening */
"0DU47KZ" = "1" /* Supplement Esophagogastric Junction with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU487Z" = "1" /* Supplement Esophagogastric Junction with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU48JZ" = "1" /* Supplement Esophagogastric Junction with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU48KZ" = "1" /* Supplement Esophagogastric Junction with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU507Z" = "1" /* Supplement Esophagus with Autologous Tissue Substitute, Open Approach */
"0DU50JZ" = "1" /* Supplement Esophagus with Synthetic Substitute, Open Approach */
"0DU50KZ" = "1" /* Supplement Esophagus with Nonautologous Tissue Substitute, Open Approach */
"0DU547Z" = "1" /* Supplement Esophagus with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU54JZ" = "1" /* Supplement Esophagus with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0DU54KZ" = "1" /* Supplement Esophagus with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0DU577Z" = "1" /* Supplement Esophagus with Autologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU57JZ" = "1" /* Supplement Esophagus with Synthetic Substitute, Via Natural or Artificial Opening */
"0DU57KZ" = "1" /* Supplement Esophagus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening */
"0DU587Z" = "1" /* Supplement Esophagus with Autologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU58JZ" = "1" /* Supplement Esophagus with Synthetic Substitute, Via Natural or Artificial Opening Endoscopic */
"0DU58KZ" = "1" /* Supplement Esophagus with Nonautologous Tissue Substitute, Via Natural or Artificial Opening Endoscopic */
"0DV10CZ" = "1" /* Restriction of Upper Esophagus with Extraluminal Device, Open Approach */
"0DV10DZ" = "1" /* Restriction of Upper Esophagus with Intraluminal Device, Open Approach */
"0DV10ZZ" = "1" /* Restriction of Upper Esophagus, Open Approach */
"0DV13CZ" = "1" /* Restriction of Upper Esophagus with Extraluminal Device, Percutaneous Approach */
"0DV13DZ" = "1" /* Restriction of Upper Esophagus with Intraluminal Device, Percutaneous Approach */
"0DV13ZZ" = "1" /* Restriction of Upper Esophagus, Percutaneous Approach */
"0DV14CZ" = "1" /* Restriction of Upper Esophagus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DV14DZ" = "1" /* Restriction of Upper Esophagus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DV14ZZ" = "1" /* Restriction of Upper Esophagus, Percutaneous Endoscopic Approach */
"0DV17DZ" = "1" /* Restriction of Upper Esophagus with Intraluminal Device, Via Natural or Artificial Opening */
"0DV17ZZ" = "1" /* Restriction of Upper Esophagus, Via Natural or Artificial Opening */
"0DV18DZ" = "1" /* Restriction of Upper Esophagus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DV18ZZ" = "1" /* Restriction of Upper Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DV20CZ" = "1" /* Restriction of Middle Esophagus with Extraluminal Device, Open Approach */
"0DV20DZ" = "1" /* Restriction of Middle Esophagus with Intraluminal Device, Open Approach */
"0DV20ZZ" = "1" /* Restriction of Middle Esophagus, Open Approach */
"0DV23CZ" = "1" /* Restriction of Middle Esophagus with Extraluminal Device, Percutaneous Approach */
"0DV23DZ" = "1" /* Restriction of Middle Esophagus with Intraluminal Device, Percutaneous Approach */
"0DV23ZZ" = "1" /* Restriction of Middle Esophagus, Percutaneous Approach */
"0DV24CZ" = "1" /* Restriction of Middle Esophagus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DV24DZ" = "1" /* Restriction of Middle Esophagus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DV24ZZ" = "1" /* Restriction of Middle Esophagus, Percutaneous Endoscopic Approach */
"0DV27DZ" = "1" /* Restriction of Middle Esophagus with Intraluminal Device, Via Natural or Artificial Opening */
"0DV27ZZ" = "1" /* Restriction of Middle Esophagus, Via Natural or Artificial Opening */
"0DV28DZ" = "1" /* Restriction of Middle Esophagus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DV28ZZ" = "1" /* Restriction of Middle Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DV30CZ" = "1" /* Restriction of Lower Esophagus with Extraluminal Device, Open Approach */
"0DV30DZ" = "1" /* Restriction of Lower Esophagus with Intraluminal Device, Open Approach */
"0DV30ZZ" = "1" /* Restriction of Lower Esophagus, Open Approach */
"0DV33CZ" = "1" /* Restriction of Lower Esophagus with Extraluminal Device, Percutaneous Approach */
"0DV33DZ" = "1" /* Restriction of Lower Esophagus with Intraluminal Device, Percutaneous Approach */
"0DV33ZZ" = "1" /* Restriction of Lower Esophagus, Percutaneous Approach */
"0DV34CZ" = "1" /* Restriction of Lower Esophagus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DV34DZ" = "1" /* Restriction of Lower Esophagus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DV34ZZ" = "1" /* Restriction of Lower Esophagus, Percutaneous Endoscopic Approach */
"0DV37DZ" = "1" /* Restriction of Lower Esophagus with Intraluminal Device, Via Natural or Artificial Opening */
"0DV37ZZ" = "1" /* Restriction of Lower Esophagus, Via Natural or Artificial Opening */
"0DV38DZ" = "1" /* Restriction of Lower Esophagus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DV38ZZ" = "1" /* Restriction of Lower Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DV40CZ" = "1" /* Restriction of Esophagogastric Junction with Extraluminal Device, Open Approach */
"0DV40DZ" = "1" /* Restriction of Esophagogastric Junction with Intraluminal Device, Open Approach */
"0DV40ZZ" = "1" /* Restriction of Esophagogastric Junction, Open Approach */
"0DV43CZ" = "1" /* Restriction of Esophagogastric Junction with Extraluminal Device, Percutaneous Approach */
"0DV43DZ" = "1" /* Restriction of Esophagogastric Junction with Intraluminal Device, Percutaneous Approach */
"0DV43ZZ" = "1" /* Restriction of Esophagogastric Junction, Percutaneous Approach */
"0DV44CZ" = "1" /* Restriction of Esophagogastric Junction with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DV44DZ" = "1" /* Restriction of Esophagogastric Junction with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DV44ZZ" = "1" /* Restriction of Esophagogastric Junction, Percutaneous Endoscopic Approach */
"0DV47DZ" = "1" /* Restriction of Esophagogastric Junction with Intraluminal Device, Via Natural or Artificial Opening */
"0DV47ZZ" = "1" /* Restriction of Esophagogastric Junction, Via Natural or Artificial Opening */
"0DV48DZ" = "1" /* Restriction of Esophagogastric Junction with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DV48ZZ" = "1" /* Restriction of Esophagogastric Junction, Via Natural or Artificial Opening Endoscopic */
"0DV50CZ" = "1" /* Restriction of Esophagus with Extraluminal Device, Open Approach */
"0DV50DZ" = "1" /* Restriction of Esophagus with Intraluminal Device, Open Approach */
"0DV50ZZ" = "1" /* Restriction of Esophagus, Open Approach */
"0DV53CZ" = "1" /* Restriction of Esophagus with Extraluminal Device, Percutaneous Approach */
"0DV53DZ" = "1" /* Restriction of Esophagus with Intraluminal Device, Percutaneous Approach */
"0DV53ZZ" = "1" /* Restriction of Esophagus, Percutaneous Approach */
"0DV54CZ" = "1" /* Restriction of Esophagus with Extraluminal Device, Percutaneous Endoscopic Approach */
"0DV54DZ" = "1" /* Restriction of Esophagus with Intraluminal Device, Percutaneous Endoscopic Approach */
"0DV54ZZ" = "1" /* Restriction of Esophagus, Percutaneous Endoscopic Approach */
"0DV57DZ" = "1" /* Restriction of Esophagus with Intraluminal Device, Via Natural or Artificial Opening */
"0DV57ZZ" = "1" /* Restriction of Esophagus, Via Natural or Artificial Opening */
"0DV58DZ" = "1" /* Restriction of Esophagus with Intraluminal Device, Via Natural or Artificial Opening Endoscopic */
"0DV58ZZ" = "1" /* Restriction of Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DW57DZ" = "1" /* Revision of Intraluminal Device in Esophagus, Via Natural or Artificial Opening */
"0DW58DZ" = "1" /* Revision of Intraluminal Device in Esophagus, Via Natural or Artificial Opening Endoscopic */
"0DX60Z5" = "1" /* Transfer Stomach to Esophagus, Open Approach */
"0DX64Z5" = "1" /* Transfer Stomach to Esophagus, Percutaneous Endoscopic Approach */
"0DX80Z5" = "1" /* Transfer Small Intestine to Esophagus, Open Approach */
"0DX84Z5" = "1" /* Transfer Small Intestine to Esophagus, Percutaneous Endoscopic Approach */
"0DXE0Z5" = "1" /* Transfer Large Intestine to Esophagus, Open Approach */
"0DXE4Z5" = "1" /* Transfer Large Intestine to Esophagus, Percutaneous Endoscopic Approach */
"0PB00ZZ" = "1" /* Excision of Sternum, Open Approach */
"0PB03ZZ" = "1" /* Excision of Sternum, Percutaneous Approach */
"0PB04ZZ" = "1" /* Excision of Sternum, Percutaneous Endoscopic Approach */
"0PB10ZZ" = "1" /* Excision of Right Rib, Open Approach */
"0PB13ZZ" = "1" /* Excision of Right Rib, Percutaneous Approach */
"0PB14ZZ" = "1" /* Excision of Right Rib, Percutaneous Endoscopic Approach */
"0PB20ZZ" = "1" /* Excision of Left Rib, Open Approach */
"0PB23ZZ" = "1" /* Excision of Left Rib, Percutaneous Approach */
"0PB24ZZ" = "1" /* Excision of Left Rib, Percutaneous Endoscopic Approach */
"0PT00ZZ" = "1" /* Resection of Sternum, Open Approach */
"0PT10ZZ" = "1" /* Resection of Right Rib, Open Approach */
"0PT20ZZ" = "1" /* Resection of Left Rib, Open Approach */
"0RG6070" = "1" /* Fusion of Thoracic Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG60A0" = "1" /* Fusion of Thoracic Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0RG60J0" = "1" /* Fusion of Thoracic Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG60K0" = "1" /* Fusion of Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG60Z0" = "1" /* Fusion of Thoracic Vertebral Joint, Anterior Approach, Anterior Column, Open Approach */
"0RG6370" = "1" /* Fusion of Thoracic Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG63A0" = "1" /* Fusion of Thoracic Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG63J0" = "1" /* Fusion of Thoracic Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG63K0" = "1" /* Fusion of Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG63Z0" = "1" /* Fusion of Thoracic Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG6470" = "1" /* Fusion of Thoracic Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG64A0" = "1" /* Fusion of Thoracic Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG64J0" = "1" /* Fusion of Thoracic Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG64K0" = "1" /* Fusion of Thoracic Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG64Z0" = "1" /* Fusion of Thoracic Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG7070" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG70A0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0RG70J0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG70K0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG70Z0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints, Anterior Approach, Anterior Column, Open Approach */
"0RG7370" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG73A0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG73J0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG73K0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG73Z0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG7470" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG74A0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG74J0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG74K0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG74Z0" = "1" /* Fusion of 2 to 7 Thoracic Vertebral Joints, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG8070" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG80A0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0RG80J0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG80K0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RG80Z0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints, Anterior Approach, Anterior Column, Open Approach */
"0RG8370" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG83A0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG83J0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG83K0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG83Z0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RG8470" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG84A0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG84J0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG84K0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RG84Z0" = "1" /* Fusion of 8 or more Thoracic Vertebral Joints, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA070" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RGA0A0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Open Approach */
"0RGA0J0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RGA0K0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Open Approach */
"0RGA0Z0" = "1" /* Fusion of Thoracolumbar Vertebral Joint, Anterior Approach, Anterior Column, Open Approach */
"0RGA370" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RGA3A0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RGA3J0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RGA3K0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RGA3Z0" = "1" /* Fusion of Thoracolumbar Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Approach */
"0RGA470" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Autologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA4A0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Interbody Fusion Device, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA4J0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Synthetic Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA4K0" = "1" /* Fusion of Thoracolumbar Vertebral Joint with Nonautologous Tissue Substitute, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0RGA4Z0" = "1" /* Fusion of Thoracolumbar Vertebral Joint, Anterior Approach, Anterior Column, Percutaneous Endoscopic Approach */
"0W190J4" = "1" /* Bypass Right Pleural Cavity to Cutaneous with Synthetic Substitute, Open Approach */
"0W190J9" = "1" /* Bypass Right Pleural Cavity to Right Pleural Cavity with Synthetic Substitute, Open Approach */
"0W190JB" = "1" /* Bypass Right Pleural Cavity to Left Pleural Cavity with Synthetic Substitute, Open Approach */
"0W190JG" = "1" /* Bypass Right Pleural Cavity to Peritoneal Cavity with Synthetic Substitute, Open Approach */
"0W190JJ" = "1" /* Bypass Right Pleural Cavity to Pelvic Cavity with Synthetic Substitute, Open Approach */
"0W190JY" = "1" /* Bypass Right Pleural Cavity to Lower Vein with Synthetic Substitute, Open Approach */
"0W193J4" = "1" /* Bypass Right Pleural Cavity to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0W194J4" = "1" /* Bypass Right Pleural Cavity to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W194J9" = "1" /* Bypass Right Pleural Cavity to Right Pleural Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W194JB" = "1" /* Bypass Right Pleural Cavity to Left Pleural Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W194JG" = "1" /* Bypass Right Pleural Cavity to Peritoneal Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W194JJ" = "1" /* Bypass Right Pleural Cavity to Pelvic Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W194JY" = "1" /* Bypass Right Pleural Cavity to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1B0J4" = "1" /* Bypass Left Pleural Cavity to Cutaneous with Synthetic Substitute, Open Approach */
"0W1B0J9" = "1" /* Bypass Left Pleural Cavity to Right Pleural Cavity with Synthetic Substitute, Open Approach */
"0W1B0JB" = "1" /* Bypass Left Pleural Cavity to Left Pleural Cavity with Synthetic Substitute, Open Approach */
"0W1B0JG" = "1" /* Bypass Left Pleural Cavity to Peritoneal Cavity with Synthetic Substitute, Open Approach */
"0W1B0JJ" = "1" /* Bypass Left Pleural Cavity to Pelvic Cavity with Synthetic Substitute, Open Approach */
"0W1B0JY" = "1" /* Bypass Left Pleural Cavity to Lower Vein with Synthetic Substitute, Open Approach */
"0W1B3J4" = "1" /* Bypass Left Pleural Cavity to Cutaneous with Synthetic Substitute, Percutaneous Approach */
"0W1B4J4" = "1" /* Bypass Left Pleural Cavity to Cutaneous with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1B4J9" = "1" /* Bypass Left Pleural Cavity to Right Pleural Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1B4JB" = "1" /* Bypass Left Pleural Cavity to Left Pleural Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1B4JG" = "1" /* Bypass Left Pleural Cavity to Peritoneal Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1B4JJ" = "1" /* Bypass Left Pleural Cavity to Pelvic Cavity with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W1B4JY" = "1" /* Bypass Left Pleural Cavity to Lower Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0W390ZZ" = "1" /* Control Bleeding in Right Pleural Cavity, Open Approach */
"0W3B0ZZ" = "1" /* Control Bleeding in Left Pleural Cavity, Open Approach */
"0W3D0ZZ" = "1" /* Control Bleeding in Pericardial Cavity, Open Approach */
"0W3Q0ZZ" = "1" /* Control Bleeding in Respiratory Tract, Open Approach */
"0W9800Z" = "1" /* Drainage of Chest Wall with Drainage Device, Open Approach */
"0W980ZX" = "1" /* Drainage of Chest Wall, Open Approach, Diagnostic */
"0W980ZZ" = "1" /* Drainage of Chest Wall, Open Approach */
"0W9830Z" = "1" /* Drainage of Chest Wall with Drainage Device, Percutaneous Approach */
"0W983ZX" = "1" /* Drainage of Chest Wall, Percutaneous Approach, Diagnostic */
"0W983ZZ" = "1" /* Drainage of Chest Wall, Percutaneous Approach */
"0W9840Z" = "1" /* Drainage of Chest Wall with Drainage Device, Percutaneous Endoscopic Approach */
"0W984ZX" = "1" /* Drainage of Chest Wall, Percutaneous Endoscopic Approach, Diagnostic */
"0W984ZZ" = "1" /* Drainage of Chest Wall, Percutaneous Endoscopic Approach */
"0W9900Z" = "1" /* Drainage of Right Pleural Cavity with Drainage Device, Open Approach */
"0W990ZZ" = "1" /* Drainage of Right Pleural Cavity, Open Approach */
"0W994ZZ" = "1" /* Drainage of Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0W9B00Z" = "1" /* Drainage of Left Pleural Cavity with Drainage Device, Open Approach */
"0W9B0ZZ" = "1" /* Drainage of Left Pleural Cavity, Open Approach */
"0W9B4ZZ" = "1" /* Drainage of Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0W9C00Z" = "1" /* Drainage of Mediastinum with Drainage Device, Open Approach */
"0W9C0ZX" = "1" /* Drainage of Mediastinum, Open Approach, Diagnostic */
"0W9C0ZZ" = "1" /* Drainage of Mediastinum, Open Approach */
"0W9C30Z" = "1" /* Drainage of Mediastinum with Drainage Device, Percutaneous Approach */
"0W9C3ZX" = "1" /* Drainage of Mediastinum, Percutaneous Approach, Diagnostic */
"0W9C3ZZ" = "1" /* Drainage of Mediastinum, Percutaneous Approach */
"0W9C40Z" = "1" /* Drainage of Mediastinum with Drainage Device, Percutaneous Endoscopic Approach */
"0W9C4ZX" = "1" /* Drainage of Mediastinum, Percutaneous Endoscopic Approach, Diagnostic */
"0W9C4ZZ" = "1" /* Drainage of Mediastinum, Percutaneous Endoscopic Approach */
"0WB80ZX" = "1" /* Excision of Chest Wall, Open Approach, Diagnostic */
"0WB80ZZ" = "1" /* Excision of Chest Wall, Open Approach */
"0WB83ZX" = "1" /* Excision of Chest Wall, Percutaneous Approach, Diagnostic */
"0WB83ZZ" = "1" /* Excision of Chest Wall, Percutaneous Approach */
"0WB84ZX" = "1" /* Excision of Chest Wall, Percutaneous Endoscopic Approach, Diagnostic */
"0WB84ZZ" = "1" /* Excision of Chest Wall, Percutaneous Endoscopic Approach */
"0WB8XZX" = "1" /* Excision of Chest Wall, External Approach, Diagnostic */
"0WB8XZZ" = "1" /* Excision of Chest Wall, External Approach */
"0WBC0ZX" = "1" /* Excision of Mediastinum, Open Approach, Diagnostic */
"0WBC0ZZ" = "1" /* Excision of Mediastinum, Open Approach */
"0WBC3ZX" = "1" /* Excision of Mediastinum, Percutaneous Approach, Diagnostic */
"0WBC3ZZ" = "1" /* Excision of Mediastinum, Percutaneous Approach */
"0WBC4ZX" = "1" /* Excision of Mediastinum, Percutaneous Endoscopic Approach, Diagnostic */
"0WBC4ZZ" = "1" /* Excision of Mediastinum, Percutaneous Endoscopic Approach */
"0WC90ZZ" = "1" /* Extirpation of Matter from Right Pleural Cavity, Open Approach */
"0WC93ZZ" = "1" /* Extirpation of Matter from Right Pleural Cavity, Percutaneous Approach */
"0WC94ZZ" = "1" /* Extirpation of Matter from Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0WCB0ZZ" = "1" /* Extirpation of Matter from Left Pleural Cavity, Open Approach */
"0WCB3ZZ" = "1" /* Extirpation of Matter from Left Pleural Cavity, Percutaneous Approach */
"0WCB4ZZ" = "1" /* Extirpation of Matter from Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0WCC0ZZ" = "1" /* Extirpation of Matter from Mediastinum, Open Approach */
"0WCC3ZZ" = "1" /* Extirpation of Matter from Mediastinum, Percutaneous Approach */
"0WCC4ZZ" = "1" /* Extirpation of Matter from Mediastinum, Percutaneous Endoscopic Approach */
"0WCQ0ZZ" = "1" /* Extirpation of Matter from Respiratory Tract, Open Approach */
"0WCQ3ZZ" = "1" /* Extirpation of Matter from Respiratory Tract, Percutaneous Approach */
"0WCQ4ZZ" = "1" /* Extirpation of Matter from Respiratory Tract, Percutaneous Endoscopic Approach */
"0WCQ7ZZ" = "1" /* Extirpation of Matter from Respiratory Tract, Via Natural or Artificial Opening */
"0WCQ8ZZ" = "1" /* Extirpation of Matter from Respiratory Tract, Via Natural or Artificial Opening Endoscopic */
"0WF90ZZ" = "1" /* Fragmentation in Right Pleural Cavity, Open Approach */
"0WF93ZZ" = "1" /* Fragmentation in Right Pleural Cavity, Percutaneous Approach */
"0WF94ZZ" = "1" /* Fragmentation in Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0WFB0ZZ" = "1" /* Fragmentation in Left Pleural Cavity, Open Approach */
"0WFB3ZZ" = "1" /* Fragmentation in Left Pleural Cavity, Percutaneous Approach */
"0WFB4ZZ" = "1" /* Fragmentation in Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0WFC0ZZ" = "1" /* Fragmentation in Mediastinum, Open Approach */
"0WFC3ZZ" = "1" /* Fragmentation in Mediastinum, Percutaneous Approach */
"0WFC4ZZ" = "1" /* Fragmentation in Mediastinum, Percutaneous Endoscopic Approach */
"0WFQ0ZZ" = "1" /* Fragmentation in Respiratory Tract, Open Approach */
"0WFQ3ZZ" = "1" /* Fragmentation in Respiratory Tract, Percutaneous Approach */
"0WFQ4ZZ" = "1" /* Fragmentation in Respiratory Tract, Percutaneous Endoscopic Approach */
"0WFQ7ZZ" = "1" /* Fragmentation in Respiratory Tract, Via Natural or Artificial Opening */
"0WFQ8ZZ" = "1" /* Fragmentation in Respiratory Tract, Via Natural or Artificial Opening Endoscopic */
"0WH803Z" = "1" /* Insertion of Infusion Device into Chest Wall, Open Approach */
"0WH80YZ" = "1" /* Insertion of Other Device into Chest Wall, Open Approach */
"0WH833Z" = "1" /* Insertion of Infusion Device into Chest Wall, Percutaneous Approach */
"0WH83YZ" = "1" /* Insertion of Other Device into Chest Wall, Percutaneous Approach */
"0WH843Z" = "1" /* Insertion of Infusion Device into Chest Wall, Percutaneous Endoscopic Approach */
"0WH84YZ" = "1" /* Insertion of Other Device into Chest Wall, Percutaneous Endoscopic Approach */
"0WH903Z" = "1" /* Insertion of Infusion Device into Right Pleural Cavity, Open Approach */
"0WH90YZ" = "1" /* Insertion of Other Device into Right Pleural Cavity, Open Approach */
"0WH933Z" = "1" /* Insertion of Infusion Device into Right Pleural Cavity, Percutaneous Approach */
"0WH93YZ" = "1" /* Insertion of Other Device into Right Pleural Cavity, Percutaneous Approach */
"0WH943Z" = "1" /* Insertion of Infusion Device into Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0WH94YZ" = "1" /* Insertion of Other Device into Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0WHB03Z" = "1" /* Insertion of Infusion Device into Left Pleural Cavity, Open Approach */
"0WHB0YZ" = "1" /* Insertion of Other Device into Left Pleural Cavity, Open Approach */
"0WHB33Z" = "1" /* Insertion of Infusion Device into Left Pleural Cavity, Percutaneous Approach */
"0WHB3YZ" = "1" /* Insertion of Other Device into Left Pleural Cavity, Percutaneous Approach */
"0WHB43Z" = "1" /* Insertion of Infusion Device into Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0WHB4YZ" = "1" /* Insertion of Other Device into Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0WHC03Z" = "1" /* Insertion of Infusion Device into Mediastinum, Open Approach */
"0WHC0YZ" = "1" /* Insertion of Other Device into Mediastinum, Open Approach */
"0WHC33Z" = "1" /* Insertion of Infusion Device into Mediastinum, Percutaneous Approach */
"0WHC3YZ" = "1" /* Insertion of Other Device into Mediastinum, Percutaneous Approach */
"0WHC43Z" = "1" /* Insertion of Infusion Device into Mediastinum, Percutaneous Endoscopic Approach */
"0WHC4YZ" = "1" /* Insertion of Other Device into Mediastinum, Percutaneous Endoscopic Approach */
"0WHQ03Z" = "1" /* Insertion of Infusion Device into Respiratory Tract, Open Approach */
"0WHQ0YZ" = "1" /* Insertion of Other Device into Respiratory Tract, Open Approach */
"0WHQ33Z" = "1" /* Insertion of Infusion Device into Respiratory Tract, Percutaneous Approach */
"0WHQ3YZ" = "1" /* Insertion of Other Device into Respiratory Tract, Percutaneous Approach */
"0WHQ43Z" = "1" /* Insertion of Infusion Device into Respiratory Tract, Percutaneous Endoscopic Approach */
"0WHQ4YZ" = "1" /* Insertion of Other Device into Respiratory Tract, Percutaneous Endoscopic Approach */
"0WJ80ZZ" = "1" /* Inspection of Chest Wall, Open Approach */
"0WJ83ZZ" = "1" /* Inspection of Chest Wall, Percutaneous Approach */
"0WJ84ZZ" = "1" /* Inspection of Chest Wall, Percutaneous Endoscopic Approach */
"0WJ90ZZ" = "1" /* Inspection of Right Pleural Cavity, Open Approach */
"0WJ93ZZ" = "1" /* Inspection of Right Pleural Cavity, Percutaneous Approach */
"0WJ94ZZ" = "1" /* Inspection of Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0WJB0ZZ" = "1" /* Inspection of Left Pleural Cavity, Open Approach */
"0WJB3ZZ" = "1" /* Inspection of Left Pleural Cavity, Percutaneous Approach */
"0WJB4ZZ" = "1" /* Inspection of Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0WJC0ZZ" = "1" /* Inspection of Mediastinum, Open Approach */
"0WJC3ZZ" = "1" /* Inspection of Mediastinum, Percutaneous Approach */
"0WJC4ZZ" = "1" /* Inspection of Mediastinum, Percutaneous Endoscopic Approach */
"0WJD4ZZ" = "1" /* Inspection of Pericardial Cavity, Percutaneous Endoscopic Approach */
"0WJQ0ZZ" = "1" /* Inspection of Respiratory Tract, Open Approach */
"0WJQ3ZZ" = "1" /* Inspection of Respiratory Tract, Percutaneous Approach */
"0WJQ4ZZ" = "1" /* Inspection of Respiratory Tract, Percutaneous Endoscopic Approach */
"0WJQ7ZZ" = "1" /* Inspection of Respiratory Tract, Via Natural or Artificial Opening Approach */
"0WJQ8ZZ" = "1" /* Inspection of Respiratory Tract, Via Natural or Artificial Opening Endoscopic Approach */
"0WM80ZZ" = "1" /* Reattachment of Chest Wall, Open Approach */
"0WP800Z" = "1" /* Removal of Drainage Device from Chest Wall, Open Approach */
"0WP801Z" = "1" /* Removal of Radioactive Element from Chest Wall, Open Approach */
"0WP803Z" = "1" /* Removal of Infusion Device from Chest Wall, Open Approach */
"0WP807Z" = "1" /* Removal of Autologous Tissue Substitute from Chest Wall, Open Approach */
"0WP80JZ" = "1" /* Removal of Synthetic Substitute from Chest Wall, Open Approach */
"0WP80KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Chest Wall, Open Approach */
"0WP80YZ" = "1" /* Removal of Other Device from Chest Wall, Open Approach */
"0WP830Z" = "1" /* Removal of Drainage Device from Chest Wall, Percutaneous Approach */
"0WP831Z" = "1" /* Removal of Radioactive Element from Chest Wall, Percutaneous Approach */
"0WP833Z" = "1" /* Removal of Infusion Device from Chest Wall, Percutaneous Approach */
"0WP837Z" = "1" /* Removal of Autologous Tissue Substitute from Chest Wall, Percutaneous Approach */
"0WP83JZ" = "1" /* Removal of Synthetic Substitute from Chest Wall, Percutaneous Approach */
"0WP83KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Chest Wall, Percutaneous Approach */
"0WP83YZ" = "1" /* Removal of Other Device from Chest Wall, Percutaneous Approach */
"0WP840Z" = "1" /* Removal of Drainage Device from Chest Wall, Percutaneous Endoscopic Approach */
"0WP841Z" = "1" /* Removal of Radioactive Element from Chest Wall, Percutaneous Endoscopic Approach */
"0WP843Z" = "1" /* Removal of Infusion Device from Chest Wall, Percutaneous Endoscopic Approach */
"0WP847Z" = "1" /* Removal of Autologous Tissue Substitute from Chest Wall, Percutaneous Endoscopic Approach */
"0WP84JZ" = "1" /* Removal of Synthetic Substitute from Chest Wall, Percutaneous Endoscopic Approach */
"0WP84KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Chest Wall, Percutaneous Endoscopic Approach */
"0WP84YZ" = "1" /* Removal of Other Device from Chest Wall, Percutaneous Endoscopic Approach */
"0WP900Z" = "1" /* Removal of Drainage Device from Right Pleural Cavity, Open Approach */
"0WP901Z" = "1" /* Removal of Radioactive Element from Right Pleural Cavity, Open Approach */
"0WP903Z" = "1" /* Removal of Infusion Device from Right Pleural Cavity, Open Approach */
"0WP90JZ" = "1" /* Removal of Synthetic Substitute from Right Pleural Cavity, Open Approach */
"0WP90YZ" = "1" /* Removal of Other Device from Right Pleural Cavity, Open Approach */
"0WP930Z" = "1" /* Removal of Drainage Device from Right Pleural Cavity, Percutaneous Approach */
"0WP931Z" = "1" /* Removal of Radioactive Element from Right Pleural Cavity, Percutaneous Approach */
"0WP933Z" = "1" /* Removal of Infusion Device from Right Pleural Cavity, Percutaneous Approach */
"0WP93JZ" = "1" /* Removal of Synthetic Substitute from Right Pleural Cavity, Percutaneous Approach */
"0WP93YZ" = "1" /* Removal of Other Device from Right Pleural Cavity, Percutaneous Approach */
"0WP940Z" = "1" /* Removal of Drainage Device from Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0WP941Z" = "1" /* Removal of Radioactive Element from Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0WP943Z" = "1" /* Removal of Infusion Device from Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0WP94JZ" = "1" /* Removal of Synthetic Substitute from Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0WP94YZ" = "1" /* Removal of Other Device from Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0WPB00Z" = "1" /* Removal of Drainage Device from Left Pleural Cavity, Open Approach */
"0WPB01Z" = "1" /* Removal of Radioactive Element from Left Pleural Cavity, Open Approach */
"0WPB03Z" = "1" /* Removal of Infusion Device from Left Pleural Cavity, Open Approach */
"0WPB0JZ" = "1" /* Removal of Synthetic Substitute from Left Pleural Cavity, Open Approach */
"0WPB0YZ" = "1" /* Removal of Other Device from Left Pleural Cavity, Open Approach */
"0WPB30Z" = "1" /* Removal of Drainage Device from Left Pleural Cavity, Percutaneous Approach */
"0WPB31Z" = "1" /* Removal of Radioactive Element from Left Pleural Cavity, Percutaneous Approach */
"0WPB33Z" = "1" /* Removal of Infusion Device from Left Pleural Cavity, Percutaneous Approach */
"0WPB3JZ" = "1" /* Removal of Synthetic Substitute from Left Pleural Cavity, Percutaneous Approach */
"0WPB3YZ" = "1" /* Removal of Other Device from Left Pleural Cavity, Percutaneous Approach */
"0WPB40Z" = "1" /* Removal of Drainage Device from Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0WPB41Z" = "1" /* Removal of Radioactive Element from Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0WPB43Z" = "1" /* Removal of Infusion Device from Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0WPB4JZ" = "1" /* Removal of Synthetic Substitute from Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0WPB4YZ" = "1" /* Removal of Other Device from Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0WPC00Z" = "1" /* Removal of Drainage Device from Mediastinum, Open Approach */
"0WPC01Z" = "1" /* Removal of Radioactive Element from Mediastinum, Open Approach */
"0WPC03Z" = "1" /* Removal of Infusion Device from Mediastinum, Open Approach */
"0WPC07Z" = "1" /* Removal of Autologous Tissue Substitute from Mediastinum, Open Approach */
"0WPC0JZ" = "1" /* Removal of Synthetic Substitute from Mediastinum, Open Approach */
"0WPC0KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Mediastinum, Open Approach */
"0WPC0YZ" = "1" /* Removal of Other Device from Mediastinum, Open Approach */
"0WPC30Z" = "1" /* Removal of Drainage Device from Mediastinum, Percutaneous Approach */
"0WPC31Z" = "1" /* Removal of Radioactive Element from Mediastinum, Percutaneous Approach */
"0WPC33Z" = "1" /* Removal of Infusion Device from Mediastinum, Percutaneous Approach */
"0WPC37Z" = "1" /* Removal of Autologous Tissue Substitute from Mediastinum, Percutaneous Approach */
"0WPC3JZ" = "1" /* Removal of Synthetic Substitute from Mediastinum, Percutaneous Approach */
"0WPC3KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Mediastinum, Percutaneous Approach */
"0WPC3YZ" = "1" /* Removal of Other Device from Mediastinum, Percutaneous Approach */
"0WPC40Z" = "1" /* Removal of Drainage Device from Mediastinum, Percutaneous Endoscopic Approach */
"0WPC41Z" = "1" /* Removal of Radioactive Element from Mediastinum, Percutaneous Endoscopic Approach */
"0WPC43Z" = "1" /* Removal of Infusion Device from Mediastinum, Percutaneous Endoscopic Approach */
"0WPC47Z" = "1" /* Removal of Autologous Tissue Substitute from Mediastinum, Percutaneous Endoscopic Approach */
"0WPC4JZ" = "1" /* Removal of Synthetic Substitute from Mediastinum, Percutaneous Endoscopic Approach */
"0WPC4KZ" = "1" /* Removal of Nonautologous Tissue Substitute from Mediastinum, Percutaneous Endoscopic Approach */
"0WPC4YZ" = "1" /* Removal of Other Device from Mediastinum, Percutaneous Endoscopic Approach */
"0WPQ01Z" = "1" /* Removal of Radioactive Element from Respiratory Tract, Open Approach */
"0WPQ03Z" = "1" /* Removal of Infusion Device from Respiratory Tract, Open Approach */
"0WPQ0YZ" = "1" /* Removal of Other Device from Respiratory Tract, Open Approach */
"0WPQ31Z" = "1" /* Removal of Radioactive Element from Respiratory Tract, Percutaneous Approach */
"0WPQ33Z" = "1" /* Removal of Infusion Device from Respiratory Tract, Percutaneous Approach */
"0WPQ3YZ" = "1" /* Removal of Other Device from Respiratory Tract, Percutaneous Approach */
"0WPQ41Z" = "1" /* Removal of Radioactive Element from Respiratory Tract, Percutaneous Endoscopic Approach */
"0WPQ43Z" = "1" /* Removal of Infusion Device from Respiratory Tract, Percutaneous Endoscopic Approach */
"0WPQ4YZ" = "1" /* Removal of Other Device from Respiratory Tract, Percutaneous Endoscopic Approach */
"0WPQ71Z" = "1" /* Removal of Radioactive Element from Respiratory Tract, Via Natural or Artificial Opening */
"0WPQ73Z" = "1" /* Removal of Infusion Device from Respiratory Tract, Via Natural or Artificial Opening */
"0WPQ7YZ" = "1" /* Removal of Other Device from Respiratory Tract, Via Natural or Artificial Opening */
"0WPQ81Z" = "1" /* Removal of Radioactive Element from Respiratory Tract, Via Natural or Artificial Opening Endoscopic */
"0WQ6XZ2" = "1" /* Repair Neck, Stoma, External Approach */
"0WQ80ZZ" = "1" /* Repair Chest Wall, Open Approach */
"0WQ83ZZ" = "1" /* Repair Chest Wall, Percutaneous Approach */
"0WQ84ZZ" = "1" /* Repair Chest Wall, Percutaneous Endoscopic Approach */
"0WQ8XZZ" = "1" /* Repair Chest Wall, External Approach */
"0WQC0ZZ" = "1" /* Repair Mediastinum, Open Approach */
"0WQC3ZZ" = "1" /* Repair Mediastinum, Percutaneous Approach */
"0WQC4ZZ" = "1" /* Repair Mediastinum, Percutaneous Endoscopic Approach */
"0WU807Z" = "1" /* Supplement Chest Wall with Autologous Tissue Substitute, Open Approach */
"0WU80JZ" = "1" /* Supplement Chest Wall with Synthetic Substitute, Open Approach */
"0WU80KZ" = "1" /* Supplement Chest Wall with Nonautologous Tissue Substitute, Open Approach */
"0WU847Z" = "1" /* Supplement Chest Wall with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WU84JZ" = "1" /* Supplement Chest Wall with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0WU84KZ" = "1" /* Supplement Chest Wall with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WUC07Z" = "1" /* Supplement Mediastinum with Autologous Tissue Substitute, Open Approach */
"0WUC0JZ" = "1" /* Supplement Mediastinum with Synthetic Substitute, Open Approach */
"0WUC0KZ" = "1" /* Supplement Mediastinum with Nonautologous Tissue Substitute, Open Approach */
"0WUC47Z" = "1" /* Supplement Mediastinum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WUC4JZ" = "1" /* Supplement Mediastinum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"0WUC4KZ" = "1" /* Supplement Mediastinum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"0WW800Z" = "1" /* Revision of Drainage Device in Chest Wall, Open Approach */
"0WW801Z" = "1" /* Revision of Radioactive Element in Chest Wall, Open Approach */
"0WW803Z" = "1" /* Revision of Infusion Device in Chest Wall, Open Approach */
"0WW807Z" = "1" /* Revision of Autologous Tissue Substitute in Chest Wall, Open Approach */
"0WW80JZ" = "1" /* Revision of Synthetic Substitute in Chest Wall, Open Approach */
"0WW80KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Chest Wall, Open Approach */
"0WW80YZ" = "1" /* Revision of Other Device in Chest Wall, Open Approach */
"0WW830Z" = "1" /* Revision of Drainage Device in Chest Wall, Percutaneous Approach */
"0WW831Z" = "1" /* Revision of Radioactive Element in Chest Wall, Percutaneous Approach */
"0WW833Z" = "1" /* Revision of Infusion Device in Chest Wall, Percutaneous Approach */
"0WW837Z" = "1" /* Revision of Autologous Tissue Substitute in Chest Wall, Percutaneous Approach */
"0WW83JZ" = "1" /* Revision of Synthetic Substitute in Chest Wall, Percutaneous Approach */
"0WW83KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Chest Wall, Percutaneous Approach */
"0WW83YZ" = "1" /* Revision of Other Device in Chest Wall, Percutaneous Approach */
"0WW840Z" = "1" /* Revision of Drainage Device in Chest Wall, Percutaneous Endoscopic Approach */
"0WW841Z" = "1" /* Revision of Radioactive Element in Chest Wall, Percutaneous Endoscopic Approach */
"0WW843Z" = "1" /* Revision of Infusion Device in Chest Wall, Percutaneous Endoscopic Approach */
"0WW847Z" = "1" /* Revision of Autologous Tissue Substitute in Chest Wall, Percutaneous Endoscopic Approach */
"0WW84JZ" = "1" /* Revision of Synthetic Substitute in Chest Wall, Percutaneous Endoscopic Approach */
"0WW84KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Chest Wall, Percutaneous Endoscopic Approach */
"0WW84YZ" = "1" /* Revision of Other Device in Chest Wall, Percutaneous Endoscopic Approach */
"0WW900Z" = "1" /* Revision of Drainage Device in Right Pleural Cavity, Open Approach */
"0WW901Z" = "1" /* Revision of Radioactive Element in Right Pleural Cavity, Open Approach */
"0WW903Z" = "1" /* Revision of Infusion Device in Right Pleural Cavity, Open Approach */
"0WW90JZ" = "1" /* Revision of Synthetic Substitute in Right Pleural Cavity, Open Approach */
"0WW90YZ" = "1" /* Revision of Other Device in Right Pleural Cavity, Open Approach */
"0WW930Z" = "1" /* Revision of Drainage Device in Right Pleural Cavity, Percutaneous Approach */
"0WW931Z" = "1" /* Revision of Radioactive Element in Right Pleural Cavity, Percutaneous Approach */
"0WW933Z" = "1" /* Revision of Infusion Device in Right Pleural Cavity, Percutaneous Approach */
"0WW93JZ" = "1" /* Revision of Synthetic Substitute in Right Pleural Cavity, Percutaneous Approach */
"0WW93YZ" = "1" /* Revision of Other Device in Right Pleural Cavity, Percutaneous Approach */
"0WW940Z" = "1" /* Revision of Drainage Device in Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0WW941Z" = "1" /* Revision of Radioactive Element in Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0WW943Z" = "1" /* Revision of Infusion Device in Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0WW94JZ" = "1" /* Revision of Synthetic Substitute in Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0WW94YZ" = "1" /* Revision of Other Device in Right Pleural Cavity, Percutaneous Endoscopic Approach */
"0WWB00Z" = "1" /* Revision of Drainage Device in Left Pleural Cavity, Open Approach */
"0WWB01Z" = "1" /* Revision of Radioactive Element in Left Pleural Cavity, Open Approach */
"0WWB03Z" = "1" /* Revision of Infusion Device in Left Pleural Cavity, Open Approach */
"0WWB0JZ" = "1" /* Revision of Synthetic Substitute in Left Pleural Cavity, Open Approach */
"0WWB0YZ" = "1" /* Revision of Other Device in Left Pleural Cavity, Open Approach */
"0WWB30Z" = "1" /* Revision of Drainage Device in Left Pleural Cavity, Percutaneous Approach */
"0WWB31Z" = "1" /* Revision of Radioactive Element in Left Pleural Cavity, Percutaneous Approach */
"0WWB33Z" = "1" /* Revision of Infusion Device in Left Pleural Cavity, Percutaneous Approach */
"0WWB3JZ" = "1" /* Revision of Synthetic Substitute in Left Pleural Cavity, Percutaneous Approach */
"0WWB3YZ" = "1" /* Revision of Other Device in Left Pleural Cavity, Percutaneous Approach */
"0WWB40Z" = "1" /* Revision of Drainage Device in Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0WWB41Z" = "1" /* Revision of Radioactive Element in Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0WWB43Z" = "1" /* Revision of Infusion Device in Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0WWB4JZ" = "1" /* Revision of Synthetic Substitute in Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0WWB4YZ" = "1" /* Revision of Other Device in Left Pleural Cavity, Percutaneous Endoscopic Approach */
"0WWC00Z" = "1" /* Revision of Drainage Device in Mediastinum, Open Approach */
"0WWC01Z" = "1" /* Revision of Radioactive Element in Mediastinum, Open Approach */
"0WWC03Z" = "1" /* Revision of Infusion Device in Mediastinum, Open Approach */
"0WWC07Z" = "1" /* Revision of Autologous Tissue Substitute in Mediastinum, Open Approach */
"0WWC0JZ" = "1" /* Revision of Synthetic Substitute in Mediastinum, Open Approach */
"0WWC0KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mediastinum, Open Approach */
"0WWC0YZ" = "1" /* Revision of Other Device in Mediastinum, Open Approach */
"0WWC30Z" = "1" /* Revision of Drainage Device in Mediastinum, Percutaneous Approach */
"0WWC31Z" = "1" /* Revision of Radioactive Element in Mediastinum, Percutaneous Approach */
"0WWC33Z" = "1" /* Revision of Infusion Device in Mediastinum, Percutaneous Approach */
"0WWC37Z" = "1" /* Revision of Autologous Tissue Substitute in Mediastinum, Percutaneous Approach */
"0WWC3JZ" = "1" /* Revision of Synthetic Substitute in Mediastinum, Percutaneous Approach */
"0WWC3KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mediastinum, Percutaneous Approach */
"0WWC3YZ" = "1" /* Revision of Other Device in Mediastinum, Percutaneous Approach */
"0WWC40Z" = "1" /* Revision of Drainage Device in Mediastinum, Percutaneous Endoscopic Approach */
"0WWC41Z" = "1" /* Revision of Radioactive Element in Mediastinum, Percutaneous Endoscopic Approach */
"0WWC43Z" = "1" /* Revision of Infusion Device in Mediastinum, Percutaneous Endoscopic Approach */
"0WWC47Z" = "1" /* Revision of Autologous Tissue Substitute in Mediastinum, Percutaneous Endoscopic Approach */
"0WWC4JZ" = "1" /* Revision of Synthetic Substitute in Mediastinum, Percutaneous Endoscopic Approach */
"0WWC4KZ" = "1" /* Revision of Nonautologous Tissue Substitute in Mediastinum, Percutaneous Endoscopic Approach */
"0WWC4YZ" = "1" /* Revision of Other Device in Mediastinum, Percutaneous Endoscopic Approach */
"0WWQ01Z" = "1" /* Revision of Radioactive Element in Respiratory Tract, Open Approach */
"0WWQ03Z" = "1" /* Revision of Infusion Device in Respiratory Tract, Open Approach */
"0WWQ0YZ" = "1" /* Revision of Other Device in Respiratory Tract, Open Approach */
"0WWQ31Z" = "1" /* Revision of Radioactive Element in Respiratory Tract, Percutaneous Approach */
"0WWQ33Z" = "1" /* Revision of Infusion Device in Respiratory Tract, Percutaneous Approach */
"0WWQ3YZ" = "1" /* Revision of Other Device in Respiratory Tract, Percutaneous Approach */
"0WWQ41Z" = "1" /* Revision of Radioactive Element in Respiratory Tract, Percutaneous Endoscopic Approach */
"0WWQ43Z" = "1" /* Revision of Infusion Device in Respiratory Tract, Percutaneous Endoscopic Approach */
"0WWQ4YZ" = "1" /* Revision of Other Device in Respiratory Tract, Percutaneous Endoscopic Approach */
"0WWQ71Z" = "1" /* Revision of Radioactive Element in Respiratory Tract, Via Natural or Artificial Opening */
"0WWQ73Z" = "1" /* Revision of Infusion Device in Respiratory Tract, Via Natural or Artificial Opening */
"0WWQ7YZ" = "1" /* Revision of Other Device in Respiratory Tract, Via Natural or Artificial Opening */
"0WWQ81Z" = "1" /* Revision of Radioactive Element in Respiratory Tract, Via Natural or Artificial Opening Endoscopic */
"0WWQ83Z" = "1" /* Revision of Infusion Device in Respiratory Tract, Via Natural or Artificial Opening Endoscopic */
"0WWQ8YZ" = "1" /* Revision of Other Device in Respiratory Tract, Via Natural or Artificial Opening Endoscopic */
"3E0L3SF" = "1" /* Introduction of Other Gas into Pleural Cavity, Percutaneous Approach */
"3E0L7SF" = "1" /* Introduction of Other Gas into Pleural Cavity, Via Natural or Artificial Opening */
"3E0M3SF" = "1" /* Introduction of Other Gas into Peritoneal Cavity, Percutaneous Approach */
Other = "0"
;

/* Procedure codeset TRANSPP last updated 161203 for ICD10 v70rev0 */
Value $TRANSPP
"02YA0Z0" = "1" /* Transplantation of Heart, Allogeneic, Open Approach */
"02YA0Z2" = "1" /* Transplantation of Heart, Zooplastic, Open Approach */
"0BYC0Z0" = "1" /* Transplantation of Right Upper Lung Lobe, Allogeneic, Open Approach */
"0BYC0Z2" = "1" /* Transplantation of Right Upper Lung Lobe, Zooplastic, Open Approach */
"0BYD0Z0" = "1" /* Transplantation of Right Middle Lung Lobe, Allogeneic, Open Approach */
"0BYD0Z2" = "1" /* Transplantation of Right Middle Lung Lobe, Zooplastic, Open Approach */
"0BYF0Z0" = "1" /* Transplantation of Right Lower Lung Lobe, Allogeneic, Open Approach */
"0BYF0Z2" = "1" /* Transplantation of Right Lower Lung Lobe, Zooplastic, Open Approach */
"0BYG0Z0" = "1" /* Transplantation of Left Upper Lung Lobe, Allogeneic, Open Approach */
"0BYG0Z2" = "1" /* Transplantation of Left Upper Lung Lobe, Zooplastic, Open Approach */
"0BYH0Z0" = "1" /* Transplantation of Lung Lingula, Allogeneic, Open Approach */
"0BYH0Z2" = "1" /* Transplantation of Lung Lingula, Zooplastic, Open Approach */
"0BYJ0Z0" = "1" /* Transplantation of Left Lower Lung Lobe, Allogeneic, Open Approach */
"0BYJ0Z2" = "1" /* Transplantation of Left Lower Lung Lobe, Zooplastic, Open Approach */
"0BYK0Z0" = "1" /* Transplantation of Right Lung, Allogeneic, Open Approach */
"0BYK0Z2" = "1" /* Transplantation of Right Lung, Zooplastic, Open Approach */
"0BYL0Z0" = "1" /* Transplantation of Left Lung, Allogeneic, Open Approach */
"0BYL0Z2" = "1" /* Transplantation of Left Lung, Zooplastic, Open Approach */
"0BYM0Z0" = "1" /* Transplantation of Bilateral Lungs, Allogeneic, Open Approach */
"0BYM0Z2" = "1" /* Transplantation of Bilateral Lungs, Zooplastic, Open Approach */
"0DY50Z0" = "1" /* Transplantation of Esophagus, Allogeneic, Open Approach */
"0DY50Z2" = "1" /* Transplantation of Esophagus, Zooplastic, Open Approach */
"0DY60Z0" = "1" /* Transplantation of Stomach, Allogeneic, Open Approach */
"0DY60Z2" = "1" /* Transplantation of Stomach, Zooplastic, Open Approach */
"0DY80Z0" = "1" /* Transplantation of Small Intestine, Allogeneic, Open Approach */
"0DY80Z2" = "1" /* Transplantation of Small Intestine, Zooplastic, Open Approach */
"0DYE0Z0" = "1" /* Transplantation of Large Intestine, Allogeneic, Open Approach */
"0DYE0Z2" = "1" /* Transplantation of Large Intestine, Zooplastic, Open Approach */
"0FSG0ZZ" = "1" /* Reposition Pancreas, Open Approach */
"0FSG4ZZ" = "1" /* Reposition Pancreas, Percutaneous Endoscopic Approach */
"0FY00Z0" = "1" /* Transplantation of Liver, Allogeneic, Open Approach */
"0FY00Z2" = "1" /* Transplantation of Liver, Zooplastic, Open Approach */
"0FYG0Z0" = "1" /* Transplantation of Pancreas, Allogeneic, Open Approach */
"0FYG0Z2" = "1" /* Transplantation of Pancreas, Zooplastic, Open Approach */
"0TY00Z0" = "1" /* Transplantation of Right Kidney, Allogeneic, Open Approach */
"0TY00Z2" = "1" /* Transplantation of Right Kidney, Zooplastic, Open Approach */
"0TY10Z0" = "1" /* Transplantation of Left Kidney, Allogeneic, Open Approach */
"0TY10Z2" = "1" /* Transplantation of Left Kidney, Zooplastic, Open Approach */
"30230AZ" = "1" /* Transfusion of Embryonic Stem Cells into Peripheral Vein, Open Approach */
"30230G0" = "1" /* Transfusion of Autologous Bone Marrow into Peripheral Vein, Open Approach */
"30230G1" = "1" /* Transfusion of Nonautologous Bone Marrow into Peripheral Vein, Open Approach */
"30230X0" = "1" /* Transfusion of Autologous Cord Blood Stem Cells into Peripheral Vein, Open Approach */
"30230X1" = "1" /* Transfusion of Nonautologous Cord Blood Stem Cells into Peripheral Vein, Open Approach */
"30230Y0" = "1" /* Transfusion of Autologous Hematopoietic Stem Cells into Peripheral Vein, Open Approach */
"30230Y1" = "1" /* Transfusion of Nonautologous Hematopoietic Stem Cells into Peripheral Vein, Open Approach */
"30233AZ" = "1" /* Transfusion of Embryonic Stem Cells into Peripheral Vein, Percutaneous Approach */
"30233G0" = "1" /* Transfusion of Autologous Bone Marrow into Peripheral Vein, Percutaneous Approach */
"30233G1" = "1" /* Transfusion of Nonautologous Bone Marrow into Peripheral Vein, Percutaneous Approach */
"30233X0" = "1" /* Transfusion of Autologous Cord Blood Stem Cells into Peripheral Vein, Percutaneous Approach */
"30233X1" = "1" /* Transfusion of Nonautologous Cord Blood Stem Cells into Peripheral Vein, Percutaneous Approach */
"30233Y0" = "1" /* Transfusion of Autologous Hematopoietic Stem Cells into Peripheral Vein, Percutaneous Approach */
"30233Y1" = "1" /* Transfusion of Nonautologous Hematopoietic Stem Cells into Peripheral Vein, Percutaneous Approach */
"30240AZ" = "1" /* Transfusion of Embryonic Stem Cells into Central Vein, Open Approach */
"30240G0" = "1" /* Transfusion of Autologous Bone Marrow into Central Vein, Open Approach */
"30240G1" = "1" /* Transfusion of Nonautologous Bone Marrow into Central Vein, Open Approach */
"30240X0" = "1" /* Transfusion of Autologous Cord Blood Stem Cells into Central Vein, Open Approach */
"30240X1" = "1" /* Transfusion of Nonautologous Cord Blood Stem Cells into Central Vein, Open Approach */
"30240Y0" = "1" /* Transfusion of Autologous Hematopoietic Stem Cells into Central Vein, Open Approach */
"30240Y1" = "1" /* Transfusion of Nonautologous Hematopoietic Stem Cells into Central Vein, Open Approach */
"30243AZ" = "1" /* Transfusion of Embryonic Stem Cells into Central Vein, Percutaneous Approach */
"30243G0" = "1" /* Transfusion of Autologous Bone Marrow into Central Vein, Percutaneous Approach */
"30243G1" = "1" /* Transfusion of Nonautologous Bone Marrow into Central Vein, Percutaneous Approach */
"30243X0" = "1" /* Transfusion of Autologous Cord Blood Stem Cells into Central Vein, Percutaneous Approach */
"30243X1" = "1" /* Transfusion of Nonautologous Cord Blood Stem Cells into Central Vein, Percutaneous Approach */
"30243Y0" = "1" /* Transfusion of Autologous Hematopoietic Stem Cells into Central Vein, Percutaneous Approach */
"30243Y1" = "1" /* Transfusion of Nonautologous Hematopoietic Stem Cells into Central Vein, Percutaneous Approach */
"30250G0" = "1" /* Transfusion of Autologous Bone Marrow into Peripheral Artery, Open Approach */
"30250G1" = "1" /* Transfusion of Nonautologous Bone Marrow into Peripheral Artery, Open Approach */
"30250X0" = "1" /* Transfusion of Autologous Cord Blood Stem Cells into Peripheral Artery, Open Approach */
"30250X1" = "1" /* Transfusion of Nonautologous Cord Blood Stem Cells into Peripheral Artery, Open Approach */
"30250Y0" = "1" /* Transfusion of Autologous Hematopoietic Stem Cells into Peripheral Artery, Open Approach */
"30250Y1" = "1" /* Transfusion of Nonautologous Hematopoietic Stem Cells into Peripheral Artery, Open Approach */
"30253G0" = "1" /* Transfusion of Autologous Bone Marrow into Peripheral Artery, Percutaneous Approach */
"30253G1" = "1" /* Transfusion of Nonautologous Bone Marrow into Peripheral Artery, Percutaneous Approach */
"30253X0" = "1" /* Transfusion of Autologous Cord Blood Stem Cells into Peripheral Artery, Percutaneous Approach */
"30253X1" = "1" /* Transfusion of Nonautologous Cord Blood Stem Cells into Peripheral Artery, Percutaneous Approach */
"30253Y0" = "1" /* Transfusion of Autologous Hematopoietic Stem Cells into Peripheral Artery, Percutaneous Approach */
"30253Y1" = "1" /* Transfusion of Nonautologous Hematopoietic Stem Cells into Peripheral Artery, Percutaneous Approach */
"30260G0" = "1" /* Transfusion of Autologous Bone Marrow into Central Artery, Open Approach */
"30260G1" = "1" /* Transfusion of Nonautologous Bone Marrow into Central Artery, Open Approach */
"30260X0" = "1" /* Transfusion of Autologous Cord Blood Stem Cells into Central Artery, Open Approach */
"30260X1" = "1" /* Transfusion of Nonautologous Cord Blood Stem Cells into Central Artery, Open Approach */
"30260Y0" = "1" /* Transfusion of Autologous Hematopoietic Stem Cells into Central Artery, Open Approach */
"30260Y1" = "1" /* Transfusion of Nonautologous Hematopoietic Stem Cells into Central Artery, Open Approach */
"30263G0" = "1" /* Transfusion of Autologous Bone Marrow into Central Artery, Percutaneous Approach */
"30263G1" = "1" /* Transfusion of Nonautologous Bone Marrow into Central Artery, Percutaneous Approach */
"30263X0" = "1" /* Transfusion of Autologous Cord Blood Stem Cells into Central Artery, Percutaneous Approach */
"30263X1" = "1" /* Transfusion of Nonautologous Cord Blood Stem Cells into Central Artery, Percutaneous Approach */
"30263Y0" = "1" /* Transfusion of Autologous Hematopoietic Stem Cells into Central Artery, Percutaneous Approach */
"30263Y1" = "1" /* Transfusion of Nonautologous Hematopoietic Stem Cells into Central Artery, Percutaneous Approach */
"3E030U1" = "1" /* Introduction of Nonautologous Pancreatic Islet Cells into Peripheral Vein, Open Approach */
"3E033U1" = "1" /* Introduction of Nonautologous Pancreatic Islet Cells into Peripheral Vein, Percutaneous Approach */
"3E0J3U1" = "1" /* Introduction of Nonautologous Pancreatic Islet Cells into Biliary and Pancreatic Tract, Percutaneous Approach */
"3E0J7U1" = "1" /* Introduction of Nonautologous Pancreatic Islet Cells into Biliary and Pancreatic Tract, Via Natural or Artificial Opening */
"3E0J8U1" = "1" /* Introduction of Nonautologous Pancreatic Islet Cells into Biliary and Pancreatic Tract, Via Natural or Artificial Opening Endoscopic */
"0WY20Z0" = "1" /* Transplantation of Face, Allogeneic, Open Approach */
"0XYJ0Z0" = "1" /* Transplantation of Right Hand, Allogeneic, Open Approach */
"0XYK0Z0" = "1" /* Transplantation of Left Hand, Allogeneic, Open Approach */
"30230G2" = "1" /* Transfusion of Allogeneic Related Bone Marrow into Peripheral Vein, Open Approach */
"30230G3" = "1" /* Transfusion of Allogeneic Unrelated Bone Marrow into Peripheral Vein, Open Approach */
"30230G4" = "1" /* Transfusion of Allogeneic Unspecified Bone Marrow into Peripheral Vein, Open Approach */
"30230X2" = "1" /* Transfusion of Allogeneic Related Cord Blood Stem Cells into Peripheral Vein, Open Approach */
"30230X3" = "1" /* Transfusion of Allogeneic Unrelated Cord Blood Stem Cells into Peripheral Vein, Open Approach */
"30230X4" = "1" /* Transfusion of Allogeneic Unspecified Cord Blood Stem Cells into Peripheral Vein, Open Approach */
"30230Y2" = "1" /* Transfusion of Allogeneic Related Hematopoietic Stem Cells into Peripheral Vein, Open Approach */
"30230Y3" = "1" /* Transfusion of Allogeneic Unrelated Hematopoietic Stem Cells into Peripheral Vein, Open Approach */
"30230Y4" = "1" /* Transfusion of Allogeneic Unspecified Hematopoietic Stem Cells into Peripheral Vein, Open Approach */
"30233G2" = "1" /* Transfusion of Allogeneic Related Bone Marrow into Peripheral Vein, Percutaneous Approach */
"30233G3" = "1" /* Transfusion of Allogeneic Unrelated Bone Marrow into Peripheral Vein, Percutaneous Approach */
"30233G4" = "1" /* Transfusion of Allogeneic Unspecified Bone Marrow into Peripheral Vein, Percutaneous Approach */
"30233X2" = "1" /* Transfusion of Allogeneic Related Cord Blood Stem Cells into Peripheral Vein, Percutaneous Approach */
"30233X3" = "1" /* Transfusion of Allogeneic Unrelated Cord Blood Stem Cells into Peripheral Vein, Percutaneous Approach */
"30233X4" = "1" /* Transfusion of Allogeneic Unspecified Cord Blood Stem Cells into Peripheral Vein, Percutaneous Approach */
"30233Y2" = "1" /* Transfusion of Allogeneic Related Hematopoietic Stem Cells into Peripheral Vein, Percutaneous Approach */
"30233Y3" = "1" /* Transfusion of Allogeneic Unrelated Hematopoietic Stem Cells into Peripheral Vein, Percutaneous Approach */
"30233Y4" = "1" /* Transfusion of Allogeneic Unspecified Hematopoietic Stem Cells into Peripheral Vein, Percutaneous Approach */
"30240G2" = "1" /* Transfusion of Allogeneic Related Bone Marrow into Central Vein, Open Approach */
"30240G3" = "1" /* Transfusion of Allogeneic Unrelated Bone Marrow into Central Vein, Open Approach */
"30240G4" = "1" /* Transfusion of Allogeneic Unspecified Bone Marrow into Central Vein, Open Approach */
"30240X2" = "1" /* Transfusion of Allogeneic Related Cord Blood Stem Cells into Central Vein, Open Approach */
"30240X3" = "1" /* Transfusion of Allogeneic Unrelated Cord Blood Stem Cells into Central Vein, Open Approach */
"30240X4" = "1" /* Transfusion of Allogeneic Unspecified Cord Blood Stem Cells into Central Vein, Open Approach */
"30240Y2" = "1" /* Transfusion of Allogeneic Related Hematopoietic Stem Cells into Central Vein, Open Approach */
"30240Y3" = "1" /* Transfusion of Allogeneic Unrelated Hematopoietic Stem Cells into Central Vein, Open Approach */
"30240Y4" = "1" /* Transfusion of Allogeneic Unspecified Hematopoietic Stem Cells into Central Vein, Open Approach */
"30243G2" = "1" /* Transfusion of Allogeneic Related Bone Marrow into Central Vein, Percutaneous Approach */
"30243G3" = "1" /* Transfusion of Allogeneic Unrelated Bone Marrow into Central Vein, Percutaneous Approach */
"30243G4" = "1" /* Transfusion of Allogeneic Unspecified Bone Marrow into Central Vein, Percutaneous Approach */
"30243X2" = "1" /* Transfusion of Allogeneic Related Cord Blood Stem Cells into Central Vein, Percutaneous Approach */
"30243X3" = "1" /* Transfusion of Allogeneic Unrelated Cord Blood Stem Cells into Central Vein, Percutaneous Approach */
"30243X4" = "1" /* Transfusion of Allogeneic Unspecified Cord Blood Stem Cells into Central Vein, Percutaneous Approach */
"30243Y2" = "1" /* Transfusion of Allogeneic Related Hematopoietic Stem Cells into Central Vein, Percutaneous Approach */
"30243Y3" = "1" /* Transfusion of Allogeneic Unrelated Hematopoietic Stem Cells into Central Vein, Percutaneous Approach */
"30243Y4" = "1" /* Transfusion of Allogeneic Unspecified Hematopoietic Stem Cells into Central Vein, Percutaneous Approach */
Other = "0"
;

Run;

*Restore source option to setting used prior to formats;
option &orgoptionValue;
